prompt PL/SQL Developer import file
prompt Created on Dienstag, 2. September 2014 by Cornel
set feedback off
set define off
prompt Creating CHARTS...
create table CHARTS
(
  day         NUMBER,
  corp        CHAR(5),
  stock_price NUMBER
)
;

prompt Creating CUSTOMERS...
create table CUSTOMERS
(
  customerid  NUMBER(11) not null,
  company     VARCHAR2(50 CHAR),
  lastname    VARCHAR2(50 CHAR),
  firstname   VARCHAR2(50 CHAR),
  street      VARCHAR2(50 CHAR),
  zip         VARCHAR2(25 CHAR),
  city        VARCHAR2(50 CHAR),
  countrycode VARCHAR2(5 CHAR),
  statecode   VARCHAR2(5 CHAR),
  phone       VARCHAR2(50 CHAR),
  fax         VARCHAR2(50 CHAR),
  e_mail      VARCHAR2(50 CHAR)
)
;
create index COUNTRYCODE on CUSTOMERS (COUNTRYCODE);
create index STATECODE on CUSTOMERS (STATECODE);
alter table CUSTOMERS
  add constraint PK_CUSTOMERS primary key (CUSTOMERID);

prompt Creating DIM_COLOUR...
create table DIM_COLOUR
(
  dcl_id         NUMBER(11) not null,
  dcl_colourname VARCHAR2(50 CHAR)
)
;
alter table DIM_COLOUR
  add constraint PK_DIMCOLOUR primary key (DCL_ID);

prompt Creating DIM_DATE...
create table DIM_DATE
(
  date_id            NUMBER(10) not null,
  day_date           DATE,
  day_of_week        VARCHAR2(1),
  day_of_month       VARCHAR2(2),
  day_of_year        VARCHAR2(3),
  month              VARCHAR2(2),
  year               VARCHAR2(4),
  iso_week           VARCHAR2(2),
  quarter            VARCHAR2(1),
  weekday_name       VARCHAR2(15),
  weekday_short_name VARCHAR2(5),
  month_name         VARCHAR2(15),
  month_short_name   VARCHAR2(5)
)
;
alter table DIM_DATE
  add constraint PK_DIMDATE primary key (DATE_ID);

prompt Creating DIM_MATERIAL...
create table DIM_MATERIAL
(
  dma_id           NUMBER(11) not null,
  dma_materialname VARCHAR2(50 CHAR)
)
;
alter table DIM_MATERIAL
  add constraint PK_DIMMATERIAL primary key (DMA_ID);

prompt Creating DIM_SHAPE...
create table DIM_SHAPE
(
  dsh_id        NUMBER(11) not null,
  dsh_shapename VARCHAR2(50 CHAR)
)
;
alter table DIM_SHAPE
  add constraint PK_DIMSHAPE primary key (DSH_ID);

prompt Creating FINRESULTS...
create table FINRESULTS
(
  year    DATE,
  revenue NUMBER(11)
)
;

prompt Creating FKT_SALES...
create table FKT_SALES
(
  date_id  NUMBER,
  dcl_id   NUMBER(11),
  dma_id   NUMBER(11),
  dsh_id   NUMBER(11),
  quantity NUMBER(11),
  amount   NUMBER(11)
)
;
create index FK_FKT_SALES_DIM_DATE on FKT_SALES (DATE_ID);
create index FKT_SALES_DIM_COLOUR on FKT_SALES (DCL_ID);
alter table FKT_SALES
  add constraint FK_COLOUR foreign key (DCL_ID)
  references DIM_COLOUR (DCL_ID);
alter table FKT_SALES
  add constraint FK_DATE foreign key (DATE_ID)
  references DIM_DATE (DATE_ID);
alter table FKT_SALES
  add constraint FK_MATERIAL foreign key (DMA_ID)
  references DIM_MATERIAL (DMA_ID);
alter table FKT_SALES
  add constraint FK_SHAPE foreign key (DSH_ID)
  references DIM_SHAPE (DSH_ID);

prompt Creating INVOICES...
create table INVOICES
(
  invno      NUMBER(16) not null,
  invdate    DATE,
  duedate    DATE,
  customerid NUMBER(11),
  invamount  NUMBER(11) default 0,
  paydate    DATE
)
;
create index FK_INVTOSINVOICES on INVOICES (CUSTOMERID);
alter table INVOICES
  add constraint PK_INVOICES primary key (INVNO);
alter table INVOICES
  add constraint CUSTOMERS_INVOICES foreign key (CUSTOMERID)
  references CUSTOMERS (CUSTOMERID);

prompt Creating PRODCOLOURS...
create table PRODCOLOURS
(
  prodcolourid   NUMBER(11) not null,
  prodcolourname VARCHAR2(50 CHAR)
)
;
alter table PRODCOLOURS
  add constraint PK_PRODCOLOURS primary key (PRODCOLOURID);

prompt Creating PRODFORMS...
create table PRODFORMS
(
  prodformid   NUMBER(11) not null,
  prodformname VARCHAR2(50 CHAR)
)
;
alter table PRODFORMS
  add constraint PK_PRODFORMS primary key (PRODFORMID);

prompt Creating PRODMATERIAL...
create table PRODMATERIAL
(
  prodmaterialid   NUMBER(11) not null,
  prodmaterialname VARCHAR2(50 CHAR)
)
;
alter table PRODMATERIAL
  add constraint PK_PRODMATERIAL primary key (PRODMATERIALID);

prompt Creating PRODUCTS...
create table PRODUCTS
(
  productid      NUMBER(11) not null,
  productname    VARCHAR2(50 CHAR),
  prodcolourid   NUMBER(11),
  prodformid     NUMBER(11),
  prodmaterialid NUMBER(11),
  productprice   NUMBER(11)
)
;
create index FK_PRODCOLOURSPRODUCTS on PRODUCTS (PRODCOLOURID);
create index PRODFORMID on PRODUCTS (PRODFORMID);
create index PRODMATERIALID on PRODUCTS (PRODMATERIALID);
alter table PRODUCTS
  add constraint PK_PRODUCTS primary key (PRODUCTID);
alter table PRODUCTS
  add constraint PRODCOLOURSPRODUCTS foreign key (PRODCOLOURID)
  references PRODCOLOURS (PRODCOLOURID);
alter table PRODUCTS
  add constraint PRODFORMSPRODUCTS foreign key (PRODFORMID)
  references PRODFORMS (PRODFORMID);
alter table PRODUCTS
  add constraint PRODMATERIALPRODUCTS foreign key (PRODMATERIALID)
  references PRODMATERIAL (PRODMATERIALID);

prompt Creating INVLINES...
create table INVLINES
(
  invno         NUMBER(16) not null,
  invlineno     NUMBER(11) not null,
  productid     NUMBER(11),
  quantity      NUMBER(11),
  price         NUMBER(11),
  invlineamount NUMBER(11)
)
;
create index FK_INVOICESINVDETAILS on INVLINES (INVNO);
create index PRODUCTID on INVLINES (PRODUCTID);
alter table INVLINES
  add constraint PK_INVLINES primary key (INVNO, INVLINENO);
alter table INVLINES
  add constraint INVOICESINVDETAILS foreign key (INVNO)
  references INVOICES (INVNO);
alter table INVLINES
  add constraint PRODUCTSINVDETAILS foreign key (PRODUCTID)
  references PRODUCTS (PRODUCTID);

prompt Creating LAUNDERING_ACCOUNT...
create table LAUNDERING_ACCOUNT
(
  transaction_nr INTEGER,
  booking_date   DATE,
  amount         NUMBER,
  text           VARCHAR2(100)
)
;

prompt Creating MEIERS...
create table MEIERS
(
  name VARCHAR2(100)
)
;

prompt Creating REALCHARTS...
create table REALCHARTS
(
  symbol VARCHAR2(10),
  day    DATE,
  open   NUMBER,
  high   NUMBER,
  low    NUMBER,
  close  NUMBER
)
;

prompt Creating RESULTS...
create table RESULTS
(
  year    DATE,
  corp    CHAR(5),
  revenue NUMBER(11)
)
;

prompt Creating REVENUE...
create table REVENUE
(
  revenue NUMBER
)
;

prompt Creating REVYEAR...
create table REVYEAR
(
  calyear NUMBER,
  revenue NUMBER
)
;

prompt Creating RUSSIAN_BUSINESS...
create table RUSSIAN_BUSINESS
(
  name VARCHAR2(100)
)
;

prompt Disabling triggers for CHARTS...
alter table CHARTS disable all triggers;
prompt Disabling triggers for CUSTOMERS...
alter table CUSTOMERS disable all triggers;
prompt Disabling triggers for DIM_COLOUR...
alter table DIM_COLOUR disable all triggers;
prompt Disabling triggers for DIM_DATE...
alter table DIM_DATE disable all triggers;
prompt Disabling triggers for DIM_MATERIAL...
alter table DIM_MATERIAL disable all triggers;
prompt Disabling triggers for DIM_SHAPE...
alter table DIM_SHAPE disable all triggers;
prompt Disabling triggers for FINRESULTS...
alter table FINRESULTS disable all triggers;
prompt Disabling triggers for FKT_SALES...
alter table FKT_SALES disable all triggers;
prompt Disabling triggers for INVOICES...
alter table INVOICES disable all triggers;
prompt Disabling triggers for PRODCOLOURS...
alter table PRODCOLOURS disable all triggers;
prompt Disabling triggers for PRODFORMS...
alter table PRODFORMS disable all triggers;
prompt Disabling triggers for PRODMATERIAL...
alter table PRODMATERIAL disable all triggers;
prompt Disabling triggers for PRODUCTS...
alter table PRODUCTS disable all triggers;
prompt Disabling triggers for INVLINES...
alter table INVLINES disable all triggers;
prompt Disabling triggers for LAUNDERING_ACCOUNT...
alter table LAUNDERING_ACCOUNT disable all triggers;
prompt Disabling triggers for MEIERS...
alter table MEIERS disable all triggers;
prompt Disabling triggers for REALCHARTS...
alter table REALCHARTS disable all triggers;
prompt Disabling triggers for RESULTS...
alter table RESULTS disable all triggers;
prompt Disabling triggers for REVENUE...
alter table REVENUE disable all triggers;
prompt Disabling triggers for REVYEAR...
alter table REVYEAR disable all triggers;
prompt Disabling triggers for RUSSIAN_BUSINESS...
alter table RUSSIAN_BUSINESS disable all triggers;
prompt Disabling foreign key constraints for FKT_SALES...
alter table FKT_SALES disable constraint FK_COLOUR;
alter table FKT_SALES disable constraint FK_DATE;
alter table FKT_SALES disable constraint FK_MATERIAL;
alter table FKT_SALES disable constraint FK_SHAPE;
prompt Disabling foreign key constraints for INVOICES...
alter table INVOICES disable constraint CUSTOMERS_INVOICES;
prompt Disabling foreign key constraints for PRODUCTS...
alter table PRODUCTS disable constraint PRODCOLOURSPRODUCTS;
alter table PRODUCTS disable constraint PRODFORMSPRODUCTS;
alter table PRODUCTS disable constraint PRODMATERIALPRODUCTS;
prompt Disabling foreign key constraints for INVLINES...
alter table INVLINES disable constraint INVOICESINVDETAILS;
alter table INVLINES disable constraint PRODUCTSINVDETAILS;
prompt Loading CHARTS...
insert into CHARTS (day, corp, stock_price)
values (1, 'CORP1', 100);
insert into CHARTS (day, corp, stock_price)
values (2, 'CORP1', 150);
insert into CHARTS (day, corp, stock_price)
values (3, 'CORP1', 160);
insert into CHARTS (day, corp, stock_price)
values (4, 'CORP1', 200);
insert into CHARTS (day, corp, stock_price)
values (5, 'CORP1', 170);
insert into CHARTS (day, corp, stock_price)
values (6, 'CORP1', 130);
insert into CHARTS (day, corp, stock_price)
values (7, 'CORP1', 190);
insert into CHARTS (day, corp, stock_price)
values (8, 'CORP1', 160);
insert into CHARTS (day, corp, stock_price)
values (9, 'CORP1', 200);
insert into CHARTS (day, corp, stock_price)
values (10, 'CORP1', 140);
insert into CHARTS (day, corp, stock_price)
values (11, 'CORP1', 120);
insert into CHARTS (day, corp, stock_price)
values (12, 'CORP1', 90);
insert into CHARTS (day, corp, stock_price)
values (13, 'CORP1', 100);
insert into CHARTS (day, corp, stock_price)
values (14, 'CORP1', 110);
insert into CHARTS (day, corp, stock_price)
values (15, 'CORP1', 150);
insert into CHARTS (day, corp, stock_price)
values (16, 'CORP1', 140);
insert into CHARTS (day, corp, stock_price)
values (17, 'CORP1', 160);
insert into CHARTS (day, corp, stock_price)
values (18, 'CORP1', 180);
insert into CHARTS (day, corp, stock_price)
values (19, 'CORP1', 200);
insert into CHARTS (day, corp, stock_price)
values (20, 'CORP1', 210);
insert into CHARTS (day, corp, stock_price)
values (1, 'CORP2', 127);
insert into CHARTS (day, corp, stock_price)
values (2, 'CORP2', 151);
insert into CHARTS (day, corp, stock_price)
values (3, 'CORP2', 126);
insert into CHARTS (day, corp, stock_price)
values (4, 'CORP2', 224);
insert into CHARTS (day, corp, stock_price)
values (5, 'CORP2', 208);
insert into CHARTS (day, corp, stock_price)
values (6, 'CORP2', 169);
insert into CHARTS (day, corp, stock_price)
values (7, 'CORP2', 214);
insert into CHARTS (day, corp, stock_price)
values (8, 'CORP2', 144);
insert into CHARTS (day, corp, stock_price)
values (9, 'CORP2', 167);
insert into CHARTS (day, corp, stock_price)
values (10, 'CORP2', 153);
insert into CHARTS (day, corp, stock_price)
values (11, 'CORP2', 92);
insert into CHARTS (day, corp, stock_price)
values (12, 'CORP2', 75);
insert into CHARTS (day, corp, stock_price)
values (13, 'CORP2', 119);
insert into CHARTS (day, corp, stock_price)
values (14, 'CORP2', 135);
insert into CHARTS (day, corp, stock_price)
values (15, 'CORP2', 134);
insert into CHARTS (day, corp, stock_price)
values (16, 'CORP2', 122);
insert into CHARTS (day, corp, stock_price)
values (17, 'CORP2', 152);
insert into CHARTS (day, corp, stock_price)
values (18, 'CORP2', 198);
insert into CHARTS (day, corp, stock_price)
values (19, 'CORP2', 164);
insert into CHARTS (day, corp, stock_price)
values (20, 'CORP2', 241);
insert into CHARTS (day, corp, stock_price)
values (1, 'CORP3', 123);
insert into CHARTS (day, corp, stock_price)
values (2, 'CORP3', 173);
insert into CHARTS (day, corp, stock_price)
values (3, 'CORP3', 209);
insert into CHARTS (day, corp, stock_price)
values (4, 'CORP3', 222);
insert into CHARTS (day, corp, stock_price)
values (5, 'CORP3', 213);
insert into CHARTS (day, corp, stock_price)
values (6, 'CORP3', 166);
insert into CHARTS (day, corp, stock_price)
values (7, 'CORP3', 144);
insert into CHARTS (day, corp, stock_price)
values (8, 'CORP3', 159);
insert into CHARTS (day, corp, stock_price)
values (9, 'CORP3', 227);
insert into CHARTS (day, corp, stock_price)
values (10, 'CORP3', 129);
insert into CHARTS (day, corp, stock_price)
values (11, 'CORP3', 74);
insert into CHARTS (day, corp, stock_price)
values (12, 'CORP3', 124);
insert into CHARTS (day, corp, stock_price)
values (13, 'CORP3', 103);
insert into CHARTS (day, corp, stock_price)
values (14, 'CORP3', 129);
insert into CHARTS (day, corp, stock_price)
values (15, 'CORP3', 167);
insert into CHARTS (day, corp, stock_price)
values (16, 'CORP3', 117);
insert into CHARTS (day, corp, stock_price)
values (17, 'CORP3', 129);
insert into CHARTS (day, corp, stock_price)
values (18, 'CORP3', 151);
insert into CHARTS (day, corp, stock_price)
values (19, 'CORP3', 193);
insert into CHARTS (day, corp, stock_price)
values (20, 'CORP3', 252);
commit;
prompt 60 records loaded
prompt Loading CUSTOMERS...
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (1, 'Miller Ltd.', 'Miller', 'Sean', 'Elm Street', 'WC2E 7LB', 'London', 'GB', null, null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (2, 'Mller GmbH', 'Mller', 'Siegfried', 'Bahnhofstr. 12', '60311', 'Frankfurt', 'DE', 'HE', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (3, 'Cordonbleu SA', 'Cordonbleu', 'Pierre', 'Rue de la Concorde 12', '75001', 'Paris', 'FR', null, null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (4, 'Meier AG', 'Meier', 'Michael', 'Hauptstr. 23', '64283', 'Darmstadt', 'DE', 'HE', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (5, 'Schmidt OHG', 'Schmidt', 'Willi', 'Postweg 17', '20095', 'Hamburg', 'DE', 'HH', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (6, 'Schulze GmbH', 'Schulze', 'Max', 'Feldbergstr. 77', '79098', 'Freiburg', 'DE', 'BW', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (7, 'Camembert SA', 'Camembert', 'Jaques', 'Avenue Fromage 3', '13011', 'Marseille', 'FR', null, null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (8, 'Foster plc', 'Foster', 'Henry', 'Main Street', 'EH14 2SP', 'Edinburgh', 'GB', null, null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (9, 'Zocker AG', 'Zocker', 'Karl', 'Zuse-Str. 83', '80331', 'Mnchen', 'DE', 'BY', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (10, 'Baller GmbH', 'Baller', 'Toni', 'Malle-Weg 93', '63065', 'Offenbach', 'DE', 'HE', null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (11, 'Cambozola s.r.l.', 'Toni', 'Cambozola', 'Via Roma 98', '20100', 'Milano', 'IT', null, null, null, null);
insert into CUSTOMERS (customerid, company, lastname, firstname, street, zip, city, countrycode, statecode, phone, fax, e_mail)
values (12, 'Cheddar plc', 'Cheddar', 'Charles', 'Cracker Street 5', 'BN2 0GN', 'Brighton', 'GB', null, null, null, null);
commit;
prompt 12 records loaded
prompt Loading DIM_COLOUR...
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (1, 'Schwarz');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (2, 'Rot');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (3, 'Gold');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (4, 'Blau');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (5, 'Weiss');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (6, 'Grn');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (7, 'Gelb');
insert into DIM_COLOUR (dcl_id, dcl_colourname)
values (8, 'Silber');
commit;
prompt 8 records loaded
prompt Loading DIM_DATE...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3890, to_date('25-08-2010', 'dd-mm-yyyy'), '3', '25', '237', '08', '2010', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3891, to_date('26-08-2010', 'dd-mm-yyyy'), '4', '26', '238', '08', '2010', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3892, to_date('27-08-2010', 'dd-mm-yyyy'), '5', '27', '239', '08', '2010', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3893, to_date('28-08-2010', 'dd-mm-yyyy'), '6', '28', '240', '08', '2010', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3894, to_date('29-08-2010', 'dd-mm-yyyy'), '7', '29', '241', '08', '2010', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3895, to_date('30-08-2010', 'dd-mm-yyyy'), '1', '30', '242', '08', '2010', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3896, to_date('31-08-2010', 'dd-mm-yyyy'), '2', '31', '243', '08', '2010', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3897, to_date('01-09-2010', 'dd-mm-yyyy'), '3', '01', '244', '09', '2010', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3898, to_date('02-09-2010', 'dd-mm-yyyy'), '4', '02', '245', '09', '2010', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3899, to_date('03-09-2010', 'dd-mm-yyyy'), '5', '03', '246', '09', '2010', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3900, to_date('04-09-2010', 'dd-mm-yyyy'), '6', '04', '247', '09', '2010', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3901, to_date('05-09-2010', 'dd-mm-yyyy'), '7', '05', '248', '09', '2010', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3902, to_date('06-09-2010', 'dd-mm-yyyy'), '1', '06', '249', '09', '2010', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3903, to_date('07-09-2010', 'dd-mm-yyyy'), '2', '07', '250', '09', '2010', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3904, to_date('08-09-2010', 'dd-mm-yyyy'), '3', '08', '251', '09', '2010', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3905, to_date('09-09-2010', 'dd-mm-yyyy'), '4', '09', '252', '09', '2010', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3906, to_date('10-09-2010', 'dd-mm-yyyy'), '5', '10', '253', '09', '2010', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3907, to_date('11-09-2010', 'dd-mm-yyyy'), '6', '11', '254', '09', '2010', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3908, to_date('12-09-2010', 'dd-mm-yyyy'), '7', '12', '255', '09', '2010', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3909, to_date('13-09-2010', 'dd-mm-yyyy'), '1', '13', '256', '09', '2010', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3910, to_date('14-09-2010', 'dd-mm-yyyy'), '2', '14', '257', '09', '2010', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3911, to_date('15-09-2010', 'dd-mm-yyyy'), '3', '15', '258', '09', '2010', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3912, to_date('16-09-2010', 'dd-mm-yyyy'), '4', '16', '259', '09', '2010', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3913, to_date('17-09-2010', 'dd-mm-yyyy'), '5', '17', '260', '09', '2010', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3914, to_date('18-09-2010', 'dd-mm-yyyy'), '6', '18', '261', '09', '2010', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3915, to_date('19-09-2010', 'dd-mm-yyyy'), '7', '19', '262', '09', '2010', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3916, to_date('20-09-2010', 'dd-mm-yyyy'), '1', '20', '263', '09', '2010', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3917, to_date('21-09-2010', 'dd-mm-yyyy'), '2', '21', '264', '09', '2010', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3918, to_date('22-09-2010', 'dd-mm-yyyy'), '3', '22', '265', '09', '2010', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3919, to_date('23-09-2010', 'dd-mm-yyyy'), '4', '23', '266', '09', '2010', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3920, to_date('24-09-2010', 'dd-mm-yyyy'), '5', '24', '267', '09', '2010', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3921, to_date('25-09-2010', 'dd-mm-yyyy'), '6', '25', '268', '09', '2010', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3922, to_date('26-09-2010', 'dd-mm-yyyy'), '7', '26', '269', '09', '2010', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3923, to_date('27-09-2010', 'dd-mm-yyyy'), '1', '27', '270', '09', '2010', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3924, to_date('28-09-2010', 'dd-mm-yyyy'), '2', '28', '271', '09', '2010', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3925, to_date('29-09-2010', 'dd-mm-yyyy'), '3', '29', '272', '09', '2010', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3926, to_date('30-09-2010', 'dd-mm-yyyy'), '4', '30', '273', '09', '2010', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3927, to_date('01-10-2010', 'dd-mm-yyyy'), '5', '01', '274', '10', '2010', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3928, to_date('02-10-2010', 'dd-mm-yyyy'), '6', '02', '275', '10', '2010', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3929, to_date('03-10-2010', 'dd-mm-yyyy'), '7', '03', '276', '10', '2010', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3930, to_date('04-10-2010', 'dd-mm-yyyy'), '1', '04', '277', '10', '2010', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3931, to_date('05-10-2010', 'dd-mm-yyyy'), '2', '05', '278', '10', '2010', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3932, to_date('06-10-2010', 'dd-mm-yyyy'), '3', '06', '279', '10', '2010', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3933, to_date('07-10-2010', 'dd-mm-yyyy'), '4', '07', '280', '10', '2010', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3934, to_date('08-10-2010', 'dd-mm-yyyy'), '5', '08', '281', '10', '2010', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3935, to_date('09-10-2010', 'dd-mm-yyyy'), '6', '09', '282', '10', '2010', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3936, to_date('10-10-2010', 'dd-mm-yyyy'), '7', '10', '283', '10', '2010', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3937, to_date('11-10-2010', 'dd-mm-yyyy'), '1', '11', '284', '10', '2010', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3938, to_date('12-10-2010', 'dd-mm-yyyy'), '2', '12', '285', '10', '2010', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3939, to_date('13-10-2010', 'dd-mm-yyyy'), '3', '13', '286', '10', '2010', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3940, to_date('14-10-2010', 'dd-mm-yyyy'), '4', '14', '287', '10', '2010', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3941, to_date('15-10-2010', 'dd-mm-yyyy'), '5', '15', '288', '10', '2010', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3942, to_date('16-10-2010', 'dd-mm-yyyy'), '6', '16', '289', '10', '2010', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3943, to_date('17-10-2010', 'dd-mm-yyyy'), '7', '17', '290', '10', '2010', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3944, to_date('18-10-2010', 'dd-mm-yyyy'), '1', '18', '291', '10', '2010', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3945, to_date('19-10-2010', 'dd-mm-yyyy'), '2', '19', '292', '10', '2010', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3946, to_date('20-10-2010', 'dd-mm-yyyy'), '3', '20', '293', '10', '2010', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3947, to_date('21-10-2010', 'dd-mm-yyyy'), '4', '21', '294', '10', '2010', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3948, to_date('22-10-2010', 'dd-mm-yyyy'), '5', '22', '295', '10', '2010', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3949, to_date('23-10-2010', 'dd-mm-yyyy'), '6', '23', '296', '10', '2010', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3950, to_date('24-10-2010', 'dd-mm-yyyy'), '7', '24', '297', '10', '2010', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3951, to_date('25-10-2010', 'dd-mm-yyyy'), '1', '25', '298', '10', '2010', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3952, to_date('26-10-2010', 'dd-mm-yyyy'), '2', '26', '299', '10', '2010', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3953, to_date('27-10-2010', 'dd-mm-yyyy'), '3', '27', '300', '10', '2010', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3954, to_date('28-10-2010', 'dd-mm-yyyy'), '4', '28', '301', '10', '2010', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3955, to_date('29-10-2010', 'dd-mm-yyyy'), '5', '29', '302', '10', '2010', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3956, to_date('30-10-2010', 'dd-mm-yyyy'), '6', '30', '303', '10', '2010', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3957, to_date('31-10-2010', 'dd-mm-yyyy'), '7', '31', '304', '10', '2010', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3958, to_date('01-11-2010', 'dd-mm-yyyy'), '1', '01', '305', '11', '2010', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3959, to_date('02-11-2010', 'dd-mm-yyyy'), '2', '02', '306', '11', '2010', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3960, to_date('03-11-2010', 'dd-mm-yyyy'), '3', '03', '307', '11', '2010', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3961, to_date('04-11-2010', 'dd-mm-yyyy'), '4', '04', '308', '11', '2010', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3962, to_date('05-11-2010', 'dd-mm-yyyy'), '5', '05', '309', '11', '2010', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3963, to_date('06-11-2010', 'dd-mm-yyyy'), '6', '06', '310', '11', '2010', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3964, to_date('07-11-2010', 'dd-mm-yyyy'), '7', '07', '311', '11', '2010', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3965, to_date('08-11-2010', 'dd-mm-yyyy'), '1', '08', '312', '11', '2010', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3966, to_date('09-11-2010', 'dd-mm-yyyy'), '2', '09', '313', '11', '2010', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3967, to_date('10-11-2010', 'dd-mm-yyyy'), '3', '10', '314', '11', '2010', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3968, to_date('11-11-2010', 'dd-mm-yyyy'), '4', '11', '315', '11', '2010', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3969, to_date('12-11-2010', 'dd-mm-yyyy'), '5', '12', '316', '11', '2010', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3970, to_date('13-11-2010', 'dd-mm-yyyy'), '6', '13', '317', '11', '2010', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3971, to_date('14-11-2010', 'dd-mm-yyyy'), '7', '14', '318', '11', '2010', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3972, to_date('15-11-2010', 'dd-mm-yyyy'), '1', '15', '319', '11', '2010', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3973, to_date('16-11-2010', 'dd-mm-yyyy'), '2', '16', '320', '11', '2010', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3974, to_date('17-11-2010', 'dd-mm-yyyy'), '3', '17', '321', '11', '2010', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3975, to_date('18-11-2010', 'dd-mm-yyyy'), '4', '18', '322', '11', '2010', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3976, to_date('19-11-2010', 'dd-mm-yyyy'), '5', '19', '323', '11', '2010', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3977, to_date('20-11-2010', 'dd-mm-yyyy'), '6', '20', '324', '11', '2010', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3978, to_date('21-11-2010', 'dd-mm-yyyy'), '7', '21', '325', '11', '2010', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3979, to_date('22-11-2010', 'dd-mm-yyyy'), '1', '22', '326', '11', '2010', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3980, to_date('23-11-2010', 'dd-mm-yyyy'), '2', '23', '327', '11', '2010', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3981, to_date('24-11-2010', 'dd-mm-yyyy'), '3', '24', '328', '11', '2010', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3982, to_date('25-11-2010', 'dd-mm-yyyy'), '4', '25', '329', '11', '2010', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3983, to_date('26-11-2010', 'dd-mm-yyyy'), '5', '26', '330', '11', '2010', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3984, to_date('27-11-2010', 'dd-mm-yyyy'), '6', '27', '331', '11', '2010', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3985, to_date('28-11-2010', 'dd-mm-yyyy'), '7', '28', '332', '11', '2010', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3986, to_date('29-11-2010', 'dd-mm-yyyy'), '1', '29', '333', '11', '2010', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3987, to_date('30-11-2010', 'dd-mm-yyyy'), '2', '30', '334', '11', '2010', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3988, to_date('01-12-2010', 'dd-mm-yyyy'), '3', '01', '335', '12', '2010', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3989, to_date('02-12-2010', 'dd-mm-yyyy'), '4', '02', '336', '12', '2010', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3990, to_date('03-12-2010', 'dd-mm-yyyy'), '5', '03', '337', '12', '2010', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3991, to_date('04-12-2010', 'dd-mm-yyyy'), '6', '04', '338', '12', '2010', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3992, to_date('05-12-2010', 'dd-mm-yyyy'), '7', '05', '339', '12', '2010', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3993, to_date('06-12-2010', 'dd-mm-yyyy'), '1', '06', '340', '12', '2010', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3994, to_date('07-12-2010', 'dd-mm-yyyy'), '2', '07', '341', '12', '2010', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3995, to_date('08-12-2010', 'dd-mm-yyyy'), '3', '08', '342', '12', '2010', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3996, to_date('09-12-2010', 'dd-mm-yyyy'), '4', '09', '343', '12', '2010', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3997, to_date('10-12-2010', 'dd-mm-yyyy'), '5', '10', '344', '12', '2010', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3998, to_date('11-12-2010', 'dd-mm-yyyy'), '6', '11', '345', '12', '2010', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3999, to_date('12-12-2010', 'dd-mm-yyyy'), '7', '12', '346', '12', '2010', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4000, to_date('13-12-2010', 'dd-mm-yyyy'), '1', '13', '347', '12', '2010', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4001, to_date('14-12-2010', 'dd-mm-yyyy'), '2', '14', '348', '12', '2010', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4002, to_date('15-12-2010', 'dd-mm-yyyy'), '3', '15', '349', '12', '2010', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4003, to_date('16-12-2010', 'dd-mm-yyyy'), '4', '16', '350', '12', '2010', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4004, to_date('17-12-2010', 'dd-mm-yyyy'), '5', '17', '351', '12', '2010', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4005, to_date('18-12-2010', 'dd-mm-yyyy'), '6', '18', '352', '12', '2010', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4006, to_date('19-12-2010', 'dd-mm-yyyy'), '7', '19', '353', '12', '2010', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4007, to_date('20-12-2010', 'dd-mm-yyyy'), '1', '20', '354', '12', '2010', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4008, to_date('21-12-2010', 'dd-mm-yyyy'), '2', '21', '355', '12', '2010', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4009, to_date('22-12-2010', 'dd-mm-yyyy'), '3', '22', '356', '12', '2010', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4010, to_date('23-12-2010', 'dd-mm-yyyy'), '4', '23', '357', '12', '2010', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4011, to_date('24-12-2010', 'dd-mm-yyyy'), '5', '24', '358', '12', '2010', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4012, to_date('25-12-2010', 'dd-mm-yyyy'), '6', '25', '359', '12', '2010', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4013, to_date('26-12-2010', 'dd-mm-yyyy'), '7', '26', '360', '12', '2010', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4014, to_date('27-12-2010', 'dd-mm-yyyy'), '1', '27', '361', '12', '2010', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4015, to_date('28-12-2010', 'dd-mm-yyyy'), '2', '28', '362', '12', '2010', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4016, to_date('29-12-2010', 'dd-mm-yyyy'), '3', '29', '363', '12', '2010', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4017, to_date('30-12-2010', 'dd-mm-yyyy'), '4', '30', '364', '12', '2010', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4018, to_date('31-12-2010', 'dd-mm-yyyy'), '5', '31', '365', '12', '2010', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4019, to_date('01-01-2011', 'dd-mm-yyyy'), '6', '01', '001', '01', '2011', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4020, to_date('02-01-2011', 'dd-mm-yyyy'), '7', '02', '002', '01', '2011', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4021, to_date('03-01-2011', 'dd-mm-yyyy'), '1', '03', '003', '01', '2011', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4022, to_date('04-01-2011', 'dd-mm-yyyy'), '2', '04', '004', '01', '2011', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4023, to_date('05-01-2011', 'dd-mm-yyyy'), '3', '05', '005', '01', '2011', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4024, to_date('06-01-2011', 'dd-mm-yyyy'), '4', '06', '006', '01', '2011', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4025, to_date('07-01-2011', 'dd-mm-yyyy'), '5', '07', '007', '01', '2011', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4026, to_date('08-01-2011', 'dd-mm-yyyy'), '6', '08', '008', '01', '2011', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4027, to_date('09-01-2011', 'dd-mm-yyyy'), '7', '09', '009', '01', '2011', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4028, to_date('10-01-2011', 'dd-mm-yyyy'), '1', '10', '010', '01', '2011', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4029, to_date('11-01-2011', 'dd-mm-yyyy'), '2', '11', '011', '01', '2011', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4030, to_date('12-01-2011', 'dd-mm-yyyy'), '3', '12', '012', '01', '2011', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4031, to_date('13-01-2011', 'dd-mm-yyyy'), '4', '13', '013', '01', '2011', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4032, to_date('14-01-2011', 'dd-mm-yyyy'), '5', '14', '014', '01', '2011', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4033, to_date('15-01-2011', 'dd-mm-yyyy'), '6', '15', '015', '01', '2011', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4034, to_date('16-01-2011', 'dd-mm-yyyy'), '7', '16', '016', '01', '2011', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4035, to_date('17-01-2011', 'dd-mm-yyyy'), '1', '17', '017', '01', '2011', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4036, to_date('18-01-2011', 'dd-mm-yyyy'), '2', '18', '018', '01', '2011', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4037, to_date('19-01-2011', 'dd-mm-yyyy'), '3', '19', '019', '01', '2011', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4038, to_date('20-01-2011', 'dd-mm-yyyy'), '4', '20', '020', '01', '2011', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4039, to_date('21-01-2011', 'dd-mm-yyyy'), '5', '21', '021', '01', '2011', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4040, to_date('22-01-2011', 'dd-mm-yyyy'), '6', '22', '022', '01', '2011', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4041, to_date('23-01-2011', 'dd-mm-yyyy'), '7', '23', '023', '01', '2011', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4042, to_date('24-01-2011', 'dd-mm-yyyy'), '1', '24', '024', '01', '2011', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4043, to_date('25-01-2011', 'dd-mm-yyyy'), '2', '25', '025', '01', '2011', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4044, to_date('26-01-2011', 'dd-mm-yyyy'), '3', '26', '026', '01', '2011', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4045, to_date('27-01-2011', 'dd-mm-yyyy'), '4', '27', '027', '01', '2011', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4046, to_date('28-01-2011', 'dd-mm-yyyy'), '5', '28', '028', '01', '2011', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4047, to_date('29-01-2011', 'dd-mm-yyyy'), '6', '29', '029', '01', '2011', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4048, to_date('30-01-2011', 'dd-mm-yyyy'), '7', '30', '030', '01', '2011', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4049, to_date('31-01-2011', 'dd-mm-yyyy'), '1', '31', '031', '01', '2011', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4050, to_date('01-02-2011', 'dd-mm-yyyy'), '2', '01', '032', '02', '2011', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4051, to_date('02-02-2011', 'dd-mm-yyyy'), '3', '02', '033', '02', '2011', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4052, to_date('03-02-2011', 'dd-mm-yyyy'), '4', '03', '034', '02', '2011', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4053, to_date('04-02-2011', 'dd-mm-yyyy'), '5', '04', '035', '02', '2011', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4054, to_date('05-02-2011', 'dd-mm-yyyy'), '6', '05', '036', '02', '2011', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4055, to_date('06-02-2011', 'dd-mm-yyyy'), '7', '06', '037', '02', '2011', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4056, to_date('07-02-2011', 'dd-mm-yyyy'), '1', '07', '038', '02', '2011', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4057, to_date('08-02-2011', 'dd-mm-yyyy'), '2', '08', '039', '02', '2011', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4058, to_date('09-02-2011', 'dd-mm-yyyy'), '3', '09', '040', '02', '2011', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4059, to_date('10-02-2011', 'dd-mm-yyyy'), '4', '10', '041', '02', '2011', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4060, to_date('11-02-2011', 'dd-mm-yyyy'), '5', '11', '042', '02', '2011', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4061, to_date('12-02-2011', 'dd-mm-yyyy'), '6', '12', '043', '02', '2011', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4062, to_date('13-02-2011', 'dd-mm-yyyy'), '7', '13', '044', '02', '2011', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4063, to_date('14-02-2011', 'dd-mm-yyyy'), '1', '14', '045', '02', '2011', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4064, to_date('15-02-2011', 'dd-mm-yyyy'), '2', '15', '046', '02', '2011', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4065, to_date('16-02-2011', 'dd-mm-yyyy'), '3', '16', '047', '02', '2011', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4066, to_date('17-02-2011', 'dd-mm-yyyy'), '4', '17', '048', '02', '2011', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4067, to_date('18-02-2011', 'dd-mm-yyyy'), '5', '18', '049', '02', '2011', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4068, to_date('19-02-2011', 'dd-mm-yyyy'), '6', '19', '050', '02', '2011', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4069, to_date('20-02-2011', 'dd-mm-yyyy'), '7', '20', '051', '02', '2011', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4070, to_date('21-02-2011', 'dd-mm-yyyy'), '1', '21', '052', '02', '2011', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4071, to_date('22-02-2011', 'dd-mm-yyyy'), '2', '22', '053', '02', '2011', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4072, to_date('23-02-2011', 'dd-mm-yyyy'), '3', '23', '054', '02', '2011', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4073, to_date('24-02-2011', 'dd-mm-yyyy'), '4', '24', '055', '02', '2011', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4074, to_date('25-02-2011', 'dd-mm-yyyy'), '5', '25', '056', '02', '2011', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4075, to_date('26-02-2011', 'dd-mm-yyyy'), '6', '26', '057', '02', '2011', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4076, to_date('27-02-2011', 'dd-mm-yyyy'), '7', '27', '058', '02', '2011', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4077, to_date('28-02-2011', 'dd-mm-yyyy'), '1', '28', '059', '02', '2011', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4078, to_date('01-03-2011', 'dd-mm-yyyy'), '2', '01', '060', '03', '2011', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4079, to_date('02-03-2011', 'dd-mm-yyyy'), '3', '02', '061', '03', '2011', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4080, to_date('03-03-2011', 'dd-mm-yyyy'), '4', '03', '062', '03', '2011', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4081, to_date('04-03-2011', 'dd-mm-yyyy'), '5', '04', '063', '03', '2011', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4082, to_date('05-03-2011', 'dd-mm-yyyy'), '6', '05', '064', '03', '2011', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4083, to_date('06-03-2011', 'dd-mm-yyyy'), '7', '06', '065', '03', '2011', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4084, to_date('07-03-2011', 'dd-mm-yyyy'), '1', '07', '066', '03', '2011', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4085, to_date('08-03-2011', 'dd-mm-yyyy'), '2', '08', '067', '03', '2011', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4086, to_date('09-03-2011', 'dd-mm-yyyy'), '3', '09', '068', '03', '2011', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4087, to_date('10-03-2011', 'dd-mm-yyyy'), '4', '10', '069', '03', '2011', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4088, to_date('11-03-2011', 'dd-mm-yyyy'), '5', '11', '070', '03', '2011', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4089, to_date('12-03-2011', 'dd-mm-yyyy'), '6', '12', '071', '03', '2011', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4090, to_date('13-03-2011', 'dd-mm-yyyy'), '7', '13', '072', '03', '2011', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4091, to_date('14-03-2011', 'dd-mm-yyyy'), '1', '14', '073', '03', '2011', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4092, to_date('15-03-2011', 'dd-mm-yyyy'), '2', '15', '074', '03', '2011', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4093, to_date('16-03-2011', 'dd-mm-yyyy'), '3', '16', '075', '03', '2011', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4094, to_date('17-03-2011', 'dd-mm-yyyy'), '4', '17', '076', '03', '2011', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4095, to_date('18-03-2011', 'dd-mm-yyyy'), '5', '18', '077', '03', '2011', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4096, to_date('19-03-2011', 'dd-mm-yyyy'), '6', '19', '078', '03', '2011', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4097, to_date('20-03-2011', 'dd-mm-yyyy'), '7', '20', '079', '03', '2011', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4098, to_date('21-03-2011', 'dd-mm-yyyy'), '1', '21', '080', '03', '2011', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4099, to_date('22-03-2011', 'dd-mm-yyyy'), '2', '22', '081', '03', '2011', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4100, to_date('23-03-2011', 'dd-mm-yyyy'), '3', '23', '082', '03', '2011', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4101, to_date('24-03-2011', 'dd-mm-yyyy'), '4', '24', '083', '03', '2011', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4102, to_date('25-03-2011', 'dd-mm-yyyy'), '5', '25', '084', '03', '2011', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4103, to_date('26-03-2011', 'dd-mm-yyyy'), '6', '26', '085', '03', '2011', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4104, to_date('27-03-2011', 'dd-mm-yyyy'), '7', '27', '086', '03', '2011', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4105, to_date('28-03-2011', 'dd-mm-yyyy'), '1', '28', '087', '03', '2011', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4106, to_date('29-03-2011', 'dd-mm-yyyy'), '2', '29', '088', '03', '2011', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4107, to_date('30-03-2011', 'dd-mm-yyyy'), '3', '30', '089', '03', '2011', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4108, to_date('31-03-2011', 'dd-mm-yyyy'), '4', '31', '090', '03', '2011', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4109, to_date('01-04-2011', 'dd-mm-yyyy'), '5', '01', '091', '04', '2011', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4110, to_date('02-04-2011', 'dd-mm-yyyy'), '6', '02', '092', '04', '2011', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4111, to_date('03-04-2011', 'dd-mm-yyyy'), '7', '03', '093', '04', '2011', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4112, to_date('04-04-2011', 'dd-mm-yyyy'), '1', '04', '094', '04', '2011', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4113, to_date('05-04-2011', 'dd-mm-yyyy'), '2', '05', '095', '04', '2011', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4114, to_date('06-04-2011', 'dd-mm-yyyy'), '3', '06', '096', '04', '2011', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4115, to_date('07-04-2011', 'dd-mm-yyyy'), '4', '07', '097', '04', '2011', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4116, to_date('08-04-2011', 'dd-mm-yyyy'), '5', '08', '098', '04', '2011', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4117, to_date('09-04-2011', 'dd-mm-yyyy'), '6', '09', '099', '04', '2011', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4118, to_date('10-04-2011', 'dd-mm-yyyy'), '7', '10', '100', '04', '2011', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4119, to_date('11-04-2011', 'dd-mm-yyyy'), '1', '11', '101', '04', '2011', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4120, to_date('12-04-2011', 'dd-mm-yyyy'), '2', '12', '102', '04', '2011', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4121, to_date('13-04-2011', 'dd-mm-yyyy'), '3', '13', '103', '04', '2011', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4122, to_date('14-04-2011', 'dd-mm-yyyy'), '4', '14', '104', '04', '2011', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4123, to_date('15-04-2011', 'dd-mm-yyyy'), '5', '15', '105', '04', '2011', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4124, to_date('16-04-2011', 'dd-mm-yyyy'), '6', '16', '106', '04', '2011', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4125, to_date('17-04-2011', 'dd-mm-yyyy'), '7', '17', '107', '04', '2011', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4126, to_date('18-04-2011', 'dd-mm-yyyy'), '1', '18', '108', '04', '2011', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4127, to_date('19-04-2011', 'dd-mm-yyyy'), '2', '19', '109', '04', '2011', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4128, to_date('20-04-2011', 'dd-mm-yyyy'), '3', '20', '110', '04', '2011', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4129, to_date('21-04-2011', 'dd-mm-yyyy'), '4', '21', '111', '04', '2011', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4130, to_date('22-04-2011', 'dd-mm-yyyy'), '5', '22', '112', '04', '2011', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4131, to_date('23-04-2011', 'dd-mm-yyyy'), '6', '23', '113', '04', '2011', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4132, to_date('24-04-2011', 'dd-mm-yyyy'), '7', '24', '114', '04', '2011', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4133, to_date('25-04-2011', 'dd-mm-yyyy'), '1', '25', '115', '04', '2011', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4134, to_date('26-04-2011', 'dd-mm-yyyy'), '2', '26', '116', '04', '2011', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4135, to_date('27-04-2011', 'dd-mm-yyyy'), '3', '27', '117', '04', '2011', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4136, to_date('28-04-2011', 'dd-mm-yyyy'), '4', '28', '118', '04', '2011', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4137, to_date('29-04-2011', 'dd-mm-yyyy'), '5', '29', '119', '04', '2011', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4138, to_date('30-04-2011', 'dd-mm-yyyy'), '6', '30', '120', '04', '2011', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4139, to_date('01-05-2011', 'dd-mm-yyyy'), '7', '01', '121', '05', '2011', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4140, to_date('02-05-2011', 'dd-mm-yyyy'), '1', '02', '122', '05', '2011', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4141, to_date('03-05-2011', 'dd-mm-yyyy'), '2', '03', '123', '05', '2011', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4142, to_date('04-05-2011', 'dd-mm-yyyy'), '3', '04', '124', '05', '2011', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4143, to_date('05-05-2011', 'dd-mm-yyyy'), '4', '05', '125', '05', '2011', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4144, to_date('06-05-2011', 'dd-mm-yyyy'), '5', '06', '126', '05', '2011', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4145, to_date('07-05-2011', 'dd-mm-yyyy'), '6', '07', '127', '05', '2011', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4146, to_date('08-05-2011', 'dd-mm-yyyy'), '7', '08', '128', '05', '2011', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4147, to_date('09-05-2011', 'dd-mm-yyyy'), '1', '09', '129', '05', '2011', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4148, to_date('10-05-2011', 'dd-mm-yyyy'), '2', '10', '130', '05', '2011', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4149, to_date('11-05-2011', 'dd-mm-yyyy'), '3', '11', '131', '05', '2011', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4150, to_date('12-05-2011', 'dd-mm-yyyy'), '4', '12', '132', '05', '2011', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4151, to_date('13-05-2011', 'dd-mm-yyyy'), '5', '13', '133', '05', '2011', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4152, to_date('14-05-2011', 'dd-mm-yyyy'), '6', '14', '134', '05', '2011', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4153, to_date('15-05-2011', 'dd-mm-yyyy'), '7', '15', '135', '05', '2011', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4154, to_date('16-05-2011', 'dd-mm-yyyy'), '1', '16', '136', '05', '2011', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4155, to_date('17-05-2011', 'dd-mm-yyyy'), '2', '17', '137', '05', '2011', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4156, to_date('18-05-2011', 'dd-mm-yyyy'), '3', '18', '138', '05', '2011', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4157, to_date('19-05-2011', 'dd-mm-yyyy'), '4', '19', '139', '05', '2011', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4158, to_date('20-05-2011', 'dd-mm-yyyy'), '5', '20', '140', '05', '2011', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4159, to_date('21-05-2011', 'dd-mm-yyyy'), '6', '21', '141', '05', '2011', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4160, to_date('22-05-2011', 'dd-mm-yyyy'), '7', '22', '142', '05', '2011', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4161, to_date('23-05-2011', 'dd-mm-yyyy'), '1', '23', '143', '05', '2011', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4162, to_date('24-05-2011', 'dd-mm-yyyy'), '2', '24', '144', '05', '2011', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4163, to_date('25-05-2011', 'dd-mm-yyyy'), '3', '25', '145', '05', '2011', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4164, to_date('26-05-2011', 'dd-mm-yyyy'), '4', '26', '146', '05', '2011', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4165, to_date('27-05-2011', 'dd-mm-yyyy'), '5', '27', '147', '05', '2011', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4166, to_date('28-05-2011', 'dd-mm-yyyy'), '6', '28', '148', '05', '2011', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4167, to_date('29-05-2011', 'dd-mm-yyyy'), '7', '29', '149', '05', '2011', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4168, to_date('30-05-2011', 'dd-mm-yyyy'), '1', '30', '150', '05', '2011', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4169, to_date('31-05-2011', 'dd-mm-yyyy'), '2', '31', '151', '05', '2011', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4170, to_date('01-06-2011', 'dd-mm-yyyy'), '3', '01', '152', '06', '2011', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4171, to_date('02-06-2011', 'dd-mm-yyyy'), '4', '02', '153', '06', '2011', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4172, to_date('03-06-2011', 'dd-mm-yyyy'), '5', '03', '154', '06', '2011', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4173, to_date('04-06-2011', 'dd-mm-yyyy'), '6', '04', '155', '06', '2011', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4174, to_date('05-06-2011', 'dd-mm-yyyy'), '7', '05', '156', '06', '2011', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4175, to_date('06-06-2011', 'dd-mm-yyyy'), '1', '06', '157', '06', '2011', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4176, to_date('07-06-2011', 'dd-mm-yyyy'), '2', '07', '158', '06', '2011', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4177, to_date('08-06-2011', 'dd-mm-yyyy'), '3', '08', '159', '06', '2011', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4178, to_date('09-06-2011', 'dd-mm-yyyy'), '4', '09', '160', '06', '2011', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4179, to_date('10-06-2011', 'dd-mm-yyyy'), '5', '10', '161', '06', '2011', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4180, to_date('11-06-2011', 'dd-mm-yyyy'), '6', '11', '162', '06', '2011', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4181, to_date('12-06-2011', 'dd-mm-yyyy'), '7', '12', '163', '06', '2011', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4182, to_date('13-06-2011', 'dd-mm-yyyy'), '1', '13', '164', '06', '2011', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4183, to_date('14-06-2011', 'dd-mm-yyyy'), '2', '14', '165', '06', '2011', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4184, to_date('15-06-2011', 'dd-mm-yyyy'), '3', '15', '166', '06', '2011', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4185, to_date('16-06-2011', 'dd-mm-yyyy'), '4', '16', '167', '06', '2011', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4186, to_date('17-06-2011', 'dd-mm-yyyy'), '5', '17', '168', '06', '2011', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4187, to_date('18-06-2011', 'dd-mm-yyyy'), '6', '18', '169', '06', '2011', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4188, to_date('19-06-2011', 'dd-mm-yyyy'), '7', '19', '170', '06', '2011', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4189, to_date('20-06-2011', 'dd-mm-yyyy'), '1', '20', '171', '06', '2011', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4190, to_date('21-06-2011', 'dd-mm-yyyy'), '2', '21', '172', '06', '2011', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4191, to_date('22-06-2011', 'dd-mm-yyyy'), '3', '22', '173', '06', '2011', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4192, to_date('23-06-2011', 'dd-mm-yyyy'), '4', '23', '174', '06', '2011', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4193, to_date('24-06-2011', 'dd-mm-yyyy'), '5', '24', '175', '06', '2011', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4194, to_date('25-06-2011', 'dd-mm-yyyy'), '6', '25', '176', '06', '2011', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4195, to_date('26-06-2011', 'dd-mm-yyyy'), '7', '26', '177', '06', '2011', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4196, to_date('27-06-2011', 'dd-mm-yyyy'), '1', '27', '178', '06', '2011', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4197, to_date('28-06-2011', 'dd-mm-yyyy'), '2', '28', '179', '06', '2011', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4198, to_date('29-06-2011', 'dd-mm-yyyy'), '3', '29', '180', '06', '2011', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4199, to_date('30-06-2011', 'dd-mm-yyyy'), '4', '30', '181', '06', '2011', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4200, to_date('01-07-2011', 'dd-mm-yyyy'), '5', '01', '182', '07', '2011', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4201, to_date('02-07-2011', 'dd-mm-yyyy'), '6', '02', '183', '07', '2011', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4202, to_date('03-07-2011', 'dd-mm-yyyy'), '7', '03', '184', '07', '2011', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4203, to_date('04-07-2011', 'dd-mm-yyyy'), '1', '04', '185', '07', '2011', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4204, to_date('05-07-2011', 'dd-mm-yyyy'), '2', '05', '186', '07', '2011', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4205, to_date('06-07-2011', 'dd-mm-yyyy'), '3', '06', '187', '07', '2011', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4206, to_date('07-07-2011', 'dd-mm-yyyy'), '4', '07', '188', '07', '2011', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4207, to_date('08-07-2011', 'dd-mm-yyyy'), '5', '08', '189', '07', '2011', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4208, to_date('09-07-2011', 'dd-mm-yyyy'), '6', '09', '190', '07', '2011', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4209, to_date('10-07-2011', 'dd-mm-yyyy'), '7', '10', '191', '07', '2011', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4210, to_date('11-07-2011', 'dd-mm-yyyy'), '1', '11', '192', '07', '2011', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4211, to_date('12-07-2011', 'dd-mm-yyyy'), '2', '12', '193', '07', '2011', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4212, to_date('13-07-2011', 'dd-mm-yyyy'), '3', '13', '194', '07', '2011', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4213, to_date('14-07-2011', 'dd-mm-yyyy'), '4', '14', '195', '07', '2011', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4214, to_date('15-07-2011', 'dd-mm-yyyy'), '5', '15', '196', '07', '2011', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4215, to_date('16-07-2011', 'dd-mm-yyyy'), '6', '16', '197', '07', '2011', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4216, to_date('17-07-2011', 'dd-mm-yyyy'), '7', '17', '198', '07', '2011', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4217, to_date('18-07-2011', 'dd-mm-yyyy'), '1', '18', '199', '07', '2011', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4218, to_date('19-07-2011', 'dd-mm-yyyy'), '2', '19', '200', '07', '2011', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4219, to_date('20-07-2011', 'dd-mm-yyyy'), '3', '20', '201', '07', '2011', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4220, to_date('21-07-2011', 'dd-mm-yyyy'), '4', '21', '202', '07', '2011', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4221, to_date('22-07-2011', 'dd-mm-yyyy'), '5', '22', '203', '07', '2011', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4222, to_date('23-07-2011', 'dd-mm-yyyy'), '6', '23', '204', '07', '2011', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4223, to_date('24-07-2011', 'dd-mm-yyyy'), '7', '24', '205', '07', '2011', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4224, to_date('25-07-2011', 'dd-mm-yyyy'), '1', '25', '206', '07', '2011', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4225, to_date('26-07-2011', 'dd-mm-yyyy'), '2', '26', '207', '07', '2011', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4226, to_date('27-07-2011', 'dd-mm-yyyy'), '3', '27', '208', '07', '2011', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4227, to_date('28-07-2011', 'dd-mm-yyyy'), '4', '28', '209', '07', '2011', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4228, to_date('29-07-2011', 'dd-mm-yyyy'), '5', '29', '210', '07', '2011', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4229, to_date('30-07-2011', 'dd-mm-yyyy'), '6', '30', '211', '07', '2011', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4230, to_date('31-07-2011', 'dd-mm-yyyy'), '7', '31', '212', '07', '2011', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4231, to_date('01-08-2011', 'dd-mm-yyyy'), '1', '01', '213', '08', '2011', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4232, to_date('02-08-2011', 'dd-mm-yyyy'), '2', '02', '214', '08', '2011', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4233, to_date('03-08-2011', 'dd-mm-yyyy'), '3', '03', '215', '08', '2011', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4234, to_date('04-08-2011', 'dd-mm-yyyy'), '4', '04', '216', '08', '2011', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4235, to_date('05-08-2011', 'dd-mm-yyyy'), '5', '05', '217', '08', '2011', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4236, to_date('06-08-2011', 'dd-mm-yyyy'), '6', '06', '218', '08', '2011', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4237, to_date('07-08-2011', 'dd-mm-yyyy'), '7', '07', '219', '08', '2011', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4238, to_date('08-08-2011', 'dd-mm-yyyy'), '1', '08', '220', '08', '2011', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4239, to_date('09-08-2011', 'dd-mm-yyyy'), '2', '09', '221', '08', '2011', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4240, to_date('10-08-2011', 'dd-mm-yyyy'), '3', '10', '222', '08', '2011', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4241, to_date('11-08-2011', 'dd-mm-yyyy'), '4', '11', '223', '08', '2011', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4242, to_date('12-08-2011', 'dd-mm-yyyy'), '5', '12', '224', '08', '2011', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4243, to_date('13-08-2011', 'dd-mm-yyyy'), '6', '13', '225', '08', '2011', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4244, to_date('14-08-2011', 'dd-mm-yyyy'), '7', '14', '226', '08', '2011', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4245, to_date('15-08-2011', 'dd-mm-yyyy'), '1', '15', '227', '08', '2011', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4246, to_date('16-08-2011', 'dd-mm-yyyy'), '2', '16', '228', '08', '2011', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4247, to_date('17-08-2011', 'dd-mm-yyyy'), '3', '17', '229', '08', '2011', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4248, to_date('18-08-2011', 'dd-mm-yyyy'), '4', '18', '230', '08', '2011', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4249, to_date('19-08-2011', 'dd-mm-yyyy'), '5', '19', '231', '08', '2011', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4250, to_date('20-08-2011', 'dd-mm-yyyy'), '6', '20', '232', '08', '2011', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4251, to_date('21-08-2011', 'dd-mm-yyyy'), '7', '21', '233', '08', '2011', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4252, to_date('22-08-2011', 'dd-mm-yyyy'), '1', '22', '234', '08', '2011', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4253, to_date('23-08-2011', 'dd-mm-yyyy'), '2', '23', '235', '08', '2011', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4254, to_date('24-08-2011', 'dd-mm-yyyy'), '3', '24', '236', '08', '2011', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4255, to_date('25-08-2011', 'dd-mm-yyyy'), '4', '25', '237', '08', '2011', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4256, to_date('26-08-2011', 'dd-mm-yyyy'), '5', '26', '238', '08', '2011', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4257, to_date('27-08-2011', 'dd-mm-yyyy'), '6', '27', '239', '08', '2011', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4258, to_date('28-08-2011', 'dd-mm-yyyy'), '7', '28', '240', '08', '2011', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4259, to_date('29-08-2011', 'dd-mm-yyyy'), '1', '29', '241', '08', '2011', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4260, to_date('30-08-2011', 'dd-mm-yyyy'), '2', '30', '242', '08', '2011', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4261, to_date('31-08-2011', 'dd-mm-yyyy'), '3', '31', '243', '08', '2011', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4262, to_date('01-09-2011', 'dd-mm-yyyy'), '4', '01', '244', '09', '2011', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4263, to_date('02-09-2011', 'dd-mm-yyyy'), '5', '02', '245', '09', '2011', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4264, to_date('03-09-2011', 'dd-mm-yyyy'), '6', '03', '246', '09', '2011', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4265, to_date('04-09-2011', 'dd-mm-yyyy'), '7', '04', '247', '09', '2011', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4266, to_date('05-09-2011', 'dd-mm-yyyy'), '1', '05', '248', '09', '2011', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4267, to_date('06-09-2011', 'dd-mm-yyyy'), '2', '06', '249', '09', '2011', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4268, to_date('07-09-2011', 'dd-mm-yyyy'), '3', '07', '250', '09', '2011', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4269, to_date('08-09-2011', 'dd-mm-yyyy'), '4', '08', '251', '09', '2011', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4270, to_date('09-09-2011', 'dd-mm-yyyy'), '5', '09', '252', '09', '2011', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4271, to_date('10-09-2011', 'dd-mm-yyyy'), '6', '10', '253', '09', '2011', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4272, to_date('11-09-2011', 'dd-mm-yyyy'), '7', '11', '254', '09', '2011', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4273, to_date('12-09-2011', 'dd-mm-yyyy'), '1', '12', '255', '09', '2011', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4274, to_date('13-09-2011', 'dd-mm-yyyy'), '2', '13', '256', '09', '2011', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4275, to_date('14-09-2011', 'dd-mm-yyyy'), '3', '14', '257', '09', '2011', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4276, to_date('15-09-2011', 'dd-mm-yyyy'), '4', '15', '258', '09', '2011', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4277, to_date('16-09-2011', 'dd-mm-yyyy'), '5', '16', '259', '09', '2011', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4278, to_date('17-09-2011', 'dd-mm-yyyy'), '6', '17', '260', '09', '2011', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4279, to_date('18-09-2011', 'dd-mm-yyyy'), '7', '18', '261', '09', '2011', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4280, to_date('19-09-2011', 'dd-mm-yyyy'), '1', '19', '262', '09', '2011', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4281, to_date('20-09-2011', 'dd-mm-yyyy'), '2', '20', '263', '09', '2011', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4282, to_date('21-09-2011', 'dd-mm-yyyy'), '3', '21', '264', '09', '2011', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4283, to_date('22-09-2011', 'dd-mm-yyyy'), '4', '22', '265', '09', '2011', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4284, to_date('23-09-2011', 'dd-mm-yyyy'), '5', '23', '266', '09', '2011', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4285, to_date('24-09-2011', 'dd-mm-yyyy'), '6', '24', '267', '09', '2011', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4286, to_date('25-09-2011', 'dd-mm-yyyy'), '7', '25', '268', '09', '2011', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4287, to_date('26-09-2011', 'dd-mm-yyyy'), '1', '26', '269', '09', '2011', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4288, to_date('27-09-2011', 'dd-mm-yyyy'), '2', '27', '270', '09', '2011', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4289, to_date('28-09-2011', 'dd-mm-yyyy'), '3', '28', '271', '09', '2011', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4290, to_date('29-09-2011', 'dd-mm-yyyy'), '4', '29', '272', '09', '2011', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4291, to_date('30-09-2011', 'dd-mm-yyyy'), '5', '30', '273', '09', '2011', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4292, to_date('01-10-2011', 'dd-mm-yyyy'), '6', '01', '274', '10', '2011', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4293, to_date('02-10-2011', 'dd-mm-yyyy'), '7', '02', '275', '10', '2011', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4294, to_date('03-10-2011', 'dd-mm-yyyy'), '1', '03', '276', '10', '2011', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4295, to_date('04-10-2011', 'dd-mm-yyyy'), '2', '04', '277', '10', '2011', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4296, to_date('05-10-2011', 'dd-mm-yyyy'), '3', '05', '278', '10', '2011', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4297, to_date('06-10-2011', 'dd-mm-yyyy'), '4', '06', '279', '10', '2011', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4298, to_date('07-10-2011', 'dd-mm-yyyy'), '5', '07', '280', '10', '2011', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4299, to_date('08-10-2011', 'dd-mm-yyyy'), '6', '08', '281', '10', '2011', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4300, to_date('09-10-2011', 'dd-mm-yyyy'), '7', '09', '282', '10', '2011', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4301, to_date('10-10-2011', 'dd-mm-yyyy'), '1', '10', '283', '10', '2011', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4302, to_date('11-10-2011', 'dd-mm-yyyy'), '2', '11', '284', '10', '2011', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4303, to_date('12-10-2011', 'dd-mm-yyyy'), '3', '12', '285', '10', '2011', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4304, to_date('13-10-2011', 'dd-mm-yyyy'), '4', '13', '286', '10', '2011', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4305, to_date('14-10-2011', 'dd-mm-yyyy'), '5', '14', '287', '10', '2011', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4306, to_date('15-10-2011', 'dd-mm-yyyy'), '6', '15', '288', '10', '2011', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4307, to_date('16-10-2011', 'dd-mm-yyyy'), '7', '16', '289', '10', '2011', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4308, to_date('17-10-2011', 'dd-mm-yyyy'), '1', '17', '290', '10', '2011', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4309, to_date('18-10-2011', 'dd-mm-yyyy'), '2', '18', '291', '10', '2011', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4310, to_date('19-10-2011', 'dd-mm-yyyy'), '3', '19', '292', '10', '2011', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4311, to_date('20-10-2011', 'dd-mm-yyyy'), '4', '20', '293', '10', '2011', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4312, to_date('21-10-2011', 'dd-mm-yyyy'), '5', '21', '294', '10', '2011', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4313, to_date('22-10-2011', 'dd-mm-yyyy'), '6', '22', '295', '10', '2011', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4314, to_date('23-10-2011', 'dd-mm-yyyy'), '7', '23', '296', '10', '2011', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4315, to_date('24-10-2011', 'dd-mm-yyyy'), '1', '24', '297', '10', '2011', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4316, to_date('25-10-2011', 'dd-mm-yyyy'), '2', '25', '298', '10', '2011', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4317, to_date('26-10-2011', 'dd-mm-yyyy'), '3', '26', '299', '10', '2011', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4318, to_date('27-10-2011', 'dd-mm-yyyy'), '4', '27', '300', '10', '2011', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4319, to_date('28-10-2011', 'dd-mm-yyyy'), '5', '28', '301', '10', '2011', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4320, to_date('29-10-2011', 'dd-mm-yyyy'), '6', '29', '302', '10', '2011', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4321, to_date('30-10-2011', 'dd-mm-yyyy'), '7', '30', '303', '10', '2011', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4322, to_date('31-10-2011', 'dd-mm-yyyy'), '1', '31', '304', '10', '2011', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4323, to_date('01-11-2011', 'dd-mm-yyyy'), '2', '01', '305', '11', '2011', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4324, to_date('02-11-2011', 'dd-mm-yyyy'), '3', '02', '306', '11', '2011', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4325, to_date('03-11-2011', 'dd-mm-yyyy'), '4', '03', '307', '11', '2011', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4326, to_date('04-11-2011', 'dd-mm-yyyy'), '5', '04', '308', '11', '2011', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4327, to_date('05-11-2011', 'dd-mm-yyyy'), '6', '05', '309', '11', '2011', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4328, to_date('06-11-2011', 'dd-mm-yyyy'), '7', '06', '310', '11', '2011', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4329, to_date('07-11-2011', 'dd-mm-yyyy'), '1', '07', '311', '11', '2011', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4330, to_date('08-11-2011', 'dd-mm-yyyy'), '2', '08', '312', '11', '2011', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4331, to_date('09-11-2011', 'dd-mm-yyyy'), '3', '09', '313', '11', '2011', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4332, to_date('10-11-2011', 'dd-mm-yyyy'), '4', '10', '314', '11', '2011', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4333, to_date('11-11-2011', 'dd-mm-yyyy'), '5', '11', '315', '11', '2011', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4334, to_date('12-11-2011', 'dd-mm-yyyy'), '6', '12', '316', '11', '2011', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4335, to_date('13-11-2011', 'dd-mm-yyyy'), '7', '13', '317', '11', '2011', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4336, to_date('14-11-2011', 'dd-mm-yyyy'), '1', '14', '318', '11', '2011', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4337, to_date('15-11-2011', 'dd-mm-yyyy'), '2', '15', '319', '11', '2011', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4338, to_date('16-11-2011', 'dd-mm-yyyy'), '3', '16', '320', '11', '2011', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4339, to_date('17-11-2011', 'dd-mm-yyyy'), '4', '17', '321', '11', '2011', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4340, to_date('18-11-2011', 'dd-mm-yyyy'), '5', '18', '322', '11', '2011', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4341, to_date('19-11-2011', 'dd-mm-yyyy'), '6', '19', '323', '11', '2011', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4342, to_date('20-11-2011', 'dd-mm-yyyy'), '7', '20', '324', '11', '2011', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4343, to_date('21-11-2011', 'dd-mm-yyyy'), '1', '21', '325', '11', '2011', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4344, to_date('22-11-2011', 'dd-mm-yyyy'), '2', '22', '326', '11', '2011', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4345, to_date('23-11-2011', 'dd-mm-yyyy'), '3', '23', '327', '11', '2011', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4346, to_date('24-11-2011', 'dd-mm-yyyy'), '4', '24', '328', '11', '2011', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4347, to_date('25-11-2011', 'dd-mm-yyyy'), '5', '25', '329', '11', '2011', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4348, to_date('26-11-2011', 'dd-mm-yyyy'), '6', '26', '330', '11', '2011', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4349, to_date('27-11-2011', 'dd-mm-yyyy'), '7', '27', '331', '11', '2011', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4350, to_date('28-11-2011', 'dd-mm-yyyy'), '1', '28', '332', '11', '2011', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4351, to_date('29-11-2011', 'dd-mm-yyyy'), '2', '29', '333', '11', '2011', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4352, to_date('30-11-2011', 'dd-mm-yyyy'), '3', '30', '334', '11', '2011', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4353, to_date('01-12-2011', 'dd-mm-yyyy'), '4', '01', '335', '12', '2011', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4354, to_date('02-12-2011', 'dd-mm-yyyy'), '5', '02', '336', '12', '2011', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4355, to_date('03-12-2011', 'dd-mm-yyyy'), '6', '03', '337', '12', '2011', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4356, to_date('04-12-2011', 'dd-mm-yyyy'), '7', '04', '338', '12', '2011', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4357, to_date('05-12-2011', 'dd-mm-yyyy'), '1', '05', '339', '12', '2011', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4358, to_date('06-12-2011', 'dd-mm-yyyy'), '2', '06', '340', '12', '2011', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4359, to_date('07-12-2011', 'dd-mm-yyyy'), '3', '07', '341', '12', '2011', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4360, to_date('08-12-2011', 'dd-mm-yyyy'), '4', '08', '342', '12', '2011', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4361, to_date('09-12-2011', 'dd-mm-yyyy'), '5', '09', '343', '12', '2011', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4362, to_date('10-12-2011', 'dd-mm-yyyy'), '6', '10', '344', '12', '2011', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4363, to_date('11-12-2011', 'dd-mm-yyyy'), '7', '11', '345', '12', '2011', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4364, to_date('12-12-2011', 'dd-mm-yyyy'), '1', '12', '346', '12', '2011', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4365, to_date('13-12-2011', 'dd-mm-yyyy'), '2', '13', '347', '12', '2011', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4366, to_date('14-12-2011', 'dd-mm-yyyy'), '3', '14', '348', '12', '2011', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4367, to_date('15-12-2011', 'dd-mm-yyyy'), '4', '15', '349', '12', '2011', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4368, to_date('16-12-2011', 'dd-mm-yyyy'), '5', '16', '350', '12', '2011', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4369, to_date('17-12-2011', 'dd-mm-yyyy'), '6', '17', '351', '12', '2011', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4370, to_date('18-12-2011', 'dd-mm-yyyy'), '7', '18', '352', '12', '2011', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4371, to_date('19-12-2011', 'dd-mm-yyyy'), '1', '19', '353', '12', '2011', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4372, to_date('20-12-2011', 'dd-mm-yyyy'), '2', '20', '354', '12', '2011', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4373, to_date('21-12-2011', 'dd-mm-yyyy'), '3', '21', '355', '12', '2011', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4374, to_date('22-12-2011', 'dd-mm-yyyy'), '4', '22', '356', '12', '2011', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4375, to_date('23-12-2011', 'dd-mm-yyyy'), '5', '23', '357', '12', '2011', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4376, to_date('24-12-2011', 'dd-mm-yyyy'), '6', '24', '358', '12', '2011', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4377, to_date('25-12-2011', 'dd-mm-yyyy'), '7', '25', '359', '12', '2011', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4378, to_date('26-12-2011', 'dd-mm-yyyy'), '1', '26', '360', '12', '2011', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4379, to_date('27-12-2011', 'dd-mm-yyyy'), '2', '27', '361', '12', '2011', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4380, to_date('28-12-2011', 'dd-mm-yyyy'), '3', '28', '362', '12', '2011', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4381, to_date('29-12-2011', 'dd-mm-yyyy'), '4', '29', '363', '12', '2011', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4382, to_date('30-12-2011', 'dd-mm-yyyy'), '5', '30', '364', '12', '2011', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4383, to_date('31-12-2011', 'dd-mm-yyyy'), '6', '31', '365', '12', '2011', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4384, to_date('01-01-2012', 'dd-mm-yyyy'), '7', '01', '001', '01', '2012', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4385, to_date('02-01-2012', 'dd-mm-yyyy'), '1', '02', '002', '01', '2012', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4386, to_date('03-01-2012', 'dd-mm-yyyy'), '2', '03', '003', '01', '2012', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4387, to_date('04-01-2012', 'dd-mm-yyyy'), '3', '04', '004', '01', '2012', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4388, to_date('05-01-2012', 'dd-mm-yyyy'), '4', '05', '005', '01', '2012', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4389, to_date('06-01-2012', 'dd-mm-yyyy'), '5', '06', '006', '01', '2012', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4390, to_date('07-01-2012', 'dd-mm-yyyy'), '6', '07', '007', '01', '2012', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4391, to_date('08-01-2012', 'dd-mm-yyyy'), '7', '08', '008', '01', '2012', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4392, to_date('09-01-2012', 'dd-mm-yyyy'), '1', '09', '009', '01', '2012', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4393, to_date('10-01-2012', 'dd-mm-yyyy'), '2', '10', '010', '01', '2012', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4394, to_date('11-01-2012', 'dd-mm-yyyy'), '3', '11', '011', '01', '2012', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4395, to_date('12-01-2012', 'dd-mm-yyyy'), '4', '12', '012', '01', '2012', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4396, to_date('13-01-2012', 'dd-mm-yyyy'), '5', '13', '013', '01', '2012', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4397, to_date('14-01-2012', 'dd-mm-yyyy'), '6', '14', '014', '01', '2012', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4398, to_date('15-01-2012', 'dd-mm-yyyy'), '7', '15', '015', '01', '2012', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4399, to_date('16-01-2012', 'dd-mm-yyyy'), '1', '16', '016', '01', '2012', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4400, to_date('17-01-2012', 'dd-mm-yyyy'), '2', '17', '017', '01', '2012', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4401, to_date('18-01-2012', 'dd-mm-yyyy'), '3', '18', '018', '01', '2012', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4402, to_date('19-01-2012', 'dd-mm-yyyy'), '4', '19', '019', '01', '2012', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4403, to_date('20-01-2012', 'dd-mm-yyyy'), '5', '20', '020', '01', '2012', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4404, to_date('21-01-2012', 'dd-mm-yyyy'), '6', '21', '021', '01', '2012', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4405, to_date('22-01-2012', 'dd-mm-yyyy'), '7', '22', '022', '01', '2012', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4406, to_date('23-01-2012', 'dd-mm-yyyy'), '1', '23', '023', '01', '2012', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4407, to_date('24-01-2012', 'dd-mm-yyyy'), '2', '24', '024', '01', '2012', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4408, to_date('25-01-2012', 'dd-mm-yyyy'), '3', '25', '025', '01', '2012', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4409, to_date('26-01-2012', 'dd-mm-yyyy'), '4', '26', '026', '01', '2012', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4410, to_date('27-01-2012', 'dd-mm-yyyy'), '5', '27', '027', '01', '2012', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4411, to_date('28-01-2012', 'dd-mm-yyyy'), '6', '28', '028', '01', '2012', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4412, to_date('29-01-2012', 'dd-mm-yyyy'), '7', '29', '029', '01', '2012', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4413, to_date('30-01-2012', 'dd-mm-yyyy'), '1', '30', '030', '01', '2012', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4414, to_date('31-01-2012', 'dd-mm-yyyy'), '2', '31', '031', '01', '2012', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4415, to_date('01-02-2012', 'dd-mm-yyyy'), '3', '01', '032', '02', '2012', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4416, to_date('02-02-2012', 'dd-mm-yyyy'), '4', '02', '033', '02', '2012', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4417, to_date('03-02-2012', 'dd-mm-yyyy'), '5', '03', '034', '02', '2012', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4418, to_date('04-02-2012', 'dd-mm-yyyy'), '6', '04', '035', '02', '2012', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4419, to_date('05-02-2012', 'dd-mm-yyyy'), '7', '05', '036', '02', '2012', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4420, to_date('06-02-2012', 'dd-mm-yyyy'), '1', '06', '037', '02', '2012', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4421, to_date('07-02-2012', 'dd-mm-yyyy'), '2', '07', '038', '02', '2012', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4422, to_date('08-02-2012', 'dd-mm-yyyy'), '3', '08', '039', '02', '2012', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4423, to_date('09-02-2012', 'dd-mm-yyyy'), '4', '09', '040', '02', '2012', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4424, to_date('10-02-2012', 'dd-mm-yyyy'), '5', '10', '041', '02', '2012', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4425, to_date('11-02-2012', 'dd-mm-yyyy'), '6', '11', '042', '02', '2012', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4426, to_date('12-02-2012', 'dd-mm-yyyy'), '7', '12', '043', '02', '2012', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4427, to_date('13-02-2012', 'dd-mm-yyyy'), '1', '13', '044', '02', '2012', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4428, to_date('14-02-2012', 'dd-mm-yyyy'), '2', '14', '045', '02', '2012', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4429, to_date('15-02-2012', 'dd-mm-yyyy'), '3', '15', '046', '02', '2012', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4430, to_date('16-02-2012', 'dd-mm-yyyy'), '4', '16', '047', '02', '2012', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4431, to_date('17-02-2012', 'dd-mm-yyyy'), '5', '17', '048', '02', '2012', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4432, to_date('18-02-2012', 'dd-mm-yyyy'), '6', '18', '049', '02', '2012', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4433, to_date('19-02-2012', 'dd-mm-yyyy'), '7', '19', '050', '02', '2012', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4434, to_date('20-02-2012', 'dd-mm-yyyy'), '1', '20', '051', '02', '2012', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4435, to_date('21-02-2012', 'dd-mm-yyyy'), '2', '21', '052', '02', '2012', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4436, to_date('22-02-2012', 'dd-mm-yyyy'), '3', '22', '053', '02', '2012', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4437, to_date('23-02-2012', 'dd-mm-yyyy'), '4', '23', '054', '02', '2012', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4438, to_date('24-02-2012', 'dd-mm-yyyy'), '5', '24', '055', '02', '2012', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4439, to_date('25-02-2012', 'dd-mm-yyyy'), '6', '25', '056', '02', '2012', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4440, to_date('26-02-2012', 'dd-mm-yyyy'), '7', '26', '057', '02', '2012', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4441, to_date('27-02-2012', 'dd-mm-yyyy'), '1', '27', '058', '02', '2012', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4442, to_date('28-02-2012', 'dd-mm-yyyy'), '2', '28', '059', '02', '2012', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4443, to_date('29-02-2012', 'dd-mm-yyyy'), '3', '29', '060', '02', '2012', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4444, to_date('01-03-2012', 'dd-mm-yyyy'), '4', '01', '061', '03', '2012', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4445, to_date('02-03-2012', 'dd-mm-yyyy'), '5', '02', '062', '03', '2012', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4446, to_date('03-03-2012', 'dd-mm-yyyy'), '6', '03', '063', '03', '2012', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4447, to_date('04-03-2012', 'dd-mm-yyyy'), '7', '04', '064', '03', '2012', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4448, to_date('05-03-2012', 'dd-mm-yyyy'), '1', '05', '065', '03', '2012', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4449, to_date('06-03-2012', 'dd-mm-yyyy'), '2', '06', '066', '03', '2012', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4450, to_date('07-03-2012', 'dd-mm-yyyy'), '3', '07', '067', '03', '2012', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4451, to_date('08-03-2012', 'dd-mm-yyyy'), '4', '08', '068', '03', '2012', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4452, to_date('09-03-2012', 'dd-mm-yyyy'), '5', '09', '069', '03', '2012', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4453, to_date('10-03-2012', 'dd-mm-yyyy'), '6', '10', '070', '03', '2012', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4454, to_date('11-03-2012', 'dd-mm-yyyy'), '7', '11', '071', '03', '2012', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4455, to_date('12-03-2012', 'dd-mm-yyyy'), '1', '12', '072', '03', '2012', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4456, to_date('13-03-2012', 'dd-mm-yyyy'), '2', '13', '073', '03', '2012', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4457, to_date('14-03-2012', 'dd-mm-yyyy'), '3', '14', '074', '03', '2012', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4458, to_date('15-03-2012', 'dd-mm-yyyy'), '4', '15', '075', '03', '2012', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4459, to_date('16-03-2012', 'dd-mm-yyyy'), '5', '16', '076', '03', '2012', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4460, to_date('17-03-2012', 'dd-mm-yyyy'), '6', '17', '077', '03', '2012', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4461, to_date('18-03-2012', 'dd-mm-yyyy'), '7', '18', '078', '03', '2012', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4462, to_date('19-03-2012', 'dd-mm-yyyy'), '1', '19', '079', '03', '2012', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4463, to_date('20-03-2012', 'dd-mm-yyyy'), '2', '20', '080', '03', '2012', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4464, to_date('21-03-2012', 'dd-mm-yyyy'), '3', '21', '081', '03', '2012', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4465, to_date('22-03-2012', 'dd-mm-yyyy'), '4', '22', '082', '03', '2012', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4466, to_date('23-03-2012', 'dd-mm-yyyy'), '5', '23', '083', '03', '2012', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4467, to_date('24-03-2012', 'dd-mm-yyyy'), '6', '24', '084', '03', '2012', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4468, to_date('25-03-2012', 'dd-mm-yyyy'), '7', '25', '085', '03', '2012', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4469, to_date('26-03-2012', 'dd-mm-yyyy'), '1', '26', '086', '03', '2012', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4470, to_date('27-03-2012', 'dd-mm-yyyy'), '2', '27', '087', '03', '2012', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4471, to_date('28-03-2012', 'dd-mm-yyyy'), '3', '28', '088', '03', '2012', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4472, to_date('29-03-2012', 'dd-mm-yyyy'), '4', '29', '089', '03', '2012', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4473, to_date('30-03-2012', 'dd-mm-yyyy'), '5', '30', '090', '03', '2012', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4474, to_date('31-03-2012', 'dd-mm-yyyy'), '6', '31', '091', '03', '2012', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4475, to_date('01-04-2012', 'dd-mm-yyyy'), '7', '01', '092', '04', '2012', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4476, to_date('02-04-2012', 'dd-mm-yyyy'), '1', '02', '093', '04', '2012', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4477, to_date('03-04-2012', 'dd-mm-yyyy'), '2', '03', '094', '04', '2012', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4478, to_date('04-04-2012', 'dd-mm-yyyy'), '3', '04', '095', '04', '2012', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4479, to_date('05-04-2012', 'dd-mm-yyyy'), '4', '05', '096', '04', '2012', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4480, to_date('06-04-2012', 'dd-mm-yyyy'), '5', '06', '097', '04', '2012', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4481, to_date('07-04-2012', 'dd-mm-yyyy'), '6', '07', '098', '04', '2012', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4482, to_date('08-04-2012', 'dd-mm-yyyy'), '7', '08', '099', '04', '2012', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4483, to_date('09-04-2012', 'dd-mm-yyyy'), '1', '09', '100', '04', '2012', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4484, to_date('10-04-2012', 'dd-mm-yyyy'), '2', '10', '101', '04', '2012', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4485, to_date('11-04-2012', 'dd-mm-yyyy'), '3', '11', '102', '04', '2012', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4486, to_date('12-04-2012', 'dd-mm-yyyy'), '4', '12', '103', '04', '2012', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4487, to_date('13-04-2012', 'dd-mm-yyyy'), '5', '13', '104', '04', '2012', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4488, to_date('14-04-2012', 'dd-mm-yyyy'), '6', '14', '105', '04', '2012', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4489, to_date('15-04-2012', 'dd-mm-yyyy'), '7', '15', '106', '04', '2012', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4490, to_date('16-04-2012', 'dd-mm-yyyy'), '1', '16', '107', '04', '2012', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4491, to_date('17-04-2012', 'dd-mm-yyyy'), '2', '17', '108', '04', '2012', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4492, to_date('18-04-2012', 'dd-mm-yyyy'), '3', '18', '109', '04', '2012', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4493, to_date('19-04-2012', 'dd-mm-yyyy'), '4', '19', '110', '04', '2012', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4494, to_date('20-04-2012', 'dd-mm-yyyy'), '5', '20', '111', '04', '2012', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4495, to_date('21-04-2012', 'dd-mm-yyyy'), '6', '21', '112', '04', '2012', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4496, to_date('22-04-2012', 'dd-mm-yyyy'), '7', '22', '113', '04', '2012', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4497, to_date('23-04-2012', 'dd-mm-yyyy'), '1', '23', '114', '04', '2012', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4498, to_date('24-04-2012', 'dd-mm-yyyy'), '2', '24', '115', '04', '2012', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4499, to_date('25-04-2012', 'dd-mm-yyyy'), '3', '25', '116', '04', '2012', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4500, to_date('26-04-2012', 'dd-mm-yyyy'), '4', '26', '117', '04', '2012', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4501, to_date('27-04-2012', 'dd-mm-yyyy'), '5', '27', '118', '04', '2012', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4502, to_date('28-04-2012', 'dd-mm-yyyy'), '6', '28', '119', '04', '2012', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4503, to_date('29-04-2012', 'dd-mm-yyyy'), '7', '29', '120', '04', '2012', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4504, to_date('30-04-2012', 'dd-mm-yyyy'), '1', '30', '121', '04', '2012', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4505, to_date('01-05-2012', 'dd-mm-yyyy'), '2', '01', '122', '05', '2012', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4506, to_date('02-05-2012', 'dd-mm-yyyy'), '3', '02', '123', '05', '2012', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4507, to_date('03-05-2012', 'dd-mm-yyyy'), '4', '03', '124', '05', '2012', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4508, to_date('04-05-2012', 'dd-mm-yyyy'), '5', '04', '125', '05', '2012', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4509, to_date('05-05-2012', 'dd-mm-yyyy'), '6', '05', '126', '05', '2012', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4510, to_date('06-05-2012', 'dd-mm-yyyy'), '7', '06', '127', '05', '2012', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4511, to_date('07-05-2012', 'dd-mm-yyyy'), '1', '07', '128', '05', '2012', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4512, to_date('08-05-2012', 'dd-mm-yyyy'), '2', '08', '129', '05', '2012', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4513, to_date('09-05-2012', 'dd-mm-yyyy'), '3', '09', '130', '05', '2012', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4514, to_date('10-05-2012', 'dd-mm-yyyy'), '4', '10', '131', '05', '2012', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4515, to_date('11-05-2012', 'dd-mm-yyyy'), '5', '11', '132', '05', '2012', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4516, to_date('12-05-2012', 'dd-mm-yyyy'), '6', '12', '133', '05', '2012', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4517, to_date('13-05-2012', 'dd-mm-yyyy'), '7', '13', '134', '05', '2012', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4518, to_date('14-05-2012', 'dd-mm-yyyy'), '1', '14', '135', '05', '2012', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4519, to_date('15-05-2012', 'dd-mm-yyyy'), '2', '15', '136', '05', '2012', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4520, to_date('16-05-2012', 'dd-mm-yyyy'), '3', '16', '137', '05', '2012', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4521, to_date('17-05-2012', 'dd-mm-yyyy'), '4', '17', '138', '05', '2012', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4522, to_date('18-05-2012', 'dd-mm-yyyy'), '5', '18', '139', '05', '2012', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4523, to_date('19-05-2012', 'dd-mm-yyyy'), '6', '19', '140', '05', '2012', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4524, to_date('20-05-2012', 'dd-mm-yyyy'), '7', '20', '141', '05', '2012', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4525, to_date('21-05-2012', 'dd-mm-yyyy'), '1', '21', '142', '05', '2012', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4526, to_date('22-05-2012', 'dd-mm-yyyy'), '2', '22', '143', '05', '2012', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4527, to_date('23-05-2012', 'dd-mm-yyyy'), '3', '23', '144', '05', '2012', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4528, to_date('24-05-2012', 'dd-mm-yyyy'), '4', '24', '145', '05', '2012', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4529, to_date('25-05-2012', 'dd-mm-yyyy'), '5', '25', '146', '05', '2012', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4530, to_date('26-05-2012', 'dd-mm-yyyy'), '6', '26', '147', '05', '2012', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4531, to_date('27-05-2012', 'dd-mm-yyyy'), '7', '27', '148', '05', '2012', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4532, to_date('28-05-2012', 'dd-mm-yyyy'), '1', '28', '149', '05', '2012', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4533, to_date('29-05-2012', 'dd-mm-yyyy'), '2', '29', '150', '05', '2012', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4534, to_date('30-05-2012', 'dd-mm-yyyy'), '3', '30', '151', '05', '2012', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4535, to_date('31-05-2012', 'dd-mm-yyyy'), '4', '31', '152', '05', '2012', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4536, to_date('01-06-2012', 'dd-mm-yyyy'), '5', '01', '153', '06', '2012', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4537, to_date('02-06-2012', 'dd-mm-yyyy'), '6', '02', '154', '06', '2012', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4538, to_date('03-06-2012', 'dd-mm-yyyy'), '7', '03', '155', '06', '2012', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4539, to_date('04-06-2012', 'dd-mm-yyyy'), '1', '04', '156', '06', '2012', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4540, to_date('05-06-2012', 'dd-mm-yyyy'), '2', '05', '157', '06', '2012', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4541, to_date('06-06-2012', 'dd-mm-yyyy'), '3', '06', '158', '06', '2012', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4542, to_date('07-06-2012', 'dd-mm-yyyy'), '4', '07', '159', '06', '2012', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4543, to_date('08-06-2012', 'dd-mm-yyyy'), '5', '08', '160', '06', '2012', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4544, to_date('09-06-2012', 'dd-mm-yyyy'), '6', '09', '161', '06', '2012', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4545, to_date('10-06-2012', 'dd-mm-yyyy'), '7', '10', '162', '06', '2012', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4546, to_date('11-06-2012', 'dd-mm-yyyy'), '1', '11', '163', '06', '2012', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4547, to_date('12-06-2012', 'dd-mm-yyyy'), '2', '12', '164', '06', '2012', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4548, to_date('13-06-2012', 'dd-mm-yyyy'), '3', '13', '165', '06', '2012', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4549, to_date('14-06-2012', 'dd-mm-yyyy'), '4', '14', '166', '06', '2012', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4550, to_date('15-06-2012', 'dd-mm-yyyy'), '5', '15', '167', '06', '2012', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4551, to_date('16-06-2012', 'dd-mm-yyyy'), '6', '16', '168', '06', '2012', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4552, to_date('17-06-2012', 'dd-mm-yyyy'), '7', '17', '169', '06', '2012', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4553, to_date('18-06-2012', 'dd-mm-yyyy'), '1', '18', '170', '06', '2012', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4554, to_date('19-06-2012', 'dd-mm-yyyy'), '2', '19', '171', '06', '2012', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4555, to_date('20-06-2012', 'dd-mm-yyyy'), '3', '20', '172', '06', '2012', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4556, to_date('21-06-2012', 'dd-mm-yyyy'), '4', '21', '173', '06', '2012', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4557, to_date('22-06-2012', 'dd-mm-yyyy'), '5', '22', '174', '06', '2012', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4558, to_date('23-06-2012', 'dd-mm-yyyy'), '6', '23', '175', '06', '2012', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4559, to_date('24-06-2012', 'dd-mm-yyyy'), '7', '24', '176', '06', '2012', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4560, to_date('25-06-2012', 'dd-mm-yyyy'), '1', '25', '177', '06', '2012', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4561, to_date('26-06-2012', 'dd-mm-yyyy'), '2', '26', '178', '06', '2012', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4562, to_date('27-06-2012', 'dd-mm-yyyy'), '3', '27', '179', '06', '2012', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4563, to_date('28-06-2012', 'dd-mm-yyyy'), '4', '28', '180', '06', '2012', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4564, to_date('29-06-2012', 'dd-mm-yyyy'), '5', '29', '181', '06', '2012', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4565, to_date('30-06-2012', 'dd-mm-yyyy'), '6', '30', '182', '06', '2012', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4566, to_date('01-07-2012', 'dd-mm-yyyy'), '7', '01', '183', '07', '2012', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4567, to_date('02-07-2012', 'dd-mm-yyyy'), '1', '02', '184', '07', '2012', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4568, to_date('03-07-2012', 'dd-mm-yyyy'), '2', '03', '185', '07', '2012', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4569, to_date('04-07-2012', 'dd-mm-yyyy'), '3', '04', '186', '07', '2012', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4570, to_date('05-07-2012', 'dd-mm-yyyy'), '4', '05', '187', '07', '2012', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4571, to_date('06-07-2012', 'dd-mm-yyyy'), '5', '06', '188', '07', '2012', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4572, to_date('07-07-2012', 'dd-mm-yyyy'), '6', '07', '189', '07', '2012', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4573, to_date('08-07-2012', 'dd-mm-yyyy'), '7', '08', '190', '07', '2012', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4574, to_date('09-07-2012', 'dd-mm-yyyy'), '1', '09', '191', '07', '2012', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4575, to_date('10-07-2012', 'dd-mm-yyyy'), '2', '10', '192', '07', '2012', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4576, to_date('11-07-2012', 'dd-mm-yyyy'), '3', '11', '193', '07', '2012', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4577, to_date('12-07-2012', 'dd-mm-yyyy'), '4', '12', '194', '07', '2012', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4578, to_date('13-07-2012', 'dd-mm-yyyy'), '5', '13', '195', '07', '2012', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4579, to_date('14-07-2012', 'dd-mm-yyyy'), '6', '14', '196', '07', '2012', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4580, to_date('15-07-2012', 'dd-mm-yyyy'), '7', '15', '197', '07', '2012', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4581, to_date('16-07-2012', 'dd-mm-yyyy'), '1', '16', '198', '07', '2012', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4582, to_date('17-07-2012', 'dd-mm-yyyy'), '2', '17', '199', '07', '2012', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4583, to_date('18-07-2012', 'dd-mm-yyyy'), '3', '18', '200', '07', '2012', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4584, to_date('19-07-2012', 'dd-mm-yyyy'), '4', '19', '201', '07', '2012', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4585, to_date('20-07-2012', 'dd-mm-yyyy'), '5', '20', '202', '07', '2012', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4586, to_date('21-07-2012', 'dd-mm-yyyy'), '6', '21', '203', '07', '2012', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4587, to_date('22-07-2012', 'dd-mm-yyyy'), '7', '22', '204', '07', '2012', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4588, to_date('23-07-2012', 'dd-mm-yyyy'), '1', '23', '205', '07', '2012', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4589, to_date('24-07-2012', 'dd-mm-yyyy'), '2', '24', '206', '07', '2012', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4590, to_date('25-07-2012', 'dd-mm-yyyy'), '3', '25', '207', '07', '2012', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4591, to_date('26-07-2012', 'dd-mm-yyyy'), '4', '26', '208', '07', '2012', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4592, to_date('27-07-2012', 'dd-mm-yyyy'), '5', '27', '209', '07', '2012', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4593, to_date('28-07-2012', 'dd-mm-yyyy'), '6', '28', '210', '07', '2012', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4594, to_date('29-07-2012', 'dd-mm-yyyy'), '7', '29', '211', '07', '2012', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4595, to_date('30-07-2012', 'dd-mm-yyyy'), '1', '30', '212', '07', '2012', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4596, to_date('31-07-2012', 'dd-mm-yyyy'), '2', '31', '213', '07', '2012', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4597, to_date('01-08-2012', 'dd-mm-yyyy'), '3', '01', '214', '08', '2012', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4598, to_date('02-08-2012', 'dd-mm-yyyy'), '4', '02', '215', '08', '2012', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4599, to_date('03-08-2012', 'dd-mm-yyyy'), '5', '03', '216', '08', '2012', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4600, to_date('04-08-2012', 'dd-mm-yyyy'), '6', '04', '217', '08', '2012', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4601, to_date('05-08-2012', 'dd-mm-yyyy'), '7', '05', '218', '08', '2012', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4602, to_date('06-08-2012', 'dd-mm-yyyy'), '1', '06', '219', '08', '2012', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4603, to_date('07-08-2012', 'dd-mm-yyyy'), '2', '07', '220', '08', '2012', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4604, to_date('08-08-2012', 'dd-mm-yyyy'), '3', '08', '221', '08', '2012', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4605, to_date('09-08-2012', 'dd-mm-yyyy'), '4', '09', '222', '08', '2012', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4606, to_date('10-08-2012', 'dd-mm-yyyy'), '5', '10', '223', '08', '2012', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4607, to_date('11-08-2012', 'dd-mm-yyyy'), '6', '11', '224', '08', '2012', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4608, to_date('12-08-2012', 'dd-mm-yyyy'), '7', '12', '225', '08', '2012', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4609, to_date('13-08-2012', 'dd-mm-yyyy'), '1', '13', '226', '08', '2012', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4610, to_date('14-08-2012', 'dd-mm-yyyy'), '2', '14', '227', '08', '2012', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4611, to_date('15-08-2012', 'dd-mm-yyyy'), '3', '15', '228', '08', '2012', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4612, to_date('16-08-2012', 'dd-mm-yyyy'), '4', '16', '229', '08', '2012', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4613, to_date('17-08-2012', 'dd-mm-yyyy'), '5', '17', '230', '08', '2012', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4614, to_date('18-08-2012', 'dd-mm-yyyy'), '6', '18', '231', '08', '2012', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4615, to_date('19-08-2012', 'dd-mm-yyyy'), '7', '19', '232', '08', '2012', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4616, to_date('20-08-2012', 'dd-mm-yyyy'), '1', '20', '233', '08', '2012', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4617, to_date('21-08-2012', 'dd-mm-yyyy'), '2', '21', '234', '08', '2012', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4618, to_date('22-08-2012', 'dd-mm-yyyy'), '3', '22', '235', '08', '2012', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4619, to_date('23-08-2012', 'dd-mm-yyyy'), '4', '23', '236', '08', '2012', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4620, to_date('24-08-2012', 'dd-mm-yyyy'), '5', '24', '237', '08', '2012', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4621, to_date('25-08-2012', 'dd-mm-yyyy'), '6', '25', '238', '08', '2012', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4622, to_date('26-08-2012', 'dd-mm-yyyy'), '7', '26', '239', '08', '2012', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4623, to_date('27-08-2012', 'dd-mm-yyyy'), '1', '27', '240', '08', '2012', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4624, to_date('28-08-2012', 'dd-mm-yyyy'), '2', '28', '241', '08', '2012', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4625, to_date('29-08-2012', 'dd-mm-yyyy'), '3', '29', '242', '08', '2012', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4626, to_date('30-08-2012', 'dd-mm-yyyy'), '4', '30', '243', '08', '2012', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4627, to_date('31-08-2012', 'dd-mm-yyyy'), '5', '31', '244', '08', '2012', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4628, to_date('01-09-2012', 'dd-mm-yyyy'), '6', '01', '245', '09', '2012', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4629, to_date('02-09-2012', 'dd-mm-yyyy'), '7', '02', '246', '09', '2012', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4630, to_date('03-09-2012', 'dd-mm-yyyy'), '1', '03', '247', '09', '2012', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4631, to_date('04-09-2012', 'dd-mm-yyyy'), '2', '04', '248', '09', '2012', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4632, to_date('05-09-2012', 'dd-mm-yyyy'), '3', '05', '249', '09', '2012', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4633, to_date('06-09-2012', 'dd-mm-yyyy'), '4', '06', '250', '09', '2012', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4634, to_date('07-09-2012', 'dd-mm-yyyy'), '5', '07', '251', '09', '2012', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4635, to_date('08-09-2012', 'dd-mm-yyyy'), '6', '08', '252', '09', '2012', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4636, to_date('09-09-2012', 'dd-mm-yyyy'), '7', '09', '253', '09', '2012', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4637, to_date('10-09-2012', 'dd-mm-yyyy'), '1', '10', '254', '09', '2012', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4638, to_date('11-09-2012', 'dd-mm-yyyy'), '2', '11', '255', '09', '2012', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4639, to_date('12-09-2012', 'dd-mm-yyyy'), '3', '12', '256', '09', '2012', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4640, to_date('13-09-2012', 'dd-mm-yyyy'), '4', '13', '257', '09', '2012', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4641, to_date('14-09-2012', 'dd-mm-yyyy'), '5', '14', '258', '09', '2012', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4642, to_date('15-09-2012', 'dd-mm-yyyy'), '6', '15', '259', '09', '2012', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4643, to_date('16-09-2012', 'dd-mm-yyyy'), '7', '16', '260', '09', '2012', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4644, to_date('17-09-2012', 'dd-mm-yyyy'), '1', '17', '261', '09', '2012', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4645, to_date('18-09-2012', 'dd-mm-yyyy'), '2', '18', '262', '09', '2012', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3242, to_date('15-11-2008', 'dd-mm-yyyy'), '6', '15', '320', '11', '2008', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3243, to_date('16-11-2008', 'dd-mm-yyyy'), '7', '16', '321', '11', '2008', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3244, to_date('17-11-2008', 'dd-mm-yyyy'), '1', '17', '322', '11', '2008', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3245, to_date('18-11-2008', 'dd-mm-yyyy'), '2', '18', '323', '11', '2008', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3246, to_date('19-11-2008', 'dd-mm-yyyy'), '3', '19', '324', '11', '2008', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3247, to_date('20-11-2008', 'dd-mm-yyyy'), '4', '20', '325', '11', '2008', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3248, to_date('21-11-2008', 'dd-mm-yyyy'), '5', '21', '326', '11', '2008', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3249, to_date('22-11-2008', 'dd-mm-yyyy'), '6', '22', '327', '11', '2008', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3250, to_date('23-11-2008', 'dd-mm-yyyy'), '7', '23', '328', '11', '2008', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3251, to_date('24-11-2008', 'dd-mm-yyyy'), '1', '24', '329', '11', '2008', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3252, to_date('25-11-2008', 'dd-mm-yyyy'), '2', '25', '330', '11', '2008', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3253, to_date('26-11-2008', 'dd-mm-yyyy'), '3', '26', '331', '11', '2008', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3254, to_date('27-11-2008', 'dd-mm-yyyy'), '4', '27', '332', '11', '2008', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3255, to_date('28-11-2008', 'dd-mm-yyyy'), '5', '28', '333', '11', '2008', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3256, to_date('29-11-2008', 'dd-mm-yyyy'), '6', '29', '334', '11', '2008', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3257, to_date('30-11-2008', 'dd-mm-yyyy'), '7', '30', '335', '11', '2008', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3258, to_date('01-12-2008', 'dd-mm-yyyy'), '1', '01', '336', '12', '2008', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3259, to_date('02-12-2008', 'dd-mm-yyyy'), '2', '02', '337', '12', '2008', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3260, to_date('03-12-2008', 'dd-mm-yyyy'), '3', '03', '338', '12', '2008', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3261, to_date('04-12-2008', 'dd-mm-yyyy'), '4', '04', '339', '12', '2008', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3262, to_date('05-12-2008', 'dd-mm-yyyy'), '5', '05', '340', '12', '2008', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3263, to_date('06-12-2008', 'dd-mm-yyyy'), '6', '06', '341', '12', '2008', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3264, to_date('07-12-2008', 'dd-mm-yyyy'), '7', '07', '342', '12', '2008', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3265, to_date('08-12-2008', 'dd-mm-yyyy'), '1', '08', '343', '12', '2008', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3266, to_date('09-12-2008', 'dd-mm-yyyy'), '2', '09', '344', '12', '2008', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3267, to_date('10-12-2008', 'dd-mm-yyyy'), '3', '10', '345', '12', '2008', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3268, to_date('11-12-2008', 'dd-mm-yyyy'), '4', '11', '346', '12', '2008', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3269, to_date('12-12-2008', 'dd-mm-yyyy'), '5', '12', '347', '12', '2008', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3270, to_date('13-12-2008', 'dd-mm-yyyy'), '6', '13', '348', '12', '2008', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3271, to_date('14-12-2008', 'dd-mm-yyyy'), '7', '14', '349', '12', '2008', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3272, to_date('15-12-2008', 'dd-mm-yyyy'), '1', '15', '350', '12', '2008', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3273, to_date('16-12-2008', 'dd-mm-yyyy'), '2', '16', '351', '12', '2008', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3274, to_date('17-12-2008', 'dd-mm-yyyy'), '3', '17', '352', '12', '2008', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3275, to_date('18-12-2008', 'dd-mm-yyyy'), '4', '18', '353', '12', '2008', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3276, to_date('19-12-2008', 'dd-mm-yyyy'), '5', '19', '354', '12', '2008', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3277, to_date('20-12-2008', 'dd-mm-yyyy'), '6', '20', '355', '12', '2008', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3278, to_date('21-12-2008', 'dd-mm-yyyy'), '7', '21', '356', '12', '2008', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3279, to_date('22-12-2008', 'dd-mm-yyyy'), '1', '22', '357', '12', '2008', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3280, to_date('23-12-2008', 'dd-mm-yyyy'), '2', '23', '358', '12', '2008', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3281, to_date('24-12-2008', 'dd-mm-yyyy'), '3', '24', '359', '12', '2008', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3282, to_date('25-12-2008', 'dd-mm-yyyy'), '4', '25', '360', '12', '2008', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3283, to_date('26-12-2008', 'dd-mm-yyyy'), '5', '26', '361', '12', '2008', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3284, to_date('27-12-2008', 'dd-mm-yyyy'), '6', '27', '362', '12', '2008', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3285, to_date('28-12-2008', 'dd-mm-yyyy'), '7', '28', '363', '12', '2008', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3286, to_date('29-12-2008', 'dd-mm-yyyy'), '1', '29', '364', '12', '2008', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3287, to_date('30-12-2008', 'dd-mm-yyyy'), '2', '30', '365', '12', '2008', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3288, to_date('31-12-2008', 'dd-mm-yyyy'), '3', '31', '366', '12', '2008', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3289, to_date('01-01-2009', 'dd-mm-yyyy'), '4', '01', '001', '01', '2009', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3290, to_date('02-01-2009', 'dd-mm-yyyy'), '5', '02', '002', '01', '2009', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3291, to_date('03-01-2009', 'dd-mm-yyyy'), '6', '03', '003', '01', '2009', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3292, to_date('04-01-2009', 'dd-mm-yyyy'), '7', '04', '004', '01', '2009', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3293, to_date('05-01-2009', 'dd-mm-yyyy'), '1', '05', '005', '01', '2009', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3294, to_date('06-01-2009', 'dd-mm-yyyy'), '2', '06', '006', '01', '2009', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3295, to_date('07-01-2009', 'dd-mm-yyyy'), '3', '07', '007', '01', '2009', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3296, to_date('08-01-2009', 'dd-mm-yyyy'), '4', '08', '008', '01', '2009', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3297, to_date('09-01-2009', 'dd-mm-yyyy'), '5', '09', '009', '01', '2009', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3298, to_date('10-01-2009', 'dd-mm-yyyy'), '6', '10', '010', '01', '2009', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3299, to_date('11-01-2009', 'dd-mm-yyyy'), '7', '11', '011', '01', '2009', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3300, to_date('12-01-2009', 'dd-mm-yyyy'), '1', '12', '012', '01', '2009', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3301, to_date('13-01-2009', 'dd-mm-yyyy'), '2', '13', '013', '01', '2009', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3302, to_date('14-01-2009', 'dd-mm-yyyy'), '3', '14', '014', '01', '2009', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3303, to_date('15-01-2009', 'dd-mm-yyyy'), '4', '15', '015', '01', '2009', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3304, to_date('16-01-2009', 'dd-mm-yyyy'), '5', '16', '016', '01', '2009', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3305, to_date('17-01-2009', 'dd-mm-yyyy'), '6', '17', '017', '01', '2009', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3306, to_date('18-01-2009', 'dd-mm-yyyy'), '7', '18', '018', '01', '2009', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3307, to_date('19-01-2009', 'dd-mm-yyyy'), '1', '19', '019', '01', '2009', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3308, to_date('20-01-2009', 'dd-mm-yyyy'), '2', '20', '020', '01', '2009', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3309, to_date('21-01-2009', 'dd-mm-yyyy'), '3', '21', '021', '01', '2009', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3310, to_date('22-01-2009', 'dd-mm-yyyy'), '4', '22', '022', '01', '2009', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3311, to_date('23-01-2009', 'dd-mm-yyyy'), '5', '23', '023', '01', '2009', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3312, to_date('24-01-2009', 'dd-mm-yyyy'), '6', '24', '024', '01', '2009', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3313, to_date('25-01-2009', 'dd-mm-yyyy'), '7', '25', '025', '01', '2009', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3314, to_date('26-01-2009', 'dd-mm-yyyy'), '1', '26', '026', '01', '2009', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3315, to_date('27-01-2009', 'dd-mm-yyyy'), '2', '27', '027', '01', '2009', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3316, to_date('28-01-2009', 'dd-mm-yyyy'), '3', '28', '028', '01', '2009', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3317, to_date('29-01-2009', 'dd-mm-yyyy'), '4', '29', '029', '01', '2009', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3318, to_date('30-01-2009', 'dd-mm-yyyy'), '5', '30', '030', '01', '2009', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3319, to_date('31-01-2009', 'dd-mm-yyyy'), '6', '31', '031', '01', '2009', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3320, to_date('01-02-2009', 'dd-mm-yyyy'), '7', '01', '032', '02', '2009', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3321, to_date('02-02-2009', 'dd-mm-yyyy'), '1', '02', '033', '02', '2009', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3322, to_date('03-02-2009', 'dd-mm-yyyy'), '2', '03', '034', '02', '2009', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3323, to_date('04-02-2009', 'dd-mm-yyyy'), '3', '04', '035', '02', '2009', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3324, to_date('05-02-2009', 'dd-mm-yyyy'), '4', '05', '036', '02', '2009', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3325, to_date('06-02-2009', 'dd-mm-yyyy'), '5', '06', '037', '02', '2009', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3326, to_date('07-02-2009', 'dd-mm-yyyy'), '6', '07', '038', '02', '2009', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3327, to_date('08-02-2009', 'dd-mm-yyyy'), '7', '08', '039', '02', '2009', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3328, to_date('09-02-2009', 'dd-mm-yyyy'), '1', '09', '040', '02', '2009', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3329, to_date('10-02-2009', 'dd-mm-yyyy'), '2', '10', '041', '02', '2009', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3330, to_date('11-02-2009', 'dd-mm-yyyy'), '3', '11', '042', '02', '2009', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3331, to_date('12-02-2009', 'dd-mm-yyyy'), '4', '12', '043', '02', '2009', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3332, to_date('13-02-2009', 'dd-mm-yyyy'), '5', '13', '044', '02', '2009', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3333, to_date('14-02-2009', 'dd-mm-yyyy'), '6', '14', '045', '02', '2009', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3334, to_date('15-02-2009', 'dd-mm-yyyy'), '7', '15', '046', '02', '2009', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3335, to_date('16-02-2009', 'dd-mm-yyyy'), '1', '16', '047', '02', '2009', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3336, to_date('17-02-2009', 'dd-mm-yyyy'), '2', '17', '048', '02', '2009', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3337, to_date('18-02-2009', 'dd-mm-yyyy'), '3', '18', '049', '02', '2009', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3338, to_date('19-02-2009', 'dd-mm-yyyy'), '4', '19', '050', '02', '2009', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3339, to_date('20-02-2009', 'dd-mm-yyyy'), '5', '20', '051', '02', '2009', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3340, to_date('21-02-2009', 'dd-mm-yyyy'), '6', '21', '052', '02', '2009', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3341, to_date('22-02-2009', 'dd-mm-yyyy'), '7', '22', '053', '02', '2009', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3342, to_date('23-02-2009', 'dd-mm-yyyy'), '1', '23', '054', '02', '2009', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3343, to_date('24-02-2009', 'dd-mm-yyyy'), '2', '24', '055', '02', '2009', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3344, to_date('25-02-2009', 'dd-mm-yyyy'), '3', '25', '056', '02', '2009', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3345, to_date('26-02-2009', 'dd-mm-yyyy'), '4', '26', '057', '02', '2009', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3346, to_date('27-02-2009', 'dd-mm-yyyy'), '5', '27', '058', '02', '2009', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3347, to_date('28-02-2009', 'dd-mm-yyyy'), '6', '28', '059', '02', '2009', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3348, to_date('01-03-2009', 'dd-mm-yyyy'), '7', '01', '060', '03', '2009', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3349, to_date('02-03-2009', 'dd-mm-yyyy'), '1', '02', '061', '03', '2009', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3350, to_date('03-03-2009', 'dd-mm-yyyy'), '2', '03', '062', '03', '2009', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3351, to_date('04-03-2009', 'dd-mm-yyyy'), '3', '04', '063', '03', '2009', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3352, to_date('05-03-2009', 'dd-mm-yyyy'), '4', '05', '064', '03', '2009', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3353, to_date('06-03-2009', 'dd-mm-yyyy'), '5', '06', '065', '03', '2009', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3354, to_date('07-03-2009', 'dd-mm-yyyy'), '6', '07', '066', '03', '2009', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3355, to_date('08-03-2009', 'dd-mm-yyyy'), '7', '08', '067', '03', '2009', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3356, to_date('09-03-2009', 'dd-mm-yyyy'), '1', '09', '068', '03', '2009', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3357, to_date('10-03-2009', 'dd-mm-yyyy'), '2', '10', '069', '03', '2009', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3358, to_date('11-03-2009', 'dd-mm-yyyy'), '3', '11', '070', '03', '2009', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3359, to_date('12-03-2009', 'dd-mm-yyyy'), '4', '12', '071', '03', '2009', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3360, to_date('13-03-2009', 'dd-mm-yyyy'), '5', '13', '072', '03', '2009', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3361, to_date('14-03-2009', 'dd-mm-yyyy'), '6', '14', '073', '03', '2009', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3362, to_date('15-03-2009', 'dd-mm-yyyy'), '7', '15', '074', '03', '2009', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3363, to_date('16-03-2009', 'dd-mm-yyyy'), '1', '16', '075', '03', '2009', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3364, to_date('17-03-2009', 'dd-mm-yyyy'), '2', '17', '076', '03', '2009', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3365, to_date('18-03-2009', 'dd-mm-yyyy'), '3', '18', '077', '03', '2009', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3366, to_date('19-03-2009', 'dd-mm-yyyy'), '4', '19', '078', '03', '2009', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3367, to_date('20-03-2009', 'dd-mm-yyyy'), '5', '20', '079', '03', '2009', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3368, to_date('21-03-2009', 'dd-mm-yyyy'), '6', '21', '080', '03', '2009', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3369, to_date('22-03-2009', 'dd-mm-yyyy'), '7', '22', '081', '03', '2009', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3370, to_date('23-03-2009', 'dd-mm-yyyy'), '1', '23', '082', '03', '2009', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3371, to_date('24-03-2009', 'dd-mm-yyyy'), '2', '24', '083', '03', '2009', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3372, to_date('25-03-2009', 'dd-mm-yyyy'), '3', '25', '084', '03', '2009', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3373, to_date('26-03-2009', 'dd-mm-yyyy'), '4', '26', '085', '03', '2009', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3374, to_date('27-03-2009', 'dd-mm-yyyy'), '5', '27', '086', '03', '2009', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3375, to_date('28-03-2009', 'dd-mm-yyyy'), '6', '28', '087', '03', '2009', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3376, to_date('29-03-2009', 'dd-mm-yyyy'), '7', '29', '088', '03', '2009', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3377, to_date('30-03-2009', 'dd-mm-yyyy'), '1', '30', '089', '03', '2009', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3378, to_date('31-03-2009', 'dd-mm-yyyy'), '2', '31', '090', '03', '2009', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3379, to_date('01-04-2009', 'dd-mm-yyyy'), '3', '01', '091', '04', '2009', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3380, to_date('02-04-2009', 'dd-mm-yyyy'), '4', '02', '092', '04', '2009', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3381, to_date('03-04-2009', 'dd-mm-yyyy'), '5', '03', '093', '04', '2009', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3382, to_date('04-04-2009', 'dd-mm-yyyy'), '6', '04', '094', '04', '2009', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3383, to_date('05-04-2009', 'dd-mm-yyyy'), '7', '05', '095', '04', '2009', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3384, to_date('06-04-2009', 'dd-mm-yyyy'), '1', '06', '096', '04', '2009', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3385, to_date('07-04-2009', 'dd-mm-yyyy'), '2', '07', '097', '04', '2009', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3386, to_date('08-04-2009', 'dd-mm-yyyy'), '3', '08', '098', '04', '2009', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3387, to_date('09-04-2009', 'dd-mm-yyyy'), '4', '09', '099', '04', '2009', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3388, to_date('10-04-2009', 'dd-mm-yyyy'), '5', '10', '100', '04', '2009', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3389, to_date('11-04-2009', 'dd-mm-yyyy'), '6', '11', '101', '04', '2009', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3390, to_date('12-04-2009', 'dd-mm-yyyy'), '7', '12', '102', '04', '2009', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3391, to_date('13-04-2009', 'dd-mm-yyyy'), '1', '13', '103', '04', '2009', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3392, to_date('14-04-2009', 'dd-mm-yyyy'), '2', '14', '104', '04', '2009', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3393, to_date('15-04-2009', 'dd-mm-yyyy'), '3', '15', '105', '04', '2009', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3394, to_date('16-04-2009', 'dd-mm-yyyy'), '4', '16', '106', '04', '2009', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3395, to_date('17-04-2009', 'dd-mm-yyyy'), '5', '17', '107', '04', '2009', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3396, to_date('18-04-2009', 'dd-mm-yyyy'), '6', '18', '108', '04', '2009', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3397, to_date('19-04-2009', 'dd-mm-yyyy'), '7', '19', '109', '04', '2009', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3398, to_date('20-04-2009', 'dd-mm-yyyy'), '1', '20', '110', '04', '2009', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3399, to_date('21-04-2009', 'dd-mm-yyyy'), '2', '21', '111', '04', '2009', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3400, to_date('22-04-2009', 'dd-mm-yyyy'), '3', '22', '112', '04', '2009', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3401, to_date('23-04-2009', 'dd-mm-yyyy'), '4', '23', '113', '04', '2009', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3402, to_date('24-04-2009', 'dd-mm-yyyy'), '5', '24', '114', '04', '2009', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3403, to_date('25-04-2009', 'dd-mm-yyyy'), '6', '25', '115', '04', '2009', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3404, to_date('26-04-2009', 'dd-mm-yyyy'), '7', '26', '116', '04', '2009', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3405, to_date('27-04-2009', 'dd-mm-yyyy'), '1', '27', '117', '04', '2009', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3406, to_date('28-04-2009', 'dd-mm-yyyy'), '2', '28', '118', '04', '2009', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3407, to_date('29-04-2009', 'dd-mm-yyyy'), '3', '29', '119', '04', '2009', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3408, to_date('30-04-2009', 'dd-mm-yyyy'), '4', '30', '120', '04', '2009', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3409, to_date('01-05-2009', 'dd-mm-yyyy'), '5', '01', '121', '05', '2009', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3410, to_date('02-05-2009', 'dd-mm-yyyy'), '6', '02', '122', '05', '2009', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3411, to_date('03-05-2009', 'dd-mm-yyyy'), '7', '03', '123', '05', '2009', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3412, to_date('04-05-2009', 'dd-mm-yyyy'), '1', '04', '124', '05', '2009', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3413, to_date('05-05-2009', 'dd-mm-yyyy'), '2', '05', '125', '05', '2009', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3414, to_date('06-05-2009', 'dd-mm-yyyy'), '3', '06', '126', '05', '2009', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3415, to_date('07-05-2009', 'dd-mm-yyyy'), '4', '07', '127', '05', '2009', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3416, to_date('08-05-2009', 'dd-mm-yyyy'), '5', '08', '128', '05', '2009', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3417, to_date('09-05-2009', 'dd-mm-yyyy'), '6', '09', '129', '05', '2009', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3418, to_date('10-05-2009', 'dd-mm-yyyy'), '7', '10', '130', '05', '2009', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3419, to_date('11-05-2009', 'dd-mm-yyyy'), '1', '11', '131', '05', '2009', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3420, to_date('12-05-2009', 'dd-mm-yyyy'), '2', '12', '132', '05', '2009', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3421, to_date('13-05-2009', 'dd-mm-yyyy'), '3', '13', '133', '05', '2009', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3422, to_date('14-05-2009', 'dd-mm-yyyy'), '4', '14', '134', '05', '2009', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3423, to_date('15-05-2009', 'dd-mm-yyyy'), '5', '15', '135', '05', '2009', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3424, to_date('16-05-2009', 'dd-mm-yyyy'), '6', '16', '136', '05', '2009', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3425, to_date('17-05-2009', 'dd-mm-yyyy'), '7', '17', '137', '05', '2009', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3426, to_date('18-05-2009', 'dd-mm-yyyy'), '1', '18', '138', '05', '2009', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3427, to_date('19-05-2009', 'dd-mm-yyyy'), '2', '19', '139', '05', '2009', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3428, to_date('20-05-2009', 'dd-mm-yyyy'), '3', '20', '140', '05', '2009', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3429, to_date('21-05-2009', 'dd-mm-yyyy'), '4', '21', '141', '05', '2009', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3430, to_date('22-05-2009', 'dd-mm-yyyy'), '5', '22', '142', '05', '2009', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3431, to_date('23-05-2009', 'dd-mm-yyyy'), '6', '23', '143', '05', '2009', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3432, to_date('24-05-2009', 'dd-mm-yyyy'), '7', '24', '144', '05', '2009', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3433, to_date('25-05-2009', 'dd-mm-yyyy'), '1', '25', '145', '05', '2009', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3434, to_date('26-05-2009', 'dd-mm-yyyy'), '2', '26', '146', '05', '2009', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3435, to_date('27-05-2009', 'dd-mm-yyyy'), '3', '27', '147', '05', '2009', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3436, to_date('28-05-2009', 'dd-mm-yyyy'), '4', '28', '148', '05', '2009', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3437, to_date('29-05-2009', 'dd-mm-yyyy'), '5', '29', '149', '05', '2009', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3438, to_date('30-05-2009', 'dd-mm-yyyy'), '6', '30', '150', '05', '2009', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3439, to_date('31-05-2009', 'dd-mm-yyyy'), '7', '31', '151', '05', '2009', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3440, to_date('01-06-2009', 'dd-mm-yyyy'), '1', '01', '152', '06', '2009', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3441, to_date('02-06-2009', 'dd-mm-yyyy'), '2', '02', '153', '06', '2009', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3442, to_date('03-06-2009', 'dd-mm-yyyy'), '3', '03', '154', '06', '2009', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3443, to_date('04-06-2009', 'dd-mm-yyyy'), '4', '04', '155', '06', '2009', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3444, to_date('05-06-2009', 'dd-mm-yyyy'), '5', '05', '156', '06', '2009', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3445, to_date('06-06-2009', 'dd-mm-yyyy'), '6', '06', '157', '06', '2009', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3446, to_date('07-06-2009', 'dd-mm-yyyy'), '7', '07', '158', '06', '2009', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3447, to_date('08-06-2009', 'dd-mm-yyyy'), '1', '08', '159', '06', '2009', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3448, to_date('09-06-2009', 'dd-mm-yyyy'), '2', '09', '160', '06', '2009', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3449, to_date('10-06-2009', 'dd-mm-yyyy'), '3', '10', '161', '06', '2009', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3450, to_date('11-06-2009', 'dd-mm-yyyy'), '4', '11', '162', '06', '2009', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3451, to_date('12-06-2009', 'dd-mm-yyyy'), '5', '12', '163', '06', '2009', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3452, to_date('13-06-2009', 'dd-mm-yyyy'), '6', '13', '164', '06', '2009', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3453, to_date('14-06-2009', 'dd-mm-yyyy'), '7', '14', '165', '06', '2009', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3454, to_date('15-06-2009', 'dd-mm-yyyy'), '1', '15', '166', '06', '2009', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3455, to_date('16-06-2009', 'dd-mm-yyyy'), '2', '16', '167', '06', '2009', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3456, to_date('17-06-2009', 'dd-mm-yyyy'), '3', '17', '168', '06', '2009', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3457, to_date('18-06-2009', 'dd-mm-yyyy'), '4', '18', '169', '06', '2009', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3458, to_date('19-06-2009', 'dd-mm-yyyy'), '5', '19', '170', '06', '2009', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3459, to_date('20-06-2009', 'dd-mm-yyyy'), '6', '20', '171', '06', '2009', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3460, to_date('21-06-2009', 'dd-mm-yyyy'), '7', '21', '172', '06', '2009', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3461, to_date('22-06-2009', 'dd-mm-yyyy'), '1', '22', '173', '06', '2009', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3462, to_date('23-06-2009', 'dd-mm-yyyy'), '2', '23', '174', '06', '2009', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3463, to_date('24-06-2009', 'dd-mm-yyyy'), '3', '24', '175', '06', '2009', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3464, to_date('25-06-2009', 'dd-mm-yyyy'), '4', '25', '176', '06', '2009', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3465, to_date('26-06-2009', 'dd-mm-yyyy'), '5', '26', '177', '06', '2009', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3466, to_date('27-06-2009', 'dd-mm-yyyy'), '6', '27', '178', '06', '2009', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3467, to_date('28-06-2009', 'dd-mm-yyyy'), '7', '28', '179', '06', '2009', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3468, to_date('29-06-2009', 'dd-mm-yyyy'), '1', '29', '180', '06', '2009', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3469, to_date('30-06-2009', 'dd-mm-yyyy'), '2', '30', '181', '06', '2009', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3470, to_date('01-07-2009', 'dd-mm-yyyy'), '3', '01', '182', '07', '2009', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3471, to_date('02-07-2009', 'dd-mm-yyyy'), '4', '02', '183', '07', '2009', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3472, to_date('03-07-2009', 'dd-mm-yyyy'), '5', '03', '184', '07', '2009', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3473, to_date('04-07-2009', 'dd-mm-yyyy'), '6', '04', '185', '07', '2009', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3474, to_date('05-07-2009', 'dd-mm-yyyy'), '7', '05', '186', '07', '2009', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3475, to_date('06-07-2009', 'dd-mm-yyyy'), '1', '06', '187', '07', '2009', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3476, to_date('07-07-2009', 'dd-mm-yyyy'), '2', '07', '188', '07', '2009', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3477, to_date('08-07-2009', 'dd-mm-yyyy'), '3', '08', '189', '07', '2009', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3478, to_date('09-07-2009', 'dd-mm-yyyy'), '4', '09', '190', '07', '2009', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3479, to_date('10-07-2009', 'dd-mm-yyyy'), '5', '10', '191', '07', '2009', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3480, to_date('11-07-2009', 'dd-mm-yyyy'), '6', '11', '192', '07', '2009', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3481, to_date('12-07-2009', 'dd-mm-yyyy'), '7', '12', '193', '07', '2009', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3482, to_date('13-07-2009', 'dd-mm-yyyy'), '1', '13', '194', '07', '2009', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3483, to_date('14-07-2009', 'dd-mm-yyyy'), '2', '14', '195', '07', '2009', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3484, to_date('15-07-2009', 'dd-mm-yyyy'), '3', '15', '196', '07', '2009', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3485, to_date('16-07-2009', 'dd-mm-yyyy'), '4', '16', '197', '07', '2009', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
commit;
prompt 1000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3486, to_date('17-07-2009', 'dd-mm-yyyy'), '5', '17', '198', '07', '2009', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3487, to_date('18-07-2009', 'dd-mm-yyyy'), '6', '18', '199', '07', '2009', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3488, to_date('19-07-2009', 'dd-mm-yyyy'), '7', '19', '200', '07', '2009', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3489, to_date('20-07-2009', 'dd-mm-yyyy'), '1', '20', '201', '07', '2009', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3490, to_date('21-07-2009', 'dd-mm-yyyy'), '2', '21', '202', '07', '2009', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3491, to_date('22-07-2009', 'dd-mm-yyyy'), '3', '22', '203', '07', '2009', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3492, to_date('23-07-2009', 'dd-mm-yyyy'), '4', '23', '204', '07', '2009', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3493, to_date('24-07-2009', 'dd-mm-yyyy'), '5', '24', '205', '07', '2009', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3494, to_date('25-07-2009', 'dd-mm-yyyy'), '6', '25', '206', '07', '2009', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3495, to_date('26-07-2009', 'dd-mm-yyyy'), '7', '26', '207', '07', '2009', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3496, to_date('27-07-2009', 'dd-mm-yyyy'), '1', '27', '208', '07', '2009', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3497, to_date('28-07-2009', 'dd-mm-yyyy'), '2', '28', '209', '07', '2009', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3498, to_date('29-07-2009', 'dd-mm-yyyy'), '3', '29', '210', '07', '2009', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3499, to_date('30-07-2009', 'dd-mm-yyyy'), '4', '30', '211', '07', '2009', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3500, to_date('31-07-2009', 'dd-mm-yyyy'), '5', '31', '212', '07', '2009', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3501, to_date('01-08-2009', 'dd-mm-yyyy'), '6', '01', '213', '08', '2009', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3502, to_date('02-08-2009', 'dd-mm-yyyy'), '7', '02', '214', '08', '2009', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3503, to_date('03-08-2009', 'dd-mm-yyyy'), '1', '03', '215', '08', '2009', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3504, to_date('04-08-2009', 'dd-mm-yyyy'), '2', '04', '216', '08', '2009', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3505, to_date('05-08-2009', 'dd-mm-yyyy'), '3', '05', '217', '08', '2009', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3506, to_date('06-08-2009', 'dd-mm-yyyy'), '4', '06', '218', '08', '2009', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3507, to_date('07-08-2009', 'dd-mm-yyyy'), '5', '07', '219', '08', '2009', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3508, to_date('08-08-2009', 'dd-mm-yyyy'), '6', '08', '220', '08', '2009', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3509, to_date('09-08-2009', 'dd-mm-yyyy'), '7', '09', '221', '08', '2009', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3510, to_date('10-08-2009', 'dd-mm-yyyy'), '1', '10', '222', '08', '2009', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3511, to_date('11-08-2009', 'dd-mm-yyyy'), '2', '11', '223', '08', '2009', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3512, to_date('12-08-2009', 'dd-mm-yyyy'), '3', '12', '224', '08', '2009', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3513, to_date('13-08-2009', 'dd-mm-yyyy'), '4', '13', '225', '08', '2009', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3514, to_date('14-08-2009', 'dd-mm-yyyy'), '5', '14', '226', '08', '2009', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3515, to_date('15-08-2009', 'dd-mm-yyyy'), '6', '15', '227', '08', '2009', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3516, to_date('16-08-2009', 'dd-mm-yyyy'), '7', '16', '228', '08', '2009', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3517, to_date('17-08-2009', 'dd-mm-yyyy'), '1', '17', '229', '08', '2009', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3518, to_date('18-08-2009', 'dd-mm-yyyy'), '2', '18', '230', '08', '2009', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3519, to_date('19-08-2009', 'dd-mm-yyyy'), '3', '19', '231', '08', '2009', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3520, to_date('20-08-2009', 'dd-mm-yyyy'), '4', '20', '232', '08', '2009', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3521, to_date('21-08-2009', 'dd-mm-yyyy'), '5', '21', '233', '08', '2009', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3522, to_date('22-08-2009', 'dd-mm-yyyy'), '6', '22', '234', '08', '2009', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3523, to_date('23-08-2009', 'dd-mm-yyyy'), '7', '23', '235', '08', '2009', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3524, to_date('24-08-2009', 'dd-mm-yyyy'), '1', '24', '236', '08', '2009', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3525, to_date('25-08-2009', 'dd-mm-yyyy'), '2', '25', '237', '08', '2009', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3526, to_date('26-08-2009', 'dd-mm-yyyy'), '3', '26', '238', '08', '2009', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3527, to_date('27-08-2009', 'dd-mm-yyyy'), '4', '27', '239', '08', '2009', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3528, to_date('28-08-2009', 'dd-mm-yyyy'), '5', '28', '240', '08', '2009', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3529, to_date('29-08-2009', 'dd-mm-yyyy'), '6', '29', '241', '08', '2009', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3530, to_date('30-08-2009', 'dd-mm-yyyy'), '7', '30', '242', '08', '2009', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3531, to_date('31-08-2009', 'dd-mm-yyyy'), '1', '31', '243', '08', '2009', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3532, to_date('01-09-2009', 'dd-mm-yyyy'), '2', '01', '244', '09', '2009', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3533, to_date('02-09-2009', 'dd-mm-yyyy'), '3', '02', '245', '09', '2009', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3534, to_date('03-09-2009', 'dd-mm-yyyy'), '4', '03', '246', '09', '2009', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3535, to_date('04-09-2009', 'dd-mm-yyyy'), '5', '04', '247', '09', '2009', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3536, to_date('05-09-2009', 'dd-mm-yyyy'), '6', '05', '248', '09', '2009', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3537, to_date('06-09-2009', 'dd-mm-yyyy'), '7', '06', '249', '09', '2009', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3538, to_date('07-09-2009', 'dd-mm-yyyy'), '1', '07', '250', '09', '2009', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3539, to_date('08-09-2009', 'dd-mm-yyyy'), '2', '08', '251', '09', '2009', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3540, to_date('09-09-2009', 'dd-mm-yyyy'), '3', '09', '252', '09', '2009', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3541, to_date('10-09-2009', 'dd-mm-yyyy'), '4', '10', '253', '09', '2009', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3542, to_date('11-09-2009', 'dd-mm-yyyy'), '5', '11', '254', '09', '2009', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3543, to_date('12-09-2009', 'dd-mm-yyyy'), '6', '12', '255', '09', '2009', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3544, to_date('13-09-2009', 'dd-mm-yyyy'), '7', '13', '256', '09', '2009', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3545, to_date('14-09-2009', 'dd-mm-yyyy'), '1', '14', '257', '09', '2009', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3546, to_date('15-09-2009', 'dd-mm-yyyy'), '2', '15', '258', '09', '2009', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3547, to_date('16-09-2009', 'dd-mm-yyyy'), '3', '16', '259', '09', '2009', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3548, to_date('17-09-2009', 'dd-mm-yyyy'), '4', '17', '260', '09', '2009', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3549, to_date('18-09-2009', 'dd-mm-yyyy'), '5', '18', '261', '09', '2009', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3550, to_date('19-09-2009', 'dd-mm-yyyy'), '6', '19', '262', '09', '2009', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3551, to_date('20-09-2009', 'dd-mm-yyyy'), '7', '20', '263', '09', '2009', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3552, to_date('21-09-2009', 'dd-mm-yyyy'), '1', '21', '264', '09', '2009', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3553, to_date('22-09-2009', 'dd-mm-yyyy'), '2', '22', '265', '09', '2009', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3554, to_date('23-09-2009', 'dd-mm-yyyy'), '3', '23', '266', '09', '2009', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3555, to_date('24-09-2009', 'dd-mm-yyyy'), '4', '24', '267', '09', '2009', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3556, to_date('25-09-2009', 'dd-mm-yyyy'), '5', '25', '268', '09', '2009', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3557, to_date('26-09-2009', 'dd-mm-yyyy'), '6', '26', '269', '09', '2009', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3558, to_date('27-09-2009', 'dd-mm-yyyy'), '7', '27', '270', '09', '2009', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3559, to_date('28-09-2009', 'dd-mm-yyyy'), '1', '28', '271', '09', '2009', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3560, to_date('29-09-2009', 'dd-mm-yyyy'), '2', '29', '272', '09', '2009', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3561, to_date('30-09-2009', 'dd-mm-yyyy'), '3', '30', '273', '09', '2009', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3562, to_date('01-10-2009', 'dd-mm-yyyy'), '4', '01', '274', '10', '2009', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3563, to_date('02-10-2009', 'dd-mm-yyyy'), '5', '02', '275', '10', '2009', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3564, to_date('03-10-2009', 'dd-mm-yyyy'), '6', '03', '276', '10', '2009', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3565, to_date('04-10-2009', 'dd-mm-yyyy'), '7', '04', '277', '10', '2009', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3566, to_date('05-10-2009', 'dd-mm-yyyy'), '1', '05', '278', '10', '2009', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3567, to_date('06-10-2009', 'dd-mm-yyyy'), '2', '06', '279', '10', '2009', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3568, to_date('07-10-2009', 'dd-mm-yyyy'), '3', '07', '280', '10', '2009', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3569, to_date('08-10-2009', 'dd-mm-yyyy'), '4', '08', '281', '10', '2009', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3570, to_date('09-10-2009', 'dd-mm-yyyy'), '5', '09', '282', '10', '2009', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3571, to_date('10-10-2009', 'dd-mm-yyyy'), '6', '10', '283', '10', '2009', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3572, to_date('11-10-2009', 'dd-mm-yyyy'), '7', '11', '284', '10', '2009', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3573, to_date('12-10-2009', 'dd-mm-yyyy'), '1', '12', '285', '10', '2009', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3574, to_date('13-10-2009', 'dd-mm-yyyy'), '2', '13', '286', '10', '2009', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3575, to_date('14-10-2009', 'dd-mm-yyyy'), '3', '14', '287', '10', '2009', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3576, to_date('15-10-2009', 'dd-mm-yyyy'), '4', '15', '288', '10', '2009', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3577, to_date('16-10-2009', 'dd-mm-yyyy'), '5', '16', '289', '10', '2009', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3578, to_date('17-10-2009', 'dd-mm-yyyy'), '6', '17', '290', '10', '2009', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3579, to_date('18-10-2009', 'dd-mm-yyyy'), '7', '18', '291', '10', '2009', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3580, to_date('19-10-2009', 'dd-mm-yyyy'), '1', '19', '292', '10', '2009', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3581, to_date('20-10-2009', 'dd-mm-yyyy'), '2', '20', '293', '10', '2009', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3582, to_date('21-10-2009', 'dd-mm-yyyy'), '3', '21', '294', '10', '2009', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3583, to_date('22-10-2009', 'dd-mm-yyyy'), '4', '22', '295', '10', '2009', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3584, to_date('23-10-2009', 'dd-mm-yyyy'), '5', '23', '296', '10', '2009', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3585, to_date('24-10-2009', 'dd-mm-yyyy'), '6', '24', '297', '10', '2009', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3586, to_date('25-10-2009', 'dd-mm-yyyy'), '7', '25', '298', '10', '2009', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3587, to_date('26-10-2009', 'dd-mm-yyyy'), '1', '26', '299', '10', '2009', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3588, to_date('27-10-2009', 'dd-mm-yyyy'), '2', '27', '300', '10', '2009', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3589, to_date('28-10-2009', 'dd-mm-yyyy'), '3', '28', '301', '10', '2009', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3590, to_date('29-10-2009', 'dd-mm-yyyy'), '4', '29', '302', '10', '2009', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3591, to_date('30-10-2009', 'dd-mm-yyyy'), '5', '30', '303', '10', '2009', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3592, to_date('31-10-2009', 'dd-mm-yyyy'), '6', '31', '304', '10', '2009', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3593, to_date('01-11-2009', 'dd-mm-yyyy'), '7', '01', '305', '11', '2009', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3594, to_date('02-11-2009', 'dd-mm-yyyy'), '1', '02', '306', '11', '2009', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3595, to_date('03-11-2009', 'dd-mm-yyyy'), '2', '03', '307', '11', '2009', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3596, to_date('04-11-2009', 'dd-mm-yyyy'), '3', '04', '308', '11', '2009', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3597, to_date('05-11-2009', 'dd-mm-yyyy'), '4', '05', '309', '11', '2009', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3598, to_date('06-11-2009', 'dd-mm-yyyy'), '5', '06', '310', '11', '2009', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3599, to_date('07-11-2009', 'dd-mm-yyyy'), '6', '07', '311', '11', '2009', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3600, to_date('08-11-2009', 'dd-mm-yyyy'), '7', '08', '312', '11', '2009', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3601, to_date('09-11-2009', 'dd-mm-yyyy'), '1', '09', '313', '11', '2009', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3602, to_date('10-11-2009', 'dd-mm-yyyy'), '2', '10', '314', '11', '2009', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3603, to_date('11-11-2009', 'dd-mm-yyyy'), '3', '11', '315', '11', '2009', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3604, to_date('12-11-2009', 'dd-mm-yyyy'), '4', '12', '316', '11', '2009', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3605, to_date('13-11-2009', 'dd-mm-yyyy'), '5', '13', '317', '11', '2009', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3606, to_date('14-11-2009', 'dd-mm-yyyy'), '6', '14', '318', '11', '2009', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3607, to_date('15-11-2009', 'dd-mm-yyyy'), '7', '15', '319', '11', '2009', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3608, to_date('16-11-2009', 'dd-mm-yyyy'), '1', '16', '320', '11', '2009', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3609, to_date('17-11-2009', 'dd-mm-yyyy'), '2', '17', '321', '11', '2009', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3610, to_date('18-11-2009', 'dd-mm-yyyy'), '3', '18', '322', '11', '2009', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3611, to_date('19-11-2009', 'dd-mm-yyyy'), '4', '19', '323', '11', '2009', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3612, to_date('20-11-2009', 'dd-mm-yyyy'), '5', '20', '324', '11', '2009', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3613, to_date('21-11-2009', 'dd-mm-yyyy'), '6', '21', '325', '11', '2009', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3614, to_date('22-11-2009', 'dd-mm-yyyy'), '7', '22', '326', '11', '2009', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3615, to_date('23-11-2009', 'dd-mm-yyyy'), '1', '23', '327', '11', '2009', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3616, to_date('24-11-2009', 'dd-mm-yyyy'), '2', '24', '328', '11', '2009', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3617, to_date('25-11-2009', 'dd-mm-yyyy'), '3', '25', '329', '11', '2009', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3618, to_date('26-11-2009', 'dd-mm-yyyy'), '4', '26', '330', '11', '2009', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3619, to_date('27-11-2009', 'dd-mm-yyyy'), '5', '27', '331', '11', '2009', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3620, to_date('28-11-2009', 'dd-mm-yyyy'), '6', '28', '332', '11', '2009', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3621, to_date('29-11-2009', 'dd-mm-yyyy'), '7', '29', '333', '11', '2009', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3622, to_date('30-11-2009', 'dd-mm-yyyy'), '1', '30', '334', '11', '2009', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3623, to_date('01-12-2009', 'dd-mm-yyyy'), '2', '01', '335', '12', '2009', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3624, to_date('02-12-2009', 'dd-mm-yyyy'), '3', '02', '336', '12', '2009', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3625, to_date('03-12-2009', 'dd-mm-yyyy'), '4', '03', '337', '12', '2009', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3626, to_date('04-12-2009', 'dd-mm-yyyy'), '5', '04', '338', '12', '2009', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3627, to_date('05-12-2009', 'dd-mm-yyyy'), '6', '05', '339', '12', '2009', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3628, to_date('06-12-2009', 'dd-mm-yyyy'), '7', '06', '340', '12', '2009', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3629, to_date('07-12-2009', 'dd-mm-yyyy'), '1', '07', '341', '12', '2009', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3630, to_date('08-12-2009', 'dd-mm-yyyy'), '2', '08', '342', '12', '2009', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3631, to_date('09-12-2009', 'dd-mm-yyyy'), '3', '09', '343', '12', '2009', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3632, to_date('10-12-2009', 'dd-mm-yyyy'), '4', '10', '344', '12', '2009', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3633, to_date('11-12-2009', 'dd-mm-yyyy'), '5', '11', '345', '12', '2009', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3634, to_date('12-12-2009', 'dd-mm-yyyy'), '6', '12', '346', '12', '2009', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3635, to_date('13-12-2009', 'dd-mm-yyyy'), '7', '13', '347', '12', '2009', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3636, to_date('14-12-2009', 'dd-mm-yyyy'), '1', '14', '348', '12', '2009', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3637, to_date('15-12-2009', 'dd-mm-yyyy'), '2', '15', '349', '12', '2009', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3638, to_date('16-12-2009', 'dd-mm-yyyy'), '3', '16', '350', '12', '2009', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3639, to_date('17-12-2009', 'dd-mm-yyyy'), '4', '17', '351', '12', '2009', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3640, to_date('18-12-2009', 'dd-mm-yyyy'), '5', '18', '352', '12', '2009', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3641, to_date('19-12-2009', 'dd-mm-yyyy'), '6', '19', '353', '12', '2009', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3642, to_date('20-12-2009', 'dd-mm-yyyy'), '7', '20', '354', '12', '2009', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3643, to_date('21-12-2009', 'dd-mm-yyyy'), '1', '21', '355', '12', '2009', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3644, to_date('22-12-2009', 'dd-mm-yyyy'), '2', '22', '356', '12', '2009', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3645, to_date('23-12-2009', 'dd-mm-yyyy'), '3', '23', '357', '12', '2009', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3646, to_date('24-12-2009', 'dd-mm-yyyy'), '4', '24', '358', '12', '2009', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3647, to_date('25-12-2009', 'dd-mm-yyyy'), '5', '25', '359', '12', '2009', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3648, to_date('26-12-2009', 'dd-mm-yyyy'), '6', '26', '360', '12', '2009', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3649, to_date('27-12-2009', 'dd-mm-yyyy'), '7', '27', '361', '12', '2009', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3650, to_date('28-12-2009', 'dd-mm-yyyy'), '1', '28', '362', '12', '2009', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3651, to_date('29-12-2009', 'dd-mm-yyyy'), '2', '29', '363', '12', '2009', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3652, to_date('30-12-2009', 'dd-mm-yyyy'), '3', '30', '364', '12', '2009', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3653, to_date('31-12-2009', 'dd-mm-yyyy'), '4', '31', '365', '12', '2009', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3654, to_date('01-01-2010', 'dd-mm-yyyy'), '5', '01', '001', '01', '2010', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3655, to_date('02-01-2010', 'dd-mm-yyyy'), '6', '02', '002', '01', '2010', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3656, to_date('03-01-2010', 'dd-mm-yyyy'), '7', '03', '003', '01', '2010', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3657, to_date('04-01-2010', 'dd-mm-yyyy'), '1', '04', '004', '01', '2010', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3658, to_date('05-01-2010', 'dd-mm-yyyy'), '2', '05', '005', '01', '2010', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3659, to_date('06-01-2010', 'dd-mm-yyyy'), '3', '06', '006', '01', '2010', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3660, to_date('07-01-2010', 'dd-mm-yyyy'), '4', '07', '007', '01', '2010', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3661, to_date('08-01-2010', 'dd-mm-yyyy'), '5', '08', '008', '01', '2010', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3662, to_date('09-01-2010', 'dd-mm-yyyy'), '6', '09', '009', '01', '2010', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3663, to_date('10-01-2010', 'dd-mm-yyyy'), '7', '10', '010', '01', '2010', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3664, to_date('11-01-2010', 'dd-mm-yyyy'), '1', '11', '011', '01', '2010', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3665, to_date('12-01-2010', 'dd-mm-yyyy'), '2', '12', '012', '01', '2010', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3666, to_date('13-01-2010', 'dd-mm-yyyy'), '3', '13', '013', '01', '2010', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3667, to_date('14-01-2010', 'dd-mm-yyyy'), '4', '14', '014', '01', '2010', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3668, to_date('15-01-2010', 'dd-mm-yyyy'), '5', '15', '015', '01', '2010', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3669, to_date('16-01-2010', 'dd-mm-yyyy'), '6', '16', '016', '01', '2010', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3670, to_date('17-01-2010', 'dd-mm-yyyy'), '7', '17', '017', '01', '2010', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3671, to_date('18-01-2010', 'dd-mm-yyyy'), '1', '18', '018', '01', '2010', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3672, to_date('19-01-2010', 'dd-mm-yyyy'), '2', '19', '019', '01', '2010', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3673, to_date('20-01-2010', 'dd-mm-yyyy'), '3', '20', '020', '01', '2010', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3674, to_date('21-01-2010', 'dd-mm-yyyy'), '4', '21', '021', '01', '2010', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3675, to_date('22-01-2010', 'dd-mm-yyyy'), '5', '22', '022', '01', '2010', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3676, to_date('23-01-2010', 'dd-mm-yyyy'), '6', '23', '023', '01', '2010', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3677, to_date('24-01-2010', 'dd-mm-yyyy'), '7', '24', '024', '01', '2010', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3678, to_date('25-01-2010', 'dd-mm-yyyy'), '1', '25', '025', '01', '2010', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3679, to_date('26-01-2010', 'dd-mm-yyyy'), '2', '26', '026', '01', '2010', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3680, to_date('27-01-2010', 'dd-mm-yyyy'), '3', '27', '027', '01', '2010', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3681, to_date('28-01-2010', 'dd-mm-yyyy'), '4', '28', '028', '01', '2010', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3682, to_date('29-01-2010', 'dd-mm-yyyy'), '5', '29', '029', '01', '2010', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3683, to_date('30-01-2010', 'dd-mm-yyyy'), '6', '30', '030', '01', '2010', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3684, to_date('31-01-2010', 'dd-mm-yyyy'), '7', '31', '031', '01', '2010', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3685, to_date('01-02-2010', 'dd-mm-yyyy'), '1', '01', '032', '02', '2010', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3686, to_date('02-02-2010', 'dd-mm-yyyy'), '2', '02', '033', '02', '2010', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3687, to_date('03-02-2010', 'dd-mm-yyyy'), '3', '03', '034', '02', '2010', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3688, to_date('04-02-2010', 'dd-mm-yyyy'), '4', '04', '035', '02', '2010', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3689, to_date('05-02-2010', 'dd-mm-yyyy'), '5', '05', '036', '02', '2010', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3690, to_date('06-02-2010', 'dd-mm-yyyy'), '6', '06', '037', '02', '2010', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3691, to_date('07-02-2010', 'dd-mm-yyyy'), '7', '07', '038', '02', '2010', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3692, to_date('08-02-2010', 'dd-mm-yyyy'), '1', '08', '039', '02', '2010', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3693, to_date('09-02-2010', 'dd-mm-yyyy'), '2', '09', '040', '02', '2010', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3694, to_date('10-02-2010', 'dd-mm-yyyy'), '3', '10', '041', '02', '2010', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3695, to_date('11-02-2010', 'dd-mm-yyyy'), '4', '11', '042', '02', '2010', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3696, to_date('12-02-2010', 'dd-mm-yyyy'), '5', '12', '043', '02', '2010', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3697, to_date('13-02-2010', 'dd-mm-yyyy'), '6', '13', '044', '02', '2010', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3698, to_date('14-02-2010', 'dd-mm-yyyy'), '7', '14', '045', '02', '2010', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3699, to_date('15-02-2010', 'dd-mm-yyyy'), '1', '15', '046', '02', '2010', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3700, to_date('16-02-2010', 'dd-mm-yyyy'), '2', '16', '047', '02', '2010', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3701, to_date('17-02-2010', 'dd-mm-yyyy'), '3', '17', '048', '02', '2010', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3702, to_date('18-02-2010', 'dd-mm-yyyy'), '4', '18', '049', '02', '2010', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3703, to_date('19-02-2010', 'dd-mm-yyyy'), '5', '19', '050', '02', '2010', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3704, to_date('20-02-2010', 'dd-mm-yyyy'), '6', '20', '051', '02', '2010', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3705, to_date('21-02-2010', 'dd-mm-yyyy'), '7', '21', '052', '02', '2010', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3706, to_date('22-02-2010', 'dd-mm-yyyy'), '1', '22', '053', '02', '2010', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3707, to_date('23-02-2010', 'dd-mm-yyyy'), '2', '23', '054', '02', '2010', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3708, to_date('24-02-2010', 'dd-mm-yyyy'), '3', '24', '055', '02', '2010', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3709, to_date('25-02-2010', 'dd-mm-yyyy'), '4', '25', '056', '02', '2010', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3710, to_date('26-02-2010', 'dd-mm-yyyy'), '5', '26', '057', '02', '2010', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3711, to_date('27-02-2010', 'dd-mm-yyyy'), '6', '27', '058', '02', '2010', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3712, to_date('28-02-2010', 'dd-mm-yyyy'), '7', '28', '059', '02', '2010', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3713, to_date('01-03-2010', 'dd-mm-yyyy'), '1', '01', '060', '03', '2010', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3714, to_date('02-03-2010', 'dd-mm-yyyy'), '2', '02', '061', '03', '2010', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3715, to_date('03-03-2010', 'dd-mm-yyyy'), '3', '03', '062', '03', '2010', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3716, to_date('04-03-2010', 'dd-mm-yyyy'), '4', '04', '063', '03', '2010', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3717, to_date('05-03-2010', 'dd-mm-yyyy'), '5', '05', '064', '03', '2010', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3718, to_date('06-03-2010', 'dd-mm-yyyy'), '6', '06', '065', '03', '2010', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3719, to_date('07-03-2010', 'dd-mm-yyyy'), '7', '07', '066', '03', '2010', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3720, to_date('08-03-2010', 'dd-mm-yyyy'), '1', '08', '067', '03', '2010', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3721, to_date('09-03-2010', 'dd-mm-yyyy'), '2', '09', '068', '03', '2010', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3722, to_date('10-03-2010', 'dd-mm-yyyy'), '3', '10', '069', '03', '2010', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3723, to_date('11-03-2010', 'dd-mm-yyyy'), '4', '11', '070', '03', '2010', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3724, to_date('12-03-2010', 'dd-mm-yyyy'), '5', '12', '071', '03', '2010', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3725, to_date('13-03-2010', 'dd-mm-yyyy'), '6', '13', '072', '03', '2010', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3726, to_date('14-03-2010', 'dd-mm-yyyy'), '7', '14', '073', '03', '2010', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3727, to_date('15-03-2010', 'dd-mm-yyyy'), '1', '15', '074', '03', '2010', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3728, to_date('16-03-2010', 'dd-mm-yyyy'), '2', '16', '075', '03', '2010', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3729, to_date('17-03-2010', 'dd-mm-yyyy'), '3', '17', '076', '03', '2010', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3730, to_date('18-03-2010', 'dd-mm-yyyy'), '4', '18', '077', '03', '2010', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3731, to_date('19-03-2010', 'dd-mm-yyyy'), '5', '19', '078', '03', '2010', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3732, to_date('20-03-2010', 'dd-mm-yyyy'), '6', '20', '079', '03', '2010', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3733, to_date('21-03-2010', 'dd-mm-yyyy'), '7', '21', '080', '03', '2010', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3734, to_date('22-03-2010', 'dd-mm-yyyy'), '1', '22', '081', '03', '2010', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3735, to_date('23-03-2010', 'dd-mm-yyyy'), '2', '23', '082', '03', '2010', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3736, to_date('24-03-2010', 'dd-mm-yyyy'), '3', '24', '083', '03', '2010', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3737, to_date('25-03-2010', 'dd-mm-yyyy'), '4', '25', '084', '03', '2010', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3738, to_date('26-03-2010', 'dd-mm-yyyy'), '5', '26', '085', '03', '2010', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3739, to_date('27-03-2010', 'dd-mm-yyyy'), '6', '27', '086', '03', '2010', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3740, to_date('28-03-2010', 'dd-mm-yyyy'), '7', '28', '087', '03', '2010', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3741, to_date('29-03-2010', 'dd-mm-yyyy'), '1', '29', '088', '03', '2010', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3742, to_date('30-03-2010', 'dd-mm-yyyy'), '2', '30', '089', '03', '2010', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3743, to_date('31-03-2010', 'dd-mm-yyyy'), '3', '31', '090', '03', '2010', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3744, to_date('01-04-2010', 'dd-mm-yyyy'), '4', '01', '091', '04', '2010', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3745, to_date('02-04-2010', 'dd-mm-yyyy'), '5', '02', '092', '04', '2010', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3746, to_date('03-04-2010', 'dd-mm-yyyy'), '6', '03', '093', '04', '2010', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3747, to_date('04-04-2010', 'dd-mm-yyyy'), '7', '04', '094', '04', '2010', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3748, to_date('05-04-2010', 'dd-mm-yyyy'), '1', '05', '095', '04', '2010', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3749, to_date('06-04-2010', 'dd-mm-yyyy'), '2', '06', '096', '04', '2010', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3750, to_date('07-04-2010', 'dd-mm-yyyy'), '3', '07', '097', '04', '2010', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3751, to_date('08-04-2010', 'dd-mm-yyyy'), '4', '08', '098', '04', '2010', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3752, to_date('09-04-2010', 'dd-mm-yyyy'), '5', '09', '099', '04', '2010', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3753, to_date('10-04-2010', 'dd-mm-yyyy'), '6', '10', '100', '04', '2010', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3754, to_date('11-04-2010', 'dd-mm-yyyy'), '7', '11', '101', '04', '2010', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3755, to_date('12-04-2010', 'dd-mm-yyyy'), '1', '12', '102', '04', '2010', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3756, to_date('13-04-2010', 'dd-mm-yyyy'), '2', '13', '103', '04', '2010', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3757, to_date('14-04-2010', 'dd-mm-yyyy'), '3', '14', '104', '04', '2010', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3758, to_date('15-04-2010', 'dd-mm-yyyy'), '4', '15', '105', '04', '2010', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3759, to_date('16-04-2010', 'dd-mm-yyyy'), '5', '16', '106', '04', '2010', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3760, to_date('17-04-2010', 'dd-mm-yyyy'), '6', '17', '107', '04', '2010', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3761, to_date('18-04-2010', 'dd-mm-yyyy'), '7', '18', '108', '04', '2010', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3762, to_date('19-04-2010', 'dd-mm-yyyy'), '1', '19', '109', '04', '2010', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3763, to_date('20-04-2010', 'dd-mm-yyyy'), '2', '20', '110', '04', '2010', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3764, to_date('21-04-2010', 'dd-mm-yyyy'), '3', '21', '111', '04', '2010', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3765, to_date('22-04-2010', 'dd-mm-yyyy'), '4', '22', '112', '04', '2010', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3766, to_date('23-04-2010', 'dd-mm-yyyy'), '5', '23', '113', '04', '2010', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3767, to_date('24-04-2010', 'dd-mm-yyyy'), '6', '24', '114', '04', '2010', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3768, to_date('25-04-2010', 'dd-mm-yyyy'), '7', '25', '115', '04', '2010', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3769, to_date('26-04-2010', 'dd-mm-yyyy'), '1', '26', '116', '04', '2010', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3770, to_date('27-04-2010', 'dd-mm-yyyy'), '2', '27', '117', '04', '2010', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3771, to_date('28-04-2010', 'dd-mm-yyyy'), '3', '28', '118', '04', '2010', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3772, to_date('29-04-2010', 'dd-mm-yyyy'), '4', '29', '119', '04', '2010', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3773, to_date('30-04-2010', 'dd-mm-yyyy'), '5', '30', '120', '04', '2010', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3774, to_date('01-05-2010', 'dd-mm-yyyy'), '6', '01', '121', '05', '2010', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3775, to_date('02-05-2010', 'dd-mm-yyyy'), '7', '02', '122', '05', '2010', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3776, to_date('03-05-2010', 'dd-mm-yyyy'), '1', '03', '123', '05', '2010', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3777, to_date('04-05-2010', 'dd-mm-yyyy'), '2', '04', '124', '05', '2010', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3778, to_date('05-05-2010', 'dd-mm-yyyy'), '3', '05', '125', '05', '2010', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3779, to_date('06-05-2010', 'dd-mm-yyyy'), '4', '06', '126', '05', '2010', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3780, to_date('07-05-2010', 'dd-mm-yyyy'), '5', '07', '127', '05', '2010', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3781, to_date('08-05-2010', 'dd-mm-yyyy'), '6', '08', '128', '05', '2010', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3782, to_date('09-05-2010', 'dd-mm-yyyy'), '7', '09', '129', '05', '2010', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3783, to_date('10-05-2010', 'dd-mm-yyyy'), '1', '10', '130', '05', '2010', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3784, to_date('11-05-2010', 'dd-mm-yyyy'), '2', '11', '131', '05', '2010', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3785, to_date('12-05-2010', 'dd-mm-yyyy'), '3', '12', '132', '05', '2010', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3786, to_date('13-05-2010', 'dd-mm-yyyy'), '4', '13', '133', '05', '2010', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3787, to_date('14-05-2010', 'dd-mm-yyyy'), '5', '14', '134', '05', '2010', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3788, to_date('15-05-2010', 'dd-mm-yyyy'), '6', '15', '135', '05', '2010', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3789, to_date('16-05-2010', 'dd-mm-yyyy'), '7', '16', '136', '05', '2010', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3790, to_date('17-05-2010', 'dd-mm-yyyy'), '1', '17', '137', '05', '2010', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3791, to_date('18-05-2010', 'dd-mm-yyyy'), '2', '18', '138', '05', '2010', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3792, to_date('19-05-2010', 'dd-mm-yyyy'), '3', '19', '139', '05', '2010', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3793, to_date('20-05-2010', 'dd-mm-yyyy'), '4', '20', '140', '05', '2010', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3794, to_date('21-05-2010', 'dd-mm-yyyy'), '5', '21', '141', '05', '2010', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3795, to_date('22-05-2010', 'dd-mm-yyyy'), '6', '22', '142', '05', '2010', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3796, to_date('23-05-2010', 'dd-mm-yyyy'), '7', '23', '143', '05', '2010', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3797, to_date('24-05-2010', 'dd-mm-yyyy'), '1', '24', '144', '05', '2010', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3798, to_date('25-05-2010', 'dd-mm-yyyy'), '2', '25', '145', '05', '2010', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3799, to_date('26-05-2010', 'dd-mm-yyyy'), '3', '26', '146', '05', '2010', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3800, to_date('27-05-2010', 'dd-mm-yyyy'), '4', '27', '147', '05', '2010', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3801, to_date('28-05-2010', 'dd-mm-yyyy'), '5', '28', '148', '05', '2010', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3802, to_date('29-05-2010', 'dd-mm-yyyy'), '6', '29', '149', '05', '2010', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3803, to_date('30-05-2010', 'dd-mm-yyyy'), '7', '30', '150', '05', '2010', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3804, to_date('31-05-2010', 'dd-mm-yyyy'), '1', '31', '151', '05', '2010', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3805, to_date('01-06-2010', 'dd-mm-yyyy'), '2', '01', '152', '06', '2010', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3806, to_date('02-06-2010', 'dd-mm-yyyy'), '3', '02', '153', '06', '2010', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3807, to_date('03-06-2010', 'dd-mm-yyyy'), '4', '03', '154', '06', '2010', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3808, to_date('04-06-2010', 'dd-mm-yyyy'), '5', '04', '155', '06', '2010', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3809, to_date('05-06-2010', 'dd-mm-yyyy'), '6', '05', '156', '06', '2010', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3810, to_date('06-06-2010', 'dd-mm-yyyy'), '7', '06', '157', '06', '2010', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3811, to_date('07-06-2010', 'dd-mm-yyyy'), '1', '07', '158', '06', '2010', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3812, to_date('08-06-2010', 'dd-mm-yyyy'), '2', '08', '159', '06', '2010', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3813, to_date('09-06-2010', 'dd-mm-yyyy'), '3', '09', '160', '06', '2010', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3814, to_date('10-06-2010', 'dd-mm-yyyy'), '4', '10', '161', '06', '2010', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3815, to_date('11-06-2010', 'dd-mm-yyyy'), '5', '11', '162', '06', '2010', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3816, to_date('12-06-2010', 'dd-mm-yyyy'), '6', '12', '163', '06', '2010', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3817, to_date('13-06-2010', 'dd-mm-yyyy'), '7', '13', '164', '06', '2010', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3818, to_date('14-06-2010', 'dd-mm-yyyy'), '1', '14', '165', '06', '2010', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3819, to_date('15-06-2010', 'dd-mm-yyyy'), '2', '15', '166', '06', '2010', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3820, to_date('16-06-2010', 'dd-mm-yyyy'), '3', '16', '167', '06', '2010', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3821, to_date('17-06-2010', 'dd-mm-yyyy'), '4', '17', '168', '06', '2010', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3822, to_date('18-06-2010', 'dd-mm-yyyy'), '5', '18', '169', '06', '2010', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3823, to_date('19-06-2010', 'dd-mm-yyyy'), '6', '19', '170', '06', '2010', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3824, to_date('20-06-2010', 'dd-mm-yyyy'), '7', '20', '171', '06', '2010', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3825, to_date('21-06-2010', 'dd-mm-yyyy'), '1', '21', '172', '06', '2010', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3826, to_date('22-06-2010', 'dd-mm-yyyy'), '2', '22', '173', '06', '2010', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3827, to_date('23-06-2010', 'dd-mm-yyyy'), '3', '23', '174', '06', '2010', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3828, to_date('24-06-2010', 'dd-mm-yyyy'), '4', '24', '175', '06', '2010', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3829, to_date('25-06-2010', 'dd-mm-yyyy'), '5', '25', '176', '06', '2010', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3830, to_date('26-06-2010', 'dd-mm-yyyy'), '6', '26', '177', '06', '2010', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3831, to_date('27-06-2010', 'dd-mm-yyyy'), '7', '27', '178', '06', '2010', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3832, to_date('28-06-2010', 'dd-mm-yyyy'), '1', '28', '179', '06', '2010', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3833, to_date('29-06-2010', 'dd-mm-yyyy'), '2', '29', '180', '06', '2010', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3834, to_date('30-06-2010', 'dd-mm-yyyy'), '3', '30', '181', '06', '2010', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3835, to_date('01-07-2010', 'dd-mm-yyyy'), '4', '01', '182', '07', '2010', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3836, to_date('02-07-2010', 'dd-mm-yyyy'), '5', '02', '183', '07', '2010', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3837, to_date('03-07-2010', 'dd-mm-yyyy'), '6', '03', '184', '07', '2010', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3838, to_date('04-07-2010', 'dd-mm-yyyy'), '7', '04', '185', '07', '2010', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3839, to_date('05-07-2010', 'dd-mm-yyyy'), '1', '05', '186', '07', '2010', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3840, to_date('06-07-2010', 'dd-mm-yyyy'), '2', '06', '187', '07', '2010', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3841, to_date('07-07-2010', 'dd-mm-yyyy'), '3', '07', '188', '07', '2010', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3842, to_date('08-07-2010', 'dd-mm-yyyy'), '4', '08', '189', '07', '2010', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3843, to_date('09-07-2010', 'dd-mm-yyyy'), '5', '09', '190', '07', '2010', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3844, to_date('10-07-2010', 'dd-mm-yyyy'), '6', '10', '191', '07', '2010', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3845, to_date('11-07-2010', 'dd-mm-yyyy'), '7', '11', '192', '07', '2010', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3846, to_date('12-07-2010', 'dd-mm-yyyy'), '1', '12', '193', '07', '2010', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3847, to_date('13-07-2010', 'dd-mm-yyyy'), '2', '13', '194', '07', '2010', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3848, to_date('14-07-2010', 'dd-mm-yyyy'), '3', '14', '195', '07', '2010', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3849, to_date('15-07-2010', 'dd-mm-yyyy'), '4', '15', '196', '07', '2010', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3850, to_date('16-07-2010', 'dd-mm-yyyy'), '5', '16', '197', '07', '2010', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3851, to_date('17-07-2010', 'dd-mm-yyyy'), '6', '17', '198', '07', '2010', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3852, to_date('18-07-2010', 'dd-mm-yyyy'), '7', '18', '199', '07', '2010', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3853, to_date('19-07-2010', 'dd-mm-yyyy'), '1', '19', '200', '07', '2010', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3854, to_date('20-07-2010', 'dd-mm-yyyy'), '2', '20', '201', '07', '2010', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3855, to_date('21-07-2010', 'dd-mm-yyyy'), '3', '21', '202', '07', '2010', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3856, to_date('22-07-2010', 'dd-mm-yyyy'), '4', '22', '203', '07', '2010', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3857, to_date('23-07-2010', 'dd-mm-yyyy'), '5', '23', '204', '07', '2010', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3858, to_date('24-07-2010', 'dd-mm-yyyy'), '6', '24', '205', '07', '2010', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3859, to_date('25-07-2010', 'dd-mm-yyyy'), '7', '25', '206', '07', '2010', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3860, to_date('26-07-2010', 'dd-mm-yyyy'), '1', '26', '207', '07', '2010', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3861, to_date('27-07-2010', 'dd-mm-yyyy'), '2', '27', '208', '07', '2010', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3862, to_date('28-07-2010', 'dd-mm-yyyy'), '3', '28', '209', '07', '2010', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3863, to_date('29-07-2010', 'dd-mm-yyyy'), '4', '29', '210', '07', '2010', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3864, to_date('30-07-2010', 'dd-mm-yyyy'), '5', '30', '211', '07', '2010', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3865, to_date('31-07-2010', 'dd-mm-yyyy'), '6', '31', '212', '07', '2010', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3866, to_date('01-08-2010', 'dd-mm-yyyy'), '7', '01', '213', '08', '2010', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3867, to_date('02-08-2010', 'dd-mm-yyyy'), '1', '02', '214', '08', '2010', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3868, to_date('03-08-2010', 'dd-mm-yyyy'), '2', '03', '215', '08', '2010', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3869, to_date('04-08-2010', 'dd-mm-yyyy'), '3', '04', '216', '08', '2010', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3870, to_date('05-08-2010', 'dd-mm-yyyy'), '4', '05', '217', '08', '2010', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3871, to_date('06-08-2010', 'dd-mm-yyyy'), '5', '06', '218', '08', '2010', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3872, to_date('07-08-2010', 'dd-mm-yyyy'), '6', '07', '219', '08', '2010', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3873, to_date('08-08-2010', 'dd-mm-yyyy'), '7', '08', '220', '08', '2010', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3874, to_date('09-08-2010', 'dd-mm-yyyy'), '1', '09', '221', '08', '2010', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3875, to_date('10-08-2010', 'dd-mm-yyyy'), '2', '10', '222', '08', '2010', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3876, to_date('11-08-2010', 'dd-mm-yyyy'), '3', '11', '223', '08', '2010', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3877, to_date('12-08-2010', 'dd-mm-yyyy'), '4', '12', '224', '08', '2010', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3878, to_date('13-08-2010', 'dd-mm-yyyy'), '5', '13', '225', '08', '2010', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3879, to_date('14-08-2010', 'dd-mm-yyyy'), '6', '14', '226', '08', '2010', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3880, to_date('15-08-2010', 'dd-mm-yyyy'), '7', '15', '227', '08', '2010', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3881, to_date('16-08-2010', 'dd-mm-yyyy'), '1', '16', '228', '08', '2010', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3882, to_date('17-08-2010', 'dd-mm-yyyy'), '2', '17', '229', '08', '2010', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3883, to_date('18-08-2010', 'dd-mm-yyyy'), '3', '18', '230', '08', '2010', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3884, to_date('19-08-2010', 'dd-mm-yyyy'), '4', '19', '231', '08', '2010', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3885, to_date('20-08-2010', 'dd-mm-yyyy'), '5', '20', '232', '08', '2010', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3886, to_date('21-08-2010', 'dd-mm-yyyy'), '6', '21', '233', '08', '2010', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3887, to_date('22-08-2010', 'dd-mm-yyyy'), '7', '22', '234', '08', '2010', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3888, to_date('23-08-2010', 'dd-mm-yyyy'), '1', '23', '235', '08', '2010', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3889, to_date('24-08-2010', 'dd-mm-yyyy'), '2', '24', '236', '08', '2010', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (866, to_date('15-05-2002', 'dd-mm-yyyy'), '3', '15', '135', '05', '2002', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (867, to_date('16-05-2002', 'dd-mm-yyyy'), '4', '16', '136', '05', '2002', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (868, to_date('17-05-2002', 'dd-mm-yyyy'), '5', '17', '137', '05', '2002', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (869, to_date('18-05-2002', 'dd-mm-yyyy'), '6', '18', '138', '05', '2002', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (870, to_date('19-05-2002', 'dd-mm-yyyy'), '7', '19', '139', '05', '2002', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (871, to_date('20-05-2002', 'dd-mm-yyyy'), '1', '20', '140', '05', '2002', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (872, to_date('21-05-2002', 'dd-mm-yyyy'), '2', '21', '141', '05', '2002', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (873, to_date('22-05-2002', 'dd-mm-yyyy'), '3', '22', '142', '05', '2002', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (874, to_date('23-05-2002', 'dd-mm-yyyy'), '4', '23', '143', '05', '2002', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (875, to_date('24-05-2002', 'dd-mm-yyyy'), '5', '24', '144', '05', '2002', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (876, to_date('25-05-2002', 'dd-mm-yyyy'), '6', '25', '145', '05', '2002', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (877, to_date('26-05-2002', 'dd-mm-yyyy'), '7', '26', '146', '05', '2002', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (878, to_date('27-05-2002', 'dd-mm-yyyy'), '1', '27', '147', '05', '2002', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (879, to_date('28-05-2002', 'dd-mm-yyyy'), '2', '28', '148', '05', '2002', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (880, to_date('29-05-2002', 'dd-mm-yyyy'), '3', '29', '149', '05', '2002', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (881, to_date('30-05-2002', 'dd-mm-yyyy'), '4', '30', '150', '05', '2002', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (882, to_date('31-05-2002', 'dd-mm-yyyy'), '5', '31', '151', '05', '2002', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (883, to_date('01-06-2002', 'dd-mm-yyyy'), '6', '01', '152', '06', '2002', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (884, to_date('02-06-2002', 'dd-mm-yyyy'), '7', '02', '153', '06', '2002', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (885, to_date('03-06-2002', 'dd-mm-yyyy'), '1', '03', '154', '06', '2002', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (886, to_date('04-06-2002', 'dd-mm-yyyy'), '2', '04', '155', '06', '2002', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (887, to_date('05-06-2002', 'dd-mm-yyyy'), '3', '05', '156', '06', '2002', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (888, to_date('06-06-2002', 'dd-mm-yyyy'), '4', '06', '157', '06', '2002', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (889, to_date('07-06-2002', 'dd-mm-yyyy'), '5', '07', '158', '06', '2002', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (890, to_date('08-06-2002', 'dd-mm-yyyy'), '6', '08', '159', '06', '2002', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (891, to_date('09-06-2002', 'dd-mm-yyyy'), '7', '09', '160', '06', '2002', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (892, to_date('10-06-2002', 'dd-mm-yyyy'), '1', '10', '161', '06', '2002', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (893, to_date('11-06-2002', 'dd-mm-yyyy'), '2', '11', '162', '06', '2002', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (894, to_date('12-06-2002', 'dd-mm-yyyy'), '3', '12', '163', '06', '2002', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (895, to_date('13-06-2002', 'dd-mm-yyyy'), '4', '13', '164', '06', '2002', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (896, to_date('14-06-2002', 'dd-mm-yyyy'), '5', '14', '165', '06', '2002', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (897, to_date('15-06-2002', 'dd-mm-yyyy'), '6', '15', '166', '06', '2002', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (898, to_date('16-06-2002', 'dd-mm-yyyy'), '7', '16', '167', '06', '2002', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (899, to_date('17-06-2002', 'dd-mm-yyyy'), '1', '17', '168', '06', '2002', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (900, to_date('18-06-2002', 'dd-mm-yyyy'), '2', '18', '169', '06', '2002', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (901, to_date('19-06-2002', 'dd-mm-yyyy'), '3', '19', '170', '06', '2002', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (902, to_date('20-06-2002', 'dd-mm-yyyy'), '4', '20', '171', '06', '2002', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (903, to_date('21-06-2002', 'dd-mm-yyyy'), '5', '21', '172', '06', '2002', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (904, to_date('22-06-2002', 'dd-mm-yyyy'), '6', '22', '173', '06', '2002', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (905, to_date('23-06-2002', 'dd-mm-yyyy'), '7', '23', '174', '06', '2002', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (906, to_date('24-06-2002', 'dd-mm-yyyy'), '1', '24', '175', '06', '2002', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (907, to_date('25-06-2002', 'dd-mm-yyyy'), '2', '25', '176', '06', '2002', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (908, to_date('26-06-2002', 'dd-mm-yyyy'), '3', '26', '177', '06', '2002', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (909, to_date('27-06-2002', 'dd-mm-yyyy'), '4', '27', '178', '06', '2002', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (910, to_date('28-06-2002', 'dd-mm-yyyy'), '5', '28', '179', '06', '2002', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (911, to_date('29-06-2002', 'dd-mm-yyyy'), '6', '29', '180', '06', '2002', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (912, to_date('30-06-2002', 'dd-mm-yyyy'), '7', '30', '181', '06', '2002', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (913, to_date('01-07-2002', 'dd-mm-yyyy'), '1', '01', '182', '07', '2002', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (914, to_date('02-07-2002', 'dd-mm-yyyy'), '2', '02', '183', '07', '2002', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (915, to_date('03-07-2002', 'dd-mm-yyyy'), '3', '03', '184', '07', '2002', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (916, to_date('04-07-2002', 'dd-mm-yyyy'), '4', '04', '185', '07', '2002', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (917, to_date('05-07-2002', 'dd-mm-yyyy'), '5', '05', '186', '07', '2002', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (918, to_date('06-07-2002', 'dd-mm-yyyy'), '6', '06', '187', '07', '2002', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (919, to_date('07-07-2002', 'dd-mm-yyyy'), '7', '07', '188', '07', '2002', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (920, to_date('08-07-2002', 'dd-mm-yyyy'), '1', '08', '189', '07', '2002', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (921, to_date('09-07-2002', 'dd-mm-yyyy'), '2', '09', '190', '07', '2002', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (922, to_date('10-07-2002', 'dd-mm-yyyy'), '3', '10', '191', '07', '2002', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (923, to_date('11-07-2002', 'dd-mm-yyyy'), '4', '11', '192', '07', '2002', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (924, to_date('12-07-2002', 'dd-mm-yyyy'), '5', '12', '193', '07', '2002', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (925, to_date('13-07-2002', 'dd-mm-yyyy'), '6', '13', '194', '07', '2002', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (926, to_date('14-07-2002', 'dd-mm-yyyy'), '7', '14', '195', '07', '2002', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (927, to_date('15-07-2002', 'dd-mm-yyyy'), '1', '15', '196', '07', '2002', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (928, to_date('16-07-2002', 'dd-mm-yyyy'), '2', '16', '197', '07', '2002', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (929, to_date('17-07-2002', 'dd-mm-yyyy'), '3', '17', '198', '07', '2002', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (930, to_date('18-07-2002', 'dd-mm-yyyy'), '4', '18', '199', '07', '2002', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (931, to_date('19-07-2002', 'dd-mm-yyyy'), '5', '19', '200', '07', '2002', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (932, to_date('20-07-2002', 'dd-mm-yyyy'), '6', '20', '201', '07', '2002', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (933, to_date('21-07-2002', 'dd-mm-yyyy'), '7', '21', '202', '07', '2002', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (934, to_date('22-07-2002', 'dd-mm-yyyy'), '1', '22', '203', '07', '2002', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (935, to_date('23-07-2002', 'dd-mm-yyyy'), '2', '23', '204', '07', '2002', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (936, to_date('24-07-2002', 'dd-mm-yyyy'), '3', '24', '205', '07', '2002', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (937, to_date('25-07-2002', 'dd-mm-yyyy'), '4', '25', '206', '07', '2002', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (938, to_date('26-07-2002', 'dd-mm-yyyy'), '5', '26', '207', '07', '2002', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (939, to_date('27-07-2002', 'dd-mm-yyyy'), '6', '27', '208', '07', '2002', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (940, to_date('28-07-2002', 'dd-mm-yyyy'), '7', '28', '209', '07', '2002', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (941, to_date('29-07-2002', 'dd-mm-yyyy'), '1', '29', '210', '07', '2002', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (942, to_date('30-07-2002', 'dd-mm-yyyy'), '2', '30', '211', '07', '2002', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (943, to_date('31-07-2002', 'dd-mm-yyyy'), '3', '31', '212', '07', '2002', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (944, to_date('01-08-2002', 'dd-mm-yyyy'), '4', '01', '213', '08', '2002', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (945, to_date('02-08-2002', 'dd-mm-yyyy'), '5', '02', '214', '08', '2002', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (946, to_date('03-08-2002', 'dd-mm-yyyy'), '6', '03', '215', '08', '2002', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (947, to_date('04-08-2002', 'dd-mm-yyyy'), '7', '04', '216', '08', '2002', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (948, to_date('05-08-2002', 'dd-mm-yyyy'), '1', '05', '217', '08', '2002', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (949, to_date('06-08-2002', 'dd-mm-yyyy'), '2', '06', '218', '08', '2002', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (950, to_date('07-08-2002', 'dd-mm-yyyy'), '3', '07', '219', '08', '2002', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (951, to_date('08-08-2002', 'dd-mm-yyyy'), '4', '08', '220', '08', '2002', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (952, to_date('09-08-2002', 'dd-mm-yyyy'), '5', '09', '221', '08', '2002', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (953, to_date('10-08-2002', 'dd-mm-yyyy'), '6', '10', '222', '08', '2002', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (954, to_date('11-08-2002', 'dd-mm-yyyy'), '7', '11', '223', '08', '2002', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (955, to_date('12-08-2002', 'dd-mm-yyyy'), '1', '12', '224', '08', '2002', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (956, to_date('13-08-2002', 'dd-mm-yyyy'), '2', '13', '225', '08', '2002', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (957, to_date('14-08-2002', 'dd-mm-yyyy'), '3', '14', '226', '08', '2002', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (958, to_date('15-08-2002', 'dd-mm-yyyy'), '4', '15', '227', '08', '2002', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (959, to_date('16-08-2002', 'dd-mm-yyyy'), '5', '16', '228', '08', '2002', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (960, to_date('17-08-2002', 'dd-mm-yyyy'), '6', '17', '229', '08', '2002', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (961, to_date('18-08-2002', 'dd-mm-yyyy'), '7', '18', '230', '08', '2002', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (962, to_date('19-08-2002', 'dd-mm-yyyy'), '1', '19', '231', '08', '2002', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (963, to_date('20-08-2002', 'dd-mm-yyyy'), '2', '20', '232', '08', '2002', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (964, to_date('21-08-2002', 'dd-mm-yyyy'), '3', '21', '233', '08', '2002', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (965, to_date('22-08-2002', 'dd-mm-yyyy'), '4', '22', '234', '08', '2002', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (966, to_date('23-08-2002', 'dd-mm-yyyy'), '5', '23', '235', '08', '2002', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (967, to_date('24-08-2002', 'dd-mm-yyyy'), '6', '24', '236', '08', '2002', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (968, to_date('25-08-2002', 'dd-mm-yyyy'), '7', '25', '237', '08', '2002', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (969, to_date('26-08-2002', 'dd-mm-yyyy'), '1', '26', '238', '08', '2002', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (970, to_date('27-08-2002', 'dd-mm-yyyy'), '2', '27', '239', '08', '2002', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (971, to_date('28-08-2002', 'dd-mm-yyyy'), '3', '28', '240', '08', '2002', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (972, to_date('29-08-2002', 'dd-mm-yyyy'), '4', '29', '241', '08', '2002', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (973, to_date('30-08-2002', 'dd-mm-yyyy'), '5', '30', '242', '08', '2002', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (974, to_date('31-08-2002', 'dd-mm-yyyy'), '6', '31', '243', '08', '2002', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (975, to_date('01-09-2002', 'dd-mm-yyyy'), '7', '01', '244', '09', '2002', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (976, to_date('02-09-2002', 'dd-mm-yyyy'), '1', '02', '245', '09', '2002', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (977, to_date('03-09-2002', 'dd-mm-yyyy'), '2', '03', '246', '09', '2002', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (978, to_date('04-09-2002', 'dd-mm-yyyy'), '3', '04', '247', '09', '2002', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (979, to_date('05-09-2002', 'dd-mm-yyyy'), '4', '05', '248', '09', '2002', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (980, to_date('06-09-2002', 'dd-mm-yyyy'), '5', '06', '249', '09', '2002', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (981, to_date('07-09-2002', 'dd-mm-yyyy'), '6', '07', '250', '09', '2002', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (982, to_date('08-09-2002', 'dd-mm-yyyy'), '7', '08', '251', '09', '2002', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (983, to_date('09-09-2002', 'dd-mm-yyyy'), '1', '09', '252', '09', '2002', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (984, to_date('10-09-2002', 'dd-mm-yyyy'), '2', '10', '253', '09', '2002', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (985, to_date('11-09-2002', 'dd-mm-yyyy'), '3', '11', '254', '09', '2002', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (986, to_date('12-09-2002', 'dd-mm-yyyy'), '4', '12', '255', '09', '2002', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (987, to_date('13-09-2002', 'dd-mm-yyyy'), '5', '13', '256', '09', '2002', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (988, to_date('14-09-2002', 'dd-mm-yyyy'), '6', '14', '257', '09', '2002', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (989, to_date('15-09-2002', 'dd-mm-yyyy'), '7', '15', '258', '09', '2002', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (990, to_date('16-09-2002', 'dd-mm-yyyy'), '1', '16', '259', '09', '2002', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (991, to_date('17-09-2002', 'dd-mm-yyyy'), '2', '17', '260', '09', '2002', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (992, to_date('18-09-2002', 'dd-mm-yyyy'), '3', '18', '261', '09', '2002', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (993, to_date('19-09-2002', 'dd-mm-yyyy'), '4', '19', '262', '09', '2002', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (994, to_date('20-09-2002', 'dd-mm-yyyy'), '5', '20', '263', '09', '2002', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (995, to_date('21-09-2002', 'dd-mm-yyyy'), '6', '21', '264', '09', '2002', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (996, to_date('22-09-2002', 'dd-mm-yyyy'), '7', '22', '265', '09', '2002', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (997, to_date('23-09-2002', 'dd-mm-yyyy'), '1', '23', '266', '09', '2002', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (998, to_date('24-09-2002', 'dd-mm-yyyy'), '2', '24', '267', '09', '2002', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (999, to_date('25-09-2002', 'dd-mm-yyyy'), '3', '25', '268', '09', '2002', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1000, to_date('26-09-2002', 'dd-mm-yyyy'), '4', '26', '269', '09', '2002', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1001, to_date('27-09-2002', 'dd-mm-yyyy'), '5', '27', '270', '09', '2002', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1002, to_date('28-09-2002', 'dd-mm-yyyy'), '6', '28', '271', '09', '2002', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1003, to_date('29-09-2002', 'dd-mm-yyyy'), '7', '29', '272', '09', '2002', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1004, to_date('30-09-2002', 'dd-mm-yyyy'), '1', '30', '273', '09', '2002', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1005, to_date('01-10-2002', 'dd-mm-yyyy'), '2', '01', '274', '10', '2002', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1006, to_date('02-10-2002', 'dd-mm-yyyy'), '3', '02', '275', '10', '2002', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1007, to_date('03-10-2002', 'dd-mm-yyyy'), '4', '03', '276', '10', '2002', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1008, to_date('04-10-2002', 'dd-mm-yyyy'), '5', '04', '277', '10', '2002', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1009, to_date('05-10-2002', 'dd-mm-yyyy'), '6', '05', '278', '10', '2002', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1010, to_date('06-10-2002', 'dd-mm-yyyy'), '7', '06', '279', '10', '2002', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1011, to_date('07-10-2002', 'dd-mm-yyyy'), '1', '07', '280', '10', '2002', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1012, to_date('08-10-2002', 'dd-mm-yyyy'), '2', '08', '281', '10', '2002', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1013, to_date('09-10-2002', 'dd-mm-yyyy'), '3', '09', '282', '10', '2002', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1014, to_date('10-10-2002', 'dd-mm-yyyy'), '4', '10', '283', '10', '2002', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1015, to_date('11-10-2002', 'dd-mm-yyyy'), '5', '11', '284', '10', '2002', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1016, to_date('12-10-2002', 'dd-mm-yyyy'), '6', '12', '285', '10', '2002', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1017, to_date('13-10-2002', 'dd-mm-yyyy'), '7', '13', '286', '10', '2002', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1018, to_date('14-10-2002', 'dd-mm-yyyy'), '1', '14', '287', '10', '2002', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1019, to_date('15-10-2002', 'dd-mm-yyyy'), '2', '15', '288', '10', '2002', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1020, to_date('16-10-2002', 'dd-mm-yyyy'), '3', '16', '289', '10', '2002', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1021, to_date('17-10-2002', 'dd-mm-yyyy'), '4', '17', '290', '10', '2002', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1022, to_date('18-10-2002', 'dd-mm-yyyy'), '5', '18', '291', '10', '2002', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1023, to_date('19-10-2002', 'dd-mm-yyyy'), '6', '19', '292', '10', '2002', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1024, to_date('20-10-2002', 'dd-mm-yyyy'), '7', '20', '293', '10', '2002', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1025, to_date('21-10-2002', 'dd-mm-yyyy'), '1', '21', '294', '10', '2002', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1026, to_date('22-10-2002', 'dd-mm-yyyy'), '2', '22', '295', '10', '2002', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1027, to_date('23-10-2002', 'dd-mm-yyyy'), '3', '23', '296', '10', '2002', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1028, to_date('24-10-2002', 'dd-mm-yyyy'), '4', '24', '297', '10', '2002', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1029, to_date('25-10-2002', 'dd-mm-yyyy'), '5', '25', '298', '10', '2002', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1030, to_date('26-10-2002', 'dd-mm-yyyy'), '6', '26', '299', '10', '2002', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1031, to_date('27-10-2002', 'dd-mm-yyyy'), '7', '27', '300', '10', '2002', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1032, to_date('28-10-2002', 'dd-mm-yyyy'), '1', '28', '301', '10', '2002', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1033, to_date('29-10-2002', 'dd-mm-yyyy'), '2', '29', '302', '10', '2002', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1034, to_date('30-10-2002', 'dd-mm-yyyy'), '3', '30', '303', '10', '2002', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1035, to_date('31-10-2002', 'dd-mm-yyyy'), '4', '31', '304', '10', '2002', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1036, to_date('01-11-2002', 'dd-mm-yyyy'), '5', '01', '305', '11', '2002', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1037, to_date('02-11-2002', 'dd-mm-yyyy'), '6', '02', '306', '11', '2002', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1038, to_date('03-11-2002', 'dd-mm-yyyy'), '7', '03', '307', '11', '2002', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1039, to_date('04-11-2002', 'dd-mm-yyyy'), '1', '04', '308', '11', '2002', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1040, to_date('05-11-2002', 'dd-mm-yyyy'), '2', '05', '309', '11', '2002', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1041, to_date('06-11-2002', 'dd-mm-yyyy'), '3', '06', '310', '11', '2002', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1042, to_date('07-11-2002', 'dd-mm-yyyy'), '4', '07', '311', '11', '2002', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1043, to_date('08-11-2002', 'dd-mm-yyyy'), '5', '08', '312', '11', '2002', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1044, to_date('09-11-2002', 'dd-mm-yyyy'), '6', '09', '313', '11', '2002', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1045, to_date('10-11-2002', 'dd-mm-yyyy'), '7', '10', '314', '11', '2002', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1046, to_date('11-11-2002', 'dd-mm-yyyy'), '1', '11', '315', '11', '2002', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1047, to_date('12-11-2002', 'dd-mm-yyyy'), '2', '12', '316', '11', '2002', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1048, to_date('13-11-2002', 'dd-mm-yyyy'), '3', '13', '317', '11', '2002', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1049, to_date('14-11-2002', 'dd-mm-yyyy'), '4', '14', '318', '11', '2002', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1050, to_date('15-11-2002', 'dd-mm-yyyy'), '5', '15', '319', '11', '2002', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1051, to_date('16-11-2002', 'dd-mm-yyyy'), '6', '16', '320', '11', '2002', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1052, to_date('17-11-2002', 'dd-mm-yyyy'), '7', '17', '321', '11', '2002', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1053, to_date('18-11-2002', 'dd-mm-yyyy'), '1', '18', '322', '11', '2002', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1054, to_date('19-11-2002', 'dd-mm-yyyy'), '2', '19', '323', '11', '2002', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1055, to_date('20-11-2002', 'dd-mm-yyyy'), '3', '20', '324', '11', '2002', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1056, to_date('21-11-2002', 'dd-mm-yyyy'), '4', '21', '325', '11', '2002', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1057, to_date('22-11-2002', 'dd-mm-yyyy'), '5', '22', '326', '11', '2002', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1058, to_date('23-11-2002', 'dd-mm-yyyy'), '6', '23', '327', '11', '2002', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1059, to_date('24-11-2002', 'dd-mm-yyyy'), '7', '24', '328', '11', '2002', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1060, to_date('25-11-2002', 'dd-mm-yyyy'), '1', '25', '329', '11', '2002', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1061, to_date('26-11-2002', 'dd-mm-yyyy'), '2', '26', '330', '11', '2002', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1062, to_date('27-11-2002', 'dd-mm-yyyy'), '3', '27', '331', '11', '2002', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1063, to_date('28-11-2002', 'dd-mm-yyyy'), '4', '28', '332', '11', '2002', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1064, to_date('29-11-2002', 'dd-mm-yyyy'), '5', '29', '333', '11', '2002', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1065, to_date('30-11-2002', 'dd-mm-yyyy'), '6', '30', '334', '11', '2002', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1066, to_date('01-12-2002', 'dd-mm-yyyy'), '7', '01', '335', '12', '2002', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1067, to_date('02-12-2002', 'dd-mm-yyyy'), '1', '02', '336', '12', '2002', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1068, to_date('03-12-2002', 'dd-mm-yyyy'), '2', '03', '337', '12', '2002', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1069, to_date('04-12-2002', 'dd-mm-yyyy'), '3', '04', '338', '12', '2002', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1070, to_date('05-12-2002', 'dd-mm-yyyy'), '4', '05', '339', '12', '2002', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1071, to_date('06-12-2002', 'dd-mm-yyyy'), '5', '06', '340', '12', '2002', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1072, to_date('07-12-2002', 'dd-mm-yyyy'), '6', '07', '341', '12', '2002', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1073, to_date('08-12-2002', 'dd-mm-yyyy'), '7', '08', '342', '12', '2002', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1074, to_date('09-12-2002', 'dd-mm-yyyy'), '1', '09', '343', '12', '2002', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1075, to_date('10-12-2002', 'dd-mm-yyyy'), '2', '10', '344', '12', '2002', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1076, to_date('11-12-2002', 'dd-mm-yyyy'), '3', '11', '345', '12', '2002', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1077, to_date('12-12-2002', 'dd-mm-yyyy'), '4', '12', '346', '12', '2002', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1078, to_date('13-12-2002', 'dd-mm-yyyy'), '5', '13', '347', '12', '2002', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1079, to_date('14-12-2002', 'dd-mm-yyyy'), '6', '14', '348', '12', '2002', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1080, to_date('15-12-2002', 'dd-mm-yyyy'), '7', '15', '349', '12', '2002', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1081, to_date('16-12-2002', 'dd-mm-yyyy'), '1', '16', '350', '12', '2002', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1082, to_date('17-12-2002', 'dd-mm-yyyy'), '2', '17', '351', '12', '2002', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1083, to_date('18-12-2002', 'dd-mm-yyyy'), '3', '18', '352', '12', '2002', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1084, to_date('19-12-2002', 'dd-mm-yyyy'), '4', '19', '353', '12', '2002', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1085, to_date('20-12-2002', 'dd-mm-yyyy'), '5', '20', '354', '12', '2002', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1086, to_date('21-12-2002', 'dd-mm-yyyy'), '6', '21', '355', '12', '2002', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1087, to_date('22-12-2002', 'dd-mm-yyyy'), '7', '22', '356', '12', '2002', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1088, to_date('23-12-2002', 'dd-mm-yyyy'), '1', '23', '357', '12', '2002', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1089, to_date('24-12-2002', 'dd-mm-yyyy'), '2', '24', '358', '12', '2002', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1090, to_date('25-12-2002', 'dd-mm-yyyy'), '3', '25', '359', '12', '2002', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1091, to_date('26-12-2002', 'dd-mm-yyyy'), '4', '26', '360', '12', '2002', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1092, to_date('27-12-2002', 'dd-mm-yyyy'), '5', '27', '361', '12', '2002', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1093, to_date('28-12-2002', 'dd-mm-yyyy'), '6', '28', '362', '12', '2002', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1094, to_date('29-12-2002', 'dd-mm-yyyy'), '7', '29', '363', '12', '2002', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1095, to_date('30-12-2002', 'dd-mm-yyyy'), '1', '30', '364', '12', '2002', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1096, to_date('31-12-2002', 'dd-mm-yyyy'), '2', '31', '365', '12', '2002', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1097, to_date('01-01-2003', 'dd-mm-yyyy'), '3', '01', '001', '01', '2003', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1098, to_date('02-01-2003', 'dd-mm-yyyy'), '4', '02', '002', '01', '2003', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1099, to_date('03-01-2003', 'dd-mm-yyyy'), '5', '03', '003', '01', '2003', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1100, to_date('04-01-2003', 'dd-mm-yyyy'), '6', '04', '004', '01', '2003', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1101, to_date('05-01-2003', 'dd-mm-yyyy'), '7', '05', '005', '01', '2003', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1102, to_date('06-01-2003', 'dd-mm-yyyy'), '1', '06', '006', '01', '2003', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1103, to_date('07-01-2003', 'dd-mm-yyyy'), '2', '07', '007', '01', '2003', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1104, to_date('08-01-2003', 'dd-mm-yyyy'), '3', '08', '008', '01', '2003', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1105, to_date('09-01-2003', 'dd-mm-yyyy'), '4', '09', '009', '01', '2003', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1106, to_date('10-01-2003', 'dd-mm-yyyy'), '5', '10', '010', '01', '2003', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1107, to_date('11-01-2003', 'dd-mm-yyyy'), '6', '11', '011', '01', '2003', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1108, to_date('12-01-2003', 'dd-mm-yyyy'), '7', '12', '012', '01', '2003', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1109, to_date('13-01-2003', 'dd-mm-yyyy'), '1', '13', '013', '01', '2003', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1110, to_date('14-01-2003', 'dd-mm-yyyy'), '2', '14', '014', '01', '2003', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1111, to_date('15-01-2003', 'dd-mm-yyyy'), '3', '15', '015', '01', '2003', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1112, to_date('16-01-2003', 'dd-mm-yyyy'), '4', '16', '016', '01', '2003', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1113, to_date('17-01-2003', 'dd-mm-yyyy'), '5', '17', '017', '01', '2003', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1114, to_date('18-01-2003', 'dd-mm-yyyy'), '6', '18', '018', '01', '2003', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1115, to_date('19-01-2003', 'dd-mm-yyyy'), '7', '19', '019', '01', '2003', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1116, to_date('20-01-2003', 'dd-mm-yyyy'), '1', '20', '020', '01', '2003', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1117, to_date('21-01-2003', 'dd-mm-yyyy'), '2', '21', '021', '01', '2003', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1118, to_date('22-01-2003', 'dd-mm-yyyy'), '3', '22', '022', '01', '2003', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1119, to_date('23-01-2003', 'dd-mm-yyyy'), '4', '23', '023', '01', '2003', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1120, to_date('24-01-2003', 'dd-mm-yyyy'), '5', '24', '024', '01', '2003', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1121, to_date('25-01-2003', 'dd-mm-yyyy'), '6', '25', '025', '01', '2003', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1122, to_date('26-01-2003', 'dd-mm-yyyy'), '7', '26', '026', '01', '2003', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1123, to_date('27-01-2003', 'dd-mm-yyyy'), '1', '27', '027', '01', '2003', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1124, to_date('28-01-2003', 'dd-mm-yyyy'), '2', '28', '028', '01', '2003', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1125, to_date('29-01-2003', 'dd-mm-yyyy'), '3', '29', '029', '01', '2003', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1126, to_date('30-01-2003', 'dd-mm-yyyy'), '4', '30', '030', '01', '2003', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1127, to_date('31-01-2003', 'dd-mm-yyyy'), '5', '31', '031', '01', '2003', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1128, to_date('01-02-2003', 'dd-mm-yyyy'), '6', '01', '032', '02', '2003', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1129, to_date('02-02-2003', 'dd-mm-yyyy'), '7', '02', '033', '02', '2003', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1130, to_date('03-02-2003', 'dd-mm-yyyy'), '1', '03', '034', '02', '2003', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1131, to_date('04-02-2003', 'dd-mm-yyyy'), '2', '04', '035', '02', '2003', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1132, to_date('05-02-2003', 'dd-mm-yyyy'), '3', '05', '036', '02', '2003', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1133, to_date('06-02-2003', 'dd-mm-yyyy'), '4', '06', '037', '02', '2003', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1134, to_date('07-02-2003', 'dd-mm-yyyy'), '5', '07', '038', '02', '2003', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1135, to_date('08-02-2003', 'dd-mm-yyyy'), '6', '08', '039', '02', '2003', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1136, to_date('09-02-2003', 'dd-mm-yyyy'), '7', '09', '040', '02', '2003', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1137, to_date('10-02-2003', 'dd-mm-yyyy'), '1', '10', '041', '02', '2003', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1138, to_date('11-02-2003', 'dd-mm-yyyy'), '2', '11', '042', '02', '2003', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1139, to_date('12-02-2003', 'dd-mm-yyyy'), '3', '12', '043', '02', '2003', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1140, to_date('13-02-2003', 'dd-mm-yyyy'), '4', '13', '044', '02', '2003', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1141, to_date('14-02-2003', 'dd-mm-yyyy'), '5', '14', '045', '02', '2003', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1142, to_date('15-02-2003', 'dd-mm-yyyy'), '6', '15', '046', '02', '2003', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1143, to_date('16-02-2003', 'dd-mm-yyyy'), '7', '16', '047', '02', '2003', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1144, to_date('17-02-2003', 'dd-mm-yyyy'), '1', '17', '048', '02', '2003', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1145, to_date('18-02-2003', 'dd-mm-yyyy'), '2', '18', '049', '02', '2003', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1146, to_date('19-02-2003', 'dd-mm-yyyy'), '3', '19', '050', '02', '2003', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1147, to_date('20-02-2003', 'dd-mm-yyyy'), '4', '20', '051', '02', '2003', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1148, to_date('21-02-2003', 'dd-mm-yyyy'), '5', '21', '052', '02', '2003', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1149, to_date('22-02-2003', 'dd-mm-yyyy'), '6', '22', '053', '02', '2003', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1150, to_date('23-02-2003', 'dd-mm-yyyy'), '7', '23', '054', '02', '2003', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1151, to_date('24-02-2003', 'dd-mm-yyyy'), '1', '24', '055', '02', '2003', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1152, to_date('25-02-2003', 'dd-mm-yyyy'), '2', '25', '056', '02', '2003', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1153, to_date('26-02-2003', 'dd-mm-yyyy'), '3', '26', '057', '02', '2003', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1154, to_date('27-02-2003', 'dd-mm-yyyy'), '4', '27', '058', '02', '2003', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1155, to_date('28-02-2003', 'dd-mm-yyyy'), '5', '28', '059', '02', '2003', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1156, to_date('01-03-2003', 'dd-mm-yyyy'), '6', '01', '060', '03', '2003', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1157, to_date('02-03-2003', 'dd-mm-yyyy'), '7', '02', '061', '03', '2003', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1158, to_date('03-03-2003', 'dd-mm-yyyy'), '1', '03', '062', '03', '2003', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1159, to_date('04-03-2003', 'dd-mm-yyyy'), '2', '04', '063', '03', '2003', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1160, to_date('05-03-2003', 'dd-mm-yyyy'), '3', '05', '064', '03', '2003', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1161, to_date('06-03-2003', 'dd-mm-yyyy'), '4', '06', '065', '03', '2003', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1162, to_date('07-03-2003', 'dd-mm-yyyy'), '5', '07', '066', '03', '2003', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1163, to_date('08-03-2003', 'dd-mm-yyyy'), '6', '08', '067', '03', '2003', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1164, to_date('09-03-2003', 'dd-mm-yyyy'), '7', '09', '068', '03', '2003', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1165, to_date('10-03-2003', 'dd-mm-yyyy'), '1', '10', '069', '03', '2003', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1166, to_date('11-03-2003', 'dd-mm-yyyy'), '2', '11', '070', '03', '2003', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1167, to_date('12-03-2003', 'dd-mm-yyyy'), '3', '12', '071', '03', '2003', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1168, to_date('13-03-2003', 'dd-mm-yyyy'), '4', '13', '072', '03', '2003', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1169, to_date('14-03-2003', 'dd-mm-yyyy'), '5', '14', '073', '03', '2003', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1170, to_date('15-03-2003', 'dd-mm-yyyy'), '6', '15', '074', '03', '2003', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1171, to_date('16-03-2003', 'dd-mm-yyyy'), '7', '16', '075', '03', '2003', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1172, to_date('17-03-2003', 'dd-mm-yyyy'), '1', '17', '076', '03', '2003', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1173, to_date('18-03-2003', 'dd-mm-yyyy'), '2', '18', '077', '03', '2003', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1174, to_date('19-03-2003', 'dd-mm-yyyy'), '3', '19', '078', '03', '2003', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1175, to_date('20-03-2003', 'dd-mm-yyyy'), '4', '20', '079', '03', '2003', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1176, to_date('21-03-2003', 'dd-mm-yyyy'), '5', '21', '080', '03', '2003', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1177, to_date('22-03-2003', 'dd-mm-yyyy'), '6', '22', '081', '03', '2003', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1178, to_date('23-03-2003', 'dd-mm-yyyy'), '7', '23', '082', '03', '2003', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1179, to_date('24-03-2003', 'dd-mm-yyyy'), '1', '24', '083', '03', '2003', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1180, to_date('25-03-2003', 'dd-mm-yyyy'), '2', '25', '084', '03', '2003', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1181, to_date('26-03-2003', 'dd-mm-yyyy'), '3', '26', '085', '03', '2003', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1182, to_date('27-03-2003', 'dd-mm-yyyy'), '4', '27', '086', '03', '2003', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1183, to_date('28-03-2003', 'dd-mm-yyyy'), '5', '28', '087', '03', '2003', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1184, to_date('29-03-2003', 'dd-mm-yyyy'), '6', '29', '088', '03', '2003', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1185, to_date('30-03-2003', 'dd-mm-yyyy'), '7', '30', '089', '03', '2003', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1186, to_date('31-03-2003', 'dd-mm-yyyy'), '1', '31', '090', '03', '2003', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1187, to_date('01-04-2003', 'dd-mm-yyyy'), '2', '01', '091', '04', '2003', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1188, to_date('02-04-2003', 'dd-mm-yyyy'), '3', '02', '092', '04', '2003', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1189, to_date('03-04-2003', 'dd-mm-yyyy'), '4', '03', '093', '04', '2003', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1190, to_date('04-04-2003', 'dd-mm-yyyy'), '5', '04', '094', '04', '2003', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1191, to_date('05-04-2003', 'dd-mm-yyyy'), '6', '05', '095', '04', '2003', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1192, to_date('06-04-2003', 'dd-mm-yyyy'), '7', '06', '096', '04', '2003', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1193, to_date('07-04-2003', 'dd-mm-yyyy'), '1', '07', '097', '04', '2003', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1194, to_date('08-04-2003', 'dd-mm-yyyy'), '2', '08', '098', '04', '2003', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1195, to_date('09-04-2003', 'dd-mm-yyyy'), '3', '09', '099', '04', '2003', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1196, to_date('10-04-2003', 'dd-mm-yyyy'), '4', '10', '100', '04', '2003', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1197, to_date('11-04-2003', 'dd-mm-yyyy'), '5', '11', '101', '04', '2003', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1198, to_date('12-04-2003', 'dd-mm-yyyy'), '6', '12', '102', '04', '2003', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1199, to_date('13-04-2003', 'dd-mm-yyyy'), '7', '13', '103', '04', '2003', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1200, to_date('14-04-2003', 'dd-mm-yyyy'), '1', '14', '104', '04', '2003', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1201, to_date('15-04-2003', 'dd-mm-yyyy'), '2', '15', '105', '04', '2003', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1202, to_date('16-04-2003', 'dd-mm-yyyy'), '3', '16', '106', '04', '2003', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1203, to_date('17-04-2003', 'dd-mm-yyyy'), '4', '17', '107', '04', '2003', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1204, to_date('18-04-2003', 'dd-mm-yyyy'), '5', '18', '108', '04', '2003', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1205, to_date('19-04-2003', 'dd-mm-yyyy'), '6', '19', '109', '04', '2003', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1206, to_date('20-04-2003', 'dd-mm-yyyy'), '7', '20', '110', '04', '2003', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1207, to_date('21-04-2003', 'dd-mm-yyyy'), '1', '21', '111', '04', '2003', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1208, to_date('22-04-2003', 'dd-mm-yyyy'), '2', '22', '112', '04', '2003', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1209, to_date('23-04-2003', 'dd-mm-yyyy'), '3', '23', '113', '04', '2003', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1210, to_date('24-04-2003', 'dd-mm-yyyy'), '4', '24', '114', '04', '2003', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1211, to_date('25-04-2003', 'dd-mm-yyyy'), '5', '25', '115', '04', '2003', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1212, to_date('26-04-2003', 'dd-mm-yyyy'), '6', '26', '116', '04', '2003', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1213, to_date('27-04-2003', 'dd-mm-yyyy'), '7', '27', '117', '04', '2003', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1214, to_date('28-04-2003', 'dd-mm-yyyy'), '1', '28', '118', '04', '2003', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1215, to_date('29-04-2003', 'dd-mm-yyyy'), '2', '29', '119', '04', '2003', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1216, to_date('30-04-2003', 'dd-mm-yyyy'), '3', '30', '120', '04', '2003', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1217, to_date('01-05-2003', 'dd-mm-yyyy'), '4', '01', '121', '05', '2003', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1218, to_date('02-05-2003', 'dd-mm-yyyy'), '5', '02', '122', '05', '2003', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1219, to_date('03-05-2003', 'dd-mm-yyyy'), '6', '03', '123', '05', '2003', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1220, to_date('04-05-2003', 'dd-mm-yyyy'), '7', '04', '124', '05', '2003', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1221, to_date('05-05-2003', 'dd-mm-yyyy'), '1', '05', '125', '05', '2003', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1222, to_date('06-05-2003', 'dd-mm-yyyy'), '2', '06', '126', '05', '2003', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1223, to_date('07-05-2003', 'dd-mm-yyyy'), '3', '07', '127', '05', '2003', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1224, to_date('08-05-2003', 'dd-mm-yyyy'), '4', '08', '128', '05', '2003', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1225, to_date('09-05-2003', 'dd-mm-yyyy'), '5', '09', '129', '05', '2003', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1226, to_date('10-05-2003', 'dd-mm-yyyy'), '6', '10', '130', '05', '2003', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1227, to_date('11-05-2003', 'dd-mm-yyyy'), '7', '11', '131', '05', '2003', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1228, to_date('12-05-2003', 'dd-mm-yyyy'), '1', '12', '132', '05', '2003', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1229, to_date('13-05-2003', 'dd-mm-yyyy'), '2', '13', '133', '05', '2003', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1230, to_date('14-05-2003', 'dd-mm-yyyy'), '3', '14', '134', '05', '2003', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1231, to_date('15-05-2003', 'dd-mm-yyyy'), '4', '15', '135', '05', '2003', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1232, to_date('16-05-2003', 'dd-mm-yyyy'), '5', '16', '136', '05', '2003', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1233, to_date('17-05-2003', 'dd-mm-yyyy'), '6', '17', '137', '05', '2003', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1234, to_date('18-05-2003', 'dd-mm-yyyy'), '7', '18', '138', '05', '2003', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1235, to_date('19-05-2003', 'dd-mm-yyyy'), '1', '19', '139', '05', '2003', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1236, to_date('20-05-2003', 'dd-mm-yyyy'), '2', '20', '140', '05', '2003', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1237, to_date('21-05-2003', 'dd-mm-yyyy'), '3', '21', '141', '05', '2003', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1238, to_date('22-05-2003', 'dd-mm-yyyy'), '4', '22', '142', '05', '2003', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1239, to_date('23-05-2003', 'dd-mm-yyyy'), '5', '23', '143', '05', '2003', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1240, to_date('24-05-2003', 'dd-mm-yyyy'), '6', '24', '144', '05', '2003', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1241, to_date('25-05-2003', 'dd-mm-yyyy'), '7', '25', '145', '05', '2003', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1242, to_date('26-05-2003', 'dd-mm-yyyy'), '1', '26', '146', '05', '2003', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1243, to_date('27-05-2003', 'dd-mm-yyyy'), '2', '27', '147', '05', '2003', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1244, to_date('28-05-2003', 'dd-mm-yyyy'), '3', '28', '148', '05', '2003', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1245, to_date('29-05-2003', 'dd-mm-yyyy'), '4', '29', '149', '05', '2003', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1246, to_date('30-05-2003', 'dd-mm-yyyy'), '5', '30', '150', '05', '2003', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1247, to_date('31-05-2003', 'dd-mm-yyyy'), '6', '31', '151', '05', '2003', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1248, to_date('01-06-2003', 'dd-mm-yyyy'), '7', '01', '152', '06', '2003', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1249, to_date('02-06-2003', 'dd-mm-yyyy'), '1', '02', '153', '06', '2003', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1250, to_date('03-06-2003', 'dd-mm-yyyy'), '2', '03', '154', '06', '2003', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1251, to_date('04-06-2003', 'dd-mm-yyyy'), '3', '04', '155', '06', '2003', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1252, to_date('05-06-2003', 'dd-mm-yyyy'), '4', '05', '156', '06', '2003', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1253, to_date('06-06-2003', 'dd-mm-yyyy'), '5', '06', '157', '06', '2003', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1254, to_date('07-06-2003', 'dd-mm-yyyy'), '6', '07', '158', '06', '2003', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1255, to_date('08-06-2003', 'dd-mm-yyyy'), '7', '08', '159', '06', '2003', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1256, to_date('09-06-2003', 'dd-mm-yyyy'), '1', '09', '160', '06', '2003', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1257, to_date('10-06-2003', 'dd-mm-yyyy'), '2', '10', '161', '06', '2003', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1258, to_date('11-06-2003', 'dd-mm-yyyy'), '3', '11', '162', '06', '2003', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1259, to_date('12-06-2003', 'dd-mm-yyyy'), '4', '12', '163', '06', '2003', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1260, to_date('13-06-2003', 'dd-mm-yyyy'), '5', '13', '164', '06', '2003', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1261, to_date('14-06-2003', 'dd-mm-yyyy'), '6', '14', '165', '06', '2003', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1262, to_date('15-06-2003', 'dd-mm-yyyy'), '7', '15', '166', '06', '2003', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1263, to_date('16-06-2003', 'dd-mm-yyyy'), '1', '16', '167', '06', '2003', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1264, to_date('17-06-2003', 'dd-mm-yyyy'), '2', '17', '168', '06', '2003', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1265, to_date('18-06-2003', 'dd-mm-yyyy'), '3', '18', '169', '06', '2003', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1266, to_date('19-06-2003', 'dd-mm-yyyy'), '4', '19', '170', '06', '2003', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1267, to_date('20-06-2003', 'dd-mm-yyyy'), '5', '20', '171', '06', '2003', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1268, to_date('21-06-2003', 'dd-mm-yyyy'), '6', '21', '172', '06', '2003', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1269, to_date('22-06-2003', 'dd-mm-yyyy'), '7', '22', '173', '06', '2003', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1270, to_date('23-06-2003', 'dd-mm-yyyy'), '1', '23', '174', '06', '2003', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1271, to_date('24-06-2003', 'dd-mm-yyyy'), '2', '24', '175', '06', '2003', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1272, to_date('25-06-2003', 'dd-mm-yyyy'), '3', '25', '176', '06', '2003', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1273, to_date('26-06-2003', 'dd-mm-yyyy'), '4', '26', '177', '06', '2003', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1274, to_date('27-06-2003', 'dd-mm-yyyy'), '5', '27', '178', '06', '2003', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1275, to_date('28-06-2003', 'dd-mm-yyyy'), '6', '28', '179', '06', '2003', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1276, to_date('29-06-2003', 'dd-mm-yyyy'), '7', '29', '180', '06', '2003', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1277, to_date('30-06-2003', 'dd-mm-yyyy'), '1', '30', '181', '06', '2003', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1278, to_date('01-07-2003', 'dd-mm-yyyy'), '2', '01', '182', '07', '2003', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1279, to_date('02-07-2003', 'dd-mm-yyyy'), '3', '02', '183', '07', '2003', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1280, to_date('03-07-2003', 'dd-mm-yyyy'), '4', '03', '184', '07', '2003', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1281, to_date('04-07-2003', 'dd-mm-yyyy'), '5', '04', '185', '07', '2003', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1282, to_date('05-07-2003', 'dd-mm-yyyy'), '6', '05', '186', '07', '2003', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1283, to_date('06-07-2003', 'dd-mm-yyyy'), '7', '06', '187', '07', '2003', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1284, to_date('07-07-2003', 'dd-mm-yyyy'), '1', '07', '188', '07', '2003', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1285, to_date('08-07-2003', 'dd-mm-yyyy'), '2', '08', '189', '07', '2003', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1286, to_date('09-07-2003', 'dd-mm-yyyy'), '3', '09', '190', '07', '2003', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1287, to_date('10-07-2003', 'dd-mm-yyyy'), '4', '10', '191', '07', '2003', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1288, to_date('11-07-2003', 'dd-mm-yyyy'), '5', '11', '192', '07', '2003', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1289, to_date('12-07-2003', 'dd-mm-yyyy'), '6', '12', '193', '07', '2003', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1290, to_date('13-07-2003', 'dd-mm-yyyy'), '7', '13', '194', '07', '2003', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1291, to_date('14-07-2003', 'dd-mm-yyyy'), '1', '14', '195', '07', '2003', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1292, to_date('15-07-2003', 'dd-mm-yyyy'), '2', '15', '196', '07', '2003', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1293, to_date('16-07-2003', 'dd-mm-yyyy'), '3', '16', '197', '07', '2003', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1294, to_date('17-07-2003', 'dd-mm-yyyy'), '4', '17', '198', '07', '2003', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1295, to_date('18-07-2003', 'dd-mm-yyyy'), '5', '18', '199', '07', '2003', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1296, to_date('19-07-2003', 'dd-mm-yyyy'), '6', '19', '200', '07', '2003', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1297, to_date('20-07-2003', 'dd-mm-yyyy'), '7', '20', '201', '07', '2003', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1298, to_date('21-07-2003', 'dd-mm-yyyy'), '1', '21', '202', '07', '2003', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1299, to_date('22-07-2003', 'dd-mm-yyyy'), '2', '22', '203', '07', '2003', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1300, to_date('23-07-2003', 'dd-mm-yyyy'), '3', '23', '204', '07', '2003', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1301, to_date('24-07-2003', 'dd-mm-yyyy'), '4', '24', '205', '07', '2003', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1302, to_date('25-07-2003', 'dd-mm-yyyy'), '5', '25', '206', '07', '2003', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1303, to_date('26-07-2003', 'dd-mm-yyyy'), '6', '26', '207', '07', '2003', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1304, to_date('27-07-2003', 'dd-mm-yyyy'), '7', '27', '208', '07', '2003', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1305, to_date('28-07-2003', 'dd-mm-yyyy'), '1', '28', '209', '07', '2003', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1306, to_date('29-07-2003', 'dd-mm-yyyy'), '2', '29', '210', '07', '2003', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1307, to_date('30-07-2003', 'dd-mm-yyyy'), '3', '30', '211', '07', '2003', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1308, to_date('31-07-2003', 'dd-mm-yyyy'), '4', '31', '212', '07', '2003', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1309, to_date('01-08-2003', 'dd-mm-yyyy'), '5', '01', '213', '08', '2003', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1310, to_date('02-08-2003', 'dd-mm-yyyy'), '6', '02', '214', '08', '2003', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1311, to_date('03-08-2003', 'dd-mm-yyyy'), '7', '03', '215', '08', '2003', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1312, to_date('04-08-2003', 'dd-mm-yyyy'), '1', '04', '216', '08', '2003', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1313, to_date('05-08-2003', 'dd-mm-yyyy'), '2', '05', '217', '08', '2003', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1314, to_date('06-08-2003', 'dd-mm-yyyy'), '3', '06', '218', '08', '2003', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1315, to_date('07-08-2003', 'dd-mm-yyyy'), '4', '07', '219', '08', '2003', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1316, to_date('08-08-2003', 'dd-mm-yyyy'), '5', '08', '220', '08', '2003', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1317, to_date('09-08-2003', 'dd-mm-yyyy'), '6', '09', '221', '08', '2003', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1318, to_date('10-08-2003', 'dd-mm-yyyy'), '7', '10', '222', '08', '2003', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1319, to_date('11-08-2003', 'dd-mm-yyyy'), '1', '11', '223', '08', '2003', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1320, to_date('12-08-2003', 'dd-mm-yyyy'), '2', '12', '224', '08', '2003', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1321, to_date('13-08-2003', 'dd-mm-yyyy'), '3', '13', '225', '08', '2003', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1322, to_date('14-08-2003', 'dd-mm-yyyy'), '4', '14', '226', '08', '2003', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1323, to_date('15-08-2003', 'dd-mm-yyyy'), '5', '15', '227', '08', '2003', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1324, to_date('16-08-2003', 'dd-mm-yyyy'), '6', '16', '228', '08', '2003', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1325, to_date('17-08-2003', 'dd-mm-yyyy'), '7', '17', '229', '08', '2003', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1326, to_date('18-08-2003', 'dd-mm-yyyy'), '1', '18', '230', '08', '2003', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1327, to_date('19-08-2003', 'dd-mm-yyyy'), '2', '19', '231', '08', '2003', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1328, to_date('20-08-2003', 'dd-mm-yyyy'), '3', '20', '232', '08', '2003', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1329, to_date('21-08-2003', 'dd-mm-yyyy'), '4', '21', '233', '08', '2003', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1330, to_date('22-08-2003', 'dd-mm-yyyy'), '5', '22', '234', '08', '2003', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1331, to_date('23-08-2003', 'dd-mm-yyyy'), '6', '23', '235', '08', '2003', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1332, to_date('24-08-2003', 'dd-mm-yyyy'), '7', '24', '236', '08', '2003', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1333, to_date('25-08-2003', 'dd-mm-yyyy'), '1', '25', '237', '08', '2003', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1334, to_date('26-08-2003', 'dd-mm-yyyy'), '2', '26', '238', '08', '2003', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1335, to_date('27-08-2003', 'dd-mm-yyyy'), '3', '27', '239', '08', '2003', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1336, to_date('28-08-2003', 'dd-mm-yyyy'), '4', '28', '240', '08', '2003', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1337, to_date('29-08-2003', 'dd-mm-yyyy'), '5', '29', '241', '08', '2003', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1338, to_date('30-08-2003', 'dd-mm-yyyy'), '6', '30', '242', '08', '2003', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1339, to_date('31-08-2003', 'dd-mm-yyyy'), '7', '31', '243', '08', '2003', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1340, to_date('01-09-2003', 'dd-mm-yyyy'), '1', '01', '244', '09', '2003', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1341, to_date('02-09-2003', 'dd-mm-yyyy'), '2', '02', '245', '09', '2003', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1342, to_date('03-09-2003', 'dd-mm-yyyy'), '3', '03', '246', '09', '2003', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1343, to_date('04-09-2003', 'dd-mm-yyyy'), '4', '04', '247', '09', '2003', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1344, to_date('05-09-2003', 'dd-mm-yyyy'), '5', '05', '248', '09', '2003', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1345, to_date('06-09-2003', 'dd-mm-yyyy'), '6', '06', '249', '09', '2003', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1346, to_date('07-09-2003', 'dd-mm-yyyy'), '7', '07', '250', '09', '2003', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1347, to_date('08-09-2003', 'dd-mm-yyyy'), '1', '08', '251', '09', '2003', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1348, to_date('09-09-2003', 'dd-mm-yyyy'), '2', '09', '252', '09', '2003', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1349, to_date('10-09-2003', 'dd-mm-yyyy'), '3', '10', '253', '09', '2003', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1350, to_date('11-09-2003', 'dd-mm-yyyy'), '4', '11', '254', '09', '2003', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1351, to_date('12-09-2003', 'dd-mm-yyyy'), '5', '12', '255', '09', '2003', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1352, to_date('13-09-2003', 'dd-mm-yyyy'), '6', '13', '256', '09', '2003', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1353, to_date('14-09-2003', 'dd-mm-yyyy'), '7', '14', '257', '09', '2003', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1354, to_date('15-09-2003', 'dd-mm-yyyy'), '1', '15', '258', '09', '2003', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1355, to_date('16-09-2003', 'dd-mm-yyyy'), '2', '16', '259', '09', '2003', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1356, to_date('17-09-2003', 'dd-mm-yyyy'), '3', '17', '260', '09', '2003', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1357, to_date('18-09-2003', 'dd-mm-yyyy'), '4', '18', '261', '09', '2003', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1358, to_date('19-09-2003', 'dd-mm-yyyy'), '5', '19', '262', '09', '2003', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1359, to_date('20-09-2003', 'dd-mm-yyyy'), '6', '20', '263', '09', '2003', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1360, to_date('21-09-2003', 'dd-mm-yyyy'), '7', '21', '264', '09', '2003', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1361, to_date('22-09-2003', 'dd-mm-yyyy'), '1', '22', '265', '09', '2003', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1362, to_date('23-09-2003', 'dd-mm-yyyy'), '2', '23', '266', '09', '2003', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1363, to_date('24-09-2003', 'dd-mm-yyyy'), '3', '24', '267', '09', '2003', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1364, to_date('25-09-2003', 'dd-mm-yyyy'), '4', '25', '268', '09', '2003', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1365, to_date('26-09-2003', 'dd-mm-yyyy'), '5', '26', '269', '09', '2003', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1366, to_date('27-09-2003', 'dd-mm-yyyy'), '6', '27', '270', '09', '2003', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1367, to_date('28-09-2003', 'dd-mm-yyyy'), '7', '28', '271', '09', '2003', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1368, to_date('29-09-2003', 'dd-mm-yyyy'), '1', '29', '272', '09', '2003', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1369, to_date('30-09-2003', 'dd-mm-yyyy'), '2', '30', '273', '09', '2003', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1370, to_date('01-10-2003', 'dd-mm-yyyy'), '3', '01', '274', '10', '2003', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1371, to_date('02-10-2003', 'dd-mm-yyyy'), '4', '02', '275', '10', '2003', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1372, to_date('03-10-2003', 'dd-mm-yyyy'), '5', '03', '276', '10', '2003', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1373, to_date('04-10-2003', 'dd-mm-yyyy'), '6', '04', '277', '10', '2003', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1374, to_date('05-10-2003', 'dd-mm-yyyy'), '7', '05', '278', '10', '2003', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1375, to_date('06-10-2003', 'dd-mm-yyyy'), '1', '06', '279', '10', '2003', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1376, to_date('07-10-2003', 'dd-mm-yyyy'), '2', '07', '280', '10', '2003', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1377, to_date('08-10-2003', 'dd-mm-yyyy'), '3', '08', '281', '10', '2003', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1378, to_date('09-10-2003', 'dd-mm-yyyy'), '4', '09', '282', '10', '2003', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1379, to_date('10-10-2003', 'dd-mm-yyyy'), '5', '10', '283', '10', '2003', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1380, to_date('11-10-2003', 'dd-mm-yyyy'), '6', '11', '284', '10', '2003', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1381, to_date('12-10-2003', 'dd-mm-yyyy'), '7', '12', '285', '10', '2003', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1382, to_date('13-10-2003', 'dd-mm-yyyy'), '1', '13', '286', '10', '2003', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1383, to_date('14-10-2003', 'dd-mm-yyyy'), '2', '14', '287', '10', '2003', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1384, to_date('15-10-2003', 'dd-mm-yyyy'), '3', '15', '288', '10', '2003', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1385, to_date('16-10-2003', 'dd-mm-yyyy'), '4', '16', '289', '10', '2003', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1386, to_date('17-10-2003', 'dd-mm-yyyy'), '5', '17', '290', '10', '2003', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1387, to_date('18-10-2003', 'dd-mm-yyyy'), '6', '18', '291', '10', '2003', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1388, to_date('19-10-2003', 'dd-mm-yyyy'), '7', '19', '292', '10', '2003', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1389, to_date('20-10-2003', 'dd-mm-yyyy'), '1', '20', '293', '10', '2003', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1390, to_date('21-10-2003', 'dd-mm-yyyy'), '2', '21', '294', '10', '2003', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1391, to_date('22-10-2003', 'dd-mm-yyyy'), '3', '22', '295', '10', '2003', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1392, to_date('23-10-2003', 'dd-mm-yyyy'), '4', '23', '296', '10', '2003', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1393, to_date('24-10-2003', 'dd-mm-yyyy'), '5', '24', '297', '10', '2003', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1394, to_date('25-10-2003', 'dd-mm-yyyy'), '6', '25', '298', '10', '2003', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1395, to_date('26-10-2003', 'dd-mm-yyyy'), '7', '26', '299', '10', '2003', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1396, to_date('27-10-2003', 'dd-mm-yyyy'), '1', '27', '300', '10', '2003', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1397, to_date('28-10-2003', 'dd-mm-yyyy'), '2', '28', '301', '10', '2003', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1398, to_date('29-10-2003', 'dd-mm-yyyy'), '3', '29', '302', '10', '2003', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1399, to_date('30-10-2003', 'dd-mm-yyyy'), '4', '30', '303', '10', '2003', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1400, to_date('31-10-2003', 'dd-mm-yyyy'), '5', '31', '304', '10', '2003', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1401, to_date('01-11-2003', 'dd-mm-yyyy'), '6', '01', '305', '11', '2003', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1402, to_date('02-11-2003', 'dd-mm-yyyy'), '7', '02', '306', '11', '2003', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1403, to_date('03-11-2003', 'dd-mm-yyyy'), '1', '03', '307', '11', '2003', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1404, to_date('04-11-2003', 'dd-mm-yyyy'), '2', '04', '308', '11', '2003', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1405, to_date('05-11-2003', 'dd-mm-yyyy'), '3', '05', '309', '11', '2003', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1406, to_date('06-11-2003', 'dd-mm-yyyy'), '4', '06', '310', '11', '2003', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1407, to_date('07-11-2003', 'dd-mm-yyyy'), '5', '07', '311', '11', '2003', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1408, to_date('08-11-2003', 'dd-mm-yyyy'), '6', '08', '312', '11', '2003', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1409, to_date('09-11-2003', 'dd-mm-yyyy'), '7', '09', '313', '11', '2003', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1410, to_date('10-11-2003', 'dd-mm-yyyy'), '1', '10', '314', '11', '2003', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1411, to_date('11-11-2003', 'dd-mm-yyyy'), '2', '11', '315', '11', '2003', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1412, to_date('12-11-2003', 'dd-mm-yyyy'), '3', '12', '316', '11', '2003', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1413, to_date('13-11-2003', 'dd-mm-yyyy'), '4', '13', '317', '11', '2003', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1414, to_date('14-11-2003', 'dd-mm-yyyy'), '5', '14', '318', '11', '2003', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1415, to_date('15-11-2003', 'dd-mm-yyyy'), '6', '15', '319', '11', '2003', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1416, to_date('16-11-2003', 'dd-mm-yyyy'), '7', '16', '320', '11', '2003', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1417, to_date('17-11-2003', 'dd-mm-yyyy'), '1', '17', '321', '11', '2003', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1418, to_date('18-11-2003', 'dd-mm-yyyy'), '2', '18', '322', '11', '2003', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1419, to_date('19-11-2003', 'dd-mm-yyyy'), '3', '19', '323', '11', '2003', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1420, to_date('20-11-2003', 'dd-mm-yyyy'), '4', '20', '324', '11', '2003', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1421, to_date('21-11-2003', 'dd-mm-yyyy'), '5', '21', '325', '11', '2003', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1422, to_date('22-11-2003', 'dd-mm-yyyy'), '6', '22', '326', '11', '2003', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1423, to_date('23-11-2003', 'dd-mm-yyyy'), '7', '23', '327', '11', '2003', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1424, to_date('24-11-2003', 'dd-mm-yyyy'), '1', '24', '328', '11', '2003', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1425, to_date('25-11-2003', 'dd-mm-yyyy'), '2', '25', '329', '11', '2003', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1426, to_date('26-11-2003', 'dd-mm-yyyy'), '3', '26', '330', '11', '2003', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1427, to_date('27-11-2003', 'dd-mm-yyyy'), '4', '27', '331', '11', '2003', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1428, to_date('28-11-2003', 'dd-mm-yyyy'), '5', '28', '332', '11', '2003', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1429, to_date('29-11-2003', 'dd-mm-yyyy'), '6', '29', '333', '11', '2003', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1430, to_date('30-11-2003', 'dd-mm-yyyy'), '7', '30', '334', '11', '2003', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1431, to_date('01-12-2003', 'dd-mm-yyyy'), '1', '01', '335', '12', '2003', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1432, to_date('02-12-2003', 'dd-mm-yyyy'), '2', '02', '336', '12', '2003', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1433, to_date('03-12-2003', 'dd-mm-yyyy'), '3', '03', '337', '12', '2003', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1434, to_date('04-12-2003', 'dd-mm-yyyy'), '4', '04', '338', '12', '2003', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1435, to_date('05-12-2003', 'dd-mm-yyyy'), '5', '05', '339', '12', '2003', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1436, to_date('06-12-2003', 'dd-mm-yyyy'), '6', '06', '340', '12', '2003', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1437, to_date('07-12-2003', 'dd-mm-yyyy'), '7', '07', '341', '12', '2003', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1438, to_date('08-12-2003', 'dd-mm-yyyy'), '1', '08', '342', '12', '2003', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1439, to_date('09-12-2003', 'dd-mm-yyyy'), '2', '09', '343', '12', '2003', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1440, to_date('10-12-2003', 'dd-mm-yyyy'), '3', '10', '344', '12', '2003', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1441, to_date('11-12-2003', 'dd-mm-yyyy'), '4', '11', '345', '12', '2003', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1442, to_date('12-12-2003', 'dd-mm-yyyy'), '5', '12', '346', '12', '2003', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1443, to_date('13-12-2003', 'dd-mm-yyyy'), '6', '13', '347', '12', '2003', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1444, to_date('14-12-2003', 'dd-mm-yyyy'), '7', '14', '348', '12', '2003', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1445, to_date('15-12-2003', 'dd-mm-yyyy'), '1', '15', '349', '12', '2003', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1446, to_date('16-12-2003', 'dd-mm-yyyy'), '2', '16', '350', '12', '2003', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1447, to_date('17-12-2003', 'dd-mm-yyyy'), '3', '17', '351', '12', '2003', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1448, to_date('18-12-2003', 'dd-mm-yyyy'), '4', '18', '352', '12', '2003', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1449, to_date('19-12-2003', 'dd-mm-yyyy'), '5', '19', '353', '12', '2003', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1450, to_date('20-12-2003', 'dd-mm-yyyy'), '6', '20', '354', '12', '2003', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1451, to_date('21-12-2003', 'dd-mm-yyyy'), '7', '21', '355', '12', '2003', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1452, to_date('22-12-2003', 'dd-mm-yyyy'), '1', '22', '356', '12', '2003', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1453, to_date('23-12-2003', 'dd-mm-yyyy'), '2', '23', '357', '12', '2003', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1454, to_date('24-12-2003', 'dd-mm-yyyy'), '3', '24', '358', '12', '2003', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1455, to_date('25-12-2003', 'dd-mm-yyyy'), '4', '25', '359', '12', '2003', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1456, to_date('26-12-2003', 'dd-mm-yyyy'), '5', '26', '360', '12', '2003', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1457, to_date('27-12-2003', 'dd-mm-yyyy'), '6', '27', '361', '12', '2003', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1458, to_date('28-12-2003', 'dd-mm-yyyy'), '7', '28', '362', '12', '2003', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1459, to_date('29-12-2003', 'dd-mm-yyyy'), '1', '29', '363', '12', '2003', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1460, to_date('30-12-2003', 'dd-mm-yyyy'), '2', '30', '364', '12', '2003', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1461, to_date('31-12-2003', 'dd-mm-yyyy'), '3', '31', '365', '12', '2003', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
commit;
prompt 2000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1462, to_date('01-01-2004', 'dd-mm-yyyy'), '4', '01', '001', '01', '2004', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1463, to_date('02-01-2004', 'dd-mm-yyyy'), '5', '02', '002', '01', '2004', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1464, to_date('03-01-2004', 'dd-mm-yyyy'), '6', '03', '003', '01', '2004', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1465, to_date('04-01-2004', 'dd-mm-yyyy'), '7', '04', '004', '01', '2004', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1466, to_date('05-01-2004', 'dd-mm-yyyy'), '1', '05', '005', '01', '2004', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1467, to_date('06-01-2004', 'dd-mm-yyyy'), '2', '06', '006', '01', '2004', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1468, to_date('07-01-2004', 'dd-mm-yyyy'), '3', '07', '007', '01', '2004', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1469, to_date('08-01-2004', 'dd-mm-yyyy'), '4', '08', '008', '01', '2004', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1470, to_date('09-01-2004', 'dd-mm-yyyy'), '5', '09', '009', '01', '2004', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1471, to_date('10-01-2004', 'dd-mm-yyyy'), '6', '10', '010', '01', '2004', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1472, to_date('11-01-2004', 'dd-mm-yyyy'), '7', '11', '011', '01', '2004', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1473, to_date('12-01-2004', 'dd-mm-yyyy'), '1', '12', '012', '01', '2004', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1474, to_date('13-01-2004', 'dd-mm-yyyy'), '2', '13', '013', '01', '2004', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1475, to_date('14-01-2004', 'dd-mm-yyyy'), '3', '14', '014', '01', '2004', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1476, to_date('15-01-2004', 'dd-mm-yyyy'), '4', '15', '015', '01', '2004', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1477, to_date('16-01-2004', 'dd-mm-yyyy'), '5', '16', '016', '01', '2004', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1478, to_date('17-01-2004', 'dd-mm-yyyy'), '6', '17', '017', '01', '2004', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1479, to_date('18-01-2004', 'dd-mm-yyyy'), '7', '18', '018', '01', '2004', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1480, to_date('19-01-2004', 'dd-mm-yyyy'), '1', '19', '019', '01', '2004', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1481, to_date('20-01-2004', 'dd-mm-yyyy'), '2', '20', '020', '01', '2004', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1482, to_date('21-01-2004', 'dd-mm-yyyy'), '3', '21', '021', '01', '2004', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1483, to_date('22-01-2004', 'dd-mm-yyyy'), '4', '22', '022', '01', '2004', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1484, to_date('23-01-2004', 'dd-mm-yyyy'), '5', '23', '023', '01', '2004', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1485, to_date('24-01-2004', 'dd-mm-yyyy'), '6', '24', '024', '01', '2004', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1486, to_date('25-01-2004', 'dd-mm-yyyy'), '7', '25', '025', '01', '2004', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1487, to_date('26-01-2004', 'dd-mm-yyyy'), '1', '26', '026', '01', '2004', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1488, to_date('27-01-2004', 'dd-mm-yyyy'), '2', '27', '027', '01', '2004', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1489, to_date('28-01-2004', 'dd-mm-yyyy'), '3', '28', '028', '01', '2004', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1490, to_date('29-01-2004', 'dd-mm-yyyy'), '4', '29', '029', '01', '2004', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1491, to_date('30-01-2004', 'dd-mm-yyyy'), '5', '30', '030', '01', '2004', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1492, to_date('31-01-2004', 'dd-mm-yyyy'), '6', '31', '031', '01', '2004', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1493, to_date('01-02-2004', 'dd-mm-yyyy'), '7', '01', '032', '02', '2004', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1494, to_date('02-02-2004', 'dd-mm-yyyy'), '1', '02', '033', '02', '2004', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1495, to_date('03-02-2004', 'dd-mm-yyyy'), '2', '03', '034', '02', '2004', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1496, to_date('04-02-2004', 'dd-mm-yyyy'), '3', '04', '035', '02', '2004', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1497, to_date('05-02-2004', 'dd-mm-yyyy'), '4', '05', '036', '02', '2004', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1498, to_date('06-02-2004', 'dd-mm-yyyy'), '5', '06', '037', '02', '2004', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1499, to_date('07-02-2004', 'dd-mm-yyyy'), '6', '07', '038', '02', '2004', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1500, to_date('08-02-2004', 'dd-mm-yyyy'), '7', '08', '039', '02', '2004', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1501, to_date('09-02-2004', 'dd-mm-yyyy'), '1', '09', '040', '02', '2004', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1502, to_date('10-02-2004', 'dd-mm-yyyy'), '2', '10', '041', '02', '2004', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1503, to_date('11-02-2004', 'dd-mm-yyyy'), '3', '11', '042', '02', '2004', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1504, to_date('12-02-2004', 'dd-mm-yyyy'), '4', '12', '043', '02', '2004', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1505, to_date('13-02-2004', 'dd-mm-yyyy'), '5', '13', '044', '02', '2004', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1506, to_date('14-02-2004', 'dd-mm-yyyy'), '6', '14', '045', '02', '2004', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1507, to_date('15-02-2004', 'dd-mm-yyyy'), '7', '15', '046', '02', '2004', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1508, to_date('16-02-2004', 'dd-mm-yyyy'), '1', '16', '047', '02', '2004', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1509, to_date('17-02-2004', 'dd-mm-yyyy'), '2', '17', '048', '02', '2004', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1510, to_date('18-02-2004', 'dd-mm-yyyy'), '3', '18', '049', '02', '2004', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1511, to_date('19-02-2004', 'dd-mm-yyyy'), '4', '19', '050', '02', '2004', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1512, to_date('20-02-2004', 'dd-mm-yyyy'), '5', '20', '051', '02', '2004', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1513, to_date('21-02-2004', 'dd-mm-yyyy'), '6', '21', '052', '02', '2004', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1514, to_date('22-02-2004', 'dd-mm-yyyy'), '7', '22', '053', '02', '2004', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1515, to_date('23-02-2004', 'dd-mm-yyyy'), '1', '23', '054', '02', '2004', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1516, to_date('24-02-2004', 'dd-mm-yyyy'), '2', '24', '055', '02', '2004', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1517, to_date('25-02-2004', 'dd-mm-yyyy'), '3', '25', '056', '02', '2004', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1518, to_date('26-02-2004', 'dd-mm-yyyy'), '4', '26', '057', '02', '2004', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1519, to_date('27-02-2004', 'dd-mm-yyyy'), '5', '27', '058', '02', '2004', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1520, to_date('28-02-2004', 'dd-mm-yyyy'), '6', '28', '059', '02', '2004', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1521, to_date('29-02-2004', 'dd-mm-yyyy'), '7', '29', '060', '02', '2004', '09', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1522, to_date('01-03-2004', 'dd-mm-yyyy'), '1', '01', '061', '03', '2004', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1523, to_date('02-03-2004', 'dd-mm-yyyy'), '2', '02', '062', '03', '2004', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1524, to_date('03-03-2004', 'dd-mm-yyyy'), '3', '03', '063', '03', '2004', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1525, to_date('04-03-2004', 'dd-mm-yyyy'), '4', '04', '064', '03', '2004', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1526, to_date('05-03-2004', 'dd-mm-yyyy'), '5', '05', '065', '03', '2004', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1527, to_date('06-03-2004', 'dd-mm-yyyy'), '6', '06', '066', '03', '2004', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1528, to_date('07-03-2004', 'dd-mm-yyyy'), '7', '07', '067', '03', '2004', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1529, to_date('08-03-2004', 'dd-mm-yyyy'), '1', '08', '068', '03', '2004', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1530, to_date('09-03-2004', 'dd-mm-yyyy'), '2', '09', '069', '03', '2004', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1531, to_date('10-03-2004', 'dd-mm-yyyy'), '3', '10', '070', '03', '2004', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1532, to_date('11-03-2004', 'dd-mm-yyyy'), '4', '11', '071', '03', '2004', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1533, to_date('12-03-2004', 'dd-mm-yyyy'), '5', '12', '072', '03', '2004', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1534, to_date('13-03-2004', 'dd-mm-yyyy'), '6', '13', '073', '03', '2004', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1535, to_date('14-03-2004', 'dd-mm-yyyy'), '7', '14', '074', '03', '2004', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1536, to_date('15-03-2004', 'dd-mm-yyyy'), '1', '15', '075', '03', '2004', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1537, to_date('16-03-2004', 'dd-mm-yyyy'), '2', '16', '076', '03', '2004', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1538, to_date('17-03-2004', 'dd-mm-yyyy'), '3', '17', '077', '03', '2004', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1539, to_date('18-03-2004', 'dd-mm-yyyy'), '4', '18', '078', '03', '2004', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1540, to_date('19-03-2004', 'dd-mm-yyyy'), '5', '19', '079', '03', '2004', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1541, to_date('20-03-2004', 'dd-mm-yyyy'), '6', '20', '080', '03', '2004', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1542, to_date('21-03-2004', 'dd-mm-yyyy'), '7', '21', '081', '03', '2004', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1543, to_date('22-03-2004', 'dd-mm-yyyy'), '1', '22', '082', '03', '2004', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1544, to_date('23-03-2004', 'dd-mm-yyyy'), '2', '23', '083', '03', '2004', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1545, to_date('24-03-2004', 'dd-mm-yyyy'), '3', '24', '084', '03', '2004', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1546, to_date('25-03-2004', 'dd-mm-yyyy'), '4', '25', '085', '03', '2004', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1547, to_date('26-03-2004', 'dd-mm-yyyy'), '5', '26', '086', '03', '2004', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1548, to_date('27-03-2004', 'dd-mm-yyyy'), '6', '27', '087', '03', '2004', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1549, to_date('28-03-2004', 'dd-mm-yyyy'), '7', '28', '088', '03', '2004', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1550, to_date('29-03-2004', 'dd-mm-yyyy'), '1', '29', '089', '03', '2004', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1551, to_date('30-03-2004', 'dd-mm-yyyy'), '2', '30', '090', '03', '2004', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1552, to_date('31-03-2004', 'dd-mm-yyyy'), '3', '31', '091', '03', '2004', '14', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1553, to_date('01-04-2004', 'dd-mm-yyyy'), '4', '01', '092', '04', '2004', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1554, to_date('02-04-2004', 'dd-mm-yyyy'), '5', '02', '093', '04', '2004', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1555, to_date('03-04-2004', 'dd-mm-yyyy'), '6', '03', '094', '04', '2004', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1556, to_date('04-04-2004', 'dd-mm-yyyy'), '7', '04', '095', '04', '2004', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1557, to_date('05-04-2004', 'dd-mm-yyyy'), '1', '05', '096', '04', '2004', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1558, to_date('06-04-2004', 'dd-mm-yyyy'), '2', '06', '097', '04', '2004', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1559, to_date('07-04-2004', 'dd-mm-yyyy'), '3', '07', '098', '04', '2004', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1560, to_date('08-04-2004', 'dd-mm-yyyy'), '4', '08', '099', '04', '2004', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1561, to_date('09-04-2004', 'dd-mm-yyyy'), '5', '09', '100', '04', '2004', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1562, to_date('10-04-2004', 'dd-mm-yyyy'), '6', '10', '101', '04', '2004', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1563, to_date('11-04-2004', 'dd-mm-yyyy'), '7', '11', '102', '04', '2004', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1564, to_date('12-04-2004', 'dd-mm-yyyy'), '1', '12', '103', '04', '2004', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1565, to_date('13-04-2004', 'dd-mm-yyyy'), '2', '13', '104', '04', '2004', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1566, to_date('14-04-2004', 'dd-mm-yyyy'), '3', '14', '105', '04', '2004', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1567, to_date('15-04-2004', 'dd-mm-yyyy'), '4', '15', '106', '04', '2004', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1568, to_date('16-04-2004', 'dd-mm-yyyy'), '5', '16', '107', '04', '2004', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1569, to_date('17-04-2004', 'dd-mm-yyyy'), '6', '17', '108', '04', '2004', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1570, to_date('18-04-2004', 'dd-mm-yyyy'), '7', '18', '109', '04', '2004', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1571, to_date('19-04-2004', 'dd-mm-yyyy'), '1', '19', '110', '04', '2004', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1572, to_date('20-04-2004', 'dd-mm-yyyy'), '2', '20', '111', '04', '2004', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1573, to_date('21-04-2004', 'dd-mm-yyyy'), '3', '21', '112', '04', '2004', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1574, to_date('22-04-2004', 'dd-mm-yyyy'), '4', '22', '113', '04', '2004', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1575, to_date('23-04-2004', 'dd-mm-yyyy'), '5', '23', '114', '04', '2004', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1576, to_date('24-04-2004', 'dd-mm-yyyy'), '6', '24', '115', '04', '2004', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1577, to_date('25-04-2004', 'dd-mm-yyyy'), '7', '25', '116', '04', '2004', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1578, to_date('26-04-2004', 'dd-mm-yyyy'), '1', '26', '117', '04', '2004', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1579, to_date('27-04-2004', 'dd-mm-yyyy'), '2', '27', '118', '04', '2004', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1580, to_date('28-04-2004', 'dd-mm-yyyy'), '3', '28', '119', '04', '2004', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1581, to_date('29-04-2004', 'dd-mm-yyyy'), '4', '29', '120', '04', '2004', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1582, to_date('30-04-2004', 'dd-mm-yyyy'), '5', '30', '121', '04', '2004', '18', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1583, to_date('01-05-2004', 'dd-mm-yyyy'), '6', '01', '122', '05', '2004', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1584, to_date('02-05-2004', 'dd-mm-yyyy'), '7', '02', '123', '05', '2004', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1585, to_date('03-05-2004', 'dd-mm-yyyy'), '1', '03', '124', '05', '2004', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1586, to_date('04-05-2004', 'dd-mm-yyyy'), '2', '04', '125', '05', '2004', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1587, to_date('05-05-2004', 'dd-mm-yyyy'), '3', '05', '126', '05', '2004', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1588, to_date('06-05-2004', 'dd-mm-yyyy'), '4', '06', '127', '05', '2004', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1589, to_date('07-05-2004', 'dd-mm-yyyy'), '5', '07', '128', '05', '2004', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1590, to_date('08-05-2004', 'dd-mm-yyyy'), '6', '08', '129', '05', '2004', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1591, to_date('09-05-2004', 'dd-mm-yyyy'), '7', '09', '130', '05', '2004', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1592, to_date('10-05-2004', 'dd-mm-yyyy'), '1', '10', '131', '05', '2004', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1593, to_date('11-05-2004', 'dd-mm-yyyy'), '2', '11', '132', '05', '2004', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1594, to_date('12-05-2004', 'dd-mm-yyyy'), '3', '12', '133', '05', '2004', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1595, to_date('13-05-2004', 'dd-mm-yyyy'), '4', '13', '134', '05', '2004', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1596, to_date('14-05-2004', 'dd-mm-yyyy'), '5', '14', '135', '05', '2004', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1597, to_date('15-05-2004', 'dd-mm-yyyy'), '6', '15', '136', '05', '2004', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1598, to_date('16-05-2004', 'dd-mm-yyyy'), '7', '16', '137', '05', '2004', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1599, to_date('17-05-2004', 'dd-mm-yyyy'), '1', '17', '138', '05', '2004', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1600, to_date('18-05-2004', 'dd-mm-yyyy'), '2', '18', '139', '05', '2004', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1601, to_date('19-05-2004', 'dd-mm-yyyy'), '3', '19', '140', '05', '2004', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1602, to_date('20-05-2004', 'dd-mm-yyyy'), '4', '20', '141', '05', '2004', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1603, to_date('21-05-2004', 'dd-mm-yyyy'), '5', '21', '142', '05', '2004', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1604, to_date('22-05-2004', 'dd-mm-yyyy'), '6', '22', '143', '05', '2004', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1605, to_date('23-05-2004', 'dd-mm-yyyy'), '7', '23', '144', '05', '2004', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1606, to_date('24-05-2004', 'dd-mm-yyyy'), '1', '24', '145', '05', '2004', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1607, to_date('25-05-2004', 'dd-mm-yyyy'), '2', '25', '146', '05', '2004', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1608, to_date('26-05-2004', 'dd-mm-yyyy'), '3', '26', '147', '05', '2004', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1609, to_date('27-05-2004', 'dd-mm-yyyy'), '4', '27', '148', '05', '2004', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1610, to_date('28-05-2004', 'dd-mm-yyyy'), '5', '28', '149', '05', '2004', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1611, to_date('29-05-2004', 'dd-mm-yyyy'), '6', '29', '150', '05', '2004', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1612, to_date('30-05-2004', 'dd-mm-yyyy'), '7', '30', '151', '05', '2004', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1613, to_date('31-05-2004', 'dd-mm-yyyy'), '1', '31', '152', '05', '2004', '23', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1614, to_date('01-06-2004', 'dd-mm-yyyy'), '2', '01', '153', '06', '2004', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1615, to_date('02-06-2004', 'dd-mm-yyyy'), '3', '02', '154', '06', '2004', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1616, to_date('03-06-2004', 'dd-mm-yyyy'), '4', '03', '155', '06', '2004', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1617, to_date('04-06-2004', 'dd-mm-yyyy'), '5', '04', '156', '06', '2004', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1618, to_date('05-06-2004', 'dd-mm-yyyy'), '6', '05', '157', '06', '2004', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1619, to_date('06-06-2004', 'dd-mm-yyyy'), '7', '06', '158', '06', '2004', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1620, to_date('07-06-2004', 'dd-mm-yyyy'), '1', '07', '159', '06', '2004', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1621, to_date('08-06-2004', 'dd-mm-yyyy'), '2', '08', '160', '06', '2004', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1, to_date('01-01-2000', 'dd-mm-yyyy'), '6', '01', '001', '01', '2000', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2, to_date('02-01-2000', 'dd-mm-yyyy'), '7', '02', '002', '01', '2000', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3, to_date('03-01-2000', 'dd-mm-yyyy'), '1', '03', '003', '01', '2000', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4, to_date('04-01-2000', 'dd-mm-yyyy'), '2', '04', '004', '01', '2000', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5, to_date('05-01-2000', 'dd-mm-yyyy'), '3', '05', '005', '01', '2000', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6, to_date('06-01-2000', 'dd-mm-yyyy'), '4', '06', '006', '01', '2000', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7, to_date('07-01-2000', 'dd-mm-yyyy'), '5', '07', '007', '01', '2000', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8, to_date('08-01-2000', 'dd-mm-yyyy'), '6', '08', '008', '01', '2000', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9, to_date('09-01-2000', 'dd-mm-yyyy'), '7', '09', '009', '01', '2000', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10, to_date('10-01-2000', 'dd-mm-yyyy'), '1', '10', '010', '01', '2000', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11, to_date('11-01-2000', 'dd-mm-yyyy'), '2', '11', '011', '01', '2000', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12, to_date('12-01-2000', 'dd-mm-yyyy'), '3', '12', '012', '01', '2000', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13, to_date('13-01-2000', 'dd-mm-yyyy'), '4', '13', '013', '01', '2000', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14, to_date('14-01-2000', 'dd-mm-yyyy'), '5', '14', '014', '01', '2000', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15, to_date('15-01-2000', 'dd-mm-yyyy'), '6', '15', '015', '01', '2000', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16, to_date('16-01-2000', 'dd-mm-yyyy'), '7', '16', '016', '01', '2000', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17, to_date('17-01-2000', 'dd-mm-yyyy'), '1', '17', '017', '01', '2000', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18, to_date('18-01-2000', 'dd-mm-yyyy'), '2', '18', '018', '01', '2000', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19, to_date('19-01-2000', 'dd-mm-yyyy'), '3', '19', '019', '01', '2000', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20, to_date('20-01-2000', 'dd-mm-yyyy'), '4', '20', '020', '01', '2000', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21, to_date('21-01-2000', 'dd-mm-yyyy'), '5', '21', '021', '01', '2000', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22, to_date('22-01-2000', 'dd-mm-yyyy'), '6', '22', '022', '01', '2000', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23, to_date('23-01-2000', 'dd-mm-yyyy'), '7', '23', '023', '01', '2000', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24, to_date('24-01-2000', 'dd-mm-yyyy'), '1', '24', '024', '01', '2000', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25, to_date('25-01-2000', 'dd-mm-yyyy'), '2', '25', '025', '01', '2000', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26, to_date('26-01-2000', 'dd-mm-yyyy'), '3', '26', '026', '01', '2000', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27, to_date('27-01-2000', 'dd-mm-yyyy'), '4', '27', '027', '01', '2000', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28, to_date('28-01-2000', 'dd-mm-yyyy'), '5', '28', '028', '01', '2000', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29, to_date('29-01-2000', 'dd-mm-yyyy'), '6', '29', '029', '01', '2000', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30, to_date('30-01-2000', 'dd-mm-yyyy'), '7', '30', '030', '01', '2000', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31, to_date('31-01-2000', 'dd-mm-yyyy'), '1', '31', '031', '01', '2000', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32, to_date('01-02-2000', 'dd-mm-yyyy'), '2', '01', '032', '02', '2000', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33, to_date('02-02-2000', 'dd-mm-yyyy'), '3', '02', '033', '02', '2000', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34, to_date('03-02-2000', 'dd-mm-yyyy'), '4', '03', '034', '02', '2000', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35, to_date('04-02-2000', 'dd-mm-yyyy'), '5', '04', '035', '02', '2000', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36, to_date('05-02-2000', 'dd-mm-yyyy'), '6', '05', '036', '02', '2000', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (37, to_date('06-02-2000', 'dd-mm-yyyy'), '7', '06', '037', '02', '2000', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (38, to_date('07-02-2000', 'dd-mm-yyyy'), '1', '07', '038', '02', '2000', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (39, to_date('08-02-2000', 'dd-mm-yyyy'), '2', '08', '039', '02', '2000', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (40, to_date('09-02-2000', 'dd-mm-yyyy'), '3', '09', '040', '02', '2000', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (41, to_date('10-02-2000', 'dd-mm-yyyy'), '4', '10', '041', '02', '2000', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (42, to_date('11-02-2000', 'dd-mm-yyyy'), '5', '11', '042', '02', '2000', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (43, to_date('12-02-2000', 'dd-mm-yyyy'), '6', '12', '043', '02', '2000', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (44, to_date('13-02-2000', 'dd-mm-yyyy'), '7', '13', '044', '02', '2000', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (45, to_date('14-02-2000', 'dd-mm-yyyy'), '1', '14', '045', '02', '2000', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (46, to_date('15-02-2000', 'dd-mm-yyyy'), '2', '15', '046', '02', '2000', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (47, to_date('16-02-2000', 'dd-mm-yyyy'), '3', '16', '047', '02', '2000', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (48, to_date('17-02-2000', 'dd-mm-yyyy'), '4', '17', '048', '02', '2000', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (49, to_date('18-02-2000', 'dd-mm-yyyy'), '5', '18', '049', '02', '2000', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (50, to_date('19-02-2000', 'dd-mm-yyyy'), '6', '19', '050', '02', '2000', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (51, to_date('20-02-2000', 'dd-mm-yyyy'), '7', '20', '051', '02', '2000', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (52, to_date('21-02-2000', 'dd-mm-yyyy'), '1', '21', '052', '02', '2000', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (53, to_date('22-02-2000', 'dd-mm-yyyy'), '2', '22', '053', '02', '2000', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (54, to_date('23-02-2000', 'dd-mm-yyyy'), '3', '23', '054', '02', '2000', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (55, to_date('24-02-2000', 'dd-mm-yyyy'), '4', '24', '055', '02', '2000', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (56, to_date('25-02-2000', 'dd-mm-yyyy'), '5', '25', '056', '02', '2000', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (57, to_date('26-02-2000', 'dd-mm-yyyy'), '6', '26', '057', '02', '2000', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (58, to_date('27-02-2000', 'dd-mm-yyyy'), '7', '27', '058', '02', '2000', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (59, to_date('28-02-2000', 'dd-mm-yyyy'), '1', '28', '059', '02', '2000', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (60, to_date('29-02-2000', 'dd-mm-yyyy'), '2', '29', '060', '02', '2000', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (61, to_date('01-03-2000', 'dd-mm-yyyy'), '3', '01', '061', '03', '2000', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (62, to_date('02-03-2000', 'dd-mm-yyyy'), '4', '02', '062', '03', '2000', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (63, to_date('03-03-2000', 'dd-mm-yyyy'), '5', '03', '063', '03', '2000', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (64, to_date('04-03-2000', 'dd-mm-yyyy'), '6', '04', '064', '03', '2000', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (65, to_date('05-03-2000', 'dd-mm-yyyy'), '7', '05', '065', '03', '2000', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (66, to_date('06-03-2000', 'dd-mm-yyyy'), '1', '06', '066', '03', '2000', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (67, to_date('07-03-2000', 'dd-mm-yyyy'), '2', '07', '067', '03', '2000', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (68, to_date('08-03-2000', 'dd-mm-yyyy'), '3', '08', '068', '03', '2000', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (69, to_date('09-03-2000', 'dd-mm-yyyy'), '4', '09', '069', '03', '2000', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (70, to_date('10-03-2000', 'dd-mm-yyyy'), '5', '10', '070', '03', '2000', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (71, to_date('11-03-2000', 'dd-mm-yyyy'), '6', '11', '071', '03', '2000', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (72, to_date('12-03-2000', 'dd-mm-yyyy'), '7', '12', '072', '03', '2000', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (73, to_date('13-03-2000', 'dd-mm-yyyy'), '1', '13', '073', '03', '2000', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (74, to_date('14-03-2000', 'dd-mm-yyyy'), '2', '14', '074', '03', '2000', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (75, to_date('15-03-2000', 'dd-mm-yyyy'), '3', '15', '075', '03', '2000', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (76, to_date('16-03-2000', 'dd-mm-yyyy'), '4', '16', '076', '03', '2000', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (77, to_date('17-03-2000', 'dd-mm-yyyy'), '5', '17', '077', '03', '2000', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (78, to_date('18-03-2000', 'dd-mm-yyyy'), '6', '18', '078', '03', '2000', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (79, to_date('19-03-2000', 'dd-mm-yyyy'), '7', '19', '079', '03', '2000', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (80, to_date('20-03-2000', 'dd-mm-yyyy'), '1', '20', '080', '03', '2000', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (81, to_date('21-03-2000', 'dd-mm-yyyy'), '2', '21', '081', '03', '2000', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (82, to_date('22-03-2000', 'dd-mm-yyyy'), '3', '22', '082', '03', '2000', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (83, to_date('23-03-2000', 'dd-mm-yyyy'), '4', '23', '083', '03', '2000', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (84, to_date('24-03-2000', 'dd-mm-yyyy'), '5', '24', '084', '03', '2000', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (85, to_date('25-03-2000', 'dd-mm-yyyy'), '6', '25', '085', '03', '2000', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (86, to_date('26-03-2000', 'dd-mm-yyyy'), '7', '26', '086', '03', '2000', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (87, to_date('27-03-2000', 'dd-mm-yyyy'), '1', '27', '087', '03', '2000', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (88, to_date('28-03-2000', 'dd-mm-yyyy'), '2', '28', '088', '03', '2000', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (89, to_date('29-03-2000', 'dd-mm-yyyy'), '3', '29', '089', '03', '2000', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (90, to_date('30-03-2000', 'dd-mm-yyyy'), '4', '30', '090', '03', '2000', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (91, to_date('31-03-2000', 'dd-mm-yyyy'), '5', '31', '091', '03', '2000', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (92, to_date('01-04-2000', 'dd-mm-yyyy'), '6', '01', '092', '04', '2000', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (93, to_date('02-04-2000', 'dd-mm-yyyy'), '7', '02', '093', '04', '2000', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (94, to_date('03-04-2000', 'dd-mm-yyyy'), '1', '03', '094', '04', '2000', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (95, to_date('04-04-2000', 'dd-mm-yyyy'), '2', '04', '095', '04', '2000', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (96, to_date('05-04-2000', 'dd-mm-yyyy'), '3', '05', '096', '04', '2000', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (97, to_date('06-04-2000', 'dd-mm-yyyy'), '4', '06', '097', '04', '2000', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (98, to_date('07-04-2000', 'dd-mm-yyyy'), '5', '07', '098', '04', '2000', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (99, to_date('08-04-2000', 'dd-mm-yyyy'), '6', '08', '099', '04', '2000', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (100, to_date('09-04-2000', 'dd-mm-yyyy'), '7', '09', '100', '04', '2000', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (101, to_date('10-04-2000', 'dd-mm-yyyy'), '1', '10', '101', '04', '2000', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (102, to_date('11-04-2000', 'dd-mm-yyyy'), '2', '11', '102', '04', '2000', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (103, to_date('12-04-2000', 'dd-mm-yyyy'), '3', '12', '103', '04', '2000', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (104, to_date('13-04-2000', 'dd-mm-yyyy'), '4', '13', '104', '04', '2000', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (105, to_date('14-04-2000', 'dd-mm-yyyy'), '5', '14', '105', '04', '2000', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (106, to_date('15-04-2000', 'dd-mm-yyyy'), '6', '15', '106', '04', '2000', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (107, to_date('16-04-2000', 'dd-mm-yyyy'), '7', '16', '107', '04', '2000', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (108, to_date('17-04-2000', 'dd-mm-yyyy'), '1', '17', '108', '04', '2000', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (109, to_date('18-04-2000', 'dd-mm-yyyy'), '2', '18', '109', '04', '2000', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (110, to_date('19-04-2000', 'dd-mm-yyyy'), '3', '19', '110', '04', '2000', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (111, to_date('20-04-2000', 'dd-mm-yyyy'), '4', '20', '111', '04', '2000', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (112, to_date('21-04-2000', 'dd-mm-yyyy'), '5', '21', '112', '04', '2000', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (113, to_date('22-04-2000', 'dd-mm-yyyy'), '6', '22', '113', '04', '2000', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (114, to_date('23-04-2000', 'dd-mm-yyyy'), '7', '23', '114', '04', '2000', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (115, to_date('24-04-2000', 'dd-mm-yyyy'), '1', '24', '115', '04', '2000', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (116, to_date('25-04-2000', 'dd-mm-yyyy'), '2', '25', '116', '04', '2000', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (117, to_date('26-04-2000', 'dd-mm-yyyy'), '3', '26', '117', '04', '2000', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (118, to_date('27-04-2000', 'dd-mm-yyyy'), '4', '27', '118', '04', '2000', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (119, to_date('28-04-2000', 'dd-mm-yyyy'), '5', '28', '119', '04', '2000', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (120, to_date('29-04-2000', 'dd-mm-yyyy'), '6', '29', '120', '04', '2000', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (121, to_date('30-04-2000', 'dd-mm-yyyy'), '7', '30', '121', '04', '2000', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (122, to_date('01-05-2000', 'dd-mm-yyyy'), '1', '01', '122', '05', '2000', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (123, to_date('02-05-2000', 'dd-mm-yyyy'), '2', '02', '123', '05', '2000', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (124, to_date('03-05-2000', 'dd-mm-yyyy'), '3', '03', '124', '05', '2000', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (125, to_date('04-05-2000', 'dd-mm-yyyy'), '4', '04', '125', '05', '2000', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (126, to_date('05-05-2000', 'dd-mm-yyyy'), '5', '05', '126', '05', '2000', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (127, to_date('06-05-2000', 'dd-mm-yyyy'), '6', '06', '127', '05', '2000', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (128, to_date('07-05-2000', 'dd-mm-yyyy'), '7', '07', '128', '05', '2000', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (129, to_date('08-05-2000', 'dd-mm-yyyy'), '1', '08', '129', '05', '2000', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (130, to_date('09-05-2000', 'dd-mm-yyyy'), '2', '09', '130', '05', '2000', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (131, to_date('10-05-2000', 'dd-mm-yyyy'), '3', '10', '131', '05', '2000', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (132, to_date('11-05-2000', 'dd-mm-yyyy'), '4', '11', '132', '05', '2000', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (133, to_date('12-05-2000', 'dd-mm-yyyy'), '5', '12', '133', '05', '2000', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (134, to_date('13-05-2000', 'dd-mm-yyyy'), '6', '13', '134', '05', '2000', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (135, to_date('14-05-2000', 'dd-mm-yyyy'), '7', '14', '135', '05', '2000', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (136, to_date('15-05-2000', 'dd-mm-yyyy'), '1', '15', '136', '05', '2000', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (137, to_date('16-05-2000', 'dd-mm-yyyy'), '2', '16', '137', '05', '2000', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (138, to_date('17-05-2000', 'dd-mm-yyyy'), '3', '17', '138', '05', '2000', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (139, to_date('18-05-2000', 'dd-mm-yyyy'), '4', '18', '139', '05', '2000', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (140, to_date('19-05-2000', 'dd-mm-yyyy'), '5', '19', '140', '05', '2000', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (141, to_date('20-05-2000', 'dd-mm-yyyy'), '6', '20', '141', '05', '2000', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (142, to_date('21-05-2000', 'dd-mm-yyyy'), '7', '21', '142', '05', '2000', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (143, to_date('22-05-2000', 'dd-mm-yyyy'), '1', '22', '143', '05', '2000', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (144, to_date('23-05-2000', 'dd-mm-yyyy'), '2', '23', '144', '05', '2000', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (145, to_date('24-05-2000', 'dd-mm-yyyy'), '3', '24', '145', '05', '2000', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (146, to_date('25-05-2000', 'dd-mm-yyyy'), '4', '25', '146', '05', '2000', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (147, to_date('26-05-2000', 'dd-mm-yyyy'), '5', '26', '147', '05', '2000', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (148, to_date('27-05-2000', 'dd-mm-yyyy'), '6', '27', '148', '05', '2000', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (149, to_date('28-05-2000', 'dd-mm-yyyy'), '7', '28', '149', '05', '2000', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (150, to_date('29-05-2000', 'dd-mm-yyyy'), '1', '29', '150', '05', '2000', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (151, to_date('30-05-2000', 'dd-mm-yyyy'), '2', '30', '151', '05', '2000', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (152, to_date('31-05-2000', 'dd-mm-yyyy'), '3', '31', '152', '05', '2000', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (153, to_date('01-06-2000', 'dd-mm-yyyy'), '4', '01', '153', '06', '2000', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (154, to_date('02-06-2000', 'dd-mm-yyyy'), '5', '02', '154', '06', '2000', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (155, to_date('03-06-2000', 'dd-mm-yyyy'), '6', '03', '155', '06', '2000', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (156, to_date('04-06-2000', 'dd-mm-yyyy'), '7', '04', '156', '06', '2000', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (157, to_date('05-06-2000', 'dd-mm-yyyy'), '1', '05', '157', '06', '2000', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (158, to_date('06-06-2000', 'dd-mm-yyyy'), '2', '06', '158', '06', '2000', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (159, to_date('07-06-2000', 'dd-mm-yyyy'), '3', '07', '159', '06', '2000', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (160, to_date('08-06-2000', 'dd-mm-yyyy'), '4', '08', '160', '06', '2000', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (161, to_date('09-06-2000', 'dd-mm-yyyy'), '5', '09', '161', '06', '2000', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (162, to_date('10-06-2000', 'dd-mm-yyyy'), '6', '10', '162', '06', '2000', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (163, to_date('11-06-2000', 'dd-mm-yyyy'), '7', '11', '163', '06', '2000', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (164, to_date('12-06-2000', 'dd-mm-yyyy'), '1', '12', '164', '06', '2000', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (165, to_date('13-06-2000', 'dd-mm-yyyy'), '2', '13', '165', '06', '2000', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (166, to_date('14-06-2000', 'dd-mm-yyyy'), '3', '14', '166', '06', '2000', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (167, to_date('15-06-2000', 'dd-mm-yyyy'), '4', '15', '167', '06', '2000', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (168, to_date('16-06-2000', 'dd-mm-yyyy'), '5', '16', '168', '06', '2000', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (169, to_date('17-06-2000', 'dd-mm-yyyy'), '6', '17', '169', '06', '2000', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (170, to_date('18-06-2000', 'dd-mm-yyyy'), '7', '18', '170', '06', '2000', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (171, to_date('19-06-2000', 'dd-mm-yyyy'), '1', '19', '171', '06', '2000', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (172, to_date('20-06-2000', 'dd-mm-yyyy'), '2', '20', '172', '06', '2000', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (173, to_date('21-06-2000', 'dd-mm-yyyy'), '3', '21', '173', '06', '2000', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (174, to_date('22-06-2000', 'dd-mm-yyyy'), '4', '22', '174', '06', '2000', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (175, to_date('23-06-2000', 'dd-mm-yyyy'), '5', '23', '175', '06', '2000', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (176, to_date('24-06-2000', 'dd-mm-yyyy'), '6', '24', '176', '06', '2000', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (177, to_date('25-06-2000', 'dd-mm-yyyy'), '7', '25', '177', '06', '2000', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (178, to_date('26-06-2000', 'dd-mm-yyyy'), '1', '26', '178', '06', '2000', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (179, to_date('27-06-2000', 'dd-mm-yyyy'), '2', '27', '179', '06', '2000', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (180, to_date('28-06-2000', 'dd-mm-yyyy'), '3', '28', '180', '06', '2000', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (181, to_date('29-06-2000', 'dd-mm-yyyy'), '4', '29', '181', '06', '2000', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (182, to_date('30-06-2000', 'dd-mm-yyyy'), '5', '30', '182', '06', '2000', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (183, to_date('01-07-2000', 'dd-mm-yyyy'), '6', '01', '183', '07', '2000', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (184, to_date('02-07-2000', 'dd-mm-yyyy'), '7', '02', '184', '07', '2000', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (185, to_date('03-07-2000', 'dd-mm-yyyy'), '1', '03', '185', '07', '2000', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (186, to_date('04-07-2000', 'dd-mm-yyyy'), '2', '04', '186', '07', '2000', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (187, to_date('05-07-2000', 'dd-mm-yyyy'), '3', '05', '187', '07', '2000', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (188, to_date('06-07-2000', 'dd-mm-yyyy'), '4', '06', '188', '07', '2000', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (189, to_date('07-07-2000', 'dd-mm-yyyy'), '5', '07', '189', '07', '2000', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (190, to_date('08-07-2000', 'dd-mm-yyyy'), '6', '08', '190', '07', '2000', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (191, to_date('09-07-2000', 'dd-mm-yyyy'), '7', '09', '191', '07', '2000', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (192, to_date('10-07-2000', 'dd-mm-yyyy'), '1', '10', '192', '07', '2000', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (193, to_date('11-07-2000', 'dd-mm-yyyy'), '2', '11', '193', '07', '2000', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (194, to_date('12-07-2000', 'dd-mm-yyyy'), '3', '12', '194', '07', '2000', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (195, to_date('13-07-2000', 'dd-mm-yyyy'), '4', '13', '195', '07', '2000', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (196, to_date('14-07-2000', 'dd-mm-yyyy'), '5', '14', '196', '07', '2000', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (197, to_date('15-07-2000', 'dd-mm-yyyy'), '6', '15', '197', '07', '2000', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (198, to_date('16-07-2000', 'dd-mm-yyyy'), '7', '16', '198', '07', '2000', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (199, to_date('17-07-2000', 'dd-mm-yyyy'), '1', '17', '199', '07', '2000', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (200, to_date('18-07-2000', 'dd-mm-yyyy'), '2', '18', '200', '07', '2000', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (201, to_date('19-07-2000', 'dd-mm-yyyy'), '3', '19', '201', '07', '2000', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (202, to_date('20-07-2000', 'dd-mm-yyyy'), '4', '20', '202', '07', '2000', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (203, to_date('21-07-2000', 'dd-mm-yyyy'), '5', '21', '203', '07', '2000', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (204, to_date('22-07-2000', 'dd-mm-yyyy'), '6', '22', '204', '07', '2000', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (205, to_date('23-07-2000', 'dd-mm-yyyy'), '7', '23', '205', '07', '2000', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (206, to_date('24-07-2000', 'dd-mm-yyyy'), '1', '24', '206', '07', '2000', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (207, to_date('25-07-2000', 'dd-mm-yyyy'), '2', '25', '207', '07', '2000', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (208, to_date('26-07-2000', 'dd-mm-yyyy'), '3', '26', '208', '07', '2000', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (209, to_date('27-07-2000', 'dd-mm-yyyy'), '4', '27', '209', '07', '2000', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (210, to_date('28-07-2000', 'dd-mm-yyyy'), '5', '28', '210', '07', '2000', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (211, to_date('29-07-2000', 'dd-mm-yyyy'), '6', '29', '211', '07', '2000', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (212, to_date('30-07-2000', 'dd-mm-yyyy'), '7', '30', '212', '07', '2000', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (213, to_date('31-07-2000', 'dd-mm-yyyy'), '1', '31', '213', '07', '2000', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (214, to_date('01-08-2000', 'dd-mm-yyyy'), '2', '01', '214', '08', '2000', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (215, to_date('02-08-2000', 'dd-mm-yyyy'), '3', '02', '215', '08', '2000', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (216, to_date('03-08-2000', 'dd-mm-yyyy'), '4', '03', '216', '08', '2000', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (217, to_date('04-08-2000', 'dd-mm-yyyy'), '5', '04', '217', '08', '2000', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (218, to_date('05-08-2000', 'dd-mm-yyyy'), '6', '05', '218', '08', '2000', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (219, to_date('06-08-2000', 'dd-mm-yyyy'), '7', '06', '219', '08', '2000', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (220, to_date('07-08-2000', 'dd-mm-yyyy'), '1', '07', '220', '08', '2000', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (221, to_date('08-08-2000', 'dd-mm-yyyy'), '2', '08', '221', '08', '2000', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (222, to_date('09-08-2000', 'dd-mm-yyyy'), '3', '09', '222', '08', '2000', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (223, to_date('10-08-2000', 'dd-mm-yyyy'), '4', '10', '223', '08', '2000', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (224, to_date('11-08-2000', 'dd-mm-yyyy'), '5', '11', '224', '08', '2000', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (225, to_date('12-08-2000', 'dd-mm-yyyy'), '6', '12', '225', '08', '2000', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (226, to_date('13-08-2000', 'dd-mm-yyyy'), '7', '13', '226', '08', '2000', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (227, to_date('14-08-2000', 'dd-mm-yyyy'), '1', '14', '227', '08', '2000', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (228, to_date('15-08-2000', 'dd-mm-yyyy'), '2', '15', '228', '08', '2000', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (229, to_date('16-08-2000', 'dd-mm-yyyy'), '3', '16', '229', '08', '2000', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (230, to_date('17-08-2000', 'dd-mm-yyyy'), '4', '17', '230', '08', '2000', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (231, to_date('18-08-2000', 'dd-mm-yyyy'), '5', '18', '231', '08', '2000', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (232, to_date('19-08-2000', 'dd-mm-yyyy'), '6', '19', '232', '08', '2000', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (233, to_date('20-08-2000', 'dd-mm-yyyy'), '7', '20', '233', '08', '2000', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (234, to_date('21-08-2000', 'dd-mm-yyyy'), '1', '21', '234', '08', '2000', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (235, to_date('22-08-2000', 'dd-mm-yyyy'), '2', '22', '235', '08', '2000', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (236, to_date('23-08-2000', 'dd-mm-yyyy'), '3', '23', '236', '08', '2000', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (237, to_date('24-08-2000', 'dd-mm-yyyy'), '4', '24', '237', '08', '2000', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (238, to_date('25-08-2000', 'dd-mm-yyyy'), '5', '25', '238', '08', '2000', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (239, to_date('26-08-2000', 'dd-mm-yyyy'), '6', '26', '239', '08', '2000', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (240, to_date('27-08-2000', 'dd-mm-yyyy'), '7', '27', '240', '08', '2000', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (241, to_date('28-08-2000', 'dd-mm-yyyy'), '1', '28', '241', '08', '2000', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (242, to_date('29-08-2000', 'dd-mm-yyyy'), '2', '29', '242', '08', '2000', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (243, to_date('30-08-2000', 'dd-mm-yyyy'), '3', '30', '243', '08', '2000', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (244, to_date('31-08-2000', 'dd-mm-yyyy'), '4', '31', '244', '08', '2000', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (245, to_date('01-09-2000', 'dd-mm-yyyy'), '5', '01', '245', '09', '2000', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (246, to_date('02-09-2000', 'dd-mm-yyyy'), '6', '02', '246', '09', '2000', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (247, to_date('03-09-2000', 'dd-mm-yyyy'), '7', '03', '247', '09', '2000', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (248, to_date('04-09-2000', 'dd-mm-yyyy'), '1', '04', '248', '09', '2000', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (249, to_date('05-09-2000', 'dd-mm-yyyy'), '2', '05', '249', '09', '2000', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (250, to_date('06-09-2000', 'dd-mm-yyyy'), '3', '06', '250', '09', '2000', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (251, to_date('07-09-2000', 'dd-mm-yyyy'), '4', '07', '251', '09', '2000', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (252, to_date('08-09-2000', 'dd-mm-yyyy'), '5', '08', '252', '09', '2000', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (253, to_date('09-09-2000', 'dd-mm-yyyy'), '6', '09', '253', '09', '2000', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (254, to_date('10-09-2000', 'dd-mm-yyyy'), '7', '10', '254', '09', '2000', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (255, to_date('11-09-2000', 'dd-mm-yyyy'), '1', '11', '255', '09', '2000', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (256, to_date('12-09-2000', 'dd-mm-yyyy'), '2', '12', '256', '09', '2000', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (257, to_date('13-09-2000', 'dd-mm-yyyy'), '3', '13', '257', '09', '2000', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (258, to_date('14-09-2000', 'dd-mm-yyyy'), '4', '14', '258', '09', '2000', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (259, to_date('15-09-2000', 'dd-mm-yyyy'), '5', '15', '259', '09', '2000', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (260, to_date('16-09-2000', 'dd-mm-yyyy'), '6', '16', '260', '09', '2000', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (261, to_date('17-09-2000', 'dd-mm-yyyy'), '7', '17', '261', '09', '2000', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (262, to_date('18-09-2000', 'dd-mm-yyyy'), '1', '18', '262', '09', '2000', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (263, to_date('19-09-2000', 'dd-mm-yyyy'), '2', '19', '263', '09', '2000', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (264, to_date('20-09-2000', 'dd-mm-yyyy'), '3', '20', '264', '09', '2000', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (265, to_date('21-09-2000', 'dd-mm-yyyy'), '4', '21', '265', '09', '2000', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (266, to_date('22-09-2000', 'dd-mm-yyyy'), '5', '22', '266', '09', '2000', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (267, to_date('23-09-2000', 'dd-mm-yyyy'), '6', '23', '267', '09', '2000', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (268, to_date('24-09-2000', 'dd-mm-yyyy'), '7', '24', '268', '09', '2000', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (269, to_date('25-09-2000', 'dd-mm-yyyy'), '1', '25', '269', '09', '2000', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (270, to_date('26-09-2000', 'dd-mm-yyyy'), '2', '26', '270', '09', '2000', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (271, to_date('27-09-2000', 'dd-mm-yyyy'), '3', '27', '271', '09', '2000', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (272, to_date('28-09-2000', 'dd-mm-yyyy'), '4', '28', '272', '09', '2000', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (273, to_date('29-09-2000', 'dd-mm-yyyy'), '5', '29', '273', '09', '2000', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (274, to_date('30-09-2000', 'dd-mm-yyyy'), '6', '30', '274', '09', '2000', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (275, to_date('01-10-2000', 'dd-mm-yyyy'), '7', '01', '275', '10', '2000', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (276, to_date('02-10-2000', 'dd-mm-yyyy'), '1', '02', '276', '10', '2000', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (277, to_date('03-10-2000', 'dd-mm-yyyy'), '2', '03', '277', '10', '2000', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (278, to_date('04-10-2000', 'dd-mm-yyyy'), '3', '04', '278', '10', '2000', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (279, to_date('05-10-2000', 'dd-mm-yyyy'), '4', '05', '279', '10', '2000', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (280, to_date('06-10-2000', 'dd-mm-yyyy'), '5', '06', '280', '10', '2000', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (281, to_date('07-10-2000', 'dd-mm-yyyy'), '6', '07', '281', '10', '2000', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (282, to_date('08-10-2000', 'dd-mm-yyyy'), '7', '08', '282', '10', '2000', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (283, to_date('09-10-2000', 'dd-mm-yyyy'), '1', '09', '283', '10', '2000', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (284, to_date('10-10-2000', 'dd-mm-yyyy'), '2', '10', '284', '10', '2000', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (285, to_date('11-10-2000', 'dd-mm-yyyy'), '3', '11', '285', '10', '2000', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (286, to_date('12-10-2000', 'dd-mm-yyyy'), '4', '12', '286', '10', '2000', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (287, to_date('13-10-2000', 'dd-mm-yyyy'), '5', '13', '287', '10', '2000', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (288, to_date('14-10-2000', 'dd-mm-yyyy'), '6', '14', '288', '10', '2000', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (289, to_date('15-10-2000', 'dd-mm-yyyy'), '7', '15', '289', '10', '2000', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (290, to_date('16-10-2000', 'dd-mm-yyyy'), '1', '16', '290', '10', '2000', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (291, to_date('17-10-2000', 'dd-mm-yyyy'), '2', '17', '291', '10', '2000', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (292, to_date('18-10-2000', 'dd-mm-yyyy'), '3', '18', '292', '10', '2000', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (293, to_date('19-10-2000', 'dd-mm-yyyy'), '4', '19', '293', '10', '2000', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (294, to_date('20-10-2000', 'dd-mm-yyyy'), '5', '20', '294', '10', '2000', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (295, to_date('21-10-2000', 'dd-mm-yyyy'), '6', '21', '295', '10', '2000', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (296, to_date('22-10-2000', 'dd-mm-yyyy'), '7', '22', '296', '10', '2000', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (297, to_date('23-10-2000', 'dd-mm-yyyy'), '1', '23', '297', '10', '2000', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (298, to_date('24-10-2000', 'dd-mm-yyyy'), '2', '24', '298', '10', '2000', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (299, to_date('25-10-2000', 'dd-mm-yyyy'), '3', '25', '299', '10', '2000', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (300, to_date('26-10-2000', 'dd-mm-yyyy'), '4', '26', '300', '10', '2000', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (301, to_date('27-10-2000', 'dd-mm-yyyy'), '5', '27', '301', '10', '2000', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (302, to_date('28-10-2000', 'dd-mm-yyyy'), '6', '28', '302', '10', '2000', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (303, to_date('29-10-2000', 'dd-mm-yyyy'), '7', '29', '303', '10', '2000', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (304, to_date('30-10-2000', 'dd-mm-yyyy'), '1', '30', '304', '10', '2000', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (305, to_date('31-10-2000', 'dd-mm-yyyy'), '2', '31', '305', '10', '2000', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (306, to_date('01-11-2000', 'dd-mm-yyyy'), '3', '01', '306', '11', '2000', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (307, to_date('02-11-2000', 'dd-mm-yyyy'), '4', '02', '307', '11', '2000', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (308, to_date('03-11-2000', 'dd-mm-yyyy'), '5', '03', '308', '11', '2000', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (309, to_date('04-11-2000', 'dd-mm-yyyy'), '6', '04', '309', '11', '2000', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (310, to_date('05-11-2000', 'dd-mm-yyyy'), '7', '05', '310', '11', '2000', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (311, to_date('06-11-2000', 'dd-mm-yyyy'), '1', '06', '311', '11', '2000', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (312, to_date('07-11-2000', 'dd-mm-yyyy'), '2', '07', '312', '11', '2000', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (313, to_date('08-11-2000', 'dd-mm-yyyy'), '3', '08', '313', '11', '2000', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (314, to_date('09-11-2000', 'dd-mm-yyyy'), '4', '09', '314', '11', '2000', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (315, to_date('10-11-2000', 'dd-mm-yyyy'), '5', '10', '315', '11', '2000', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (316, to_date('11-11-2000', 'dd-mm-yyyy'), '6', '11', '316', '11', '2000', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (317, to_date('12-11-2000', 'dd-mm-yyyy'), '7', '12', '317', '11', '2000', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (318, to_date('13-11-2000', 'dd-mm-yyyy'), '1', '13', '318', '11', '2000', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (319, to_date('14-11-2000', 'dd-mm-yyyy'), '2', '14', '319', '11', '2000', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (320, to_date('15-11-2000', 'dd-mm-yyyy'), '3', '15', '320', '11', '2000', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (321, to_date('16-11-2000', 'dd-mm-yyyy'), '4', '16', '321', '11', '2000', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (322, to_date('17-11-2000', 'dd-mm-yyyy'), '5', '17', '322', '11', '2000', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (323, to_date('18-11-2000', 'dd-mm-yyyy'), '6', '18', '323', '11', '2000', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (324, to_date('19-11-2000', 'dd-mm-yyyy'), '7', '19', '324', '11', '2000', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (325, to_date('20-11-2000', 'dd-mm-yyyy'), '1', '20', '325', '11', '2000', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (326, to_date('21-11-2000', 'dd-mm-yyyy'), '2', '21', '326', '11', '2000', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (327, to_date('22-11-2000', 'dd-mm-yyyy'), '3', '22', '327', '11', '2000', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (328, to_date('23-11-2000', 'dd-mm-yyyy'), '4', '23', '328', '11', '2000', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (329, to_date('24-11-2000', 'dd-mm-yyyy'), '5', '24', '329', '11', '2000', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (330, to_date('25-11-2000', 'dd-mm-yyyy'), '6', '25', '330', '11', '2000', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (331, to_date('26-11-2000', 'dd-mm-yyyy'), '7', '26', '331', '11', '2000', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (332, to_date('27-11-2000', 'dd-mm-yyyy'), '1', '27', '332', '11', '2000', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (333, to_date('28-11-2000', 'dd-mm-yyyy'), '2', '28', '333', '11', '2000', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (334, to_date('29-11-2000', 'dd-mm-yyyy'), '3', '29', '334', '11', '2000', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (335, to_date('30-11-2000', 'dd-mm-yyyy'), '4', '30', '335', '11', '2000', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (336, to_date('01-12-2000', 'dd-mm-yyyy'), '5', '01', '336', '12', '2000', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (337, to_date('02-12-2000', 'dd-mm-yyyy'), '6', '02', '337', '12', '2000', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (338, to_date('03-12-2000', 'dd-mm-yyyy'), '7', '03', '338', '12', '2000', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (339, to_date('04-12-2000', 'dd-mm-yyyy'), '1', '04', '339', '12', '2000', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (340, to_date('05-12-2000', 'dd-mm-yyyy'), '2', '05', '340', '12', '2000', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (341, to_date('06-12-2000', 'dd-mm-yyyy'), '3', '06', '341', '12', '2000', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (342, to_date('07-12-2000', 'dd-mm-yyyy'), '4', '07', '342', '12', '2000', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (343, to_date('08-12-2000', 'dd-mm-yyyy'), '5', '08', '343', '12', '2000', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (344, to_date('09-12-2000', 'dd-mm-yyyy'), '6', '09', '344', '12', '2000', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (345, to_date('10-12-2000', 'dd-mm-yyyy'), '7', '10', '345', '12', '2000', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (346, to_date('11-12-2000', 'dd-mm-yyyy'), '1', '11', '346', '12', '2000', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (347, to_date('12-12-2000', 'dd-mm-yyyy'), '2', '12', '347', '12', '2000', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (348, to_date('13-12-2000', 'dd-mm-yyyy'), '3', '13', '348', '12', '2000', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (349, to_date('14-12-2000', 'dd-mm-yyyy'), '4', '14', '349', '12', '2000', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (350, to_date('15-12-2000', 'dd-mm-yyyy'), '5', '15', '350', '12', '2000', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (351, to_date('16-12-2000', 'dd-mm-yyyy'), '6', '16', '351', '12', '2000', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (352, to_date('17-12-2000', 'dd-mm-yyyy'), '7', '17', '352', '12', '2000', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (353, to_date('18-12-2000', 'dd-mm-yyyy'), '1', '18', '353', '12', '2000', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (354, to_date('19-12-2000', 'dd-mm-yyyy'), '2', '19', '354', '12', '2000', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (355, to_date('20-12-2000', 'dd-mm-yyyy'), '3', '20', '355', '12', '2000', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (356, to_date('21-12-2000', 'dd-mm-yyyy'), '4', '21', '356', '12', '2000', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (357, to_date('22-12-2000', 'dd-mm-yyyy'), '5', '22', '357', '12', '2000', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (358, to_date('23-12-2000', 'dd-mm-yyyy'), '6', '23', '358', '12', '2000', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (359, to_date('24-12-2000', 'dd-mm-yyyy'), '7', '24', '359', '12', '2000', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (360, to_date('25-12-2000', 'dd-mm-yyyy'), '1', '25', '360', '12', '2000', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (361, to_date('26-12-2000', 'dd-mm-yyyy'), '2', '26', '361', '12', '2000', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (362, to_date('27-12-2000', 'dd-mm-yyyy'), '3', '27', '362', '12', '2000', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (363, to_date('28-12-2000', 'dd-mm-yyyy'), '4', '28', '363', '12', '2000', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (364, to_date('29-12-2000', 'dd-mm-yyyy'), '5', '29', '364', '12', '2000', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (365, to_date('30-12-2000', 'dd-mm-yyyy'), '6', '30', '365', '12', '2000', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (366, to_date('31-12-2000', 'dd-mm-yyyy'), '7', '31', '366', '12', '2000', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (367, to_date('01-01-2001', 'dd-mm-yyyy'), '1', '01', '001', '01', '2001', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (368, to_date('02-01-2001', 'dd-mm-yyyy'), '2', '02', '002', '01', '2001', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (369, to_date('03-01-2001', 'dd-mm-yyyy'), '3', '03', '003', '01', '2001', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (370, to_date('04-01-2001', 'dd-mm-yyyy'), '4', '04', '004', '01', '2001', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (371, to_date('05-01-2001', 'dd-mm-yyyy'), '5', '05', '005', '01', '2001', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (372, to_date('06-01-2001', 'dd-mm-yyyy'), '6', '06', '006', '01', '2001', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (373, to_date('07-01-2001', 'dd-mm-yyyy'), '7', '07', '007', '01', '2001', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (374, to_date('08-01-2001', 'dd-mm-yyyy'), '1', '08', '008', '01', '2001', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (375, to_date('09-01-2001', 'dd-mm-yyyy'), '2', '09', '009', '01', '2001', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (376, to_date('10-01-2001', 'dd-mm-yyyy'), '3', '10', '010', '01', '2001', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (377, to_date('11-01-2001', 'dd-mm-yyyy'), '4', '11', '011', '01', '2001', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (378, to_date('12-01-2001', 'dd-mm-yyyy'), '5', '12', '012', '01', '2001', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (379, to_date('13-01-2001', 'dd-mm-yyyy'), '6', '13', '013', '01', '2001', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (380, to_date('14-01-2001', 'dd-mm-yyyy'), '7', '14', '014', '01', '2001', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (381, to_date('15-01-2001', 'dd-mm-yyyy'), '1', '15', '015', '01', '2001', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (382, to_date('16-01-2001', 'dd-mm-yyyy'), '2', '16', '016', '01', '2001', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (383, to_date('17-01-2001', 'dd-mm-yyyy'), '3', '17', '017', '01', '2001', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (384, to_date('18-01-2001', 'dd-mm-yyyy'), '4', '18', '018', '01', '2001', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (385, to_date('19-01-2001', 'dd-mm-yyyy'), '5', '19', '019', '01', '2001', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (386, to_date('20-01-2001', 'dd-mm-yyyy'), '6', '20', '020', '01', '2001', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (387, to_date('21-01-2001', 'dd-mm-yyyy'), '7', '21', '021', '01', '2001', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (388, to_date('22-01-2001', 'dd-mm-yyyy'), '1', '22', '022', '01', '2001', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (389, to_date('23-01-2001', 'dd-mm-yyyy'), '2', '23', '023', '01', '2001', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (390, to_date('24-01-2001', 'dd-mm-yyyy'), '3', '24', '024', '01', '2001', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (391, to_date('25-01-2001', 'dd-mm-yyyy'), '4', '25', '025', '01', '2001', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (392, to_date('26-01-2001', 'dd-mm-yyyy'), '5', '26', '026', '01', '2001', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (393, to_date('27-01-2001', 'dd-mm-yyyy'), '6', '27', '027', '01', '2001', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (394, to_date('28-01-2001', 'dd-mm-yyyy'), '7', '28', '028', '01', '2001', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (395, to_date('29-01-2001', 'dd-mm-yyyy'), '1', '29', '029', '01', '2001', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (396, to_date('30-01-2001', 'dd-mm-yyyy'), '2', '30', '030', '01', '2001', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (397, to_date('31-01-2001', 'dd-mm-yyyy'), '3', '31', '031', '01', '2001', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (398, to_date('01-02-2001', 'dd-mm-yyyy'), '4', '01', '032', '02', '2001', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (399, to_date('02-02-2001', 'dd-mm-yyyy'), '5', '02', '033', '02', '2001', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (400, to_date('03-02-2001', 'dd-mm-yyyy'), '6', '03', '034', '02', '2001', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (401, to_date('04-02-2001', 'dd-mm-yyyy'), '7', '04', '035', '02', '2001', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (402, to_date('05-02-2001', 'dd-mm-yyyy'), '1', '05', '036', '02', '2001', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (403, to_date('06-02-2001', 'dd-mm-yyyy'), '2', '06', '037', '02', '2001', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (404, to_date('07-02-2001', 'dd-mm-yyyy'), '3', '07', '038', '02', '2001', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (405, to_date('08-02-2001', 'dd-mm-yyyy'), '4', '08', '039', '02', '2001', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (406, to_date('09-02-2001', 'dd-mm-yyyy'), '5', '09', '040', '02', '2001', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (407, to_date('10-02-2001', 'dd-mm-yyyy'), '6', '10', '041', '02', '2001', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (408, to_date('11-02-2001', 'dd-mm-yyyy'), '7', '11', '042', '02', '2001', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (409, to_date('12-02-2001', 'dd-mm-yyyy'), '1', '12', '043', '02', '2001', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (410, to_date('13-02-2001', 'dd-mm-yyyy'), '2', '13', '044', '02', '2001', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (411, to_date('14-02-2001', 'dd-mm-yyyy'), '3', '14', '045', '02', '2001', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (412, to_date('15-02-2001', 'dd-mm-yyyy'), '4', '15', '046', '02', '2001', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (413, to_date('16-02-2001', 'dd-mm-yyyy'), '5', '16', '047', '02', '2001', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (414, to_date('17-02-2001', 'dd-mm-yyyy'), '6', '17', '048', '02', '2001', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (415, to_date('18-02-2001', 'dd-mm-yyyy'), '7', '18', '049', '02', '2001', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (416, to_date('19-02-2001', 'dd-mm-yyyy'), '1', '19', '050', '02', '2001', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (417, to_date('20-02-2001', 'dd-mm-yyyy'), '2', '20', '051', '02', '2001', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (418, to_date('21-02-2001', 'dd-mm-yyyy'), '3', '21', '052', '02', '2001', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (419, to_date('22-02-2001', 'dd-mm-yyyy'), '4', '22', '053', '02', '2001', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (420, to_date('23-02-2001', 'dd-mm-yyyy'), '5', '23', '054', '02', '2001', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (421, to_date('24-02-2001', 'dd-mm-yyyy'), '6', '24', '055', '02', '2001', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (422, to_date('25-02-2001', 'dd-mm-yyyy'), '7', '25', '056', '02', '2001', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (423, to_date('26-02-2001', 'dd-mm-yyyy'), '1', '26', '057', '02', '2001', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (424, to_date('27-02-2001', 'dd-mm-yyyy'), '2', '27', '058', '02', '2001', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (425, to_date('28-02-2001', 'dd-mm-yyyy'), '3', '28', '059', '02', '2001', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (426, to_date('01-03-2001', 'dd-mm-yyyy'), '4', '01', '060', '03', '2001', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (427, to_date('02-03-2001', 'dd-mm-yyyy'), '5', '02', '061', '03', '2001', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (428, to_date('03-03-2001', 'dd-mm-yyyy'), '6', '03', '062', '03', '2001', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (429, to_date('04-03-2001', 'dd-mm-yyyy'), '7', '04', '063', '03', '2001', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (430, to_date('05-03-2001', 'dd-mm-yyyy'), '1', '05', '064', '03', '2001', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (431, to_date('06-03-2001', 'dd-mm-yyyy'), '2', '06', '065', '03', '2001', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (432, to_date('07-03-2001', 'dd-mm-yyyy'), '3', '07', '066', '03', '2001', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (433, to_date('08-03-2001', 'dd-mm-yyyy'), '4', '08', '067', '03', '2001', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (434, to_date('09-03-2001', 'dd-mm-yyyy'), '5', '09', '068', '03', '2001', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (435, to_date('10-03-2001', 'dd-mm-yyyy'), '6', '10', '069', '03', '2001', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (436, to_date('11-03-2001', 'dd-mm-yyyy'), '7', '11', '070', '03', '2001', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (437, to_date('12-03-2001', 'dd-mm-yyyy'), '1', '12', '071', '03', '2001', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (438, to_date('13-03-2001', 'dd-mm-yyyy'), '2', '13', '072', '03', '2001', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (439, to_date('14-03-2001', 'dd-mm-yyyy'), '3', '14', '073', '03', '2001', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (440, to_date('15-03-2001', 'dd-mm-yyyy'), '4', '15', '074', '03', '2001', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (441, to_date('16-03-2001', 'dd-mm-yyyy'), '5', '16', '075', '03', '2001', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (442, to_date('17-03-2001', 'dd-mm-yyyy'), '6', '17', '076', '03', '2001', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (443, to_date('18-03-2001', 'dd-mm-yyyy'), '7', '18', '077', '03', '2001', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (444, to_date('19-03-2001', 'dd-mm-yyyy'), '1', '19', '078', '03', '2001', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (445, to_date('20-03-2001', 'dd-mm-yyyy'), '2', '20', '079', '03', '2001', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (446, to_date('21-03-2001', 'dd-mm-yyyy'), '3', '21', '080', '03', '2001', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (447, to_date('22-03-2001', 'dd-mm-yyyy'), '4', '22', '081', '03', '2001', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (448, to_date('23-03-2001', 'dd-mm-yyyy'), '5', '23', '082', '03', '2001', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (449, to_date('24-03-2001', 'dd-mm-yyyy'), '6', '24', '083', '03', '2001', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (450, to_date('25-03-2001', 'dd-mm-yyyy'), '7', '25', '084', '03', '2001', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (451, to_date('26-03-2001', 'dd-mm-yyyy'), '1', '26', '085', '03', '2001', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (452, to_date('27-03-2001', 'dd-mm-yyyy'), '2', '27', '086', '03', '2001', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (453, to_date('28-03-2001', 'dd-mm-yyyy'), '3', '28', '087', '03', '2001', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (454, to_date('29-03-2001', 'dd-mm-yyyy'), '4', '29', '088', '03', '2001', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (455, to_date('30-03-2001', 'dd-mm-yyyy'), '5', '30', '089', '03', '2001', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (456, to_date('31-03-2001', 'dd-mm-yyyy'), '6', '31', '090', '03', '2001', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (457, to_date('01-04-2001', 'dd-mm-yyyy'), '7', '01', '091', '04', '2001', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (458, to_date('02-04-2001', 'dd-mm-yyyy'), '1', '02', '092', '04', '2001', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (459, to_date('03-04-2001', 'dd-mm-yyyy'), '2', '03', '093', '04', '2001', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (460, to_date('04-04-2001', 'dd-mm-yyyy'), '3', '04', '094', '04', '2001', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (461, to_date('05-04-2001', 'dd-mm-yyyy'), '4', '05', '095', '04', '2001', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (462, to_date('06-04-2001', 'dd-mm-yyyy'), '5', '06', '096', '04', '2001', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (463, to_date('07-04-2001', 'dd-mm-yyyy'), '6', '07', '097', '04', '2001', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (464, to_date('08-04-2001', 'dd-mm-yyyy'), '7', '08', '098', '04', '2001', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (465, to_date('09-04-2001', 'dd-mm-yyyy'), '1', '09', '099', '04', '2001', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (466, to_date('10-04-2001', 'dd-mm-yyyy'), '2', '10', '100', '04', '2001', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (467, to_date('11-04-2001', 'dd-mm-yyyy'), '3', '11', '101', '04', '2001', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (468, to_date('12-04-2001', 'dd-mm-yyyy'), '4', '12', '102', '04', '2001', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (469, to_date('13-04-2001', 'dd-mm-yyyy'), '5', '13', '103', '04', '2001', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (470, to_date('14-04-2001', 'dd-mm-yyyy'), '6', '14', '104', '04', '2001', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (471, to_date('15-04-2001', 'dd-mm-yyyy'), '7', '15', '105', '04', '2001', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (472, to_date('16-04-2001', 'dd-mm-yyyy'), '1', '16', '106', '04', '2001', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (473, to_date('17-04-2001', 'dd-mm-yyyy'), '2', '17', '107', '04', '2001', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (474, to_date('18-04-2001', 'dd-mm-yyyy'), '3', '18', '108', '04', '2001', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (475, to_date('19-04-2001', 'dd-mm-yyyy'), '4', '19', '109', '04', '2001', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (476, to_date('20-04-2001', 'dd-mm-yyyy'), '5', '20', '110', '04', '2001', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (477, to_date('21-04-2001', 'dd-mm-yyyy'), '6', '21', '111', '04', '2001', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (478, to_date('22-04-2001', 'dd-mm-yyyy'), '7', '22', '112', '04', '2001', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (479, to_date('23-04-2001', 'dd-mm-yyyy'), '1', '23', '113', '04', '2001', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (480, to_date('24-04-2001', 'dd-mm-yyyy'), '2', '24', '114', '04', '2001', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (481, to_date('25-04-2001', 'dd-mm-yyyy'), '3', '25', '115', '04', '2001', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (482, to_date('26-04-2001', 'dd-mm-yyyy'), '4', '26', '116', '04', '2001', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (483, to_date('27-04-2001', 'dd-mm-yyyy'), '5', '27', '117', '04', '2001', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (484, to_date('28-04-2001', 'dd-mm-yyyy'), '6', '28', '118', '04', '2001', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (485, to_date('29-04-2001', 'dd-mm-yyyy'), '7', '29', '119', '04', '2001', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (486, to_date('30-04-2001', 'dd-mm-yyyy'), '1', '30', '120', '04', '2001', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (487, to_date('01-05-2001', 'dd-mm-yyyy'), '2', '01', '121', '05', '2001', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (488, to_date('02-05-2001', 'dd-mm-yyyy'), '3', '02', '122', '05', '2001', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (489, to_date('03-05-2001', 'dd-mm-yyyy'), '4', '03', '123', '05', '2001', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (490, to_date('04-05-2001', 'dd-mm-yyyy'), '5', '04', '124', '05', '2001', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (491, to_date('05-05-2001', 'dd-mm-yyyy'), '6', '05', '125', '05', '2001', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (492, to_date('06-05-2001', 'dd-mm-yyyy'), '7', '06', '126', '05', '2001', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (493, to_date('07-05-2001', 'dd-mm-yyyy'), '1', '07', '127', '05', '2001', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (494, to_date('08-05-2001', 'dd-mm-yyyy'), '2', '08', '128', '05', '2001', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (495, to_date('09-05-2001', 'dd-mm-yyyy'), '3', '09', '129', '05', '2001', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (496, to_date('10-05-2001', 'dd-mm-yyyy'), '4', '10', '130', '05', '2001', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (497, to_date('11-05-2001', 'dd-mm-yyyy'), '5', '11', '131', '05', '2001', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (498, to_date('12-05-2001', 'dd-mm-yyyy'), '6', '12', '132', '05', '2001', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (499, to_date('13-05-2001', 'dd-mm-yyyy'), '7', '13', '133', '05', '2001', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (500, to_date('14-05-2001', 'dd-mm-yyyy'), '1', '14', '134', '05', '2001', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (501, to_date('15-05-2001', 'dd-mm-yyyy'), '2', '15', '135', '05', '2001', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (502, to_date('16-05-2001', 'dd-mm-yyyy'), '3', '16', '136', '05', '2001', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (503, to_date('17-05-2001', 'dd-mm-yyyy'), '4', '17', '137', '05', '2001', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (504, to_date('18-05-2001', 'dd-mm-yyyy'), '5', '18', '138', '05', '2001', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (505, to_date('19-05-2001', 'dd-mm-yyyy'), '6', '19', '139', '05', '2001', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (506, to_date('20-05-2001', 'dd-mm-yyyy'), '7', '20', '140', '05', '2001', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (507, to_date('21-05-2001', 'dd-mm-yyyy'), '1', '21', '141', '05', '2001', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (508, to_date('22-05-2001', 'dd-mm-yyyy'), '2', '22', '142', '05', '2001', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (509, to_date('23-05-2001', 'dd-mm-yyyy'), '3', '23', '143', '05', '2001', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (510, to_date('24-05-2001', 'dd-mm-yyyy'), '4', '24', '144', '05', '2001', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (511, to_date('25-05-2001', 'dd-mm-yyyy'), '5', '25', '145', '05', '2001', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (512, to_date('26-05-2001', 'dd-mm-yyyy'), '6', '26', '146', '05', '2001', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (513, to_date('27-05-2001', 'dd-mm-yyyy'), '7', '27', '147', '05', '2001', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (514, to_date('28-05-2001', 'dd-mm-yyyy'), '1', '28', '148', '05', '2001', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (515, to_date('29-05-2001', 'dd-mm-yyyy'), '2', '29', '149', '05', '2001', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (516, to_date('30-05-2001', 'dd-mm-yyyy'), '3', '30', '150', '05', '2001', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (517, to_date('31-05-2001', 'dd-mm-yyyy'), '4', '31', '151', '05', '2001', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (518, to_date('01-06-2001', 'dd-mm-yyyy'), '5', '01', '152', '06', '2001', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (519, to_date('02-06-2001', 'dd-mm-yyyy'), '6', '02', '153', '06', '2001', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (520, to_date('03-06-2001', 'dd-mm-yyyy'), '7', '03', '154', '06', '2001', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (521, to_date('04-06-2001', 'dd-mm-yyyy'), '1', '04', '155', '06', '2001', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (522, to_date('05-06-2001', 'dd-mm-yyyy'), '2', '05', '156', '06', '2001', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (523, to_date('06-06-2001', 'dd-mm-yyyy'), '3', '06', '157', '06', '2001', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (524, to_date('07-06-2001', 'dd-mm-yyyy'), '4', '07', '158', '06', '2001', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (525, to_date('08-06-2001', 'dd-mm-yyyy'), '5', '08', '159', '06', '2001', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (526, to_date('09-06-2001', 'dd-mm-yyyy'), '6', '09', '160', '06', '2001', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (527, to_date('10-06-2001', 'dd-mm-yyyy'), '7', '10', '161', '06', '2001', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (528, to_date('11-06-2001', 'dd-mm-yyyy'), '1', '11', '162', '06', '2001', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (529, to_date('12-06-2001', 'dd-mm-yyyy'), '2', '12', '163', '06', '2001', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (530, to_date('13-06-2001', 'dd-mm-yyyy'), '3', '13', '164', '06', '2001', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (531, to_date('14-06-2001', 'dd-mm-yyyy'), '4', '14', '165', '06', '2001', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (532, to_date('15-06-2001', 'dd-mm-yyyy'), '5', '15', '166', '06', '2001', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (533, to_date('16-06-2001', 'dd-mm-yyyy'), '6', '16', '167', '06', '2001', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (534, to_date('17-06-2001', 'dd-mm-yyyy'), '7', '17', '168', '06', '2001', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (535, to_date('18-06-2001', 'dd-mm-yyyy'), '1', '18', '169', '06', '2001', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (536, to_date('19-06-2001', 'dd-mm-yyyy'), '2', '19', '170', '06', '2001', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (537, to_date('20-06-2001', 'dd-mm-yyyy'), '3', '20', '171', '06', '2001', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (538, to_date('21-06-2001', 'dd-mm-yyyy'), '4', '21', '172', '06', '2001', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (539, to_date('22-06-2001', 'dd-mm-yyyy'), '5', '22', '173', '06', '2001', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (540, to_date('23-06-2001', 'dd-mm-yyyy'), '6', '23', '174', '06', '2001', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (541, to_date('24-06-2001', 'dd-mm-yyyy'), '7', '24', '175', '06', '2001', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (542, to_date('25-06-2001', 'dd-mm-yyyy'), '1', '25', '176', '06', '2001', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (543, to_date('26-06-2001', 'dd-mm-yyyy'), '2', '26', '177', '06', '2001', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (544, to_date('27-06-2001', 'dd-mm-yyyy'), '3', '27', '178', '06', '2001', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (545, to_date('28-06-2001', 'dd-mm-yyyy'), '4', '28', '179', '06', '2001', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (546, to_date('29-06-2001', 'dd-mm-yyyy'), '5', '29', '180', '06', '2001', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (547, to_date('30-06-2001', 'dd-mm-yyyy'), '6', '30', '181', '06', '2001', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (548, to_date('01-07-2001', 'dd-mm-yyyy'), '7', '01', '182', '07', '2001', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (549, to_date('02-07-2001', 'dd-mm-yyyy'), '1', '02', '183', '07', '2001', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (550, to_date('03-07-2001', 'dd-mm-yyyy'), '2', '03', '184', '07', '2001', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (551, to_date('04-07-2001', 'dd-mm-yyyy'), '3', '04', '185', '07', '2001', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (552, to_date('05-07-2001', 'dd-mm-yyyy'), '4', '05', '186', '07', '2001', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (553, to_date('06-07-2001', 'dd-mm-yyyy'), '5', '06', '187', '07', '2001', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (554, to_date('07-07-2001', 'dd-mm-yyyy'), '6', '07', '188', '07', '2001', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (555, to_date('08-07-2001', 'dd-mm-yyyy'), '7', '08', '189', '07', '2001', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (556, to_date('09-07-2001', 'dd-mm-yyyy'), '1', '09', '190', '07', '2001', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (557, to_date('10-07-2001', 'dd-mm-yyyy'), '2', '10', '191', '07', '2001', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (558, to_date('11-07-2001', 'dd-mm-yyyy'), '3', '11', '192', '07', '2001', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (559, to_date('12-07-2001', 'dd-mm-yyyy'), '4', '12', '193', '07', '2001', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (560, to_date('13-07-2001', 'dd-mm-yyyy'), '5', '13', '194', '07', '2001', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (561, to_date('14-07-2001', 'dd-mm-yyyy'), '6', '14', '195', '07', '2001', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (562, to_date('15-07-2001', 'dd-mm-yyyy'), '7', '15', '196', '07', '2001', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (563, to_date('16-07-2001', 'dd-mm-yyyy'), '1', '16', '197', '07', '2001', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (564, to_date('17-07-2001', 'dd-mm-yyyy'), '2', '17', '198', '07', '2001', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (565, to_date('18-07-2001', 'dd-mm-yyyy'), '3', '18', '199', '07', '2001', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (566, to_date('19-07-2001', 'dd-mm-yyyy'), '4', '19', '200', '07', '2001', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (567, to_date('20-07-2001', 'dd-mm-yyyy'), '5', '20', '201', '07', '2001', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (568, to_date('21-07-2001', 'dd-mm-yyyy'), '6', '21', '202', '07', '2001', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (569, to_date('22-07-2001', 'dd-mm-yyyy'), '7', '22', '203', '07', '2001', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (570, to_date('23-07-2001', 'dd-mm-yyyy'), '1', '23', '204', '07', '2001', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (571, to_date('24-07-2001', 'dd-mm-yyyy'), '2', '24', '205', '07', '2001', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (572, to_date('25-07-2001', 'dd-mm-yyyy'), '3', '25', '206', '07', '2001', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (573, to_date('26-07-2001', 'dd-mm-yyyy'), '4', '26', '207', '07', '2001', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (574, to_date('27-07-2001', 'dd-mm-yyyy'), '5', '27', '208', '07', '2001', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (575, to_date('28-07-2001', 'dd-mm-yyyy'), '6', '28', '209', '07', '2001', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (576, to_date('29-07-2001', 'dd-mm-yyyy'), '7', '29', '210', '07', '2001', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (577, to_date('30-07-2001', 'dd-mm-yyyy'), '1', '30', '211', '07', '2001', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (578, to_date('31-07-2001', 'dd-mm-yyyy'), '2', '31', '212', '07', '2001', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (579, to_date('01-08-2001', 'dd-mm-yyyy'), '3', '01', '213', '08', '2001', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (580, to_date('02-08-2001', 'dd-mm-yyyy'), '4', '02', '214', '08', '2001', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (581, to_date('03-08-2001', 'dd-mm-yyyy'), '5', '03', '215', '08', '2001', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (582, to_date('04-08-2001', 'dd-mm-yyyy'), '6', '04', '216', '08', '2001', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (583, to_date('05-08-2001', 'dd-mm-yyyy'), '7', '05', '217', '08', '2001', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (584, to_date('06-08-2001', 'dd-mm-yyyy'), '1', '06', '218', '08', '2001', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (585, to_date('07-08-2001', 'dd-mm-yyyy'), '2', '07', '219', '08', '2001', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (586, to_date('08-08-2001', 'dd-mm-yyyy'), '3', '08', '220', '08', '2001', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (587, to_date('09-08-2001', 'dd-mm-yyyy'), '4', '09', '221', '08', '2001', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (588, to_date('10-08-2001', 'dd-mm-yyyy'), '5', '10', '222', '08', '2001', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (589, to_date('11-08-2001', 'dd-mm-yyyy'), '6', '11', '223', '08', '2001', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (590, to_date('12-08-2001', 'dd-mm-yyyy'), '7', '12', '224', '08', '2001', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (591, to_date('13-08-2001', 'dd-mm-yyyy'), '1', '13', '225', '08', '2001', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (592, to_date('14-08-2001', 'dd-mm-yyyy'), '2', '14', '226', '08', '2001', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (593, to_date('15-08-2001', 'dd-mm-yyyy'), '3', '15', '227', '08', '2001', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (594, to_date('16-08-2001', 'dd-mm-yyyy'), '4', '16', '228', '08', '2001', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (595, to_date('17-08-2001', 'dd-mm-yyyy'), '5', '17', '229', '08', '2001', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (596, to_date('18-08-2001', 'dd-mm-yyyy'), '6', '18', '230', '08', '2001', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (597, to_date('19-08-2001', 'dd-mm-yyyy'), '7', '19', '231', '08', '2001', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (598, to_date('20-08-2001', 'dd-mm-yyyy'), '1', '20', '232', '08', '2001', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (599, to_date('21-08-2001', 'dd-mm-yyyy'), '2', '21', '233', '08', '2001', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (600, to_date('22-08-2001', 'dd-mm-yyyy'), '3', '22', '234', '08', '2001', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (601, to_date('23-08-2001', 'dd-mm-yyyy'), '4', '23', '235', '08', '2001', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (602, to_date('24-08-2001', 'dd-mm-yyyy'), '5', '24', '236', '08', '2001', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (603, to_date('25-08-2001', 'dd-mm-yyyy'), '6', '25', '237', '08', '2001', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (604, to_date('26-08-2001', 'dd-mm-yyyy'), '7', '26', '238', '08', '2001', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (605, to_date('27-08-2001', 'dd-mm-yyyy'), '1', '27', '239', '08', '2001', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (606, to_date('28-08-2001', 'dd-mm-yyyy'), '2', '28', '240', '08', '2001', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (607, to_date('29-08-2001', 'dd-mm-yyyy'), '3', '29', '241', '08', '2001', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (608, to_date('30-08-2001', 'dd-mm-yyyy'), '4', '30', '242', '08', '2001', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (609, to_date('31-08-2001', 'dd-mm-yyyy'), '5', '31', '243', '08', '2001', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (610, to_date('01-09-2001', 'dd-mm-yyyy'), '6', '01', '244', '09', '2001', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (611, to_date('02-09-2001', 'dd-mm-yyyy'), '7', '02', '245', '09', '2001', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (612, to_date('03-09-2001', 'dd-mm-yyyy'), '1', '03', '246', '09', '2001', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (613, to_date('04-09-2001', 'dd-mm-yyyy'), '2', '04', '247', '09', '2001', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (614, to_date('05-09-2001', 'dd-mm-yyyy'), '3', '05', '248', '09', '2001', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (615, to_date('06-09-2001', 'dd-mm-yyyy'), '4', '06', '249', '09', '2001', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (616, to_date('07-09-2001', 'dd-mm-yyyy'), '5', '07', '250', '09', '2001', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (617, to_date('08-09-2001', 'dd-mm-yyyy'), '6', '08', '251', '09', '2001', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (618, to_date('09-09-2001', 'dd-mm-yyyy'), '7', '09', '252', '09', '2001', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (619, to_date('10-09-2001', 'dd-mm-yyyy'), '1', '10', '253', '09', '2001', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (620, to_date('11-09-2001', 'dd-mm-yyyy'), '2', '11', '254', '09', '2001', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (621, to_date('12-09-2001', 'dd-mm-yyyy'), '3', '12', '255', '09', '2001', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (622, to_date('13-09-2001', 'dd-mm-yyyy'), '4', '13', '256', '09', '2001', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (623, to_date('14-09-2001', 'dd-mm-yyyy'), '5', '14', '257', '09', '2001', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (624, to_date('15-09-2001', 'dd-mm-yyyy'), '6', '15', '258', '09', '2001', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (625, to_date('16-09-2001', 'dd-mm-yyyy'), '7', '16', '259', '09', '2001', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (626, to_date('17-09-2001', 'dd-mm-yyyy'), '1', '17', '260', '09', '2001', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (627, to_date('18-09-2001', 'dd-mm-yyyy'), '2', '18', '261', '09', '2001', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (628, to_date('19-09-2001', 'dd-mm-yyyy'), '3', '19', '262', '09', '2001', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (629, to_date('20-09-2001', 'dd-mm-yyyy'), '4', '20', '263', '09', '2001', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (630, to_date('21-09-2001', 'dd-mm-yyyy'), '5', '21', '264', '09', '2001', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (631, to_date('22-09-2001', 'dd-mm-yyyy'), '6', '22', '265', '09', '2001', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (632, to_date('23-09-2001', 'dd-mm-yyyy'), '7', '23', '266', '09', '2001', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (633, to_date('24-09-2001', 'dd-mm-yyyy'), '1', '24', '267', '09', '2001', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (634, to_date('25-09-2001', 'dd-mm-yyyy'), '2', '25', '268', '09', '2001', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (635, to_date('26-09-2001', 'dd-mm-yyyy'), '3', '26', '269', '09', '2001', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (636, to_date('27-09-2001', 'dd-mm-yyyy'), '4', '27', '270', '09', '2001', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (637, to_date('28-09-2001', 'dd-mm-yyyy'), '5', '28', '271', '09', '2001', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (638, to_date('29-09-2001', 'dd-mm-yyyy'), '6', '29', '272', '09', '2001', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (639, to_date('30-09-2001', 'dd-mm-yyyy'), '7', '30', '273', '09', '2001', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (640, to_date('01-10-2001', 'dd-mm-yyyy'), '1', '01', '274', '10', '2001', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (641, to_date('02-10-2001', 'dd-mm-yyyy'), '2', '02', '275', '10', '2001', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (642, to_date('03-10-2001', 'dd-mm-yyyy'), '3', '03', '276', '10', '2001', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (643, to_date('04-10-2001', 'dd-mm-yyyy'), '4', '04', '277', '10', '2001', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (644, to_date('05-10-2001', 'dd-mm-yyyy'), '5', '05', '278', '10', '2001', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (645, to_date('06-10-2001', 'dd-mm-yyyy'), '6', '06', '279', '10', '2001', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (646, to_date('07-10-2001', 'dd-mm-yyyy'), '7', '07', '280', '10', '2001', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (647, to_date('08-10-2001', 'dd-mm-yyyy'), '1', '08', '281', '10', '2001', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (648, to_date('09-10-2001', 'dd-mm-yyyy'), '2', '09', '282', '10', '2001', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (649, to_date('10-10-2001', 'dd-mm-yyyy'), '3', '10', '283', '10', '2001', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (650, to_date('11-10-2001', 'dd-mm-yyyy'), '4', '11', '284', '10', '2001', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (651, to_date('12-10-2001', 'dd-mm-yyyy'), '5', '12', '285', '10', '2001', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (652, to_date('13-10-2001', 'dd-mm-yyyy'), '6', '13', '286', '10', '2001', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (653, to_date('14-10-2001', 'dd-mm-yyyy'), '7', '14', '287', '10', '2001', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (654, to_date('15-10-2001', 'dd-mm-yyyy'), '1', '15', '288', '10', '2001', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (655, to_date('16-10-2001', 'dd-mm-yyyy'), '2', '16', '289', '10', '2001', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (656, to_date('17-10-2001', 'dd-mm-yyyy'), '3', '17', '290', '10', '2001', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (657, to_date('18-10-2001', 'dd-mm-yyyy'), '4', '18', '291', '10', '2001', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (658, to_date('19-10-2001', 'dd-mm-yyyy'), '5', '19', '292', '10', '2001', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (659, to_date('20-10-2001', 'dd-mm-yyyy'), '6', '20', '293', '10', '2001', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (660, to_date('21-10-2001', 'dd-mm-yyyy'), '7', '21', '294', '10', '2001', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (661, to_date('22-10-2001', 'dd-mm-yyyy'), '1', '22', '295', '10', '2001', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (662, to_date('23-10-2001', 'dd-mm-yyyy'), '2', '23', '296', '10', '2001', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (663, to_date('24-10-2001', 'dd-mm-yyyy'), '3', '24', '297', '10', '2001', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (664, to_date('25-10-2001', 'dd-mm-yyyy'), '4', '25', '298', '10', '2001', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (665, to_date('26-10-2001', 'dd-mm-yyyy'), '5', '26', '299', '10', '2001', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (666, to_date('27-10-2001', 'dd-mm-yyyy'), '6', '27', '300', '10', '2001', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (667, to_date('28-10-2001', 'dd-mm-yyyy'), '7', '28', '301', '10', '2001', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (668, to_date('29-10-2001', 'dd-mm-yyyy'), '1', '29', '302', '10', '2001', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (669, to_date('30-10-2001', 'dd-mm-yyyy'), '2', '30', '303', '10', '2001', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (670, to_date('31-10-2001', 'dd-mm-yyyy'), '3', '31', '304', '10', '2001', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (671, to_date('01-11-2001', 'dd-mm-yyyy'), '4', '01', '305', '11', '2001', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (672, to_date('02-11-2001', 'dd-mm-yyyy'), '5', '02', '306', '11', '2001', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (673, to_date('03-11-2001', 'dd-mm-yyyy'), '6', '03', '307', '11', '2001', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (674, to_date('04-11-2001', 'dd-mm-yyyy'), '7', '04', '308', '11', '2001', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (675, to_date('05-11-2001', 'dd-mm-yyyy'), '1', '05', '309', '11', '2001', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (676, to_date('06-11-2001', 'dd-mm-yyyy'), '2', '06', '310', '11', '2001', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (677, to_date('07-11-2001', 'dd-mm-yyyy'), '3', '07', '311', '11', '2001', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (678, to_date('08-11-2001', 'dd-mm-yyyy'), '4', '08', '312', '11', '2001', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (679, to_date('09-11-2001', 'dd-mm-yyyy'), '5', '09', '313', '11', '2001', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (680, to_date('10-11-2001', 'dd-mm-yyyy'), '6', '10', '314', '11', '2001', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (681, to_date('11-11-2001', 'dd-mm-yyyy'), '7', '11', '315', '11', '2001', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (682, to_date('12-11-2001', 'dd-mm-yyyy'), '1', '12', '316', '11', '2001', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (683, to_date('13-11-2001', 'dd-mm-yyyy'), '2', '13', '317', '11', '2001', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (684, to_date('14-11-2001', 'dd-mm-yyyy'), '3', '14', '318', '11', '2001', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (685, to_date('15-11-2001', 'dd-mm-yyyy'), '4', '15', '319', '11', '2001', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (686, to_date('16-11-2001', 'dd-mm-yyyy'), '5', '16', '320', '11', '2001', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (687, to_date('17-11-2001', 'dd-mm-yyyy'), '6', '17', '321', '11', '2001', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (688, to_date('18-11-2001', 'dd-mm-yyyy'), '7', '18', '322', '11', '2001', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (689, to_date('19-11-2001', 'dd-mm-yyyy'), '1', '19', '323', '11', '2001', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (690, to_date('20-11-2001', 'dd-mm-yyyy'), '2', '20', '324', '11', '2001', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (691, to_date('21-11-2001', 'dd-mm-yyyy'), '3', '21', '325', '11', '2001', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (692, to_date('22-11-2001', 'dd-mm-yyyy'), '4', '22', '326', '11', '2001', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (693, to_date('23-11-2001', 'dd-mm-yyyy'), '5', '23', '327', '11', '2001', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (694, to_date('24-11-2001', 'dd-mm-yyyy'), '6', '24', '328', '11', '2001', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (695, to_date('25-11-2001', 'dd-mm-yyyy'), '7', '25', '329', '11', '2001', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (696, to_date('26-11-2001', 'dd-mm-yyyy'), '1', '26', '330', '11', '2001', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (697, to_date('27-11-2001', 'dd-mm-yyyy'), '2', '27', '331', '11', '2001', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (698, to_date('28-11-2001', 'dd-mm-yyyy'), '3', '28', '332', '11', '2001', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (699, to_date('29-11-2001', 'dd-mm-yyyy'), '4', '29', '333', '11', '2001', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (700, to_date('30-11-2001', 'dd-mm-yyyy'), '5', '30', '334', '11', '2001', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (701, to_date('01-12-2001', 'dd-mm-yyyy'), '6', '01', '335', '12', '2001', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (702, to_date('02-12-2001', 'dd-mm-yyyy'), '7', '02', '336', '12', '2001', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (703, to_date('03-12-2001', 'dd-mm-yyyy'), '1', '03', '337', '12', '2001', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (704, to_date('04-12-2001', 'dd-mm-yyyy'), '2', '04', '338', '12', '2001', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (705, to_date('05-12-2001', 'dd-mm-yyyy'), '3', '05', '339', '12', '2001', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (706, to_date('06-12-2001', 'dd-mm-yyyy'), '4', '06', '340', '12', '2001', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (707, to_date('07-12-2001', 'dd-mm-yyyy'), '5', '07', '341', '12', '2001', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (708, to_date('08-12-2001', 'dd-mm-yyyy'), '6', '08', '342', '12', '2001', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (709, to_date('09-12-2001', 'dd-mm-yyyy'), '7', '09', '343', '12', '2001', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (710, to_date('10-12-2001', 'dd-mm-yyyy'), '1', '10', '344', '12', '2001', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (711, to_date('11-12-2001', 'dd-mm-yyyy'), '2', '11', '345', '12', '2001', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (712, to_date('12-12-2001', 'dd-mm-yyyy'), '3', '12', '346', '12', '2001', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (713, to_date('13-12-2001', 'dd-mm-yyyy'), '4', '13', '347', '12', '2001', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (714, to_date('14-12-2001', 'dd-mm-yyyy'), '5', '14', '348', '12', '2001', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (715, to_date('15-12-2001', 'dd-mm-yyyy'), '6', '15', '349', '12', '2001', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (716, to_date('16-12-2001', 'dd-mm-yyyy'), '7', '16', '350', '12', '2001', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (717, to_date('17-12-2001', 'dd-mm-yyyy'), '1', '17', '351', '12', '2001', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (718, to_date('18-12-2001', 'dd-mm-yyyy'), '2', '18', '352', '12', '2001', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (719, to_date('19-12-2001', 'dd-mm-yyyy'), '3', '19', '353', '12', '2001', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (720, to_date('20-12-2001', 'dd-mm-yyyy'), '4', '20', '354', '12', '2001', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (721, to_date('21-12-2001', 'dd-mm-yyyy'), '5', '21', '355', '12', '2001', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (722, to_date('22-12-2001', 'dd-mm-yyyy'), '6', '22', '356', '12', '2001', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (723, to_date('23-12-2001', 'dd-mm-yyyy'), '7', '23', '357', '12', '2001', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (724, to_date('24-12-2001', 'dd-mm-yyyy'), '1', '24', '358', '12', '2001', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (725, to_date('25-12-2001', 'dd-mm-yyyy'), '2', '25', '359', '12', '2001', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (726, to_date('26-12-2001', 'dd-mm-yyyy'), '3', '26', '360', '12', '2001', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (727, to_date('27-12-2001', 'dd-mm-yyyy'), '4', '27', '361', '12', '2001', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (728, to_date('28-12-2001', 'dd-mm-yyyy'), '5', '28', '362', '12', '2001', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (729, to_date('29-12-2001', 'dd-mm-yyyy'), '6', '29', '363', '12', '2001', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (730, to_date('30-12-2001', 'dd-mm-yyyy'), '7', '30', '364', '12', '2001', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (731, to_date('31-12-2001', 'dd-mm-yyyy'), '1', '31', '365', '12', '2001', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (732, to_date('01-01-2002', 'dd-mm-yyyy'), '2', '01', '001', '01', '2002', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (733, to_date('02-01-2002', 'dd-mm-yyyy'), '3', '02', '002', '01', '2002', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (734, to_date('03-01-2002', 'dd-mm-yyyy'), '4', '03', '003', '01', '2002', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (735, to_date('04-01-2002', 'dd-mm-yyyy'), '5', '04', '004', '01', '2002', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (736, to_date('05-01-2002', 'dd-mm-yyyy'), '6', '05', '005', '01', '2002', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (737, to_date('06-01-2002', 'dd-mm-yyyy'), '7', '06', '006', '01', '2002', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (738, to_date('07-01-2002', 'dd-mm-yyyy'), '1', '07', '007', '01', '2002', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (739, to_date('08-01-2002', 'dd-mm-yyyy'), '2', '08', '008', '01', '2002', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (740, to_date('09-01-2002', 'dd-mm-yyyy'), '3', '09', '009', '01', '2002', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (741, to_date('10-01-2002', 'dd-mm-yyyy'), '4', '10', '010', '01', '2002', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (742, to_date('11-01-2002', 'dd-mm-yyyy'), '5', '11', '011', '01', '2002', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (743, to_date('12-01-2002', 'dd-mm-yyyy'), '6', '12', '012', '01', '2002', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (744, to_date('13-01-2002', 'dd-mm-yyyy'), '7', '13', '013', '01', '2002', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (745, to_date('14-01-2002', 'dd-mm-yyyy'), '1', '14', '014', '01', '2002', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (746, to_date('15-01-2002', 'dd-mm-yyyy'), '2', '15', '015', '01', '2002', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (747, to_date('16-01-2002', 'dd-mm-yyyy'), '3', '16', '016', '01', '2002', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (748, to_date('17-01-2002', 'dd-mm-yyyy'), '4', '17', '017', '01', '2002', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (749, to_date('18-01-2002', 'dd-mm-yyyy'), '5', '18', '018', '01', '2002', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (750, to_date('19-01-2002', 'dd-mm-yyyy'), '6', '19', '019', '01', '2002', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (751, to_date('20-01-2002', 'dd-mm-yyyy'), '7', '20', '020', '01', '2002', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (752, to_date('21-01-2002', 'dd-mm-yyyy'), '1', '21', '021', '01', '2002', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (753, to_date('22-01-2002', 'dd-mm-yyyy'), '2', '22', '022', '01', '2002', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (754, to_date('23-01-2002', 'dd-mm-yyyy'), '3', '23', '023', '01', '2002', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (755, to_date('24-01-2002', 'dd-mm-yyyy'), '4', '24', '024', '01', '2002', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (756, to_date('25-01-2002', 'dd-mm-yyyy'), '5', '25', '025', '01', '2002', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (757, to_date('26-01-2002', 'dd-mm-yyyy'), '6', '26', '026', '01', '2002', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (758, to_date('27-01-2002', 'dd-mm-yyyy'), '7', '27', '027', '01', '2002', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (759, to_date('28-01-2002', 'dd-mm-yyyy'), '1', '28', '028', '01', '2002', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (760, to_date('29-01-2002', 'dd-mm-yyyy'), '2', '29', '029', '01', '2002', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (761, to_date('30-01-2002', 'dd-mm-yyyy'), '3', '30', '030', '01', '2002', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (762, to_date('31-01-2002', 'dd-mm-yyyy'), '4', '31', '031', '01', '2002', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (763, to_date('01-02-2002', 'dd-mm-yyyy'), '5', '01', '032', '02', '2002', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (764, to_date('02-02-2002', 'dd-mm-yyyy'), '6', '02', '033', '02', '2002', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (765, to_date('03-02-2002', 'dd-mm-yyyy'), '7', '03', '034', '02', '2002', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (766, to_date('04-02-2002', 'dd-mm-yyyy'), '1', '04', '035', '02', '2002', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (767, to_date('05-02-2002', 'dd-mm-yyyy'), '2', '05', '036', '02', '2002', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (768, to_date('06-02-2002', 'dd-mm-yyyy'), '3', '06', '037', '02', '2002', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (769, to_date('07-02-2002', 'dd-mm-yyyy'), '4', '07', '038', '02', '2002', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (770, to_date('08-02-2002', 'dd-mm-yyyy'), '5', '08', '039', '02', '2002', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (771, to_date('09-02-2002', 'dd-mm-yyyy'), '6', '09', '040', '02', '2002', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (772, to_date('10-02-2002', 'dd-mm-yyyy'), '7', '10', '041', '02', '2002', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (773, to_date('11-02-2002', 'dd-mm-yyyy'), '1', '11', '042', '02', '2002', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (774, to_date('12-02-2002', 'dd-mm-yyyy'), '2', '12', '043', '02', '2002', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (775, to_date('13-02-2002', 'dd-mm-yyyy'), '3', '13', '044', '02', '2002', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (776, to_date('14-02-2002', 'dd-mm-yyyy'), '4', '14', '045', '02', '2002', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (777, to_date('15-02-2002', 'dd-mm-yyyy'), '5', '15', '046', '02', '2002', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (778, to_date('16-02-2002', 'dd-mm-yyyy'), '6', '16', '047', '02', '2002', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (779, to_date('17-02-2002', 'dd-mm-yyyy'), '7', '17', '048', '02', '2002', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (780, to_date('18-02-2002', 'dd-mm-yyyy'), '1', '18', '049', '02', '2002', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (781, to_date('19-02-2002', 'dd-mm-yyyy'), '2', '19', '050', '02', '2002', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (782, to_date('20-02-2002', 'dd-mm-yyyy'), '3', '20', '051', '02', '2002', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (783, to_date('21-02-2002', 'dd-mm-yyyy'), '4', '21', '052', '02', '2002', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (784, to_date('22-02-2002', 'dd-mm-yyyy'), '5', '22', '053', '02', '2002', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (785, to_date('23-02-2002', 'dd-mm-yyyy'), '6', '23', '054', '02', '2002', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (786, to_date('24-02-2002', 'dd-mm-yyyy'), '7', '24', '055', '02', '2002', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (787, to_date('25-02-2002', 'dd-mm-yyyy'), '1', '25', '056', '02', '2002', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (788, to_date('26-02-2002', 'dd-mm-yyyy'), '2', '26', '057', '02', '2002', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (789, to_date('27-02-2002', 'dd-mm-yyyy'), '3', '27', '058', '02', '2002', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (790, to_date('28-02-2002', 'dd-mm-yyyy'), '4', '28', '059', '02', '2002', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (791, to_date('01-03-2002', 'dd-mm-yyyy'), '5', '01', '060', '03', '2002', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (792, to_date('02-03-2002', 'dd-mm-yyyy'), '6', '02', '061', '03', '2002', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (793, to_date('03-03-2002', 'dd-mm-yyyy'), '7', '03', '062', '03', '2002', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (794, to_date('04-03-2002', 'dd-mm-yyyy'), '1', '04', '063', '03', '2002', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (795, to_date('05-03-2002', 'dd-mm-yyyy'), '2', '05', '064', '03', '2002', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (796, to_date('06-03-2002', 'dd-mm-yyyy'), '3', '06', '065', '03', '2002', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (797, to_date('07-03-2002', 'dd-mm-yyyy'), '4', '07', '066', '03', '2002', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (798, to_date('08-03-2002', 'dd-mm-yyyy'), '5', '08', '067', '03', '2002', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (799, to_date('09-03-2002', 'dd-mm-yyyy'), '6', '09', '068', '03', '2002', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (800, to_date('10-03-2002', 'dd-mm-yyyy'), '7', '10', '069', '03', '2002', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (801, to_date('11-03-2002', 'dd-mm-yyyy'), '1', '11', '070', '03', '2002', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (802, to_date('12-03-2002', 'dd-mm-yyyy'), '2', '12', '071', '03', '2002', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (803, to_date('13-03-2002', 'dd-mm-yyyy'), '3', '13', '072', '03', '2002', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (804, to_date('14-03-2002', 'dd-mm-yyyy'), '4', '14', '073', '03', '2002', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (805, to_date('15-03-2002', 'dd-mm-yyyy'), '5', '15', '074', '03', '2002', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (806, to_date('16-03-2002', 'dd-mm-yyyy'), '6', '16', '075', '03', '2002', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (807, to_date('17-03-2002', 'dd-mm-yyyy'), '7', '17', '076', '03', '2002', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (808, to_date('18-03-2002', 'dd-mm-yyyy'), '1', '18', '077', '03', '2002', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (809, to_date('19-03-2002', 'dd-mm-yyyy'), '2', '19', '078', '03', '2002', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (810, to_date('20-03-2002', 'dd-mm-yyyy'), '3', '20', '079', '03', '2002', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (811, to_date('21-03-2002', 'dd-mm-yyyy'), '4', '21', '080', '03', '2002', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (812, to_date('22-03-2002', 'dd-mm-yyyy'), '5', '22', '081', '03', '2002', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (813, to_date('23-03-2002', 'dd-mm-yyyy'), '6', '23', '082', '03', '2002', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (814, to_date('24-03-2002', 'dd-mm-yyyy'), '7', '24', '083', '03', '2002', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (815, to_date('25-03-2002', 'dd-mm-yyyy'), '1', '25', '084', '03', '2002', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (816, to_date('26-03-2002', 'dd-mm-yyyy'), '2', '26', '085', '03', '2002', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (817, to_date('27-03-2002', 'dd-mm-yyyy'), '3', '27', '086', '03', '2002', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (818, to_date('28-03-2002', 'dd-mm-yyyy'), '4', '28', '087', '03', '2002', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (819, to_date('29-03-2002', 'dd-mm-yyyy'), '5', '29', '088', '03', '2002', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (820, to_date('30-03-2002', 'dd-mm-yyyy'), '6', '30', '089', '03', '2002', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (821, to_date('31-03-2002', 'dd-mm-yyyy'), '7', '31', '090', '03', '2002', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (822, to_date('01-04-2002', 'dd-mm-yyyy'), '1', '01', '091', '04', '2002', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (823, to_date('02-04-2002', 'dd-mm-yyyy'), '2', '02', '092', '04', '2002', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (824, to_date('03-04-2002', 'dd-mm-yyyy'), '3', '03', '093', '04', '2002', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (825, to_date('04-04-2002', 'dd-mm-yyyy'), '4', '04', '094', '04', '2002', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (826, to_date('05-04-2002', 'dd-mm-yyyy'), '5', '05', '095', '04', '2002', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (827, to_date('06-04-2002', 'dd-mm-yyyy'), '6', '06', '096', '04', '2002', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (828, to_date('07-04-2002', 'dd-mm-yyyy'), '7', '07', '097', '04', '2002', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (829, to_date('08-04-2002', 'dd-mm-yyyy'), '1', '08', '098', '04', '2002', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (830, to_date('09-04-2002', 'dd-mm-yyyy'), '2', '09', '099', '04', '2002', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (831, to_date('10-04-2002', 'dd-mm-yyyy'), '3', '10', '100', '04', '2002', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (832, to_date('11-04-2002', 'dd-mm-yyyy'), '4', '11', '101', '04', '2002', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (833, to_date('12-04-2002', 'dd-mm-yyyy'), '5', '12', '102', '04', '2002', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (834, to_date('13-04-2002', 'dd-mm-yyyy'), '6', '13', '103', '04', '2002', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (835, to_date('14-04-2002', 'dd-mm-yyyy'), '7', '14', '104', '04', '2002', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (836, to_date('15-04-2002', 'dd-mm-yyyy'), '1', '15', '105', '04', '2002', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (837, to_date('16-04-2002', 'dd-mm-yyyy'), '2', '16', '106', '04', '2002', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (838, to_date('17-04-2002', 'dd-mm-yyyy'), '3', '17', '107', '04', '2002', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (839, to_date('18-04-2002', 'dd-mm-yyyy'), '4', '18', '108', '04', '2002', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (840, to_date('19-04-2002', 'dd-mm-yyyy'), '5', '19', '109', '04', '2002', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
commit;
prompt 3000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (841, to_date('20-04-2002', 'dd-mm-yyyy'), '6', '20', '110', '04', '2002', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (842, to_date('21-04-2002', 'dd-mm-yyyy'), '7', '21', '111', '04', '2002', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (843, to_date('22-04-2002', 'dd-mm-yyyy'), '1', '22', '112', '04', '2002', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (844, to_date('23-04-2002', 'dd-mm-yyyy'), '2', '23', '113', '04', '2002', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (845, to_date('24-04-2002', 'dd-mm-yyyy'), '3', '24', '114', '04', '2002', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (846, to_date('25-04-2002', 'dd-mm-yyyy'), '4', '25', '115', '04', '2002', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (847, to_date('26-04-2002', 'dd-mm-yyyy'), '5', '26', '116', '04', '2002', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (848, to_date('27-04-2002', 'dd-mm-yyyy'), '6', '27', '117', '04', '2002', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (849, to_date('28-04-2002', 'dd-mm-yyyy'), '7', '28', '118', '04', '2002', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (850, to_date('29-04-2002', 'dd-mm-yyyy'), '1', '29', '119', '04', '2002', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (851, to_date('30-04-2002', 'dd-mm-yyyy'), '2', '30', '120', '04', '2002', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (852, to_date('01-05-2002', 'dd-mm-yyyy'), '3', '01', '121', '05', '2002', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (853, to_date('02-05-2002', 'dd-mm-yyyy'), '4', '02', '122', '05', '2002', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (854, to_date('03-05-2002', 'dd-mm-yyyy'), '5', '03', '123', '05', '2002', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (855, to_date('04-05-2002', 'dd-mm-yyyy'), '6', '04', '124', '05', '2002', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (856, to_date('05-05-2002', 'dd-mm-yyyy'), '7', '05', '125', '05', '2002', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (857, to_date('06-05-2002', 'dd-mm-yyyy'), '1', '06', '126', '05', '2002', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (858, to_date('07-05-2002', 'dd-mm-yyyy'), '2', '07', '127', '05', '2002', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (859, to_date('08-05-2002', 'dd-mm-yyyy'), '3', '08', '128', '05', '2002', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (860, to_date('09-05-2002', 'dd-mm-yyyy'), '4', '09', '129', '05', '2002', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (861, to_date('10-05-2002', 'dd-mm-yyyy'), '5', '10', '130', '05', '2002', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (862, to_date('11-05-2002', 'dd-mm-yyyy'), '6', '11', '131', '05', '2002', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (863, to_date('12-05-2002', 'dd-mm-yyyy'), '7', '12', '132', '05', '2002', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (864, to_date('13-05-2002', 'dd-mm-yyyy'), '1', '13', '133', '05', '2002', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (865, to_date('14-05-2002', 'dd-mm-yyyy'), '2', '14', '134', '05', '2002', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2486, to_date('21-10-2006', 'dd-mm-yyyy'), '6', '21', '294', '10', '2006', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2487, to_date('22-10-2006', 'dd-mm-yyyy'), '7', '22', '295', '10', '2006', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2488, to_date('23-10-2006', 'dd-mm-yyyy'), '1', '23', '296', '10', '2006', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2489, to_date('24-10-2006', 'dd-mm-yyyy'), '2', '24', '297', '10', '2006', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2490, to_date('25-10-2006', 'dd-mm-yyyy'), '3', '25', '298', '10', '2006', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2491, to_date('26-10-2006', 'dd-mm-yyyy'), '4', '26', '299', '10', '2006', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2492, to_date('27-10-2006', 'dd-mm-yyyy'), '5', '27', '300', '10', '2006', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2493, to_date('28-10-2006', 'dd-mm-yyyy'), '6', '28', '301', '10', '2006', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2494, to_date('29-10-2006', 'dd-mm-yyyy'), '7', '29', '302', '10', '2006', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2495, to_date('30-10-2006', 'dd-mm-yyyy'), '1', '30', '303', '10', '2006', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2496, to_date('31-10-2006', 'dd-mm-yyyy'), '2', '31', '304', '10', '2006', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2497, to_date('01-11-2006', 'dd-mm-yyyy'), '3', '01', '305', '11', '2006', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2498, to_date('02-11-2006', 'dd-mm-yyyy'), '4', '02', '306', '11', '2006', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2499, to_date('03-11-2006', 'dd-mm-yyyy'), '5', '03', '307', '11', '2006', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2500, to_date('04-11-2006', 'dd-mm-yyyy'), '6', '04', '308', '11', '2006', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2501, to_date('05-11-2006', 'dd-mm-yyyy'), '7', '05', '309', '11', '2006', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2502, to_date('06-11-2006', 'dd-mm-yyyy'), '1', '06', '310', '11', '2006', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2503, to_date('07-11-2006', 'dd-mm-yyyy'), '2', '07', '311', '11', '2006', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2504, to_date('08-11-2006', 'dd-mm-yyyy'), '3', '08', '312', '11', '2006', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2505, to_date('09-11-2006', 'dd-mm-yyyy'), '4', '09', '313', '11', '2006', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2506, to_date('10-11-2006', 'dd-mm-yyyy'), '5', '10', '314', '11', '2006', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2507, to_date('11-11-2006', 'dd-mm-yyyy'), '6', '11', '315', '11', '2006', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2508, to_date('12-11-2006', 'dd-mm-yyyy'), '7', '12', '316', '11', '2006', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2509, to_date('13-11-2006', 'dd-mm-yyyy'), '1', '13', '317', '11', '2006', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2510, to_date('14-11-2006', 'dd-mm-yyyy'), '2', '14', '318', '11', '2006', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2511, to_date('15-11-2006', 'dd-mm-yyyy'), '3', '15', '319', '11', '2006', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2512, to_date('16-11-2006', 'dd-mm-yyyy'), '4', '16', '320', '11', '2006', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2513, to_date('17-11-2006', 'dd-mm-yyyy'), '5', '17', '321', '11', '2006', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2514, to_date('18-11-2006', 'dd-mm-yyyy'), '6', '18', '322', '11', '2006', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2515, to_date('19-11-2006', 'dd-mm-yyyy'), '7', '19', '323', '11', '2006', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2516, to_date('20-11-2006', 'dd-mm-yyyy'), '1', '20', '324', '11', '2006', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2517, to_date('21-11-2006', 'dd-mm-yyyy'), '2', '21', '325', '11', '2006', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2518, to_date('22-11-2006', 'dd-mm-yyyy'), '3', '22', '326', '11', '2006', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2519, to_date('23-11-2006', 'dd-mm-yyyy'), '4', '23', '327', '11', '2006', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2520, to_date('24-11-2006', 'dd-mm-yyyy'), '5', '24', '328', '11', '2006', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2521, to_date('25-11-2006', 'dd-mm-yyyy'), '6', '25', '329', '11', '2006', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2522, to_date('26-11-2006', 'dd-mm-yyyy'), '7', '26', '330', '11', '2006', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2523, to_date('27-11-2006', 'dd-mm-yyyy'), '1', '27', '331', '11', '2006', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2524, to_date('28-11-2006', 'dd-mm-yyyy'), '2', '28', '332', '11', '2006', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2525, to_date('29-11-2006', 'dd-mm-yyyy'), '3', '29', '333', '11', '2006', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2526, to_date('30-11-2006', 'dd-mm-yyyy'), '4', '30', '334', '11', '2006', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2527, to_date('01-12-2006', 'dd-mm-yyyy'), '5', '01', '335', '12', '2006', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2528, to_date('02-12-2006', 'dd-mm-yyyy'), '6', '02', '336', '12', '2006', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2529, to_date('03-12-2006', 'dd-mm-yyyy'), '7', '03', '337', '12', '2006', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2530, to_date('04-12-2006', 'dd-mm-yyyy'), '1', '04', '338', '12', '2006', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2531, to_date('05-12-2006', 'dd-mm-yyyy'), '2', '05', '339', '12', '2006', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2532, to_date('06-12-2006', 'dd-mm-yyyy'), '3', '06', '340', '12', '2006', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2533, to_date('07-12-2006', 'dd-mm-yyyy'), '4', '07', '341', '12', '2006', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2534, to_date('08-12-2006', 'dd-mm-yyyy'), '5', '08', '342', '12', '2006', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2535, to_date('09-12-2006', 'dd-mm-yyyy'), '6', '09', '343', '12', '2006', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2536, to_date('10-12-2006', 'dd-mm-yyyy'), '7', '10', '344', '12', '2006', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2537, to_date('11-12-2006', 'dd-mm-yyyy'), '1', '11', '345', '12', '2006', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2538, to_date('12-12-2006', 'dd-mm-yyyy'), '2', '12', '346', '12', '2006', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2539, to_date('13-12-2006', 'dd-mm-yyyy'), '3', '13', '347', '12', '2006', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2540, to_date('14-12-2006', 'dd-mm-yyyy'), '4', '14', '348', '12', '2006', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2541, to_date('15-12-2006', 'dd-mm-yyyy'), '5', '15', '349', '12', '2006', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2542, to_date('16-12-2006', 'dd-mm-yyyy'), '6', '16', '350', '12', '2006', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2543, to_date('17-12-2006', 'dd-mm-yyyy'), '7', '17', '351', '12', '2006', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2544, to_date('18-12-2006', 'dd-mm-yyyy'), '1', '18', '352', '12', '2006', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2545, to_date('19-12-2006', 'dd-mm-yyyy'), '2', '19', '353', '12', '2006', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2546, to_date('20-12-2006', 'dd-mm-yyyy'), '3', '20', '354', '12', '2006', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2547, to_date('21-12-2006', 'dd-mm-yyyy'), '4', '21', '355', '12', '2006', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2548, to_date('22-12-2006', 'dd-mm-yyyy'), '5', '22', '356', '12', '2006', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2549, to_date('23-12-2006', 'dd-mm-yyyy'), '6', '23', '357', '12', '2006', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2550, to_date('24-12-2006', 'dd-mm-yyyy'), '7', '24', '358', '12', '2006', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2551, to_date('25-12-2006', 'dd-mm-yyyy'), '1', '25', '359', '12', '2006', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2552, to_date('26-12-2006', 'dd-mm-yyyy'), '2', '26', '360', '12', '2006', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2553, to_date('27-12-2006', 'dd-mm-yyyy'), '3', '27', '361', '12', '2006', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2554, to_date('28-12-2006', 'dd-mm-yyyy'), '4', '28', '362', '12', '2006', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2555, to_date('29-12-2006', 'dd-mm-yyyy'), '5', '29', '363', '12', '2006', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2556, to_date('30-12-2006', 'dd-mm-yyyy'), '6', '30', '364', '12', '2006', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2557, to_date('31-12-2006', 'dd-mm-yyyy'), '7', '31', '365', '12', '2006', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2558, to_date('01-01-2007', 'dd-mm-yyyy'), '1', '01', '001', '01', '2007', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2559, to_date('02-01-2007', 'dd-mm-yyyy'), '2', '02', '002', '01', '2007', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2560, to_date('03-01-2007', 'dd-mm-yyyy'), '3', '03', '003', '01', '2007', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2561, to_date('04-01-2007', 'dd-mm-yyyy'), '4', '04', '004', '01', '2007', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2562, to_date('05-01-2007', 'dd-mm-yyyy'), '5', '05', '005', '01', '2007', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2563, to_date('06-01-2007', 'dd-mm-yyyy'), '6', '06', '006', '01', '2007', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2564, to_date('07-01-2007', 'dd-mm-yyyy'), '7', '07', '007', '01', '2007', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2565, to_date('08-01-2007', 'dd-mm-yyyy'), '1', '08', '008', '01', '2007', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2566, to_date('09-01-2007', 'dd-mm-yyyy'), '2', '09', '009', '01', '2007', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2567, to_date('10-01-2007', 'dd-mm-yyyy'), '3', '10', '010', '01', '2007', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2568, to_date('11-01-2007', 'dd-mm-yyyy'), '4', '11', '011', '01', '2007', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2569, to_date('12-01-2007', 'dd-mm-yyyy'), '5', '12', '012', '01', '2007', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2570, to_date('13-01-2007', 'dd-mm-yyyy'), '6', '13', '013', '01', '2007', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2571, to_date('14-01-2007', 'dd-mm-yyyy'), '7', '14', '014', '01', '2007', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2572, to_date('15-01-2007', 'dd-mm-yyyy'), '1', '15', '015', '01', '2007', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2573, to_date('16-01-2007', 'dd-mm-yyyy'), '2', '16', '016', '01', '2007', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2574, to_date('17-01-2007', 'dd-mm-yyyy'), '3', '17', '017', '01', '2007', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2575, to_date('18-01-2007', 'dd-mm-yyyy'), '4', '18', '018', '01', '2007', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2576, to_date('19-01-2007', 'dd-mm-yyyy'), '5', '19', '019', '01', '2007', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2577, to_date('20-01-2007', 'dd-mm-yyyy'), '6', '20', '020', '01', '2007', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2578, to_date('21-01-2007', 'dd-mm-yyyy'), '7', '21', '021', '01', '2007', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2579, to_date('22-01-2007', 'dd-mm-yyyy'), '1', '22', '022', '01', '2007', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2580, to_date('23-01-2007', 'dd-mm-yyyy'), '2', '23', '023', '01', '2007', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2581, to_date('24-01-2007', 'dd-mm-yyyy'), '3', '24', '024', '01', '2007', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2582, to_date('25-01-2007', 'dd-mm-yyyy'), '4', '25', '025', '01', '2007', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2583, to_date('26-01-2007', 'dd-mm-yyyy'), '5', '26', '026', '01', '2007', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2584, to_date('27-01-2007', 'dd-mm-yyyy'), '6', '27', '027', '01', '2007', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2585, to_date('28-01-2007', 'dd-mm-yyyy'), '7', '28', '028', '01', '2007', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2586, to_date('29-01-2007', 'dd-mm-yyyy'), '1', '29', '029', '01', '2007', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2587, to_date('30-01-2007', 'dd-mm-yyyy'), '2', '30', '030', '01', '2007', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2588, to_date('31-01-2007', 'dd-mm-yyyy'), '3', '31', '031', '01', '2007', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2589, to_date('01-02-2007', 'dd-mm-yyyy'), '4', '01', '032', '02', '2007', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2590, to_date('02-02-2007', 'dd-mm-yyyy'), '5', '02', '033', '02', '2007', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2591, to_date('03-02-2007', 'dd-mm-yyyy'), '6', '03', '034', '02', '2007', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2592, to_date('04-02-2007', 'dd-mm-yyyy'), '7', '04', '035', '02', '2007', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2593, to_date('05-02-2007', 'dd-mm-yyyy'), '1', '05', '036', '02', '2007', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2594, to_date('06-02-2007', 'dd-mm-yyyy'), '2', '06', '037', '02', '2007', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2595, to_date('07-02-2007', 'dd-mm-yyyy'), '3', '07', '038', '02', '2007', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2596, to_date('08-02-2007', 'dd-mm-yyyy'), '4', '08', '039', '02', '2007', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2597, to_date('09-02-2007', 'dd-mm-yyyy'), '5', '09', '040', '02', '2007', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2598, to_date('10-02-2007', 'dd-mm-yyyy'), '6', '10', '041', '02', '2007', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2599, to_date('11-02-2007', 'dd-mm-yyyy'), '7', '11', '042', '02', '2007', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2600, to_date('12-02-2007', 'dd-mm-yyyy'), '1', '12', '043', '02', '2007', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2601, to_date('13-02-2007', 'dd-mm-yyyy'), '2', '13', '044', '02', '2007', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2602, to_date('14-02-2007', 'dd-mm-yyyy'), '3', '14', '045', '02', '2007', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2603, to_date('15-02-2007', 'dd-mm-yyyy'), '4', '15', '046', '02', '2007', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2604, to_date('16-02-2007', 'dd-mm-yyyy'), '5', '16', '047', '02', '2007', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2605, to_date('17-02-2007', 'dd-mm-yyyy'), '6', '17', '048', '02', '2007', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2606, to_date('18-02-2007', 'dd-mm-yyyy'), '7', '18', '049', '02', '2007', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2607, to_date('19-02-2007', 'dd-mm-yyyy'), '1', '19', '050', '02', '2007', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2608, to_date('20-02-2007', 'dd-mm-yyyy'), '2', '20', '051', '02', '2007', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2609, to_date('21-02-2007', 'dd-mm-yyyy'), '3', '21', '052', '02', '2007', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2610, to_date('22-02-2007', 'dd-mm-yyyy'), '4', '22', '053', '02', '2007', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2611, to_date('23-02-2007', 'dd-mm-yyyy'), '5', '23', '054', '02', '2007', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2612, to_date('24-02-2007', 'dd-mm-yyyy'), '6', '24', '055', '02', '2007', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2613, to_date('25-02-2007', 'dd-mm-yyyy'), '7', '25', '056', '02', '2007', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2614, to_date('26-02-2007', 'dd-mm-yyyy'), '1', '26', '057', '02', '2007', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2615, to_date('27-02-2007', 'dd-mm-yyyy'), '2', '27', '058', '02', '2007', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2616, to_date('28-02-2007', 'dd-mm-yyyy'), '3', '28', '059', '02', '2007', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2617, to_date('01-03-2007', 'dd-mm-yyyy'), '4', '01', '060', '03', '2007', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2618, to_date('02-03-2007', 'dd-mm-yyyy'), '5', '02', '061', '03', '2007', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2619, to_date('03-03-2007', 'dd-mm-yyyy'), '6', '03', '062', '03', '2007', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2620, to_date('04-03-2007', 'dd-mm-yyyy'), '7', '04', '063', '03', '2007', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2621, to_date('05-03-2007', 'dd-mm-yyyy'), '1', '05', '064', '03', '2007', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2622, to_date('06-03-2007', 'dd-mm-yyyy'), '2', '06', '065', '03', '2007', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2623, to_date('07-03-2007', 'dd-mm-yyyy'), '3', '07', '066', '03', '2007', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2624, to_date('08-03-2007', 'dd-mm-yyyy'), '4', '08', '067', '03', '2007', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2625, to_date('09-03-2007', 'dd-mm-yyyy'), '5', '09', '068', '03', '2007', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2626, to_date('10-03-2007', 'dd-mm-yyyy'), '6', '10', '069', '03', '2007', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2627, to_date('11-03-2007', 'dd-mm-yyyy'), '7', '11', '070', '03', '2007', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2628, to_date('12-03-2007', 'dd-mm-yyyy'), '1', '12', '071', '03', '2007', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2629, to_date('13-03-2007', 'dd-mm-yyyy'), '2', '13', '072', '03', '2007', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2630, to_date('14-03-2007', 'dd-mm-yyyy'), '3', '14', '073', '03', '2007', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2631, to_date('15-03-2007', 'dd-mm-yyyy'), '4', '15', '074', '03', '2007', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2632, to_date('16-03-2007', 'dd-mm-yyyy'), '5', '16', '075', '03', '2007', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2633, to_date('17-03-2007', 'dd-mm-yyyy'), '6', '17', '076', '03', '2007', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2634, to_date('18-03-2007', 'dd-mm-yyyy'), '7', '18', '077', '03', '2007', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2635, to_date('19-03-2007', 'dd-mm-yyyy'), '1', '19', '078', '03', '2007', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2636, to_date('20-03-2007', 'dd-mm-yyyy'), '2', '20', '079', '03', '2007', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2637, to_date('21-03-2007', 'dd-mm-yyyy'), '3', '21', '080', '03', '2007', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2638, to_date('22-03-2007', 'dd-mm-yyyy'), '4', '22', '081', '03', '2007', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2639, to_date('23-03-2007', 'dd-mm-yyyy'), '5', '23', '082', '03', '2007', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2640, to_date('24-03-2007', 'dd-mm-yyyy'), '6', '24', '083', '03', '2007', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2641, to_date('25-03-2007', 'dd-mm-yyyy'), '7', '25', '084', '03', '2007', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2642, to_date('26-03-2007', 'dd-mm-yyyy'), '1', '26', '085', '03', '2007', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2643, to_date('27-03-2007', 'dd-mm-yyyy'), '2', '27', '086', '03', '2007', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2644, to_date('28-03-2007', 'dd-mm-yyyy'), '3', '28', '087', '03', '2007', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2645, to_date('29-03-2007', 'dd-mm-yyyy'), '4', '29', '088', '03', '2007', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2646, to_date('30-03-2007', 'dd-mm-yyyy'), '5', '30', '089', '03', '2007', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2647, to_date('31-03-2007', 'dd-mm-yyyy'), '6', '31', '090', '03', '2007', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2648, to_date('01-04-2007', 'dd-mm-yyyy'), '7', '01', '091', '04', '2007', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2649, to_date('02-04-2007', 'dd-mm-yyyy'), '1', '02', '092', '04', '2007', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2650, to_date('03-04-2007', 'dd-mm-yyyy'), '2', '03', '093', '04', '2007', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2651, to_date('04-04-2007', 'dd-mm-yyyy'), '3', '04', '094', '04', '2007', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2652, to_date('05-04-2007', 'dd-mm-yyyy'), '4', '05', '095', '04', '2007', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2653, to_date('06-04-2007', 'dd-mm-yyyy'), '5', '06', '096', '04', '2007', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2654, to_date('07-04-2007', 'dd-mm-yyyy'), '6', '07', '097', '04', '2007', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2655, to_date('08-04-2007', 'dd-mm-yyyy'), '7', '08', '098', '04', '2007', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2656, to_date('09-04-2007', 'dd-mm-yyyy'), '1', '09', '099', '04', '2007', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2657, to_date('10-04-2007', 'dd-mm-yyyy'), '2', '10', '100', '04', '2007', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2658, to_date('11-04-2007', 'dd-mm-yyyy'), '3', '11', '101', '04', '2007', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2659, to_date('12-04-2007', 'dd-mm-yyyy'), '4', '12', '102', '04', '2007', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2660, to_date('13-04-2007', 'dd-mm-yyyy'), '5', '13', '103', '04', '2007', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2661, to_date('14-04-2007', 'dd-mm-yyyy'), '6', '14', '104', '04', '2007', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2662, to_date('15-04-2007', 'dd-mm-yyyy'), '7', '15', '105', '04', '2007', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2663, to_date('16-04-2007', 'dd-mm-yyyy'), '1', '16', '106', '04', '2007', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2664, to_date('17-04-2007', 'dd-mm-yyyy'), '2', '17', '107', '04', '2007', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2665, to_date('18-04-2007', 'dd-mm-yyyy'), '3', '18', '108', '04', '2007', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2666, to_date('19-04-2007', 'dd-mm-yyyy'), '4', '19', '109', '04', '2007', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2667, to_date('20-04-2007', 'dd-mm-yyyy'), '5', '20', '110', '04', '2007', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2668, to_date('21-04-2007', 'dd-mm-yyyy'), '6', '21', '111', '04', '2007', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2669, to_date('22-04-2007', 'dd-mm-yyyy'), '7', '22', '112', '04', '2007', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2670, to_date('23-04-2007', 'dd-mm-yyyy'), '1', '23', '113', '04', '2007', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2671, to_date('24-04-2007', 'dd-mm-yyyy'), '2', '24', '114', '04', '2007', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2672, to_date('25-04-2007', 'dd-mm-yyyy'), '3', '25', '115', '04', '2007', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2673, to_date('26-04-2007', 'dd-mm-yyyy'), '4', '26', '116', '04', '2007', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2674, to_date('27-04-2007', 'dd-mm-yyyy'), '5', '27', '117', '04', '2007', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2675, to_date('28-04-2007', 'dd-mm-yyyy'), '6', '28', '118', '04', '2007', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2676, to_date('29-04-2007', 'dd-mm-yyyy'), '7', '29', '119', '04', '2007', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2677, to_date('30-04-2007', 'dd-mm-yyyy'), '1', '30', '120', '04', '2007', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2678, to_date('01-05-2007', 'dd-mm-yyyy'), '2', '01', '121', '05', '2007', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2679, to_date('02-05-2007', 'dd-mm-yyyy'), '3', '02', '122', '05', '2007', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2680, to_date('03-05-2007', 'dd-mm-yyyy'), '4', '03', '123', '05', '2007', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2681, to_date('04-05-2007', 'dd-mm-yyyy'), '5', '04', '124', '05', '2007', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2682, to_date('05-05-2007', 'dd-mm-yyyy'), '6', '05', '125', '05', '2007', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2683, to_date('06-05-2007', 'dd-mm-yyyy'), '7', '06', '126', '05', '2007', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2684, to_date('07-05-2007', 'dd-mm-yyyy'), '1', '07', '127', '05', '2007', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2685, to_date('08-05-2007', 'dd-mm-yyyy'), '2', '08', '128', '05', '2007', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2686, to_date('09-05-2007', 'dd-mm-yyyy'), '3', '09', '129', '05', '2007', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2687, to_date('10-05-2007', 'dd-mm-yyyy'), '4', '10', '130', '05', '2007', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2688, to_date('11-05-2007', 'dd-mm-yyyy'), '5', '11', '131', '05', '2007', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2689, to_date('12-05-2007', 'dd-mm-yyyy'), '6', '12', '132', '05', '2007', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2690, to_date('13-05-2007', 'dd-mm-yyyy'), '7', '13', '133', '05', '2007', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2691, to_date('14-05-2007', 'dd-mm-yyyy'), '1', '14', '134', '05', '2007', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2692, to_date('15-05-2007', 'dd-mm-yyyy'), '2', '15', '135', '05', '2007', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2693, to_date('16-05-2007', 'dd-mm-yyyy'), '3', '16', '136', '05', '2007', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2694, to_date('17-05-2007', 'dd-mm-yyyy'), '4', '17', '137', '05', '2007', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2695, to_date('18-05-2007', 'dd-mm-yyyy'), '5', '18', '138', '05', '2007', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2696, to_date('19-05-2007', 'dd-mm-yyyy'), '6', '19', '139', '05', '2007', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2697, to_date('20-05-2007', 'dd-mm-yyyy'), '7', '20', '140', '05', '2007', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2698, to_date('21-05-2007', 'dd-mm-yyyy'), '1', '21', '141', '05', '2007', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2699, to_date('22-05-2007', 'dd-mm-yyyy'), '2', '22', '142', '05', '2007', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2700, to_date('23-05-2007', 'dd-mm-yyyy'), '3', '23', '143', '05', '2007', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2701, to_date('24-05-2007', 'dd-mm-yyyy'), '4', '24', '144', '05', '2007', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2702, to_date('25-05-2007', 'dd-mm-yyyy'), '5', '25', '145', '05', '2007', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2703, to_date('26-05-2007', 'dd-mm-yyyy'), '6', '26', '146', '05', '2007', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2704, to_date('27-05-2007', 'dd-mm-yyyy'), '7', '27', '147', '05', '2007', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2705, to_date('28-05-2007', 'dd-mm-yyyy'), '1', '28', '148', '05', '2007', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2706, to_date('29-05-2007', 'dd-mm-yyyy'), '2', '29', '149', '05', '2007', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2707, to_date('30-05-2007', 'dd-mm-yyyy'), '3', '30', '150', '05', '2007', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2708, to_date('31-05-2007', 'dd-mm-yyyy'), '4', '31', '151', '05', '2007', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2709, to_date('01-06-2007', 'dd-mm-yyyy'), '5', '01', '152', '06', '2007', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2710, to_date('02-06-2007', 'dd-mm-yyyy'), '6', '02', '153', '06', '2007', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2711, to_date('03-06-2007', 'dd-mm-yyyy'), '7', '03', '154', '06', '2007', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2712, to_date('04-06-2007', 'dd-mm-yyyy'), '1', '04', '155', '06', '2007', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2713, to_date('05-06-2007', 'dd-mm-yyyy'), '2', '05', '156', '06', '2007', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2714, to_date('06-06-2007', 'dd-mm-yyyy'), '3', '06', '157', '06', '2007', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2715, to_date('07-06-2007', 'dd-mm-yyyy'), '4', '07', '158', '06', '2007', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2716, to_date('08-06-2007', 'dd-mm-yyyy'), '5', '08', '159', '06', '2007', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2717, to_date('09-06-2007', 'dd-mm-yyyy'), '6', '09', '160', '06', '2007', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2718, to_date('10-06-2007', 'dd-mm-yyyy'), '7', '10', '161', '06', '2007', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2719, to_date('11-06-2007', 'dd-mm-yyyy'), '1', '11', '162', '06', '2007', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2720, to_date('12-06-2007', 'dd-mm-yyyy'), '2', '12', '163', '06', '2007', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2721, to_date('13-06-2007', 'dd-mm-yyyy'), '3', '13', '164', '06', '2007', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2722, to_date('14-06-2007', 'dd-mm-yyyy'), '4', '14', '165', '06', '2007', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2723, to_date('15-06-2007', 'dd-mm-yyyy'), '5', '15', '166', '06', '2007', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2724, to_date('16-06-2007', 'dd-mm-yyyy'), '6', '16', '167', '06', '2007', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2725, to_date('17-06-2007', 'dd-mm-yyyy'), '7', '17', '168', '06', '2007', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2726, to_date('18-06-2007', 'dd-mm-yyyy'), '1', '18', '169', '06', '2007', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2727, to_date('19-06-2007', 'dd-mm-yyyy'), '2', '19', '170', '06', '2007', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2728, to_date('20-06-2007', 'dd-mm-yyyy'), '3', '20', '171', '06', '2007', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2729, to_date('21-06-2007', 'dd-mm-yyyy'), '4', '21', '172', '06', '2007', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2730, to_date('22-06-2007', 'dd-mm-yyyy'), '5', '22', '173', '06', '2007', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2731, to_date('23-06-2007', 'dd-mm-yyyy'), '6', '23', '174', '06', '2007', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2732, to_date('24-06-2007', 'dd-mm-yyyy'), '7', '24', '175', '06', '2007', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2733, to_date('25-06-2007', 'dd-mm-yyyy'), '1', '25', '176', '06', '2007', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2734, to_date('26-06-2007', 'dd-mm-yyyy'), '2', '26', '177', '06', '2007', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2735, to_date('27-06-2007', 'dd-mm-yyyy'), '3', '27', '178', '06', '2007', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2736, to_date('28-06-2007', 'dd-mm-yyyy'), '4', '28', '179', '06', '2007', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2737, to_date('29-06-2007', 'dd-mm-yyyy'), '5', '29', '180', '06', '2007', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2738, to_date('30-06-2007', 'dd-mm-yyyy'), '6', '30', '181', '06', '2007', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2739, to_date('01-07-2007', 'dd-mm-yyyy'), '7', '01', '182', '07', '2007', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2740, to_date('02-07-2007', 'dd-mm-yyyy'), '1', '02', '183', '07', '2007', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2741, to_date('03-07-2007', 'dd-mm-yyyy'), '2', '03', '184', '07', '2007', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2742, to_date('04-07-2007', 'dd-mm-yyyy'), '3', '04', '185', '07', '2007', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2743, to_date('05-07-2007', 'dd-mm-yyyy'), '4', '05', '186', '07', '2007', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2744, to_date('06-07-2007', 'dd-mm-yyyy'), '5', '06', '187', '07', '2007', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2745, to_date('07-07-2007', 'dd-mm-yyyy'), '6', '07', '188', '07', '2007', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2746, to_date('08-07-2007', 'dd-mm-yyyy'), '7', '08', '189', '07', '2007', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2747, to_date('09-07-2007', 'dd-mm-yyyy'), '1', '09', '190', '07', '2007', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2748, to_date('10-07-2007', 'dd-mm-yyyy'), '2', '10', '191', '07', '2007', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2749, to_date('11-07-2007', 'dd-mm-yyyy'), '3', '11', '192', '07', '2007', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2750, to_date('12-07-2007', 'dd-mm-yyyy'), '4', '12', '193', '07', '2007', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2751, to_date('13-07-2007', 'dd-mm-yyyy'), '5', '13', '194', '07', '2007', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2752, to_date('14-07-2007', 'dd-mm-yyyy'), '6', '14', '195', '07', '2007', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2753, to_date('15-07-2007', 'dd-mm-yyyy'), '7', '15', '196', '07', '2007', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2754, to_date('16-07-2007', 'dd-mm-yyyy'), '1', '16', '197', '07', '2007', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2755, to_date('17-07-2007', 'dd-mm-yyyy'), '2', '17', '198', '07', '2007', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2756, to_date('18-07-2007', 'dd-mm-yyyy'), '3', '18', '199', '07', '2007', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2757, to_date('19-07-2007', 'dd-mm-yyyy'), '4', '19', '200', '07', '2007', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2758, to_date('20-07-2007', 'dd-mm-yyyy'), '5', '20', '201', '07', '2007', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2759, to_date('21-07-2007', 'dd-mm-yyyy'), '6', '21', '202', '07', '2007', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2760, to_date('22-07-2007', 'dd-mm-yyyy'), '7', '22', '203', '07', '2007', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2761, to_date('23-07-2007', 'dd-mm-yyyy'), '1', '23', '204', '07', '2007', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2762, to_date('24-07-2007', 'dd-mm-yyyy'), '2', '24', '205', '07', '2007', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2763, to_date('25-07-2007', 'dd-mm-yyyy'), '3', '25', '206', '07', '2007', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2764, to_date('26-07-2007', 'dd-mm-yyyy'), '4', '26', '207', '07', '2007', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2765, to_date('27-07-2007', 'dd-mm-yyyy'), '5', '27', '208', '07', '2007', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2766, to_date('28-07-2007', 'dd-mm-yyyy'), '6', '28', '209', '07', '2007', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2767, to_date('29-07-2007', 'dd-mm-yyyy'), '7', '29', '210', '07', '2007', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2768, to_date('30-07-2007', 'dd-mm-yyyy'), '1', '30', '211', '07', '2007', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2769, to_date('31-07-2007', 'dd-mm-yyyy'), '2', '31', '212', '07', '2007', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2770, to_date('01-08-2007', 'dd-mm-yyyy'), '3', '01', '213', '08', '2007', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2771, to_date('02-08-2007', 'dd-mm-yyyy'), '4', '02', '214', '08', '2007', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2772, to_date('03-08-2007', 'dd-mm-yyyy'), '5', '03', '215', '08', '2007', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2773, to_date('04-08-2007', 'dd-mm-yyyy'), '6', '04', '216', '08', '2007', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2774, to_date('05-08-2007', 'dd-mm-yyyy'), '7', '05', '217', '08', '2007', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2775, to_date('06-08-2007', 'dd-mm-yyyy'), '1', '06', '218', '08', '2007', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2776, to_date('07-08-2007', 'dd-mm-yyyy'), '2', '07', '219', '08', '2007', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2777, to_date('08-08-2007', 'dd-mm-yyyy'), '3', '08', '220', '08', '2007', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2778, to_date('09-08-2007', 'dd-mm-yyyy'), '4', '09', '221', '08', '2007', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2779, to_date('10-08-2007', 'dd-mm-yyyy'), '5', '10', '222', '08', '2007', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2780, to_date('11-08-2007', 'dd-mm-yyyy'), '6', '11', '223', '08', '2007', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2781, to_date('12-08-2007', 'dd-mm-yyyy'), '7', '12', '224', '08', '2007', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2782, to_date('13-08-2007', 'dd-mm-yyyy'), '1', '13', '225', '08', '2007', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2783, to_date('14-08-2007', 'dd-mm-yyyy'), '2', '14', '226', '08', '2007', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2784, to_date('15-08-2007', 'dd-mm-yyyy'), '3', '15', '227', '08', '2007', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2785, to_date('16-08-2007', 'dd-mm-yyyy'), '4', '16', '228', '08', '2007', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2786, to_date('17-08-2007', 'dd-mm-yyyy'), '5', '17', '229', '08', '2007', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2787, to_date('18-08-2007', 'dd-mm-yyyy'), '6', '18', '230', '08', '2007', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2788, to_date('19-08-2007', 'dd-mm-yyyy'), '7', '19', '231', '08', '2007', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2789, to_date('20-08-2007', 'dd-mm-yyyy'), '1', '20', '232', '08', '2007', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2790, to_date('21-08-2007', 'dd-mm-yyyy'), '2', '21', '233', '08', '2007', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2791, to_date('22-08-2007', 'dd-mm-yyyy'), '3', '22', '234', '08', '2007', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2792, to_date('23-08-2007', 'dd-mm-yyyy'), '4', '23', '235', '08', '2007', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2793, to_date('24-08-2007', 'dd-mm-yyyy'), '5', '24', '236', '08', '2007', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2794, to_date('25-08-2007', 'dd-mm-yyyy'), '6', '25', '237', '08', '2007', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2795, to_date('26-08-2007', 'dd-mm-yyyy'), '7', '26', '238', '08', '2007', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2796, to_date('27-08-2007', 'dd-mm-yyyy'), '1', '27', '239', '08', '2007', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2797, to_date('28-08-2007', 'dd-mm-yyyy'), '2', '28', '240', '08', '2007', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2798, to_date('29-08-2007', 'dd-mm-yyyy'), '3', '29', '241', '08', '2007', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2799, to_date('30-08-2007', 'dd-mm-yyyy'), '4', '30', '242', '08', '2007', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2800, to_date('31-08-2007', 'dd-mm-yyyy'), '5', '31', '243', '08', '2007', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2801, to_date('01-09-2007', 'dd-mm-yyyy'), '6', '01', '244', '09', '2007', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2802, to_date('02-09-2007', 'dd-mm-yyyy'), '7', '02', '245', '09', '2007', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2803, to_date('03-09-2007', 'dd-mm-yyyy'), '1', '03', '246', '09', '2007', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2804, to_date('04-09-2007', 'dd-mm-yyyy'), '2', '04', '247', '09', '2007', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2805, to_date('05-09-2007', 'dd-mm-yyyy'), '3', '05', '248', '09', '2007', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2806, to_date('06-09-2007', 'dd-mm-yyyy'), '4', '06', '249', '09', '2007', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2807, to_date('07-09-2007', 'dd-mm-yyyy'), '5', '07', '250', '09', '2007', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2808, to_date('08-09-2007', 'dd-mm-yyyy'), '6', '08', '251', '09', '2007', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2809, to_date('09-09-2007', 'dd-mm-yyyy'), '7', '09', '252', '09', '2007', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2810, to_date('10-09-2007', 'dd-mm-yyyy'), '1', '10', '253', '09', '2007', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2811, to_date('11-09-2007', 'dd-mm-yyyy'), '2', '11', '254', '09', '2007', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2812, to_date('12-09-2007', 'dd-mm-yyyy'), '3', '12', '255', '09', '2007', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2813, to_date('13-09-2007', 'dd-mm-yyyy'), '4', '13', '256', '09', '2007', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2814, to_date('14-09-2007', 'dd-mm-yyyy'), '5', '14', '257', '09', '2007', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2815, to_date('15-09-2007', 'dd-mm-yyyy'), '6', '15', '258', '09', '2007', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2816, to_date('16-09-2007', 'dd-mm-yyyy'), '7', '16', '259', '09', '2007', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2817, to_date('17-09-2007', 'dd-mm-yyyy'), '1', '17', '260', '09', '2007', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2818, to_date('18-09-2007', 'dd-mm-yyyy'), '2', '18', '261', '09', '2007', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2819, to_date('19-09-2007', 'dd-mm-yyyy'), '3', '19', '262', '09', '2007', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2820, to_date('20-09-2007', 'dd-mm-yyyy'), '4', '20', '263', '09', '2007', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2821, to_date('21-09-2007', 'dd-mm-yyyy'), '5', '21', '264', '09', '2007', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2822, to_date('22-09-2007', 'dd-mm-yyyy'), '6', '22', '265', '09', '2007', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2823, to_date('23-09-2007', 'dd-mm-yyyy'), '7', '23', '266', '09', '2007', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2824, to_date('24-09-2007', 'dd-mm-yyyy'), '1', '24', '267', '09', '2007', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2825, to_date('25-09-2007', 'dd-mm-yyyy'), '2', '25', '268', '09', '2007', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2826, to_date('26-09-2007', 'dd-mm-yyyy'), '3', '26', '269', '09', '2007', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2827, to_date('27-09-2007', 'dd-mm-yyyy'), '4', '27', '270', '09', '2007', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2828, to_date('28-09-2007', 'dd-mm-yyyy'), '5', '28', '271', '09', '2007', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2829, to_date('29-09-2007', 'dd-mm-yyyy'), '6', '29', '272', '09', '2007', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2830, to_date('30-09-2007', 'dd-mm-yyyy'), '7', '30', '273', '09', '2007', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2831, to_date('01-10-2007', 'dd-mm-yyyy'), '1', '01', '274', '10', '2007', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2832, to_date('02-10-2007', 'dd-mm-yyyy'), '2', '02', '275', '10', '2007', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2833, to_date('03-10-2007', 'dd-mm-yyyy'), '3', '03', '276', '10', '2007', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2834, to_date('04-10-2007', 'dd-mm-yyyy'), '4', '04', '277', '10', '2007', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2835, to_date('05-10-2007', 'dd-mm-yyyy'), '5', '05', '278', '10', '2007', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2836, to_date('06-10-2007', 'dd-mm-yyyy'), '6', '06', '279', '10', '2007', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2837, to_date('07-10-2007', 'dd-mm-yyyy'), '7', '07', '280', '10', '2007', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2838, to_date('08-10-2007', 'dd-mm-yyyy'), '1', '08', '281', '10', '2007', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2839, to_date('09-10-2007', 'dd-mm-yyyy'), '2', '09', '282', '10', '2007', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2840, to_date('10-10-2007', 'dd-mm-yyyy'), '3', '10', '283', '10', '2007', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2841, to_date('11-10-2007', 'dd-mm-yyyy'), '4', '11', '284', '10', '2007', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2842, to_date('12-10-2007', 'dd-mm-yyyy'), '5', '12', '285', '10', '2007', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2843, to_date('13-10-2007', 'dd-mm-yyyy'), '6', '13', '286', '10', '2007', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2844, to_date('14-10-2007', 'dd-mm-yyyy'), '7', '14', '287', '10', '2007', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2845, to_date('15-10-2007', 'dd-mm-yyyy'), '1', '15', '288', '10', '2007', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2846, to_date('16-10-2007', 'dd-mm-yyyy'), '2', '16', '289', '10', '2007', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2847, to_date('17-10-2007', 'dd-mm-yyyy'), '3', '17', '290', '10', '2007', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2848, to_date('18-10-2007', 'dd-mm-yyyy'), '4', '18', '291', '10', '2007', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2849, to_date('19-10-2007', 'dd-mm-yyyy'), '5', '19', '292', '10', '2007', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2850, to_date('20-10-2007', 'dd-mm-yyyy'), '6', '20', '293', '10', '2007', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2851, to_date('21-10-2007', 'dd-mm-yyyy'), '7', '21', '294', '10', '2007', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2852, to_date('22-10-2007', 'dd-mm-yyyy'), '1', '22', '295', '10', '2007', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2853, to_date('23-10-2007', 'dd-mm-yyyy'), '2', '23', '296', '10', '2007', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2854, to_date('24-10-2007', 'dd-mm-yyyy'), '3', '24', '297', '10', '2007', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2855, to_date('25-10-2007', 'dd-mm-yyyy'), '4', '25', '298', '10', '2007', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2856, to_date('26-10-2007', 'dd-mm-yyyy'), '5', '26', '299', '10', '2007', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2857, to_date('27-10-2007', 'dd-mm-yyyy'), '6', '27', '300', '10', '2007', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2858, to_date('28-10-2007', 'dd-mm-yyyy'), '7', '28', '301', '10', '2007', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2859, to_date('29-10-2007', 'dd-mm-yyyy'), '1', '29', '302', '10', '2007', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2860, to_date('30-10-2007', 'dd-mm-yyyy'), '2', '30', '303', '10', '2007', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2861, to_date('31-10-2007', 'dd-mm-yyyy'), '3', '31', '304', '10', '2007', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2862, to_date('01-11-2007', 'dd-mm-yyyy'), '4', '01', '305', '11', '2007', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2863, to_date('02-11-2007', 'dd-mm-yyyy'), '5', '02', '306', '11', '2007', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2864, to_date('03-11-2007', 'dd-mm-yyyy'), '6', '03', '307', '11', '2007', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2865, to_date('04-11-2007', 'dd-mm-yyyy'), '7', '04', '308', '11', '2007', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2866, to_date('05-11-2007', 'dd-mm-yyyy'), '1', '05', '309', '11', '2007', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2867, to_date('06-11-2007', 'dd-mm-yyyy'), '2', '06', '310', '11', '2007', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2868, to_date('07-11-2007', 'dd-mm-yyyy'), '3', '07', '311', '11', '2007', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2869, to_date('08-11-2007', 'dd-mm-yyyy'), '4', '08', '312', '11', '2007', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2870, to_date('09-11-2007', 'dd-mm-yyyy'), '5', '09', '313', '11', '2007', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2871, to_date('10-11-2007', 'dd-mm-yyyy'), '6', '10', '314', '11', '2007', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2872, to_date('11-11-2007', 'dd-mm-yyyy'), '7', '11', '315', '11', '2007', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2873, to_date('12-11-2007', 'dd-mm-yyyy'), '1', '12', '316', '11', '2007', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2874, to_date('13-11-2007', 'dd-mm-yyyy'), '2', '13', '317', '11', '2007', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2875, to_date('14-11-2007', 'dd-mm-yyyy'), '3', '14', '318', '11', '2007', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2876, to_date('15-11-2007', 'dd-mm-yyyy'), '4', '15', '319', '11', '2007', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2877, to_date('16-11-2007', 'dd-mm-yyyy'), '5', '16', '320', '11', '2007', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2878, to_date('17-11-2007', 'dd-mm-yyyy'), '6', '17', '321', '11', '2007', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2879, to_date('18-11-2007', 'dd-mm-yyyy'), '7', '18', '322', '11', '2007', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2880, to_date('19-11-2007', 'dd-mm-yyyy'), '1', '19', '323', '11', '2007', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2881, to_date('20-11-2007', 'dd-mm-yyyy'), '2', '20', '324', '11', '2007', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2882, to_date('21-11-2007', 'dd-mm-yyyy'), '3', '21', '325', '11', '2007', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2883, to_date('22-11-2007', 'dd-mm-yyyy'), '4', '22', '326', '11', '2007', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2884, to_date('23-11-2007', 'dd-mm-yyyy'), '5', '23', '327', '11', '2007', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2885, to_date('24-11-2007', 'dd-mm-yyyy'), '6', '24', '328', '11', '2007', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2886, to_date('25-11-2007', 'dd-mm-yyyy'), '7', '25', '329', '11', '2007', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2887, to_date('26-11-2007', 'dd-mm-yyyy'), '1', '26', '330', '11', '2007', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2888, to_date('27-11-2007', 'dd-mm-yyyy'), '2', '27', '331', '11', '2007', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2889, to_date('28-11-2007', 'dd-mm-yyyy'), '3', '28', '332', '11', '2007', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2890, to_date('29-11-2007', 'dd-mm-yyyy'), '4', '29', '333', '11', '2007', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2891, to_date('30-11-2007', 'dd-mm-yyyy'), '5', '30', '334', '11', '2007', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2892, to_date('01-12-2007', 'dd-mm-yyyy'), '6', '01', '335', '12', '2007', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2893, to_date('02-12-2007', 'dd-mm-yyyy'), '7', '02', '336', '12', '2007', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2894, to_date('03-12-2007', 'dd-mm-yyyy'), '1', '03', '337', '12', '2007', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2895, to_date('04-12-2007', 'dd-mm-yyyy'), '2', '04', '338', '12', '2007', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2896, to_date('05-12-2007', 'dd-mm-yyyy'), '3', '05', '339', '12', '2007', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2897, to_date('06-12-2007', 'dd-mm-yyyy'), '4', '06', '340', '12', '2007', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2898, to_date('07-12-2007', 'dd-mm-yyyy'), '5', '07', '341', '12', '2007', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2899, to_date('08-12-2007', 'dd-mm-yyyy'), '6', '08', '342', '12', '2007', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2900, to_date('09-12-2007', 'dd-mm-yyyy'), '7', '09', '343', '12', '2007', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2901, to_date('10-12-2007', 'dd-mm-yyyy'), '1', '10', '344', '12', '2007', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2902, to_date('11-12-2007', 'dd-mm-yyyy'), '2', '11', '345', '12', '2007', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2903, to_date('12-12-2007', 'dd-mm-yyyy'), '3', '12', '346', '12', '2007', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2904, to_date('13-12-2007', 'dd-mm-yyyy'), '4', '13', '347', '12', '2007', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2905, to_date('14-12-2007', 'dd-mm-yyyy'), '5', '14', '348', '12', '2007', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2906, to_date('15-12-2007', 'dd-mm-yyyy'), '6', '15', '349', '12', '2007', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2907, to_date('16-12-2007', 'dd-mm-yyyy'), '7', '16', '350', '12', '2007', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2908, to_date('17-12-2007', 'dd-mm-yyyy'), '1', '17', '351', '12', '2007', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2909, to_date('18-12-2007', 'dd-mm-yyyy'), '2', '18', '352', '12', '2007', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2910, to_date('19-12-2007', 'dd-mm-yyyy'), '3', '19', '353', '12', '2007', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2911, to_date('20-12-2007', 'dd-mm-yyyy'), '4', '20', '354', '12', '2007', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2912, to_date('21-12-2007', 'dd-mm-yyyy'), '5', '21', '355', '12', '2007', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2913, to_date('22-12-2007', 'dd-mm-yyyy'), '6', '22', '356', '12', '2007', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2914, to_date('23-12-2007', 'dd-mm-yyyy'), '7', '23', '357', '12', '2007', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2915, to_date('24-12-2007', 'dd-mm-yyyy'), '1', '24', '358', '12', '2007', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2916, to_date('25-12-2007', 'dd-mm-yyyy'), '2', '25', '359', '12', '2007', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2917, to_date('26-12-2007', 'dd-mm-yyyy'), '3', '26', '360', '12', '2007', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2918, to_date('27-12-2007', 'dd-mm-yyyy'), '4', '27', '361', '12', '2007', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2919, to_date('28-12-2007', 'dd-mm-yyyy'), '5', '28', '362', '12', '2007', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2920, to_date('29-12-2007', 'dd-mm-yyyy'), '6', '29', '363', '12', '2007', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2921, to_date('30-12-2007', 'dd-mm-yyyy'), '7', '30', '364', '12', '2007', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2922, to_date('31-12-2007', 'dd-mm-yyyy'), '1', '31', '365', '12', '2007', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2923, to_date('01-01-2008', 'dd-mm-yyyy'), '2', '01', '001', '01', '2008', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2924, to_date('02-01-2008', 'dd-mm-yyyy'), '3', '02', '002', '01', '2008', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2925, to_date('03-01-2008', 'dd-mm-yyyy'), '4', '03', '003', '01', '2008', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2926, to_date('04-01-2008', 'dd-mm-yyyy'), '5', '04', '004', '01', '2008', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2927, to_date('05-01-2008', 'dd-mm-yyyy'), '6', '05', '005', '01', '2008', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2928, to_date('06-01-2008', 'dd-mm-yyyy'), '7', '06', '006', '01', '2008', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2929, to_date('07-01-2008', 'dd-mm-yyyy'), '1', '07', '007', '01', '2008', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2930, to_date('08-01-2008', 'dd-mm-yyyy'), '2', '08', '008', '01', '2008', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2931, to_date('09-01-2008', 'dd-mm-yyyy'), '3', '09', '009', '01', '2008', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2932, to_date('10-01-2008', 'dd-mm-yyyy'), '4', '10', '010', '01', '2008', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2933, to_date('11-01-2008', 'dd-mm-yyyy'), '5', '11', '011', '01', '2008', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2934, to_date('12-01-2008', 'dd-mm-yyyy'), '6', '12', '012', '01', '2008', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2935, to_date('13-01-2008', 'dd-mm-yyyy'), '7', '13', '013', '01', '2008', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2936, to_date('14-01-2008', 'dd-mm-yyyy'), '1', '14', '014', '01', '2008', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2937, to_date('15-01-2008', 'dd-mm-yyyy'), '2', '15', '015', '01', '2008', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2938, to_date('16-01-2008', 'dd-mm-yyyy'), '3', '16', '016', '01', '2008', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2939, to_date('17-01-2008', 'dd-mm-yyyy'), '4', '17', '017', '01', '2008', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2940, to_date('18-01-2008', 'dd-mm-yyyy'), '5', '18', '018', '01', '2008', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2941, to_date('19-01-2008', 'dd-mm-yyyy'), '6', '19', '019', '01', '2008', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2942, to_date('20-01-2008', 'dd-mm-yyyy'), '7', '20', '020', '01', '2008', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2943, to_date('21-01-2008', 'dd-mm-yyyy'), '1', '21', '021', '01', '2008', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2944, to_date('22-01-2008', 'dd-mm-yyyy'), '2', '22', '022', '01', '2008', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2945, to_date('23-01-2008', 'dd-mm-yyyy'), '3', '23', '023', '01', '2008', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2946, to_date('24-01-2008', 'dd-mm-yyyy'), '4', '24', '024', '01', '2008', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2947, to_date('25-01-2008', 'dd-mm-yyyy'), '5', '25', '025', '01', '2008', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2948, to_date('26-01-2008', 'dd-mm-yyyy'), '6', '26', '026', '01', '2008', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2949, to_date('27-01-2008', 'dd-mm-yyyy'), '7', '27', '027', '01', '2008', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2950, to_date('28-01-2008', 'dd-mm-yyyy'), '1', '28', '028', '01', '2008', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2951, to_date('29-01-2008', 'dd-mm-yyyy'), '2', '29', '029', '01', '2008', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2952, to_date('30-01-2008', 'dd-mm-yyyy'), '3', '30', '030', '01', '2008', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2953, to_date('31-01-2008', 'dd-mm-yyyy'), '4', '31', '031', '01', '2008', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2954, to_date('01-02-2008', 'dd-mm-yyyy'), '5', '01', '032', '02', '2008', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2955, to_date('02-02-2008', 'dd-mm-yyyy'), '6', '02', '033', '02', '2008', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2956, to_date('03-02-2008', 'dd-mm-yyyy'), '7', '03', '034', '02', '2008', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2957, to_date('04-02-2008', 'dd-mm-yyyy'), '1', '04', '035', '02', '2008', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2958, to_date('05-02-2008', 'dd-mm-yyyy'), '2', '05', '036', '02', '2008', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2959, to_date('06-02-2008', 'dd-mm-yyyy'), '3', '06', '037', '02', '2008', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2960, to_date('07-02-2008', 'dd-mm-yyyy'), '4', '07', '038', '02', '2008', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2961, to_date('08-02-2008', 'dd-mm-yyyy'), '5', '08', '039', '02', '2008', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2962, to_date('09-02-2008', 'dd-mm-yyyy'), '6', '09', '040', '02', '2008', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2963, to_date('10-02-2008', 'dd-mm-yyyy'), '7', '10', '041', '02', '2008', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2964, to_date('11-02-2008', 'dd-mm-yyyy'), '1', '11', '042', '02', '2008', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2965, to_date('12-02-2008', 'dd-mm-yyyy'), '2', '12', '043', '02', '2008', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2966, to_date('13-02-2008', 'dd-mm-yyyy'), '3', '13', '044', '02', '2008', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2967, to_date('14-02-2008', 'dd-mm-yyyy'), '4', '14', '045', '02', '2008', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2968, to_date('15-02-2008', 'dd-mm-yyyy'), '5', '15', '046', '02', '2008', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2969, to_date('16-02-2008', 'dd-mm-yyyy'), '6', '16', '047', '02', '2008', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2970, to_date('17-02-2008', 'dd-mm-yyyy'), '7', '17', '048', '02', '2008', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2971, to_date('18-02-2008', 'dd-mm-yyyy'), '1', '18', '049', '02', '2008', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2972, to_date('19-02-2008', 'dd-mm-yyyy'), '2', '19', '050', '02', '2008', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2973, to_date('20-02-2008', 'dd-mm-yyyy'), '3', '20', '051', '02', '2008', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2974, to_date('21-02-2008', 'dd-mm-yyyy'), '4', '21', '052', '02', '2008', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2975, to_date('22-02-2008', 'dd-mm-yyyy'), '5', '22', '053', '02', '2008', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2976, to_date('23-02-2008', 'dd-mm-yyyy'), '6', '23', '054', '02', '2008', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2977, to_date('24-02-2008', 'dd-mm-yyyy'), '7', '24', '055', '02', '2008', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2978, to_date('25-02-2008', 'dd-mm-yyyy'), '1', '25', '056', '02', '2008', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2979, to_date('26-02-2008', 'dd-mm-yyyy'), '2', '26', '057', '02', '2008', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2980, to_date('27-02-2008', 'dd-mm-yyyy'), '3', '27', '058', '02', '2008', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2981, to_date('28-02-2008', 'dd-mm-yyyy'), '4', '28', '059', '02', '2008', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2982, to_date('29-02-2008', 'dd-mm-yyyy'), '5', '29', '060', '02', '2008', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2983, to_date('01-03-2008', 'dd-mm-yyyy'), '6', '01', '061', '03', '2008', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2984, to_date('02-03-2008', 'dd-mm-yyyy'), '7', '02', '062', '03', '2008', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2985, to_date('03-03-2008', 'dd-mm-yyyy'), '1', '03', '063', '03', '2008', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2986, to_date('04-03-2008', 'dd-mm-yyyy'), '2', '04', '064', '03', '2008', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2987, to_date('05-03-2008', 'dd-mm-yyyy'), '3', '05', '065', '03', '2008', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2988, to_date('06-03-2008', 'dd-mm-yyyy'), '4', '06', '066', '03', '2008', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2989, to_date('07-03-2008', 'dd-mm-yyyy'), '5', '07', '067', '03', '2008', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2990, to_date('08-03-2008', 'dd-mm-yyyy'), '6', '08', '068', '03', '2008', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2991, to_date('09-03-2008', 'dd-mm-yyyy'), '7', '09', '069', '03', '2008', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2992, to_date('10-03-2008', 'dd-mm-yyyy'), '1', '10', '070', '03', '2008', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2993, to_date('11-03-2008', 'dd-mm-yyyy'), '2', '11', '071', '03', '2008', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2994, to_date('12-03-2008', 'dd-mm-yyyy'), '3', '12', '072', '03', '2008', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2995, to_date('13-03-2008', 'dd-mm-yyyy'), '4', '13', '073', '03', '2008', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2996, to_date('14-03-2008', 'dd-mm-yyyy'), '5', '14', '074', '03', '2008', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2997, to_date('15-03-2008', 'dd-mm-yyyy'), '6', '15', '075', '03', '2008', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2998, to_date('16-03-2008', 'dd-mm-yyyy'), '7', '16', '076', '03', '2008', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2999, to_date('17-03-2008', 'dd-mm-yyyy'), '1', '17', '077', '03', '2008', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3000, to_date('18-03-2008', 'dd-mm-yyyy'), '2', '18', '078', '03', '2008', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3001, to_date('19-03-2008', 'dd-mm-yyyy'), '3', '19', '079', '03', '2008', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3002, to_date('20-03-2008', 'dd-mm-yyyy'), '4', '20', '080', '03', '2008', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3003, to_date('21-03-2008', 'dd-mm-yyyy'), '5', '21', '081', '03', '2008', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3004, to_date('22-03-2008', 'dd-mm-yyyy'), '6', '22', '082', '03', '2008', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3005, to_date('23-03-2008', 'dd-mm-yyyy'), '7', '23', '083', '03', '2008', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3006, to_date('24-03-2008', 'dd-mm-yyyy'), '1', '24', '084', '03', '2008', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3007, to_date('25-03-2008', 'dd-mm-yyyy'), '2', '25', '085', '03', '2008', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3008, to_date('26-03-2008', 'dd-mm-yyyy'), '3', '26', '086', '03', '2008', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3009, to_date('27-03-2008', 'dd-mm-yyyy'), '4', '27', '087', '03', '2008', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3010, to_date('28-03-2008', 'dd-mm-yyyy'), '5', '28', '088', '03', '2008', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3011, to_date('29-03-2008', 'dd-mm-yyyy'), '6', '29', '089', '03', '2008', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3012, to_date('30-03-2008', 'dd-mm-yyyy'), '7', '30', '090', '03', '2008', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3013, to_date('31-03-2008', 'dd-mm-yyyy'), '1', '31', '091', '03', '2008', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3014, to_date('01-04-2008', 'dd-mm-yyyy'), '2', '01', '092', '04', '2008', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3015, to_date('02-04-2008', 'dd-mm-yyyy'), '3', '02', '093', '04', '2008', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3016, to_date('03-04-2008', 'dd-mm-yyyy'), '4', '03', '094', '04', '2008', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3017, to_date('04-04-2008', 'dd-mm-yyyy'), '5', '04', '095', '04', '2008', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3018, to_date('05-04-2008', 'dd-mm-yyyy'), '6', '05', '096', '04', '2008', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3019, to_date('06-04-2008', 'dd-mm-yyyy'), '7', '06', '097', '04', '2008', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3020, to_date('07-04-2008', 'dd-mm-yyyy'), '1', '07', '098', '04', '2008', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3021, to_date('08-04-2008', 'dd-mm-yyyy'), '2', '08', '099', '04', '2008', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3022, to_date('09-04-2008', 'dd-mm-yyyy'), '3', '09', '100', '04', '2008', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3023, to_date('10-04-2008', 'dd-mm-yyyy'), '4', '10', '101', '04', '2008', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3024, to_date('11-04-2008', 'dd-mm-yyyy'), '5', '11', '102', '04', '2008', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3025, to_date('12-04-2008', 'dd-mm-yyyy'), '6', '12', '103', '04', '2008', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3026, to_date('13-04-2008', 'dd-mm-yyyy'), '7', '13', '104', '04', '2008', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3027, to_date('14-04-2008', 'dd-mm-yyyy'), '1', '14', '105', '04', '2008', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3028, to_date('15-04-2008', 'dd-mm-yyyy'), '2', '15', '106', '04', '2008', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3029, to_date('16-04-2008', 'dd-mm-yyyy'), '3', '16', '107', '04', '2008', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3030, to_date('17-04-2008', 'dd-mm-yyyy'), '4', '17', '108', '04', '2008', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3031, to_date('18-04-2008', 'dd-mm-yyyy'), '5', '18', '109', '04', '2008', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3032, to_date('19-04-2008', 'dd-mm-yyyy'), '6', '19', '110', '04', '2008', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3033, to_date('20-04-2008', 'dd-mm-yyyy'), '7', '20', '111', '04', '2008', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3034, to_date('21-04-2008', 'dd-mm-yyyy'), '1', '21', '112', '04', '2008', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3035, to_date('22-04-2008', 'dd-mm-yyyy'), '2', '22', '113', '04', '2008', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3036, to_date('23-04-2008', 'dd-mm-yyyy'), '3', '23', '114', '04', '2008', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3037, to_date('24-04-2008', 'dd-mm-yyyy'), '4', '24', '115', '04', '2008', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3038, to_date('25-04-2008', 'dd-mm-yyyy'), '5', '25', '116', '04', '2008', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3039, to_date('26-04-2008', 'dd-mm-yyyy'), '6', '26', '117', '04', '2008', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3040, to_date('27-04-2008', 'dd-mm-yyyy'), '7', '27', '118', '04', '2008', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3041, to_date('28-04-2008', 'dd-mm-yyyy'), '1', '28', '119', '04', '2008', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3042, to_date('29-04-2008', 'dd-mm-yyyy'), '2', '29', '120', '04', '2008', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3043, to_date('30-04-2008', 'dd-mm-yyyy'), '3', '30', '121', '04', '2008', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3044, to_date('01-05-2008', 'dd-mm-yyyy'), '4', '01', '122', '05', '2008', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3045, to_date('02-05-2008', 'dd-mm-yyyy'), '5', '02', '123', '05', '2008', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3046, to_date('03-05-2008', 'dd-mm-yyyy'), '6', '03', '124', '05', '2008', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3047, to_date('04-05-2008', 'dd-mm-yyyy'), '7', '04', '125', '05', '2008', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3048, to_date('05-05-2008', 'dd-mm-yyyy'), '1', '05', '126', '05', '2008', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3049, to_date('06-05-2008', 'dd-mm-yyyy'), '2', '06', '127', '05', '2008', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3050, to_date('07-05-2008', 'dd-mm-yyyy'), '3', '07', '128', '05', '2008', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3051, to_date('08-05-2008', 'dd-mm-yyyy'), '4', '08', '129', '05', '2008', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3052, to_date('09-05-2008', 'dd-mm-yyyy'), '5', '09', '130', '05', '2008', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3053, to_date('10-05-2008', 'dd-mm-yyyy'), '6', '10', '131', '05', '2008', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3054, to_date('11-05-2008', 'dd-mm-yyyy'), '7', '11', '132', '05', '2008', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3055, to_date('12-05-2008', 'dd-mm-yyyy'), '1', '12', '133', '05', '2008', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3056, to_date('13-05-2008', 'dd-mm-yyyy'), '2', '13', '134', '05', '2008', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3057, to_date('14-05-2008', 'dd-mm-yyyy'), '3', '14', '135', '05', '2008', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3058, to_date('15-05-2008', 'dd-mm-yyyy'), '4', '15', '136', '05', '2008', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3059, to_date('16-05-2008', 'dd-mm-yyyy'), '5', '16', '137', '05', '2008', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3060, to_date('17-05-2008', 'dd-mm-yyyy'), '6', '17', '138', '05', '2008', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3061, to_date('18-05-2008', 'dd-mm-yyyy'), '7', '18', '139', '05', '2008', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3062, to_date('19-05-2008', 'dd-mm-yyyy'), '1', '19', '140', '05', '2008', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3063, to_date('20-05-2008', 'dd-mm-yyyy'), '2', '20', '141', '05', '2008', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3064, to_date('21-05-2008', 'dd-mm-yyyy'), '3', '21', '142', '05', '2008', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3065, to_date('22-05-2008', 'dd-mm-yyyy'), '4', '22', '143', '05', '2008', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3066, to_date('23-05-2008', 'dd-mm-yyyy'), '5', '23', '144', '05', '2008', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3067, to_date('24-05-2008', 'dd-mm-yyyy'), '6', '24', '145', '05', '2008', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3068, to_date('25-05-2008', 'dd-mm-yyyy'), '7', '25', '146', '05', '2008', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3069, to_date('26-05-2008', 'dd-mm-yyyy'), '1', '26', '147', '05', '2008', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3070, to_date('27-05-2008', 'dd-mm-yyyy'), '2', '27', '148', '05', '2008', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3071, to_date('28-05-2008', 'dd-mm-yyyy'), '3', '28', '149', '05', '2008', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3072, to_date('29-05-2008', 'dd-mm-yyyy'), '4', '29', '150', '05', '2008', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3073, to_date('30-05-2008', 'dd-mm-yyyy'), '5', '30', '151', '05', '2008', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3074, to_date('31-05-2008', 'dd-mm-yyyy'), '6', '31', '152', '05', '2008', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3075, to_date('01-06-2008', 'dd-mm-yyyy'), '7', '01', '153', '06', '2008', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3076, to_date('02-06-2008', 'dd-mm-yyyy'), '1', '02', '154', '06', '2008', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3077, to_date('03-06-2008', 'dd-mm-yyyy'), '2', '03', '155', '06', '2008', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3078, to_date('04-06-2008', 'dd-mm-yyyy'), '3', '04', '156', '06', '2008', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3079, to_date('05-06-2008', 'dd-mm-yyyy'), '4', '05', '157', '06', '2008', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3080, to_date('06-06-2008', 'dd-mm-yyyy'), '5', '06', '158', '06', '2008', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3081, to_date('07-06-2008', 'dd-mm-yyyy'), '6', '07', '159', '06', '2008', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3082, to_date('08-06-2008', 'dd-mm-yyyy'), '7', '08', '160', '06', '2008', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3083, to_date('09-06-2008', 'dd-mm-yyyy'), '1', '09', '161', '06', '2008', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3084, to_date('10-06-2008', 'dd-mm-yyyy'), '2', '10', '162', '06', '2008', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3085, to_date('11-06-2008', 'dd-mm-yyyy'), '3', '11', '163', '06', '2008', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3086, to_date('12-06-2008', 'dd-mm-yyyy'), '4', '12', '164', '06', '2008', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3087, to_date('13-06-2008', 'dd-mm-yyyy'), '5', '13', '165', '06', '2008', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3088, to_date('14-06-2008', 'dd-mm-yyyy'), '6', '14', '166', '06', '2008', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3089, to_date('15-06-2008', 'dd-mm-yyyy'), '7', '15', '167', '06', '2008', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3090, to_date('16-06-2008', 'dd-mm-yyyy'), '1', '16', '168', '06', '2008', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3091, to_date('17-06-2008', 'dd-mm-yyyy'), '2', '17', '169', '06', '2008', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3092, to_date('18-06-2008', 'dd-mm-yyyy'), '3', '18', '170', '06', '2008', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3093, to_date('19-06-2008', 'dd-mm-yyyy'), '4', '19', '171', '06', '2008', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3094, to_date('20-06-2008', 'dd-mm-yyyy'), '5', '20', '172', '06', '2008', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3095, to_date('21-06-2008', 'dd-mm-yyyy'), '6', '21', '173', '06', '2008', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3096, to_date('22-06-2008', 'dd-mm-yyyy'), '7', '22', '174', '06', '2008', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3097, to_date('23-06-2008', 'dd-mm-yyyy'), '1', '23', '175', '06', '2008', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3098, to_date('24-06-2008', 'dd-mm-yyyy'), '2', '24', '176', '06', '2008', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3099, to_date('25-06-2008', 'dd-mm-yyyy'), '3', '25', '177', '06', '2008', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3100, to_date('26-06-2008', 'dd-mm-yyyy'), '4', '26', '178', '06', '2008', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3101, to_date('27-06-2008', 'dd-mm-yyyy'), '5', '27', '179', '06', '2008', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3102, to_date('28-06-2008', 'dd-mm-yyyy'), '6', '28', '180', '06', '2008', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3103, to_date('29-06-2008', 'dd-mm-yyyy'), '7', '29', '181', '06', '2008', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3104, to_date('30-06-2008', 'dd-mm-yyyy'), '1', '30', '182', '06', '2008', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3105, to_date('01-07-2008', 'dd-mm-yyyy'), '2', '01', '183', '07', '2008', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3106, to_date('02-07-2008', 'dd-mm-yyyy'), '3', '02', '184', '07', '2008', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3107, to_date('03-07-2008', 'dd-mm-yyyy'), '4', '03', '185', '07', '2008', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3108, to_date('04-07-2008', 'dd-mm-yyyy'), '5', '04', '186', '07', '2008', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3109, to_date('05-07-2008', 'dd-mm-yyyy'), '6', '05', '187', '07', '2008', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3110, to_date('06-07-2008', 'dd-mm-yyyy'), '7', '06', '188', '07', '2008', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3111, to_date('07-07-2008', 'dd-mm-yyyy'), '1', '07', '189', '07', '2008', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3112, to_date('08-07-2008', 'dd-mm-yyyy'), '2', '08', '190', '07', '2008', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3113, to_date('09-07-2008', 'dd-mm-yyyy'), '3', '09', '191', '07', '2008', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3114, to_date('10-07-2008', 'dd-mm-yyyy'), '4', '10', '192', '07', '2008', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3115, to_date('11-07-2008', 'dd-mm-yyyy'), '5', '11', '193', '07', '2008', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3116, to_date('12-07-2008', 'dd-mm-yyyy'), '6', '12', '194', '07', '2008', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3117, to_date('13-07-2008', 'dd-mm-yyyy'), '7', '13', '195', '07', '2008', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3118, to_date('14-07-2008', 'dd-mm-yyyy'), '1', '14', '196', '07', '2008', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3119, to_date('15-07-2008', 'dd-mm-yyyy'), '2', '15', '197', '07', '2008', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3120, to_date('16-07-2008', 'dd-mm-yyyy'), '3', '16', '198', '07', '2008', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3121, to_date('17-07-2008', 'dd-mm-yyyy'), '4', '17', '199', '07', '2008', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3122, to_date('18-07-2008', 'dd-mm-yyyy'), '5', '18', '200', '07', '2008', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3123, to_date('19-07-2008', 'dd-mm-yyyy'), '6', '19', '201', '07', '2008', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3124, to_date('20-07-2008', 'dd-mm-yyyy'), '7', '20', '202', '07', '2008', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3125, to_date('21-07-2008', 'dd-mm-yyyy'), '1', '21', '203', '07', '2008', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3126, to_date('22-07-2008', 'dd-mm-yyyy'), '2', '22', '204', '07', '2008', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3127, to_date('23-07-2008', 'dd-mm-yyyy'), '3', '23', '205', '07', '2008', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3128, to_date('24-07-2008', 'dd-mm-yyyy'), '4', '24', '206', '07', '2008', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3129, to_date('25-07-2008', 'dd-mm-yyyy'), '5', '25', '207', '07', '2008', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3130, to_date('26-07-2008', 'dd-mm-yyyy'), '6', '26', '208', '07', '2008', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3131, to_date('27-07-2008', 'dd-mm-yyyy'), '7', '27', '209', '07', '2008', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3132, to_date('28-07-2008', 'dd-mm-yyyy'), '1', '28', '210', '07', '2008', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3133, to_date('29-07-2008', 'dd-mm-yyyy'), '2', '29', '211', '07', '2008', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3134, to_date('30-07-2008', 'dd-mm-yyyy'), '3', '30', '212', '07', '2008', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3135, to_date('31-07-2008', 'dd-mm-yyyy'), '4', '31', '213', '07', '2008', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3136, to_date('01-08-2008', 'dd-mm-yyyy'), '5', '01', '214', '08', '2008', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3137, to_date('02-08-2008', 'dd-mm-yyyy'), '6', '02', '215', '08', '2008', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3138, to_date('03-08-2008', 'dd-mm-yyyy'), '7', '03', '216', '08', '2008', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3139, to_date('04-08-2008', 'dd-mm-yyyy'), '1', '04', '217', '08', '2008', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3140, to_date('05-08-2008', 'dd-mm-yyyy'), '2', '05', '218', '08', '2008', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3141, to_date('06-08-2008', 'dd-mm-yyyy'), '3', '06', '219', '08', '2008', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3142, to_date('07-08-2008', 'dd-mm-yyyy'), '4', '07', '220', '08', '2008', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3143, to_date('08-08-2008', 'dd-mm-yyyy'), '5', '08', '221', '08', '2008', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3144, to_date('09-08-2008', 'dd-mm-yyyy'), '6', '09', '222', '08', '2008', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3145, to_date('10-08-2008', 'dd-mm-yyyy'), '7', '10', '223', '08', '2008', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3146, to_date('11-08-2008', 'dd-mm-yyyy'), '1', '11', '224', '08', '2008', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3147, to_date('12-08-2008', 'dd-mm-yyyy'), '2', '12', '225', '08', '2008', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3148, to_date('13-08-2008', 'dd-mm-yyyy'), '3', '13', '226', '08', '2008', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3149, to_date('14-08-2008', 'dd-mm-yyyy'), '4', '14', '227', '08', '2008', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3150, to_date('15-08-2008', 'dd-mm-yyyy'), '5', '15', '228', '08', '2008', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3151, to_date('16-08-2008', 'dd-mm-yyyy'), '6', '16', '229', '08', '2008', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3152, to_date('17-08-2008', 'dd-mm-yyyy'), '7', '17', '230', '08', '2008', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3153, to_date('18-08-2008', 'dd-mm-yyyy'), '1', '18', '231', '08', '2008', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3154, to_date('19-08-2008', 'dd-mm-yyyy'), '2', '19', '232', '08', '2008', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3155, to_date('20-08-2008', 'dd-mm-yyyy'), '3', '20', '233', '08', '2008', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3156, to_date('21-08-2008', 'dd-mm-yyyy'), '4', '21', '234', '08', '2008', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3157, to_date('22-08-2008', 'dd-mm-yyyy'), '5', '22', '235', '08', '2008', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3158, to_date('23-08-2008', 'dd-mm-yyyy'), '6', '23', '236', '08', '2008', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3159, to_date('24-08-2008', 'dd-mm-yyyy'), '7', '24', '237', '08', '2008', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3160, to_date('25-08-2008', 'dd-mm-yyyy'), '1', '25', '238', '08', '2008', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3161, to_date('26-08-2008', 'dd-mm-yyyy'), '2', '26', '239', '08', '2008', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3162, to_date('27-08-2008', 'dd-mm-yyyy'), '3', '27', '240', '08', '2008', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3163, to_date('28-08-2008', 'dd-mm-yyyy'), '4', '28', '241', '08', '2008', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3164, to_date('29-08-2008', 'dd-mm-yyyy'), '5', '29', '242', '08', '2008', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3165, to_date('30-08-2008', 'dd-mm-yyyy'), '6', '30', '243', '08', '2008', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3166, to_date('31-08-2008', 'dd-mm-yyyy'), '7', '31', '244', '08', '2008', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3167, to_date('01-09-2008', 'dd-mm-yyyy'), '1', '01', '245', '09', '2008', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3168, to_date('02-09-2008', 'dd-mm-yyyy'), '2', '02', '246', '09', '2008', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3169, to_date('03-09-2008', 'dd-mm-yyyy'), '3', '03', '247', '09', '2008', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3170, to_date('04-09-2008', 'dd-mm-yyyy'), '4', '04', '248', '09', '2008', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3171, to_date('05-09-2008', 'dd-mm-yyyy'), '5', '05', '249', '09', '2008', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3172, to_date('06-09-2008', 'dd-mm-yyyy'), '6', '06', '250', '09', '2008', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3173, to_date('07-09-2008', 'dd-mm-yyyy'), '7', '07', '251', '09', '2008', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3174, to_date('08-09-2008', 'dd-mm-yyyy'), '1', '08', '252', '09', '2008', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3175, to_date('09-09-2008', 'dd-mm-yyyy'), '2', '09', '253', '09', '2008', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3176, to_date('10-09-2008', 'dd-mm-yyyy'), '3', '10', '254', '09', '2008', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3177, to_date('11-09-2008', 'dd-mm-yyyy'), '4', '11', '255', '09', '2008', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3178, to_date('12-09-2008', 'dd-mm-yyyy'), '5', '12', '256', '09', '2008', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3179, to_date('13-09-2008', 'dd-mm-yyyy'), '6', '13', '257', '09', '2008', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3180, to_date('14-09-2008', 'dd-mm-yyyy'), '7', '14', '258', '09', '2008', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3181, to_date('15-09-2008', 'dd-mm-yyyy'), '1', '15', '259', '09', '2008', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3182, to_date('16-09-2008', 'dd-mm-yyyy'), '2', '16', '260', '09', '2008', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3183, to_date('17-09-2008', 'dd-mm-yyyy'), '3', '17', '261', '09', '2008', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3184, to_date('18-09-2008', 'dd-mm-yyyy'), '4', '18', '262', '09', '2008', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3185, to_date('19-09-2008', 'dd-mm-yyyy'), '5', '19', '263', '09', '2008', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3186, to_date('20-09-2008', 'dd-mm-yyyy'), '6', '20', '264', '09', '2008', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3187, to_date('21-09-2008', 'dd-mm-yyyy'), '7', '21', '265', '09', '2008', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3188, to_date('22-09-2008', 'dd-mm-yyyy'), '1', '22', '266', '09', '2008', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3189, to_date('23-09-2008', 'dd-mm-yyyy'), '2', '23', '267', '09', '2008', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3190, to_date('24-09-2008', 'dd-mm-yyyy'), '3', '24', '268', '09', '2008', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3191, to_date('25-09-2008', 'dd-mm-yyyy'), '4', '25', '269', '09', '2008', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3192, to_date('26-09-2008', 'dd-mm-yyyy'), '5', '26', '270', '09', '2008', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3193, to_date('27-09-2008', 'dd-mm-yyyy'), '6', '27', '271', '09', '2008', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3194, to_date('28-09-2008', 'dd-mm-yyyy'), '7', '28', '272', '09', '2008', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3195, to_date('29-09-2008', 'dd-mm-yyyy'), '1', '29', '273', '09', '2008', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3196, to_date('30-09-2008', 'dd-mm-yyyy'), '2', '30', '274', '09', '2008', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3197, to_date('01-10-2008', 'dd-mm-yyyy'), '3', '01', '275', '10', '2008', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3198, to_date('02-10-2008', 'dd-mm-yyyy'), '4', '02', '276', '10', '2008', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3199, to_date('03-10-2008', 'dd-mm-yyyy'), '5', '03', '277', '10', '2008', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3200, to_date('04-10-2008', 'dd-mm-yyyy'), '6', '04', '278', '10', '2008', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3201, to_date('05-10-2008', 'dd-mm-yyyy'), '7', '05', '279', '10', '2008', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3202, to_date('06-10-2008', 'dd-mm-yyyy'), '1', '06', '280', '10', '2008', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3203, to_date('07-10-2008', 'dd-mm-yyyy'), '2', '07', '281', '10', '2008', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3204, to_date('08-10-2008', 'dd-mm-yyyy'), '3', '08', '282', '10', '2008', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3205, to_date('09-10-2008', 'dd-mm-yyyy'), '4', '09', '283', '10', '2008', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3206, to_date('10-10-2008', 'dd-mm-yyyy'), '5', '10', '284', '10', '2008', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3207, to_date('11-10-2008', 'dd-mm-yyyy'), '6', '11', '285', '10', '2008', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3208, to_date('12-10-2008', 'dd-mm-yyyy'), '7', '12', '286', '10', '2008', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3209, to_date('13-10-2008', 'dd-mm-yyyy'), '1', '13', '287', '10', '2008', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3210, to_date('14-10-2008', 'dd-mm-yyyy'), '2', '14', '288', '10', '2008', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3211, to_date('15-10-2008', 'dd-mm-yyyy'), '3', '15', '289', '10', '2008', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3212, to_date('16-10-2008', 'dd-mm-yyyy'), '4', '16', '290', '10', '2008', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3213, to_date('17-10-2008', 'dd-mm-yyyy'), '5', '17', '291', '10', '2008', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3214, to_date('18-10-2008', 'dd-mm-yyyy'), '6', '18', '292', '10', '2008', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3215, to_date('19-10-2008', 'dd-mm-yyyy'), '7', '19', '293', '10', '2008', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3216, to_date('20-10-2008', 'dd-mm-yyyy'), '1', '20', '294', '10', '2008', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3217, to_date('21-10-2008', 'dd-mm-yyyy'), '2', '21', '295', '10', '2008', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3218, to_date('22-10-2008', 'dd-mm-yyyy'), '3', '22', '296', '10', '2008', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3219, to_date('23-10-2008', 'dd-mm-yyyy'), '4', '23', '297', '10', '2008', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3220, to_date('24-10-2008', 'dd-mm-yyyy'), '5', '24', '298', '10', '2008', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3221, to_date('25-10-2008', 'dd-mm-yyyy'), '6', '25', '299', '10', '2008', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3222, to_date('26-10-2008', 'dd-mm-yyyy'), '7', '26', '300', '10', '2008', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3223, to_date('27-10-2008', 'dd-mm-yyyy'), '1', '27', '301', '10', '2008', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3224, to_date('28-10-2008', 'dd-mm-yyyy'), '2', '28', '302', '10', '2008', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3225, to_date('29-10-2008', 'dd-mm-yyyy'), '3', '29', '303', '10', '2008', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3226, to_date('30-10-2008', 'dd-mm-yyyy'), '4', '30', '304', '10', '2008', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3227, to_date('31-10-2008', 'dd-mm-yyyy'), '5', '31', '305', '10', '2008', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3228, to_date('01-11-2008', 'dd-mm-yyyy'), '6', '01', '306', '11', '2008', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3229, to_date('02-11-2008', 'dd-mm-yyyy'), '7', '02', '307', '11', '2008', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3230, to_date('03-11-2008', 'dd-mm-yyyy'), '1', '03', '308', '11', '2008', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3231, to_date('04-11-2008', 'dd-mm-yyyy'), '2', '04', '309', '11', '2008', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3232, to_date('05-11-2008', 'dd-mm-yyyy'), '3', '05', '310', '11', '2008', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3233, to_date('06-11-2008', 'dd-mm-yyyy'), '4', '06', '311', '11', '2008', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3234, to_date('07-11-2008', 'dd-mm-yyyy'), '5', '07', '312', '11', '2008', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3235, to_date('08-11-2008', 'dd-mm-yyyy'), '6', '08', '313', '11', '2008', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3236, to_date('09-11-2008', 'dd-mm-yyyy'), '7', '09', '314', '11', '2008', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3237, to_date('10-11-2008', 'dd-mm-yyyy'), '1', '10', '315', '11', '2008', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3238, to_date('11-11-2008', 'dd-mm-yyyy'), '2', '11', '316', '11', '2008', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3239, to_date('12-11-2008', 'dd-mm-yyyy'), '3', '12', '317', '11', '2008', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3240, to_date('13-11-2008', 'dd-mm-yyyy'), '4', '13', '318', '11', '2008', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (3241, to_date('14-11-2008', 'dd-mm-yyyy'), '5', '14', '319', '11', '2008', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1622, to_date('09-06-2004', 'dd-mm-yyyy'), '3', '09', '161', '06', '2004', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1623, to_date('10-06-2004', 'dd-mm-yyyy'), '4', '10', '162', '06', '2004', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1624, to_date('11-06-2004', 'dd-mm-yyyy'), '5', '11', '163', '06', '2004', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1625, to_date('12-06-2004', 'dd-mm-yyyy'), '6', '12', '164', '06', '2004', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1626, to_date('13-06-2004', 'dd-mm-yyyy'), '7', '13', '165', '06', '2004', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1627, to_date('14-06-2004', 'dd-mm-yyyy'), '1', '14', '166', '06', '2004', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1628, to_date('15-06-2004', 'dd-mm-yyyy'), '2', '15', '167', '06', '2004', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1629, to_date('16-06-2004', 'dd-mm-yyyy'), '3', '16', '168', '06', '2004', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1630, to_date('17-06-2004', 'dd-mm-yyyy'), '4', '17', '169', '06', '2004', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1631, to_date('18-06-2004', 'dd-mm-yyyy'), '5', '18', '170', '06', '2004', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1632, to_date('19-06-2004', 'dd-mm-yyyy'), '6', '19', '171', '06', '2004', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1633, to_date('20-06-2004', 'dd-mm-yyyy'), '7', '20', '172', '06', '2004', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1634, to_date('21-06-2004', 'dd-mm-yyyy'), '1', '21', '173', '06', '2004', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1635, to_date('22-06-2004', 'dd-mm-yyyy'), '2', '22', '174', '06', '2004', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1636, to_date('23-06-2004', 'dd-mm-yyyy'), '3', '23', '175', '06', '2004', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1637, to_date('24-06-2004', 'dd-mm-yyyy'), '4', '24', '176', '06', '2004', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1638, to_date('25-06-2004', 'dd-mm-yyyy'), '5', '25', '177', '06', '2004', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1639, to_date('26-06-2004', 'dd-mm-yyyy'), '6', '26', '178', '06', '2004', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1640, to_date('27-06-2004', 'dd-mm-yyyy'), '7', '27', '179', '06', '2004', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1641, to_date('28-06-2004', 'dd-mm-yyyy'), '1', '28', '180', '06', '2004', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1642, to_date('29-06-2004', 'dd-mm-yyyy'), '2', '29', '181', '06', '2004', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1643, to_date('30-06-2004', 'dd-mm-yyyy'), '3', '30', '182', '06', '2004', '27', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1644, to_date('01-07-2004', 'dd-mm-yyyy'), '4', '01', '183', '07', '2004', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1645, to_date('02-07-2004', 'dd-mm-yyyy'), '5', '02', '184', '07', '2004', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1646, to_date('03-07-2004', 'dd-mm-yyyy'), '6', '03', '185', '07', '2004', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1647, to_date('04-07-2004', 'dd-mm-yyyy'), '7', '04', '186', '07', '2004', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1648, to_date('05-07-2004', 'dd-mm-yyyy'), '1', '05', '187', '07', '2004', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1649, to_date('06-07-2004', 'dd-mm-yyyy'), '2', '06', '188', '07', '2004', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1650, to_date('07-07-2004', 'dd-mm-yyyy'), '3', '07', '189', '07', '2004', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1651, to_date('08-07-2004', 'dd-mm-yyyy'), '4', '08', '190', '07', '2004', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1652, to_date('09-07-2004', 'dd-mm-yyyy'), '5', '09', '191', '07', '2004', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1653, to_date('10-07-2004', 'dd-mm-yyyy'), '6', '10', '192', '07', '2004', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1654, to_date('11-07-2004', 'dd-mm-yyyy'), '7', '11', '193', '07', '2004', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1655, to_date('12-07-2004', 'dd-mm-yyyy'), '1', '12', '194', '07', '2004', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1656, to_date('13-07-2004', 'dd-mm-yyyy'), '2', '13', '195', '07', '2004', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1657, to_date('14-07-2004', 'dd-mm-yyyy'), '3', '14', '196', '07', '2004', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1658, to_date('15-07-2004', 'dd-mm-yyyy'), '4', '15', '197', '07', '2004', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1659, to_date('16-07-2004', 'dd-mm-yyyy'), '5', '16', '198', '07', '2004', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1660, to_date('17-07-2004', 'dd-mm-yyyy'), '6', '17', '199', '07', '2004', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1661, to_date('18-07-2004', 'dd-mm-yyyy'), '7', '18', '200', '07', '2004', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1662, to_date('19-07-2004', 'dd-mm-yyyy'), '1', '19', '201', '07', '2004', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1663, to_date('20-07-2004', 'dd-mm-yyyy'), '2', '20', '202', '07', '2004', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1664, to_date('21-07-2004', 'dd-mm-yyyy'), '3', '21', '203', '07', '2004', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1665, to_date('22-07-2004', 'dd-mm-yyyy'), '4', '22', '204', '07', '2004', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1666, to_date('23-07-2004', 'dd-mm-yyyy'), '5', '23', '205', '07', '2004', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1667, to_date('24-07-2004', 'dd-mm-yyyy'), '6', '24', '206', '07', '2004', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1668, to_date('25-07-2004', 'dd-mm-yyyy'), '7', '25', '207', '07', '2004', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1669, to_date('26-07-2004', 'dd-mm-yyyy'), '1', '26', '208', '07', '2004', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1670, to_date('27-07-2004', 'dd-mm-yyyy'), '2', '27', '209', '07', '2004', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1671, to_date('28-07-2004', 'dd-mm-yyyy'), '3', '28', '210', '07', '2004', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1672, to_date('29-07-2004', 'dd-mm-yyyy'), '4', '29', '211', '07', '2004', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1673, to_date('30-07-2004', 'dd-mm-yyyy'), '5', '30', '212', '07', '2004', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1674, to_date('31-07-2004', 'dd-mm-yyyy'), '6', '31', '213', '07', '2004', '31', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1675, to_date('01-08-2004', 'dd-mm-yyyy'), '7', '01', '214', '08', '2004', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1676, to_date('02-08-2004', 'dd-mm-yyyy'), '1', '02', '215', '08', '2004', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1677, to_date('03-08-2004', 'dd-mm-yyyy'), '2', '03', '216', '08', '2004', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1678, to_date('04-08-2004', 'dd-mm-yyyy'), '3', '04', '217', '08', '2004', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1679, to_date('05-08-2004', 'dd-mm-yyyy'), '4', '05', '218', '08', '2004', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1680, to_date('06-08-2004', 'dd-mm-yyyy'), '5', '06', '219', '08', '2004', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1681, to_date('07-08-2004', 'dd-mm-yyyy'), '6', '07', '220', '08', '2004', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1682, to_date('08-08-2004', 'dd-mm-yyyy'), '7', '08', '221', '08', '2004', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1683, to_date('09-08-2004', 'dd-mm-yyyy'), '1', '09', '222', '08', '2004', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1684, to_date('10-08-2004', 'dd-mm-yyyy'), '2', '10', '223', '08', '2004', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1685, to_date('11-08-2004', 'dd-mm-yyyy'), '3', '11', '224', '08', '2004', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1686, to_date('12-08-2004', 'dd-mm-yyyy'), '4', '12', '225', '08', '2004', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1687, to_date('13-08-2004', 'dd-mm-yyyy'), '5', '13', '226', '08', '2004', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1688, to_date('14-08-2004', 'dd-mm-yyyy'), '6', '14', '227', '08', '2004', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1689, to_date('15-08-2004', 'dd-mm-yyyy'), '7', '15', '228', '08', '2004', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1690, to_date('16-08-2004', 'dd-mm-yyyy'), '1', '16', '229', '08', '2004', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1691, to_date('17-08-2004', 'dd-mm-yyyy'), '2', '17', '230', '08', '2004', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1692, to_date('18-08-2004', 'dd-mm-yyyy'), '3', '18', '231', '08', '2004', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1693, to_date('19-08-2004', 'dd-mm-yyyy'), '4', '19', '232', '08', '2004', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1694, to_date('20-08-2004', 'dd-mm-yyyy'), '5', '20', '233', '08', '2004', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1695, to_date('21-08-2004', 'dd-mm-yyyy'), '6', '21', '234', '08', '2004', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1696, to_date('22-08-2004', 'dd-mm-yyyy'), '7', '22', '235', '08', '2004', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1697, to_date('23-08-2004', 'dd-mm-yyyy'), '1', '23', '236', '08', '2004', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1698, to_date('24-08-2004', 'dd-mm-yyyy'), '2', '24', '237', '08', '2004', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1699, to_date('25-08-2004', 'dd-mm-yyyy'), '3', '25', '238', '08', '2004', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1700, to_date('26-08-2004', 'dd-mm-yyyy'), '4', '26', '239', '08', '2004', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1701, to_date('27-08-2004', 'dd-mm-yyyy'), '5', '27', '240', '08', '2004', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1702, to_date('28-08-2004', 'dd-mm-yyyy'), '6', '28', '241', '08', '2004', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1703, to_date('29-08-2004', 'dd-mm-yyyy'), '7', '29', '242', '08', '2004', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1704, to_date('30-08-2004', 'dd-mm-yyyy'), '1', '30', '243', '08', '2004', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1705, to_date('31-08-2004', 'dd-mm-yyyy'), '2', '31', '244', '08', '2004', '36', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1706, to_date('01-09-2004', 'dd-mm-yyyy'), '3', '01', '245', '09', '2004', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1707, to_date('02-09-2004', 'dd-mm-yyyy'), '4', '02', '246', '09', '2004', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1708, to_date('03-09-2004', 'dd-mm-yyyy'), '5', '03', '247', '09', '2004', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1709, to_date('04-09-2004', 'dd-mm-yyyy'), '6', '04', '248', '09', '2004', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1710, to_date('05-09-2004', 'dd-mm-yyyy'), '7', '05', '249', '09', '2004', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1711, to_date('06-09-2004', 'dd-mm-yyyy'), '1', '06', '250', '09', '2004', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1712, to_date('07-09-2004', 'dd-mm-yyyy'), '2', '07', '251', '09', '2004', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1713, to_date('08-09-2004', 'dd-mm-yyyy'), '3', '08', '252', '09', '2004', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1714, to_date('09-09-2004', 'dd-mm-yyyy'), '4', '09', '253', '09', '2004', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1715, to_date('10-09-2004', 'dd-mm-yyyy'), '5', '10', '254', '09', '2004', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1716, to_date('11-09-2004', 'dd-mm-yyyy'), '6', '11', '255', '09', '2004', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1717, to_date('12-09-2004', 'dd-mm-yyyy'), '7', '12', '256', '09', '2004', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1718, to_date('13-09-2004', 'dd-mm-yyyy'), '1', '13', '257', '09', '2004', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1719, to_date('14-09-2004', 'dd-mm-yyyy'), '2', '14', '258', '09', '2004', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1720, to_date('15-09-2004', 'dd-mm-yyyy'), '3', '15', '259', '09', '2004', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1721, to_date('16-09-2004', 'dd-mm-yyyy'), '4', '16', '260', '09', '2004', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1722, to_date('17-09-2004', 'dd-mm-yyyy'), '5', '17', '261', '09', '2004', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1723, to_date('18-09-2004', 'dd-mm-yyyy'), '6', '18', '262', '09', '2004', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1724, to_date('19-09-2004', 'dd-mm-yyyy'), '7', '19', '263', '09', '2004', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1725, to_date('20-09-2004', 'dd-mm-yyyy'), '1', '20', '264', '09', '2004', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1726, to_date('21-09-2004', 'dd-mm-yyyy'), '2', '21', '265', '09', '2004', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1727, to_date('22-09-2004', 'dd-mm-yyyy'), '3', '22', '266', '09', '2004', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1728, to_date('23-09-2004', 'dd-mm-yyyy'), '4', '23', '267', '09', '2004', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1729, to_date('24-09-2004', 'dd-mm-yyyy'), '5', '24', '268', '09', '2004', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1730, to_date('25-09-2004', 'dd-mm-yyyy'), '6', '25', '269', '09', '2004', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1731, to_date('26-09-2004', 'dd-mm-yyyy'), '7', '26', '270', '09', '2004', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1732, to_date('27-09-2004', 'dd-mm-yyyy'), '1', '27', '271', '09', '2004', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1733, to_date('28-09-2004', 'dd-mm-yyyy'), '2', '28', '272', '09', '2004', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1734, to_date('29-09-2004', 'dd-mm-yyyy'), '3', '29', '273', '09', '2004', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1735, to_date('30-09-2004', 'dd-mm-yyyy'), '4', '30', '274', '09', '2004', '40', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1736, to_date('01-10-2004', 'dd-mm-yyyy'), '5', '01', '275', '10', '2004', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1737, to_date('02-10-2004', 'dd-mm-yyyy'), '6', '02', '276', '10', '2004', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1738, to_date('03-10-2004', 'dd-mm-yyyy'), '7', '03', '277', '10', '2004', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1739, to_date('04-10-2004', 'dd-mm-yyyy'), '1', '04', '278', '10', '2004', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1740, to_date('05-10-2004', 'dd-mm-yyyy'), '2', '05', '279', '10', '2004', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1741, to_date('06-10-2004', 'dd-mm-yyyy'), '3', '06', '280', '10', '2004', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1742, to_date('07-10-2004', 'dd-mm-yyyy'), '4', '07', '281', '10', '2004', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1743, to_date('08-10-2004', 'dd-mm-yyyy'), '5', '08', '282', '10', '2004', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1744, to_date('09-10-2004', 'dd-mm-yyyy'), '6', '09', '283', '10', '2004', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1745, to_date('10-10-2004', 'dd-mm-yyyy'), '7', '10', '284', '10', '2004', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1746, to_date('11-10-2004', 'dd-mm-yyyy'), '1', '11', '285', '10', '2004', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1747, to_date('12-10-2004', 'dd-mm-yyyy'), '2', '12', '286', '10', '2004', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1748, to_date('13-10-2004', 'dd-mm-yyyy'), '3', '13', '287', '10', '2004', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1749, to_date('14-10-2004', 'dd-mm-yyyy'), '4', '14', '288', '10', '2004', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1750, to_date('15-10-2004', 'dd-mm-yyyy'), '5', '15', '289', '10', '2004', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1751, to_date('16-10-2004', 'dd-mm-yyyy'), '6', '16', '290', '10', '2004', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1752, to_date('17-10-2004', 'dd-mm-yyyy'), '7', '17', '291', '10', '2004', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1753, to_date('18-10-2004', 'dd-mm-yyyy'), '1', '18', '292', '10', '2004', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1754, to_date('19-10-2004', 'dd-mm-yyyy'), '2', '19', '293', '10', '2004', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1755, to_date('20-10-2004', 'dd-mm-yyyy'), '3', '20', '294', '10', '2004', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1756, to_date('21-10-2004', 'dd-mm-yyyy'), '4', '21', '295', '10', '2004', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1757, to_date('22-10-2004', 'dd-mm-yyyy'), '5', '22', '296', '10', '2004', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1758, to_date('23-10-2004', 'dd-mm-yyyy'), '6', '23', '297', '10', '2004', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1759, to_date('24-10-2004', 'dd-mm-yyyy'), '7', '24', '298', '10', '2004', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1760, to_date('25-10-2004', 'dd-mm-yyyy'), '1', '25', '299', '10', '2004', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1761, to_date('26-10-2004', 'dd-mm-yyyy'), '2', '26', '300', '10', '2004', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1762, to_date('27-10-2004', 'dd-mm-yyyy'), '3', '27', '301', '10', '2004', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1763, to_date('28-10-2004', 'dd-mm-yyyy'), '4', '28', '302', '10', '2004', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1764, to_date('29-10-2004', 'dd-mm-yyyy'), '5', '29', '303', '10', '2004', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1765, to_date('30-10-2004', 'dd-mm-yyyy'), '6', '30', '304', '10', '2004', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1766, to_date('31-10-2004', 'dd-mm-yyyy'), '7', '31', '305', '10', '2004', '44', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1767, to_date('01-11-2004', 'dd-mm-yyyy'), '1', '01', '306', '11', '2004', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1768, to_date('02-11-2004', 'dd-mm-yyyy'), '2', '02', '307', '11', '2004', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1769, to_date('03-11-2004', 'dd-mm-yyyy'), '3', '03', '308', '11', '2004', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1770, to_date('04-11-2004', 'dd-mm-yyyy'), '4', '04', '309', '11', '2004', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1771, to_date('05-11-2004', 'dd-mm-yyyy'), '5', '05', '310', '11', '2004', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1772, to_date('06-11-2004', 'dd-mm-yyyy'), '6', '06', '311', '11', '2004', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1773, to_date('07-11-2004', 'dd-mm-yyyy'), '7', '07', '312', '11', '2004', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1774, to_date('08-11-2004', 'dd-mm-yyyy'), '1', '08', '313', '11', '2004', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1775, to_date('09-11-2004', 'dd-mm-yyyy'), '2', '09', '314', '11', '2004', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1776, to_date('10-11-2004', 'dd-mm-yyyy'), '3', '10', '315', '11', '2004', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1777, to_date('11-11-2004', 'dd-mm-yyyy'), '4', '11', '316', '11', '2004', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1778, to_date('12-11-2004', 'dd-mm-yyyy'), '5', '12', '317', '11', '2004', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1779, to_date('13-11-2004', 'dd-mm-yyyy'), '6', '13', '318', '11', '2004', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1780, to_date('14-11-2004', 'dd-mm-yyyy'), '7', '14', '319', '11', '2004', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1781, to_date('15-11-2004', 'dd-mm-yyyy'), '1', '15', '320', '11', '2004', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1782, to_date('16-11-2004', 'dd-mm-yyyy'), '2', '16', '321', '11', '2004', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1783, to_date('17-11-2004', 'dd-mm-yyyy'), '3', '17', '322', '11', '2004', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1784, to_date('18-11-2004', 'dd-mm-yyyy'), '4', '18', '323', '11', '2004', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1785, to_date('19-11-2004', 'dd-mm-yyyy'), '5', '19', '324', '11', '2004', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1786, to_date('20-11-2004', 'dd-mm-yyyy'), '6', '20', '325', '11', '2004', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1787, to_date('21-11-2004', 'dd-mm-yyyy'), '7', '21', '326', '11', '2004', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1788, to_date('22-11-2004', 'dd-mm-yyyy'), '1', '22', '327', '11', '2004', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1789, to_date('23-11-2004', 'dd-mm-yyyy'), '2', '23', '328', '11', '2004', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1790, to_date('24-11-2004', 'dd-mm-yyyy'), '3', '24', '329', '11', '2004', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1791, to_date('25-11-2004', 'dd-mm-yyyy'), '4', '25', '330', '11', '2004', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1792, to_date('26-11-2004', 'dd-mm-yyyy'), '5', '26', '331', '11', '2004', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1793, to_date('27-11-2004', 'dd-mm-yyyy'), '6', '27', '332', '11', '2004', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1794, to_date('28-11-2004', 'dd-mm-yyyy'), '7', '28', '333', '11', '2004', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1795, to_date('29-11-2004', 'dd-mm-yyyy'), '1', '29', '334', '11', '2004', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1796, to_date('30-11-2004', 'dd-mm-yyyy'), '2', '30', '335', '11', '2004', '49', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1797, to_date('01-12-2004', 'dd-mm-yyyy'), '3', '01', '336', '12', '2004', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1798, to_date('02-12-2004', 'dd-mm-yyyy'), '4', '02', '337', '12', '2004', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1799, to_date('03-12-2004', 'dd-mm-yyyy'), '5', '03', '338', '12', '2004', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1800, to_date('04-12-2004', 'dd-mm-yyyy'), '6', '04', '339', '12', '2004', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1801, to_date('05-12-2004', 'dd-mm-yyyy'), '7', '05', '340', '12', '2004', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1802, to_date('06-12-2004', 'dd-mm-yyyy'), '1', '06', '341', '12', '2004', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1803, to_date('07-12-2004', 'dd-mm-yyyy'), '2', '07', '342', '12', '2004', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1804, to_date('08-12-2004', 'dd-mm-yyyy'), '3', '08', '343', '12', '2004', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1805, to_date('09-12-2004', 'dd-mm-yyyy'), '4', '09', '344', '12', '2004', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1806, to_date('10-12-2004', 'dd-mm-yyyy'), '5', '10', '345', '12', '2004', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1807, to_date('11-12-2004', 'dd-mm-yyyy'), '6', '11', '346', '12', '2004', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1808, to_date('12-12-2004', 'dd-mm-yyyy'), '7', '12', '347', '12', '2004', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1809, to_date('13-12-2004', 'dd-mm-yyyy'), '1', '13', '348', '12', '2004', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1810, to_date('14-12-2004', 'dd-mm-yyyy'), '2', '14', '349', '12', '2004', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1811, to_date('15-12-2004', 'dd-mm-yyyy'), '3', '15', '350', '12', '2004', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1812, to_date('16-12-2004', 'dd-mm-yyyy'), '4', '16', '351', '12', '2004', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1813, to_date('17-12-2004', 'dd-mm-yyyy'), '5', '17', '352', '12', '2004', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1814, to_date('18-12-2004', 'dd-mm-yyyy'), '6', '18', '353', '12', '2004', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1815, to_date('19-12-2004', 'dd-mm-yyyy'), '7', '19', '354', '12', '2004', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1816, to_date('20-12-2004', 'dd-mm-yyyy'), '1', '20', '355', '12', '2004', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1817, to_date('21-12-2004', 'dd-mm-yyyy'), '2', '21', '356', '12', '2004', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1818, to_date('22-12-2004', 'dd-mm-yyyy'), '3', '22', '357', '12', '2004', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1819, to_date('23-12-2004', 'dd-mm-yyyy'), '4', '23', '358', '12', '2004', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1820, to_date('24-12-2004', 'dd-mm-yyyy'), '5', '24', '359', '12', '2004', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1821, to_date('25-12-2004', 'dd-mm-yyyy'), '6', '25', '360', '12', '2004', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1822, to_date('26-12-2004', 'dd-mm-yyyy'), '7', '26', '361', '12', '2004', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1823, to_date('27-12-2004', 'dd-mm-yyyy'), '1', '27', '362', '12', '2004', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1824, to_date('28-12-2004', 'dd-mm-yyyy'), '2', '28', '363', '12', '2004', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1825, to_date('29-12-2004', 'dd-mm-yyyy'), '3', '29', '364', '12', '2004', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1826, to_date('30-12-2004', 'dd-mm-yyyy'), '4', '30', '365', '12', '2004', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1827, to_date('31-12-2004', 'dd-mm-yyyy'), '5', '31', '366', '12', '2004', '53', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1828, to_date('01-01-2005', 'dd-mm-yyyy'), '6', '01', '001', '01', '2005', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1829, to_date('02-01-2005', 'dd-mm-yyyy'), '7', '02', '002', '01', '2005', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1830, to_date('03-01-2005', 'dd-mm-yyyy'), '1', '03', '003', '01', '2005', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1831, to_date('04-01-2005', 'dd-mm-yyyy'), '2', '04', '004', '01', '2005', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1832, to_date('05-01-2005', 'dd-mm-yyyy'), '3', '05', '005', '01', '2005', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1833, to_date('06-01-2005', 'dd-mm-yyyy'), '4', '06', '006', '01', '2005', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1834, to_date('07-01-2005', 'dd-mm-yyyy'), '5', '07', '007', '01', '2005', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1835, to_date('08-01-2005', 'dd-mm-yyyy'), '6', '08', '008', '01', '2005', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1836, to_date('09-01-2005', 'dd-mm-yyyy'), '7', '09', '009', '01', '2005', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1837, to_date('10-01-2005', 'dd-mm-yyyy'), '1', '10', '010', '01', '2005', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1838, to_date('11-01-2005', 'dd-mm-yyyy'), '2', '11', '011', '01', '2005', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1839, to_date('12-01-2005', 'dd-mm-yyyy'), '3', '12', '012', '01', '2005', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1840, to_date('13-01-2005', 'dd-mm-yyyy'), '4', '13', '013', '01', '2005', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
commit;
prompt 4000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1841, to_date('14-01-2005', 'dd-mm-yyyy'), '5', '14', '014', '01', '2005', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1842, to_date('15-01-2005', 'dd-mm-yyyy'), '6', '15', '015', '01', '2005', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1843, to_date('16-01-2005', 'dd-mm-yyyy'), '7', '16', '016', '01', '2005', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1844, to_date('17-01-2005', 'dd-mm-yyyy'), '1', '17', '017', '01', '2005', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1845, to_date('18-01-2005', 'dd-mm-yyyy'), '2', '18', '018', '01', '2005', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1846, to_date('19-01-2005', 'dd-mm-yyyy'), '3', '19', '019', '01', '2005', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1847, to_date('20-01-2005', 'dd-mm-yyyy'), '4', '20', '020', '01', '2005', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1848, to_date('21-01-2005', 'dd-mm-yyyy'), '5', '21', '021', '01', '2005', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1849, to_date('22-01-2005', 'dd-mm-yyyy'), '6', '22', '022', '01', '2005', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1850, to_date('23-01-2005', 'dd-mm-yyyy'), '7', '23', '023', '01', '2005', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1851, to_date('24-01-2005', 'dd-mm-yyyy'), '1', '24', '024', '01', '2005', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1852, to_date('25-01-2005', 'dd-mm-yyyy'), '2', '25', '025', '01', '2005', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1853, to_date('26-01-2005', 'dd-mm-yyyy'), '3', '26', '026', '01', '2005', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1854, to_date('27-01-2005', 'dd-mm-yyyy'), '4', '27', '027', '01', '2005', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1855, to_date('28-01-2005', 'dd-mm-yyyy'), '5', '28', '028', '01', '2005', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1856, to_date('29-01-2005', 'dd-mm-yyyy'), '6', '29', '029', '01', '2005', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1857, to_date('30-01-2005', 'dd-mm-yyyy'), '7', '30', '030', '01', '2005', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1858, to_date('31-01-2005', 'dd-mm-yyyy'), '1', '31', '031', '01', '2005', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1859, to_date('01-02-2005', 'dd-mm-yyyy'), '2', '01', '032', '02', '2005', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1860, to_date('02-02-2005', 'dd-mm-yyyy'), '3', '02', '033', '02', '2005', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1861, to_date('03-02-2005', 'dd-mm-yyyy'), '4', '03', '034', '02', '2005', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1862, to_date('04-02-2005', 'dd-mm-yyyy'), '5', '04', '035', '02', '2005', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1863, to_date('05-02-2005', 'dd-mm-yyyy'), '6', '05', '036', '02', '2005', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1864, to_date('06-02-2005', 'dd-mm-yyyy'), '7', '06', '037', '02', '2005', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1865, to_date('07-02-2005', 'dd-mm-yyyy'), '1', '07', '038', '02', '2005', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1866, to_date('08-02-2005', 'dd-mm-yyyy'), '2', '08', '039', '02', '2005', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1867, to_date('09-02-2005', 'dd-mm-yyyy'), '3', '09', '040', '02', '2005', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1868, to_date('10-02-2005', 'dd-mm-yyyy'), '4', '10', '041', '02', '2005', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1869, to_date('11-02-2005', 'dd-mm-yyyy'), '5', '11', '042', '02', '2005', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1870, to_date('12-02-2005', 'dd-mm-yyyy'), '6', '12', '043', '02', '2005', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1871, to_date('13-02-2005', 'dd-mm-yyyy'), '7', '13', '044', '02', '2005', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1872, to_date('14-02-2005', 'dd-mm-yyyy'), '1', '14', '045', '02', '2005', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1873, to_date('15-02-2005', 'dd-mm-yyyy'), '2', '15', '046', '02', '2005', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1874, to_date('16-02-2005', 'dd-mm-yyyy'), '3', '16', '047', '02', '2005', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1875, to_date('17-02-2005', 'dd-mm-yyyy'), '4', '17', '048', '02', '2005', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1876, to_date('18-02-2005', 'dd-mm-yyyy'), '5', '18', '049', '02', '2005', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1877, to_date('19-02-2005', 'dd-mm-yyyy'), '6', '19', '050', '02', '2005', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1878, to_date('20-02-2005', 'dd-mm-yyyy'), '7', '20', '051', '02', '2005', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1879, to_date('21-02-2005', 'dd-mm-yyyy'), '1', '21', '052', '02', '2005', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1880, to_date('22-02-2005', 'dd-mm-yyyy'), '2', '22', '053', '02', '2005', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1881, to_date('23-02-2005', 'dd-mm-yyyy'), '3', '23', '054', '02', '2005', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1882, to_date('24-02-2005', 'dd-mm-yyyy'), '4', '24', '055', '02', '2005', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1883, to_date('25-02-2005', 'dd-mm-yyyy'), '5', '25', '056', '02', '2005', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1884, to_date('26-02-2005', 'dd-mm-yyyy'), '6', '26', '057', '02', '2005', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1885, to_date('27-02-2005', 'dd-mm-yyyy'), '7', '27', '058', '02', '2005', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1886, to_date('28-02-2005', 'dd-mm-yyyy'), '1', '28', '059', '02', '2005', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1887, to_date('01-03-2005', 'dd-mm-yyyy'), '2', '01', '060', '03', '2005', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1888, to_date('02-03-2005', 'dd-mm-yyyy'), '3', '02', '061', '03', '2005', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1889, to_date('03-03-2005', 'dd-mm-yyyy'), '4', '03', '062', '03', '2005', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1890, to_date('04-03-2005', 'dd-mm-yyyy'), '5', '04', '063', '03', '2005', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1891, to_date('05-03-2005', 'dd-mm-yyyy'), '6', '05', '064', '03', '2005', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1892, to_date('06-03-2005', 'dd-mm-yyyy'), '7', '06', '065', '03', '2005', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1893, to_date('07-03-2005', 'dd-mm-yyyy'), '1', '07', '066', '03', '2005', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1894, to_date('08-03-2005', 'dd-mm-yyyy'), '2', '08', '067', '03', '2005', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1895, to_date('09-03-2005', 'dd-mm-yyyy'), '3', '09', '068', '03', '2005', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1896, to_date('10-03-2005', 'dd-mm-yyyy'), '4', '10', '069', '03', '2005', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1897, to_date('11-03-2005', 'dd-mm-yyyy'), '5', '11', '070', '03', '2005', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1898, to_date('12-03-2005', 'dd-mm-yyyy'), '6', '12', '071', '03', '2005', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1899, to_date('13-03-2005', 'dd-mm-yyyy'), '7', '13', '072', '03', '2005', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1900, to_date('14-03-2005', 'dd-mm-yyyy'), '1', '14', '073', '03', '2005', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1901, to_date('15-03-2005', 'dd-mm-yyyy'), '2', '15', '074', '03', '2005', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1902, to_date('16-03-2005', 'dd-mm-yyyy'), '3', '16', '075', '03', '2005', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1903, to_date('17-03-2005', 'dd-mm-yyyy'), '4', '17', '076', '03', '2005', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1904, to_date('18-03-2005', 'dd-mm-yyyy'), '5', '18', '077', '03', '2005', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1905, to_date('19-03-2005', 'dd-mm-yyyy'), '6', '19', '078', '03', '2005', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1906, to_date('20-03-2005', 'dd-mm-yyyy'), '7', '20', '079', '03', '2005', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1907, to_date('21-03-2005', 'dd-mm-yyyy'), '1', '21', '080', '03', '2005', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1908, to_date('22-03-2005', 'dd-mm-yyyy'), '2', '22', '081', '03', '2005', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1909, to_date('23-03-2005', 'dd-mm-yyyy'), '3', '23', '082', '03', '2005', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1910, to_date('24-03-2005', 'dd-mm-yyyy'), '4', '24', '083', '03', '2005', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1911, to_date('25-03-2005', 'dd-mm-yyyy'), '5', '25', '084', '03', '2005', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1912, to_date('26-03-2005', 'dd-mm-yyyy'), '6', '26', '085', '03', '2005', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1913, to_date('27-03-2005', 'dd-mm-yyyy'), '7', '27', '086', '03', '2005', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1914, to_date('28-03-2005', 'dd-mm-yyyy'), '1', '28', '087', '03', '2005', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1915, to_date('29-03-2005', 'dd-mm-yyyy'), '2', '29', '088', '03', '2005', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1916, to_date('30-03-2005', 'dd-mm-yyyy'), '3', '30', '089', '03', '2005', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1917, to_date('31-03-2005', 'dd-mm-yyyy'), '4', '31', '090', '03', '2005', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1918, to_date('01-04-2005', 'dd-mm-yyyy'), '5', '01', '091', '04', '2005', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1919, to_date('02-04-2005', 'dd-mm-yyyy'), '6', '02', '092', '04', '2005', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1920, to_date('03-04-2005', 'dd-mm-yyyy'), '7', '03', '093', '04', '2005', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1921, to_date('04-04-2005', 'dd-mm-yyyy'), '1', '04', '094', '04', '2005', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1922, to_date('05-04-2005', 'dd-mm-yyyy'), '2', '05', '095', '04', '2005', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1923, to_date('06-04-2005', 'dd-mm-yyyy'), '3', '06', '096', '04', '2005', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1924, to_date('07-04-2005', 'dd-mm-yyyy'), '4', '07', '097', '04', '2005', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1925, to_date('08-04-2005', 'dd-mm-yyyy'), '5', '08', '098', '04', '2005', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1926, to_date('09-04-2005', 'dd-mm-yyyy'), '6', '09', '099', '04', '2005', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1927, to_date('10-04-2005', 'dd-mm-yyyy'), '7', '10', '100', '04', '2005', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1928, to_date('11-04-2005', 'dd-mm-yyyy'), '1', '11', '101', '04', '2005', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1929, to_date('12-04-2005', 'dd-mm-yyyy'), '2', '12', '102', '04', '2005', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1930, to_date('13-04-2005', 'dd-mm-yyyy'), '3', '13', '103', '04', '2005', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1931, to_date('14-04-2005', 'dd-mm-yyyy'), '4', '14', '104', '04', '2005', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1932, to_date('15-04-2005', 'dd-mm-yyyy'), '5', '15', '105', '04', '2005', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1933, to_date('16-04-2005', 'dd-mm-yyyy'), '6', '16', '106', '04', '2005', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1934, to_date('17-04-2005', 'dd-mm-yyyy'), '7', '17', '107', '04', '2005', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1935, to_date('18-04-2005', 'dd-mm-yyyy'), '1', '18', '108', '04', '2005', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1936, to_date('19-04-2005', 'dd-mm-yyyy'), '2', '19', '109', '04', '2005', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1937, to_date('20-04-2005', 'dd-mm-yyyy'), '3', '20', '110', '04', '2005', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1938, to_date('21-04-2005', 'dd-mm-yyyy'), '4', '21', '111', '04', '2005', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1939, to_date('22-04-2005', 'dd-mm-yyyy'), '5', '22', '112', '04', '2005', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1940, to_date('23-04-2005', 'dd-mm-yyyy'), '6', '23', '113', '04', '2005', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1941, to_date('24-04-2005', 'dd-mm-yyyy'), '7', '24', '114', '04', '2005', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1942, to_date('25-04-2005', 'dd-mm-yyyy'), '1', '25', '115', '04', '2005', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1943, to_date('26-04-2005', 'dd-mm-yyyy'), '2', '26', '116', '04', '2005', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1944, to_date('27-04-2005', 'dd-mm-yyyy'), '3', '27', '117', '04', '2005', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1945, to_date('28-04-2005', 'dd-mm-yyyy'), '4', '28', '118', '04', '2005', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1946, to_date('29-04-2005', 'dd-mm-yyyy'), '5', '29', '119', '04', '2005', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1947, to_date('30-04-2005', 'dd-mm-yyyy'), '6', '30', '120', '04', '2005', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1948, to_date('01-05-2005', 'dd-mm-yyyy'), '7', '01', '121', '05', '2005', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1949, to_date('02-05-2005', 'dd-mm-yyyy'), '1', '02', '122', '05', '2005', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1950, to_date('03-05-2005', 'dd-mm-yyyy'), '2', '03', '123', '05', '2005', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1951, to_date('04-05-2005', 'dd-mm-yyyy'), '3', '04', '124', '05', '2005', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1952, to_date('05-05-2005', 'dd-mm-yyyy'), '4', '05', '125', '05', '2005', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1953, to_date('06-05-2005', 'dd-mm-yyyy'), '5', '06', '126', '05', '2005', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1954, to_date('07-05-2005', 'dd-mm-yyyy'), '6', '07', '127', '05', '2005', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1955, to_date('08-05-2005', 'dd-mm-yyyy'), '7', '08', '128', '05', '2005', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1956, to_date('09-05-2005', 'dd-mm-yyyy'), '1', '09', '129', '05', '2005', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1957, to_date('10-05-2005', 'dd-mm-yyyy'), '2', '10', '130', '05', '2005', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1958, to_date('11-05-2005', 'dd-mm-yyyy'), '3', '11', '131', '05', '2005', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1959, to_date('12-05-2005', 'dd-mm-yyyy'), '4', '12', '132', '05', '2005', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1960, to_date('13-05-2005', 'dd-mm-yyyy'), '5', '13', '133', '05', '2005', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1961, to_date('14-05-2005', 'dd-mm-yyyy'), '6', '14', '134', '05', '2005', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1962, to_date('15-05-2005', 'dd-mm-yyyy'), '7', '15', '135', '05', '2005', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1963, to_date('16-05-2005', 'dd-mm-yyyy'), '1', '16', '136', '05', '2005', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1964, to_date('17-05-2005', 'dd-mm-yyyy'), '2', '17', '137', '05', '2005', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1965, to_date('18-05-2005', 'dd-mm-yyyy'), '3', '18', '138', '05', '2005', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1966, to_date('19-05-2005', 'dd-mm-yyyy'), '4', '19', '139', '05', '2005', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1967, to_date('20-05-2005', 'dd-mm-yyyy'), '5', '20', '140', '05', '2005', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1968, to_date('21-05-2005', 'dd-mm-yyyy'), '6', '21', '141', '05', '2005', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1969, to_date('22-05-2005', 'dd-mm-yyyy'), '7', '22', '142', '05', '2005', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1970, to_date('23-05-2005', 'dd-mm-yyyy'), '1', '23', '143', '05', '2005', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1971, to_date('24-05-2005', 'dd-mm-yyyy'), '2', '24', '144', '05', '2005', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1972, to_date('25-05-2005', 'dd-mm-yyyy'), '3', '25', '145', '05', '2005', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1973, to_date('26-05-2005', 'dd-mm-yyyy'), '4', '26', '146', '05', '2005', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1974, to_date('27-05-2005', 'dd-mm-yyyy'), '5', '27', '147', '05', '2005', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1975, to_date('28-05-2005', 'dd-mm-yyyy'), '6', '28', '148', '05', '2005', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1976, to_date('29-05-2005', 'dd-mm-yyyy'), '7', '29', '149', '05', '2005', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1977, to_date('30-05-2005', 'dd-mm-yyyy'), '1', '30', '150', '05', '2005', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1978, to_date('31-05-2005', 'dd-mm-yyyy'), '2', '31', '151', '05', '2005', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1979, to_date('01-06-2005', 'dd-mm-yyyy'), '3', '01', '152', '06', '2005', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1980, to_date('02-06-2005', 'dd-mm-yyyy'), '4', '02', '153', '06', '2005', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1981, to_date('03-06-2005', 'dd-mm-yyyy'), '5', '03', '154', '06', '2005', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1982, to_date('04-06-2005', 'dd-mm-yyyy'), '6', '04', '155', '06', '2005', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1983, to_date('05-06-2005', 'dd-mm-yyyy'), '7', '05', '156', '06', '2005', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1984, to_date('06-06-2005', 'dd-mm-yyyy'), '1', '06', '157', '06', '2005', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1985, to_date('07-06-2005', 'dd-mm-yyyy'), '2', '07', '158', '06', '2005', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1986, to_date('08-06-2005', 'dd-mm-yyyy'), '3', '08', '159', '06', '2005', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1987, to_date('09-06-2005', 'dd-mm-yyyy'), '4', '09', '160', '06', '2005', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1988, to_date('10-06-2005', 'dd-mm-yyyy'), '5', '10', '161', '06', '2005', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1989, to_date('11-06-2005', 'dd-mm-yyyy'), '6', '11', '162', '06', '2005', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1990, to_date('12-06-2005', 'dd-mm-yyyy'), '7', '12', '163', '06', '2005', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1991, to_date('13-06-2005', 'dd-mm-yyyy'), '1', '13', '164', '06', '2005', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1992, to_date('14-06-2005', 'dd-mm-yyyy'), '2', '14', '165', '06', '2005', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1993, to_date('15-06-2005', 'dd-mm-yyyy'), '3', '15', '166', '06', '2005', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1994, to_date('16-06-2005', 'dd-mm-yyyy'), '4', '16', '167', '06', '2005', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1995, to_date('17-06-2005', 'dd-mm-yyyy'), '5', '17', '168', '06', '2005', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1996, to_date('18-06-2005', 'dd-mm-yyyy'), '6', '18', '169', '06', '2005', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1997, to_date('19-06-2005', 'dd-mm-yyyy'), '7', '19', '170', '06', '2005', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1998, to_date('20-06-2005', 'dd-mm-yyyy'), '1', '20', '171', '06', '2005', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (1999, to_date('21-06-2005', 'dd-mm-yyyy'), '2', '21', '172', '06', '2005', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2000, to_date('22-06-2005', 'dd-mm-yyyy'), '3', '22', '173', '06', '2005', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2001, to_date('23-06-2005', 'dd-mm-yyyy'), '4', '23', '174', '06', '2005', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2002, to_date('24-06-2005', 'dd-mm-yyyy'), '5', '24', '175', '06', '2005', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2003, to_date('25-06-2005', 'dd-mm-yyyy'), '6', '25', '176', '06', '2005', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2004, to_date('26-06-2005', 'dd-mm-yyyy'), '7', '26', '177', '06', '2005', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2005, to_date('27-06-2005', 'dd-mm-yyyy'), '1', '27', '178', '06', '2005', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2006, to_date('28-06-2005', 'dd-mm-yyyy'), '2', '28', '179', '06', '2005', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2007, to_date('29-06-2005', 'dd-mm-yyyy'), '3', '29', '180', '06', '2005', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2008, to_date('30-06-2005', 'dd-mm-yyyy'), '4', '30', '181', '06', '2005', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2009, to_date('01-07-2005', 'dd-mm-yyyy'), '5', '01', '182', '07', '2005', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2010, to_date('02-07-2005', 'dd-mm-yyyy'), '6', '02', '183', '07', '2005', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2011, to_date('03-07-2005', 'dd-mm-yyyy'), '7', '03', '184', '07', '2005', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2012, to_date('04-07-2005', 'dd-mm-yyyy'), '1', '04', '185', '07', '2005', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2013, to_date('05-07-2005', 'dd-mm-yyyy'), '2', '05', '186', '07', '2005', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2014, to_date('06-07-2005', 'dd-mm-yyyy'), '3', '06', '187', '07', '2005', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2015, to_date('07-07-2005', 'dd-mm-yyyy'), '4', '07', '188', '07', '2005', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2016, to_date('08-07-2005', 'dd-mm-yyyy'), '5', '08', '189', '07', '2005', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2017, to_date('09-07-2005', 'dd-mm-yyyy'), '6', '09', '190', '07', '2005', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2018, to_date('10-07-2005', 'dd-mm-yyyy'), '7', '10', '191', '07', '2005', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2019, to_date('11-07-2005', 'dd-mm-yyyy'), '1', '11', '192', '07', '2005', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2020, to_date('12-07-2005', 'dd-mm-yyyy'), '2', '12', '193', '07', '2005', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2021, to_date('13-07-2005', 'dd-mm-yyyy'), '3', '13', '194', '07', '2005', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2022, to_date('14-07-2005', 'dd-mm-yyyy'), '4', '14', '195', '07', '2005', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2023, to_date('15-07-2005', 'dd-mm-yyyy'), '5', '15', '196', '07', '2005', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2024, to_date('16-07-2005', 'dd-mm-yyyy'), '6', '16', '197', '07', '2005', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2025, to_date('17-07-2005', 'dd-mm-yyyy'), '7', '17', '198', '07', '2005', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2026, to_date('18-07-2005', 'dd-mm-yyyy'), '1', '18', '199', '07', '2005', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2027, to_date('19-07-2005', 'dd-mm-yyyy'), '2', '19', '200', '07', '2005', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2028, to_date('20-07-2005', 'dd-mm-yyyy'), '3', '20', '201', '07', '2005', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2029, to_date('21-07-2005', 'dd-mm-yyyy'), '4', '21', '202', '07', '2005', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2030, to_date('22-07-2005', 'dd-mm-yyyy'), '5', '22', '203', '07', '2005', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2031, to_date('23-07-2005', 'dd-mm-yyyy'), '6', '23', '204', '07', '2005', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2032, to_date('24-07-2005', 'dd-mm-yyyy'), '7', '24', '205', '07', '2005', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2033, to_date('25-07-2005', 'dd-mm-yyyy'), '1', '25', '206', '07', '2005', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2034, to_date('26-07-2005', 'dd-mm-yyyy'), '2', '26', '207', '07', '2005', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2035, to_date('27-07-2005', 'dd-mm-yyyy'), '3', '27', '208', '07', '2005', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2036, to_date('28-07-2005', 'dd-mm-yyyy'), '4', '28', '209', '07', '2005', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2037, to_date('29-07-2005', 'dd-mm-yyyy'), '5', '29', '210', '07', '2005', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2038, to_date('30-07-2005', 'dd-mm-yyyy'), '6', '30', '211', '07', '2005', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2039, to_date('31-07-2005', 'dd-mm-yyyy'), '7', '31', '212', '07', '2005', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2040, to_date('01-08-2005', 'dd-mm-yyyy'), '1', '01', '213', '08', '2005', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2041, to_date('02-08-2005', 'dd-mm-yyyy'), '2', '02', '214', '08', '2005', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2042, to_date('03-08-2005', 'dd-mm-yyyy'), '3', '03', '215', '08', '2005', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2043, to_date('04-08-2005', 'dd-mm-yyyy'), '4', '04', '216', '08', '2005', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2044, to_date('05-08-2005', 'dd-mm-yyyy'), '5', '05', '217', '08', '2005', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2045, to_date('06-08-2005', 'dd-mm-yyyy'), '6', '06', '218', '08', '2005', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2046, to_date('07-08-2005', 'dd-mm-yyyy'), '7', '07', '219', '08', '2005', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2047, to_date('08-08-2005', 'dd-mm-yyyy'), '1', '08', '220', '08', '2005', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2048, to_date('09-08-2005', 'dd-mm-yyyy'), '2', '09', '221', '08', '2005', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2049, to_date('10-08-2005', 'dd-mm-yyyy'), '3', '10', '222', '08', '2005', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2050, to_date('11-08-2005', 'dd-mm-yyyy'), '4', '11', '223', '08', '2005', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2051, to_date('12-08-2005', 'dd-mm-yyyy'), '5', '12', '224', '08', '2005', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2052, to_date('13-08-2005', 'dd-mm-yyyy'), '6', '13', '225', '08', '2005', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2053, to_date('14-08-2005', 'dd-mm-yyyy'), '7', '14', '226', '08', '2005', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2054, to_date('15-08-2005', 'dd-mm-yyyy'), '1', '15', '227', '08', '2005', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2055, to_date('16-08-2005', 'dd-mm-yyyy'), '2', '16', '228', '08', '2005', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2056, to_date('17-08-2005', 'dd-mm-yyyy'), '3', '17', '229', '08', '2005', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2057, to_date('18-08-2005', 'dd-mm-yyyy'), '4', '18', '230', '08', '2005', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2058, to_date('19-08-2005', 'dd-mm-yyyy'), '5', '19', '231', '08', '2005', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2059, to_date('20-08-2005', 'dd-mm-yyyy'), '6', '20', '232', '08', '2005', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2060, to_date('21-08-2005', 'dd-mm-yyyy'), '7', '21', '233', '08', '2005', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2061, to_date('22-08-2005', 'dd-mm-yyyy'), '1', '22', '234', '08', '2005', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2062, to_date('23-08-2005', 'dd-mm-yyyy'), '2', '23', '235', '08', '2005', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2063, to_date('24-08-2005', 'dd-mm-yyyy'), '3', '24', '236', '08', '2005', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2064, to_date('25-08-2005', 'dd-mm-yyyy'), '4', '25', '237', '08', '2005', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2065, to_date('26-08-2005', 'dd-mm-yyyy'), '5', '26', '238', '08', '2005', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2066, to_date('27-08-2005', 'dd-mm-yyyy'), '6', '27', '239', '08', '2005', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2067, to_date('28-08-2005', 'dd-mm-yyyy'), '7', '28', '240', '08', '2005', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2068, to_date('29-08-2005', 'dd-mm-yyyy'), '1', '29', '241', '08', '2005', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2069, to_date('30-08-2005', 'dd-mm-yyyy'), '2', '30', '242', '08', '2005', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2070, to_date('31-08-2005', 'dd-mm-yyyy'), '3', '31', '243', '08', '2005', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2071, to_date('01-09-2005', 'dd-mm-yyyy'), '4', '01', '244', '09', '2005', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2072, to_date('02-09-2005', 'dd-mm-yyyy'), '5', '02', '245', '09', '2005', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2073, to_date('03-09-2005', 'dd-mm-yyyy'), '6', '03', '246', '09', '2005', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2074, to_date('04-09-2005', 'dd-mm-yyyy'), '7', '04', '247', '09', '2005', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2075, to_date('05-09-2005', 'dd-mm-yyyy'), '1', '05', '248', '09', '2005', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2076, to_date('06-09-2005', 'dd-mm-yyyy'), '2', '06', '249', '09', '2005', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2077, to_date('07-09-2005', 'dd-mm-yyyy'), '3', '07', '250', '09', '2005', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2078, to_date('08-09-2005', 'dd-mm-yyyy'), '4', '08', '251', '09', '2005', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2079, to_date('09-09-2005', 'dd-mm-yyyy'), '5', '09', '252', '09', '2005', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2080, to_date('10-09-2005', 'dd-mm-yyyy'), '6', '10', '253', '09', '2005', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2081, to_date('11-09-2005', 'dd-mm-yyyy'), '7', '11', '254', '09', '2005', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2082, to_date('12-09-2005', 'dd-mm-yyyy'), '1', '12', '255', '09', '2005', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2083, to_date('13-09-2005', 'dd-mm-yyyy'), '2', '13', '256', '09', '2005', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2084, to_date('14-09-2005', 'dd-mm-yyyy'), '3', '14', '257', '09', '2005', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2085, to_date('15-09-2005', 'dd-mm-yyyy'), '4', '15', '258', '09', '2005', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2086, to_date('16-09-2005', 'dd-mm-yyyy'), '5', '16', '259', '09', '2005', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2087, to_date('17-09-2005', 'dd-mm-yyyy'), '6', '17', '260', '09', '2005', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2088, to_date('18-09-2005', 'dd-mm-yyyy'), '7', '18', '261', '09', '2005', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2089, to_date('19-09-2005', 'dd-mm-yyyy'), '1', '19', '262', '09', '2005', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2090, to_date('20-09-2005', 'dd-mm-yyyy'), '2', '20', '263', '09', '2005', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2091, to_date('21-09-2005', 'dd-mm-yyyy'), '3', '21', '264', '09', '2005', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2092, to_date('22-09-2005', 'dd-mm-yyyy'), '4', '22', '265', '09', '2005', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2093, to_date('23-09-2005', 'dd-mm-yyyy'), '5', '23', '266', '09', '2005', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2094, to_date('24-09-2005', 'dd-mm-yyyy'), '6', '24', '267', '09', '2005', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2095, to_date('25-09-2005', 'dd-mm-yyyy'), '7', '25', '268', '09', '2005', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2096, to_date('26-09-2005', 'dd-mm-yyyy'), '1', '26', '269', '09', '2005', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2097, to_date('27-09-2005', 'dd-mm-yyyy'), '2', '27', '270', '09', '2005', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2098, to_date('28-09-2005', 'dd-mm-yyyy'), '3', '28', '271', '09', '2005', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2099, to_date('29-09-2005', 'dd-mm-yyyy'), '4', '29', '272', '09', '2005', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2100, to_date('30-09-2005', 'dd-mm-yyyy'), '5', '30', '273', '09', '2005', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2101, to_date('01-10-2005', 'dd-mm-yyyy'), '6', '01', '274', '10', '2005', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2102, to_date('02-10-2005', 'dd-mm-yyyy'), '7', '02', '275', '10', '2005', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2103, to_date('03-10-2005', 'dd-mm-yyyy'), '1', '03', '276', '10', '2005', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2104, to_date('04-10-2005', 'dd-mm-yyyy'), '2', '04', '277', '10', '2005', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2105, to_date('05-10-2005', 'dd-mm-yyyy'), '3', '05', '278', '10', '2005', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2106, to_date('06-10-2005', 'dd-mm-yyyy'), '4', '06', '279', '10', '2005', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2107, to_date('07-10-2005', 'dd-mm-yyyy'), '5', '07', '280', '10', '2005', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2108, to_date('08-10-2005', 'dd-mm-yyyy'), '6', '08', '281', '10', '2005', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2109, to_date('09-10-2005', 'dd-mm-yyyy'), '7', '09', '282', '10', '2005', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2110, to_date('10-10-2005', 'dd-mm-yyyy'), '1', '10', '283', '10', '2005', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2111, to_date('11-10-2005', 'dd-mm-yyyy'), '2', '11', '284', '10', '2005', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2112, to_date('12-10-2005', 'dd-mm-yyyy'), '3', '12', '285', '10', '2005', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2113, to_date('13-10-2005', 'dd-mm-yyyy'), '4', '13', '286', '10', '2005', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2114, to_date('14-10-2005', 'dd-mm-yyyy'), '5', '14', '287', '10', '2005', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2115, to_date('15-10-2005', 'dd-mm-yyyy'), '6', '15', '288', '10', '2005', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2116, to_date('16-10-2005', 'dd-mm-yyyy'), '7', '16', '289', '10', '2005', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2117, to_date('17-10-2005', 'dd-mm-yyyy'), '1', '17', '290', '10', '2005', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2118, to_date('18-10-2005', 'dd-mm-yyyy'), '2', '18', '291', '10', '2005', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2119, to_date('19-10-2005', 'dd-mm-yyyy'), '3', '19', '292', '10', '2005', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2120, to_date('20-10-2005', 'dd-mm-yyyy'), '4', '20', '293', '10', '2005', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2121, to_date('21-10-2005', 'dd-mm-yyyy'), '5', '21', '294', '10', '2005', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2122, to_date('22-10-2005', 'dd-mm-yyyy'), '6', '22', '295', '10', '2005', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2123, to_date('23-10-2005', 'dd-mm-yyyy'), '7', '23', '296', '10', '2005', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2124, to_date('24-10-2005', 'dd-mm-yyyy'), '1', '24', '297', '10', '2005', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2125, to_date('25-10-2005', 'dd-mm-yyyy'), '2', '25', '298', '10', '2005', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2126, to_date('26-10-2005', 'dd-mm-yyyy'), '3', '26', '299', '10', '2005', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2127, to_date('27-10-2005', 'dd-mm-yyyy'), '4', '27', '300', '10', '2005', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2128, to_date('28-10-2005', 'dd-mm-yyyy'), '5', '28', '301', '10', '2005', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2129, to_date('29-10-2005', 'dd-mm-yyyy'), '6', '29', '302', '10', '2005', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2130, to_date('30-10-2005', 'dd-mm-yyyy'), '7', '30', '303', '10', '2005', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2131, to_date('31-10-2005', 'dd-mm-yyyy'), '1', '31', '304', '10', '2005', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2132, to_date('01-11-2005', 'dd-mm-yyyy'), '2', '01', '305', '11', '2005', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2133, to_date('02-11-2005', 'dd-mm-yyyy'), '3', '02', '306', '11', '2005', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2134, to_date('03-11-2005', 'dd-mm-yyyy'), '4', '03', '307', '11', '2005', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2135, to_date('04-11-2005', 'dd-mm-yyyy'), '5', '04', '308', '11', '2005', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2136, to_date('05-11-2005', 'dd-mm-yyyy'), '6', '05', '309', '11', '2005', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2137, to_date('06-11-2005', 'dd-mm-yyyy'), '7', '06', '310', '11', '2005', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2138, to_date('07-11-2005', 'dd-mm-yyyy'), '1', '07', '311', '11', '2005', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2139, to_date('08-11-2005', 'dd-mm-yyyy'), '2', '08', '312', '11', '2005', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2140, to_date('09-11-2005', 'dd-mm-yyyy'), '3', '09', '313', '11', '2005', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2141, to_date('10-11-2005', 'dd-mm-yyyy'), '4', '10', '314', '11', '2005', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2142, to_date('11-11-2005', 'dd-mm-yyyy'), '5', '11', '315', '11', '2005', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2143, to_date('12-11-2005', 'dd-mm-yyyy'), '6', '12', '316', '11', '2005', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2144, to_date('13-11-2005', 'dd-mm-yyyy'), '7', '13', '317', '11', '2005', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2145, to_date('14-11-2005', 'dd-mm-yyyy'), '1', '14', '318', '11', '2005', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2146, to_date('15-11-2005', 'dd-mm-yyyy'), '2', '15', '319', '11', '2005', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2147, to_date('16-11-2005', 'dd-mm-yyyy'), '3', '16', '320', '11', '2005', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2148, to_date('17-11-2005', 'dd-mm-yyyy'), '4', '17', '321', '11', '2005', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2149, to_date('18-11-2005', 'dd-mm-yyyy'), '5', '18', '322', '11', '2005', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2150, to_date('19-11-2005', 'dd-mm-yyyy'), '6', '19', '323', '11', '2005', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2151, to_date('20-11-2005', 'dd-mm-yyyy'), '7', '20', '324', '11', '2005', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2152, to_date('21-11-2005', 'dd-mm-yyyy'), '1', '21', '325', '11', '2005', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2153, to_date('22-11-2005', 'dd-mm-yyyy'), '2', '22', '326', '11', '2005', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2154, to_date('23-11-2005', 'dd-mm-yyyy'), '3', '23', '327', '11', '2005', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2155, to_date('24-11-2005', 'dd-mm-yyyy'), '4', '24', '328', '11', '2005', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2156, to_date('25-11-2005', 'dd-mm-yyyy'), '5', '25', '329', '11', '2005', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2157, to_date('26-11-2005', 'dd-mm-yyyy'), '6', '26', '330', '11', '2005', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2158, to_date('27-11-2005', 'dd-mm-yyyy'), '7', '27', '331', '11', '2005', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2159, to_date('28-11-2005', 'dd-mm-yyyy'), '1', '28', '332', '11', '2005', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2160, to_date('29-11-2005', 'dd-mm-yyyy'), '2', '29', '333', '11', '2005', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2161, to_date('30-11-2005', 'dd-mm-yyyy'), '3', '30', '334', '11', '2005', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2249, to_date('26-02-2006', 'dd-mm-yyyy'), '7', '26', '057', '02', '2006', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2250, to_date('27-02-2006', 'dd-mm-yyyy'), '1', '27', '058', '02', '2006', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2251, to_date('28-02-2006', 'dd-mm-yyyy'), '2', '28', '059', '02', '2006', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2252, to_date('01-03-2006', 'dd-mm-yyyy'), '3', '01', '060', '03', '2006', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2253, to_date('02-03-2006', 'dd-mm-yyyy'), '4', '02', '061', '03', '2006', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2254, to_date('03-03-2006', 'dd-mm-yyyy'), '5', '03', '062', '03', '2006', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2255, to_date('04-03-2006', 'dd-mm-yyyy'), '6', '04', '063', '03', '2006', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2256, to_date('05-03-2006', 'dd-mm-yyyy'), '7', '05', '064', '03', '2006', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2257, to_date('06-03-2006', 'dd-mm-yyyy'), '1', '06', '065', '03', '2006', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2258, to_date('07-03-2006', 'dd-mm-yyyy'), '2', '07', '066', '03', '2006', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2259, to_date('08-03-2006', 'dd-mm-yyyy'), '3', '08', '067', '03', '2006', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2260, to_date('09-03-2006', 'dd-mm-yyyy'), '4', '09', '068', '03', '2006', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2261, to_date('10-03-2006', 'dd-mm-yyyy'), '5', '10', '069', '03', '2006', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2262, to_date('11-03-2006', 'dd-mm-yyyy'), '6', '11', '070', '03', '2006', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2263, to_date('12-03-2006', 'dd-mm-yyyy'), '7', '12', '071', '03', '2006', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2264, to_date('13-03-2006', 'dd-mm-yyyy'), '1', '13', '072', '03', '2006', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2265, to_date('14-03-2006', 'dd-mm-yyyy'), '2', '14', '073', '03', '2006', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2266, to_date('15-03-2006', 'dd-mm-yyyy'), '3', '15', '074', '03', '2006', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2267, to_date('16-03-2006', 'dd-mm-yyyy'), '4', '16', '075', '03', '2006', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2268, to_date('17-03-2006', 'dd-mm-yyyy'), '5', '17', '076', '03', '2006', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2269, to_date('18-03-2006', 'dd-mm-yyyy'), '6', '18', '077', '03', '2006', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2162, to_date('01-12-2005', 'dd-mm-yyyy'), '4', '01', '335', '12', '2005', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2163, to_date('02-12-2005', 'dd-mm-yyyy'), '5', '02', '336', '12', '2005', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2164, to_date('03-12-2005', 'dd-mm-yyyy'), '6', '03', '337', '12', '2005', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2165, to_date('04-12-2005', 'dd-mm-yyyy'), '7', '04', '338', '12', '2005', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2166, to_date('05-12-2005', 'dd-mm-yyyy'), '1', '05', '339', '12', '2005', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2167, to_date('06-12-2005', 'dd-mm-yyyy'), '2', '06', '340', '12', '2005', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2168, to_date('07-12-2005', 'dd-mm-yyyy'), '3', '07', '341', '12', '2005', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2169, to_date('08-12-2005', 'dd-mm-yyyy'), '4', '08', '342', '12', '2005', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2170, to_date('09-12-2005', 'dd-mm-yyyy'), '5', '09', '343', '12', '2005', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2171, to_date('10-12-2005', 'dd-mm-yyyy'), '6', '10', '344', '12', '2005', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2172, to_date('11-12-2005', 'dd-mm-yyyy'), '7', '11', '345', '12', '2005', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2173, to_date('12-12-2005', 'dd-mm-yyyy'), '1', '12', '346', '12', '2005', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2174, to_date('13-12-2005', 'dd-mm-yyyy'), '2', '13', '347', '12', '2005', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2175, to_date('14-12-2005', 'dd-mm-yyyy'), '3', '14', '348', '12', '2005', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2176, to_date('15-12-2005', 'dd-mm-yyyy'), '4', '15', '349', '12', '2005', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2177, to_date('16-12-2005', 'dd-mm-yyyy'), '5', '16', '350', '12', '2005', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2178, to_date('17-12-2005', 'dd-mm-yyyy'), '6', '17', '351', '12', '2005', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2179, to_date('18-12-2005', 'dd-mm-yyyy'), '7', '18', '352', '12', '2005', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2180, to_date('19-12-2005', 'dd-mm-yyyy'), '1', '19', '353', '12', '2005', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2181, to_date('20-12-2005', 'dd-mm-yyyy'), '2', '20', '354', '12', '2005', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2182, to_date('21-12-2005', 'dd-mm-yyyy'), '3', '21', '355', '12', '2005', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2183, to_date('22-12-2005', 'dd-mm-yyyy'), '4', '22', '356', '12', '2005', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2184, to_date('23-12-2005', 'dd-mm-yyyy'), '5', '23', '357', '12', '2005', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2185, to_date('24-12-2005', 'dd-mm-yyyy'), '6', '24', '358', '12', '2005', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2186, to_date('25-12-2005', 'dd-mm-yyyy'), '7', '25', '359', '12', '2005', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2187, to_date('26-12-2005', 'dd-mm-yyyy'), '1', '26', '360', '12', '2005', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2188, to_date('27-12-2005', 'dd-mm-yyyy'), '2', '27', '361', '12', '2005', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2189, to_date('28-12-2005', 'dd-mm-yyyy'), '3', '28', '362', '12', '2005', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2190, to_date('29-12-2005', 'dd-mm-yyyy'), '4', '29', '363', '12', '2005', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2191, to_date('30-12-2005', 'dd-mm-yyyy'), '5', '30', '364', '12', '2005', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2192, to_date('31-12-2005', 'dd-mm-yyyy'), '6', '31', '365', '12', '2005', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2193, to_date('01-01-2006', 'dd-mm-yyyy'), '7', '01', '001', '01', '2006', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2194, to_date('02-01-2006', 'dd-mm-yyyy'), '1', '02', '002', '01', '2006', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2195, to_date('03-01-2006', 'dd-mm-yyyy'), '2', '03', '003', '01', '2006', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2196, to_date('04-01-2006', 'dd-mm-yyyy'), '3', '04', '004', '01', '2006', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2197, to_date('05-01-2006', 'dd-mm-yyyy'), '4', '05', '005', '01', '2006', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2198, to_date('06-01-2006', 'dd-mm-yyyy'), '5', '06', '006', '01', '2006', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2199, to_date('07-01-2006', 'dd-mm-yyyy'), '6', '07', '007', '01', '2006', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2200, to_date('08-01-2006', 'dd-mm-yyyy'), '7', '08', '008', '01', '2006', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2201, to_date('09-01-2006', 'dd-mm-yyyy'), '1', '09', '009', '01', '2006', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2202, to_date('10-01-2006', 'dd-mm-yyyy'), '2', '10', '010', '01', '2006', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2203, to_date('11-01-2006', 'dd-mm-yyyy'), '3', '11', '011', '01', '2006', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2204, to_date('12-01-2006', 'dd-mm-yyyy'), '4', '12', '012', '01', '2006', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2205, to_date('13-01-2006', 'dd-mm-yyyy'), '5', '13', '013', '01', '2006', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2206, to_date('14-01-2006', 'dd-mm-yyyy'), '6', '14', '014', '01', '2006', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2207, to_date('15-01-2006', 'dd-mm-yyyy'), '7', '15', '015', '01', '2006', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2208, to_date('16-01-2006', 'dd-mm-yyyy'), '1', '16', '016', '01', '2006', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2209, to_date('17-01-2006', 'dd-mm-yyyy'), '2', '17', '017', '01', '2006', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2210, to_date('18-01-2006', 'dd-mm-yyyy'), '3', '18', '018', '01', '2006', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2211, to_date('19-01-2006', 'dd-mm-yyyy'), '4', '19', '019', '01', '2006', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2212, to_date('20-01-2006', 'dd-mm-yyyy'), '5', '20', '020', '01', '2006', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2213, to_date('21-01-2006', 'dd-mm-yyyy'), '6', '21', '021', '01', '2006', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2214, to_date('22-01-2006', 'dd-mm-yyyy'), '7', '22', '022', '01', '2006', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2215, to_date('23-01-2006', 'dd-mm-yyyy'), '1', '23', '023', '01', '2006', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2216, to_date('24-01-2006', 'dd-mm-yyyy'), '2', '24', '024', '01', '2006', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2217, to_date('25-01-2006', 'dd-mm-yyyy'), '3', '25', '025', '01', '2006', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2218, to_date('26-01-2006', 'dd-mm-yyyy'), '4', '26', '026', '01', '2006', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2219, to_date('27-01-2006', 'dd-mm-yyyy'), '5', '27', '027', '01', '2006', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2220, to_date('28-01-2006', 'dd-mm-yyyy'), '6', '28', '028', '01', '2006', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2221, to_date('29-01-2006', 'dd-mm-yyyy'), '7', '29', '029', '01', '2006', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2222, to_date('30-01-2006', 'dd-mm-yyyy'), '1', '30', '030', '01', '2006', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2223, to_date('31-01-2006', 'dd-mm-yyyy'), '2', '31', '031', '01', '2006', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2224, to_date('01-02-2006', 'dd-mm-yyyy'), '3', '01', '032', '02', '2006', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2225, to_date('02-02-2006', 'dd-mm-yyyy'), '4', '02', '033', '02', '2006', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2226, to_date('03-02-2006', 'dd-mm-yyyy'), '5', '03', '034', '02', '2006', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2227, to_date('04-02-2006', 'dd-mm-yyyy'), '6', '04', '035', '02', '2006', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2228, to_date('05-02-2006', 'dd-mm-yyyy'), '7', '05', '036', '02', '2006', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2229, to_date('06-02-2006', 'dd-mm-yyyy'), '1', '06', '037', '02', '2006', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2230, to_date('07-02-2006', 'dd-mm-yyyy'), '2', '07', '038', '02', '2006', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2231, to_date('08-02-2006', 'dd-mm-yyyy'), '3', '08', '039', '02', '2006', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2232, to_date('09-02-2006', 'dd-mm-yyyy'), '4', '09', '040', '02', '2006', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2233, to_date('10-02-2006', 'dd-mm-yyyy'), '5', '10', '041', '02', '2006', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2234, to_date('11-02-2006', 'dd-mm-yyyy'), '6', '11', '042', '02', '2006', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2235, to_date('12-02-2006', 'dd-mm-yyyy'), '7', '12', '043', '02', '2006', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2236, to_date('13-02-2006', 'dd-mm-yyyy'), '1', '13', '044', '02', '2006', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2237, to_date('14-02-2006', 'dd-mm-yyyy'), '2', '14', '045', '02', '2006', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2238, to_date('15-02-2006', 'dd-mm-yyyy'), '3', '15', '046', '02', '2006', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2239, to_date('16-02-2006', 'dd-mm-yyyy'), '4', '16', '047', '02', '2006', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2240, to_date('17-02-2006', 'dd-mm-yyyy'), '5', '17', '048', '02', '2006', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2241, to_date('18-02-2006', 'dd-mm-yyyy'), '6', '18', '049', '02', '2006', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2242, to_date('19-02-2006', 'dd-mm-yyyy'), '7', '19', '050', '02', '2006', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2243, to_date('20-02-2006', 'dd-mm-yyyy'), '1', '20', '051', '02', '2006', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2244, to_date('21-02-2006', 'dd-mm-yyyy'), '2', '21', '052', '02', '2006', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2245, to_date('22-02-2006', 'dd-mm-yyyy'), '3', '22', '053', '02', '2006', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2246, to_date('23-02-2006', 'dd-mm-yyyy'), '4', '23', '054', '02', '2006', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2247, to_date('24-02-2006', 'dd-mm-yyyy'), '5', '24', '055', '02', '2006', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2248, to_date('25-02-2006', 'dd-mm-yyyy'), '6', '25', '056', '02', '2006', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2270, to_date('19-03-2006', 'dd-mm-yyyy'), '7', '19', '078', '03', '2006', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2271, to_date('20-03-2006', 'dd-mm-yyyy'), '1', '20', '079', '03', '2006', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2272, to_date('21-03-2006', 'dd-mm-yyyy'), '2', '21', '080', '03', '2006', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2273, to_date('22-03-2006', 'dd-mm-yyyy'), '3', '22', '081', '03', '2006', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2274, to_date('23-03-2006', 'dd-mm-yyyy'), '4', '23', '082', '03', '2006', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2275, to_date('24-03-2006', 'dd-mm-yyyy'), '5', '24', '083', '03', '2006', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2276, to_date('25-03-2006', 'dd-mm-yyyy'), '6', '25', '084', '03', '2006', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2277, to_date('26-03-2006', 'dd-mm-yyyy'), '7', '26', '085', '03', '2006', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2278, to_date('27-03-2006', 'dd-mm-yyyy'), '1', '27', '086', '03', '2006', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2279, to_date('28-03-2006', 'dd-mm-yyyy'), '2', '28', '087', '03', '2006', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2280, to_date('29-03-2006', 'dd-mm-yyyy'), '3', '29', '088', '03', '2006', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2281, to_date('30-03-2006', 'dd-mm-yyyy'), '4', '30', '089', '03', '2006', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2282, to_date('31-03-2006', 'dd-mm-yyyy'), '5', '31', '090', '03', '2006', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2283, to_date('01-04-2006', 'dd-mm-yyyy'), '6', '01', '091', '04', '2006', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2284, to_date('02-04-2006', 'dd-mm-yyyy'), '7', '02', '092', '04', '2006', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2285, to_date('03-04-2006', 'dd-mm-yyyy'), '1', '03', '093', '04', '2006', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2286, to_date('04-04-2006', 'dd-mm-yyyy'), '2', '04', '094', '04', '2006', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2287, to_date('05-04-2006', 'dd-mm-yyyy'), '3', '05', '095', '04', '2006', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2288, to_date('06-04-2006', 'dd-mm-yyyy'), '4', '06', '096', '04', '2006', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2289, to_date('07-04-2006', 'dd-mm-yyyy'), '5', '07', '097', '04', '2006', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2290, to_date('08-04-2006', 'dd-mm-yyyy'), '6', '08', '098', '04', '2006', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2291, to_date('09-04-2006', 'dd-mm-yyyy'), '7', '09', '099', '04', '2006', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2292, to_date('10-04-2006', 'dd-mm-yyyy'), '1', '10', '100', '04', '2006', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2293, to_date('11-04-2006', 'dd-mm-yyyy'), '2', '11', '101', '04', '2006', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2294, to_date('12-04-2006', 'dd-mm-yyyy'), '3', '12', '102', '04', '2006', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2295, to_date('13-04-2006', 'dd-mm-yyyy'), '4', '13', '103', '04', '2006', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2296, to_date('14-04-2006', 'dd-mm-yyyy'), '5', '14', '104', '04', '2006', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2297, to_date('15-04-2006', 'dd-mm-yyyy'), '6', '15', '105', '04', '2006', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2298, to_date('16-04-2006', 'dd-mm-yyyy'), '7', '16', '106', '04', '2006', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2299, to_date('17-04-2006', 'dd-mm-yyyy'), '1', '17', '107', '04', '2006', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2300, to_date('18-04-2006', 'dd-mm-yyyy'), '2', '18', '108', '04', '2006', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2301, to_date('19-04-2006', 'dd-mm-yyyy'), '3', '19', '109', '04', '2006', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2302, to_date('20-04-2006', 'dd-mm-yyyy'), '4', '20', '110', '04', '2006', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2303, to_date('21-04-2006', 'dd-mm-yyyy'), '5', '21', '111', '04', '2006', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2304, to_date('22-04-2006', 'dd-mm-yyyy'), '6', '22', '112', '04', '2006', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2305, to_date('23-04-2006', 'dd-mm-yyyy'), '7', '23', '113', '04', '2006', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2306, to_date('24-04-2006', 'dd-mm-yyyy'), '1', '24', '114', '04', '2006', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2307, to_date('25-04-2006', 'dd-mm-yyyy'), '2', '25', '115', '04', '2006', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2308, to_date('26-04-2006', 'dd-mm-yyyy'), '3', '26', '116', '04', '2006', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2309, to_date('27-04-2006', 'dd-mm-yyyy'), '4', '27', '117', '04', '2006', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2310, to_date('28-04-2006', 'dd-mm-yyyy'), '5', '28', '118', '04', '2006', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2311, to_date('29-04-2006', 'dd-mm-yyyy'), '6', '29', '119', '04', '2006', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2312, to_date('30-04-2006', 'dd-mm-yyyy'), '7', '30', '120', '04', '2006', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2313, to_date('01-05-2006', 'dd-mm-yyyy'), '1', '01', '121', '05', '2006', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2314, to_date('02-05-2006', 'dd-mm-yyyy'), '2', '02', '122', '05', '2006', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2315, to_date('03-05-2006', 'dd-mm-yyyy'), '3', '03', '123', '05', '2006', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2316, to_date('04-05-2006', 'dd-mm-yyyy'), '4', '04', '124', '05', '2006', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2317, to_date('05-05-2006', 'dd-mm-yyyy'), '5', '05', '125', '05', '2006', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2318, to_date('06-05-2006', 'dd-mm-yyyy'), '6', '06', '126', '05', '2006', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2319, to_date('07-05-2006', 'dd-mm-yyyy'), '7', '07', '127', '05', '2006', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2320, to_date('08-05-2006', 'dd-mm-yyyy'), '1', '08', '128', '05', '2006', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2321, to_date('09-05-2006', 'dd-mm-yyyy'), '2', '09', '129', '05', '2006', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2322, to_date('10-05-2006', 'dd-mm-yyyy'), '3', '10', '130', '05', '2006', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2323, to_date('11-05-2006', 'dd-mm-yyyy'), '4', '11', '131', '05', '2006', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2324, to_date('12-05-2006', 'dd-mm-yyyy'), '5', '12', '132', '05', '2006', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2325, to_date('13-05-2006', 'dd-mm-yyyy'), '6', '13', '133', '05', '2006', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2326, to_date('14-05-2006', 'dd-mm-yyyy'), '7', '14', '134', '05', '2006', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2327, to_date('15-05-2006', 'dd-mm-yyyy'), '1', '15', '135', '05', '2006', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2328, to_date('16-05-2006', 'dd-mm-yyyy'), '2', '16', '136', '05', '2006', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2329, to_date('17-05-2006', 'dd-mm-yyyy'), '3', '17', '137', '05', '2006', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2330, to_date('18-05-2006', 'dd-mm-yyyy'), '4', '18', '138', '05', '2006', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2331, to_date('19-05-2006', 'dd-mm-yyyy'), '5', '19', '139', '05', '2006', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2332, to_date('20-05-2006', 'dd-mm-yyyy'), '6', '20', '140', '05', '2006', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2333, to_date('21-05-2006', 'dd-mm-yyyy'), '7', '21', '141', '05', '2006', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2334, to_date('22-05-2006', 'dd-mm-yyyy'), '1', '22', '142', '05', '2006', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2335, to_date('23-05-2006', 'dd-mm-yyyy'), '2', '23', '143', '05', '2006', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2336, to_date('24-05-2006', 'dd-mm-yyyy'), '3', '24', '144', '05', '2006', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2337, to_date('25-05-2006', 'dd-mm-yyyy'), '4', '25', '145', '05', '2006', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2338, to_date('26-05-2006', 'dd-mm-yyyy'), '5', '26', '146', '05', '2006', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2339, to_date('27-05-2006', 'dd-mm-yyyy'), '6', '27', '147', '05', '2006', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2340, to_date('28-05-2006', 'dd-mm-yyyy'), '7', '28', '148', '05', '2006', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2341, to_date('29-05-2006', 'dd-mm-yyyy'), '1', '29', '149', '05', '2006', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2342, to_date('30-05-2006', 'dd-mm-yyyy'), '2', '30', '150', '05', '2006', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2343, to_date('31-05-2006', 'dd-mm-yyyy'), '3', '31', '151', '05', '2006', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2344, to_date('01-06-2006', 'dd-mm-yyyy'), '4', '01', '152', '06', '2006', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2345, to_date('02-06-2006', 'dd-mm-yyyy'), '5', '02', '153', '06', '2006', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2346, to_date('03-06-2006', 'dd-mm-yyyy'), '6', '03', '154', '06', '2006', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2347, to_date('04-06-2006', 'dd-mm-yyyy'), '7', '04', '155', '06', '2006', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2348, to_date('05-06-2006', 'dd-mm-yyyy'), '1', '05', '156', '06', '2006', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2349, to_date('06-06-2006', 'dd-mm-yyyy'), '2', '06', '157', '06', '2006', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2350, to_date('07-06-2006', 'dd-mm-yyyy'), '3', '07', '158', '06', '2006', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2351, to_date('08-06-2006', 'dd-mm-yyyy'), '4', '08', '159', '06', '2006', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2352, to_date('09-06-2006', 'dd-mm-yyyy'), '5', '09', '160', '06', '2006', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2353, to_date('10-06-2006', 'dd-mm-yyyy'), '6', '10', '161', '06', '2006', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2354, to_date('11-06-2006', 'dd-mm-yyyy'), '7', '11', '162', '06', '2006', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2355, to_date('12-06-2006', 'dd-mm-yyyy'), '1', '12', '163', '06', '2006', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2356, to_date('13-06-2006', 'dd-mm-yyyy'), '2', '13', '164', '06', '2006', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2357, to_date('14-06-2006', 'dd-mm-yyyy'), '3', '14', '165', '06', '2006', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2358, to_date('15-06-2006', 'dd-mm-yyyy'), '4', '15', '166', '06', '2006', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2359, to_date('16-06-2006', 'dd-mm-yyyy'), '5', '16', '167', '06', '2006', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2360, to_date('17-06-2006', 'dd-mm-yyyy'), '6', '17', '168', '06', '2006', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2361, to_date('18-06-2006', 'dd-mm-yyyy'), '7', '18', '169', '06', '2006', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2362, to_date('19-06-2006', 'dd-mm-yyyy'), '1', '19', '170', '06', '2006', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2363, to_date('20-06-2006', 'dd-mm-yyyy'), '2', '20', '171', '06', '2006', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2364, to_date('21-06-2006', 'dd-mm-yyyy'), '3', '21', '172', '06', '2006', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2365, to_date('22-06-2006', 'dd-mm-yyyy'), '4', '22', '173', '06', '2006', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2366, to_date('23-06-2006', 'dd-mm-yyyy'), '5', '23', '174', '06', '2006', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2367, to_date('24-06-2006', 'dd-mm-yyyy'), '6', '24', '175', '06', '2006', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2368, to_date('25-06-2006', 'dd-mm-yyyy'), '7', '25', '176', '06', '2006', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2369, to_date('26-06-2006', 'dd-mm-yyyy'), '1', '26', '177', '06', '2006', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2370, to_date('27-06-2006', 'dd-mm-yyyy'), '2', '27', '178', '06', '2006', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2371, to_date('28-06-2006', 'dd-mm-yyyy'), '3', '28', '179', '06', '2006', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2372, to_date('29-06-2006', 'dd-mm-yyyy'), '4', '29', '180', '06', '2006', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2373, to_date('30-06-2006', 'dd-mm-yyyy'), '5', '30', '181', '06', '2006', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2374, to_date('01-07-2006', 'dd-mm-yyyy'), '6', '01', '182', '07', '2006', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2375, to_date('02-07-2006', 'dd-mm-yyyy'), '7', '02', '183', '07', '2006', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2376, to_date('03-07-2006', 'dd-mm-yyyy'), '1', '03', '184', '07', '2006', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2377, to_date('04-07-2006', 'dd-mm-yyyy'), '2', '04', '185', '07', '2006', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2378, to_date('05-07-2006', 'dd-mm-yyyy'), '3', '05', '186', '07', '2006', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2379, to_date('06-07-2006', 'dd-mm-yyyy'), '4', '06', '187', '07', '2006', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2380, to_date('07-07-2006', 'dd-mm-yyyy'), '5', '07', '188', '07', '2006', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2381, to_date('08-07-2006', 'dd-mm-yyyy'), '6', '08', '189', '07', '2006', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2382, to_date('09-07-2006', 'dd-mm-yyyy'), '7', '09', '190', '07', '2006', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2383, to_date('10-07-2006', 'dd-mm-yyyy'), '1', '10', '191', '07', '2006', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2384, to_date('11-07-2006', 'dd-mm-yyyy'), '2', '11', '192', '07', '2006', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2385, to_date('12-07-2006', 'dd-mm-yyyy'), '3', '12', '193', '07', '2006', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2386, to_date('13-07-2006', 'dd-mm-yyyy'), '4', '13', '194', '07', '2006', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2387, to_date('14-07-2006', 'dd-mm-yyyy'), '5', '14', '195', '07', '2006', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2388, to_date('15-07-2006', 'dd-mm-yyyy'), '6', '15', '196', '07', '2006', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2389, to_date('16-07-2006', 'dd-mm-yyyy'), '7', '16', '197', '07', '2006', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2390, to_date('17-07-2006', 'dd-mm-yyyy'), '1', '17', '198', '07', '2006', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2391, to_date('18-07-2006', 'dd-mm-yyyy'), '2', '18', '199', '07', '2006', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2392, to_date('19-07-2006', 'dd-mm-yyyy'), '3', '19', '200', '07', '2006', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2393, to_date('20-07-2006', 'dd-mm-yyyy'), '4', '20', '201', '07', '2006', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2394, to_date('21-07-2006', 'dd-mm-yyyy'), '5', '21', '202', '07', '2006', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2395, to_date('22-07-2006', 'dd-mm-yyyy'), '6', '22', '203', '07', '2006', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2396, to_date('23-07-2006', 'dd-mm-yyyy'), '7', '23', '204', '07', '2006', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2397, to_date('24-07-2006', 'dd-mm-yyyy'), '1', '24', '205', '07', '2006', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2398, to_date('25-07-2006', 'dd-mm-yyyy'), '2', '25', '206', '07', '2006', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2399, to_date('26-07-2006', 'dd-mm-yyyy'), '3', '26', '207', '07', '2006', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2400, to_date('27-07-2006', 'dd-mm-yyyy'), '4', '27', '208', '07', '2006', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2401, to_date('28-07-2006', 'dd-mm-yyyy'), '5', '28', '209', '07', '2006', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2402, to_date('29-07-2006', 'dd-mm-yyyy'), '6', '29', '210', '07', '2006', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2403, to_date('30-07-2006', 'dd-mm-yyyy'), '7', '30', '211', '07', '2006', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2404, to_date('31-07-2006', 'dd-mm-yyyy'), '1', '31', '212', '07', '2006', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2405, to_date('01-08-2006', 'dd-mm-yyyy'), '2', '01', '213', '08', '2006', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2406, to_date('02-08-2006', 'dd-mm-yyyy'), '3', '02', '214', '08', '2006', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2407, to_date('03-08-2006', 'dd-mm-yyyy'), '4', '03', '215', '08', '2006', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2408, to_date('04-08-2006', 'dd-mm-yyyy'), '5', '04', '216', '08', '2006', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2409, to_date('05-08-2006', 'dd-mm-yyyy'), '6', '05', '217', '08', '2006', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2410, to_date('06-08-2006', 'dd-mm-yyyy'), '7', '06', '218', '08', '2006', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2411, to_date('07-08-2006', 'dd-mm-yyyy'), '1', '07', '219', '08', '2006', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2412, to_date('08-08-2006', 'dd-mm-yyyy'), '2', '08', '220', '08', '2006', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2413, to_date('09-08-2006', 'dd-mm-yyyy'), '3', '09', '221', '08', '2006', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2414, to_date('10-08-2006', 'dd-mm-yyyy'), '4', '10', '222', '08', '2006', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2415, to_date('11-08-2006', 'dd-mm-yyyy'), '5', '11', '223', '08', '2006', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2416, to_date('12-08-2006', 'dd-mm-yyyy'), '6', '12', '224', '08', '2006', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2417, to_date('13-08-2006', 'dd-mm-yyyy'), '7', '13', '225', '08', '2006', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2418, to_date('14-08-2006', 'dd-mm-yyyy'), '1', '14', '226', '08', '2006', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2419, to_date('15-08-2006', 'dd-mm-yyyy'), '2', '15', '227', '08', '2006', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2420, to_date('16-08-2006', 'dd-mm-yyyy'), '3', '16', '228', '08', '2006', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2421, to_date('17-08-2006', 'dd-mm-yyyy'), '4', '17', '229', '08', '2006', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2422, to_date('18-08-2006', 'dd-mm-yyyy'), '5', '18', '230', '08', '2006', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2423, to_date('19-08-2006', 'dd-mm-yyyy'), '6', '19', '231', '08', '2006', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2424, to_date('20-08-2006', 'dd-mm-yyyy'), '7', '20', '232', '08', '2006', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2425, to_date('21-08-2006', 'dd-mm-yyyy'), '1', '21', '233', '08', '2006', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2426, to_date('22-08-2006', 'dd-mm-yyyy'), '2', '22', '234', '08', '2006', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2427, to_date('23-08-2006', 'dd-mm-yyyy'), '3', '23', '235', '08', '2006', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2428, to_date('24-08-2006', 'dd-mm-yyyy'), '4', '24', '236', '08', '2006', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2429, to_date('25-08-2006', 'dd-mm-yyyy'), '5', '25', '237', '08', '2006', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2430, to_date('26-08-2006', 'dd-mm-yyyy'), '6', '26', '238', '08', '2006', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2431, to_date('27-08-2006', 'dd-mm-yyyy'), '7', '27', '239', '08', '2006', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2432, to_date('28-08-2006', 'dd-mm-yyyy'), '1', '28', '240', '08', '2006', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2433, to_date('29-08-2006', 'dd-mm-yyyy'), '2', '29', '241', '08', '2006', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2434, to_date('30-08-2006', 'dd-mm-yyyy'), '3', '30', '242', '08', '2006', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2435, to_date('31-08-2006', 'dd-mm-yyyy'), '4', '31', '243', '08', '2006', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2436, to_date('01-09-2006', 'dd-mm-yyyy'), '5', '01', '244', '09', '2006', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2437, to_date('02-09-2006', 'dd-mm-yyyy'), '6', '02', '245', '09', '2006', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2438, to_date('03-09-2006', 'dd-mm-yyyy'), '7', '03', '246', '09', '2006', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2439, to_date('04-09-2006', 'dd-mm-yyyy'), '1', '04', '247', '09', '2006', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2440, to_date('05-09-2006', 'dd-mm-yyyy'), '2', '05', '248', '09', '2006', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2441, to_date('06-09-2006', 'dd-mm-yyyy'), '3', '06', '249', '09', '2006', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2442, to_date('07-09-2006', 'dd-mm-yyyy'), '4', '07', '250', '09', '2006', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2443, to_date('08-09-2006', 'dd-mm-yyyy'), '5', '08', '251', '09', '2006', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2444, to_date('09-09-2006', 'dd-mm-yyyy'), '6', '09', '252', '09', '2006', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2445, to_date('10-09-2006', 'dd-mm-yyyy'), '7', '10', '253', '09', '2006', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2446, to_date('11-09-2006', 'dd-mm-yyyy'), '1', '11', '254', '09', '2006', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2447, to_date('12-09-2006', 'dd-mm-yyyy'), '2', '12', '255', '09', '2006', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2448, to_date('13-09-2006', 'dd-mm-yyyy'), '3', '13', '256', '09', '2006', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2449, to_date('14-09-2006', 'dd-mm-yyyy'), '4', '14', '257', '09', '2006', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2450, to_date('15-09-2006', 'dd-mm-yyyy'), '5', '15', '258', '09', '2006', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2451, to_date('16-09-2006', 'dd-mm-yyyy'), '6', '16', '259', '09', '2006', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2452, to_date('17-09-2006', 'dd-mm-yyyy'), '7', '17', '260', '09', '2006', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2453, to_date('18-09-2006', 'dd-mm-yyyy'), '1', '18', '261', '09', '2006', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2454, to_date('19-09-2006', 'dd-mm-yyyy'), '2', '19', '262', '09', '2006', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2455, to_date('20-09-2006', 'dd-mm-yyyy'), '3', '20', '263', '09', '2006', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2456, to_date('21-09-2006', 'dd-mm-yyyy'), '4', '21', '264', '09', '2006', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2457, to_date('22-09-2006', 'dd-mm-yyyy'), '5', '22', '265', '09', '2006', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2458, to_date('23-09-2006', 'dd-mm-yyyy'), '6', '23', '266', '09', '2006', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2459, to_date('24-09-2006', 'dd-mm-yyyy'), '7', '24', '267', '09', '2006', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2460, to_date('25-09-2006', 'dd-mm-yyyy'), '1', '25', '268', '09', '2006', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2461, to_date('26-09-2006', 'dd-mm-yyyy'), '2', '26', '269', '09', '2006', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2462, to_date('27-09-2006', 'dd-mm-yyyy'), '3', '27', '270', '09', '2006', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2463, to_date('28-09-2006', 'dd-mm-yyyy'), '4', '28', '271', '09', '2006', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2464, to_date('29-09-2006', 'dd-mm-yyyy'), '5', '29', '272', '09', '2006', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2465, to_date('30-09-2006', 'dd-mm-yyyy'), '6', '30', '273', '09', '2006', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2466, to_date('01-10-2006', 'dd-mm-yyyy'), '7', '01', '274', '10', '2006', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2467, to_date('02-10-2006', 'dd-mm-yyyy'), '1', '02', '275', '10', '2006', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2468, to_date('03-10-2006', 'dd-mm-yyyy'), '2', '03', '276', '10', '2006', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2469, to_date('04-10-2006', 'dd-mm-yyyy'), '3', '04', '277', '10', '2006', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2470, to_date('05-10-2006', 'dd-mm-yyyy'), '4', '05', '278', '10', '2006', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2471, to_date('06-10-2006', 'dd-mm-yyyy'), '5', '06', '279', '10', '2006', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2472, to_date('07-10-2006', 'dd-mm-yyyy'), '6', '07', '280', '10', '2006', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2473, to_date('08-10-2006', 'dd-mm-yyyy'), '7', '08', '281', '10', '2006', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2474, to_date('09-10-2006', 'dd-mm-yyyy'), '1', '09', '282', '10', '2006', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2475, to_date('10-10-2006', 'dd-mm-yyyy'), '2', '10', '283', '10', '2006', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2476, to_date('11-10-2006', 'dd-mm-yyyy'), '3', '11', '284', '10', '2006', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2477, to_date('12-10-2006', 'dd-mm-yyyy'), '4', '12', '285', '10', '2006', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2478, to_date('13-10-2006', 'dd-mm-yyyy'), '5', '13', '286', '10', '2006', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2479, to_date('14-10-2006', 'dd-mm-yyyy'), '6', '14', '287', '10', '2006', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2480, to_date('15-10-2006', 'dd-mm-yyyy'), '7', '15', '288', '10', '2006', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2481, to_date('16-10-2006', 'dd-mm-yyyy'), '1', '16', '289', '10', '2006', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2482, to_date('17-10-2006', 'dd-mm-yyyy'), '2', '17', '290', '10', '2006', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2483, to_date('18-10-2006', 'dd-mm-yyyy'), '3', '18', '291', '10', '2006', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2484, to_date('19-10-2006', 'dd-mm-yyyy'), '4', '19', '292', '10', '2006', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (2485, to_date('20-10-2006', 'dd-mm-yyyy'), '5', '20', '293', '10', '2006', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4646, to_date('19-09-2012', 'dd-mm-yyyy'), '3', '19', '263', '09', '2012', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4647, to_date('20-09-2012', 'dd-mm-yyyy'), '4', '20', '264', '09', '2012', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4648, to_date('21-09-2012', 'dd-mm-yyyy'), '5', '21', '265', '09', '2012', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4649, to_date('22-09-2012', 'dd-mm-yyyy'), '6', '22', '266', '09', '2012', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4650, to_date('23-09-2012', 'dd-mm-yyyy'), '7', '23', '267', '09', '2012', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4651, to_date('24-09-2012', 'dd-mm-yyyy'), '1', '24', '268', '09', '2012', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4652, to_date('25-09-2012', 'dd-mm-yyyy'), '2', '25', '269', '09', '2012', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4653, to_date('26-09-2012', 'dd-mm-yyyy'), '3', '26', '270', '09', '2012', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4654, to_date('27-09-2012', 'dd-mm-yyyy'), '4', '27', '271', '09', '2012', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4655, to_date('28-09-2012', 'dd-mm-yyyy'), '5', '28', '272', '09', '2012', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4656, to_date('29-09-2012', 'dd-mm-yyyy'), '6', '29', '273', '09', '2012', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4657, to_date('30-09-2012', 'dd-mm-yyyy'), '7', '30', '274', '09', '2012', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4658, to_date('01-10-2012', 'dd-mm-yyyy'), '1', '01', '275', '10', '2012', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4659, to_date('02-10-2012', 'dd-mm-yyyy'), '2', '02', '276', '10', '2012', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4660, to_date('03-10-2012', 'dd-mm-yyyy'), '3', '03', '277', '10', '2012', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4661, to_date('04-10-2012', 'dd-mm-yyyy'), '4', '04', '278', '10', '2012', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4662, to_date('05-10-2012', 'dd-mm-yyyy'), '5', '05', '279', '10', '2012', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4663, to_date('06-10-2012', 'dd-mm-yyyy'), '6', '06', '280', '10', '2012', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4664, to_date('07-10-2012', 'dd-mm-yyyy'), '7', '07', '281', '10', '2012', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4665, to_date('08-10-2012', 'dd-mm-yyyy'), '1', '08', '282', '10', '2012', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4666, to_date('09-10-2012', 'dd-mm-yyyy'), '2', '09', '283', '10', '2012', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4667, to_date('10-10-2012', 'dd-mm-yyyy'), '3', '10', '284', '10', '2012', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4668, to_date('11-10-2012', 'dd-mm-yyyy'), '4', '11', '285', '10', '2012', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4669, to_date('12-10-2012', 'dd-mm-yyyy'), '5', '12', '286', '10', '2012', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4670, to_date('13-10-2012', 'dd-mm-yyyy'), '6', '13', '287', '10', '2012', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4671, to_date('14-10-2012', 'dd-mm-yyyy'), '7', '14', '288', '10', '2012', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4672, to_date('15-10-2012', 'dd-mm-yyyy'), '1', '15', '289', '10', '2012', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4673, to_date('16-10-2012', 'dd-mm-yyyy'), '2', '16', '290', '10', '2012', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4674, to_date('17-10-2012', 'dd-mm-yyyy'), '3', '17', '291', '10', '2012', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4675, to_date('18-10-2012', 'dd-mm-yyyy'), '4', '18', '292', '10', '2012', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4676, to_date('19-10-2012', 'dd-mm-yyyy'), '5', '19', '293', '10', '2012', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4677, to_date('20-10-2012', 'dd-mm-yyyy'), '6', '20', '294', '10', '2012', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4678, to_date('21-10-2012', 'dd-mm-yyyy'), '7', '21', '295', '10', '2012', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4679, to_date('22-10-2012', 'dd-mm-yyyy'), '1', '22', '296', '10', '2012', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4680, to_date('23-10-2012', 'dd-mm-yyyy'), '2', '23', '297', '10', '2012', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4681, to_date('24-10-2012', 'dd-mm-yyyy'), '3', '24', '298', '10', '2012', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4682, to_date('25-10-2012', 'dd-mm-yyyy'), '4', '25', '299', '10', '2012', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4683, to_date('26-10-2012', 'dd-mm-yyyy'), '5', '26', '300', '10', '2012', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4684, to_date('27-10-2012', 'dd-mm-yyyy'), '6', '27', '301', '10', '2012', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4685, to_date('28-10-2012', 'dd-mm-yyyy'), '7', '28', '302', '10', '2012', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4686, to_date('29-10-2012', 'dd-mm-yyyy'), '1', '29', '303', '10', '2012', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4687, to_date('30-10-2012', 'dd-mm-yyyy'), '2', '30', '304', '10', '2012', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4688, to_date('31-10-2012', 'dd-mm-yyyy'), '3', '31', '305', '10', '2012', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4689, to_date('01-11-2012', 'dd-mm-yyyy'), '4', '01', '306', '11', '2012', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4690, to_date('02-11-2012', 'dd-mm-yyyy'), '5', '02', '307', '11', '2012', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4691, to_date('03-11-2012', 'dd-mm-yyyy'), '6', '03', '308', '11', '2012', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4692, to_date('04-11-2012', 'dd-mm-yyyy'), '7', '04', '309', '11', '2012', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4693, to_date('05-11-2012', 'dd-mm-yyyy'), '1', '05', '310', '11', '2012', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4694, to_date('06-11-2012', 'dd-mm-yyyy'), '2', '06', '311', '11', '2012', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4695, to_date('07-11-2012', 'dd-mm-yyyy'), '3', '07', '312', '11', '2012', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4696, to_date('08-11-2012', 'dd-mm-yyyy'), '4', '08', '313', '11', '2012', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4697, to_date('09-11-2012', 'dd-mm-yyyy'), '5', '09', '314', '11', '2012', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4698, to_date('10-11-2012', 'dd-mm-yyyy'), '6', '10', '315', '11', '2012', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4699, to_date('11-11-2012', 'dd-mm-yyyy'), '7', '11', '316', '11', '2012', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4700, to_date('12-11-2012', 'dd-mm-yyyy'), '1', '12', '317', '11', '2012', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4701, to_date('13-11-2012', 'dd-mm-yyyy'), '2', '13', '318', '11', '2012', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4702, to_date('14-11-2012', 'dd-mm-yyyy'), '3', '14', '319', '11', '2012', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4703, to_date('15-11-2012', 'dd-mm-yyyy'), '4', '15', '320', '11', '2012', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4704, to_date('16-11-2012', 'dd-mm-yyyy'), '5', '16', '321', '11', '2012', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4705, to_date('17-11-2012', 'dd-mm-yyyy'), '6', '17', '322', '11', '2012', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4706, to_date('18-11-2012', 'dd-mm-yyyy'), '7', '18', '323', '11', '2012', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4707, to_date('19-11-2012', 'dd-mm-yyyy'), '1', '19', '324', '11', '2012', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4708, to_date('20-11-2012', 'dd-mm-yyyy'), '2', '20', '325', '11', '2012', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4709, to_date('21-11-2012', 'dd-mm-yyyy'), '3', '21', '326', '11', '2012', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4710, to_date('22-11-2012', 'dd-mm-yyyy'), '4', '22', '327', '11', '2012', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4711, to_date('23-11-2012', 'dd-mm-yyyy'), '5', '23', '328', '11', '2012', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4712, to_date('24-11-2012', 'dd-mm-yyyy'), '6', '24', '329', '11', '2012', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4713, to_date('25-11-2012', 'dd-mm-yyyy'), '7', '25', '330', '11', '2012', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4714, to_date('26-11-2012', 'dd-mm-yyyy'), '1', '26', '331', '11', '2012', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4715, to_date('27-11-2012', 'dd-mm-yyyy'), '2', '27', '332', '11', '2012', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4716, to_date('28-11-2012', 'dd-mm-yyyy'), '3', '28', '333', '11', '2012', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4717, to_date('29-11-2012', 'dd-mm-yyyy'), '4', '29', '334', '11', '2012', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4718, to_date('30-11-2012', 'dd-mm-yyyy'), '5', '30', '335', '11', '2012', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4719, to_date('01-12-2012', 'dd-mm-yyyy'), '6', '01', '336', '12', '2012', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4720, to_date('02-12-2012', 'dd-mm-yyyy'), '7', '02', '337', '12', '2012', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4721, to_date('03-12-2012', 'dd-mm-yyyy'), '1', '03', '338', '12', '2012', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4722, to_date('04-12-2012', 'dd-mm-yyyy'), '2', '04', '339', '12', '2012', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4723, to_date('05-12-2012', 'dd-mm-yyyy'), '3', '05', '340', '12', '2012', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4724, to_date('06-12-2012', 'dd-mm-yyyy'), '4', '06', '341', '12', '2012', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4725, to_date('07-12-2012', 'dd-mm-yyyy'), '5', '07', '342', '12', '2012', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4726, to_date('08-12-2012', 'dd-mm-yyyy'), '6', '08', '343', '12', '2012', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4727, to_date('09-12-2012', 'dd-mm-yyyy'), '7', '09', '344', '12', '2012', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4728, to_date('10-12-2012', 'dd-mm-yyyy'), '1', '10', '345', '12', '2012', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4729, to_date('11-12-2012', 'dd-mm-yyyy'), '2', '11', '346', '12', '2012', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4730, to_date('12-12-2012', 'dd-mm-yyyy'), '3', '12', '347', '12', '2012', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4731, to_date('13-12-2012', 'dd-mm-yyyy'), '4', '13', '348', '12', '2012', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4732, to_date('14-12-2012', 'dd-mm-yyyy'), '5', '14', '349', '12', '2012', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4733, to_date('15-12-2012', 'dd-mm-yyyy'), '6', '15', '350', '12', '2012', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4734, to_date('16-12-2012', 'dd-mm-yyyy'), '7', '16', '351', '12', '2012', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4735, to_date('17-12-2012', 'dd-mm-yyyy'), '1', '17', '352', '12', '2012', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4736, to_date('18-12-2012', 'dd-mm-yyyy'), '2', '18', '353', '12', '2012', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4737, to_date('19-12-2012', 'dd-mm-yyyy'), '3', '19', '354', '12', '2012', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4738, to_date('20-12-2012', 'dd-mm-yyyy'), '4', '20', '355', '12', '2012', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4739, to_date('21-12-2012', 'dd-mm-yyyy'), '5', '21', '356', '12', '2012', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4740, to_date('22-12-2012', 'dd-mm-yyyy'), '6', '22', '357', '12', '2012', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4741, to_date('23-12-2012', 'dd-mm-yyyy'), '7', '23', '358', '12', '2012', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4742, to_date('24-12-2012', 'dd-mm-yyyy'), '1', '24', '359', '12', '2012', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4743, to_date('25-12-2012', 'dd-mm-yyyy'), '2', '25', '360', '12', '2012', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4744, to_date('26-12-2012', 'dd-mm-yyyy'), '3', '26', '361', '12', '2012', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4745, to_date('27-12-2012', 'dd-mm-yyyy'), '4', '27', '362', '12', '2012', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4746, to_date('28-12-2012', 'dd-mm-yyyy'), '5', '28', '363', '12', '2012', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4747, to_date('29-12-2012', 'dd-mm-yyyy'), '6', '29', '364', '12', '2012', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4748, to_date('30-12-2012', 'dd-mm-yyyy'), '7', '30', '365', '12', '2012', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4749, to_date('31-12-2012', 'dd-mm-yyyy'), '1', '31', '366', '12', '2012', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4750, to_date('01-01-2013', 'dd-mm-yyyy'), '2', '01', '001', '01', '2013', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4751, to_date('02-01-2013', 'dd-mm-yyyy'), '3', '02', '002', '01', '2013', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4752, to_date('03-01-2013', 'dd-mm-yyyy'), '4', '03', '003', '01', '2013', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4753, to_date('04-01-2013', 'dd-mm-yyyy'), '5', '04', '004', '01', '2013', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5294, to_date('29-06-2014', 'dd-mm-yyyy'), '7', '29', '180', '06', '2014', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5295, to_date('30-06-2014', 'dd-mm-yyyy'), '1', '30', '181', '06', '2014', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5296, to_date('01-07-2014', 'dd-mm-yyyy'), '2', '01', '182', '07', '2014', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5297, to_date('02-07-2014', 'dd-mm-yyyy'), '3', '02', '183', '07', '2014', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5298, to_date('03-07-2014', 'dd-mm-yyyy'), '4', '03', '184', '07', '2014', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5299, to_date('04-07-2014', 'dd-mm-yyyy'), '5', '04', '185', '07', '2014', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5300, to_date('05-07-2014', 'dd-mm-yyyy'), '6', '05', '186', '07', '2014', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5301, to_date('06-07-2014', 'dd-mm-yyyy'), '7', '06', '187', '07', '2014', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5302, to_date('07-07-2014', 'dd-mm-yyyy'), '1', '07', '188', '07', '2014', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5303, to_date('08-07-2014', 'dd-mm-yyyy'), '2', '08', '189', '07', '2014', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5304, to_date('09-07-2014', 'dd-mm-yyyy'), '3', '09', '190', '07', '2014', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5305, to_date('10-07-2014', 'dd-mm-yyyy'), '4', '10', '191', '07', '2014', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5306, to_date('11-07-2014', 'dd-mm-yyyy'), '5', '11', '192', '07', '2014', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5307, to_date('12-07-2014', 'dd-mm-yyyy'), '6', '12', '193', '07', '2014', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5308, to_date('13-07-2014', 'dd-mm-yyyy'), '7', '13', '194', '07', '2014', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5309, to_date('14-07-2014', 'dd-mm-yyyy'), '1', '14', '195', '07', '2014', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5310, to_date('15-07-2014', 'dd-mm-yyyy'), '2', '15', '196', '07', '2014', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5311, to_date('16-07-2014', 'dd-mm-yyyy'), '3', '16', '197', '07', '2014', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5312, to_date('17-07-2014', 'dd-mm-yyyy'), '4', '17', '198', '07', '2014', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5313, to_date('18-07-2014', 'dd-mm-yyyy'), '5', '18', '199', '07', '2014', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5314, to_date('19-07-2014', 'dd-mm-yyyy'), '6', '19', '200', '07', '2014', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5315, to_date('20-07-2014', 'dd-mm-yyyy'), '7', '20', '201', '07', '2014', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5316, to_date('21-07-2014', 'dd-mm-yyyy'), '1', '21', '202', '07', '2014', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5317, to_date('22-07-2014', 'dd-mm-yyyy'), '2', '22', '203', '07', '2014', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5318, to_date('23-07-2014', 'dd-mm-yyyy'), '3', '23', '204', '07', '2014', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5319, to_date('24-07-2014', 'dd-mm-yyyy'), '4', '24', '205', '07', '2014', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5320, to_date('25-07-2014', 'dd-mm-yyyy'), '5', '25', '206', '07', '2014', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5321, to_date('26-07-2014', 'dd-mm-yyyy'), '6', '26', '207', '07', '2014', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5322, to_date('27-07-2014', 'dd-mm-yyyy'), '7', '27', '208', '07', '2014', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5323, to_date('28-07-2014', 'dd-mm-yyyy'), '1', '28', '209', '07', '2014', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5324, to_date('29-07-2014', 'dd-mm-yyyy'), '2', '29', '210', '07', '2014', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5325, to_date('30-07-2014', 'dd-mm-yyyy'), '3', '30', '211', '07', '2014', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5326, to_date('31-07-2014', 'dd-mm-yyyy'), '4', '31', '212', '07', '2014', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5327, to_date('01-08-2014', 'dd-mm-yyyy'), '5', '01', '213', '08', '2014', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5328, to_date('02-08-2014', 'dd-mm-yyyy'), '6', '02', '214', '08', '2014', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5329, to_date('03-08-2014', 'dd-mm-yyyy'), '7', '03', '215', '08', '2014', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5330, to_date('04-08-2014', 'dd-mm-yyyy'), '1', '04', '216', '08', '2014', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5331, to_date('05-08-2014', 'dd-mm-yyyy'), '2', '05', '217', '08', '2014', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5332, to_date('06-08-2014', 'dd-mm-yyyy'), '3', '06', '218', '08', '2014', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5333, to_date('07-08-2014', 'dd-mm-yyyy'), '4', '07', '219', '08', '2014', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5334, to_date('08-08-2014', 'dd-mm-yyyy'), '5', '08', '220', '08', '2014', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5335, to_date('09-08-2014', 'dd-mm-yyyy'), '6', '09', '221', '08', '2014', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5336, to_date('10-08-2014', 'dd-mm-yyyy'), '7', '10', '222', '08', '2014', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5337, to_date('11-08-2014', 'dd-mm-yyyy'), '1', '11', '223', '08', '2014', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5338, to_date('12-08-2014', 'dd-mm-yyyy'), '2', '12', '224', '08', '2014', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5339, to_date('13-08-2014', 'dd-mm-yyyy'), '3', '13', '225', '08', '2014', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5340, to_date('14-08-2014', 'dd-mm-yyyy'), '4', '14', '226', '08', '2014', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5341, to_date('15-08-2014', 'dd-mm-yyyy'), '5', '15', '227', '08', '2014', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5342, to_date('16-08-2014', 'dd-mm-yyyy'), '6', '16', '228', '08', '2014', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5343, to_date('17-08-2014', 'dd-mm-yyyy'), '7', '17', '229', '08', '2014', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5344, to_date('18-08-2014', 'dd-mm-yyyy'), '1', '18', '230', '08', '2014', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5345, to_date('19-08-2014', 'dd-mm-yyyy'), '2', '19', '231', '08', '2014', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5346, to_date('20-08-2014', 'dd-mm-yyyy'), '3', '20', '232', '08', '2014', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5347, to_date('21-08-2014', 'dd-mm-yyyy'), '4', '21', '233', '08', '2014', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5348, to_date('22-08-2014', 'dd-mm-yyyy'), '5', '22', '234', '08', '2014', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5349, to_date('23-08-2014', 'dd-mm-yyyy'), '6', '23', '235', '08', '2014', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5350, to_date('24-08-2014', 'dd-mm-yyyy'), '7', '24', '236', '08', '2014', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5351, to_date('25-08-2014', 'dd-mm-yyyy'), '1', '25', '237', '08', '2014', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5352, to_date('26-08-2014', 'dd-mm-yyyy'), '2', '26', '238', '08', '2014', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5353, to_date('27-08-2014', 'dd-mm-yyyy'), '3', '27', '239', '08', '2014', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5354, to_date('28-08-2014', 'dd-mm-yyyy'), '4', '28', '240', '08', '2014', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5355, to_date('29-08-2014', 'dd-mm-yyyy'), '5', '29', '241', '08', '2014', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5356, to_date('30-08-2014', 'dd-mm-yyyy'), '6', '30', '242', '08', '2014', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5357, to_date('31-08-2014', 'dd-mm-yyyy'), '7', '31', '243', '08', '2014', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5358, to_date('01-09-2014', 'dd-mm-yyyy'), '1', '01', '244', '09', '2014', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5359, to_date('02-09-2014', 'dd-mm-yyyy'), '2', '02', '245', '09', '2014', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5360, to_date('03-09-2014', 'dd-mm-yyyy'), '3', '03', '246', '09', '2014', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5361, to_date('04-09-2014', 'dd-mm-yyyy'), '4', '04', '247', '09', '2014', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5362, to_date('05-09-2014', 'dd-mm-yyyy'), '5', '05', '248', '09', '2014', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5363, to_date('06-09-2014', 'dd-mm-yyyy'), '6', '06', '249', '09', '2014', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5364, to_date('07-09-2014', 'dd-mm-yyyy'), '7', '07', '250', '09', '2014', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5365, to_date('08-09-2014', 'dd-mm-yyyy'), '1', '08', '251', '09', '2014', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5366, to_date('09-09-2014', 'dd-mm-yyyy'), '2', '09', '252', '09', '2014', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5367, to_date('10-09-2014', 'dd-mm-yyyy'), '3', '10', '253', '09', '2014', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5368, to_date('11-09-2014', 'dd-mm-yyyy'), '4', '11', '254', '09', '2014', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5369, to_date('12-09-2014', 'dd-mm-yyyy'), '5', '12', '255', '09', '2014', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5370, to_date('13-09-2014', 'dd-mm-yyyy'), '6', '13', '256', '09', '2014', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5371, to_date('14-09-2014', 'dd-mm-yyyy'), '7', '14', '257', '09', '2014', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5372, to_date('15-09-2014', 'dd-mm-yyyy'), '1', '15', '258', '09', '2014', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5373, to_date('16-09-2014', 'dd-mm-yyyy'), '2', '16', '259', '09', '2014', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5374, to_date('17-09-2014', 'dd-mm-yyyy'), '3', '17', '260', '09', '2014', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5375, to_date('18-09-2014', 'dd-mm-yyyy'), '4', '18', '261', '09', '2014', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5376, to_date('19-09-2014', 'dd-mm-yyyy'), '5', '19', '262', '09', '2014', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5377, to_date('20-09-2014', 'dd-mm-yyyy'), '6', '20', '263', '09', '2014', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5378, to_date('21-09-2014', 'dd-mm-yyyy'), '7', '21', '264', '09', '2014', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5379, to_date('22-09-2014', 'dd-mm-yyyy'), '1', '22', '265', '09', '2014', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5380, to_date('23-09-2014', 'dd-mm-yyyy'), '2', '23', '266', '09', '2014', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5381, to_date('24-09-2014', 'dd-mm-yyyy'), '3', '24', '267', '09', '2014', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5382, to_date('25-09-2014', 'dd-mm-yyyy'), '4', '25', '268', '09', '2014', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5383, to_date('26-09-2014', 'dd-mm-yyyy'), '5', '26', '269', '09', '2014', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5384, to_date('27-09-2014', 'dd-mm-yyyy'), '6', '27', '270', '09', '2014', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5385, to_date('28-09-2014', 'dd-mm-yyyy'), '7', '28', '271', '09', '2014', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5386, to_date('29-09-2014', 'dd-mm-yyyy'), '1', '29', '272', '09', '2014', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5387, to_date('30-09-2014', 'dd-mm-yyyy'), '2', '30', '273', '09', '2014', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5388, to_date('01-10-2014', 'dd-mm-yyyy'), '3', '01', '274', '10', '2014', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5389, to_date('02-10-2014', 'dd-mm-yyyy'), '4', '02', '275', '10', '2014', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5390, to_date('03-10-2014', 'dd-mm-yyyy'), '5', '03', '276', '10', '2014', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5391, to_date('04-10-2014', 'dd-mm-yyyy'), '6', '04', '277', '10', '2014', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5392, to_date('05-10-2014', 'dd-mm-yyyy'), '7', '05', '278', '10', '2014', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5393, to_date('06-10-2014', 'dd-mm-yyyy'), '1', '06', '279', '10', '2014', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5394, to_date('07-10-2014', 'dd-mm-yyyy'), '2', '07', '280', '10', '2014', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5395, to_date('08-10-2014', 'dd-mm-yyyy'), '3', '08', '281', '10', '2014', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5396, to_date('09-10-2014', 'dd-mm-yyyy'), '4', '09', '282', '10', '2014', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5397, to_date('10-10-2014', 'dd-mm-yyyy'), '5', '10', '283', '10', '2014', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5398, to_date('11-10-2014', 'dd-mm-yyyy'), '6', '11', '284', '10', '2014', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5399, to_date('12-10-2014', 'dd-mm-yyyy'), '7', '12', '285', '10', '2014', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5400, to_date('13-10-2014', 'dd-mm-yyyy'), '1', '13', '286', '10', '2014', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5401, to_date('14-10-2014', 'dd-mm-yyyy'), '2', '14', '287', '10', '2014', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4754, to_date('05-01-2013', 'dd-mm-yyyy'), '6', '05', '005', '01', '2013', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4755, to_date('06-01-2013', 'dd-mm-yyyy'), '7', '06', '006', '01', '2013', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4756, to_date('07-01-2013', 'dd-mm-yyyy'), '1', '07', '007', '01', '2013', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4757, to_date('08-01-2013', 'dd-mm-yyyy'), '2', '08', '008', '01', '2013', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4758, to_date('09-01-2013', 'dd-mm-yyyy'), '3', '09', '009', '01', '2013', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4759, to_date('10-01-2013', 'dd-mm-yyyy'), '4', '10', '010', '01', '2013', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4760, to_date('11-01-2013', 'dd-mm-yyyy'), '5', '11', '011', '01', '2013', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4761, to_date('12-01-2013', 'dd-mm-yyyy'), '6', '12', '012', '01', '2013', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4762, to_date('13-01-2013', 'dd-mm-yyyy'), '7', '13', '013', '01', '2013', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4763, to_date('14-01-2013', 'dd-mm-yyyy'), '1', '14', '014', '01', '2013', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4764, to_date('15-01-2013', 'dd-mm-yyyy'), '2', '15', '015', '01', '2013', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4765, to_date('16-01-2013', 'dd-mm-yyyy'), '3', '16', '016', '01', '2013', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4766, to_date('17-01-2013', 'dd-mm-yyyy'), '4', '17', '017', '01', '2013', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4767, to_date('18-01-2013', 'dd-mm-yyyy'), '5', '18', '018', '01', '2013', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4768, to_date('19-01-2013', 'dd-mm-yyyy'), '6', '19', '019', '01', '2013', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4769, to_date('20-01-2013', 'dd-mm-yyyy'), '7', '20', '020', '01', '2013', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4770, to_date('21-01-2013', 'dd-mm-yyyy'), '1', '21', '021', '01', '2013', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4771, to_date('22-01-2013', 'dd-mm-yyyy'), '2', '22', '022', '01', '2013', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4772, to_date('23-01-2013', 'dd-mm-yyyy'), '3', '23', '023', '01', '2013', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4773, to_date('24-01-2013', 'dd-mm-yyyy'), '4', '24', '024', '01', '2013', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4774, to_date('25-01-2013', 'dd-mm-yyyy'), '5', '25', '025', '01', '2013', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4775, to_date('26-01-2013', 'dd-mm-yyyy'), '6', '26', '026', '01', '2013', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4776, to_date('27-01-2013', 'dd-mm-yyyy'), '7', '27', '027', '01', '2013', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4777, to_date('28-01-2013', 'dd-mm-yyyy'), '1', '28', '028', '01', '2013', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4778, to_date('29-01-2013', 'dd-mm-yyyy'), '2', '29', '029', '01', '2013', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4779, to_date('30-01-2013', 'dd-mm-yyyy'), '3', '30', '030', '01', '2013', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4780, to_date('31-01-2013', 'dd-mm-yyyy'), '4', '31', '031', '01', '2013', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4781, to_date('01-02-2013', 'dd-mm-yyyy'), '5', '01', '032', '02', '2013', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4782, to_date('02-02-2013', 'dd-mm-yyyy'), '6', '02', '033', '02', '2013', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4783, to_date('03-02-2013', 'dd-mm-yyyy'), '7', '03', '034', '02', '2013', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4784, to_date('04-02-2013', 'dd-mm-yyyy'), '1', '04', '035', '02', '2013', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4785, to_date('05-02-2013', 'dd-mm-yyyy'), '2', '05', '036', '02', '2013', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4786, to_date('06-02-2013', 'dd-mm-yyyy'), '3', '06', '037', '02', '2013', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4787, to_date('07-02-2013', 'dd-mm-yyyy'), '4', '07', '038', '02', '2013', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4788, to_date('08-02-2013', 'dd-mm-yyyy'), '5', '08', '039', '02', '2013', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4789, to_date('09-02-2013', 'dd-mm-yyyy'), '6', '09', '040', '02', '2013', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4790, to_date('10-02-2013', 'dd-mm-yyyy'), '7', '10', '041', '02', '2013', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4791, to_date('11-02-2013', 'dd-mm-yyyy'), '1', '11', '042', '02', '2013', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4792, to_date('12-02-2013', 'dd-mm-yyyy'), '2', '12', '043', '02', '2013', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4793, to_date('13-02-2013', 'dd-mm-yyyy'), '3', '13', '044', '02', '2013', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4794, to_date('14-02-2013', 'dd-mm-yyyy'), '4', '14', '045', '02', '2013', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4795, to_date('15-02-2013', 'dd-mm-yyyy'), '5', '15', '046', '02', '2013', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4796, to_date('16-02-2013', 'dd-mm-yyyy'), '6', '16', '047', '02', '2013', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4797, to_date('17-02-2013', 'dd-mm-yyyy'), '7', '17', '048', '02', '2013', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4798, to_date('18-02-2013', 'dd-mm-yyyy'), '1', '18', '049', '02', '2013', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4799, to_date('19-02-2013', 'dd-mm-yyyy'), '2', '19', '050', '02', '2013', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4800, to_date('20-02-2013', 'dd-mm-yyyy'), '3', '20', '051', '02', '2013', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4801, to_date('21-02-2013', 'dd-mm-yyyy'), '4', '21', '052', '02', '2013', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4802, to_date('22-02-2013', 'dd-mm-yyyy'), '5', '22', '053', '02', '2013', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4803, to_date('23-02-2013', 'dd-mm-yyyy'), '6', '23', '054', '02', '2013', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4804, to_date('24-02-2013', 'dd-mm-yyyy'), '7', '24', '055', '02', '2013', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4805, to_date('25-02-2013', 'dd-mm-yyyy'), '1', '25', '056', '02', '2013', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4806, to_date('26-02-2013', 'dd-mm-yyyy'), '2', '26', '057', '02', '2013', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4807, to_date('27-02-2013', 'dd-mm-yyyy'), '3', '27', '058', '02', '2013', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4808, to_date('28-02-2013', 'dd-mm-yyyy'), '4', '28', '059', '02', '2013', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4809, to_date('01-03-2013', 'dd-mm-yyyy'), '5', '01', '060', '03', '2013', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4810, to_date('02-03-2013', 'dd-mm-yyyy'), '6', '02', '061', '03', '2013', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4811, to_date('03-03-2013', 'dd-mm-yyyy'), '7', '03', '062', '03', '2013', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4812, to_date('04-03-2013', 'dd-mm-yyyy'), '1', '04', '063', '03', '2013', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4813, to_date('05-03-2013', 'dd-mm-yyyy'), '2', '05', '064', '03', '2013', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4814, to_date('06-03-2013', 'dd-mm-yyyy'), '3', '06', '065', '03', '2013', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4815, to_date('07-03-2013', 'dd-mm-yyyy'), '4', '07', '066', '03', '2013', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4816, to_date('08-03-2013', 'dd-mm-yyyy'), '5', '08', '067', '03', '2013', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4817, to_date('09-03-2013', 'dd-mm-yyyy'), '6', '09', '068', '03', '2013', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4818, to_date('10-03-2013', 'dd-mm-yyyy'), '7', '10', '069', '03', '2013', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4819, to_date('11-03-2013', 'dd-mm-yyyy'), '1', '11', '070', '03', '2013', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4820, to_date('12-03-2013', 'dd-mm-yyyy'), '2', '12', '071', '03', '2013', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4821, to_date('13-03-2013', 'dd-mm-yyyy'), '3', '13', '072', '03', '2013', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4822, to_date('14-03-2013', 'dd-mm-yyyy'), '4', '14', '073', '03', '2013', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4823, to_date('15-03-2013', 'dd-mm-yyyy'), '5', '15', '074', '03', '2013', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4824, to_date('16-03-2013', 'dd-mm-yyyy'), '6', '16', '075', '03', '2013', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4825, to_date('17-03-2013', 'dd-mm-yyyy'), '7', '17', '076', '03', '2013', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4826, to_date('18-03-2013', 'dd-mm-yyyy'), '1', '18', '077', '03', '2013', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4827, to_date('19-03-2013', 'dd-mm-yyyy'), '2', '19', '078', '03', '2013', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4828, to_date('20-03-2013', 'dd-mm-yyyy'), '3', '20', '079', '03', '2013', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4829, to_date('21-03-2013', 'dd-mm-yyyy'), '4', '21', '080', '03', '2013', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4830, to_date('22-03-2013', 'dd-mm-yyyy'), '5', '22', '081', '03', '2013', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4831, to_date('23-03-2013', 'dd-mm-yyyy'), '6', '23', '082', '03', '2013', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4832, to_date('24-03-2013', 'dd-mm-yyyy'), '7', '24', '083', '03', '2013', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4833, to_date('25-03-2013', 'dd-mm-yyyy'), '1', '25', '084', '03', '2013', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4834, to_date('26-03-2013', 'dd-mm-yyyy'), '2', '26', '085', '03', '2013', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4835, to_date('27-03-2013', 'dd-mm-yyyy'), '3', '27', '086', '03', '2013', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4836, to_date('28-03-2013', 'dd-mm-yyyy'), '4', '28', '087', '03', '2013', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4837, to_date('29-03-2013', 'dd-mm-yyyy'), '5', '29', '088', '03', '2013', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4838, to_date('30-03-2013', 'dd-mm-yyyy'), '6', '30', '089', '03', '2013', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4839, to_date('31-03-2013', 'dd-mm-yyyy'), '7', '31', '090', '03', '2013', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4840, to_date('01-04-2013', 'dd-mm-yyyy'), '1', '01', '091', '04', '2013', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4841, to_date('02-04-2013', 'dd-mm-yyyy'), '2', '02', '092', '04', '2013', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4842, to_date('03-04-2013', 'dd-mm-yyyy'), '3', '03', '093', '04', '2013', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4843, to_date('04-04-2013', 'dd-mm-yyyy'), '4', '04', '094', '04', '2013', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4844, to_date('05-04-2013', 'dd-mm-yyyy'), '5', '05', '095', '04', '2013', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4845, to_date('06-04-2013', 'dd-mm-yyyy'), '6', '06', '096', '04', '2013', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4846, to_date('07-04-2013', 'dd-mm-yyyy'), '7', '07', '097', '04', '2013', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4847, to_date('08-04-2013', 'dd-mm-yyyy'), '1', '08', '098', '04', '2013', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4848, to_date('09-04-2013', 'dd-mm-yyyy'), '2', '09', '099', '04', '2013', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4849, to_date('10-04-2013', 'dd-mm-yyyy'), '3', '10', '100', '04', '2013', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4850, to_date('11-04-2013', 'dd-mm-yyyy'), '4', '11', '101', '04', '2013', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4851, to_date('12-04-2013', 'dd-mm-yyyy'), '5', '12', '102', '04', '2013', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4852, to_date('13-04-2013', 'dd-mm-yyyy'), '6', '13', '103', '04', '2013', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4853, to_date('14-04-2013', 'dd-mm-yyyy'), '7', '14', '104', '04', '2013', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4854, to_date('15-04-2013', 'dd-mm-yyyy'), '1', '15', '105', '04', '2013', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4855, to_date('16-04-2013', 'dd-mm-yyyy'), '2', '16', '106', '04', '2013', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4856, to_date('17-04-2013', 'dd-mm-yyyy'), '3', '17', '107', '04', '2013', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4857, to_date('18-04-2013', 'dd-mm-yyyy'), '4', '18', '108', '04', '2013', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4858, to_date('19-04-2013', 'dd-mm-yyyy'), '5', '19', '109', '04', '2013', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4859, to_date('20-04-2013', 'dd-mm-yyyy'), '6', '20', '110', '04', '2013', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4860, to_date('21-04-2013', 'dd-mm-yyyy'), '7', '21', '111', '04', '2013', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4861, to_date('22-04-2013', 'dd-mm-yyyy'), '1', '22', '112', '04', '2013', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4862, to_date('23-04-2013', 'dd-mm-yyyy'), '2', '23', '113', '04', '2013', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4863, to_date('24-04-2013', 'dd-mm-yyyy'), '3', '24', '114', '04', '2013', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4864, to_date('25-04-2013', 'dd-mm-yyyy'), '4', '25', '115', '04', '2013', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4865, to_date('26-04-2013', 'dd-mm-yyyy'), '5', '26', '116', '04', '2013', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4866, to_date('27-04-2013', 'dd-mm-yyyy'), '6', '27', '117', '04', '2013', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4867, to_date('28-04-2013', 'dd-mm-yyyy'), '7', '28', '118', '04', '2013', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4868, to_date('29-04-2013', 'dd-mm-yyyy'), '1', '29', '119', '04', '2013', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4869, to_date('30-04-2013', 'dd-mm-yyyy'), '2', '30', '120', '04', '2013', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4870, to_date('01-05-2013', 'dd-mm-yyyy'), '3', '01', '121', '05', '2013', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4871, to_date('02-05-2013', 'dd-mm-yyyy'), '4', '02', '122', '05', '2013', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4872, to_date('03-05-2013', 'dd-mm-yyyy'), '5', '03', '123', '05', '2013', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4873, to_date('04-05-2013', 'dd-mm-yyyy'), '6', '04', '124', '05', '2013', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4874, to_date('05-05-2013', 'dd-mm-yyyy'), '7', '05', '125', '05', '2013', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4875, to_date('06-05-2013', 'dd-mm-yyyy'), '1', '06', '126', '05', '2013', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4876, to_date('07-05-2013', 'dd-mm-yyyy'), '2', '07', '127', '05', '2013', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4877, to_date('08-05-2013', 'dd-mm-yyyy'), '3', '08', '128', '05', '2013', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4878, to_date('09-05-2013', 'dd-mm-yyyy'), '4', '09', '129', '05', '2013', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4879, to_date('10-05-2013', 'dd-mm-yyyy'), '5', '10', '130', '05', '2013', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4880, to_date('11-05-2013', 'dd-mm-yyyy'), '6', '11', '131', '05', '2013', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4881, to_date('12-05-2013', 'dd-mm-yyyy'), '7', '12', '132', '05', '2013', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4882, to_date('13-05-2013', 'dd-mm-yyyy'), '1', '13', '133', '05', '2013', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4883, to_date('14-05-2013', 'dd-mm-yyyy'), '2', '14', '134', '05', '2013', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4884, to_date('15-05-2013', 'dd-mm-yyyy'), '3', '15', '135', '05', '2013', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4885, to_date('16-05-2013', 'dd-mm-yyyy'), '4', '16', '136', '05', '2013', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4886, to_date('17-05-2013', 'dd-mm-yyyy'), '5', '17', '137', '05', '2013', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4887, to_date('18-05-2013', 'dd-mm-yyyy'), '6', '18', '138', '05', '2013', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4888, to_date('19-05-2013', 'dd-mm-yyyy'), '7', '19', '139', '05', '2013', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4889, to_date('20-05-2013', 'dd-mm-yyyy'), '1', '20', '140', '05', '2013', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4890, to_date('21-05-2013', 'dd-mm-yyyy'), '2', '21', '141', '05', '2013', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4891, to_date('22-05-2013', 'dd-mm-yyyy'), '3', '22', '142', '05', '2013', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4892, to_date('23-05-2013', 'dd-mm-yyyy'), '4', '23', '143', '05', '2013', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
commit;
prompt 5000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4893, to_date('24-05-2013', 'dd-mm-yyyy'), '5', '24', '144', '05', '2013', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4894, to_date('25-05-2013', 'dd-mm-yyyy'), '6', '25', '145', '05', '2013', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4895, to_date('26-05-2013', 'dd-mm-yyyy'), '7', '26', '146', '05', '2013', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4896, to_date('27-05-2013', 'dd-mm-yyyy'), '1', '27', '147', '05', '2013', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4897, to_date('28-05-2013', 'dd-mm-yyyy'), '2', '28', '148', '05', '2013', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4898, to_date('29-05-2013', 'dd-mm-yyyy'), '3', '29', '149', '05', '2013', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4899, to_date('30-05-2013', 'dd-mm-yyyy'), '4', '30', '150', '05', '2013', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4900, to_date('31-05-2013', 'dd-mm-yyyy'), '5', '31', '151', '05', '2013', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4901, to_date('01-06-2013', 'dd-mm-yyyy'), '6', '01', '152', '06', '2013', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4902, to_date('02-06-2013', 'dd-mm-yyyy'), '7', '02', '153', '06', '2013', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4903, to_date('03-06-2013', 'dd-mm-yyyy'), '1', '03', '154', '06', '2013', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4904, to_date('04-06-2013', 'dd-mm-yyyy'), '2', '04', '155', '06', '2013', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4905, to_date('05-06-2013', 'dd-mm-yyyy'), '3', '05', '156', '06', '2013', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4906, to_date('06-06-2013', 'dd-mm-yyyy'), '4', '06', '157', '06', '2013', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4907, to_date('07-06-2013', 'dd-mm-yyyy'), '5', '07', '158', '06', '2013', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4908, to_date('08-06-2013', 'dd-mm-yyyy'), '6', '08', '159', '06', '2013', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4909, to_date('09-06-2013', 'dd-mm-yyyy'), '7', '09', '160', '06', '2013', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4910, to_date('10-06-2013', 'dd-mm-yyyy'), '1', '10', '161', '06', '2013', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4911, to_date('11-06-2013', 'dd-mm-yyyy'), '2', '11', '162', '06', '2013', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4912, to_date('12-06-2013', 'dd-mm-yyyy'), '3', '12', '163', '06', '2013', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4913, to_date('13-06-2013', 'dd-mm-yyyy'), '4', '13', '164', '06', '2013', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4914, to_date('14-06-2013', 'dd-mm-yyyy'), '5', '14', '165', '06', '2013', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4915, to_date('15-06-2013', 'dd-mm-yyyy'), '6', '15', '166', '06', '2013', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4916, to_date('16-06-2013', 'dd-mm-yyyy'), '7', '16', '167', '06', '2013', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4917, to_date('17-06-2013', 'dd-mm-yyyy'), '1', '17', '168', '06', '2013', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4918, to_date('18-06-2013', 'dd-mm-yyyy'), '2', '18', '169', '06', '2013', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4919, to_date('19-06-2013', 'dd-mm-yyyy'), '3', '19', '170', '06', '2013', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4920, to_date('20-06-2013', 'dd-mm-yyyy'), '4', '20', '171', '06', '2013', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4921, to_date('21-06-2013', 'dd-mm-yyyy'), '5', '21', '172', '06', '2013', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4922, to_date('22-06-2013', 'dd-mm-yyyy'), '6', '22', '173', '06', '2013', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4923, to_date('23-06-2013', 'dd-mm-yyyy'), '7', '23', '174', '06', '2013', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4924, to_date('24-06-2013', 'dd-mm-yyyy'), '1', '24', '175', '06', '2013', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4925, to_date('25-06-2013', 'dd-mm-yyyy'), '2', '25', '176', '06', '2013', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4926, to_date('26-06-2013', 'dd-mm-yyyy'), '3', '26', '177', '06', '2013', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4927, to_date('27-06-2013', 'dd-mm-yyyy'), '4', '27', '178', '06', '2013', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4928, to_date('28-06-2013', 'dd-mm-yyyy'), '5', '28', '179', '06', '2013', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4929, to_date('29-06-2013', 'dd-mm-yyyy'), '6', '29', '180', '06', '2013', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4930, to_date('30-06-2013', 'dd-mm-yyyy'), '7', '30', '181', '06', '2013', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4931, to_date('01-07-2013', 'dd-mm-yyyy'), '1', '01', '182', '07', '2013', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4932, to_date('02-07-2013', 'dd-mm-yyyy'), '2', '02', '183', '07', '2013', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4933, to_date('03-07-2013', 'dd-mm-yyyy'), '3', '03', '184', '07', '2013', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4934, to_date('04-07-2013', 'dd-mm-yyyy'), '4', '04', '185', '07', '2013', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4935, to_date('05-07-2013', 'dd-mm-yyyy'), '5', '05', '186', '07', '2013', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4936, to_date('06-07-2013', 'dd-mm-yyyy'), '6', '06', '187', '07', '2013', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4937, to_date('07-07-2013', 'dd-mm-yyyy'), '7', '07', '188', '07', '2013', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4938, to_date('08-07-2013', 'dd-mm-yyyy'), '1', '08', '189', '07', '2013', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4939, to_date('09-07-2013', 'dd-mm-yyyy'), '2', '09', '190', '07', '2013', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4940, to_date('10-07-2013', 'dd-mm-yyyy'), '3', '10', '191', '07', '2013', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4941, to_date('11-07-2013', 'dd-mm-yyyy'), '4', '11', '192', '07', '2013', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4942, to_date('12-07-2013', 'dd-mm-yyyy'), '5', '12', '193', '07', '2013', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4943, to_date('13-07-2013', 'dd-mm-yyyy'), '6', '13', '194', '07', '2013', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4944, to_date('14-07-2013', 'dd-mm-yyyy'), '7', '14', '195', '07', '2013', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4945, to_date('15-07-2013', 'dd-mm-yyyy'), '1', '15', '196', '07', '2013', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4946, to_date('16-07-2013', 'dd-mm-yyyy'), '2', '16', '197', '07', '2013', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4947, to_date('17-07-2013', 'dd-mm-yyyy'), '3', '17', '198', '07', '2013', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4948, to_date('18-07-2013', 'dd-mm-yyyy'), '4', '18', '199', '07', '2013', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4949, to_date('19-07-2013', 'dd-mm-yyyy'), '5', '19', '200', '07', '2013', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4950, to_date('20-07-2013', 'dd-mm-yyyy'), '6', '20', '201', '07', '2013', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4951, to_date('21-07-2013', 'dd-mm-yyyy'), '7', '21', '202', '07', '2013', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4952, to_date('22-07-2013', 'dd-mm-yyyy'), '1', '22', '203', '07', '2013', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4953, to_date('23-07-2013', 'dd-mm-yyyy'), '2', '23', '204', '07', '2013', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4954, to_date('24-07-2013', 'dd-mm-yyyy'), '3', '24', '205', '07', '2013', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4955, to_date('25-07-2013', 'dd-mm-yyyy'), '4', '25', '206', '07', '2013', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4956, to_date('26-07-2013', 'dd-mm-yyyy'), '5', '26', '207', '07', '2013', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4957, to_date('27-07-2013', 'dd-mm-yyyy'), '6', '27', '208', '07', '2013', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4958, to_date('28-07-2013', 'dd-mm-yyyy'), '7', '28', '209', '07', '2013', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4959, to_date('29-07-2013', 'dd-mm-yyyy'), '1', '29', '210', '07', '2013', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4960, to_date('30-07-2013', 'dd-mm-yyyy'), '2', '30', '211', '07', '2013', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4961, to_date('31-07-2013', 'dd-mm-yyyy'), '3', '31', '212', '07', '2013', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4962, to_date('01-08-2013', 'dd-mm-yyyy'), '4', '01', '213', '08', '2013', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4963, to_date('02-08-2013', 'dd-mm-yyyy'), '5', '02', '214', '08', '2013', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4964, to_date('03-08-2013', 'dd-mm-yyyy'), '6', '03', '215', '08', '2013', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4965, to_date('04-08-2013', 'dd-mm-yyyy'), '7', '04', '216', '08', '2013', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4966, to_date('05-08-2013', 'dd-mm-yyyy'), '1', '05', '217', '08', '2013', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4967, to_date('06-08-2013', 'dd-mm-yyyy'), '2', '06', '218', '08', '2013', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4968, to_date('07-08-2013', 'dd-mm-yyyy'), '3', '07', '219', '08', '2013', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4969, to_date('08-08-2013', 'dd-mm-yyyy'), '4', '08', '220', '08', '2013', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4970, to_date('09-08-2013', 'dd-mm-yyyy'), '5', '09', '221', '08', '2013', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4971, to_date('10-08-2013', 'dd-mm-yyyy'), '6', '10', '222', '08', '2013', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4972, to_date('11-08-2013', 'dd-mm-yyyy'), '7', '11', '223', '08', '2013', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4973, to_date('12-08-2013', 'dd-mm-yyyy'), '1', '12', '224', '08', '2013', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4974, to_date('13-08-2013', 'dd-mm-yyyy'), '2', '13', '225', '08', '2013', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4975, to_date('14-08-2013', 'dd-mm-yyyy'), '3', '14', '226', '08', '2013', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4976, to_date('15-08-2013', 'dd-mm-yyyy'), '4', '15', '227', '08', '2013', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4977, to_date('16-08-2013', 'dd-mm-yyyy'), '5', '16', '228', '08', '2013', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4978, to_date('17-08-2013', 'dd-mm-yyyy'), '6', '17', '229', '08', '2013', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4979, to_date('18-08-2013', 'dd-mm-yyyy'), '7', '18', '230', '08', '2013', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4980, to_date('19-08-2013', 'dd-mm-yyyy'), '1', '19', '231', '08', '2013', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4981, to_date('20-08-2013', 'dd-mm-yyyy'), '2', '20', '232', '08', '2013', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4982, to_date('21-08-2013', 'dd-mm-yyyy'), '3', '21', '233', '08', '2013', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4983, to_date('22-08-2013', 'dd-mm-yyyy'), '4', '22', '234', '08', '2013', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4984, to_date('23-08-2013', 'dd-mm-yyyy'), '5', '23', '235', '08', '2013', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4985, to_date('24-08-2013', 'dd-mm-yyyy'), '6', '24', '236', '08', '2013', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4986, to_date('25-08-2013', 'dd-mm-yyyy'), '7', '25', '237', '08', '2013', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4987, to_date('26-08-2013', 'dd-mm-yyyy'), '1', '26', '238', '08', '2013', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4988, to_date('27-08-2013', 'dd-mm-yyyy'), '2', '27', '239', '08', '2013', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4989, to_date('28-08-2013', 'dd-mm-yyyy'), '3', '28', '240', '08', '2013', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4990, to_date('29-08-2013', 'dd-mm-yyyy'), '4', '29', '241', '08', '2013', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4991, to_date('30-08-2013', 'dd-mm-yyyy'), '5', '30', '242', '08', '2013', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4992, to_date('31-08-2013', 'dd-mm-yyyy'), '6', '31', '243', '08', '2013', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4993, to_date('01-09-2013', 'dd-mm-yyyy'), '7', '01', '244', '09', '2013', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4994, to_date('02-09-2013', 'dd-mm-yyyy'), '1', '02', '245', '09', '2013', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4995, to_date('03-09-2013', 'dd-mm-yyyy'), '2', '03', '246', '09', '2013', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4996, to_date('04-09-2013', 'dd-mm-yyyy'), '3', '04', '247', '09', '2013', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4997, to_date('05-09-2013', 'dd-mm-yyyy'), '4', '05', '248', '09', '2013', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4998, to_date('06-09-2013', 'dd-mm-yyyy'), '5', '06', '249', '09', '2013', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (4999, to_date('07-09-2013', 'dd-mm-yyyy'), '6', '07', '250', '09', '2013', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5000, to_date('08-09-2013', 'dd-mm-yyyy'), '7', '08', '251', '09', '2013', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5001, to_date('09-09-2013', 'dd-mm-yyyy'), '1', '09', '252', '09', '2013', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5002, to_date('10-09-2013', 'dd-mm-yyyy'), '2', '10', '253', '09', '2013', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5003, to_date('11-09-2013', 'dd-mm-yyyy'), '3', '11', '254', '09', '2013', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5004, to_date('12-09-2013', 'dd-mm-yyyy'), '4', '12', '255', '09', '2013', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5005, to_date('13-09-2013', 'dd-mm-yyyy'), '5', '13', '256', '09', '2013', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5006, to_date('14-09-2013', 'dd-mm-yyyy'), '6', '14', '257', '09', '2013', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5007, to_date('15-09-2013', 'dd-mm-yyyy'), '7', '15', '258', '09', '2013', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5008, to_date('16-09-2013', 'dd-mm-yyyy'), '1', '16', '259', '09', '2013', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5009, to_date('17-09-2013', 'dd-mm-yyyy'), '2', '17', '260', '09', '2013', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5010, to_date('18-09-2013', 'dd-mm-yyyy'), '3', '18', '261', '09', '2013', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5011, to_date('19-09-2013', 'dd-mm-yyyy'), '4', '19', '262', '09', '2013', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5012, to_date('20-09-2013', 'dd-mm-yyyy'), '5', '20', '263', '09', '2013', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5013, to_date('21-09-2013', 'dd-mm-yyyy'), '6', '21', '264', '09', '2013', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5014, to_date('22-09-2013', 'dd-mm-yyyy'), '7', '22', '265', '09', '2013', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5015, to_date('23-09-2013', 'dd-mm-yyyy'), '1', '23', '266', '09', '2013', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5016, to_date('24-09-2013', 'dd-mm-yyyy'), '2', '24', '267', '09', '2013', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5017, to_date('25-09-2013', 'dd-mm-yyyy'), '3', '25', '268', '09', '2013', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5018, to_date('26-09-2013', 'dd-mm-yyyy'), '4', '26', '269', '09', '2013', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5019, to_date('27-09-2013', 'dd-mm-yyyy'), '5', '27', '270', '09', '2013', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5020, to_date('28-09-2013', 'dd-mm-yyyy'), '6', '28', '271', '09', '2013', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5021, to_date('29-09-2013', 'dd-mm-yyyy'), '7', '29', '272', '09', '2013', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5022, to_date('30-09-2013', 'dd-mm-yyyy'), '1', '30', '273', '09', '2013', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5023, to_date('01-10-2013', 'dd-mm-yyyy'), '2', '01', '274', '10', '2013', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5024, to_date('02-10-2013', 'dd-mm-yyyy'), '3', '02', '275', '10', '2013', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5025, to_date('03-10-2013', 'dd-mm-yyyy'), '4', '03', '276', '10', '2013', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5026, to_date('04-10-2013', 'dd-mm-yyyy'), '5', '04', '277', '10', '2013', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5027, to_date('05-10-2013', 'dd-mm-yyyy'), '6', '05', '278', '10', '2013', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5028, to_date('06-10-2013', 'dd-mm-yyyy'), '7', '06', '279', '10', '2013', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5029, to_date('07-10-2013', 'dd-mm-yyyy'), '1', '07', '280', '10', '2013', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5030, to_date('08-10-2013', 'dd-mm-yyyy'), '2', '08', '281', '10', '2013', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5031, to_date('09-10-2013', 'dd-mm-yyyy'), '3', '09', '282', '10', '2013', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5032, to_date('10-10-2013', 'dd-mm-yyyy'), '4', '10', '283', '10', '2013', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5033, to_date('11-10-2013', 'dd-mm-yyyy'), '5', '11', '284', '10', '2013', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5034, to_date('12-10-2013', 'dd-mm-yyyy'), '6', '12', '285', '10', '2013', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5035, to_date('13-10-2013', 'dd-mm-yyyy'), '7', '13', '286', '10', '2013', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5036, to_date('14-10-2013', 'dd-mm-yyyy'), '1', '14', '287', '10', '2013', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5037, to_date('15-10-2013', 'dd-mm-yyyy'), '2', '15', '288', '10', '2013', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5038, to_date('16-10-2013', 'dd-mm-yyyy'), '3', '16', '289', '10', '2013', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5039, to_date('17-10-2013', 'dd-mm-yyyy'), '4', '17', '290', '10', '2013', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5040, to_date('18-10-2013', 'dd-mm-yyyy'), '5', '18', '291', '10', '2013', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5041, to_date('19-10-2013', 'dd-mm-yyyy'), '6', '19', '292', '10', '2013', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5042, to_date('20-10-2013', 'dd-mm-yyyy'), '7', '20', '293', '10', '2013', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5043, to_date('21-10-2013', 'dd-mm-yyyy'), '1', '21', '294', '10', '2013', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5044, to_date('22-10-2013', 'dd-mm-yyyy'), '2', '22', '295', '10', '2013', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5045, to_date('23-10-2013', 'dd-mm-yyyy'), '3', '23', '296', '10', '2013', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5046, to_date('24-10-2013', 'dd-mm-yyyy'), '4', '24', '297', '10', '2013', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5047, to_date('25-10-2013', 'dd-mm-yyyy'), '5', '25', '298', '10', '2013', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5048, to_date('26-10-2013', 'dd-mm-yyyy'), '6', '26', '299', '10', '2013', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5049, to_date('27-10-2013', 'dd-mm-yyyy'), '7', '27', '300', '10', '2013', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5050, to_date('28-10-2013', 'dd-mm-yyyy'), '1', '28', '301', '10', '2013', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5051, to_date('29-10-2013', 'dd-mm-yyyy'), '2', '29', '302', '10', '2013', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5052, to_date('30-10-2013', 'dd-mm-yyyy'), '3', '30', '303', '10', '2013', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5053, to_date('31-10-2013', 'dd-mm-yyyy'), '4', '31', '304', '10', '2013', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5054, to_date('01-11-2013', 'dd-mm-yyyy'), '5', '01', '305', '11', '2013', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5055, to_date('02-11-2013', 'dd-mm-yyyy'), '6', '02', '306', '11', '2013', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5056, to_date('03-11-2013', 'dd-mm-yyyy'), '7', '03', '307', '11', '2013', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5057, to_date('04-11-2013', 'dd-mm-yyyy'), '1', '04', '308', '11', '2013', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5058, to_date('05-11-2013', 'dd-mm-yyyy'), '2', '05', '309', '11', '2013', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5059, to_date('06-11-2013', 'dd-mm-yyyy'), '3', '06', '310', '11', '2013', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5060, to_date('07-11-2013', 'dd-mm-yyyy'), '4', '07', '311', '11', '2013', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5061, to_date('08-11-2013', 'dd-mm-yyyy'), '5', '08', '312', '11', '2013', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5062, to_date('09-11-2013', 'dd-mm-yyyy'), '6', '09', '313', '11', '2013', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5063, to_date('10-11-2013', 'dd-mm-yyyy'), '7', '10', '314', '11', '2013', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5064, to_date('11-11-2013', 'dd-mm-yyyy'), '1', '11', '315', '11', '2013', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5065, to_date('12-11-2013', 'dd-mm-yyyy'), '2', '12', '316', '11', '2013', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5066, to_date('13-11-2013', 'dd-mm-yyyy'), '3', '13', '317', '11', '2013', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5067, to_date('14-11-2013', 'dd-mm-yyyy'), '4', '14', '318', '11', '2013', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5068, to_date('15-11-2013', 'dd-mm-yyyy'), '5', '15', '319', '11', '2013', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5069, to_date('16-11-2013', 'dd-mm-yyyy'), '6', '16', '320', '11', '2013', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5070, to_date('17-11-2013', 'dd-mm-yyyy'), '7', '17', '321', '11', '2013', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5071, to_date('18-11-2013', 'dd-mm-yyyy'), '1', '18', '322', '11', '2013', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5072, to_date('19-11-2013', 'dd-mm-yyyy'), '2', '19', '323', '11', '2013', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5073, to_date('20-11-2013', 'dd-mm-yyyy'), '3', '20', '324', '11', '2013', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5074, to_date('21-11-2013', 'dd-mm-yyyy'), '4', '21', '325', '11', '2013', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5075, to_date('22-11-2013', 'dd-mm-yyyy'), '5', '22', '326', '11', '2013', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5076, to_date('23-11-2013', 'dd-mm-yyyy'), '6', '23', '327', '11', '2013', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5077, to_date('24-11-2013', 'dd-mm-yyyy'), '7', '24', '328', '11', '2013', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5078, to_date('25-11-2013', 'dd-mm-yyyy'), '1', '25', '329', '11', '2013', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5079, to_date('26-11-2013', 'dd-mm-yyyy'), '2', '26', '330', '11', '2013', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5080, to_date('27-11-2013', 'dd-mm-yyyy'), '3', '27', '331', '11', '2013', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5081, to_date('28-11-2013', 'dd-mm-yyyy'), '4', '28', '332', '11', '2013', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5082, to_date('29-11-2013', 'dd-mm-yyyy'), '5', '29', '333', '11', '2013', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5083, to_date('30-11-2013', 'dd-mm-yyyy'), '6', '30', '334', '11', '2013', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5084, to_date('01-12-2013', 'dd-mm-yyyy'), '7', '01', '335', '12', '2013', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5085, to_date('02-12-2013', 'dd-mm-yyyy'), '1', '02', '336', '12', '2013', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5086, to_date('03-12-2013', 'dd-mm-yyyy'), '2', '03', '337', '12', '2013', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5087, to_date('04-12-2013', 'dd-mm-yyyy'), '3', '04', '338', '12', '2013', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5088, to_date('05-12-2013', 'dd-mm-yyyy'), '4', '05', '339', '12', '2013', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5089, to_date('06-12-2013', 'dd-mm-yyyy'), '5', '06', '340', '12', '2013', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5090, to_date('07-12-2013', 'dd-mm-yyyy'), '6', '07', '341', '12', '2013', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5091, to_date('08-12-2013', 'dd-mm-yyyy'), '7', '08', '342', '12', '2013', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5092, to_date('09-12-2013', 'dd-mm-yyyy'), '1', '09', '343', '12', '2013', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5093, to_date('10-12-2013', 'dd-mm-yyyy'), '2', '10', '344', '12', '2013', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5094, to_date('11-12-2013', 'dd-mm-yyyy'), '3', '11', '345', '12', '2013', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5095, to_date('12-12-2013', 'dd-mm-yyyy'), '4', '12', '346', '12', '2013', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5096, to_date('13-12-2013', 'dd-mm-yyyy'), '5', '13', '347', '12', '2013', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5097, to_date('14-12-2013', 'dd-mm-yyyy'), '6', '14', '348', '12', '2013', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5098, to_date('15-12-2013', 'dd-mm-yyyy'), '7', '15', '349', '12', '2013', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5099, to_date('16-12-2013', 'dd-mm-yyyy'), '1', '16', '350', '12', '2013', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5100, to_date('17-12-2013', 'dd-mm-yyyy'), '2', '17', '351', '12', '2013', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5101, to_date('18-12-2013', 'dd-mm-yyyy'), '3', '18', '352', '12', '2013', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5102, to_date('19-12-2013', 'dd-mm-yyyy'), '4', '19', '353', '12', '2013', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5103, to_date('20-12-2013', 'dd-mm-yyyy'), '5', '20', '354', '12', '2013', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5104, to_date('21-12-2013', 'dd-mm-yyyy'), '6', '21', '355', '12', '2013', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5105, to_date('22-12-2013', 'dd-mm-yyyy'), '7', '22', '356', '12', '2013', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5106, to_date('23-12-2013', 'dd-mm-yyyy'), '1', '23', '357', '12', '2013', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5107, to_date('24-12-2013', 'dd-mm-yyyy'), '2', '24', '358', '12', '2013', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5108, to_date('25-12-2013', 'dd-mm-yyyy'), '3', '25', '359', '12', '2013', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5109, to_date('26-12-2013', 'dd-mm-yyyy'), '4', '26', '360', '12', '2013', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5110, to_date('27-12-2013', 'dd-mm-yyyy'), '5', '27', '361', '12', '2013', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5111, to_date('28-12-2013', 'dd-mm-yyyy'), '6', '28', '362', '12', '2013', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5112, to_date('29-12-2013', 'dd-mm-yyyy'), '7', '29', '363', '12', '2013', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5113, to_date('30-12-2013', 'dd-mm-yyyy'), '1', '30', '364', '12', '2013', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5114, to_date('31-12-2013', 'dd-mm-yyyy'), '2', '31', '365', '12', '2013', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5115, to_date('01-01-2014', 'dd-mm-yyyy'), '3', '01', '001', '01', '2014', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5116, to_date('02-01-2014', 'dd-mm-yyyy'), '4', '02', '002', '01', '2014', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5117, to_date('03-01-2014', 'dd-mm-yyyy'), '5', '03', '003', '01', '2014', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5118, to_date('04-01-2014', 'dd-mm-yyyy'), '6', '04', '004', '01', '2014', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5119, to_date('05-01-2014', 'dd-mm-yyyy'), '7', '05', '005', '01', '2014', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5120, to_date('06-01-2014', 'dd-mm-yyyy'), '1', '06', '006', '01', '2014', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5121, to_date('07-01-2014', 'dd-mm-yyyy'), '2', '07', '007', '01', '2014', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5122, to_date('08-01-2014', 'dd-mm-yyyy'), '3', '08', '008', '01', '2014', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5123, to_date('09-01-2014', 'dd-mm-yyyy'), '4', '09', '009', '01', '2014', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5124, to_date('10-01-2014', 'dd-mm-yyyy'), '5', '10', '010', '01', '2014', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5125, to_date('11-01-2014', 'dd-mm-yyyy'), '6', '11', '011', '01', '2014', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5126, to_date('12-01-2014', 'dd-mm-yyyy'), '7', '12', '012', '01', '2014', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5127, to_date('13-01-2014', 'dd-mm-yyyy'), '1', '13', '013', '01', '2014', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5128, to_date('14-01-2014', 'dd-mm-yyyy'), '2', '14', '014', '01', '2014', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5129, to_date('15-01-2014', 'dd-mm-yyyy'), '3', '15', '015', '01', '2014', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5130, to_date('16-01-2014', 'dd-mm-yyyy'), '4', '16', '016', '01', '2014', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5131, to_date('17-01-2014', 'dd-mm-yyyy'), '5', '17', '017', '01', '2014', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5132, to_date('18-01-2014', 'dd-mm-yyyy'), '6', '18', '018', '01', '2014', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5133, to_date('19-01-2014', 'dd-mm-yyyy'), '7', '19', '019', '01', '2014', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5134, to_date('20-01-2014', 'dd-mm-yyyy'), '1', '20', '020', '01', '2014', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5135, to_date('21-01-2014', 'dd-mm-yyyy'), '2', '21', '021', '01', '2014', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5136, to_date('22-01-2014', 'dd-mm-yyyy'), '3', '22', '022', '01', '2014', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5137, to_date('23-01-2014', 'dd-mm-yyyy'), '4', '23', '023', '01', '2014', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5138, to_date('24-01-2014', 'dd-mm-yyyy'), '5', '24', '024', '01', '2014', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5139, to_date('25-01-2014', 'dd-mm-yyyy'), '6', '25', '025', '01', '2014', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5140, to_date('26-01-2014', 'dd-mm-yyyy'), '7', '26', '026', '01', '2014', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5141, to_date('27-01-2014', 'dd-mm-yyyy'), '1', '27', '027', '01', '2014', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5142, to_date('28-01-2014', 'dd-mm-yyyy'), '2', '28', '028', '01', '2014', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5143, to_date('29-01-2014', 'dd-mm-yyyy'), '3', '29', '029', '01', '2014', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5144, to_date('30-01-2014', 'dd-mm-yyyy'), '4', '30', '030', '01', '2014', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5145, to_date('31-01-2014', 'dd-mm-yyyy'), '5', '31', '031', '01', '2014', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5146, to_date('01-02-2014', 'dd-mm-yyyy'), '6', '01', '032', '02', '2014', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5147, to_date('02-02-2014', 'dd-mm-yyyy'), '7', '02', '033', '02', '2014', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5148, to_date('03-02-2014', 'dd-mm-yyyy'), '1', '03', '034', '02', '2014', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5149, to_date('04-02-2014', 'dd-mm-yyyy'), '2', '04', '035', '02', '2014', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5150, to_date('05-02-2014', 'dd-mm-yyyy'), '3', '05', '036', '02', '2014', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5151, to_date('06-02-2014', 'dd-mm-yyyy'), '4', '06', '037', '02', '2014', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5152, to_date('07-02-2014', 'dd-mm-yyyy'), '5', '07', '038', '02', '2014', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5153, to_date('08-02-2014', 'dd-mm-yyyy'), '6', '08', '039', '02', '2014', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5154, to_date('09-02-2014', 'dd-mm-yyyy'), '7', '09', '040', '02', '2014', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5155, to_date('10-02-2014', 'dd-mm-yyyy'), '1', '10', '041', '02', '2014', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5156, to_date('11-02-2014', 'dd-mm-yyyy'), '2', '11', '042', '02', '2014', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5157, to_date('12-02-2014', 'dd-mm-yyyy'), '3', '12', '043', '02', '2014', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5158, to_date('13-02-2014', 'dd-mm-yyyy'), '4', '13', '044', '02', '2014', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5159, to_date('14-02-2014', 'dd-mm-yyyy'), '5', '14', '045', '02', '2014', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5160, to_date('15-02-2014', 'dd-mm-yyyy'), '6', '15', '046', '02', '2014', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5161, to_date('16-02-2014', 'dd-mm-yyyy'), '7', '16', '047', '02', '2014', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5162, to_date('17-02-2014', 'dd-mm-yyyy'), '1', '17', '048', '02', '2014', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5163, to_date('18-02-2014', 'dd-mm-yyyy'), '2', '18', '049', '02', '2014', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5164, to_date('19-02-2014', 'dd-mm-yyyy'), '3', '19', '050', '02', '2014', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5165, to_date('20-02-2014', 'dd-mm-yyyy'), '4', '20', '051', '02', '2014', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5166, to_date('21-02-2014', 'dd-mm-yyyy'), '5', '21', '052', '02', '2014', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5167, to_date('22-02-2014', 'dd-mm-yyyy'), '6', '22', '053', '02', '2014', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5168, to_date('23-02-2014', 'dd-mm-yyyy'), '7', '23', '054', '02', '2014', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5169, to_date('24-02-2014', 'dd-mm-yyyy'), '1', '24', '055', '02', '2014', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5170, to_date('25-02-2014', 'dd-mm-yyyy'), '2', '25', '056', '02', '2014', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5171, to_date('26-02-2014', 'dd-mm-yyyy'), '3', '26', '057', '02', '2014', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5172, to_date('27-02-2014', 'dd-mm-yyyy'), '4', '27', '058', '02', '2014', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5173, to_date('28-02-2014', 'dd-mm-yyyy'), '5', '28', '059', '02', '2014', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5174, to_date('01-03-2014', 'dd-mm-yyyy'), '6', '01', '060', '03', '2014', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5175, to_date('02-03-2014', 'dd-mm-yyyy'), '7', '02', '061', '03', '2014', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5176, to_date('03-03-2014', 'dd-mm-yyyy'), '1', '03', '062', '03', '2014', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5177, to_date('04-03-2014', 'dd-mm-yyyy'), '2', '04', '063', '03', '2014', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5178, to_date('05-03-2014', 'dd-mm-yyyy'), '3', '05', '064', '03', '2014', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5179, to_date('06-03-2014', 'dd-mm-yyyy'), '4', '06', '065', '03', '2014', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5180, to_date('07-03-2014', 'dd-mm-yyyy'), '5', '07', '066', '03', '2014', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5181, to_date('08-03-2014', 'dd-mm-yyyy'), '6', '08', '067', '03', '2014', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5182, to_date('09-03-2014', 'dd-mm-yyyy'), '7', '09', '068', '03', '2014', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5183, to_date('10-03-2014', 'dd-mm-yyyy'), '1', '10', '069', '03', '2014', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5184, to_date('11-03-2014', 'dd-mm-yyyy'), '2', '11', '070', '03', '2014', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5185, to_date('12-03-2014', 'dd-mm-yyyy'), '3', '12', '071', '03', '2014', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5186, to_date('13-03-2014', 'dd-mm-yyyy'), '4', '13', '072', '03', '2014', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5187, to_date('14-03-2014', 'dd-mm-yyyy'), '5', '14', '073', '03', '2014', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5188, to_date('15-03-2014', 'dd-mm-yyyy'), '6', '15', '074', '03', '2014', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5189, to_date('16-03-2014', 'dd-mm-yyyy'), '7', '16', '075', '03', '2014', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5190, to_date('17-03-2014', 'dd-mm-yyyy'), '1', '17', '076', '03', '2014', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5191, to_date('18-03-2014', 'dd-mm-yyyy'), '2', '18', '077', '03', '2014', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5192, to_date('19-03-2014', 'dd-mm-yyyy'), '3', '19', '078', '03', '2014', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5193, to_date('20-03-2014', 'dd-mm-yyyy'), '4', '20', '079', '03', '2014', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5194, to_date('21-03-2014', 'dd-mm-yyyy'), '5', '21', '080', '03', '2014', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5195, to_date('22-03-2014', 'dd-mm-yyyy'), '6', '22', '081', '03', '2014', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5196, to_date('23-03-2014', 'dd-mm-yyyy'), '7', '23', '082', '03', '2014', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5197, to_date('24-03-2014', 'dd-mm-yyyy'), '1', '24', '083', '03', '2014', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5198, to_date('25-03-2014', 'dd-mm-yyyy'), '2', '25', '084', '03', '2014', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5199, to_date('26-03-2014', 'dd-mm-yyyy'), '3', '26', '085', '03', '2014', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5200, to_date('27-03-2014', 'dd-mm-yyyy'), '4', '27', '086', '03', '2014', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5201, to_date('28-03-2014', 'dd-mm-yyyy'), '5', '28', '087', '03', '2014', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5202, to_date('29-03-2014', 'dd-mm-yyyy'), '6', '29', '088', '03', '2014', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5203, to_date('30-03-2014', 'dd-mm-yyyy'), '7', '30', '089', '03', '2014', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5204, to_date('31-03-2014', 'dd-mm-yyyy'), '1', '31', '090', '03', '2014', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5205, to_date('01-04-2014', 'dd-mm-yyyy'), '2', '01', '091', '04', '2014', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5206, to_date('02-04-2014', 'dd-mm-yyyy'), '3', '02', '092', '04', '2014', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5207, to_date('03-04-2014', 'dd-mm-yyyy'), '4', '03', '093', '04', '2014', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5208, to_date('04-04-2014', 'dd-mm-yyyy'), '5', '04', '094', '04', '2014', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5209, to_date('05-04-2014', 'dd-mm-yyyy'), '6', '05', '095', '04', '2014', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5210, to_date('06-04-2014', 'dd-mm-yyyy'), '7', '06', '096', '04', '2014', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5211, to_date('07-04-2014', 'dd-mm-yyyy'), '1', '07', '097', '04', '2014', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5212, to_date('08-04-2014', 'dd-mm-yyyy'), '2', '08', '098', '04', '2014', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5213, to_date('09-04-2014', 'dd-mm-yyyy'), '3', '09', '099', '04', '2014', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5214, to_date('10-04-2014', 'dd-mm-yyyy'), '4', '10', '100', '04', '2014', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5215, to_date('11-04-2014', 'dd-mm-yyyy'), '5', '11', '101', '04', '2014', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5216, to_date('12-04-2014', 'dd-mm-yyyy'), '6', '12', '102', '04', '2014', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5217, to_date('13-04-2014', 'dd-mm-yyyy'), '7', '13', '103', '04', '2014', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5218, to_date('14-04-2014', 'dd-mm-yyyy'), '1', '14', '104', '04', '2014', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5219, to_date('15-04-2014', 'dd-mm-yyyy'), '2', '15', '105', '04', '2014', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5220, to_date('16-04-2014', 'dd-mm-yyyy'), '3', '16', '106', '04', '2014', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5221, to_date('17-04-2014', 'dd-mm-yyyy'), '4', '17', '107', '04', '2014', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5222, to_date('18-04-2014', 'dd-mm-yyyy'), '5', '18', '108', '04', '2014', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5223, to_date('19-04-2014', 'dd-mm-yyyy'), '6', '19', '109', '04', '2014', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5224, to_date('20-04-2014', 'dd-mm-yyyy'), '7', '20', '110', '04', '2014', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5225, to_date('21-04-2014', 'dd-mm-yyyy'), '1', '21', '111', '04', '2014', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5226, to_date('22-04-2014', 'dd-mm-yyyy'), '2', '22', '112', '04', '2014', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5227, to_date('23-04-2014', 'dd-mm-yyyy'), '3', '23', '113', '04', '2014', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5228, to_date('24-04-2014', 'dd-mm-yyyy'), '4', '24', '114', '04', '2014', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5229, to_date('25-04-2014', 'dd-mm-yyyy'), '5', '25', '115', '04', '2014', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5230, to_date('26-04-2014', 'dd-mm-yyyy'), '6', '26', '116', '04', '2014', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5231, to_date('27-04-2014', 'dd-mm-yyyy'), '7', '27', '117', '04', '2014', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5232, to_date('28-04-2014', 'dd-mm-yyyy'), '1', '28', '118', '04', '2014', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5233, to_date('29-04-2014', 'dd-mm-yyyy'), '2', '29', '119', '04', '2014', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5234, to_date('30-04-2014', 'dd-mm-yyyy'), '3', '30', '120', '04', '2014', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5235, to_date('01-05-2014', 'dd-mm-yyyy'), '4', '01', '121', '05', '2014', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5236, to_date('02-05-2014', 'dd-mm-yyyy'), '5', '02', '122', '05', '2014', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5237, to_date('03-05-2014', 'dd-mm-yyyy'), '6', '03', '123', '05', '2014', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5238, to_date('04-05-2014', 'dd-mm-yyyy'), '7', '04', '124', '05', '2014', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5239, to_date('05-05-2014', 'dd-mm-yyyy'), '1', '05', '125', '05', '2014', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5240, to_date('06-05-2014', 'dd-mm-yyyy'), '2', '06', '126', '05', '2014', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5241, to_date('07-05-2014', 'dd-mm-yyyy'), '3', '07', '127', '05', '2014', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5242, to_date('08-05-2014', 'dd-mm-yyyy'), '4', '08', '128', '05', '2014', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5243, to_date('09-05-2014', 'dd-mm-yyyy'), '5', '09', '129', '05', '2014', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5244, to_date('10-05-2014', 'dd-mm-yyyy'), '6', '10', '130', '05', '2014', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5245, to_date('11-05-2014', 'dd-mm-yyyy'), '7', '11', '131', '05', '2014', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5246, to_date('12-05-2014', 'dd-mm-yyyy'), '1', '12', '132', '05', '2014', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5247, to_date('13-05-2014', 'dd-mm-yyyy'), '2', '13', '133', '05', '2014', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5248, to_date('14-05-2014', 'dd-mm-yyyy'), '3', '14', '134', '05', '2014', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5249, to_date('15-05-2014', 'dd-mm-yyyy'), '4', '15', '135', '05', '2014', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5250, to_date('16-05-2014', 'dd-mm-yyyy'), '5', '16', '136', '05', '2014', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5251, to_date('17-05-2014', 'dd-mm-yyyy'), '6', '17', '137', '05', '2014', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5252, to_date('18-05-2014', 'dd-mm-yyyy'), '7', '18', '138', '05', '2014', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5253, to_date('19-05-2014', 'dd-mm-yyyy'), '1', '19', '139', '05', '2014', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5254, to_date('20-05-2014', 'dd-mm-yyyy'), '2', '20', '140', '05', '2014', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5255, to_date('21-05-2014', 'dd-mm-yyyy'), '3', '21', '141', '05', '2014', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5256, to_date('22-05-2014', 'dd-mm-yyyy'), '4', '22', '142', '05', '2014', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5257, to_date('23-05-2014', 'dd-mm-yyyy'), '5', '23', '143', '05', '2014', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5258, to_date('24-05-2014', 'dd-mm-yyyy'), '6', '24', '144', '05', '2014', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5259, to_date('25-05-2014', 'dd-mm-yyyy'), '7', '25', '145', '05', '2014', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5260, to_date('26-05-2014', 'dd-mm-yyyy'), '1', '26', '146', '05', '2014', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5261, to_date('27-05-2014', 'dd-mm-yyyy'), '2', '27', '147', '05', '2014', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5262, to_date('28-05-2014', 'dd-mm-yyyy'), '3', '28', '148', '05', '2014', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5263, to_date('29-05-2014', 'dd-mm-yyyy'), '4', '29', '149', '05', '2014', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5264, to_date('30-05-2014', 'dd-mm-yyyy'), '5', '30', '150', '05', '2014', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5265, to_date('31-05-2014', 'dd-mm-yyyy'), '6', '31', '151', '05', '2014', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5266, to_date('01-06-2014', 'dd-mm-yyyy'), '7', '01', '152', '06', '2014', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5267, to_date('02-06-2014', 'dd-mm-yyyy'), '1', '02', '153', '06', '2014', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5268, to_date('03-06-2014', 'dd-mm-yyyy'), '2', '03', '154', '06', '2014', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5269, to_date('04-06-2014', 'dd-mm-yyyy'), '3', '04', '155', '06', '2014', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5270, to_date('05-06-2014', 'dd-mm-yyyy'), '4', '05', '156', '06', '2014', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5271, to_date('06-06-2014', 'dd-mm-yyyy'), '5', '06', '157', '06', '2014', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5272, to_date('07-06-2014', 'dd-mm-yyyy'), '6', '07', '158', '06', '2014', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5273, to_date('08-06-2014', 'dd-mm-yyyy'), '7', '08', '159', '06', '2014', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5274, to_date('09-06-2014', 'dd-mm-yyyy'), '1', '09', '160', '06', '2014', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5275, to_date('10-06-2014', 'dd-mm-yyyy'), '2', '10', '161', '06', '2014', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5276, to_date('11-06-2014', 'dd-mm-yyyy'), '3', '11', '162', '06', '2014', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5277, to_date('12-06-2014', 'dd-mm-yyyy'), '4', '12', '163', '06', '2014', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5278, to_date('13-06-2014', 'dd-mm-yyyy'), '5', '13', '164', '06', '2014', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5279, to_date('14-06-2014', 'dd-mm-yyyy'), '6', '14', '165', '06', '2014', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5280, to_date('15-06-2014', 'dd-mm-yyyy'), '7', '15', '166', '06', '2014', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5281, to_date('16-06-2014', 'dd-mm-yyyy'), '1', '16', '167', '06', '2014', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5282, to_date('17-06-2014', 'dd-mm-yyyy'), '2', '17', '168', '06', '2014', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5283, to_date('18-06-2014', 'dd-mm-yyyy'), '3', '18', '169', '06', '2014', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5284, to_date('19-06-2014', 'dd-mm-yyyy'), '4', '19', '170', '06', '2014', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5285, to_date('20-06-2014', 'dd-mm-yyyy'), '5', '20', '171', '06', '2014', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5286, to_date('21-06-2014', 'dd-mm-yyyy'), '6', '21', '172', '06', '2014', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5287, to_date('22-06-2014', 'dd-mm-yyyy'), '7', '22', '173', '06', '2014', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5288, to_date('23-06-2014', 'dd-mm-yyyy'), '1', '23', '174', '06', '2014', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5289, to_date('24-06-2014', 'dd-mm-yyyy'), '2', '24', '175', '06', '2014', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5290, to_date('25-06-2014', 'dd-mm-yyyy'), '3', '25', '176', '06', '2014', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5291, to_date('26-06-2014', 'dd-mm-yyyy'), '4', '26', '177', '06', '2014', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5292, to_date('27-06-2014', 'dd-mm-yyyy'), '5', '27', '178', '06', '2014', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5293, to_date('28-06-2014', 'dd-mm-yyyy'), '6', '28', '179', '06', '2014', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5510, to_date('31-01-2015', 'dd-mm-yyyy'), '6', '31', '031', '01', '2015', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5511, to_date('01-02-2015', 'dd-mm-yyyy'), '7', '01', '032', '02', '2015', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5512, to_date('02-02-2015', 'dd-mm-yyyy'), '1', '02', '033', '02', '2015', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5513, to_date('03-02-2015', 'dd-mm-yyyy'), '2', '03', '034', '02', '2015', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5514, to_date('04-02-2015', 'dd-mm-yyyy'), '3', '04', '035', '02', '2015', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5515, to_date('05-02-2015', 'dd-mm-yyyy'), '4', '05', '036', '02', '2015', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5516, to_date('06-02-2015', 'dd-mm-yyyy'), '5', '06', '037', '02', '2015', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5517, to_date('07-02-2015', 'dd-mm-yyyy'), '6', '07', '038', '02', '2015', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5518, to_date('08-02-2015', 'dd-mm-yyyy'), '7', '08', '039', '02', '2015', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5519, to_date('09-02-2015', 'dd-mm-yyyy'), '1', '09', '040', '02', '2015', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5520, to_date('10-02-2015', 'dd-mm-yyyy'), '2', '10', '041', '02', '2015', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5521, to_date('11-02-2015', 'dd-mm-yyyy'), '3', '11', '042', '02', '2015', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5522, to_date('12-02-2015', 'dd-mm-yyyy'), '4', '12', '043', '02', '2015', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5523, to_date('13-02-2015', 'dd-mm-yyyy'), '5', '13', '044', '02', '2015', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5524, to_date('14-02-2015', 'dd-mm-yyyy'), '6', '14', '045', '02', '2015', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5525, to_date('15-02-2015', 'dd-mm-yyyy'), '7', '15', '046', '02', '2015', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5526, to_date('16-02-2015', 'dd-mm-yyyy'), '1', '16', '047', '02', '2015', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5527, to_date('17-02-2015', 'dd-mm-yyyy'), '2', '17', '048', '02', '2015', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5528, to_date('18-02-2015', 'dd-mm-yyyy'), '3', '18', '049', '02', '2015', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5529, to_date('19-02-2015', 'dd-mm-yyyy'), '4', '19', '050', '02', '2015', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5530, to_date('20-02-2015', 'dd-mm-yyyy'), '5', '20', '051', '02', '2015', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5531, to_date('21-02-2015', 'dd-mm-yyyy'), '6', '21', '052', '02', '2015', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5532, to_date('22-02-2015', 'dd-mm-yyyy'), '7', '22', '053', '02', '2015', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5533, to_date('23-02-2015', 'dd-mm-yyyy'), '1', '23', '054', '02', '2015', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5534, to_date('24-02-2015', 'dd-mm-yyyy'), '2', '24', '055', '02', '2015', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5535, to_date('25-02-2015', 'dd-mm-yyyy'), '3', '25', '056', '02', '2015', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5536, to_date('26-02-2015', 'dd-mm-yyyy'), '4', '26', '057', '02', '2015', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5537, to_date('27-02-2015', 'dd-mm-yyyy'), '5', '27', '058', '02', '2015', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5538, to_date('28-02-2015', 'dd-mm-yyyy'), '6', '28', '059', '02', '2015', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5539, to_date('01-03-2015', 'dd-mm-yyyy'), '7', '01', '060', '03', '2015', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5540, to_date('02-03-2015', 'dd-mm-yyyy'), '1', '02', '061', '03', '2015', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5541, to_date('03-03-2015', 'dd-mm-yyyy'), '2', '03', '062', '03', '2015', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5542, to_date('04-03-2015', 'dd-mm-yyyy'), '3', '04', '063', '03', '2015', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5543, to_date('05-03-2015', 'dd-mm-yyyy'), '4', '05', '064', '03', '2015', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5544, to_date('06-03-2015', 'dd-mm-yyyy'), '5', '06', '065', '03', '2015', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5545, to_date('07-03-2015', 'dd-mm-yyyy'), '6', '07', '066', '03', '2015', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5546, to_date('08-03-2015', 'dd-mm-yyyy'), '7', '08', '067', '03', '2015', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5547, to_date('09-03-2015', 'dd-mm-yyyy'), '1', '09', '068', '03', '2015', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5548, to_date('10-03-2015', 'dd-mm-yyyy'), '2', '10', '069', '03', '2015', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5549, to_date('11-03-2015', 'dd-mm-yyyy'), '3', '11', '070', '03', '2015', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5550, to_date('12-03-2015', 'dd-mm-yyyy'), '4', '12', '071', '03', '2015', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5551, to_date('13-03-2015', 'dd-mm-yyyy'), '5', '13', '072', '03', '2015', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5552, to_date('14-03-2015', 'dd-mm-yyyy'), '6', '14', '073', '03', '2015', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5553, to_date('15-03-2015', 'dd-mm-yyyy'), '7', '15', '074', '03', '2015', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5554, to_date('16-03-2015', 'dd-mm-yyyy'), '1', '16', '075', '03', '2015', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5555, to_date('17-03-2015', 'dd-mm-yyyy'), '2', '17', '076', '03', '2015', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5556, to_date('18-03-2015', 'dd-mm-yyyy'), '3', '18', '077', '03', '2015', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5557, to_date('19-03-2015', 'dd-mm-yyyy'), '4', '19', '078', '03', '2015', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5558, to_date('20-03-2015', 'dd-mm-yyyy'), '5', '20', '079', '03', '2015', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5559, to_date('21-03-2015', 'dd-mm-yyyy'), '6', '21', '080', '03', '2015', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5560, to_date('22-03-2015', 'dd-mm-yyyy'), '7', '22', '081', '03', '2015', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5561, to_date('23-03-2015', 'dd-mm-yyyy'), '1', '23', '082', '03', '2015', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5562, to_date('24-03-2015', 'dd-mm-yyyy'), '2', '24', '083', '03', '2015', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5563, to_date('25-03-2015', 'dd-mm-yyyy'), '3', '25', '084', '03', '2015', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5564, to_date('26-03-2015', 'dd-mm-yyyy'), '4', '26', '085', '03', '2015', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5565, to_date('27-03-2015', 'dd-mm-yyyy'), '5', '27', '086', '03', '2015', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5566, to_date('28-03-2015', 'dd-mm-yyyy'), '6', '28', '087', '03', '2015', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5567, to_date('29-03-2015', 'dd-mm-yyyy'), '7', '29', '088', '03', '2015', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5568, to_date('30-03-2015', 'dd-mm-yyyy'), '1', '30', '089', '03', '2015', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5569, to_date('31-03-2015', 'dd-mm-yyyy'), '2', '31', '090', '03', '2015', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5570, to_date('01-04-2015', 'dd-mm-yyyy'), '3', '01', '091', '04', '2015', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5571, to_date('02-04-2015', 'dd-mm-yyyy'), '4', '02', '092', '04', '2015', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5572, to_date('03-04-2015', 'dd-mm-yyyy'), '5', '03', '093', '04', '2015', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5573, to_date('04-04-2015', 'dd-mm-yyyy'), '6', '04', '094', '04', '2015', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5574, to_date('05-04-2015', 'dd-mm-yyyy'), '7', '05', '095', '04', '2015', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5575, to_date('06-04-2015', 'dd-mm-yyyy'), '1', '06', '096', '04', '2015', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5576, to_date('07-04-2015', 'dd-mm-yyyy'), '2', '07', '097', '04', '2015', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5577, to_date('08-04-2015', 'dd-mm-yyyy'), '3', '08', '098', '04', '2015', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5578, to_date('09-04-2015', 'dd-mm-yyyy'), '4', '09', '099', '04', '2015', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5579, to_date('10-04-2015', 'dd-mm-yyyy'), '5', '10', '100', '04', '2015', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5580, to_date('11-04-2015', 'dd-mm-yyyy'), '6', '11', '101', '04', '2015', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5581, to_date('12-04-2015', 'dd-mm-yyyy'), '7', '12', '102', '04', '2015', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5582, to_date('13-04-2015', 'dd-mm-yyyy'), '1', '13', '103', '04', '2015', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5583, to_date('14-04-2015', 'dd-mm-yyyy'), '2', '14', '104', '04', '2015', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5584, to_date('15-04-2015', 'dd-mm-yyyy'), '3', '15', '105', '04', '2015', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5585, to_date('16-04-2015', 'dd-mm-yyyy'), '4', '16', '106', '04', '2015', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5586, to_date('17-04-2015', 'dd-mm-yyyy'), '5', '17', '107', '04', '2015', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5587, to_date('18-04-2015', 'dd-mm-yyyy'), '6', '18', '108', '04', '2015', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5588, to_date('19-04-2015', 'dd-mm-yyyy'), '7', '19', '109', '04', '2015', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5589, to_date('20-04-2015', 'dd-mm-yyyy'), '1', '20', '110', '04', '2015', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5590, to_date('21-04-2015', 'dd-mm-yyyy'), '2', '21', '111', '04', '2015', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5591, to_date('22-04-2015', 'dd-mm-yyyy'), '3', '22', '112', '04', '2015', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5592, to_date('23-04-2015', 'dd-mm-yyyy'), '4', '23', '113', '04', '2015', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5593, to_date('24-04-2015', 'dd-mm-yyyy'), '5', '24', '114', '04', '2015', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5594, to_date('25-04-2015', 'dd-mm-yyyy'), '6', '25', '115', '04', '2015', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5595, to_date('26-04-2015', 'dd-mm-yyyy'), '7', '26', '116', '04', '2015', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5596, to_date('27-04-2015', 'dd-mm-yyyy'), '1', '27', '117', '04', '2015', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5597, to_date('28-04-2015', 'dd-mm-yyyy'), '2', '28', '118', '04', '2015', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5598, to_date('29-04-2015', 'dd-mm-yyyy'), '3', '29', '119', '04', '2015', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5599, to_date('30-04-2015', 'dd-mm-yyyy'), '4', '30', '120', '04', '2015', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5600, to_date('01-05-2015', 'dd-mm-yyyy'), '5', '01', '121', '05', '2015', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5601, to_date('02-05-2015', 'dd-mm-yyyy'), '6', '02', '122', '05', '2015', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5602, to_date('03-05-2015', 'dd-mm-yyyy'), '7', '03', '123', '05', '2015', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5603, to_date('04-05-2015', 'dd-mm-yyyy'), '1', '04', '124', '05', '2015', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5604, to_date('05-05-2015', 'dd-mm-yyyy'), '2', '05', '125', '05', '2015', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5605, to_date('06-05-2015', 'dd-mm-yyyy'), '3', '06', '126', '05', '2015', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5606, to_date('07-05-2015', 'dd-mm-yyyy'), '4', '07', '127', '05', '2015', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5607, to_date('08-05-2015', 'dd-mm-yyyy'), '5', '08', '128', '05', '2015', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5608, to_date('09-05-2015', 'dd-mm-yyyy'), '6', '09', '129', '05', '2015', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5609, to_date('10-05-2015', 'dd-mm-yyyy'), '7', '10', '130', '05', '2015', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5610, to_date('11-05-2015', 'dd-mm-yyyy'), '1', '11', '131', '05', '2015', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5611, to_date('12-05-2015', 'dd-mm-yyyy'), '2', '12', '132', '05', '2015', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5612, to_date('13-05-2015', 'dd-mm-yyyy'), '3', '13', '133', '05', '2015', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5613, to_date('14-05-2015', 'dd-mm-yyyy'), '4', '14', '134', '05', '2015', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5614, to_date('15-05-2015', 'dd-mm-yyyy'), '5', '15', '135', '05', '2015', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5615, to_date('16-05-2015', 'dd-mm-yyyy'), '6', '16', '136', '05', '2015', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5616, to_date('17-05-2015', 'dd-mm-yyyy'), '7', '17', '137', '05', '2015', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5617, to_date('18-05-2015', 'dd-mm-yyyy'), '1', '18', '138', '05', '2015', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5618, to_date('19-05-2015', 'dd-mm-yyyy'), '2', '19', '139', '05', '2015', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5619, to_date('20-05-2015', 'dd-mm-yyyy'), '3', '20', '140', '05', '2015', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5620, to_date('21-05-2015', 'dd-mm-yyyy'), '4', '21', '141', '05', '2015', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5621, to_date('22-05-2015', 'dd-mm-yyyy'), '5', '22', '142', '05', '2015', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5622, to_date('23-05-2015', 'dd-mm-yyyy'), '6', '23', '143', '05', '2015', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5623, to_date('24-05-2015', 'dd-mm-yyyy'), '7', '24', '144', '05', '2015', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5624, to_date('25-05-2015', 'dd-mm-yyyy'), '1', '25', '145', '05', '2015', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5625, to_date('26-05-2015', 'dd-mm-yyyy'), '2', '26', '146', '05', '2015', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5626, to_date('27-05-2015', 'dd-mm-yyyy'), '3', '27', '147', '05', '2015', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5627, to_date('28-05-2015', 'dd-mm-yyyy'), '4', '28', '148', '05', '2015', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5628, to_date('29-05-2015', 'dd-mm-yyyy'), '5', '29', '149', '05', '2015', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5629, to_date('30-05-2015', 'dd-mm-yyyy'), '6', '30', '150', '05', '2015', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5630, to_date('31-05-2015', 'dd-mm-yyyy'), '7', '31', '151', '05', '2015', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5631, to_date('01-06-2015', 'dd-mm-yyyy'), '1', '01', '152', '06', '2015', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5632, to_date('02-06-2015', 'dd-mm-yyyy'), '2', '02', '153', '06', '2015', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5633, to_date('03-06-2015', 'dd-mm-yyyy'), '3', '03', '154', '06', '2015', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5634, to_date('04-06-2015', 'dd-mm-yyyy'), '4', '04', '155', '06', '2015', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5635, to_date('05-06-2015', 'dd-mm-yyyy'), '5', '05', '156', '06', '2015', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5636, to_date('06-06-2015', 'dd-mm-yyyy'), '6', '06', '157', '06', '2015', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5637, to_date('07-06-2015', 'dd-mm-yyyy'), '7', '07', '158', '06', '2015', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5638, to_date('08-06-2015', 'dd-mm-yyyy'), '1', '08', '159', '06', '2015', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5639, to_date('09-06-2015', 'dd-mm-yyyy'), '2', '09', '160', '06', '2015', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5640, to_date('10-06-2015', 'dd-mm-yyyy'), '3', '10', '161', '06', '2015', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5641, to_date('11-06-2015', 'dd-mm-yyyy'), '4', '11', '162', '06', '2015', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5642, to_date('12-06-2015', 'dd-mm-yyyy'), '5', '12', '163', '06', '2015', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5643, to_date('13-06-2015', 'dd-mm-yyyy'), '6', '13', '164', '06', '2015', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5644, to_date('14-06-2015', 'dd-mm-yyyy'), '7', '14', '165', '06', '2015', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5645, to_date('15-06-2015', 'dd-mm-yyyy'), '1', '15', '166', '06', '2015', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5646, to_date('16-06-2015', 'dd-mm-yyyy'), '2', '16', '167', '06', '2015', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5647, to_date('17-06-2015', 'dd-mm-yyyy'), '3', '17', '168', '06', '2015', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5648, to_date('18-06-2015', 'dd-mm-yyyy'), '4', '18', '169', '06', '2015', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5649, to_date('19-06-2015', 'dd-mm-yyyy'), '5', '19', '170', '06', '2015', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5650, to_date('20-06-2015', 'dd-mm-yyyy'), '6', '20', '171', '06', '2015', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5651, to_date('21-06-2015', 'dd-mm-yyyy'), '7', '21', '172', '06', '2015', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5652, to_date('22-06-2015', 'dd-mm-yyyy'), '1', '22', '173', '06', '2015', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5653, to_date('23-06-2015', 'dd-mm-yyyy'), '2', '23', '174', '06', '2015', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5654, to_date('24-06-2015', 'dd-mm-yyyy'), '3', '24', '175', '06', '2015', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5655, to_date('25-06-2015', 'dd-mm-yyyy'), '4', '25', '176', '06', '2015', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5656, to_date('26-06-2015', 'dd-mm-yyyy'), '5', '26', '177', '06', '2015', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5657, to_date('27-06-2015', 'dd-mm-yyyy'), '6', '27', '178', '06', '2015', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5658, to_date('28-06-2015', 'dd-mm-yyyy'), '7', '28', '179', '06', '2015', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5659, to_date('29-06-2015', 'dd-mm-yyyy'), '1', '29', '180', '06', '2015', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5660, to_date('30-06-2015', 'dd-mm-yyyy'), '2', '30', '181', '06', '2015', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5661, to_date('01-07-2015', 'dd-mm-yyyy'), '3', '01', '182', '07', '2015', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5662, to_date('02-07-2015', 'dd-mm-yyyy'), '4', '02', '183', '07', '2015', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5663, to_date('03-07-2015', 'dd-mm-yyyy'), '5', '03', '184', '07', '2015', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5664, to_date('04-07-2015', 'dd-mm-yyyy'), '6', '04', '185', '07', '2015', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5665, to_date('05-07-2015', 'dd-mm-yyyy'), '7', '05', '186', '07', '2015', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5666, to_date('06-07-2015', 'dd-mm-yyyy'), '1', '06', '187', '07', '2015', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5667, to_date('07-07-2015', 'dd-mm-yyyy'), '2', '07', '188', '07', '2015', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5668, to_date('08-07-2015', 'dd-mm-yyyy'), '3', '08', '189', '07', '2015', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5669, to_date('09-07-2015', 'dd-mm-yyyy'), '4', '09', '190', '07', '2015', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5670, to_date('10-07-2015', 'dd-mm-yyyy'), '5', '10', '191', '07', '2015', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5671, to_date('11-07-2015', 'dd-mm-yyyy'), '6', '11', '192', '07', '2015', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5672, to_date('12-07-2015', 'dd-mm-yyyy'), '7', '12', '193', '07', '2015', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5673, to_date('13-07-2015', 'dd-mm-yyyy'), '1', '13', '194', '07', '2015', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5674, to_date('14-07-2015', 'dd-mm-yyyy'), '2', '14', '195', '07', '2015', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5675, to_date('15-07-2015', 'dd-mm-yyyy'), '3', '15', '196', '07', '2015', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5676, to_date('16-07-2015', 'dd-mm-yyyy'), '4', '16', '197', '07', '2015', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5677, to_date('17-07-2015', 'dd-mm-yyyy'), '5', '17', '198', '07', '2015', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5678, to_date('18-07-2015', 'dd-mm-yyyy'), '6', '18', '199', '07', '2015', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5679, to_date('19-07-2015', 'dd-mm-yyyy'), '7', '19', '200', '07', '2015', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5680, to_date('20-07-2015', 'dd-mm-yyyy'), '1', '20', '201', '07', '2015', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5681, to_date('21-07-2015', 'dd-mm-yyyy'), '2', '21', '202', '07', '2015', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5682, to_date('22-07-2015', 'dd-mm-yyyy'), '3', '22', '203', '07', '2015', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5683, to_date('23-07-2015', 'dd-mm-yyyy'), '4', '23', '204', '07', '2015', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5684, to_date('24-07-2015', 'dd-mm-yyyy'), '5', '24', '205', '07', '2015', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5685, to_date('25-07-2015', 'dd-mm-yyyy'), '6', '25', '206', '07', '2015', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5686, to_date('26-07-2015', 'dd-mm-yyyy'), '7', '26', '207', '07', '2015', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5687, to_date('27-07-2015', 'dd-mm-yyyy'), '1', '27', '208', '07', '2015', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5688, to_date('28-07-2015', 'dd-mm-yyyy'), '2', '28', '209', '07', '2015', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5689, to_date('29-07-2015', 'dd-mm-yyyy'), '3', '29', '210', '07', '2015', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5690, to_date('30-07-2015', 'dd-mm-yyyy'), '4', '30', '211', '07', '2015', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5691, to_date('31-07-2015', 'dd-mm-yyyy'), '5', '31', '212', '07', '2015', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5692, to_date('01-08-2015', 'dd-mm-yyyy'), '6', '01', '213', '08', '2015', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5693, to_date('02-08-2015', 'dd-mm-yyyy'), '7', '02', '214', '08', '2015', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5694, to_date('03-08-2015', 'dd-mm-yyyy'), '1', '03', '215', '08', '2015', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5695, to_date('04-08-2015', 'dd-mm-yyyy'), '2', '04', '216', '08', '2015', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5696, to_date('05-08-2015', 'dd-mm-yyyy'), '3', '05', '217', '08', '2015', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5697, to_date('06-08-2015', 'dd-mm-yyyy'), '4', '06', '218', '08', '2015', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5698, to_date('07-08-2015', 'dd-mm-yyyy'), '5', '07', '219', '08', '2015', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5699, to_date('08-08-2015', 'dd-mm-yyyy'), '6', '08', '220', '08', '2015', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5700, to_date('09-08-2015', 'dd-mm-yyyy'), '7', '09', '221', '08', '2015', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5701, to_date('10-08-2015', 'dd-mm-yyyy'), '1', '10', '222', '08', '2015', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5702, to_date('11-08-2015', 'dd-mm-yyyy'), '2', '11', '223', '08', '2015', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5703, to_date('12-08-2015', 'dd-mm-yyyy'), '3', '12', '224', '08', '2015', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5704, to_date('13-08-2015', 'dd-mm-yyyy'), '4', '13', '225', '08', '2015', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5705, to_date('14-08-2015', 'dd-mm-yyyy'), '5', '14', '226', '08', '2015', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5706, to_date('15-08-2015', 'dd-mm-yyyy'), '6', '15', '227', '08', '2015', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5707, to_date('16-08-2015', 'dd-mm-yyyy'), '7', '16', '228', '08', '2015', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5708, to_date('17-08-2015', 'dd-mm-yyyy'), '1', '17', '229', '08', '2015', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5709, to_date('18-08-2015', 'dd-mm-yyyy'), '2', '18', '230', '08', '2015', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5710, to_date('19-08-2015', 'dd-mm-yyyy'), '3', '19', '231', '08', '2015', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5711, to_date('20-08-2015', 'dd-mm-yyyy'), '4', '20', '232', '08', '2015', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5712, to_date('21-08-2015', 'dd-mm-yyyy'), '5', '21', '233', '08', '2015', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5713, to_date('22-08-2015', 'dd-mm-yyyy'), '6', '22', '234', '08', '2015', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5714, to_date('23-08-2015', 'dd-mm-yyyy'), '7', '23', '235', '08', '2015', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5715, to_date('24-08-2015', 'dd-mm-yyyy'), '1', '24', '236', '08', '2015', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5716, to_date('25-08-2015', 'dd-mm-yyyy'), '2', '25', '237', '08', '2015', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5717, to_date('26-08-2015', 'dd-mm-yyyy'), '3', '26', '238', '08', '2015', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5718, to_date('27-08-2015', 'dd-mm-yyyy'), '4', '27', '239', '08', '2015', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5719, to_date('28-08-2015', 'dd-mm-yyyy'), '5', '28', '240', '08', '2015', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5720, to_date('29-08-2015', 'dd-mm-yyyy'), '6', '29', '241', '08', '2015', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5721, to_date('30-08-2015', 'dd-mm-yyyy'), '7', '30', '242', '08', '2015', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5722, to_date('31-08-2015', 'dd-mm-yyyy'), '1', '31', '243', '08', '2015', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5723, to_date('01-09-2015', 'dd-mm-yyyy'), '2', '01', '244', '09', '2015', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5724, to_date('02-09-2015', 'dd-mm-yyyy'), '3', '02', '245', '09', '2015', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5725, to_date('03-09-2015', 'dd-mm-yyyy'), '4', '03', '246', '09', '2015', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6158, to_date('09-11-2016', 'dd-mm-yyyy'), '3', '09', '314', '11', '2016', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6159, to_date('10-11-2016', 'dd-mm-yyyy'), '4', '10', '315', '11', '2016', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6160, to_date('11-11-2016', 'dd-mm-yyyy'), '5', '11', '316', '11', '2016', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6161, to_date('12-11-2016', 'dd-mm-yyyy'), '6', '12', '317', '11', '2016', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6162, to_date('13-11-2016', 'dd-mm-yyyy'), '7', '13', '318', '11', '2016', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6163, to_date('14-11-2016', 'dd-mm-yyyy'), '1', '14', '319', '11', '2016', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6164, to_date('15-11-2016', 'dd-mm-yyyy'), '2', '15', '320', '11', '2016', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6165, to_date('16-11-2016', 'dd-mm-yyyy'), '3', '16', '321', '11', '2016', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6166, to_date('17-11-2016', 'dd-mm-yyyy'), '4', '17', '322', '11', '2016', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6167, to_date('18-11-2016', 'dd-mm-yyyy'), '5', '18', '323', '11', '2016', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6168, to_date('19-11-2016', 'dd-mm-yyyy'), '6', '19', '324', '11', '2016', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6169, to_date('20-11-2016', 'dd-mm-yyyy'), '7', '20', '325', '11', '2016', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6170, to_date('21-11-2016', 'dd-mm-yyyy'), '1', '21', '326', '11', '2016', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6171, to_date('22-11-2016', 'dd-mm-yyyy'), '2', '22', '327', '11', '2016', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6172, to_date('23-11-2016', 'dd-mm-yyyy'), '3', '23', '328', '11', '2016', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6173, to_date('24-11-2016', 'dd-mm-yyyy'), '4', '24', '329', '11', '2016', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6174, to_date('25-11-2016', 'dd-mm-yyyy'), '5', '25', '330', '11', '2016', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6175, to_date('26-11-2016', 'dd-mm-yyyy'), '6', '26', '331', '11', '2016', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6176, to_date('27-11-2016', 'dd-mm-yyyy'), '7', '27', '332', '11', '2016', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6177, to_date('28-11-2016', 'dd-mm-yyyy'), '1', '28', '333', '11', '2016', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6178, to_date('29-11-2016', 'dd-mm-yyyy'), '2', '29', '334', '11', '2016', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6179, to_date('30-11-2016', 'dd-mm-yyyy'), '3', '30', '335', '11', '2016', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6180, to_date('01-12-2016', 'dd-mm-yyyy'), '4', '01', '336', '12', '2016', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6181, to_date('02-12-2016', 'dd-mm-yyyy'), '5', '02', '337', '12', '2016', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6182, to_date('03-12-2016', 'dd-mm-yyyy'), '6', '03', '338', '12', '2016', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6183, to_date('04-12-2016', 'dd-mm-yyyy'), '7', '04', '339', '12', '2016', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6184, to_date('05-12-2016', 'dd-mm-yyyy'), '1', '05', '340', '12', '2016', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6185, to_date('06-12-2016', 'dd-mm-yyyy'), '2', '06', '341', '12', '2016', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6186, to_date('07-12-2016', 'dd-mm-yyyy'), '3', '07', '342', '12', '2016', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6187, to_date('08-12-2016', 'dd-mm-yyyy'), '4', '08', '343', '12', '2016', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6188, to_date('09-12-2016', 'dd-mm-yyyy'), '5', '09', '344', '12', '2016', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6189, to_date('10-12-2016', 'dd-mm-yyyy'), '6', '10', '345', '12', '2016', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6190, to_date('11-12-2016', 'dd-mm-yyyy'), '7', '11', '346', '12', '2016', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6191, to_date('12-12-2016', 'dd-mm-yyyy'), '1', '12', '347', '12', '2016', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6192, to_date('13-12-2016', 'dd-mm-yyyy'), '2', '13', '348', '12', '2016', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6193, to_date('14-12-2016', 'dd-mm-yyyy'), '3', '14', '349', '12', '2016', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6194, to_date('15-12-2016', 'dd-mm-yyyy'), '4', '15', '350', '12', '2016', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6195, to_date('16-12-2016', 'dd-mm-yyyy'), '5', '16', '351', '12', '2016', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6196, to_date('17-12-2016', 'dd-mm-yyyy'), '6', '17', '352', '12', '2016', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6197, to_date('18-12-2016', 'dd-mm-yyyy'), '7', '18', '353', '12', '2016', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6198, to_date('19-12-2016', 'dd-mm-yyyy'), '1', '19', '354', '12', '2016', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6199, to_date('20-12-2016', 'dd-mm-yyyy'), '2', '20', '355', '12', '2016', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6200, to_date('21-12-2016', 'dd-mm-yyyy'), '3', '21', '356', '12', '2016', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6201, to_date('22-12-2016', 'dd-mm-yyyy'), '4', '22', '357', '12', '2016', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6202, to_date('23-12-2016', 'dd-mm-yyyy'), '5', '23', '358', '12', '2016', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6203, to_date('24-12-2016', 'dd-mm-yyyy'), '6', '24', '359', '12', '2016', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6204, to_date('25-12-2016', 'dd-mm-yyyy'), '7', '25', '360', '12', '2016', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6205, to_date('26-12-2016', 'dd-mm-yyyy'), '1', '26', '361', '12', '2016', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6206, to_date('27-12-2016', 'dd-mm-yyyy'), '2', '27', '362', '12', '2016', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6207, to_date('28-12-2016', 'dd-mm-yyyy'), '3', '28', '363', '12', '2016', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6208, to_date('29-12-2016', 'dd-mm-yyyy'), '4', '29', '364', '12', '2016', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6209, to_date('30-12-2016', 'dd-mm-yyyy'), '5', '30', '365', '12', '2016', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6210, to_date('31-12-2016', 'dd-mm-yyyy'), '6', '31', '366', '12', '2016', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6211, to_date('01-01-2017', 'dd-mm-yyyy'), '7', '01', '001', '01', '2017', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6212, to_date('02-01-2017', 'dd-mm-yyyy'), '1', '02', '002', '01', '2017', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6213, to_date('03-01-2017', 'dd-mm-yyyy'), '2', '03', '003', '01', '2017', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6214, to_date('04-01-2017', 'dd-mm-yyyy'), '3', '04', '004', '01', '2017', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6215, to_date('05-01-2017', 'dd-mm-yyyy'), '4', '05', '005', '01', '2017', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6216, to_date('06-01-2017', 'dd-mm-yyyy'), '5', '06', '006', '01', '2017', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6217, to_date('07-01-2017', 'dd-mm-yyyy'), '6', '07', '007', '01', '2017', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6218, to_date('08-01-2017', 'dd-mm-yyyy'), '7', '08', '008', '01', '2017', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6219, to_date('09-01-2017', 'dd-mm-yyyy'), '1', '09', '009', '01', '2017', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6220, to_date('10-01-2017', 'dd-mm-yyyy'), '2', '10', '010', '01', '2017', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6221, to_date('11-01-2017', 'dd-mm-yyyy'), '3', '11', '011', '01', '2017', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6222, to_date('12-01-2017', 'dd-mm-yyyy'), '4', '12', '012', '01', '2017', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6223, to_date('13-01-2017', 'dd-mm-yyyy'), '5', '13', '013', '01', '2017', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6224, to_date('14-01-2017', 'dd-mm-yyyy'), '6', '14', '014', '01', '2017', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6225, to_date('15-01-2017', 'dd-mm-yyyy'), '7', '15', '015', '01', '2017', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6226, to_date('16-01-2017', 'dd-mm-yyyy'), '1', '16', '016', '01', '2017', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6227, to_date('17-01-2017', 'dd-mm-yyyy'), '2', '17', '017', '01', '2017', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6228, to_date('18-01-2017', 'dd-mm-yyyy'), '3', '18', '018', '01', '2017', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6229, to_date('19-01-2017', 'dd-mm-yyyy'), '4', '19', '019', '01', '2017', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6230, to_date('20-01-2017', 'dd-mm-yyyy'), '5', '20', '020', '01', '2017', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6231, to_date('21-01-2017', 'dd-mm-yyyy'), '6', '21', '021', '01', '2017', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6232, to_date('22-01-2017', 'dd-mm-yyyy'), '7', '22', '022', '01', '2017', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6233, to_date('23-01-2017', 'dd-mm-yyyy'), '1', '23', '023', '01', '2017', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6234, to_date('24-01-2017', 'dd-mm-yyyy'), '2', '24', '024', '01', '2017', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6235, to_date('25-01-2017', 'dd-mm-yyyy'), '3', '25', '025', '01', '2017', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6236, to_date('26-01-2017', 'dd-mm-yyyy'), '4', '26', '026', '01', '2017', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6237, to_date('27-01-2017', 'dd-mm-yyyy'), '5', '27', '027', '01', '2017', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6238, to_date('28-01-2017', 'dd-mm-yyyy'), '6', '28', '028', '01', '2017', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6239, to_date('29-01-2017', 'dd-mm-yyyy'), '7', '29', '029', '01', '2017', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6240, to_date('30-01-2017', 'dd-mm-yyyy'), '1', '30', '030', '01', '2017', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6241, to_date('31-01-2017', 'dd-mm-yyyy'), '2', '31', '031', '01', '2017', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6242, to_date('01-02-2017', 'dd-mm-yyyy'), '3', '01', '032', '02', '2017', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6243, to_date('02-02-2017', 'dd-mm-yyyy'), '4', '02', '033', '02', '2017', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6244, to_date('03-02-2017', 'dd-mm-yyyy'), '5', '03', '034', '02', '2017', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6245, to_date('04-02-2017', 'dd-mm-yyyy'), '6', '04', '035', '02', '2017', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6246, to_date('05-02-2017', 'dd-mm-yyyy'), '7', '05', '036', '02', '2017', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6247, to_date('06-02-2017', 'dd-mm-yyyy'), '1', '06', '037', '02', '2017', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6248, to_date('07-02-2017', 'dd-mm-yyyy'), '2', '07', '038', '02', '2017', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6249, to_date('08-02-2017', 'dd-mm-yyyy'), '3', '08', '039', '02', '2017', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6250, to_date('09-02-2017', 'dd-mm-yyyy'), '4', '09', '040', '02', '2017', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6251, to_date('10-02-2017', 'dd-mm-yyyy'), '5', '10', '041', '02', '2017', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6252, to_date('11-02-2017', 'dd-mm-yyyy'), '6', '11', '042', '02', '2017', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6253, to_date('12-02-2017', 'dd-mm-yyyy'), '7', '12', '043', '02', '2017', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6254, to_date('13-02-2017', 'dd-mm-yyyy'), '1', '13', '044', '02', '2017', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6255, to_date('14-02-2017', 'dd-mm-yyyy'), '2', '14', '045', '02', '2017', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6256, to_date('15-02-2017', 'dd-mm-yyyy'), '3', '15', '046', '02', '2017', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6257, to_date('16-02-2017', 'dd-mm-yyyy'), '4', '16', '047', '02', '2017', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6258, to_date('17-02-2017', 'dd-mm-yyyy'), '5', '17', '048', '02', '2017', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6259, to_date('18-02-2017', 'dd-mm-yyyy'), '6', '18', '049', '02', '2017', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6260, to_date('19-02-2017', 'dd-mm-yyyy'), '7', '19', '050', '02', '2017', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6261, to_date('20-02-2017', 'dd-mm-yyyy'), '1', '20', '051', '02', '2017', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6262, to_date('21-02-2017', 'dd-mm-yyyy'), '2', '21', '052', '02', '2017', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6263, to_date('22-02-2017', 'dd-mm-yyyy'), '3', '22', '053', '02', '2017', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6264, to_date('23-02-2017', 'dd-mm-yyyy'), '4', '23', '054', '02', '2017', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6265, to_date('24-02-2017', 'dd-mm-yyyy'), '5', '24', '055', '02', '2017', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5726, to_date('04-09-2015', 'dd-mm-yyyy'), '5', '04', '247', '09', '2015', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5727, to_date('05-09-2015', 'dd-mm-yyyy'), '6', '05', '248', '09', '2015', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5728, to_date('06-09-2015', 'dd-mm-yyyy'), '7', '06', '249', '09', '2015', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5729, to_date('07-09-2015', 'dd-mm-yyyy'), '1', '07', '250', '09', '2015', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5730, to_date('08-09-2015', 'dd-mm-yyyy'), '2', '08', '251', '09', '2015', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5731, to_date('09-09-2015', 'dd-mm-yyyy'), '3', '09', '252', '09', '2015', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5732, to_date('10-09-2015', 'dd-mm-yyyy'), '4', '10', '253', '09', '2015', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5733, to_date('11-09-2015', 'dd-mm-yyyy'), '5', '11', '254', '09', '2015', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5734, to_date('12-09-2015', 'dd-mm-yyyy'), '6', '12', '255', '09', '2015', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5735, to_date('13-09-2015', 'dd-mm-yyyy'), '7', '13', '256', '09', '2015', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5736, to_date('14-09-2015', 'dd-mm-yyyy'), '1', '14', '257', '09', '2015', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5737, to_date('15-09-2015', 'dd-mm-yyyy'), '2', '15', '258', '09', '2015', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5738, to_date('16-09-2015', 'dd-mm-yyyy'), '3', '16', '259', '09', '2015', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5739, to_date('17-09-2015', 'dd-mm-yyyy'), '4', '17', '260', '09', '2015', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5740, to_date('18-09-2015', 'dd-mm-yyyy'), '5', '18', '261', '09', '2015', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5741, to_date('19-09-2015', 'dd-mm-yyyy'), '6', '19', '262', '09', '2015', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5742, to_date('20-09-2015', 'dd-mm-yyyy'), '7', '20', '263', '09', '2015', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5743, to_date('21-09-2015', 'dd-mm-yyyy'), '1', '21', '264', '09', '2015', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5744, to_date('22-09-2015', 'dd-mm-yyyy'), '2', '22', '265', '09', '2015', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5745, to_date('23-09-2015', 'dd-mm-yyyy'), '3', '23', '266', '09', '2015', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5746, to_date('24-09-2015', 'dd-mm-yyyy'), '4', '24', '267', '09', '2015', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5747, to_date('25-09-2015', 'dd-mm-yyyy'), '5', '25', '268', '09', '2015', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5748, to_date('26-09-2015', 'dd-mm-yyyy'), '6', '26', '269', '09', '2015', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5749, to_date('27-09-2015', 'dd-mm-yyyy'), '7', '27', '270', '09', '2015', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5750, to_date('28-09-2015', 'dd-mm-yyyy'), '1', '28', '271', '09', '2015', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5751, to_date('29-09-2015', 'dd-mm-yyyy'), '2', '29', '272', '09', '2015', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5752, to_date('30-09-2015', 'dd-mm-yyyy'), '3', '30', '273', '09', '2015', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5753, to_date('01-10-2015', 'dd-mm-yyyy'), '4', '01', '274', '10', '2015', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5754, to_date('02-10-2015', 'dd-mm-yyyy'), '5', '02', '275', '10', '2015', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5755, to_date('03-10-2015', 'dd-mm-yyyy'), '6', '03', '276', '10', '2015', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5756, to_date('04-10-2015', 'dd-mm-yyyy'), '7', '04', '277', '10', '2015', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5757, to_date('05-10-2015', 'dd-mm-yyyy'), '1', '05', '278', '10', '2015', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5758, to_date('06-10-2015', 'dd-mm-yyyy'), '2', '06', '279', '10', '2015', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5759, to_date('07-10-2015', 'dd-mm-yyyy'), '3', '07', '280', '10', '2015', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5760, to_date('08-10-2015', 'dd-mm-yyyy'), '4', '08', '281', '10', '2015', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5761, to_date('09-10-2015', 'dd-mm-yyyy'), '5', '09', '282', '10', '2015', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5762, to_date('10-10-2015', 'dd-mm-yyyy'), '6', '10', '283', '10', '2015', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5763, to_date('11-10-2015', 'dd-mm-yyyy'), '7', '11', '284', '10', '2015', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5764, to_date('12-10-2015', 'dd-mm-yyyy'), '1', '12', '285', '10', '2015', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5765, to_date('13-10-2015', 'dd-mm-yyyy'), '2', '13', '286', '10', '2015', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5766, to_date('14-10-2015', 'dd-mm-yyyy'), '3', '14', '287', '10', '2015', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5767, to_date('15-10-2015', 'dd-mm-yyyy'), '4', '15', '288', '10', '2015', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5768, to_date('16-10-2015', 'dd-mm-yyyy'), '5', '16', '289', '10', '2015', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5769, to_date('17-10-2015', 'dd-mm-yyyy'), '6', '17', '290', '10', '2015', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5770, to_date('18-10-2015', 'dd-mm-yyyy'), '7', '18', '291', '10', '2015', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5771, to_date('19-10-2015', 'dd-mm-yyyy'), '1', '19', '292', '10', '2015', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5772, to_date('20-10-2015', 'dd-mm-yyyy'), '2', '20', '293', '10', '2015', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5773, to_date('21-10-2015', 'dd-mm-yyyy'), '3', '21', '294', '10', '2015', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5774, to_date('22-10-2015', 'dd-mm-yyyy'), '4', '22', '295', '10', '2015', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5775, to_date('23-10-2015', 'dd-mm-yyyy'), '5', '23', '296', '10', '2015', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5776, to_date('24-10-2015', 'dd-mm-yyyy'), '6', '24', '297', '10', '2015', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5777, to_date('25-10-2015', 'dd-mm-yyyy'), '7', '25', '298', '10', '2015', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5778, to_date('26-10-2015', 'dd-mm-yyyy'), '1', '26', '299', '10', '2015', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5779, to_date('27-10-2015', 'dd-mm-yyyy'), '2', '27', '300', '10', '2015', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5780, to_date('28-10-2015', 'dd-mm-yyyy'), '3', '28', '301', '10', '2015', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5781, to_date('29-10-2015', 'dd-mm-yyyy'), '4', '29', '302', '10', '2015', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5782, to_date('30-10-2015', 'dd-mm-yyyy'), '5', '30', '303', '10', '2015', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5783, to_date('31-10-2015', 'dd-mm-yyyy'), '6', '31', '304', '10', '2015', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5784, to_date('01-11-2015', 'dd-mm-yyyy'), '7', '01', '305', '11', '2015', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5785, to_date('02-11-2015', 'dd-mm-yyyy'), '1', '02', '306', '11', '2015', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5786, to_date('03-11-2015', 'dd-mm-yyyy'), '2', '03', '307', '11', '2015', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5787, to_date('04-11-2015', 'dd-mm-yyyy'), '3', '04', '308', '11', '2015', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5788, to_date('05-11-2015', 'dd-mm-yyyy'), '4', '05', '309', '11', '2015', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5789, to_date('06-11-2015', 'dd-mm-yyyy'), '5', '06', '310', '11', '2015', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5790, to_date('07-11-2015', 'dd-mm-yyyy'), '6', '07', '311', '11', '2015', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5791, to_date('08-11-2015', 'dd-mm-yyyy'), '7', '08', '312', '11', '2015', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5792, to_date('09-11-2015', 'dd-mm-yyyy'), '1', '09', '313', '11', '2015', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5793, to_date('10-11-2015', 'dd-mm-yyyy'), '2', '10', '314', '11', '2015', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5794, to_date('11-11-2015', 'dd-mm-yyyy'), '3', '11', '315', '11', '2015', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5795, to_date('12-11-2015', 'dd-mm-yyyy'), '4', '12', '316', '11', '2015', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5796, to_date('13-11-2015', 'dd-mm-yyyy'), '5', '13', '317', '11', '2015', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5797, to_date('14-11-2015', 'dd-mm-yyyy'), '6', '14', '318', '11', '2015', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5798, to_date('15-11-2015', 'dd-mm-yyyy'), '7', '15', '319', '11', '2015', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5799, to_date('16-11-2015', 'dd-mm-yyyy'), '1', '16', '320', '11', '2015', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5800, to_date('17-11-2015', 'dd-mm-yyyy'), '2', '17', '321', '11', '2015', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5801, to_date('18-11-2015', 'dd-mm-yyyy'), '3', '18', '322', '11', '2015', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5802, to_date('19-11-2015', 'dd-mm-yyyy'), '4', '19', '323', '11', '2015', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5803, to_date('20-11-2015', 'dd-mm-yyyy'), '5', '20', '324', '11', '2015', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5804, to_date('21-11-2015', 'dd-mm-yyyy'), '6', '21', '325', '11', '2015', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5805, to_date('22-11-2015', 'dd-mm-yyyy'), '7', '22', '326', '11', '2015', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5806, to_date('23-11-2015', 'dd-mm-yyyy'), '1', '23', '327', '11', '2015', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5807, to_date('24-11-2015', 'dd-mm-yyyy'), '2', '24', '328', '11', '2015', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5808, to_date('25-11-2015', 'dd-mm-yyyy'), '3', '25', '329', '11', '2015', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5809, to_date('26-11-2015', 'dd-mm-yyyy'), '4', '26', '330', '11', '2015', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5810, to_date('27-11-2015', 'dd-mm-yyyy'), '5', '27', '331', '11', '2015', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5811, to_date('28-11-2015', 'dd-mm-yyyy'), '6', '28', '332', '11', '2015', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5812, to_date('29-11-2015', 'dd-mm-yyyy'), '7', '29', '333', '11', '2015', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5813, to_date('30-11-2015', 'dd-mm-yyyy'), '1', '30', '334', '11', '2015', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5814, to_date('01-12-2015', 'dd-mm-yyyy'), '2', '01', '335', '12', '2015', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5815, to_date('02-12-2015', 'dd-mm-yyyy'), '3', '02', '336', '12', '2015', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5816, to_date('03-12-2015', 'dd-mm-yyyy'), '4', '03', '337', '12', '2015', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5817, to_date('04-12-2015', 'dd-mm-yyyy'), '5', '04', '338', '12', '2015', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5818, to_date('05-12-2015', 'dd-mm-yyyy'), '6', '05', '339', '12', '2015', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5819, to_date('06-12-2015', 'dd-mm-yyyy'), '7', '06', '340', '12', '2015', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5820, to_date('07-12-2015', 'dd-mm-yyyy'), '1', '07', '341', '12', '2015', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5821, to_date('08-12-2015', 'dd-mm-yyyy'), '2', '08', '342', '12', '2015', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5822, to_date('09-12-2015', 'dd-mm-yyyy'), '3', '09', '343', '12', '2015', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5823, to_date('10-12-2015', 'dd-mm-yyyy'), '4', '10', '344', '12', '2015', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5824, to_date('11-12-2015', 'dd-mm-yyyy'), '5', '11', '345', '12', '2015', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5825, to_date('12-12-2015', 'dd-mm-yyyy'), '6', '12', '346', '12', '2015', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5826, to_date('13-12-2015', 'dd-mm-yyyy'), '7', '13', '347', '12', '2015', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5827, to_date('14-12-2015', 'dd-mm-yyyy'), '1', '14', '348', '12', '2015', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5828, to_date('15-12-2015', 'dd-mm-yyyy'), '2', '15', '349', '12', '2015', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5829, to_date('16-12-2015', 'dd-mm-yyyy'), '3', '16', '350', '12', '2015', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5830, to_date('17-12-2015', 'dd-mm-yyyy'), '4', '17', '351', '12', '2015', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5831, to_date('18-12-2015', 'dd-mm-yyyy'), '5', '18', '352', '12', '2015', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5832, to_date('19-12-2015', 'dd-mm-yyyy'), '6', '19', '353', '12', '2015', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5833, to_date('20-12-2015', 'dd-mm-yyyy'), '7', '20', '354', '12', '2015', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5834, to_date('21-12-2015', 'dd-mm-yyyy'), '1', '21', '355', '12', '2015', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5835, to_date('22-12-2015', 'dd-mm-yyyy'), '2', '22', '356', '12', '2015', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5836, to_date('23-12-2015', 'dd-mm-yyyy'), '3', '23', '357', '12', '2015', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5837, to_date('24-12-2015', 'dd-mm-yyyy'), '4', '24', '358', '12', '2015', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5838, to_date('25-12-2015', 'dd-mm-yyyy'), '5', '25', '359', '12', '2015', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5839, to_date('26-12-2015', 'dd-mm-yyyy'), '6', '26', '360', '12', '2015', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5840, to_date('27-12-2015', 'dd-mm-yyyy'), '7', '27', '361', '12', '2015', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5841, to_date('28-12-2015', 'dd-mm-yyyy'), '1', '28', '362', '12', '2015', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5842, to_date('29-12-2015', 'dd-mm-yyyy'), '2', '29', '363', '12', '2015', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5843, to_date('30-12-2015', 'dd-mm-yyyy'), '3', '30', '364', '12', '2015', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5844, to_date('31-12-2015', 'dd-mm-yyyy'), '4', '31', '365', '12', '2015', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5845, to_date('01-01-2016', 'dd-mm-yyyy'), '5', '01', '001', '01', '2016', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5846, to_date('02-01-2016', 'dd-mm-yyyy'), '6', '02', '002', '01', '2016', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5847, to_date('03-01-2016', 'dd-mm-yyyy'), '7', '03', '003', '01', '2016', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5848, to_date('04-01-2016', 'dd-mm-yyyy'), '1', '04', '004', '01', '2016', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5849, to_date('05-01-2016', 'dd-mm-yyyy'), '2', '05', '005', '01', '2016', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5850, to_date('06-01-2016', 'dd-mm-yyyy'), '3', '06', '006', '01', '2016', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5851, to_date('07-01-2016', 'dd-mm-yyyy'), '4', '07', '007', '01', '2016', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5852, to_date('08-01-2016', 'dd-mm-yyyy'), '5', '08', '008', '01', '2016', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5853, to_date('09-01-2016', 'dd-mm-yyyy'), '6', '09', '009', '01', '2016', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5854, to_date('10-01-2016', 'dd-mm-yyyy'), '7', '10', '010', '01', '2016', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5855, to_date('11-01-2016', 'dd-mm-yyyy'), '1', '11', '011', '01', '2016', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5856, to_date('12-01-2016', 'dd-mm-yyyy'), '2', '12', '012', '01', '2016', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5857, to_date('13-01-2016', 'dd-mm-yyyy'), '3', '13', '013', '01', '2016', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5858, to_date('14-01-2016', 'dd-mm-yyyy'), '4', '14', '014', '01', '2016', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5859, to_date('15-01-2016', 'dd-mm-yyyy'), '5', '15', '015', '01', '2016', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5860, to_date('16-01-2016', 'dd-mm-yyyy'), '6', '16', '016', '01', '2016', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5861, to_date('17-01-2016', 'dd-mm-yyyy'), '7', '17', '017', '01', '2016', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5862, to_date('18-01-2016', 'dd-mm-yyyy'), '1', '18', '018', '01', '2016', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5863, to_date('19-01-2016', 'dd-mm-yyyy'), '2', '19', '019', '01', '2016', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5864, to_date('20-01-2016', 'dd-mm-yyyy'), '3', '20', '020', '01', '2016', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5865, to_date('21-01-2016', 'dd-mm-yyyy'), '4', '21', '021', '01', '2016', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5866, to_date('22-01-2016', 'dd-mm-yyyy'), '5', '22', '022', '01', '2016', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5867, to_date('23-01-2016', 'dd-mm-yyyy'), '6', '23', '023', '01', '2016', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5868, to_date('24-01-2016', 'dd-mm-yyyy'), '7', '24', '024', '01', '2016', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5869, to_date('25-01-2016', 'dd-mm-yyyy'), '1', '25', '025', '01', '2016', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5870, to_date('26-01-2016', 'dd-mm-yyyy'), '2', '26', '026', '01', '2016', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5871, to_date('27-01-2016', 'dd-mm-yyyy'), '3', '27', '027', '01', '2016', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5872, to_date('28-01-2016', 'dd-mm-yyyy'), '4', '28', '028', '01', '2016', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5873, to_date('29-01-2016', 'dd-mm-yyyy'), '5', '29', '029', '01', '2016', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5874, to_date('30-01-2016', 'dd-mm-yyyy'), '6', '30', '030', '01', '2016', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5875, to_date('31-01-2016', 'dd-mm-yyyy'), '7', '31', '031', '01', '2016', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5876, to_date('01-02-2016', 'dd-mm-yyyy'), '1', '01', '032', '02', '2016', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5877, to_date('02-02-2016', 'dd-mm-yyyy'), '2', '02', '033', '02', '2016', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5878, to_date('03-02-2016', 'dd-mm-yyyy'), '3', '03', '034', '02', '2016', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5879, to_date('04-02-2016', 'dd-mm-yyyy'), '4', '04', '035', '02', '2016', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5880, to_date('05-02-2016', 'dd-mm-yyyy'), '5', '05', '036', '02', '2016', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5881, to_date('06-02-2016', 'dd-mm-yyyy'), '6', '06', '037', '02', '2016', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5882, to_date('07-02-2016', 'dd-mm-yyyy'), '7', '07', '038', '02', '2016', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5883, to_date('08-02-2016', 'dd-mm-yyyy'), '1', '08', '039', '02', '2016', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5884, to_date('09-02-2016', 'dd-mm-yyyy'), '2', '09', '040', '02', '2016', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5885, to_date('10-02-2016', 'dd-mm-yyyy'), '3', '10', '041', '02', '2016', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5886, to_date('11-02-2016', 'dd-mm-yyyy'), '4', '11', '042', '02', '2016', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5887, to_date('12-02-2016', 'dd-mm-yyyy'), '5', '12', '043', '02', '2016', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5888, to_date('13-02-2016', 'dd-mm-yyyy'), '6', '13', '044', '02', '2016', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5889, to_date('14-02-2016', 'dd-mm-yyyy'), '7', '14', '045', '02', '2016', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5890, to_date('15-02-2016', 'dd-mm-yyyy'), '1', '15', '046', '02', '2016', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5891, to_date('16-02-2016', 'dd-mm-yyyy'), '2', '16', '047', '02', '2016', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5892, to_date('17-02-2016', 'dd-mm-yyyy'), '3', '17', '048', '02', '2016', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5893, to_date('18-02-2016', 'dd-mm-yyyy'), '4', '18', '049', '02', '2016', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5894, to_date('19-02-2016', 'dd-mm-yyyy'), '5', '19', '050', '02', '2016', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5895, to_date('20-02-2016', 'dd-mm-yyyy'), '6', '20', '051', '02', '2016', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5896, to_date('21-02-2016', 'dd-mm-yyyy'), '7', '21', '052', '02', '2016', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5897, to_date('22-02-2016', 'dd-mm-yyyy'), '1', '22', '053', '02', '2016', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5898, to_date('23-02-2016', 'dd-mm-yyyy'), '2', '23', '054', '02', '2016', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5899, to_date('24-02-2016', 'dd-mm-yyyy'), '3', '24', '055', '02', '2016', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5900, to_date('25-02-2016', 'dd-mm-yyyy'), '4', '25', '056', '02', '2016', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5901, to_date('26-02-2016', 'dd-mm-yyyy'), '5', '26', '057', '02', '2016', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5902, to_date('27-02-2016', 'dd-mm-yyyy'), '6', '27', '058', '02', '2016', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5903, to_date('28-02-2016', 'dd-mm-yyyy'), '7', '28', '059', '02', '2016', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5904, to_date('29-02-2016', 'dd-mm-yyyy'), '1', '29', '060', '02', '2016', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5905, to_date('01-03-2016', 'dd-mm-yyyy'), '2', '01', '061', '03', '2016', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5906, to_date('02-03-2016', 'dd-mm-yyyy'), '3', '02', '062', '03', '2016', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5907, to_date('03-03-2016', 'dd-mm-yyyy'), '4', '03', '063', '03', '2016', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5908, to_date('04-03-2016', 'dd-mm-yyyy'), '5', '04', '064', '03', '2016', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5909, to_date('05-03-2016', 'dd-mm-yyyy'), '6', '05', '065', '03', '2016', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5910, to_date('06-03-2016', 'dd-mm-yyyy'), '7', '06', '066', '03', '2016', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5911, to_date('07-03-2016', 'dd-mm-yyyy'), '1', '07', '067', '03', '2016', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5912, to_date('08-03-2016', 'dd-mm-yyyy'), '2', '08', '068', '03', '2016', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5913, to_date('09-03-2016', 'dd-mm-yyyy'), '3', '09', '069', '03', '2016', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5914, to_date('10-03-2016', 'dd-mm-yyyy'), '4', '10', '070', '03', '2016', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5915, to_date('11-03-2016', 'dd-mm-yyyy'), '5', '11', '071', '03', '2016', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5916, to_date('12-03-2016', 'dd-mm-yyyy'), '6', '12', '072', '03', '2016', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5917, to_date('13-03-2016', 'dd-mm-yyyy'), '7', '13', '073', '03', '2016', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5918, to_date('14-03-2016', 'dd-mm-yyyy'), '1', '14', '074', '03', '2016', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5919, to_date('15-03-2016', 'dd-mm-yyyy'), '2', '15', '075', '03', '2016', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5920, to_date('16-03-2016', 'dd-mm-yyyy'), '3', '16', '076', '03', '2016', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5921, to_date('17-03-2016', 'dd-mm-yyyy'), '4', '17', '077', '03', '2016', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5922, to_date('18-03-2016', 'dd-mm-yyyy'), '5', '18', '078', '03', '2016', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5923, to_date('19-03-2016', 'dd-mm-yyyy'), '6', '19', '079', '03', '2016', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5924, to_date('20-03-2016', 'dd-mm-yyyy'), '7', '20', '080', '03', '2016', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5925, to_date('21-03-2016', 'dd-mm-yyyy'), '1', '21', '081', '03', '2016', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5926, to_date('22-03-2016', 'dd-mm-yyyy'), '2', '22', '082', '03', '2016', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5927, to_date('23-03-2016', 'dd-mm-yyyy'), '3', '23', '083', '03', '2016', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5928, to_date('24-03-2016', 'dd-mm-yyyy'), '4', '24', '084', '03', '2016', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5929, to_date('25-03-2016', 'dd-mm-yyyy'), '5', '25', '085', '03', '2016', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5930, to_date('26-03-2016', 'dd-mm-yyyy'), '6', '26', '086', '03', '2016', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5931, to_date('27-03-2016', 'dd-mm-yyyy'), '7', '27', '087', '03', '2016', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5932, to_date('28-03-2016', 'dd-mm-yyyy'), '1', '28', '088', '03', '2016', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5933, to_date('29-03-2016', 'dd-mm-yyyy'), '2', '29', '089', '03', '2016', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5934, to_date('30-03-2016', 'dd-mm-yyyy'), '3', '30', '090', '03', '2016', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5935, to_date('31-03-2016', 'dd-mm-yyyy'), '4', '31', '091', '03', '2016', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5936, to_date('01-04-2016', 'dd-mm-yyyy'), '5', '01', '092', '04', '2016', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5937, to_date('02-04-2016', 'dd-mm-yyyy'), '6', '02', '093', '04', '2016', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5938, to_date('03-04-2016', 'dd-mm-yyyy'), '7', '03', '094', '04', '2016', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5939, to_date('04-04-2016', 'dd-mm-yyyy'), '1', '04', '095', '04', '2016', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5940, to_date('05-04-2016', 'dd-mm-yyyy'), '2', '05', '096', '04', '2016', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5941, to_date('06-04-2016', 'dd-mm-yyyy'), '3', '06', '097', '04', '2016', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5942, to_date('07-04-2016', 'dd-mm-yyyy'), '4', '07', '098', '04', '2016', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5943, to_date('08-04-2016', 'dd-mm-yyyy'), '5', '08', '099', '04', '2016', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5944, to_date('09-04-2016', 'dd-mm-yyyy'), '6', '09', '100', '04', '2016', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5945, to_date('10-04-2016', 'dd-mm-yyyy'), '7', '10', '101', '04', '2016', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5946, to_date('11-04-2016', 'dd-mm-yyyy'), '1', '11', '102', '04', '2016', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5947, to_date('12-04-2016', 'dd-mm-yyyy'), '2', '12', '103', '04', '2016', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5948, to_date('13-04-2016', 'dd-mm-yyyy'), '3', '13', '104', '04', '2016', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5949, to_date('14-04-2016', 'dd-mm-yyyy'), '4', '14', '105', '04', '2016', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5950, to_date('15-04-2016', 'dd-mm-yyyy'), '5', '15', '106', '04', '2016', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5951, to_date('16-04-2016', 'dd-mm-yyyy'), '6', '16', '107', '04', '2016', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5952, to_date('17-04-2016', 'dd-mm-yyyy'), '7', '17', '108', '04', '2016', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5953, to_date('18-04-2016', 'dd-mm-yyyy'), '1', '18', '109', '04', '2016', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5954, to_date('19-04-2016', 'dd-mm-yyyy'), '2', '19', '110', '04', '2016', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5955, to_date('20-04-2016', 'dd-mm-yyyy'), '3', '20', '111', '04', '2016', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5956, to_date('21-04-2016', 'dd-mm-yyyy'), '4', '21', '112', '04', '2016', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5957, to_date('22-04-2016', 'dd-mm-yyyy'), '5', '22', '113', '04', '2016', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5958, to_date('23-04-2016', 'dd-mm-yyyy'), '6', '23', '114', '04', '2016', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5959, to_date('24-04-2016', 'dd-mm-yyyy'), '7', '24', '115', '04', '2016', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5960, to_date('25-04-2016', 'dd-mm-yyyy'), '1', '25', '116', '04', '2016', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5961, to_date('26-04-2016', 'dd-mm-yyyy'), '2', '26', '117', '04', '2016', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5962, to_date('27-04-2016', 'dd-mm-yyyy'), '3', '27', '118', '04', '2016', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5963, to_date('28-04-2016', 'dd-mm-yyyy'), '4', '28', '119', '04', '2016', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5964, to_date('29-04-2016', 'dd-mm-yyyy'), '5', '29', '120', '04', '2016', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5965, to_date('30-04-2016', 'dd-mm-yyyy'), '6', '30', '121', '04', '2016', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5966, to_date('01-05-2016', 'dd-mm-yyyy'), '7', '01', '122', '05', '2016', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5967, to_date('02-05-2016', 'dd-mm-yyyy'), '1', '02', '123', '05', '2016', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5968, to_date('03-05-2016', 'dd-mm-yyyy'), '2', '03', '124', '05', '2016', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5969, to_date('04-05-2016', 'dd-mm-yyyy'), '3', '04', '125', '05', '2016', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5970, to_date('05-05-2016', 'dd-mm-yyyy'), '4', '05', '126', '05', '2016', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5971, to_date('06-05-2016', 'dd-mm-yyyy'), '5', '06', '127', '05', '2016', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5972, to_date('07-05-2016', 'dd-mm-yyyy'), '6', '07', '128', '05', '2016', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5973, to_date('08-05-2016', 'dd-mm-yyyy'), '7', '08', '129', '05', '2016', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5974, to_date('09-05-2016', 'dd-mm-yyyy'), '1', '09', '130', '05', '2016', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5975, to_date('10-05-2016', 'dd-mm-yyyy'), '2', '10', '131', '05', '2016', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5976, to_date('11-05-2016', 'dd-mm-yyyy'), '3', '11', '132', '05', '2016', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5977, to_date('12-05-2016', 'dd-mm-yyyy'), '4', '12', '133', '05', '2016', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5978, to_date('13-05-2016', 'dd-mm-yyyy'), '5', '13', '134', '05', '2016', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5979, to_date('14-05-2016', 'dd-mm-yyyy'), '6', '14', '135', '05', '2016', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5980, to_date('15-05-2016', 'dd-mm-yyyy'), '7', '15', '136', '05', '2016', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5981, to_date('16-05-2016', 'dd-mm-yyyy'), '1', '16', '137', '05', '2016', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5982, to_date('17-05-2016', 'dd-mm-yyyy'), '2', '17', '138', '05', '2016', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5983, to_date('18-05-2016', 'dd-mm-yyyy'), '3', '18', '139', '05', '2016', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5984, to_date('19-05-2016', 'dd-mm-yyyy'), '4', '19', '140', '05', '2016', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5985, to_date('20-05-2016', 'dd-mm-yyyy'), '5', '20', '141', '05', '2016', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5986, to_date('21-05-2016', 'dd-mm-yyyy'), '6', '21', '142', '05', '2016', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5987, to_date('22-05-2016', 'dd-mm-yyyy'), '7', '22', '143', '05', '2016', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5988, to_date('23-05-2016', 'dd-mm-yyyy'), '1', '23', '144', '05', '2016', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5989, to_date('24-05-2016', 'dd-mm-yyyy'), '2', '24', '145', '05', '2016', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5990, to_date('25-05-2016', 'dd-mm-yyyy'), '3', '25', '146', '05', '2016', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5991, to_date('26-05-2016', 'dd-mm-yyyy'), '4', '26', '147', '05', '2016', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5992, to_date('27-05-2016', 'dd-mm-yyyy'), '5', '27', '148', '05', '2016', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5993, to_date('28-05-2016', 'dd-mm-yyyy'), '6', '28', '149', '05', '2016', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5994, to_date('29-05-2016', 'dd-mm-yyyy'), '7', '29', '150', '05', '2016', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5995, to_date('30-05-2016', 'dd-mm-yyyy'), '1', '30', '151', '05', '2016', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5996, to_date('31-05-2016', 'dd-mm-yyyy'), '2', '31', '152', '05', '2016', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5997, to_date('01-06-2016', 'dd-mm-yyyy'), '3', '01', '153', '06', '2016', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5998, to_date('02-06-2016', 'dd-mm-yyyy'), '4', '02', '154', '06', '2016', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5999, to_date('03-06-2016', 'dd-mm-yyyy'), '5', '03', '155', '06', '2016', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6000, to_date('04-06-2016', 'dd-mm-yyyy'), '6', '04', '156', '06', '2016', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
commit;
prompt 6000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6001, to_date('05-06-2016', 'dd-mm-yyyy'), '7', '05', '157', '06', '2016', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6002, to_date('06-06-2016', 'dd-mm-yyyy'), '1', '06', '158', '06', '2016', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6003, to_date('07-06-2016', 'dd-mm-yyyy'), '2', '07', '159', '06', '2016', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6004, to_date('08-06-2016', 'dd-mm-yyyy'), '3', '08', '160', '06', '2016', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6005, to_date('09-06-2016', 'dd-mm-yyyy'), '4', '09', '161', '06', '2016', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6006, to_date('10-06-2016', 'dd-mm-yyyy'), '5', '10', '162', '06', '2016', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6007, to_date('11-06-2016', 'dd-mm-yyyy'), '6', '11', '163', '06', '2016', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6008, to_date('12-06-2016', 'dd-mm-yyyy'), '7', '12', '164', '06', '2016', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6009, to_date('13-06-2016', 'dd-mm-yyyy'), '1', '13', '165', '06', '2016', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6010, to_date('14-06-2016', 'dd-mm-yyyy'), '2', '14', '166', '06', '2016', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6011, to_date('15-06-2016', 'dd-mm-yyyy'), '3', '15', '167', '06', '2016', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6012, to_date('16-06-2016', 'dd-mm-yyyy'), '4', '16', '168', '06', '2016', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6013, to_date('17-06-2016', 'dd-mm-yyyy'), '5', '17', '169', '06', '2016', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6014, to_date('18-06-2016', 'dd-mm-yyyy'), '6', '18', '170', '06', '2016', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6015, to_date('19-06-2016', 'dd-mm-yyyy'), '7', '19', '171', '06', '2016', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6016, to_date('20-06-2016', 'dd-mm-yyyy'), '1', '20', '172', '06', '2016', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6017, to_date('21-06-2016', 'dd-mm-yyyy'), '2', '21', '173', '06', '2016', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6018, to_date('22-06-2016', 'dd-mm-yyyy'), '3', '22', '174', '06', '2016', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6019, to_date('23-06-2016', 'dd-mm-yyyy'), '4', '23', '175', '06', '2016', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6020, to_date('24-06-2016', 'dd-mm-yyyy'), '5', '24', '176', '06', '2016', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6021, to_date('25-06-2016', 'dd-mm-yyyy'), '6', '25', '177', '06', '2016', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6022, to_date('26-06-2016', 'dd-mm-yyyy'), '7', '26', '178', '06', '2016', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6023, to_date('27-06-2016', 'dd-mm-yyyy'), '1', '27', '179', '06', '2016', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6024, to_date('28-06-2016', 'dd-mm-yyyy'), '2', '28', '180', '06', '2016', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6025, to_date('29-06-2016', 'dd-mm-yyyy'), '3', '29', '181', '06', '2016', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6026, to_date('30-06-2016', 'dd-mm-yyyy'), '4', '30', '182', '06', '2016', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6027, to_date('01-07-2016', 'dd-mm-yyyy'), '5', '01', '183', '07', '2016', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6028, to_date('02-07-2016', 'dd-mm-yyyy'), '6', '02', '184', '07', '2016', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6029, to_date('03-07-2016', 'dd-mm-yyyy'), '7', '03', '185', '07', '2016', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6030, to_date('04-07-2016', 'dd-mm-yyyy'), '1', '04', '186', '07', '2016', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6031, to_date('05-07-2016', 'dd-mm-yyyy'), '2', '05', '187', '07', '2016', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6032, to_date('06-07-2016', 'dd-mm-yyyy'), '3', '06', '188', '07', '2016', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6033, to_date('07-07-2016', 'dd-mm-yyyy'), '4', '07', '189', '07', '2016', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6034, to_date('08-07-2016', 'dd-mm-yyyy'), '5', '08', '190', '07', '2016', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6035, to_date('09-07-2016', 'dd-mm-yyyy'), '6', '09', '191', '07', '2016', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6036, to_date('10-07-2016', 'dd-mm-yyyy'), '7', '10', '192', '07', '2016', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6037, to_date('11-07-2016', 'dd-mm-yyyy'), '1', '11', '193', '07', '2016', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6038, to_date('12-07-2016', 'dd-mm-yyyy'), '2', '12', '194', '07', '2016', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6039, to_date('13-07-2016', 'dd-mm-yyyy'), '3', '13', '195', '07', '2016', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6040, to_date('14-07-2016', 'dd-mm-yyyy'), '4', '14', '196', '07', '2016', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6041, to_date('15-07-2016', 'dd-mm-yyyy'), '5', '15', '197', '07', '2016', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6042, to_date('16-07-2016', 'dd-mm-yyyy'), '6', '16', '198', '07', '2016', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6043, to_date('17-07-2016', 'dd-mm-yyyy'), '7', '17', '199', '07', '2016', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6044, to_date('18-07-2016', 'dd-mm-yyyy'), '1', '18', '200', '07', '2016', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6045, to_date('19-07-2016', 'dd-mm-yyyy'), '2', '19', '201', '07', '2016', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6046, to_date('20-07-2016', 'dd-mm-yyyy'), '3', '20', '202', '07', '2016', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6047, to_date('21-07-2016', 'dd-mm-yyyy'), '4', '21', '203', '07', '2016', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6048, to_date('22-07-2016', 'dd-mm-yyyy'), '5', '22', '204', '07', '2016', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6049, to_date('23-07-2016', 'dd-mm-yyyy'), '6', '23', '205', '07', '2016', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6050, to_date('24-07-2016', 'dd-mm-yyyy'), '7', '24', '206', '07', '2016', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6051, to_date('25-07-2016', 'dd-mm-yyyy'), '1', '25', '207', '07', '2016', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6052, to_date('26-07-2016', 'dd-mm-yyyy'), '2', '26', '208', '07', '2016', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6053, to_date('27-07-2016', 'dd-mm-yyyy'), '3', '27', '209', '07', '2016', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6054, to_date('28-07-2016', 'dd-mm-yyyy'), '4', '28', '210', '07', '2016', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6055, to_date('29-07-2016', 'dd-mm-yyyy'), '5', '29', '211', '07', '2016', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6056, to_date('30-07-2016', 'dd-mm-yyyy'), '6', '30', '212', '07', '2016', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6057, to_date('31-07-2016', 'dd-mm-yyyy'), '7', '31', '213', '07', '2016', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6058, to_date('01-08-2016', 'dd-mm-yyyy'), '1', '01', '214', '08', '2016', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6059, to_date('02-08-2016', 'dd-mm-yyyy'), '2', '02', '215', '08', '2016', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6060, to_date('03-08-2016', 'dd-mm-yyyy'), '3', '03', '216', '08', '2016', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6061, to_date('04-08-2016', 'dd-mm-yyyy'), '4', '04', '217', '08', '2016', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6062, to_date('05-08-2016', 'dd-mm-yyyy'), '5', '05', '218', '08', '2016', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6063, to_date('06-08-2016', 'dd-mm-yyyy'), '6', '06', '219', '08', '2016', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6064, to_date('07-08-2016', 'dd-mm-yyyy'), '7', '07', '220', '08', '2016', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6065, to_date('08-08-2016', 'dd-mm-yyyy'), '1', '08', '221', '08', '2016', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6066, to_date('09-08-2016', 'dd-mm-yyyy'), '2', '09', '222', '08', '2016', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6067, to_date('10-08-2016', 'dd-mm-yyyy'), '3', '10', '223', '08', '2016', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6068, to_date('11-08-2016', 'dd-mm-yyyy'), '4', '11', '224', '08', '2016', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6069, to_date('12-08-2016', 'dd-mm-yyyy'), '5', '12', '225', '08', '2016', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6070, to_date('13-08-2016', 'dd-mm-yyyy'), '6', '13', '226', '08', '2016', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6071, to_date('14-08-2016', 'dd-mm-yyyy'), '7', '14', '227', '08', '2016', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6072, to_date('15-08-2016', 'dd-mm-yyyy'), '1', '15', '228', '08', '2016', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6073, to_date('16-08-2016', 'dd-mm-yyyy'), '2', '16', '229', '08', '2016', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6074, to_date('17-08-2016', 'dd-mm-yyyy'), '3', '17', '230', '08', '2016', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6075, to_date('18-08-2016', 'dd-mm-yyyy'), '4', '18', '231', '08', '2016', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6076, to_date('19-08-2016', 'dd-mm-yyyy'), '5', '19', '232', '08', '2016', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6077, to_date('20-08-2016', 'dd-mm-yyyy'), '6', '20', '233', '08', '2016', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6078, to_date('21-08-2016', 'dd-mm-yyyy'), '7', '21', '234', '08', '2016', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6079, to_date('22-08-2016', 'dd-mm-yyyy'), '1', '22', '235', '08', '2016', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6080, to_date('23-08-2016', 'dd-mm-yyyy'), '2', '23', '236', '08', '2016', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6081, to_date('24-08-2016', 'dd-mm-yyyy'), '3', '24', '237', '08', '2016', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6082, to_date('25-08-2016', 'dd-mm-yyyy'), '4', '25', '238', '08', '2016', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6083, to_date('26-08-2016', 'dd-mm-yyyy'), '5', '26', '239', '08', '2016', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6084, to_date('27-08-2016', 'dd-mm-yyyy'), '6', '27', '240', '08', '2016', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6085, to_date('28-08-2016', 'dd-mm-yyyy'), '7', '28', '241', '08', '2016', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6086, to_date('29-08-2016', 'dd-mm-yyyy'), '1', '29', '242', '08', '2016', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6087, to_date('30-08-2016', 'dd-mm-yyyy'), '2', '30', '243', '08', '2016', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6088, to_date('31-08-2016', 'dd-mm-yyyy'), '3', '31', '244', '08', '2016', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6089, to_date('01-09-2016', 'dd-mm-yyyy'), '4', '01', '245', '09', '2016', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6090, to_date('02-09-2016', 'dd-mm-yyyy'), '5', '02', '246', '09', '2016', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6091, to_date('03-09-2016', 'dd-mm-yyyy'), '6', '03', '247', '09', '2016', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6092, to_date('04-09-2016', 'dd-mm-yyyy'), '7', '04', '248', '09', '2016', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6093, to_date('05-09-2016', 'dd-mm-yyyy'), '1', '05', '249', '09', '2016', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6094, to_date('06-09-2016', 'dd-mm-yyyy'), '2', '06', '250', '09', '2016', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6095, to_date('07-09-2016', 'dd-mm-yyyy'), '3', '07', '251', '09', '2016', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6096, to_date('08-09-2016', 'dd-mm-yyyy'), '4', '08', '252', '09', '2016', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6097, to_date('09-09-2016', 'dd-mm-yyyy'), '5', '09', '253', '09', '2016', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6098, to_date('10-09-2016', 'dd-mm-yyyy'), '6', '10', '254', '09', '2016', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6099, to_date('11-09-2016', 'dd-mm-yyyy'), '7', '11', '255', '09', '2016', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6100, to_date('12-09-2016', 'dd-mm-yyyy'), '1', '12', '256', '09', '2016', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6101, to_date('13-09-2016', 'dd-mm-yyyy'), '2', '13', '257', '09', '2016', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6102, to_date('14-09-2016', 'dd-mm-yyyy'), '3', '14', '258', '09', '2016', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6103, to_date('15-09-2016', 'dd-mm-yyyy'), '4', '15', '259', '09', '2016', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6104, to_date('16-09-2016', 'dd-mm-yyyy'), '5', '16', '260', '09', '2016', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6105, to_date('17-09-2016', 'dd-mm-yyyy'), '6', '17', '261', '09', '2016', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6106, to_date('18-09-2016', 'dd-mm-yyyy'), '7', '18', '262', '09', '2016', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6107, to_date('19-09-2016', 'dd-mm-yyyy'), '1', '19', '263', '09', '2016', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6108, to_date('20-09-2016', 'dd-mm-yyyy'), '2', '20', '264', '09', '2016', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6109, to_date('21-09-2016', 'dd-mm-yyyy'), '3', '21', '265', '09', '2016', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6110, to_date('22-09-2016', 'dd-mm-yyyy'), '4', '22', '266', '09', '2016', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6111, to_date('23-09-2016', 'dd-mm-yyyy'), '5', '23', '267', '09', '2016', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6112, to_date('24-09-2016', 'dd-mm-yyyy'), '6', '24', '268', '09', '2016', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6113, to_date('25-09-2016', 'dd-mm-yyyy'), '7', '25', '269', '09', '2016', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6114, to_date('26-09-2016', 'dd-mm-yyyy'), '1', '26', '270', '09', '2016', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6115, to_date('27-09-2016', 'dd-mm-yyyy'), '2', '27', '271', '09', '2016', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6116, to_date('28-09-2016', 'dd-mm-yyyy'), '3', '28', '272', '09', '2016', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6117, to_date('29-09-2016', 'dd-mm-yyyy'), '4', '29', '273', '09', '2016', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6118, to_date('30-09-2016', 'dd-mm-yyyy'), '5', '30', '274', '09', '2016', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6119, to_date('01-10-2016', 'dd-mm-yyyy'), '6', '01', '275', '10', '2016', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6120, to_date('02-10-2016', 'dd-mm-yyyy'), '7', '02', '276', '10', '2016', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6121, to_date('03-10-2016', 'dd-mm-yyyy'), '1', '03', '277', '10', '2016', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6122, to_date('04-10-2016', 'dd-mm-yyyy'), '2', '04', '278', '10', '2016', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6123, to_date('05-10-2016', 'dd-mm-yyyy'), '3', '05', '279', '10', '2016', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6124, to_date('06-10-2016', 'dd-mm-yyyy'), '4', '06', '280', '10', '2016', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6125, to_date('07-10-2016', 'dd-mm-yyyy'), '5', '07', '281', '10', '2016', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6126, to_date('08-10-2016', 'dd-mm-yyyy'), '6', '08', '282', '10', '2016', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6127, to_date('09-10-2016', 'dd-mm-yyyy'), '7', '09', '283', '10', '2016', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6128, to_date('10-10-2016', 'dd-mm-yyyy'), '1', '10', '284', '10', '2016', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6129, to_date('11-10-2016', 'dd-mm-yyyy'), '2', '11', '285', '10', '2016', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6130, to_date('12-10-2016', 'dd-mm-yyyy'), '3', '12', '286', '10', '2016', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6131, to_date('13-10-2016', 'dd-mm-yyyy'), '4', '13', '287', '10', '2016', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6132, to_date('14-10-2016', 'dd-mm-yyyy'), '5', '14', '288', '10', '2016', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6133, to_date('15-10-2016', 'dd-mm-yyyy'), '6', '15', '289', '10', '2016', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6134, to_date('16-10-2016', 'dd-mm-yyyy'), '7', '16', '290', '10', '2016', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6135, to_date('17-10-2016', 'dd-mm-yyyy'), '1', '17', '291', '10', '2016', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6136, to_date('18-10-2016', 'dd-mm-yyyy'), '2', '18', '292', '10', '2016', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6137, to_date('19-10-2016', 'dd-mm-yyyy'), '3', '19', '293', '10', '2016', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6138, to_date('20-10-2016', 'dd-mm-yyyy'), '4', '20', '294', '10', '2016', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6139, to_date('21-10-2016', 'dd-mm-yyyy'), '5', '21', '295', '10', '2016', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6140, to_date('22-10-2016', 'dd-mm-yyyy'), '6', '22', '296', '10', '2016', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6141, to_date('23-10-2016', 'dd-mm-yyyy'), '7', '23', '297', '10', '2016', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6142, to_date('24-10-2016', 'dd-mm-yyyy'), '1', '24', '298', '10', '2016', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6143, to_date('25-10-2016', 'dd-mm-yyyy'), '2', '25', '299', '10', '2016', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6144, to_date('26-10-2016', 'dd-mm-yyyy'), '3', '26', '300', '10', '2016', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6145, to_date('27-10-2016', 'dd-mm-yyyy'), '4', '27', '301', '10', '2016', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6146, to_date('28-10-2016', 'dd-mm-yyyy'), '5', '28', '302', '10', '2016', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6147, to_date('29-10-2016', 'dd-mm-yyyy'), '6', '29', '303', '10', '2016', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6148, to_date('30-10-2016', 'dd-mm-yyyy'), '7', '30', '304', '10', '2016', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6149, to_date('31-10-2016', 'dd-mm-yyyy'), '1', '31', '305', '10', '2016', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6150, to_date('01-11-2016', 'dd-mm-yyyy'), '2', '01', '306', '11', '2016', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6151, to_date('02-11-2016', 'dd-mm-yyyy'), '3', '02', '307', '11', '2016', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6152, to_date('03-11-2016', 'dd-mm-yyyy'), '4', '03', '308', '11', '2016', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6153, to_date('04-11-2016', 'dd-mm-yyyy'), '5', '04', '309', '11', '2016', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6154, to_date('05-11-2016', 'dd-mm-yyyy'), '6', '05', '310', '11', '2016', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6155, to_date('06-11-2016', 'dd-mm-yyyy'), '7', '06', '311', '11', '2016', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6156, to_date('07-11-2016', 'dd-mm-yyyy'), '1', '07', '312', '11', '2016', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6157, to_date('08-11-2016', 'dd-mm-yyyy'), '2', '08', '313', '11', '2016', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5402, to_date('15-10-2014', 'dd-mm-yyyy'), '3', '15', '288', '10', '2014', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5403, to_date('16-10-2014', 'dd-mm-yyyy'), '4', '16', '289', '10', '2014', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5404, to_date('17-10-2014', 'dd-mm-yyyy'), '5', '17', '290', '10', '2014', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5405, to_date('18-10-2014', 'dd-mm-yyyy'), '6', '18', '291', '10', '2014', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5406, to_date('19-10-2014', 'dd-mm-yyyy'), '7', '19', '292', '10', '2014', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5407, to_date('20-10-2014', 'dd-mm-yyyy'), '1', '20', '293', '10', '2014', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5408, to_date('21-10-2014', 'dd-mm-yyyy'), '2', '21', '294', '10', '2014', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5409, to_date('22-10-2014', 'dd-mm-yyyy'), '3', '22', '295', '10', '2014', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5410, to_date('23-10-2014', 'dd-mm-yyyy'), '4', '23', '296', '10', '2014', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5411, to_date('24-10-2014', 'dd-mm-yyyy'), '5', '24', '297', '10', '2014', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5412, to_date('25-10-2014', 'dd-mm-yyyy'), '6', '25', '298', '10', '2014', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5413, to_date('26-10-2014', 'dd-mm-yyyy'), '7', '26', '299', '10', '2014', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5414, to_date('27-10-2014', 'dd-mm-yyyy'), '1', '27', '300', '10', '2014', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5415, to_date('28-10-2014', 'dd-mm-yyyy'), '2', '28', '301', '10', '2014', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5416, to_date('29-10-2014', 'dd-mm-yyyy'), '3', '29', '302', '10', '2014', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5417, to_date('30-10-2014', 'dd-mm-yyyy'), '4', '30', '303', '10', '2014', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5418, to_date('31-10-2014', 'dd-mm-yyyy'), '5', '31', '304', '10', '2014', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5419, to_date('01-11-2014', 'dd-mm-yyyy'), '6', '01', '305', '11', '2014', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5420, to_date('02-11-2014', 'dd-mm-yyyy'), '7', '02', '306', '11', '2014', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5421, to_date('03-11-2014', 'dd-mm-yyyy'), '1', '03', '307', '11', '2014', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5422, to_date('04-11-2014', 'dd-mm-yyyy'), '2', '04', '308', '11', '2014', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5423, to_date('05-11-2014', 'dd-mm-yyyy'), '3', '05', '309', '11', '2014', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5424, to_date('06-11-2014', 'dd-mm-yyyy'), '4', '06', '310', '11', '2014', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5425, to_date('07-11-2014', 'dd-mm-yyyy'), '5', '07', '311', '11', '2014', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5426, to_date('08-11-2014', 'dd-mm-yyyy'), '6', '08', '312', '11', '2014', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5427, to_date('09-11-2014', 'dd-mm-yyyy'), '7', '09', '313', '11', '2014', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5428, to_date('10-11-2014', 'dd-mm-yyyy'), '1', '10', '314', '11', '2014', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5429, to_date('11-11-2014', 'dd-mm-yyyy'), '2', '11', '315', '11', '2014', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5430, to_date('12-11-2014', 'dd-mm-yyyy'), '3', '12', '316', '11', '2014', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5431, to_date('13-11-2014', 'dd-mm-yyyy'), '4', '13', '317', '11', '2014', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5432, to_date('14-11-2014', 'dd-mm-yyyy'), '5', '14', '318', '11', '2014', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5433, to_date('15-11-2014', 'dd-mm-yyyy'), '6', '15', '319', '11', '2014', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5434, to_date('16-11-2014', 'dd-mm-yyyy'), '7', '16', '320', '11', '2014', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5435, to_date('17-11-2014', 'dd-mm-yyyy'), '1', '17', '321', '11', '2014', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5436, to_date('18-11-2014', 'dd-mm-yyyy'), '2', '18', '322', '11', '2014', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5437, to_date('19-11-2014', 'dd-mm-yyyy'), '3', '19', '323', '11', '2014', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5438, to_date('20-11-2014', 'dd-mm-yyyy'), '4', '20', '324', '11', '2014', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5439, to_date('21-11-2014', 'dd-mm-yyyy'), '5', '21', '325', '11', '2014', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5440, to_date('22-11-2014', 'dd-mm-yyyy'), '6', '22', '326', '11', '2014', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5441, to_date('23-11-2014', 'dd-mm-yyyy'), '7', '23', '327', '11', '2014', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5442, to_date('24-11-2014', 'dd-mm-yyyy'), '1', '24', '328', '11', '2014', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5443, to_date('25-11-2014', 'dd-mm-yyyy'), '2', '25', '329', '11', '2014', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5444, to_date('26-11-2014', 'dd-mm-yyyy'), '3', '26', '330', '11', '2014', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5445, to_date('27-11-2014', 'dd-mm-yyyy'), '4', '27', '331', '11', '2014', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5446, to_date('28-11-2014', 'dd-mm-yyyy'), '5', '28', '332', '11', '2014', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5447, to_date('29-11-2014', 'dd-mm-yyyy'), '6', '29', '333', '11', '2014', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5448, to_date('30-11-2014', 'dd-mm-yyyy'), '7', '30', '334', '11', '2014', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5449, to_date('01-12-2014', 'dd-mm-yyyy'), '1', '01', '335', '12', '2014', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5450, to_date('02-12-2014', 'dd-mm-yyyy'), '2', '02', '336', '12', '2014', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5451, to_date('03-12-2014', 'dd-mm-yyyy'), '3', '03', '337', '12', '2014', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5452, to_date('04-12-2014', 'dd-mm-yyyy'), '4', '04', '338', '12', '2014', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5453, to_date('05-12-2014', 'dd-mm-yyyy'), '5', '05', '339', '12', '2014', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5454, to_date('06-12-2014', 'dd-mm-yyyy'), '6', '06', '340', '12', '2014', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5455, to_date('07-12-2014', 'dd-mm-yyyy'), '7', '07', '341', '12', '2014', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5456, to_date('08-12-2014', 'dd-mm-yyyy'), '1', '08', '342', '12', '2014', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5457, to_date('09-12-2014', 'dd-mm-yyyy'), '2', '09', '343', '12', '2014', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5458, to_date('10-12-2014', 'dd-mm-yyyy'), '3', '10', '344', '12', '2014', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5459, to_date('11-12-2014', 'dd-mm-yyyy'), '4', '11', '345', '12', '2014', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5460, to_date('12-12-2014', 'dd-mm-yyyy'), '5', '12', '346', '12', '2014', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5461, to_date('13-12-2014', 'dd-mm-yyyy'), '6', '13', '347', '12', '2014', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5462, to_date('14-12-2014', 'dd-mm-yyyy'), '7', '14', '348', '12', '2014', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5463, to_date('15-12-2014', 'dd-mm-yyyy'), '1', '15', '349', '12', '2014', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5464, to_date('16-12-2014', 'dd-mm-yyyy'), '2', '16', '350', '12', '2014', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5465, to_date('17-12-2014', 'dd-mm-yyyy'), '3', '17', '351', '12', '2014', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5466, to_date('18-12-2014', 'dd-mm-yyyy'), '4', '18', '352', '12', '2014', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5467, to_date('19-12-2014', 'dd-mm-yyyy'), '5', '19', '353', '12', '2014', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5468, to_date('20-12-2014', 'dd-mm-yyyy'), '6', '20', '354', '12', '2014', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5469, to_date('21-12-2014', 'dd-mm-yyyy'), '7', '21', '355', '12', '2014', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5470, to_date('22-12-2014', 'dd-mm-yyyy'), '1', '22', '356', '12', '2014', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5471, to_date('23-12-2014', 'dd-mm-yyyy'), '2', '23', '357', '12', '2014', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5472, to_date('24-12-2014', 'dd-mm-yyyy'), '3', '24', '358', '12', '2014', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5473, to_date('25-12-2014', 'dd-mm-yyyy'), '4', '25', '359', '12', '2014', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5474, to_date('26-12-2014', 'dd-mm-yyyy'), '5', '26', '360', '12', '2014', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5475, to_date('27-12-2014', 'dd-mm-yyyy'), '6', '27', '361', '12', '2014', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5476, to_date('28-12-2014', 'dd-mm-yyyy'), '7', '28', '362', '12', '2014', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5477, to_date('29-12-2014', 'dd-mm-yyyy'), '1', '29', '363', '12', '2014', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5478, to_date('30-12-2014', 'dd-mm-yyyy'), '2', '30', '364', '12', '2014', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5479, to_date('31-12-2014', 'dd-mm-yyyy'), '3', '31', '365', '12', '2014', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5480, to_date('01-01-2015', 'dd-mm-yyyy'), '4', '01', '001', '01', '2015', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5481, to_date('02-01-2015', 'dd-mm-yyyy'), '5', '02', '002', '01', '2015', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5482, to_date('03-01-2015', 'dd-mm-yyyy'), '6', '03', '003', '01', '2015', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5483, to_date('04-01-2015', 'dd-mm-yyyy'), '7', '04', '004', '01', '2015', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5484, to_date('05-01-2015', 'dd-mm-yyyy'), '1', '05', '005', '01', '2015', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5485, to_date('06-01-2015', 'dd-mm-yyyy'), '2', '06', '006', '01', '2015', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5486, to_date('07-01-2015', 'dd-mm-yyyy'), '3', '07', '007', '01', '2015', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5487, to_date('08-01-2015', 'dd-mm-yyyy'), '4', '08', '008', '01', '2015', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5488, to_date('09-01-2015', 'dd-mm-yyyy'), '5', '09', '009', '01', '2015', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5489, to_date('10-01-2015', 'dd-mm-yyyy'), '6', '10', '010', '01', '2015', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5490, to_date('11-01-2015', 'dd-mm-yyyy'), '7', '11', '011', '01', '2015', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5491, to_date('12-01-2015', 'dd-mm-yyyy'), '1', '12', '012', '01', '2015', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5492, to_date('13-01-2015', 'dd-mm-yyyy'), '2', '13', '013', '01', '2015', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5493, to_date('14-01-2015', 'dd-mm-yyyy'), '3', '14', '014', '01', '2015', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5494, to_date('15-01-2015', 'dd-mm-yyyy'), '4', '15', '015', '01', '2015', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5495, to_date('16-01-2015', 'dd-mm-yyyy'), '5', '16', '016', '01', '2015', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5496, to_date('17-01-2015', 'dd-mm-yyyy'), '6', '17', '017', '01', '2015', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5497, to_date('18-01-2015', 'dd-mm-yyyy'), '7', '18', '018', '01', '2015', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5498, to_date('19-01-2015', 'dd-mm-yyyy'), '1', '19', '019', '01', '2015', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5499, to_date('20-01-2015', 'dd-mm-yyyy'), '2', '20', '020', '01', '2015', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5500, to_date('21-01-2015', 'dd-mm-yyyy'), '3', '21', '021', '01', '2015', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5501, to_date('22-01-2015', 'dd-mm-yyyy'), '4', '22', '022', '01', '2015', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5502, to_date('23-01-2015', 'dd-mm-yyyy'), '5', '23', '023', '01', '2015', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5503, to_date('24-01-2015', 'dd-mm-yyyy'), '6', '24', '024', '01', '2015', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5504, to_date('25-01-2015', 'dd-mm-yyyy'), '7', '25', '025', '01', '2015', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5505, to_date('26-01-2015', 'dd-mm-yyyy'), '1', '26', '026', '01', '2015', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5506, to_date('27-01-2015', 'dd-mm-yyyy'), '2', '27', '027', '01', '2015', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5507, to_date('28-01-2015', 'dd-mm-yyyy'), '3', '28', '028', '01', '2015', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5508, to_date('29-01-2015', 'dd-mm-yyyy'), '4', '29', '029', '01', '2015', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (5509, to_date('30-01-2015', 'dd-mm-yyyy'), '5', '30', '030', '01', '2015', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6266, to_date('25-02-2017', 'dd-mm-yyyy'), '6', '25', '056', '02', '2017', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6267, to_date('26-02-2017', 'dd-mm-yyyy'), '7', '26', '057', '02', '2017', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6268, to_date('27-02-2017', 'dd-mm-yyyy'), '1', '27', '058', '02', '2017', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6269, to_date('28-02-2017', 'dd-mm-yyyy'), '2', '28', '059', '02', '2017', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6270, to_date('01-03-2017', 'dd-mm-yyyy'), '3', '01', '060', '03', '2017', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6271, to_date('02-03-2017', 'dd-mm-yyyy'), '4', '02', '061', '03', '2017', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6272, to_date('03-03-2017', 'dd-mm-yyyy'), '5', '03', '062', '03', '2017', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6273, to_date('04-03-2017', 'dd-mm-yyyy'), '6', '04', '063', '03', '2017', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6274, to_date('05-03-2017', 'dd-mm-yyyy'), '7', '05', '064', '03', '2017', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6275, to_date('06-03-2017', 'dd-mm-yyyy'), '1', '06', '065', '03', '2017', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6276, to_date('07-03-2017', 'dd-mm-yyyy'), '2', '07', '066', '03', '2017', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6277, to_date('08-03-2017', 'dd-mm-yyyy'), '3', '08', '067', '03', '2017', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6278, to_date('09-03-2017', 'dd-mm-yyyy'), '4', '09', '068', '03', '2017', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6279, to_date('10-03-2017', 'dd-mm-yyyy'), '5', '10', '069', '03', '2017', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6280, to_date('11-03-2017', 'dd-mm-yyyy'), '6', '11', '070', '03', '2017', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6281, to_date('12-03-2017', 'dd-mm-yyyy'), '7', '12', '071', '03', '2017', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6282, to_date('13-03-2017', 'dd-mm-yyyy'), '1', '13', '072', '03', '2017', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6283, to_date('14-03-2017', 'dd-mm-yyyy'), '2', '14', '073', '03', '2017', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6284, to_date('15-03-2017', 'dd-mm-yyyy'), '3', '15', '074', '03', '2017', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6285, to_date('16-03-2017', 'dd-mm-yyyy'), '4', '16', '075', '03', '2017', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6286, to_date('17-03-2017', 'dd-mm-yyyy'), '5', '17', '076', '03', '2017', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6287, to_date('18-03-2017', 'dd-mm-yyyy'), '6', '18', '077', '03', '2017', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6288, to_date('19-03-2017', 'dd-mm-yyyy'), '7', '19', '078', '03', '2017', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6289, to_date('20-03-2017', 'dd-mm-yyyy'), '1', '20', '079', '03', '2017', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6290, to_date('21-03-2017', 'dd-mm-yyyy'), '2', '21', '080', '03', '2017', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6291, to_date('22-03-2017', 'dd-mm-yyyy'), '3', '22', '081', '03', '2017', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6292, to_date('23-03-2017', 'dd-mm-yyyy'), '4', '23', '082', '03', '2017', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6293, to_date('24-03-2017', 'dd-mm-yyyy'), '5', '24', '083', '03', '2017', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6294, to_date('25-03-2017', 'dd-mm-yyyy'), '6', '25', '084', '03', '2017', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6295, to_date('26-03-2017', 'dd-mm-yyyy'), '7', '26', '085', '03', '2017', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6296, to_date('27-03-2017', 'dd-mm-yyyy'), '1', '27', '086', '03', '2017', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6297, to_date('28-03-2017', 'dd-mm-yyyy'), '2', '28', '087', '03', '2017', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6298, to_date('29-03-2017', 'dd-mm-yyyy'), '3', '29', '088', '03', '2017', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6299, to_date('30-03-2017', 'dd-mm-yyyy'), '4', '30', '089', '03', '2017', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6300, to_date('31-03-2017', 'dd-mm-yyyy'), '5', '31', '090', '03', '2017', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6301, to_date('01-04-2017', 'dd-mm-yyyy'), '6', '01', '091', '04', '2017', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6302, to_date('02-04-2017', 'dd-mm-yyyy'), '7', '02', '092', '04', '2017', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6303, to_date('03-04-2017', 'dd-mm-yyyy'), '1', '03', '093', '04', '2017', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6304, to_date('04-04-2017', 'dd-mm-yyyy'), '2', '04', '094', '04', '2017', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6305, to_date('05-04-2017', 'dd-mm-yyyy'), '3', '05', '095', '04', '2017', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6306, to_date('06-04-2017', 'dd-mm-yyyy'), '4', '06', '096', '04', '2017', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6307, to_date('07-04-2017', 'dd-mm-yyyy'), '5', '07', '097', '04', '2017', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6308, to_date('08-04-2017', 'dd-mm-yyyy'), '6', '08', '098', '04', '2017', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6309, to_date('09-04-2017', 'dd-mm-yyyy'), '7', '09', '099', '04', '2017', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6310, to_date('10-04-2017', 'dd-mm-yyyy'), '1', '10', '100', '04', '2017', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6311, to_date('11-04-2017', 'dd-mm-yyyy'), '2', '11', '101', '04', '2017', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6312, to_date('12-04-2017', 'dd-mm-yyyy'), '3', '12', '102', '04', '2017', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6313, to_date('13-04-2017', 'dd-mm-yyyy'), '4', '13', '103', '04', '2017', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6314, to_date('14-04-2017', 'dd-mm-yyyy'), '5', '14', '104', '04', '2017', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6315, to_date('15-04-2017', 'dd-mm-yyyy'), '6', '15', '105', '04', '2017', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6316, to_date('16-04-2017', 'dd-mm-yyyy'), '7', '16', '106', '04', '2017', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6317, to_date('17-04-2017', 'dd-mm-yyyy'), '1', '17', '107', '04', '2017', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6318, to_date('18-04-2017', 'dd-mm-yyyy'), '2', '18', '108', '04', '2017', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6319, to_date('19-04-2017', 'dd-mm-yyyy'), '3', '19', '109', '04', '2017', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6320, to_date('20-04-2017', 'dd-mm-yyyy'), '4', '20', '110', '04', '2017', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6321, to_date('21-04-2017', 'dd-mm-yyyy'), '5', '21', '111', '04', '2017', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6322, to_date('22-04-2017', 'dd-mm-yyyy'), '6', '22', '112', '04', '2017', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6323, to_date('23-04-2017', 'dd-mm-yyyy'), '7', '23', '113', '04', '2017', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6324, to_date('24-04-2017', 'dd-mm-yyyy'), '1', '24', '114', '04', '2017', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6325, to_date('25-04-2017', 'dd-mm-yyyy'), '2', '25', '115', '04', '2017', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6326, to_date('26-04-2017', 'dd-mm-yyyy'), '3', '26', '116', '04', '2017', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6327, to_date('27-04-2017', 'dd-mm-yyyy'), '4', '27', '117', '04', '2017', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6328, to_date('28-04-2017', 'dd-mm-yyyy'), '5', '28', '118', '04', '2017', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6329, to_date('29-04-2017', 'dd-mm-yyyy'), '6', '29', '119', '04', '2017', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6330, to_date('30-04-2017', 'dd-mm-yyyy'), '7', '30', '120', '04', '2017', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6331, to_date('01-05-2017', 'dd-mm-yyyy'), '1', '01', '121', '05', '2017', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6332, to_date('02-05-2017', 'dd-mm-yyyy'), '2', '02', '122', '05', '2017', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6333, to_date('03-05-2017', 'dd-mm-yyyy'), '3', '03', '123', '05', '2017', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6334, to_date('04-05-2017', 'dd-mm-yyyy'), '4', '04', '124', '05', '2017', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6335, to_date('05-05-2017', 'dd-mm-yyyy'), '5', '05', '125', '05', '2017', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6336, to_date('06-05-2017', 'dd-mm-yyyy'), '6', '06', '126', '05', '2017', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6337, to_date('07-05-2017', 'dd-mm-yyyy'), '7', '07', '127', '05', '2017', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6338, to_date('08-05-2017', 'dd-mm-yyyy'), '1', '08', '128', '05', '2017', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6339, to_date('09-05-2017', 'dd-mm-yyyy'), '2', '09', '129', '05', '2017', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6340, to_date('10-05-2017', 'dd-mm-yyyy'), '3', '10', '130', '05', '2017', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6341, to_date('11-05-2017', 'dd-mm-yyyy'), '4', '11', '131', '05', '2017', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6342, to_date('12-05-2017', 'dd-mm-yyyy'), '5', '12', '132', '05', '2017', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6343, to_date('13-05-2017', 'dd-mm-yyyy'), '6', '13', '133', '05', '2017', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6344, to_date('14-05-2017', 'dd-mm-yyyy'), '7', '14', '134', '05', '2017', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6345, to_date('15-05-2017', 'dd-mm-yyyy'), '1', '15', '135', '05', '2017', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6346, to_date('16-05-2017', 'dd-mm-yyyy'), '2', '16', '136', '05', '2017', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6347, to_date('17-05-2017', 'dd-mm-yyyy'), '3', '17', '137', '05', '2017', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6348, to_date('18-05-2017', 'dd-mm-yyyy'), '4', '18', '138', '05', '2017', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6349, to_date('19-05-2017', 'dd-mm-yyyy'), '5', '19', '139', '05', '2017', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6350, to_date('20-05-2017', 'dd-mm-yyyy'), '6', '20', '140', '05', '2017', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6351, to_date('21-05-2017', 'dd-mm-yyyy'), '7', '21', '141', '05', '2017', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6352, to_date('22-05-2017', 'dd-mm-yyyy'), '1', '22', '142', '05', '2017', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6353, to_date('23-05-2017', 'dd-mm-yyyy'), '2', '23', '143', '05', '2017', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6354, to_date('24-05-2017', 'dd-mm-yyyy'), '3', '24', '144', '05', '2017', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6355, to_date('25-05-2017', 'dd-mm-yyyy'), '4', '25', '145', '05', '2017', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6356, to_date('26-05-2017', 'dd-mm-yyyy'), '5', '26', '146', '05', '2017', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6357, to_date('27-05-2017', 'dd-mm-yyyy'), '6', '27', '147', '05', '2017', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6358, to_date('28-05-2017', 'dd-mm-yyyy'), '7', '28', '148', '05', '2017', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6359, to_date('29-05-2017', 'dd-mm-yyyy'), '1', '29', '149', '05', '2017', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6360, to_date('30-05-2017', 'dd-mm-yyyy'), '2', '30', '150', '05', '2017', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6361, to_date('31-05-2017', 'dd-mm-yyyy'), '3', '31', '151', '05', '2017', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6362, to_date('01-06-2017', 'dd-mm-yyyy'), '4', '01', '152', '06', '2017', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6363, to_date('02-06-2017', 'dd-mm-yyyy'), '5', '02', '153', '06', '2017', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6364, to_date('03-06-2017', 'dd-mm-yyyy'), '6', '03', '154', '06', '2017', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6365, to_date('04-06-2017', 'dd-mm-yyyy'), '7', '04', '155', '06', '2017', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6366, to_date('05-06-2017', 'dd-mm-yyyy'), '1', '05', '156', '06', '2017', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6367, to_date('06-06-2017', 'dd-mm-yyyy'), '2', '06', '157', '06', '2017', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6368, to_date('07-06-2017', 'dd-mm-yyyy'), '3', '07', '158', '06', '2017', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6369, to_date('08-06-2017', 'dd-mm-yyyy'), '4', '08', '159', '06', '2017', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6370, to_date('09-06-2017', 'dd-mm-yyyy'), '5', '09', '160', '06', '2017', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6371, to_date('10-06-2017', 'dd-mm-yyyy'), '6', '10', '161', '06', '2017', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6372, to_date('11-06-2017', 'dd-mm-yyyy'), '7', '11', '162', '06', '2017', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6373, to_date('12-06-2017', 'dd-mm-yyyy'), '1', '12', '163', '06', '2017', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6914, to_date('05-12-2018', 'dd-mm-yyyy'), '3', '05', '339', '12', '2018', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6915, to_date('06-12-2018', 'dd-mm-yyyy'), '4', '06', '340', '12', '2018', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6916, to_date('07-12-2018', 'dd-mm-yyyy'), '5', '07', '341', '12', '2018', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6917, to_date('08-12-2018', 'dd-mm-yyyy'), '6', '08', '342', '12', '2018', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6918, to_date('09-12-2018', 'dd-mm-yyyy'), '7', '09', '343', '12', '2018', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6919, to_date('10-12-2018', 'dd-mm-yyyy'), '1', '10', '344', '12', '2018', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6920, to_date('11-12-2018', 'dd-mm-yyyy'), '2', '11', '345', '12', '2018', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6921, to_date('12-12-2018', 'dd-mm-yyyy'), '3', '12', '346', '12', '2018', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6922, to_date('13-12-2018', 'dd-mm-yyyy'), '4', '13', '347', '12', '2018', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6923, to_date('14-12-2018', 'dd-mm-yyyy'), '5', '14', '348', '12', '2018', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6924, to_date('15-12-2018', 'dd-mm-yyyy'), '6', '15', '349', '12', '2018', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6925, to_date('16-12-2018', 'dd-mm-yyyy'), '7', '16', '350', '12', '2018', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6926, to_date('17-12-2018', 'dd-mm-yyyy'), '1', '17', '351', '12', '2018', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6927, to_date('18-12-2018', 'dd-mm-yyyy'), '2', '18', '352', '12', '2018', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6928, to_date('19-12-2018', 'dd-mm-yyyy'), '3', '19', '353', '12', '2018', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6929, to_date('20-12-2018', 'dd-mm-yyyy'), '4', '20', '354', '12', '2018', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6930, to_date('21-12-2018', 'dd-mm-yyyy'), '5', '21', '355', '12', '2018', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6931, to_date('22-12-2018', 'dd-mm-yyyy'), '6', '22', '356', '12', '2018', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6932, to_date('23-12-2018', 'dd-mm-yyyy'), '7', '23', '357', '12', '2018', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6933, to_date('24-12-2018', 'dd-mm-yyyy'), '1', '24', '358', '12', '2018', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6934, to_date('25-12-2018', 'dd-mm-yyyy'), '2', '25', '359', '12', '2018', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6935, to_date('26-12-2018', 'dd-mm-yyyy'), '3', '26', '360', '12', '2018', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6936, to_date('27-12-2018', 'dd-mm-yyyy'), '4', '27', '361', '12', '2018', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6937, to_date('28-12-2018', 'dd-mm-yyyy'), '5', '28', '362', '12', '2018', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6938, to_date('29-12-2018', 'dd-mm-yyyy'), '6', '29', '363', '12', '2018', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6939, to_date('30-12-2018', 'dd-mm-yyyy'), '7', '30', '364', '12', '2018', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6940, to_date('31-12-2018', 'dd-mm-yyyy'), '1', '31', '365', '12', '2018', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6941, to_date('01-01-2019', 'dd-mm-yyyy'), '2', '01', '001', '01', '2019', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6942, to_date('02-01-2019', 'dd-mm-yyyy'), '3', '02', '002', '01', '2019', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6943, to_date('03-01-2019', 'dd-mm-yyyy'), '4', '03', '003', '01', '2019', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6944, to_date('04-01-2019', 'dd-mm-yyyy'), '5', '04', '004', '01', '2019', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6945, to_date('05-01-2019', 'dd-mm-yyyy'), '6', '05', '005', '01', '2019', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6946, to_date('06-01-2019', 'dd-mm-yyyy'), '7', '06', '006', '01', '2019', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6947, to_date('07-01-2019', 'dd-mm-yyyy'), '1', '07', '007', '01', '2019', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6948, to_date('08-01-2019', 'dd-mm-yyyy'), '2', '08', '008', '01', '2019', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6949, to_date('09-01-2019', 'dd-mm-yyyy'), '3', '09', '009', '01', '2019', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6950, to_date('10-01-2019', 'dd-mm-yyyy'), '4', '10', '010', '01', '2019', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6951, to_date('11-01-2019', 'dd-mm-yyyy'), '5', '11', '011', '01', '2019', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6952, to_date('12-01-2019', 'dd-mm-yyyy'), '6', '12', '012', '01', '2019', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6953, to_date('13-01-2019', 'dd-mm-yyyy'), '7', '13', '013', '01', '2019', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6954, to_date('14-01-2019', 'dd-mm-yyyy'), '1', '14', '014', '01', '2019', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6955, to_date('15-01-2019', 'dd-mm-yyyy'), '2', '15', '015', '01', '2019', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6956, to_date('16-01-2019', 'dd-mm-yyyy'), '3', '16', '016', '01', '2019', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6957, to_date('17-01-2019', 'dd-mm-yyyy'), '4', '17', '017', '01', '2019', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6958, to_date('18-01-2019', 'dd-mm-yyyy'), '5', '18', '018', '01', '2019', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6959, to_date('19-01-2019', 'dd-mm-yyyy'), '6', '19', '019', '01', '2019', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6960, to_date('20-01-2019', 'dd-mm-yyyy'), '7', '20', '020', '01', '2019', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6961, to_date('21-01-2019', 'dd-mm-yyyy'), '1', '21', '021', '01', '2019', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6962, to_date('22-01-2019', 'dd-mm-yyyy'), '2', '22', '022', '01', '2019', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6963, to_date('23-01-2019', 'dd-mm-yyyy'), '3', '23', '023', '01', '2019', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6964, to_date('24-01-2019', 'dd-mm-yyyy'), '4', '24', '024', '01', '2019', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6965, to_date('25-01-2019', 'dd-mm-yyyy'), '5', '25', '025', '01', '2019', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6966, to_date('26-01-2019', 'dd-mm-yyyy'), '6', '26', '026', '01', '2019', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6967, to_date('27-01-2019', 'dd-mm-yyyy'), '7', '27', '027', '01', '2019', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6968, to_date('28-01-2019', 'dd-mm-yyyy'), '1', '28', '028', '01', '2019', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6969, to_date('29-01-2019', 'dd-mm-yyyy'), '2', '29', '029', '01', '2019', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6970, to_date('30-01-2019', 'dd-mm-yyyy'), '3', '30', '030', '01', '2019', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6971, to_date('31-01-2019', 'dd-mm-yyyy'), '4', '31', '031', '01', '2019', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6972, to_date('01-02-2019', 'dd-mm-yyyy'), '5', '01', '032', '02', '2019', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6973, to_date('02-02-2019', 'dd-mm-yyyy'), '6', '02', '033', '02', '2019', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6974, to_date('03-02-2019', 'dd-mm-yyyy'), '7', '03', '034', '02', '2019', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6975, to_date('04-02-2019', 'dd-mm-yyyy'), '1', '04', '035', '02', '2019', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6976, to_date('05-02-2019', 'dd-mm-yyyy'), '2', '05', '036', '02', '2019', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6977, to_date('06-02-2019', 'dd-mm-yyyy'), '3', '06', '037', '02', '2019', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6978, to_date('07-02-2019', 'dd-mm-yyyy'), '4', '07', '038', '02', '2019', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6979, to_date('08-02-2019', 'dd-mm-yyyy'), '5', '08', '039', '02', '2019', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6980, to_date('09-02-2019', 'dd-mm-yyyy'), '6', '09', '040', '02', '2019', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6981, to_date('10-02-2019', 'dd-mm-yyyy'), '7', '10', '041', '02', '2019', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6982, to_date('11-02-2019', 'dd-mm-yyyy'), '1', '11', '042', '02', '2019', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6983, to_date('12-02-2019', 'dd-mm-yyyy'), '2', '12', '043', '02', '2019', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6984, to_date('13-02-2019', 'dd-mm-yyyy'), '3', '13', '044', '02', '2019', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6985, to_date('14-02-2019', 'dd-mm-yyyy'), '4', '14', '045', '02', '2019', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6986, to_date('15-02-2019', 'dd-mm-yyyy'), '5', '15', '046', '02', '2019', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6987, to_date('16-02-2019', 'dd-mm-yyyy'), '6', '16', '047', '02', '2019', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6988, to_date('17-02-2019', 'dd-mm-yyyy'), '7', '17', '048', '02', '2019', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6989, to_date('18-02-2019', 'dd-mm-yyyy'), '1', '18', '049', '02', '2019', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6990, to_date('19-02-2019', 'dd-mm-yyyy'), '2', '19', '050', '02', '2019', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6991, to_date('20-02-2019', 'dd-mm-yyyy'), '3', '20', '051', '02', '2019', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6992, to_date('21-02-2019', 'dd-mm-yyyy'), '4', '21', '052', '02', '2019', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6993, to_date('22-02-2019', 'dd-mm-yyyy'), '5', '22', '053', '02', '2019', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6994, to_date('23-02-2019', 'dd-mm-yyyy'), '6', '23', '054', '02', '2019', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6995, to_date('24-02-2019', 'dd-mm-yyyy'), '7', '24', '055', '02', '2019', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6996, to_date('25-02-2019', 'dd-mm-yyyy'), '1', '25', '056', '02', '2019', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6997, to_date('26-02-2019', 'dd-mm-yyyy'), '2', '26', '057', '02', '2019', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6998, to_date('27-02-2019', 'dd-mm-yyyy'), '3', '27', '058', '02', '2019', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6999, to_date('28-02-2019', 'dd-mm-yyyy'), '4', '28', '059', '02', '2019', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7000, to_date('01-03-2019', 'dd-mm-yyyy'), '5', '01', '060', '03', '2019', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7001, to_date('02-03-2019', 'dd-mm-yyyy'), '6', '02', '061', '03', '2019', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7002, to_date('03-03-2019', 'dd-mm-yyyy'), '7', '03', '062', '03', '2019', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7003, to_date('04-03-2019', 'dd-mm-yyyy'), '1', '04', '063', '03', '2019', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7004, to_date('05-03-2019', 'dd-mm-yyyy'), '2', '05', '064', '03', '2019', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7005, to_date('06-03-2019', 'dd-mm-yyyy'), '3', '06', '065', '03', '2019', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7006, to_date('07-03-2019', 'dd-mm-yyyy'), '4', '07', '066', '03', '2019', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7007, to_date('08-03-2019', 'dd-mm-yyyy'), '5', '08', '067', '03', '2019', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7008, to_date('09-03-2019', 'dd-mm-yyyy'), '6', '09', '068', '03', '2019', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7009, to_date('10-03-2019', 'dd-mm-yyyy'), '7', '10', '069', '03', '2019', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7010, to_date('11-03-2019', 'dd-mm-yyyy'), '1', '11', '070', '03', '2019', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7011, to_date('12-03-2019', 'dd-mm-yyyy'), '2', '12', '071', '03', '2019', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7012, to_date('13-03-2019', 'dd-mm-yyyy'), '3', '13', '072', '03', '2019', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7013, to_date('14-03-2019', 'dd-mm-yyyy'), '4', '14', '073', '03', '2019', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7014, to_date('15-03-2019', 'dd-mm-yyyy'), '5', '15', '074', '03', '2019', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7015, to_date('16-03-2019', 'dd-mm-yyyy'), '6', '16', '075', '03', '2019', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7016, to_date('17-03-2019', 'dd-mm-yyyy'), '7', '17', '076', '03', '2019', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7017, to_date('18-03-2019', 'dd-mm-yyyy'), '1', '18', '077', '03', '2019', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7018, to_date('19-03-2019', 'dd-mm-yyyy'), '2', '19', '078', '03', '2019', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7019, to_date('20-03-2019', 'dd-mm-yyyy'), '3', '20', '079', '03', '2019', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7020, to_date('21-03-2019', 'dd-mm-yyyy'), '4', '21', '080', '03', '2019', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7021, to_date('22-03-2019', 'dd-mm-yyyy'), '5', '22', '081', '03', '2019', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6374, to_date('13-06-2017', 'dd-mm-yyyy'), '2', '13', '164', '06', '2017', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6375, to_date('14-06-2017', 'dd-mm-yyyy'), '3', '14', '165', '06', '2017', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6376, to_date('15-06-2017', 'dd-mm-yyyy'), '4', '15', '166', '06', '2017', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6377, to_date('16-06-2017', 'dd-mm-yyyy'), '5', '16', '167', '06', '2017', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6378, to_date('17-06-2017', 'dd-mm-yyyy'), '6', '17', '168', '06', '2017', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6379, to_date('18-06-2017', 'dd-mm-yyyy'), '7', '18', '169', '06', '2017', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6380, to_date('19-06-2017', 'dd-mm-yyyy'), '1', '19', '170', '06', '2017', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6381, to_date('20-06-2017', 'dd-mm-yyyy'), '2', '20', '171', '06', '2017', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6382, to_date('21-06-2017', 'dd-mm-yyyy'), '3', '21', '172', '06', '2017', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6383, to_date('22-06-2017', 'dd-mm-yyyy'), '4', '22', '173', '06', '2017', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6384, to_date('23-06-2017', 'dd-mm-yyyy'), '5', '23', '174', '06', '2017', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6385, to_date('24-06-2017', 'dd-mm-yyyy'), '6', '24', '175', '06', '2017', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6386, to_date('25-06-2017', 'dd-mm-yyyy'), '7', '25', '176', '06', '2017', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6387, to_date('26-06-2017', 'dd-mm-yyyy'), '1', '26', '177', '06', '2017', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6388, to_date('27-06-2017', 'dd-mm-yyyy'), '2', '27', '178', '06', '2017', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6389, to_date('28-06-2017', 'dd-mm-yyyy'), '3', '28', '179', '06', '2017', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6390, to_date('29-06-2017', 'dd-mm-yyyy'), '4', '29', '180', '06', '2017', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6391, to_date('30-06-2017', 'dd-mm-yyyy'), '5', '30', '181', '06', '2017', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6392, to_date('01-07-2017', 'dd-mm-yyyy'), '6', '01', '182', '07', '2017', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6393, to_date('02-07-2017', 'dd-mm-yyyy'), '7', '02', '183', '07', '2017', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6394, to_date('03-07-2017', 'dd-mm-yyyy'), '1', '03', '184', '07', '2017', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6395, to_date('04-07-2017', 'dd-mm-yyyy'), '2', '04', '185', '07', '2017', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6396, to_date('05-07-2017', 'dd-mm-yyyy'), '3', '05', '186', '07', '2017', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6397, to_date('06-07-2017', 'dd-mm-yyyy'), '4', '06', '187', '07', '2017', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6398, to_date('07-07-2017', 'dd-mm-yyyy'), '5', '07', '188', '07', '2017', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6399, to_date('08-07-2017', 'dd-mm-yyyy'), '6', '08', '189', '07', '2017', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6400, to_date('09-07-2017', 'dd-mm-yyyy'), '7', '09', '190', '07', '2017', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6401, to_date('10-07-2017', 'dd-mm-yyyy'), '1', '10', '191', '07', '2017', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6402, to_date('11-07-2017', 'dd-mm-yyyy'), '2', '11', '192', '07', '2017', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6403, to_date('12-07-2017', 'dd-mm-yyyy'), '3', '12', '193', '07', '2017', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6404, to_date('13-07-2017', 'dd-mm-yyyy'), '4', '13', '194', '07', '2017', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6405, to_date('14-07-2017', 'dd-mm-yyyy'), '5', '14', '195', '07', '2017', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6406, to_date('15-07-2017', 'dd-mm-yyyy'), '6', '15', '196', '07', '2017', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6407, to_date('16-07-2017', 'dd-mm-yyyy'), '7', '16', '197', '07', '2017', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6408, to_date('17-07-2017', 'dd-mm-yyyy'), '1', '17', '198', '07', '2017', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6409, to_date('18-07-2017', 'dd-mm-yyyy'), '2', '18', '199', '07', '2017', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6410, to_date('19-07-2017', 'dd-mm-yyyy'), '3', '19', '200', '07', '2017', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6411, to_date('20-07-2017', 'dd-mm-yyyy'), '4', '20', '201', '07', '2017', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6412, to_date('21-07-2017', 'dd-mm-yyyy'), '5', '21', '202', '07', '2017', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6413, to_date('22-07-2017', 'dd-mm-yyyy'), '6', '22', '203', '07', '2017', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6414, to_date('23-07-2017', 'dd-mm-yyyy'), '7', '23', '204', '07', '2017', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6415, to_date('24-07-2017', 'dd-mm-yyyy'), '1', '24', '205', '07', '2017', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6416, to_date('25-07-2017', 'dd-mm-yyyy'), '2', '25', '206', '07', '2017', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6417, to_date('26-07-2017', 'dd-mm-yyyy'), '3', '26', '207', '07', '2017', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6418, to_date('27-07-2017', 'dd-mm-yyyy'), '4', '27', '208', '07', '2017', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6419, to_date('28-07-2017', 'dd-mm-yyyy'), '5', '28', '209', '07', '2017', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6420, to_date('29-07-2017', 'dd-mm-yyyy'), '6', '29', '210', '07', '2017', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6421, to_date('30-07-2017', 'dd-mm-yyyy'), '7', '30', '211', '07', '2017', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6422, to_date('31-07-2017', 'dd-mm-yyyy'), '1', '31', '212', '07', '2017', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6423, to_date('01-08-2017', 'dd-mm-yyyy'), '2', '01', '213', '08', '2017', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6424, to_date('02-08-2017', 'dd-mm-yyyy'), '3', '02', '214', '08', '2017', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6425, to_date('03-08-2017', 'dd-mm-yyyy'), '4', '03', '215', '08', '2017', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6426, to_date('04-08-2017', 'dd-mm-yyyy'), '5', '04', '216', '08', '2017', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6427, to_date('05-08-2017', 'dd-mm-yyyy'), '6', '05', '217', '08', '2017', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6428, to_date('06-08-2017', 'dd-mm-yyyy'), '7', '06', '218', '08', '2017', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6429, to_date('07-08-2017', 'dd-mm-yyyy'), '1', '07', '219', '08', '2017', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6430, to_date('08-08-2017', 'dd-mm-yyyy'), '2', '08', '220', '08', '2017', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6431, to_date('09-08-2017', 'dd-mm-yyyy'), '3', '09', '221', '08', '2017', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6432, to_date('10-08-2017', 'dd-mm-yyyy'), '4', '10', '222', '08', '2017', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6433, to_date('11-08-2017', 'dd-mm-yyyy'), '5', '11', '223', '08', '2017', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6434, to_date('12-08-2017', 'dd-mm-yyyy'), '6', '12', '224', '08', '2017', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6435, to_date('13-08-2017', 'dd-mm-yyyy'), '7', '13', '225', '08', '2017', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6436, to_date('14-08-2017', 'dd-mm-yyyy'), '1', '14', '226', '08', '2017', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6437, to_date('15-08-2017', 'dd-mm-yyyy'), '2', '15', '227', '08', '2017', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6438, to_date('16-08-2017', 'dd-mm-yyyy'), '3', '16', '228', '08', '2017', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6439, to_date('17-08-2017', 'dd-mm-yyyy'), '4', '17', '229', '08', '2017', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6440, to_date('18-08-2017', 'dd-mm-yyyy'), '5', '18', '230', '08', '2017', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6441, to_date('19-08-2017', 'dd-mm-yyyy'), '6', '19', '231', '08', '2017', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6442, to_date('20-08-2017', 'dd-mm-yyyy'), '7', '20', '232', '08', '2017', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6443, to_date('21-08-2017', 'dd-mm-yyyy'), '1', '21', '233', '08', '2017', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6444, to_date('22-08-2017', 'dd-mm-yyyy'), '2', '22', '234', '08', '2017', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6445, to_date('23-08-2017', 'dd-mm-yyyy'), '3', '23', '235', '08', '2017', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6446, to_date('24-08-2017', 'dd-mm-yyyy'), '4', '24', '236', '08', '2017', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6447, to_date('25-08-2017', 'dd-mm-yyyy'), '5', '25', '237', '08', '2017', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6448, to_date('26-08-2017', 'dd-mm-yyyy'), '6', '26', '238', '08', '2017', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6449, to_date('27-08-2017', 'dd-mm-yyyy'), '7', '27', '239', '08', '2017', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6450, to_date('28-08-2017', 'dd-mm-yyyy'), '1', '28', '240', '08', '2017', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6451, to_date('29-08-2017', 'dd-mm-yyyy'), '2', '29', '241', '08', '2017', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6452, to_date('30-08-2017', 'dd-mm-yyyy'), '3', '30', '242', '08', '2017', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6453, to_date('31-08-2017', 'dd-mm-yyyy'), '4', '31', '243', '08', '2017', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6454, to_date('01-09-2017', 'dd-mm-yyyy'), '5', '01', '244', '09', '2017', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6455, to_date('02-09-2017', 'dd-mm-yyyy'), '6', '02', '245', '09', '2017', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6456, to_date('03-09-2017', 'dd-mm-yyyy'), '7', '03', '246', '09', '2017', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6457, to_date('04-09-2017', 'dd-mm-yyyy'), '1', '04', '247', '09', '2017', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6458, to_date('05-09-2017', 'dd-mm-yyyy'), '2', '05', '248', '09', '2017', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6459, to_date('06-09-2017', 'dd-mm-yyyy'), '3', '06', '249', '09', '2017', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6460, to_date('07-09-2017', 'dd-mm-yyyy'), '4', '07', '250', '09', '2017', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6461, to_date('08-09-2017', 'dd-mm-yyyy'), '5', '08', '251', '09', '2017', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6462, to_date('09-09-2017', 'dd-mm-yyyy'), '6', '09', '252', '09', '2017', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6463, to_date('10-09-2017', 'dd-mm-yyyy'), '7', '10', '253', '09', '2017', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6464, to_date('11-09-2017', 'dd-mm-yyyy'), '1', '11', '254', '09', '2017', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6465, to_date('12-09-2017', 'dd-mm-yyyy'), '2', '12', '255', '09', '2017', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6466, to_date('13-09-2017', 'dd-mm-yyyy'), '3', '13', '256', '09', '2017', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6467, to_date('14-09-2017', 'dd-mm-yyyy'), '4', '14', '257', '09', '2017', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6468, to_date('15-09-2017', 'dd-mm-yyyy'), '5', '15', '258', '09', '2017', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6469, to_date('16-09-2017', 'dd-mm-yyyy'), '6', '16', '259', '09', '2017', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6470, to_date('17-09-2017', 'dd-mm-yyyy'), '7', '17', '260', '09', '2017', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6471, to_date('18-09-2017', 'dd-mm-yyyy'), '1', '18', '261', '09', '2017', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6472, to_date('19-09-2017', 'dd-mm-yyyy'), '2', '19', '262', '09', '2017', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6473, to_date('20-09-2017', 'dd-mm-yyyy'), '3', '20', '263', '09', '2017', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6474, to_date('21-09-2017', 'dd-mm-yyyy'), '4', '21', '264', '09', '2017', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6475, to_date('22-09-2017', 'dd-mm-yyyy'), '5', '22', '265', '09', '2017', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6476, to_date('23-09-2017', 'dd-mm-yyyy'), '6', '23', '266', '09', '2017', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6477, to_date('24-09-2017', 'dd-mm-yyyy'), '7', '24', '267', '09', '2017', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6478, to_date('25-09-2017', 'dd-mm-yyyy'), '1', '25', '268', '09', '2017', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6479, to_date('26-09-2017', 'dd-mm-yyyy'), '2', '26', '269', '09', '2017', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6480, to_date('27-09-2017', 'dd-mm-yyyy'), '3', '27', '270', '09', '2017', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6481, to_date('28-09-2017', 'dd-mm-yyyy'), '4', '28', '271', '09', '2017', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6482, to_date('29-09-2017', 'dd-mm-yyyy'), '5', '29', '272', '09', '2017', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6483, to_date('30-09-2017', 'dd-mm-yyyy'), '6', '30', '273', '09', '2017', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6484, to_date('01-10-2017', 'dd-mm-yyyy'), '7', '01', '274', '10', '2017', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6485, to_date('02-10-2017', 'dd-mm-yyyy'), '1', '02', '275', '10', '2017', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6486, to_date('03-10-2017', 'dd-mm-yyyy'), '2', '03', '276', '10', '2017', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6487, to_date('04-10-2017', 'dd-mm-yyyy'), '3', '04', '277', '10', '2017', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6488, to_date('05-10-2017', 'dd-mm-yyyy'), '4', '05', '278', '10', '2017', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6489, to_date('06-10-2017', 'dd-mm-yyyy'), '5', '06', '279', '10', '2017', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6490, to_date('07-10-2017', 'dd-mm-yyyy'), '6', '07', '280', '10', '2017', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6491, to_date('08-10-2017', 'dd-mm-yyyy'), '7', '08', '281', '10', '2017', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6492, to_date('09-10-2017', 'dd-mm-yyyy'), '1', '09', '282', '10', '2017', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6493, to_date('10-10-2017', 'dd-mm-yyyy'), '2', '10', '283', '10', '2017', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6494, to_date('11-10-2017', 'dd-mm-yyyy'), '3', '11', '284', '10', '2017', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6495, to_date('12-10-2017', 'dd-mm-yyyy'), '4', '12', '285', '10', '2017', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6496, to_date('13-10-2017', 'dd-mm-yyyy'), '5', '13', '286', '10', '2017', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6497, to_date('14-10-2017', 'dd-mm-yyyy'), '6', '14', '287', '10', '2017', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6498, to_date('15-10-2017', 'dd-mm-yyyy'), '7', '15', '288', '10', '2017', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6499, to_date('16-10-2017', 'dd-mm-yyyy'), '1', '16', '289', '10', '2017', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6500, to_date('17-10-2017', 'dd-mm-yyyy'), '2', '17', '290', '10', '2017', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6501, to_date('18-10-2017', 'dd-mm-yyyy'), '3', '18', '291', '10', '2017', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6502, to_date('19-10-2017', 'dd-mm-yyyy'), '4', '19', '292', '10', '2017', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6503, to_date('20-10-2017', 'dd-mm-yyyy'), '5', '20', '293', '10', '2017', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6504, to_date('21-10-2017', 'dd-mm-yyyy'), '6', '21', '294', '10', '2017', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6505, to_date('22-10-2017', 'dd-mm-yyyy'), '7', '22', '295', '10', '2017', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6506, to_date('23-10-2017', 'dd-mm-yyyy'), '1', '23', '296', '10', '2017', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6507, to_date('24-10-2017', 'dd-mm-yyyy'), '2', '24', '297', '10', '2017', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6508, to_date('25-10-2017', 'dd-mm-yyyy'), '3', '25', '298', '10', '2017', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6509, to_date('26-10-2017', 'dd-mm-yyyy'), '4', '26', '299', '10', '2017', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6510, to_date('27-10-2017', 'dd-mm-yyyy'), '5', '27', '300', '10', '2017', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6511, to_date('28-10-2017', 'dd-mm-yyyy'), '6', '28', '301', '10', '2017', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6512, to_date('29-10-2017', 'dd-mm-yyyy'), '7', '29', '302', '10', '2017', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6513, to_date('30-10-2017', 'dd-mm-yyyy'), '1', '30', '303', '10', '2017', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6514, to_date('31-10-2017', 'dd-mm-yyyy'), '2', '31', '304', '10', '2017', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6515, to_date('01-11-2017', 'dd-mm-yyyy'), '3', '01', '305', '11', '2017', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6516, to_date('02-11-2017', 'dd-mm-yyyy'), '4', '02', '306', '11', '2017', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6517, to_date('03-11-2017', 'dd-mm-yyyy'), '5', '03', '307', '11', '2017', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6518, to_date('04-11-2017', 'dd-mm-yyyy'), '6', '04', '308', '11', '2017', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6519, to_date('05-11-2017', 'dd-mm-yyyy'), '7', '05', '309', '11', '2017', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6520, to_date('06-11-2017', 'dd-mm-yyyy'), '1', '06', '310', '11', '2017', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6521, to_date('07-11-2017', 'dd-mm-yyyy'), '2', '07', '311', '11', '2017', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6522, to_date('08-11-2017', 'dd-mm-yyyy'), '3', '08', '312', '11', '2017', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6523, to_date('09-11-2017', 'dd-mm-yyyy'), '4', '09', '313', '11', '2017', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6524, to_date('10-11-2017', 'dd-mm-yyyy'), '5', '10', '314', '11', '2017', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6525, to_date('11-11-2017', 'dd-mm-yyyy'), '6', '11', '315', '11', '2017', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6526, to_date('12-11-2017', 'dd-mm-yyyy'), '7', '12', '316', '11', '2017', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6527, to_date('13-11-2017', 'dd-mm-yyyy'), '1', '13', '317', '11', '2017', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6528, to_date('14-11-2017', 'dd-mm-yyyy'), '2', '14', '318', '11', '2017', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6529, to_date('15-11-2017', 'dd-mm-yyyy'), '3', '15', '319', '11', '2017', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6530, to_date('16-11-2017', 'dd-mm-yyyy'), '4', '16', '320', '11', '2017', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6531, to_date('17-11-2017', 'dd-mm-yyyy'), '5', '17', '321', '11', '2017', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6532, to_date('18-11-2017', 'dd-mm-yyyy'), '6', '18', '322', '11', '2017', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6533, to_date('19-11-2017', 'dd-mm-yyyy'), '7', '19', '323', '11', '2017', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6534, to_date('20-11-2017', 'dd-mm-yyyy'), '1', '20', '324', '11', '2017', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6535, to_date('21-11-2017', 'dd-mm-yyyy'), '2', '21', '325', '11', '2017', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6536, to_date('22-11-2017', 'dd-mm-yyyy'), '3', '22', '326', '11', '2017', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6537, to_date('23-11-2017', 'dd-mm-yyyy'), '4', '23', '327', '11', '2017', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6538, to_date('24-11-2017', 'dd-mm-yyyy'), '5', '24', '328', '11', '2017', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6539, to_date('25-11-2017', 'dd-mm-yyyy'), '6', '25', '329', '11', '2017', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6540, to_date('26-11-2017', 'dd-mm-yyyy'), '7', '26', '330', '11', '2017', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6541, to_date('27-11-2017', 'dd-mm-yyyy'), '1', '27', '331', '11', '2017', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6542, to_date('28-11-2017', 'dd-mm-yyyy'), '2', '28', '332', '11', '2017', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6543, to_date('29-11-2017', 'dd-mm-yyyy'), '3', '29', '333', '11', '2017', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6544, to_date('30-11-2017', 'dd-mm-yyyy'), '4', '30', '334', '11', '2017', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6545, to_date('01-12-2017', 'dd-mm-yyyy'), '5', '01', '335', '12', '2017', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6546, to_date('02-12-2017', 'dd-mm-yyyy'), '6', '02', '336', '12', '2017', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6547, to_date('03-12-2017', 'dd-mm-yyyy'), '7', '03', '337', '12', '2017', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6548, to_date('04-12-2017', 'dd-mm-yyyy'), '1', '04', '338', '12', '2017', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6549, to_date('05-12-2017', 'dd-mm-yyyy'), '2', '05', '339', '12', '2017', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6550, to_date('06-12-2017', 'dd-mm-yyyy'), '3', '06', '340', '12', '2017', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6551, to_date('07-12-2017', 'dd-mm-yyyy'), '4', '07', '341', '12', '2017', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6552, to_date('08-12-2017', 'dd-mm-yyyy'), '5', '08', '342', '12', '2017', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6553, to_date('09-12-2017', 'dd-mm-yyyy'), '6', '09', '343', '12', '2017', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6554, to_date('10-12-2017', 'dd-mm-yyyy'), '7', '10', '344', '12', '2017', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6555, to_date('11-12-2017', 'dd-mm-yyyy'), '1', '11', '345', '12', '2017', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6556, to_date('12-12-2017', 'dd-mm-yyyy'), '2', '12', '346', '12', '2017', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6557, to_date('13-12-2017', 'dd-mm-yyyy'), '3', '13', '347', '12', '2017', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6558, to_date('14-12-2017', 'dd-mm-yyyy'), '4', '14', '348', '12', '2017', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6559, to_date('15-12-2017', 'dd-mm-yyyy'), '5', '15', '349', '12', '2017', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6560, to_date('16-12-2017', 'dd-mm-yyyy'), '6', '16', '350', '12', '2017', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6561, to_date('17-12-2017', 'dd-mm-yyyy'), '7', '17', '351', '12', '2017', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6562, to_date('18-12-2017', 'dd-mm-yyyy'), '1', '18', '352', '12', '2017', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6563, to_date('19-12-2017', 'dd-mm-yyyy'), '2', '19', '353', '12', '2017', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6564, to_date('20-12-2017', 'dd-mm-yyyy'), '3', '20', '354', '12', '2017', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6565, to_date('21-12-2017', 'dd-mm-yyyy'), '4', '21', '355', '12', '2017', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6566, to_date('22-12-2017', 'dd-mm-yyyy'), '5', '22', '356', '12', '2017', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6567, to_date('23-12-2017', 'dd-mm-yyyy'), '6', '23', '357', '12', '2017', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6568, to_date('24-12-2017', 'dd-mm-yyyy'), '7', '24', '358', '12', '2017', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6569, to_date('25-12-2017', 'dd-mm-yyyy'), '1', '25', '359', '12', '2017', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6570, to_date('26-12-2017', 'dd-mm-yyyy'), '2', '26', '360', '12', '2017', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6571, to_date('27-12-2017', 'dd-mm-yyyy'), '3', '27', '361', '12', '2017', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6572, to_date('28-12-2017', 'dd-mm-yyyy'), '4', '28', '362', '12', '2017', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6573, to_date('29-12-2017', 'dd-mm-yyyy'), '5', '29', '363', '12', '2017', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6574, to_date('30-12-2017', 'dd-mm-yyyy'), '6', '30', '364', '12', '2017', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6575, to_date('31-12-2017', 'dd-mm-yyyy'), '7', '31', '365', '12', '2017', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6576, to_date('01-01-2018', 'dd-mm-yyyy'), '1', '01', '001', '01', '2018', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6577, to_date('02-01-2018', 'dd-mm-yyyy'), '2', '02', '002', '01', '2018', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6578, to_date('03-01-2018', 'dd-mm-yyyy'), '3', '03', '003', '01', '2018', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6579, to_date('04-01-2018', 'dd-mm-yyyy'), '4', '04', '004', '01', '2018', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6580, to_date('05-01-2018', 'dd-mm-yyyy'), '5', '05', '005', '01', '2018', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6581, to_date('06-01-2018', 'dd-mm-yyyy'), '6', '06', '006', '01', '2018', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6582, to_date('07-01-2018', 'dd-mm-yyyy'), '7', '07', '007', '01', '2018', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6583, to_date('08-01-2018', 'dd-mm-yyyy'), '1', '08', '008', '01', '2018', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6584, to_date('09-01-2018', 'dd-mm-yyyy'), '2', '09', '009', '01', '2018', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6585, to_date('10-01-2018', 'dd-mm-yyyy'), '3', '10', '010', '01', '2018', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6586, to_date('11-01-2018', 'dd-mm-yyyy'), '4', '11', '011', '01', '2018', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6587, to_date('12-01-2018', 'dd-mm-yyyy'), '5', '12', '012', '01', '2018', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6588, to_date('13-01-2018', 'dd-mm-yyyy'), '6', '13', '013', '01', '2018', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6589, to_date('14-01-2018', 'dd-mm-yyyy'), '7', '14', '014', '01', '2018', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6590, to_date('15-01-2018', 'dd-mm-yyyy'), '1', '15', '015', '01', '2018', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6591, to_date('16-01-2018', 'dd-mm-yyyy'), '2', '16', '016', '01', '2018', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6592, to_date('17-01-2018', 'dd-mm-yyyy'), '3', '17', '017', '01', '2018', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6593, to_date('18-01-2018', 'dd-mm-yyyy'), '4', '18', '018', '01', '2018', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6594, to_date('19-01-2018', 'dd-mm-yyyy'), '5', '19', '019', '01', '2018', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6595, to_date('20-01-2018', 'dd-mm-yyyy'), '6', '20', '020', '01', '2018', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6596, to_date('21-01-2018', 'dd-mm-yyyy'), '7', '21', '021', '01', '2018', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6597, to_date('22-01-2018', 'dd-mm-yyyy'), '1', '22', '022', '01', '2018', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6598, to_date('23-01-2018', 'dd-mm-yyyy'), '2', '23', '023', '01', '2018', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6599, to_date('24-01-2018', 'dd-mm-yyyy'), '3', '24', '024', '01', '2018', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6600, to_date('25-01-2018', 'dd-mm-yyyy'), '4', '25', '025', '01', '2018', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6601, to_date('26-01-2018', 'dd-mm-yyyy'), '5', '26', '026', '01', '2018', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6602, to_date('27-01-2018', 'dd-mm-yyyy'), '6', '27', '027', '01', '2018', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6603, to_date('28-01-2018', 'dd-mm-yyyy'), '7', '28', '028', '01', '2018', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6604, to_date('29-01-2018', 'dd-mm-yyyy'), '1', '29', '029', '01', '2018', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6605, to_date('30-01-2018', 'dd-mm-yyyy'), '2', '30', '030', '01', '2018', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6606, to_date('31-01-2018', 'dd-mm-yyyy'), '3', '31', '031', '01', '2018', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6607, to_date('01-02-2018', 'dd-mm-yyyy'), '4', '01', '032', '02', '2018', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6608, to_date('02-02-2018', 'dd-mm-yyyy'), '5', '02', '033', '02', '2018', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6609, to_date('03-02-2018', 'dd-mm-yyyy'), '6', '03', '034', '02', '2018', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6610, to_date('04-02-2018', 'dd-mm-yyyy'), '7', '04', '035', '02', '2018', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6611, to_date('05-02-2018', 'dd-mm-yyyy'), '1', '05', '036', '02', '2018', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6612, to_date('06-02-2018', 'dd-mm-yyyy'), '2', '06', '037', '02', '2018', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6613, to_date('07-02-2018', 'dd-mm-yyyy'), '3', '07', '038', '02', '2018', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6614, to_date('08-02-2018', 'dd-mm-yyyy'), '4', '08', '039', '02', '2018', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6615, to_date('09-02-2018', 'dd-mm-yyyy'), '5', '09', '040', '02', '2018', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6616, to_date('10-02-2018', 'dd-mm-yyyy'), '6', '10', '041', '02', '2018', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6617, to_date('11-02-2018', 'dd-mm-yyyy'), '7', '11', '042', '02', '2018', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6618, to_date('12-02-2018', 'dd-mm-yyyy'), '1', '12', '043', '02', '2018', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6619, to_date('13-02-2018', 'dd-mm-yyyy'), '2', '13', '044', '02', '2018', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6620, to_date('14-02-2018', 'dd-mm-yyyy'), '3', '14', '045', '02', '2018', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6621, to_date('15-02-2018', 'dd-mm-yyyy'), '4', '15', '046', '02', '2018', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6622, to_date('16-02-2018', 'dd-mm-yyyy'), '5', '16', '047', '02', '2018', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6623, to_date('17-02-2018', 'dd-mm-yyyy'), '6', '17', '048', '02', '2018', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6624, to_date('18-02-2018', 'dd-mm-yyyy'), '7', '18', '049', '02', '2018', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6625, to_date('19-02-2018', 'dd-mm-yyyy'), '1', '19', '050', '02', '2018', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6626, to_date('20-02-2018', 'dd-mm-yyyy'), '2', '20', '051', '02', '2018', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6627, to_date('21-02-2018', 'dd-mm-yyyy'), '3', '21', '052', '02', '2018', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6628, to_date('22-02-2018', 'dd-mm-yyyy'), '4', '22', '053', '02', '2018', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6629, to_date('23-02-2018', 'dd-mm-yyyy'), '5', '23', '054', '02', '2018', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6630, to_date('24-02-2018', 'dd-mm-yyyy'), '6', '24', '055', '02', '2018', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6631, to_date('25-02-2018', 'dd-mm-yyyy'), '7', '25', '056', '02', '2018', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6632, to_date('26-02-2018', 'dd-mm-yyyy'), '1', '26', '057', '02', '2018', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6633, to_date('27-02-2018', 'dd-mm-yyyy'), '2', '27', '058', '02', '2018', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6634, to_date('28-02-2018', 'dd-mm-yyyy'), '3', '28', '059', '02', '2018', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6635, to_date('01-03-2018', 'dd-mm-yyyy'), '4', '01', '060', '03', '2018', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6636, to_date('02-03-2018', 'dd-mm-yyyy'), '5', '02', '061', '03', '2018', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6637, to_date('03-03-2018', 'dd-mm-yyyy'), '6', '03', '062', '03', '2018', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6638, to_date('04-03-2018', 'dd-mm-yyyy'), '7', '04', '063', '03', '2018', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6639, to_date('05-03-2018', 'dd-mm-yyyy'), '1', '05', '064', '03', '2018', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6640, to_date('06-03-2018', 'dd-mm-yyyy'), '2', '06', '065', '03', '2018', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6641, to_date('07-03-2018', 'dd-mm-yyyy'), '3', '07', '066', '03', '2018', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6642, to_date('08-03-2018', 'dd-mm-yyyy'), '4', '08', '067', '03', '2018', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6643, to_date('09-03-2018', 'dd-mm-yyyy'), '5', '09', '068', '03', '2018', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6644, to_date('10-03-2018', 'dd-mm-yyyy'), '6', '10', '069', '03', '2018', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6645, to_date('11-03-2018', 'dd-mm-yyyy'), '7', '11', '070', '03', '2018', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6646, to_date('12-03-2018', 'dd-mm-yyyy'), '1', '12', '071', '03', '2018', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6647, to_date('13-03-2018', 'dd-mm-yyyy'), '2', '13', '072', '03', '2018', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6648, to_date('14-03-2018', 'dd-mm-yyyy'), '3', '14', '073', '03', '2018', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6649, to_date('15-03-2018', 'dd-mm-yyyy'), '4', '15', '074', '03', '2018', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6650, to_date('16-03-2018', 'dd-mm-yyyy'), '5', '16', '075', '03', '2018', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6651, to_date('17-03-2018', 'dd-mm-yyyy'), '6', '17', '076', '03', '2018', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6652, to_date('18-03-2018', 'dd-mm-yyyy'), '7', '18', '077', '03', '2018', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6653, to_date('19-03-2018', 'dd-mm-yyyy'), '1', '19', '078', '03', '2018', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6654, to_date('20-03-2018', 'dd-mm-yyyy'), '2', '20', '079', '03', '2018', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6655, to_date('21-03-2018', 'dd-mm-yyyy'), '3', '21', '080', '03', '2018', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6656, to_date('22-03-2018', 'dd-mm-yyyy'), '4', '22', '081', '03', '2018', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6657, to_date('23-03-2018', 'dd-mm-yyyy'), '5', '23', '082', '03', '2018', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6658, to_date('24-03-2018', 'dd-mm-yyyy'), '6', '24', '083', '03', '2018', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6659, to_date('25-03-2018', 'dd-mm-yyyy'), '7', '25', '084', '03', '2018', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6660, to_date('26-03-2018', 'dd-mm-yyyy'), '1', '26', '085', '03', '2018', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6661, to_date('27-03-2018', 'dd-mm-yyyy'), '2', '27', '086', '03', '2018', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6662, to_date('28-03-2018', 'dd-mm-yyyy'), '3', '28', '087', '03', '2018', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6663, to_date('29-03-2018', 'dd-mm-yyyy'), '4', '29', '088', '03', '2018', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6664, to_date('30-03-2018', 'dd-mm-yyyy'), '5', '30', '089', '03', '2018', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6665, to_date('31-03-2018', 'dd-mm-yyyy'), '6', '31', '090', '03', '2018', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6666, to_date('01-04-2018', 'dd-mm-yyyy'), '7', '01', '091', '04', '2018', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6667, to_date('02-04-2018', 'dd-mm-yyyy'), '1', '02', '092', '04', '2018', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6668, to_date('03-04-2018', 'dd-mm-yyyy'), '2', '03', '093', '04', '2018', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6669, to_date('04-04-2018', 'dd-mm-yyyy'), '3', '04', '094', '04', '2018', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6670, to_date('05-04-2018', 'dd-mm-yyyy'), '4', '05', '095', '04', '2018', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6671, to_date('06-04-2018', 'dd-mm-yyyy'), '5', '06', '096', '04', '2018', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6672, to_date('07-04-2018', 'dd-mm-yyyy'), '6', '07', '097', '04', '2018', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6673, to_date('08-04-2018', 'dd-mm-yyyy'), '7', '08', '098', '04', '2018', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6674, to_date('09-04-2018', 'dd-mm-yyyy'), '1', '09', '099', '04', '2018', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6675, to_date('10-04-2018', 'dd-mm-yyyy'), '2', '10', '100', '04', '2018', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6676, to_date('11-04-2018', 'dd-mm-yyyy'), '3', '11', '101', '04', '2018', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6677, to_date('12-04-2018', 'dd-mm-yyyy'), '4', '12', '102', '04', '2018', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6678, to_date('13-04-2018', 'dd-mm-yyyy'), '5', '13', '103', '04', '2018', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6679, to_date('14-04-2018', 'dd-mm-yyyy'), '6', '14', '104', '04', '2018', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6680, to_date('15-04-2018', 'dd-mm-yyyy'), '7', '15', '105', '04', '2018', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6681, to_date('16-04-2018', 'dd-mm-yyyy'), '1', '16', '106', '04', '2018', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6682, to_date('17-04-2018', 'dd-mm-yyyy'), '2', '17', '107', '04', '2018', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6683, to_date('18-04-2018', 'dd-mm-yyyy'), '3', '18', '108', '04', '2018', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6684, to_date('19-04-2018', 'dd-mm-yyyy'), '4', '19', '109', '04', '2018', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6685, to_date('20-04-2018', 'dd-mm-yyyy'), '5', '20', '110', '04', '2018', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6686, to_date('21-04-2018', 'dd-mm-yyyy'), '6', '21', '111', '04', '2018', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6687, to_date('22-04-2018', 'dd-mm-yyyy'), '7', '22', '112', '04', '2018', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6688, to_date('23-04-2018', 'dd-mm-yyyy'), '1', '23', '113', '04', '2018', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6689, to_date('24-04-2018', 'dd-mm-yyyy'), '2', '24', '114', '04', '2018', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6690, to_date('25-04-2018', 'dd-mm-yyyy'), '3', '25', '115', '04', '2018', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6691, to_date('26-04-2018', 'dd-mm-yyyy'), '4', '26', '116', '04', '2018', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6692, to_date('27-04-2018', 'dd-mm-yyyy'), '5', '27', '117', '04', '2018', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6693, to_date('28-04-2018', 'dd-mm-yyyy'), '6', '28', '118', '04', '2018', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6694, to_date('29-04-2018', 'dd-mm-yyyy'), '7', '29', '119', '04', '2018', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6695, to_date('30-04-2018', 'dd-mm-yyyy'), '1', '30', '120', '04', '2018', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6696, to_date('01-05-2018', 'dd-mm-yyyy'), '2', '01', '121', '05', '2018', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6697, to_date('02-05-2018', 'dd-mm-yyyy'), '3', '02', '122', '05', '2018', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6698, to_date('03-05-2018', 'dd-mm-yyyy'), '4', '03', '123', '05', '2018', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6699, to_date('04-05-2018', 'dd-mm-yyyy'), '5', '04', '124', '05', '2018', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6700, to_date('05-05-2018', 'dd-mm-yyyy'), '6', '05', '125', '05', '2018', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6701, to_date('06-05-2018', 'dd-mm-yyyy'), '7', '06', '126', '05', '2018', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6702, to_date('07-05-2018', 'dd-mm-yyyy'), '1', '07', '127', '05', '2018', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6703, to_date('08-05-2018', 'dd-mm-yyyy'), '2', '08', '128', '05', '2018', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6704, to_date('09-05-2018', 'dd-mm-yyyy'), '3', '09', '129', '05', '2018', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6705, to_date('10-05-2018', 'dd-mm-yyyy'), '4', '10', '130', '05', '2018', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6706, to_date('11-05-2018', 'dd-mm-yyyy'), '5', '11', '131', '05', '2018', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6707, to_date('12-05-2018', 'dd-mm-yyyy'), '6', '12', '132', '05', '2018', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6708, to_date('13-05-2018', 'dd-mm-yyyy'), '7', '13', '133', '05', '2018', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6709, to_date('14-05-2018', 'dd-mm-yyyy'), '1', '14', '134', '05', '2018', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6710, to_date('15-05-2018', 'dd-mm-yyyy'), '2', '15', '135', '05', '2018', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6711, to_date('16-05-2018', 'dd-mm-yyyy'), '3', '16', '136', '05', '2018', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6712, to_date('17-05-2018', 'dd-mm-yyyy'), '4', '17', '137', '05', '2018', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6713, to_date('18-05-2018', 'dd-mm-yyyy'), '5', '18', '138', '05', '2018', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6714, to_date('19-05-2018', 'dd-mm-yyyy'), '6', '19', '139', '05', '2018', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6715, to_date('20-05-2018', 'dd-mm-yyyy'), '7', '20', '140', '05', '2018', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6716, to_date('21-05-2018', 'dd-mm-yyyy'), '1', '21', '141', '05', '2018', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6717, to_date('22-05-2018', 'dd-mm-yyyy'), '2', '22', '142', '05', '2018', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6718, to_date('23-05-2018', 'dd-mm-yyyy'), '3', '23', '143', '05', '2018', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6719, to_date('24-05-2018', 'dd-mm-yyyy'), '4', '24', '144', '05', '2018', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6720, to_date('25-05-2018', 'dd-mm-yyyy'), '5', '25', '145', '05', '2018', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6721, to_date('26-05-2018', 'dd-mm-yyyy'), '6', '26', '146', '05', '2018', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6722, to_date('27-05-2018', 'dd-mm-yyyy'), '7', '27', '147', '05', '2018', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6723, to_date('28-05-2018', 'dd-mm-yyyy'), '1', '28', '148', '05', '2018', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6724, to_date('29-05-2018', 'dd-mm-yyyy'), '2', '29', '149', '05', '2018', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6725, to_date('30-05-2018', 'dd-mm-yyyy'), '3', '30', '150', '05', '2018', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6726, to_date('31-05-2018', 'dd-mm-yyyy'), '4', '31', '151', '05', '2018', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6727, to_date('01-06-2018', 'dd-mm-yyyy'), '5', '01', '152', '06', '2018', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6728, to_date('02-06-2018', 'dd-mm-yyyy'), '6', '02', '153', '06', '2018', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6729, to_date('03-06-2018', 'dd-mm-yyyy'), '7', '03', '154', '06', '2018', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6730, to_date('04-06-2018', 'dd-mm-yyyy'), '1', '04', '155', '06', '2018', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6731, to_date('05-06-2018', 'dd-mm-yyyy'), '2', '05', '156', '06', '2018', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6732, to_date('06-06-2018', 'dd-mm-yyyy'), '3', '06', '157', '06', '2018', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6733, to_date('07-06-2018', 'dd-mm-yyyy'), '4', '07', '158', '06', '2018', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6734, to_date('08-06-2018', 'dd-mm-yyyy'), '5', '08', '159', '06', '2018', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6735, to_date('09-06-2018', 'dd-mm-yyyy'), '6', '09', '160', '06', '2018', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6736, to_date('10-06-2018', 'dd-mm-yyyy'), '7', '10', '161', '06', '2018', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6737, to_date('11-06-2018', 'dd-mm-yyyy'), '1', '11', '162', '06', '2018', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6738, to_date('12-06-2018', 'dd-mm-yyyy'), '2', '12', '163', '06', '2018', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6739, to_date('13-06-2018', 'dd-mm-yyyy'), '3', '13', '164', '06', '2018', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6740, to_date('14-06-2018', 'dd-mm-yyyy'), '4', '14', '165', '06', '2018', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6741, to_date('15-06-2018', 'dd-mm-yyyy'), '5', '15', '166', '06', '2018', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6742, to_date('16-06-2018', 'dd-mm-yyyy'), '6', '16', '167', '06', '2018', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6743, to_date('17-06-2018', 'dd-mm-yyyy'), '7', '17', '168', '06', '2018', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6744, to_date('18-06-2018', 'dd-mm-yyyy'), '1', '18', '169', '06', '2018', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6745, to_date('19-06-2018', 'dd-mm-yyyy'), '2', '19', '170', '06', '2018', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6746, to_date('20-06-2018', 'dd-mm-yyyy'), '3', '20', '171', '06', '2018', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6747, to_date('21-06-2018', 'dd-mm-yyyy'), '4', '21', '172', '06', '2018', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6748, to_date('22-06-2018', 'dd-mm-yyyy'), '5', '22', '173', '06', '2018', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6749, to_date('23-06-2018', 'dd-mm-yyyy'), '6', '23', '174', '06', '2018', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6750, to_date('24-06-2018', 'dd-mm-yyyy'), '7', '24', '175', '06', '2018', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6751, to_date('25-06-2018', 'dd-mm-yyyy'), '1', '25', '176', '06', '2018', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6752, to_date('26-06-2018', 'dd-mm-yyyy'), '2', '26', '177', '06', '2018', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6753, to_date('27-06-2018', 'dd-mm-yyyy'), '3', '27', '178', '06', '2018', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6754, to_date('28-06-2018', 'dd-mm-yyyy'), '4', '28', '179', '06', '2018', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6755, to_date('29-06-2018', 'dd-mm-yyyy'), '5', '29', '180', '06', '2018', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6756, to_date('30-06-2018', 'dd-mm-yyyy'), '6', '30', '181', '06', '2018', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6757, to_date('01-07-2018', 'dd-mm-yyyy'), '7', '01', '182', '07', '2018', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6758, to_date('02-07-2018', 'dd-mm-yyyy'), '1', '02', '183', '07', '2018', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6759, to_date('03-07-2018', 'dd-mm-yyyy'), '2', '03', '184', '07', '2018', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6760, to_date('04-07-2018', 'dd-mm-yyyy'), '3', '04', '185', '07', '2018', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6761, to_date('05-07-2018', 'dd-mm-yyyy'), '4', '05', '186', '07', '2018', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6762, to_date('06-07-2018', 'dd-mm-yyyy'), '5', '06', '187', '07', '2018', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6763, to_date('07-07-2018', 'dd-mm-yyyy'), '6', '07', '188', '07', '2018', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6764, to_date('08-07-2018', 'dd-mm-yyyy'), '7', '08', '189', '07', '2018', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6765, to_date('09-07-2018', 'dd-mm-yyyy'), '1', '09', '190', '07', '2018', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6766, to_date('10-07-2018', 'dd-mm-yyyy'), '2', '10', '191', '07', '2018', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6767, to_date('11-07-2018', 'dd-mm-yyyy'), '3', '11', '192', '07', '2018', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6768, to_date('12-07-2018', 'dd-mm-yyyy'), '4', '12', '193', '07', '2018', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6769, to_date('13-07-2018', 'dd-mm-yyyy'), '5', '13', '194', '07', '2018', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6770, to_date('14-07-2018', 'dd-mm-yyyy'), '6', '14', '195', '07', '2018', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6771, to_date('15-07-2018', 'dd-mm-yyyy'), '7', '15', '196', '07', '2018', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6772, to_date('16-07-2018', 'dd-mm-yyyy'), '1', '16', '197', '07', '2018', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6773, to_date('17-07-2018', 'dd-mm-yyyy'), '2', '17', '198', '07', '2018', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6774, to_date('18-07-2018', 'dd-mm-yyyy'), '3', '18', '199', '07', '2018', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6775, to_date('19-07-2018', 'dd-mm-yyyy'), '4', '19', '200', '07', '2018', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6776, to_date('20-07-2018', 'dd-mm-yyyy'), '5', '20', '201', '07', '2018', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6777, to_date('21-07-2018', 'dd-mm-yyyy'), '6', '21', '202', '07', '2018', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6778, to_date('22-07-2018', 'dd-mm-yyyy'), '7', '22', '203', '07', '2018', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6779, to_date('23-07-2018', 'dd-mm-yyyy'), '1', '23', '204', '07', '2018', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6780, to_date('24-07-2018', 'dd-mm-yyyy'), '2', '24', '205', '07', '2018', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6781, to_date('25-07-2018', 'dd-mm-yyyy'), '3', '25', '206', '07', '2018', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6782, to_date('26-07-2018', 'dd-mm-yyyy'), '4', '26', '207', '07', '2018', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6783, to_date('27-07-2018', 'dd-mm-yyyy'), '5', '27', '208', '07', '2018', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6784, to_date('28-07-2018', 'dd-mm-yyyy'), '6', '28', '209', '07', '2018', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6785, to_date('29-07-2018', 'dd-mm-yyyy'), '7', '29', '210', '07', '2018', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6786, to_date('30-07-2018', 'dd-mm-yyyy'), '1', '30', '211', '07', '2018', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6787, to_date('31-07-2018', 'dd-mm-yyyy'), '2', '31', '212', '07', '2018', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6788, to_date('01-08-2018', 'dd-mm-yyyy'), '3', '01', '213', '08', '2018', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6789, to_date('02-08-2018', 'dd-mm-yyyy'), '4', '02', '214', '08', '2018', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6790, to_date('03-08-2018', 'dd-mm-yyyy'), '5', '03', '215', '08', '2018', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6791, to_date('04-08-2018', 'dd-mm-yyyy'), '6', '04', '216', '08', '2018', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6792, to_date('05-08-2018', 'dd-mm-yyyy'), '7', '05', '217', '08', '2018', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6793, to_date('06-08-2018', 'dd-mm-yyyy'), '1', '06', '218', '08', '2018', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6794, to_date('07-08-2018', 'dd-mm-yyyy'), '2', '07', '219', '08', '2018', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6795, to_date('08-08-2018', 'dd-mm-yyyy'), '3', '08', '220', '08', '2018', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6796, to_date('09-08-2018', 'dd-mm-yyyy'), '4', '09', '221', '08', '2018', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6797, to_date('10-08-2018', 'dd-mm-yyyy'), '5', '10', '222', '08', '2018', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6798, to_date('11-08-2018', 'dd-mm-yyyy'), '6', '11', '223', '08', '2018', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6799, to_date('12-08-2018', 'dd-mm-yyyy'), '7', '12', '224', '08', '2018', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6800, to_date('13-08-2018', 'dd-mm-yyyy'), '1', '13', '225', '08', '2018', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6801, to_date('14-08-2018', 'dd-mm-yyyy'), '2', '14', '226', '08', '2018', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6802, to_date('15-08-2018', 'dd-mm-yyyy'), '3', '15', '227', '08', '2018', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6803, to_date('16-08-2018', 'dd-mm-yyyy'), '4', '16', '228', '08', '2018', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6804, to_date('17-08-2018', 'dd-mm-yyyy'), '5', '17', '229', '08', '2018', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6805, to_date('18-08-2018', 'dd-mm-yyyy'), '6', '18', '230', '08', '2018', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6806, to_date('19-08-2018', 'dd-mm-yyyy'), '7', '19', '231', '08', '2018', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6807, to_date('20-08-2018', 'dd-mm-yyyy'), '1', '20', '232', '08', '2018', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6808, to_date('21-08-2018', 'dd-mm-yyyy'), '2', '21', '233', '08', '2018', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6809, to_date('22-08-2018', 'dd-mm-yyyy'), '3', '22', '234', '08', '2018', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6810, to_date('23-08-2018', 'dd-mm-yyyy'), '4', '23', '235', '08', '2018', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6811, to_date('24-08-2018', 'dd-mm-yyyy'), '5', '24', '236', '08', '2018', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6812, to_date('25-08-2018', 'dd-mm-yyyy'), '6', '25', '237', '08', '2018', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6813, to_date('26-08-2018', 'dd-mm-yyyy'), '7', '26', '238', '08', '2018', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6814, to_date('27-08-2018', 'dd-mm-yyyy'), '1', '27', '239', '08', '2018', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6815, to_date('28-08-2018', 'dd-mm-yyyy'), '2', '28', '240', '08', '2018', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6816, to_date('29-08-2018', 'dd-mm-yyyy'), '3', '29', '241', '08', '2018', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6817, to_date('30-08-2018', 'dd-mm-yyyy'), '4', '30', '242', '08', '2018', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6818, to_date('31-08-2018', 'dd-mm-yyyy'), '5', '31', '243', '08', '2018', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6819, to_date('01-09-2018', 'dd-mm-yyyy'), '6', '01', '244', '09', '2018', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6820, to_date('02-09-2018', 'dd-mm-yyyy'), '7', '02', '245', '09', '2018', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6821, to_date('03-09-2018', 'dd-mm-yyyy'), '1', '03', '246', '09', '2018', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6822, to_date('04-09-2018', 'dd-mm-yyyy'), '2', '04', '247', '09', '2018', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6823, to_date('05-09-2018', 'dd-mm-yyyy'), '3', '05', '248', '09', '2018', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6824, to_date('06-09-2018', 'dd-mm-yyyy'), '4', '06', '249', '09', '2018', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6825, to_date('07-09-2018', 'dd-mm-yyyy'), '5', '07', '250', '09', '2018', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6826, to_date('08-09-2018', 'dd-mm-yyyy'), '6', '08', '251', '09', '2018', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6827, to_date('09-09-2018', 'dd-mm-yyyy'), '7', '09', '252', '09', '2018', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6828, to_date('10-09-2018', 'dd-mm-yyyy'), '1', '10', '253', '09', '2018', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6829, to_date('11-09-2018', 'dd-mm-yyyy'), '2', '11', '254', '09', '2018', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6830, to_date('12-09-2018', 'dd-mm-yyyy'), '3', '12', '255', '09', '2018', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6831, to_date('13-09-2018', 'dd-mm-yyyy'), '4', '13', '256', '09', '2018', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6832, to_date('14-09-2018', 'dd-mm-yyyy'), '5', '14', '257', '09', '2018', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6833, to_date('15-09-2018', 'dd-mm-yyyy'), '6', '15', '258', '09', '2018', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6834, to_date('16-09-2018', 'dd-mm-yyyy'), '7', '16', '259', '09', '2018', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6835, to_date('17-09-2018', 'dd-mm-yyyy'), '1', '17', '260', '09', '2018', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6836, to_date('18-09-2018', 'dd-mm-yyyy'), '2', '18', '261', '09', '2018', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6837, to_date('19-09-2018', 'dd-mm-yyyy'), '3', '19', '262', '09', '2018', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6838, to_date('20-09-2018', 'dd-mm-yyyy'), '4', '20', '263', '09', '2018', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6839, to_date('21-09-2018', 'dd-mm-yyyy'), '5', '21', '264', '09', '2018', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6840, to_date('22-09-2018', 'dd-mm-yyyy'), '6', '22', '265', '09', '2018', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6841, to_date('23-09-2018', 'dd-mm-yyyy'), '7', '23', '266', '09', '2018', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6842, to_date('24-09-2018', 'dd-mm-yyyy'), '1', '24', '267', '09', '2018', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6843, to_date('25-09-2018', 'dd-mm-yyyy'), '2', '25', '268', '09', '2018', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6844, to_date('26-09-2018', 'dd-mm-yyyy'), '3', '26', '269', '09', '2018', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6845, to_date('27-09-2018', 'dd-mm-yyyy'), '4', '27', '270', '09', '2018', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6846, to_date('28-09-2018', 'dd-mm-yyyy'), '5', '28', '271', '09', '2018', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6847, to_date('29-09-2018', 'dd-mm-yyyy'), '6', '29', '272', '09', '2018', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6848, to_date('30-09-2018', 'dd-mm-yyyy'), '7', '30', '273', '09', '2018', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6849, to_date('01-10-2018', 'dd-mm-yyyy'), '1', '01', '274', '10', '2018', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6850, to_date('02-10-2018', 'dd-mm-yyyy'), '2', '02', '275', '10', '2018', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6851, to_date('03-10-2018', 'dd-mm-yyyy'), '3', '03', '276', '10', '2018', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6852, to_date('04-10-2018', 'dd-mm-yyyy'), '4', '04', '277', '10', '2018', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6853, to_date('05-10-2018', 'dd-mm-yyyy'), '5', '05', '278', '10', '2018', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6854, to_date('06-10-2018', 'dd-mm-yyyy'), '6', '06', '279', '10', '2018', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6855, to_date('07-10-2018', 'dd-mm-yyyy'), '7', '07', '280', '10', '2018', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6856, to_date('08-10-2018', 'dd-mm-yyyy'), '1', '08', '281', '10', '2018', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6857, to_date('09-10-2018', 'dd-mm-yyyy'), '2', '09', '282', '10', '2018', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6858, to_date('10-10-2018', 'dd-mm-yyyy'), '3', '10', '283', '10', '2018', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6859, to_date('11-10-2018', 'dd-mm-yyyy'), '4', '11', '284', '10', '2018', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6860, to_date('12-10-2018', 'dd-mm-yyyy'), '5', '12', '285', '10', '2018', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6861, to_date('13-10-2018', 'dd-mm-yyyy'), '6', '13', '286', '10', '2018', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6862, to_date('14-10-2018', 'dd-mm-yyyy'), '7', '14', '287', '10', '2018', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6863, to_date('15-10-2018', 'dd-mm-yyyy'), '1', '15', '288', '10', '2018', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6864, to_date('16-10-2018', 'dd-mm-yyyy'), '2', '16', '289', '10', '2018', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6865, to_date('17-10-2018', 'dd-mm-yyyy'), '3', '17', '290', '10', '2018', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6866, to_date('18-10-2018', 'dd-mm-yyyy'), '4', '18', '291', '10', '2018', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6867, to_date('19-10-2018', 'dd-mm-yyyy'), '5', '19', '292', '10', '2018', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6868, to_date('20-10-2018', 'dd-mm-yyyy'), '6', '20', '293', '10', '2018', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6869, to_date('21-10-2018', 'dd-mm-yyyy'), '7', '21', '294', '10', '2018', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6870, to_date('22-10-2018', 'dd-mm-yyyy'), '1', '22', '295', '10', '2018', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6871, to_date('23-10-2018', 'dd-mm-yyyy'), '2', '23', '296', '10', '2018', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6872, to_date('24-10-2018', 'dd-mm-yyyy'), '3', '24', '297', '10', '2018', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6873, to_date('25-10-2018', 'dd-mm-yyyy'), '4', '25', '298', '10', '2018', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6874, to_date('26-10-2018', 'dd-mm-yyyy'), '5', '26', '299', '10', '2018', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6875, to_date('27-10-2018', 'dd-mm-yyyy'), '6', '27', '300', '10', '2018', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6876, to_date('28-10-2018', 'dd-mm-yyyy'), '7', '28', '301', '10', '2018', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6877, to_date('29-10-2018', 'dd-mm-yyyy'), '1', '29', '302', '10', '2018', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6878, to_date('30-10-2018', 'dd-mm-yyyy'), '2', '30', '303', '10', '2018', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6879, to_date('31-10-2018', 'dd-mm-yyyy'), '3', '31', '304', '10', '2018', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6880, to_date('01-11-2018', 'dd-mm-yyyy'), '4', '01', '305', '11', '2018', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6881, to_date('02-11-2018', 'dd-mm-yyyy'), '5', '02', '306', '11', '2018', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6882, to_date('03-11-2018', 'dd-mm-yyyy'), '6', '03', '307', '11', '2018', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6883, to_date('04-11-2018', 'dd-mm-yyyy'), '7', '04', '308', '11', '2018', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6884, to_date('05-11-2018', 'dd-mm-yyyy'), '1', '05', '309', '11', '2018', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6885, to_date('06-11-2018', 'dd-mm-yyyy'), '2', '06', '310', '11', '2018', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6886, to_date('07-11-2018', 'dd-mm-yyyy'), '3', '07', '311', '11', '2018', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6887, to_date('08-11-2018', 'dd-mm-yyyy'), '4', '08', '312', '11', '2018', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6888, to_date('09-11-2018', 'dd-mm-yyyy'), '5', '09', '313', '11', '2018', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6889, to_date('10-11-2018', 'dd-mm-yyyy'), '6', '10', '314', '11', '2018', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6890, to_date('11-11-2018', 'dd-mm-yyyy'), '7', '11', '315', '11', '2018', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6891, to_date('12-11-2018', 'dd-mm-yyyy'), '1', '12', '316', '11', '2018', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6892, to_date('13-11-2018', 'dd-mm-yyyy'), '2', '13', '317', '11', '2018', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
commit;
prompt 7000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6893, to_date('14-11-2018', 'dd-mm-yyyy'), '3', '14', '318', '11', '2018', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6894, to_date('15-11-2018', 'dd-mm-yyyy'), '4', '15', '319', '11', '2018', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6895, to_date('16-11-2018', 'dd-mm-yyyy'), '5', '16', '320', '11', '2018', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6896, to_date('17-11-2018', 'dd-mm-yyyy'), '6', '17', '321', '11', '2018', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6897, to_date('18-11-2018', 'dd-mm-yyyy'), '7', '18', '322', '11', '2018', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6898, to_date('19-11-2018', 'dd-mm-yyyy'), '1', '19', '323', '11', '2018', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6899, to_date('20-11-2018', 'dd-mm-yyyy'), '2', '20', '324', '11', '2018', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6900, to_date('21-11-2018', 'dd-mm-yyyy'), '3', '21', '325', '11', '2018', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6901, to_date('22-11-2018', 'dd-mm-yyyy'), '4', '22', '326', '11', '2018', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6902, to_date('23-11-2018', 'dd-mm-yyyy'), '5', '23', '327', '11', '2018', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6903, to_date('24-11-2018', 'dd-mm-yyyy'), '6', '24', '328', '11', '2018', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6904, to_date('25-11-2018', 'dd-mm-yyyy'), '7', '25', '329', '11', '2018', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6905, to_date('26-11-2018', 'dd-mm-yyyy'), '1', '26', '330', '11', '2018', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6906, to_date('27-11-2018', 'dd-mm-yyyy'), '2', '27', '331', '11', '2018', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6907, to_date('28-11-2018', 'dd-mm-yyyy'), '3', '28', '332', '11', '2018', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6908, to_date('29-11-2018', 'dd-mm-yyyy'), '4', '29', '333', '11', '2018', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6909, to_date('30-11-2018', 'dd-mm-yyyy'), '5', '30', '334', '11', '2018', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6910, to_date('01-12-2018', 'dd-mm-yyyy'), '6', '01', '335', '12', '2018', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6911, to_date('02-12-2018', 'dd-mm-yyyy'), '7', '02', '336', '12', '2018', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6912, to_date('03-12-2018', 'dd-mm-yyyy'), '1', '03', '337', '12', '2018', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (6913, to_date('04-12-2018', 'dd-mm-yyyy'), '2', '04', '338', '12', '2018', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7130, to_date('09-07-2019', 'dd-mm-yyyy'), '2', '09', '190', '07', '2019', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7131, to_date('10-07-2019', 'dd-mm-yyyy'), '3', '10', '191', '07', '2019', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7132, to_date('11-07-2019', 'dd-mm-yyyy'), '4', '11', '192', '07', '2019', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7133, to_date('12-07-2019', 'dd-mm-yyyy'), '5', '12', '193', '07', '2019', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7134, to_date('13-07-2019', 'dd-mm-yyyy'), '6', '13', '194', '07', '2019', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7135, to_date('14-07-2019', 'dd-mm-yyyy'), '7', '14', '195', '07', '2019', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7136, to_date('15-07-2019', 'dd-mm-yyyy'), '1', '15', '196', '07', '2019', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7137, to_date('16-07-2019', 'dd-mm-yyyy'), '2', '16', '197', '07', '2019', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7138, to_date('17-07-2019', 'dd-mm-yyyy'), '3', '17', '198', '07', '2019', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7139, to_date('18-07-2019', 'dd-mm-yyyy'), '4', '18', '199', '07', '2019', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7140, to_date('19-07-2019', 'dd-mm-yyyy'), '5', '19', '200', '07', '2019', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7141, to_date('20-07-2019', 'dd-mm-yyyy'), '6', '20', '201', '07', '2019', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7142, to_date('21-07-2019', 'dd-mm-yyyy'), '7', '21', '202', '07', '2019', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7143, to_date('22-07-2019', 'dd-mm-yyyy'), '1', '22', '203', '07', '2019', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7144, to_date('23-07-2019', 'dd-mm-yyyy'), '2', '23', '204', '07', '2019', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7145, to_date('24-07-2019', 'dd-mm-yyyy'), '3', '24', '205', '07', '2019', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7146, to_date('25-07-2019', 'dd-mm-yyyy'), '4', '25', '206', '07', '2019', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7147, to_date('26-07-2019', 'dd-mm-yyyy'), '5', '26', '207', '07', '2019', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7148, to_date('27-07-2019', 'dd-mm-yyyy'), '6', '27', '208', '07', '2019', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7149, to_date('28-07-2019', 'dd-mm-yyyy'), '7', '28', '209', '07', '2019', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7150, to_date('29-07-2019', 'dd-mm-yyyy'), '1', '29', '210', '07', '2019', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7151, to_date('30-07-2019', 'dd-mm-yyyy'), '2', '30', '211', '07', '2019', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7152, to_date('31-07-2019', 'dd-mm-yyyy'), '3', '31', '212', '07', '2019', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7153, to_date('01-08-2019', 'dd-mm-yyyy'), '4', '01', '213', '08', '2019', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7154, to_date('02-08-2019', 'dd-mm-yyyy'), '5', '02', '214', '08', '2019', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7155, to_date('03-08-2019', 'dd-mm-yyyy'), '6', '03', '215', '08', '2019', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7156, to_date('04-08-2019', 'dd-mm-yyyy'), '7', '04', '216', '08', '2019', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7157, to_date('05-08-2019', 'dd-mm-yyyy'), '1', '05', '217', '08', '2019', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7158, to_date('06-08-2019', 'dd-mm-yyyy'), '2', '06', '218', '08', '2019', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7159, to_date('07-08-2019', 'dd-mm-yyyy'), '3', '07', '219', '08', '2019', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7160, to_date('08-08-2019', 'dd-mm-yyyy'), '4', '08', '220', '08', '2019', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7161, to_date('09-08-2019', 'dd-mm-yyyy'), '5', '09', '221', '08', '2019', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7162, to_date('10-08-2019', 'dd-mm-yyyy'), '6', '10', '222', '08', '2019', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7163, to_date('11-08-2019', 'dd-mm-yyyy'), '7', '11', '223', '08', '2019', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7164, to_date('12-08-2019', 'dd-mm-yyyy'), '1', '12', '224', '08', '2019', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7165, to_date('13-08-2019', 'dd-mm-yyyy'), '2', '13', '225', '08', '2019', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7166, to_date('14-08-2019', 'dd-mm-yyyy'), '3', '14', '226', '08', '2019', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7167, to_date('15-08-2019', 'dd-mm-yyyy'), '4', '15', '227', '08', '2019', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7168, to_date('16-08-2019', 'dd-mm-yyyy'), '5', '16', '228', '08', '2019', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7169, to_date('17-08-2019', 'dd-mm-yyyy'), '6', '17', '229', '08', '2019', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7170, to_date('18-08-2019', 'dd-mm-yyyy'), '7', '18', '230', '08', '2019', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7171, to_date('19-08-2019', 'dd-mm-yyyy'), '1', '19', '231', '08', '2019', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7172, to_date('20-08-2019', 'dd-mm-yyyy'), '2', '20', '232', '08', '2019', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7173, to_date('21-08-2019', 'dd-mm-yyyy'), '3', '21', '233', '08', '2019', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7174, to_date('22-08-2019', 'dd-mm-yyyy'), '4', '22', '234', '08', '2019', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7175, to_date('23-08-2019', 'dd-mm-yyyy'), '5', '23', '235', '08', '2019', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7176, to_date('24-08-2019', 'dd-mm-yyyy'), '6', '24', '236', '08', '2019', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7177, to_date('25-08-2019', 'dd-mm-yyyy'), '7', '25', '237', '08', '2019', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7178, to_date('26-08-2019', 'dd-mm-yyyy'), '1', '26', '238', '08', '2019', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7179, to_date('27-08-2019', 'dd-mm-yyyy'), '2', '27', '239', '08', '2019', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7180, to_date('28-08-2019', 'dd-mm-yyyy'), '3', '28', '240', '08', '2019', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7181, to_date('29-08-2019', 'dd-mm-yyyy'), '4', '29', '241', '08', '2019', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7182, to_date('30-08-2019', 'dd-mm-yyyy'), '5', '30', '242', '08', '2019', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7183, to_date('31-08-2019', 'dd-mm-yyyy'), '6', '31', '243', '08', '2019', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7184, to_date('01-09-2019', 'dd-mm-yyyy'), '7', '01', '244', '09', '2019', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7185, to_date('02-09-2019', 'dd-mm-yyyy'), '1', '02', '245', '09', '2019', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7186, to_date('03-09-2019', 'dd-mm-yyyy'), '2', '03', '246', '09', '2019', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7187, to_date('04-09-2019', 'dd-mm-yyyy'), '3', '04', '247', '09', '2019', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7188, to_date('05-09-2019', 'dd-mm-yyyy'), '4', '05', '248', '09', '2019', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7189, to_date('06-09-2019', 'dd-mm-yyyy'), '5', '06', '249', '09', '2019', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7190, to_date('07-09-2019', 'dd-mm-yyyy'), '6', '07', '250', '09', '2019', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7191, to_date('08-09-2019', 'dd-mm-yyyy'), '7', '08', '251', '09', '2019', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7192, to_date('09-09-2019', 'dd-mm-yyyy'), '1', '09', '252', '09', '2019', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7193, to_date('10-09-2019', 'dd-mm-yyyy'), '2', '10', '253', '09', '2019', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7194, to_date('11-09-2019', 'dd-mm-yyyy'), '3', '11', '254', '09', '2019', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7195, to_date('12-09-2019', 'dd-mm-yyyy'), '4', '12', '255', '09', '2019', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7196, to_date('13-09-2019', 'dd-mm-yyyy'), '5', '13', '256', '09', '2019', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7197, to_date('14-09-2019', 'dd-mm-yyyy'), '6', '14', '257', '09', '2019', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7198, to_date('15-09-2019', 'dd-mm-yyyy'), '7', '15', '258', '09', '2019', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7199, to_date('16-09-2019', 'dd-mm-yyyy'), '1', '16', '259', '09', '2019', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7200, to_date('17-09-2019', 'dd-mm-yyyy'), '2', '17', '260', '09', '2019', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7201, to_date('18-09-2019', 'dd-mm-yyyy'), '3', '18', '261', '09', '2019', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7202, to_date('19-09-2019', 'dd-mm-yyyy'), '4', '19', '262', '09', '2019', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7203, to_date('20-09-2019', 'dd-mm-yyyy'), '5', '20', '263', '09', '2019', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7204, to_date('21-09-2019', 'dd-mm-yyyy'), '6', '21', '264', '09', '2019', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7205, to_date('22-09-2019', 'dd-mm-yyyy'), '7', '22', '265', '09', '2019', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7206, to_date('23-09-2019', 'dd-mm-yyyy'), '1', '23', '266', '09', '2019', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7207, to_date('24-09-2019', 'dd-mm-yyyy'), '2', '24', '267', '09', '2019', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7208, to_date('25-09-2019', 'dd-mm-yyyy'), '3', '25', '268', '09', '2019', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7209, to_date('26-09-2019', 'dd-mm-yyyy'), '4', '26', '269', '09', '2019', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7210, to_date('27-09-2019', 'dd-mm-yyyy'), '5', '27', '270', '09', '2019', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7211, to_date('28-09-2019', 'dd-mm-yyyy'), '6', '28', '271', '09', '2019', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7212, to_date('29-09-2019', 'dd-mm-yyyy'), '7', '29', '272', '09', '2019', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7213, to_date('30-09-2019', 'dd-mm-yyyy'), '1', '30', '273', '09', '2019', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7214, to_date('01-10-2019', 'dd-mm-yyyy'), '2', '01', '274', '10', '2019', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7215, to_date('02-10-2019', 'dd-mm-yyyy'), '3', '02', '275', '10', '2019', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7216, to_date('03-10-2019', 'dd-mm-yyyy'), '4', '03', '276', '10', '2019', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7217, to_date('04-10-2019', 'dd-mm-yyyy'), '5', '04', '277', '10', '2019', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7218, to_date('05-10-2019', 'dd-mm-yyyy'), '6', '05', '278', '10', '2019', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7219, to_date('06-10-2019', 'dd-mm-yyyy'), '7', '06', '279', '10', '2019', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7220, to_date('07-10-2019', 'dd-mm-yyyy'), '1', '07', '280', '10', '2019', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7221, to_date('08-10-2019', 'dd-mm-yyyy'), '2', '08', '281', '10', '2019', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7222, to_date('09-10-2019', 'dd-mm-yyyy'), '3', '09', '282', '10', '2019', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7223, to_date('10-10-2019', 'dd-mm-yyyy'), '4', '10', '283', '10', '2019', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7224, to_date('11-10-2019', 'dd-mm-yyyy'), '5', '11', '284', '10', '2019', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7225, to_date('12-10-2019', 'dd-mm-yyyy'), '6', '12', '285', '10', '2019', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7226, to_date('13-10-2019', 'dd-mm-yyyy'), '7', '13', '286', '10', '2019', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7227, to_date('14-10-2019', 'dd-mm-yyyy'), '1', '14', '287', '10', '2019', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7228, to_date('15-10-2019', 'dd-mm-yyyy'), '2', '15', '288', '10', '2019', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7229, to_date('16-10-2019', 'dd-mm-yyyy'), '3', '16', '289', '10', '2019', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7230, to_date('17-10-2019', 'dd-mm-yyyy'), '4', '17', '290', '10', '2019', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7231, to_date('18-10-2019', 'dd-mm-yyyy'), '5', '18', '291', '10', '2019', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7232, to_date('19-10-2019', 'dd-mm-yyyy'), '6', '19', '292', '10', '2019', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7233, to_date('20-10-2019', 'dd-mm-yyyy'), '7', '20', '293', '10', '2019', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7234, to_date('21-10-2019', 'dd-mm-yyyy'), '1', '21', '294', '10', '2019', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7235, to_date('22-10-2019', 'dd-mm-yyyy'), '2', '22', '295', '10', '2019', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7236, to_date('23-10-2019', 'dd-mm-yyyy'), '3', '23', '296', '10', '2019', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7237, to_date('24-10-2019', 'dd-mm-yyyy'), '4', '24', '297', '10', '2019', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7238, to_date('25-10-2019', 'dd-mm-yyyy'), '5', '25', '298', '10', '2019', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7239, to_date('26-10-2019', 'dd-mm-yyyy'), '6', '26', '299', '10', '2019', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7240, to_date('27-10-2019', 'dd-mm-yyyy'), '7', '27', '300', '10', '2019', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7241, to_date('28-10-2019', 'dd-mm-yyyy'), '1', '28', '301', '10', '2019', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7242, to_date('29-10-2019', 'dd-mm-yyyy'), '2', '29', '302', '10', '2019', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7243, to_date('30-10-2019', 'dd-mm-yyyy'), '3', '30', '303', '10', '2019', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7244, to_date('31-10-2019', 'dd-mm-yyyy'), '4', '31', '304', '10', '2019', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7245, to_date('01-11-2019', 'dd-mm-yyyy'), '5', '01', '305', '11', '2019', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7246, to_date('02-11-2019', 'dd-mm-yyyy'), '6', '02', '306', '11', '2019', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7247, to_date('03-11-2019', 'dd-mm-yyyy'), '7', '03', '307', '11', '2019', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7248, to_date('04-11-2019', 'dd-mm-yyyy'), '1', '04', '308', '11', '2019', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7249, to_date('05-11-2019', 'dd-mm-yyyy'), '2', '05', '309', '11', '2019', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7250, to_date('06-11-2019', 'dd-mm-yyyy'), '3', '06', '310', '11', '2019', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7251, to_date('07-11-2019', 'dd-mm-yyyy'), '4', '07', '311', '11', '2019', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7252, to_date('08-11-2019', 'dd-mm-yyyy'), '5', '08', '312', '11', '2019', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7253, to_date('09-11-2019', 'dd-mm-yyyy'), '6', '09', '313', '11', '2019', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7254, to_date('10-11-2019', 'dd-mm-yyyy'), '7', '10', '314', '11', '2019', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7255, to_date('11-11-2019', 'dd-mm-yyyy'), '1', '11', '315', '11', '2019', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7256, to_date('12-11-2019', 'dd-mm-yyyy'), '2', '12', '316', '11', '2019', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7257, to_date('13-11-2019', 'dd-mm-yyyy'), '3', '13', '317', '11', '2019', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7258, to_date('14-11-2019', 'dd-mm-yyyy'), '4', '14', '318', '11', '2019', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7259, to_date('15-11-2019', 'dd-mm-yyyy'), '5', '15', '319', '11', '2019', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7260, to_date('16-11-2019', 'dd-mm-yyyy'), '6', '16', '320', '11', '2019', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7261, to_date('17-11-2019', 'dd-mm-yyyy'), '7', '17', '321', '11', '2019', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7262, to_date('18-11-2019', 'dd-mm-yyyy'), '1', '18', '322', '11', '2019', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7263, to_date('19-11-2019', 'dd-mm-yyyy'), '2', '19', '323', '11', '2019', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7264, to_date('20-11-2019', 'dd-mm-yyyy'), '3', '20', '324', '11', '2019', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7265, to_date('21-11-2019', 'dd-mm-yyyy'), '4', '21', '325', '11', '2019', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7266, to_date('22-11-2019', 'dd-mm-yyyy'), '5', '22', '326', '11', '2019', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7267, to_date('23-11-2019', 'dd-mm-yyyy'), '6', '23', '327', '11', '2019', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7268, to_date('24-11-2019', 'dd-mm-yyyy'), '7', '24', '328', '11', '2019', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7269, to_date('25-11-2019', 'dd-mm-yyyy'), '1', '25', '329', '11', '2019', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7270, to_date('26-11-2019', 'dd-mm-yyyy'), '2', '26', '330', '11', '2019', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7271, to_date('27-11-2019', 'dd-mm-yyyy'), '3', '27', '331', '11', '2019', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7272, to_date('28-11-2019', 'dd-mm-yyyy'), '4', '28', '332', '11', '2019', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7273, to_date('29-11-2019', 'dd-mm-yyyy'), '5', '29', '333', '11', '2019', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7274, to_date('30-11-2019', 'dd-mm-yyyy'), '6', '30', '334', '11', '2019', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7275, to_date('01-12-2019', 'dd-mm-yyyy'), '7', '01', '335', '12', '2019', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7276, to_date('02-12-2019', 'dd-mm-yyyy'), '1', '02', '336', '12', '2019', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7277, to_date('03-12-2019', 'dd-mm-yyyy'), '2', '03', '337', '12', '2019', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7278, to_date('04-12-2019', 'dd-mm-yyyy'), '3', '04', '338', '12', '2019', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7279, to_date('05-12-2019', 'dd-mm-yyyy'), '4', '05', '339', '12', '2019', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7280, to_date('06-12-2019', 'dd-mm-yyyy'), '5', '06', '340', '12', '2019', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7281, to_date('07-12-2019', 'dd-mm-yyyy'), '6', '07', '341', '12', '2019', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7282, to_date('08-12-2019', 'dd-mm-yyyy'), '7', '08', '342', '12', '2019', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7283, to_date('09-12-2019', 'dd-mm-yyyy'), '1', '09', '343', '12', '2019', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7284, to_date('10-12-2019', 'dd-mm-yyyy'), '2', '10', '344', '12', '2019', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7285, to_date('11-12-2019', 'dd-mm-yyyy'), '3', '11', '345', '12', '2019', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7286, to_date('12-12-2019', 'dd-mm-yyyy'), '4', '12', '346', '12', '2019', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7287, to_date('13-12-2019', 'dd-mm-yyyy'), '5', '13', '347', '12', '2019', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7288, to_date('14-12-2019', 'dd-mm-yyyy'), '6', '14', '348', '12', '2019', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7289, to_date('15-12-2019', 'dd-mm-yyyy'), '7', '15', '349', '12', '2019', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7290, to_date('16-12-2019', 'dd-mm-yyyy'), '1', '16', '350', '12', '2019', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7291, to_date('17-12-2019', 'dd-mm-yyyy'), '2', '17', '351', '12', '2019', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7292, to_date('18-12-2019', 'dd-mm-yyyy'), '3', '18', '352', '12', '2019', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7293, to_date('19-12-2019', 'dd-mm-yyyy'), '4', '19', '353', '12', '2019', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7294, to_date('20-12-2019', 'dd-mm-yyyy'), '5', '20', '354', '12', '2019', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7295, to_date('21-12-2019', 'dd-mm-yyyy'), '6', '21', '355', '12', '2019', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7296, to_date('22-12-2019', 'dd-mm-yyyy'), '7', '22', '356', '12', '2019', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7297, to_date('23-12-2019', 'dd-mm-yyyy'), '1', '23', '357', '12', '2019', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7298, to_date('24-12-2019', 'dd-mm-yyyy'), '2', '24', '358', '12', '2019', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7299, to_date('25-12-2019', 'dd-mm-yyyy'), '3', '25', '359', '12', '2019', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7300, to_date('26-12-2019', 'dd-mm-yyyy'), '4', '26', '360', '12', '2019', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7301, to_date('27-12-2019', 'dd-mm-yyyy'), '5', '27', '361', '12', '2019', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7302, to_date('28-12-2019', 'dd-mm-yyyy'), '6', '28', '362', '12', '2019', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7303, to_date('29-12-2019', 'dd-mm-yyyy'), '7', '29', '363', '12', '2019', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7304, to_date('30-12-2019', 'dd-mm-yyyy'), '1', '30', '364', '12', '2019', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7305, to_date('31-12-2019', 'dd-mm-yyyy'), '2', '31', '365', '12', '2019', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7306, to_date('01-01-2020', 'dd-mm-yyyy'), '3', '01', '001', '01', '2020', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7307, to_date('02-01-2020', 'dd-mm-yyyy'), '4', '02', '002', '01', '2020', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7308, to_date('03-01-2020', 'dd-mm-yyyy'), '5', '03', '003', '01', '2020', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7309, to_date('04-01-2020', 'dd-mm-yyyy'), '6', '04', '004', '01', '2020', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7310, to_date('05-01-2020', 'dd-mm-yyyy'), '7', '05', '005', '01', '2020', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7311, to_date('06-01-2020', 'dd-mm-yyyy'), '1', '06', '006', '01', '2020', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7312, to_date('07-01-2020', 'dd-mm-yyyy'), '2', '07', '007', '01', '2020', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7313, to_date('08-01-2020', 'dd-mm-yyyy'), '3', '08', '008', '01', '2020', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7314, to_date('09-01-2020', 'dd-mm-yyyy'), '4', '09', '009', '01', '2020', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7315, to_date('10-01-2020', 'dd-mm-yyyy'), '5', '10', '010', '01', '2020', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7316, to_date('11-01-2020', 'dd-mm-yyyy'), '6', '11', '011', '01', '2020', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7317, to_date('12-01-2020', 'dd-mm-yyyy'), '7', '12', '012', '01', '2020', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7318, to_date('13-01-2020', 'dd-mm-yyyy'), '1', '13', '013', '01', '2020', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7319, to_date('14-01-2020', 'dd-mm-yyyy'), '2', '14', '014', '01', '2020', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7320, to_date('15-01-2020', 'dd-mm-yyyy'), '3', '15', '015', '01', '2020', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7321, to_date('16-01-2020', 'dd-mm-yyyy'), '4', '16', '016', '01', '2020', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7322, to_date('17-01-2020', 'dd-mm-yyyy'), '5', '17', '017', '01', '2020', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7323, to_date('18-01-2020', 'dd-mm-yyyy'), '6', '18', '018', '01', '2020', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7324, to_date('19-01-2020', 'dd-mm-yyyy'), '7', '19', '019', '01', '2020', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7325, to_date('20-01-2020', 'dd-mm-yyyy'), '1', '20', '020', '01', '2020', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7326, to_date('21-01-2020', 'dd-mm-yyyy'), '2', '21', '021', '01', '2020', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7327, to_date('22-01-2020', 'dd-mm-yyyy'), '3', '22', '022', '01', '2020', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7328, to_date('23-01-2020', 'dd-mm-yyyy'), '4', '23', '023', '01', '2020', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7329, to_date('24-01-2020', 'dd-mm-yyyy'), '5', '24', '024', '01', '2020', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7330, to_date('25-01-2020', 'dd-mm-yyyy'), '6', '25', '025', '01', '2020', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7331, to_date('26-01-2020', 'dd-mm-yyyy'), '7', '26', '026', '01', '2020', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7332, to_date('27-01-2020', 'dd-mm-yyyy'), '1', '27', '027', '01', '2020', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7333, to_date('28-01-2020', 'dd-mm-yyyy'), '2', '28', '028', '01', '2020', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7334, to_date('29-01-2020', 'dd-mm-yyyy'), '3', '29', '029', '01', '2020', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7335, to_date('30-01-2020', 'dd-mm-yyyy'), '4', '30', '030', '01', '2020', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7336, to_date('31-01-2020', 'dd-mm-yyyy'), '5', '31', '031', '01', '2020', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7337, to_date('01-02-2020', 'dd-mm-yyyy'), '6', '01', '032', '02', '2020', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7338, to_date('02-02-2020', 'dd-mm-yyyy'), '7', '02', '033', '02', '2020', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7339, to_date('03-02-2020', 'dd-mm-yyyy'), '1', '03', '034', '02', '2020', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7340, to_date('04-02-2020', 'dd-mm-yyyy'), '2', '04', '035', '02', '2020', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7341, to_date('05-02-2020', 'dd-mm-yyyy'), '3', '05', '036', '02', '2020', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7342, to_date('06-02-2020', 'dd-mm-yyyy'), '4', '06', '037', '02', '2020', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7343, to_date('07-02-2020', 'dd-mm-yyyy'), '5', '07', '038', '02', '2020', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7344, to_date('08-02-2020', 'dd-mm-yyyy'), '6', '08', '039', '02', '2020', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7345, to_date('09-02-2020', 'dd-mm-yyyy'), '7', '09', '040', '02', '2020', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7778, to_date('17-04-2021', 'dd-mm-yyyy'), '6', '17', '107', '04', '2021', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7779, to_date('18-04-2021', 'dd-mm-yyyy'), '7', '18', '108', '04', '2021', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7780, to_date('19-04-2021', 'dd-mm-yyyy'), '1', '19', '109', '04', '2021', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7781, to_date('20-04-2021', 'dd-mm-yyyy'), '2', '20', '110', '04', '2021', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7782, to_date('21-04-2021', 'dd-mm-yyyy'), '3', '21', '111', '04', '2021', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7783, to_date('22-04-2021', 'dd-mm-yyyy'), '4', '22', '112', '04', '2021', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7784, to_date('23-04-2021', 'dd-mm-yyyy'), '5', '23', '113', '04', '2021', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7785, to_date('24-04-2021', 'dd-mm-yyyy'), '6', '24', '114', '04', '2021', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7786, to_date('25-04-2021', 'dd-mm-yyyy'), '7', '25', '115', '04', '2021', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7787, to_date('26-04-2021', 'dd-mm-yyyy'), '1', '26', '116', '04', '2021', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7788, to_date('27-04-2021', 'dd-mm-yyyy'), '2', '27', '117', '04', '2021', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7789, to_date('28-04-2021', 'dd-mm-yyyy'), '3', '28', '118', '04', '2021', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7790, to_date('29-04-2021', 'dd-mm-yyyy'), '4', '29', '119', '04', '2021', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7791, to_date('30-04-2021', 'dd-mm-yyyy'), '5', '30', '120', '04', '2021', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7792, to_date('01-05-2021', 'dd-mm-yyyy'), '6', '01', '121', '05', '2021', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7793, to_date('02-05-2021', 'dd-mm-yyyy'), '7', '02', '122', '05', '2021', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7794, to_date('03-05-2021', 'dd-mm-yyyy'), '1', '03', '123', '05', '2021', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7795, to_date('04-05-2021', 'dd-mm-yyyy'), '2', '04', '124', '05', '2021', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7796, to_date('05-05-2021', 'dd-mm-yyyy'), '3', '05', '125', '05', '2021', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7797, to_date('06-05-2021', 'dd-mm-yyyy'), '4', '06', '126', '05', '2021', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7798, to_date('07-05-2021', 'dd-mm-yyyy'), '5', '07', '127', '05', '2021', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7799, to_date('08-05-2021', 'dd-mm-yyyy'), '6', '08', '128', '05', '2021', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7800, to_date('09-05-2021', 'dd-mm-yyyy'), '7', '09', '129', '05', '2021', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7801, to_date('10-05-2021', 'dd-mm-yyyy'), '1', '10', '130', '05', '2021', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7802, to_date('11-05-2021', 'dd-mm-yyyy'), '2', '11', '131', '05', '2021', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7803, to_date('12-05-2021', 'dd-mm-yyyy'), '3', '12', '132', '05', '2021', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7804, to_date('13-05-2021', 'dd-mm-yyyy'), '4', '13', '133', '05', '2021', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7805, to_date('14-05-2021', 'dd-mm-yyyy'), '5', '14', '134', '05', '2021', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7806, to_date('15-05-2021', 'dd-mm-yyyy'), '6', '15', '135', '05', '2021', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7807, to_date('16-05-2021', 'dd-mm-yyyy'), '7', '16', '136', '05', '2021', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7808, to_date('17-05-2021', 'dd-mm-yyyy'), '1', '17', '137', '05', '2021', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7809, to_date('18-05-2021', 'dd-mm-yyyy'), '2', '18', '138', '05', '2021', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7810, to_date('19-05-2021', 'dd-mm-yyyy'), '3', '19', '139', '05', '2021', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7811, to_date('20-05-2021', 'dd-mm-yyyy'), '4', '20', '140', '05', '2021', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7812, to_date('21-05-2021', 'dd-mm-yyyy'), '5', '21', '141', '05', '2021', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7813, to_date('22-05-2021', 'dd-mm-yyyy'), '6', '22', '142', '05', '2021', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7814, to_date('23-05-2021', 'dd-mm-yyyy'), '7', '23', '143', '05', '2021', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7815, to_date('24-05-2021', 'dd-mm-yyyy'), '1', '24', '144', '05', '2021', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7816, to_date('25-05-2021', 'dd-mm-yyyy'), '2', '25', '145', '05', '2021', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7817, to_date('26-05-2021', 'dd-mm-yyyy'), '3', '26', '146', '05', '2021', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7818, to_date('27-05-2021', 'dd-mm-yyyy'), '4', '27', '147', '05', '2021', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7819, to_date('28-05-2021', 'dd-mm-yyyy'), '5', '28', '148', '05', '2021', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7820, to_date('29-05-2021', 'dd-mm-yyyy'), '6', '29', '149', '05', '2021', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7821, to_date('30-05-2021', 'dd-mm-yyyy'), '7', '30', '150', '05', '2021', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7822, to_date('31-05-2021', 'dd-mm-yyyy'), '1', '31', '151', '05', '2021', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7823, to_date('01-06-2021', 'dd-mm-yyyy'), '2', '01', '152', '06', '2021', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7824, to_date('02-06-2021', 'dd-mm-yyyy'), '3', '02', '153', '06', '2021', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7825, to_date('03-06-2021', 'dd-mm-yyyy'), '4', '03', '154', '06', '2021', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7826, to_date('04-06-2021', 'dd-mm-yyyy'), '5', '04', '155', '06', '2021', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7827, to_date('05-06-2021', 'dd-mm-yyyy'), '6', '05', '156', '06', '2021', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7828, to_date('06-06-2021', 'dd-mm-yyyy'), '7', '06', '157', '06', '2021', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7829, to_date('07-06-2021', 'dd-mm-yyyy'), '1', '07', '158', '06', '2021', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7830, to_date('08-06-2021', 'dd-mm-yyyy'), '2', '08', '159', '06', '2021', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7831, to_date('09-06-2021', 'dd-mm-yyyy'), '3', '09', '160', '06', '2021', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7832, to_date('10-06-2021', 'dd-mm-yyyy'), '4', '10', '161', '06', '2021', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7833, to_date('11-06-2021', 'dd-mm-yyyy'), '5', '11', '162', '06', '2021', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7834, to_date('12-06-2021', 'dd-mm-yyyy'), '6', '12', '163', '06', '2021', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7835, to_date('13-06-2021', 'dd-mm-yyyy'), '7', '13', '164', '06', '2021', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7836, to_date('14-06-2021', 'dd-mm-yyyy'), '1', '14', '165', '06', '2021', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7837, to_date('15-06-2021', 'dd-mm-yyyy'), '2', '15', '166', '06', '2021', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7838, to_date('16-06-2021', 'dd-mm-yyyy'), '3', '16', '167', '06', '2021', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7839, to_date('17-06-2021', 'dd-mm-yyyy'), '4', '17', '168', '06', '2021', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7840, to_date('18-06-2021', 'dd-mm-yyyy'), '5', '18', '169', '06', '2021', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7841, to_date('19-06-2021', 'dd-mm-yyyy'), '6', '19', '170', '06', '2021', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7842, to_date('20-06-2021', 'dd-mm-yyyy'), '7', '20', '171', '06', '2021', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7843, to_date('21-06-2021', 'dd-mm-yyyy'), '1', '21', '172', '06', '2021', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7844, to_date('22-06-2021', 'dd-mm-yyyy'), '2', '22', '173', '06', '2021', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7845, to_date('23-06-2021', 'dd-mm-yyyy'), '3', '23', '174', '06', '2021', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7846, to_date('24-06-2021', 'dd-mm-yyyy'), '4', '24', '175', '06', '2021', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7847, to_date('25-06-2021', 'dd-mm-yyyy'), '5', '25', '176', '06', '2021', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7848, to_date('26-06-2021', 'dd-mm-yyyy'), '6', '26', '177', '06', '2021', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7849, to_date('27-06-2021', 'dd-mm-yyyy'), '7', '27', '178', '06', '2021', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7850, to_date('28-06-2021', 'dd-mm-yyyy'), '1', '28', '179', '06', '2021', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7851, to_date('29-06-2021', 'dd-mm-yyyy'), '2', '29', '180', '06', '2021', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7852, to_date('30-06-2021', 'dd-mm-yyyy'), '3', '30', '181', '06', '2021', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7853, to_date('01-07-2021', 'dd-mm-yyyy'), '4', '01', '182', '07', '2021', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7854, to_date('02-07-2021', 'dd-mm-yyyy'), '5', '02', '183', '07', '2021', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7855, to_date('03-07-2021', 'dd-mm-yyyy'), '6', '03', '184', '07', '2021', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7856, to_date('04-07-2021', 'dd-mm-yyyy'), '7', '04', '185', '07', '2021', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7857, to_date('05-07-2021', 'dd-mm-yyyy'), '1', '05', '186', '07', '2021', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7858, to_date('06-07-2021', 'dd-mm-yyyy'), '2', '06', '187', '07', '2021', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7859, to_date('07-07-2021', 'dd-mm-yyyy'), '3', '07', '188', '07', '2021', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7860, to_date('08-07-2021', 'dd-mm-yyyy'), '4', '08', '189', '07', '2021', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7861, to_date('09-07-2021', 'dd-mm-yyyy'), '5', '09', '190', '07', '2021', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7862, to_date('10-07-2021', 'dd-mm-yyyy'), '6', '10', '191', '07', '2021', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7863, to_date('11-07-2021', 'dd-mm-yyyy'), '7', '11', '192', '07', '2021', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7864, to_date('12-07-2021', 'dd-mm-yyyy'), '1', '12', '193', '07', '2021', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7865, to_date('13-07-2021', 'dd-mm-yyyy'), '2', '13', '194', '07', '2021', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7866, to_date('14-07-2021', 'dd-mm-yyyy'), '3', '14', '195', '07', '2021', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7867, to_date('15-07-2021', 'dd-mm-yyyy'), '4', '15', '196', '07', '2021', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7868, to_date('16-07-2021', 'dd-mm-yyyy'), '5', '16', '197', '07', '2021', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7869, to_date('17-07-2021', 'dd-mm-yyyy'), '6', '17', '198', '07', '2021', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7870, to_date('18-07-2021', 'dd-mm-yyyy'), '7', '18', '199', '07', '2021', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7871, to_date('19-07-2021', 'dd-mm-yyyy'), '1', '19', '200', '07', '2021', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7872, to_date('20-07-2021', 'dd-mm-yyyy'), '2', '20', '201', '07', '2021', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7873, to_date('21-07-2021', 'dd-mm-yyyy'), '3', '21', '202', '07', '2021', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7874, to_date('22-07-2021', 'dd-mm-yyyy'), '4', '22', '203', '07', '2021', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7875, to_date('23-07-2021', 'dd-mm-yyyy'), '5', '23', '204', '07', '2021', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7876, to_date('24-07-2021', 'dd-mm-yyyy'), '6', '24', '205', '07', '2021', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7877, to_date('25-07-2021', 'dd-mm-yyyy'), '7', '25', '206', '07', '2021', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7878, to_date('26-07-2021', 'dd-mm-yyyy'), '1', '26', '207', '07', '2021', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7879, to_date('27-07-2021', 'dd-mm-yyyy'), '2', '27', '208', '07', '2021', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7880, to_date('28-07-2021', 'dd-mm-yyyy'), '3', '28', '209', '07', '2021', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7881, to_date('29-07-2021', 'dd-mm-yyyy'), '4', '29', '210', '07', '2021', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7882, to_date('30-07-2021', 'dd-mm-yyyy'), '5', '30', '211', '07', '2021', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7883, to_date('31-07-2021', 'dd-mm-yyyy'), '6', '31', '212', '07', '2021', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7884, to_date('01-08-2021', 'dd-mm-yyyy'), '7', '01', '213', '08', '2021', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7885, to_date('02-08-2021', 'dd-mm-yyyy'), '1', '02', '214', '08', '2021', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7346, to_date('10-02-2020', 'dd-mm-yyyy'), '1', '10', '041', '02', '2020', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7347, to_date('11-02-2020', 'dd-mm-yyyy'), '2', '11', '042', '02', '2020', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7348, to_date('12-02-2020', 'dd-mm-yyyy'), '3', '12', '043', '02', '2020', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7349, to_date('13-02-2020', 'dd-mm-yyyy'), '4', '13', '044', '02', '2020', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7350, to_date('14-02-2020', 'dd-mm-yyyy'), '5', '14', '045', '02', '2020', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7351, to_date('15-02-2020', 'dd-mm-yyyy'), '6', '15', '046', '02', '2020', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7352, to_date('16-02-2020', 'dd-mm-yyyy'), '7', '16', '047', '02', '2020', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7353, to_date('17-02-2020', 'dd-mm-yyyy'), '1', '17', '048', '02', '2020', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7354, to_date('18-02-2020', 'dd-mm-yyyy'), '2', '18', '049', '02', '2020', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7355, to_date('19-02-2020', 'dd-mm-yyyy'), '3', '19', '050', '02', '2020', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7356, to_date('20-02-2020', 'dd-mm-yyyy'), '4', '20', '051', '02', '2020', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7357, to_date('21-02-2020', 'dd-mm-yyyy'), '5', '21', '052', '02', '2020', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7358, to_date('22-02-2020', 'dd-mm-yyyy'), '6', '22', '053', '02', '2020', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7359, to_date('23-02-2020', 'dd-mm-yyyy'), '7', '23', '054', '02', '2020', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7360, to_date('24-02-2020', 'dd-mm-yyyy'), '1', '24', '055', '02', '2020', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7361, to_date('25-02-2020', 'dd-mm-yyyy'), '2', '25', '056', '02', '2020', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7362, to_date('26-02-2020', 'dd-mm-yyyy'), '3', '26', '057', '02', '2020', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7363, to_date('27-02-2020', 'dd-mm-yyyy'), '4', '27', '058', '02', '2020', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7364, to_date('28-02-2020', 'dd-mm-yyyy'), '5', '28', '059', '02', '2020', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7365, to_date('29-02-2020', 'dd-mm-yyyy'), '6', '29', '060', '02', '2020', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7366, to_date('01-03-2020', 'dd-mm-yyyy'), '7', '01', '061', '03', '2020', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7367, to_date('02-03-2020', 'dd-mm-yyyy'), '1', '02', '062', '03', '2020', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7368, to_date('03-03-2020', 'dd-mm-yyyy'), '2', '03', '063', '03', '2020', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7369, to_date('04-03-2020', 'dd-mm-yyyy'), '3', '04', '064', '03', '2020', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7370, to_date('05-03-2020', 'dd-mm-yyyy'), '4', '05', '065', '03', '2020', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7371, to_date('06-03-2020', 'dd-mm-yyyy'), '5', '06', '066', '03', '2020', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7372, to_date('07-03-2020', 'dd-mm-yyyy'), '6', '07', '067', '03', '2020', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7373, to_date('08-03-2020', 'dd-mm-yyyy'), '7', '08', '068', '03', '2020', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7374, to_date('09-03-2020', 'dd-mm-yyyy'), '1', '09', '069', '03', '2020', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7375, to_date('10-03-2020', 'dd-mm-yyyy'), '2', '10', '070', '03', '2020', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7376, to_date('11-03-2020', 'dd-mm-yyyy'), '3', '11', '071', '03', '2020', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7377, to_date('12-03-2020', 'dd-mm-yyyy'), '4', '12', '072', '03', '2020', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7378, to_date('13-03-2020', 'dd-mm-yyyy'), '5', '13', '073', '03', '2020', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7379, to_date('14-03-2020', 'dd-mm-yyyy'), '6', '14', '074', '03', '2020', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7380, to_date('15-03-2020', 'dd-mm-yyyy'), '7', '15', '075', '03', '2020', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7381, to_date('16-03-2020', 'dd-mm-yyyy'), '1', '16', '076', '03', '2020', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7382, to_date('17-03-2020', 'dd-mm-yyyy'), '2', '17', '077', '03', '2020', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7383, to_date('18-03-2020', 'dd-mm-yyyy'), '3', '18', '078', '03', '2020', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7384, to_date('19-03-2020', 'dd-mm-yyyy'), '4', '19', '079', '03', '2020', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7385, to_date('20-03-2020', 'dd-mm-yyyy'), '5', '20', '080', '03', '2020', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7386, to_date('21-03-2020', 'dd-mm-yyyy'), '6', '21', '081', '03', '2020', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7387, to_date('22-03-2020', 'dd-mm-yyyy'), '7', '22', '082', '03', '2020', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7388, to_date('23-03-2020', 'dd-mm-yyyy'), '1', '23', '083', '03', '2020', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7389, to_date('24-03-2020', 'dd-mm-yyyy'), '2', '24', '084', '03', '2020', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7390, to_date('25-03-2020', 'dd-mm-yyyy'), '3', '25', '085', '03', '2020', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7391, to_date('26-03-2020', 'dd-mm-yyyy'), '4', '26', '086', '03', '2020', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7392, to_date('27-03-2020', 'dd-mm-yyyy'), '5', '27', '087', '03', '2020', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7393, to_date('28-03-2020', 'dd-mm-yyyy'), '6', '28', '088', '03', '2020', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7394, to_date('29-03-2020', 'dd-mm-yyyy'), '7', '29', '089', '03', '2020', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7395, to_date('30-03-2020', 'dd-mm-yyyy'), '1', '30', '090', '03', '2020', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7396, to_date('31-03-2020', 'dd-mm-yyyy'), '2', '31', '091', '03', '2020', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7397, to_date('01-04-2020', 'dd-mm-yyyy'), '3', '01', '092', '04', '2020', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7398, to_date('02-04-2020', 'dd-mm-yyyy'), '4', '02', '093', '04', '2020', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7399, to_date('03-04-2020', 'dd-mm-yyyy'), '5', '03', '094', '04', '2020', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7400, to_date('04-04-2020', 'dd-mm-yyyy'), '6', '04', '095', '04', '2020', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7401, to_date('05-04-2020', 'dd-mm-yyyy'), '7', '05', '096', '04', '2020', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7402, to_date('06-04-2020', 'dd-mm-yyyy'), '1', '06', '097', '04', '2020', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7403, to_date('07-04-2020', 'dd-mm-yyyy'), '2', '07', '098', '04', '2020', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7404, to_date('08-04-2020', 'dd-mm-yyyy'), '3', '08', '099', '04', '2020', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7405, to_date('09-04-2020', 'dd-mm-yyyy'), '4', '09', '100', '04', '2020', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7406, to_date('10-04-2020', 'dd-mm-yyyy'), '5', '10', '101', '04', '2020', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7407, to_date('11-04-2020', 'dd-mm-yyyy'), '6', '11', '102', '04', '2020', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7408, to_date('12-04-2020', 'dd-mm-yyyy'), '7', '12', '103', '04', '2020', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7409, to_date('13-04-2020', 'dd-mm-yyyy'), '1', '13', '104', '04', '2020', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7410, to_date('14-04-2020', 'dd-mm-yyyy'), '2', '14', '105', '04', '2020', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7411, to_date('15-04-2020', 'dd-mm-yyyy'), '3', '15', '106', '04', '2020', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7412, to_date('16-04-2020', 'dd-mm-yyyy'), '4', '16', '107', '04', '2020', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7413, to_date('17-04-2020', 'dd-mm-yyyy'), '5', '17', '108', '04', '2020', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7414, to_date('18-04-2020', 'dd-mm-yyyy'), '6', '18', '109', '04', '2020', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7415, to_date('19-04-2020', 'dd-mm-yyyy'), '7', '19', '110', '04', '2020', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7416, to_date('20-04-2020', 'dd-mm-yyyy'), '1', '20', '111', '04', '2020', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7417, to_date('21-04-2020', 'dd-mm-yyyy'), '2', '21', '112', '04', '2020', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7418, to_date('22-04-2020', 'dd-mm-yyyy'), '3', '22', '113', '04', '2020', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7419, to_date('23-04-2020', 'dd-mm-yyyy'), '4', '23', '114', '04', '2020', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7420, to_date('24-04-2020', 'dd-mm-yyyy'), '5', '24', '115', '04', '2020', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7421, to_date('25-04-2020', 'dd-mm-yyyy'), '6', '25', '116', '04', '2020', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7422, to_date('26-04-2020', 'dd-mm-yyyy'), '7', '26', '117', '04', '2020', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7423, to_date('27-04-2020', 'dd-mm-yyyy'), '1', '27', '118', '04', '2020', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7424, to_date('28-04-2020', 'dd-mm-yyyy'), '2', '28', '119', '04', '2020', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7425, to_date('29-04-2020', 'dd-mm-yyyy'), '3', '29', '120', '04', '2020', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7426, to_date('30-04-2020', 'dd-mm-yyyy'), '4', '30', '121', '04', '2020', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7427, to_date('01-05-2020', 'dd-mm-yyyy'), '5', '01', '122', '05', '2020', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7428, to_date('02-05-2020', 'dd-mm-yyyy'), '6', '02', '123', '05', '2020', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7429, to_date('03-05-2020', 'dd-mm-yyyy'), '7', '03', '124', '05', '2020', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7430, to_date('04-05-2020', 'dd-mm-yyyy'), '1', '04', '125', '05', '2020', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7431, to_date('05-05-2020', 'dd-mm-yyyy'), '2', '05', '126', '05', '2020', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7432, to_date('06-05-2020', 'dd-mm-yyyy'), '3', '06', '127', '05', '2020', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7433, to_date('07-05-2020', 'dd-mm-yyyy'), '4', '07', '128', '05', '2020', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7434, to_date('08-05-2020', 'dd-mm-yyyy'), '5', '08', '129', '05', '2020', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7435, to_date('09-05-2020', 'dd-mm-yyyy'), '6', '09', '130', '05', '2020', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7436, to_date('10-05-2020', 'dd-mm-yyyy'), '7', '10', '131', '05', '2020', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7437, to_date('11-05-2020', 'dd-mm-yyyy'), '1', '11', '132', '05', '2020', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7438, to_date('12-05-2020', 'dd-mm-yyyy'), '2', '12', '133', '05', '2020', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7439, to_date('13-05-2020', 'dd-mm-yyyy'), '3', '13', '134', '05', '2020', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7440, to_date('14-05-2020', 'dd-mm-yyyy'), '4', '14', '135', '05', '2020', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7441, to_date('15-05-2020', 'dd-mm-yyyy'), '5', '15', '136', '05', '2020', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7442, to_date('16-05-2020', 'dd-mm-yyyy'), '6', '16', '137', '05', '2020', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7443, to_date('17-05-2020', 'dd-mm-yyyy'), '7', '17', '138', '05', '2020', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7444, to_date('18-05-2020', 'dd-mm-yyyy'), '1', '18', '139', '05', '2020', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7445, to_date('19-05-2020', 'dd-mm-yyyy'), '2', '19', '140', '05', '2020', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7446, to_date('20-05-2020', 'dd-mm-yyyy'), '3', '20', '141', '05', '2020', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7447, to_date('21-05-2020', 'dd-mm-yyyy'), '4', '21', '142', '05', '2020', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7448, to_date('22-05-2020', 'dd-mm-yyyy'), '5', '22', '143', '05', '2020', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7449, to_date('23-05-2020', 'dd-mm-yyyy'), '6', '23', '144', '05', '2020', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7450, to_date('24-05-2020', 'dd-mm-yyyy'), '7', '24', '145', '05', '2020', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7451, to_date('25-05-2020', 'dd-mm-yyyy'), '1', '25', '146', '05', '2020', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7452, to_date('26-05-2020', 'dd-mm-yyyy'), '2', '26', '147', '05', '2020', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7453, to_date('27-05-2020', 'dd-mm-yyyy'), '3', '27', '148', '05', '2020', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7454, to_date('28-05-2020', 'dd-mm-yyyy'), '4', '28', '149', '05', '2020', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7455, to_date('29-05-2020', 'dd-mm-yyyy'), '5', '29', '150', '05', '2020', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7456, to_date('30-05-2020', 'dd-mm-yyyy'), '6', '30', '151', '05', '2020', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7457, to_date('31-05-2020', 'dd-mm-yyyy'), '7', '31', '152', '05', '2020', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7458, to_date('01-06-2020', 'dd-mm-yyyy'), '1', '01', '153', '06', '2020', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7459, to_date('02-06-2020', 'dd-mm-yyyy'), '2', '02', '154', '06', '2020', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7460, to_date('03-06-2020', 'dd-mm-yyyy'), '3', '03', '155', '06', '2020', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7461, to_date('04-06-2020', 'dd-mm-yyyy'), '4', '04', '156', '06', '2020', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7462, to_date('05-06-2020', 'dd-mm-yyyy'), '5', '05', '157', '06', '2020', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7463, to_date('06-06-2020', 'dd-mm-yyyy'), '6', '06', '158', '06', '2020', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7464, to_date('07-06-2020', 'dd-mm-yyyy'), '7', '07', '159', '06', '2020', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7465, to_date('08-06-2020', 'dd-mm-yyyy'), '1', '08', '160', '06', '2020', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7466, to_date('09-06-2020', 'dd-mm-yyyy'), '2', '09', '161', '06', '2020', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7467, to_date('10-06-2020', 'dd-mm-yyyy'), '3', '10', '162', '06', '2020', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7468, to_date('11-06-2020', 'dd-mm-yyyy'), '4', '11', '163', '06', '2020', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7469, to_date('12-06-2020', 'dd-mm-yyyy'), '5', '12', '164', '06', '2020', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7470, to_date('13-06-2020', 'dd-mm-yyyy'), '6', '13', '165', '06', '2020', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7471, to_date('14-06-2020', 'dd-mm-yyyy'), '7', '14', '166', '06', '2020', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7472, to_date('15-06-2020', 'dd-mm-yyyy'), '1', '15', '167', '06', '2020', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7473, to_date('16-06-2020', 'dd-mm-yyyy'), '2', '16', '168', '06', '2020', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7474, to_date('17-06-2020', 'dd-mm-yyyy'), '3', '17', '169', '06', '2020', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7475, to_date('18-06-2020', 'dd-mm-yyyy'), '4', '18', '170', '06', '2020', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7476, to_date('19-06-2020', 'dd-mm-yyyy'), '5', '19', '171', '06', '2020', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7477, to_date('20-06-2020', 'dd-mm-yyyy'), '6', '20', '172', '06', '2020', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7478, to_date('21-06-2020', 'dd-mm-yyyy'), '7', '21', '173', '06', '2020', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7479, to_date('22-06-2020', 'dd-mm-yyyy'), '1', '22', '174', '06', '2020', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7480, to_date('23-06-2020', 'dd-mm-yyyy'), '2', '23', '175', '06', '2020', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7481, to_date('24-06-2020', 'dd-mm-yyyy'), '3', '24', '176', '06', '2020', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7482, to_date('25-06-2020', 'dd-mm-yyyy'), '4', '25', '177', '06', '2020', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7483, to_date('26-06-2020', 'dd-mm-yyyy'), '5', '26', '178', '06', '2020', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7484, to_date('27-06-2020', 'dd-mm-yyyy'), '6', '27', '179', '06', '2020', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7485, to_date('28-06-2020', 'dd-mm-yyyy'), '7', '28', '180', '06', '2020', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7486, to_date('29-06-2020', 'dd-mm-yyyy'), '1', '29', '181', '06', '2020', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7487, to_date('30-06-2020', 'dd-mm-yyyy'), '2', '30', '182', '06', '2020', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7488, to_date('01-07-2020', 'dd-mm-yyyy'), '3', '01', '183', '07', '2020', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7489, to_date('02-07-2020', 'dd-mm-yyyy'), '4', '02', '184', '07', '2020', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7490, to_date('03-07-2020', 'dd-mm-yyyy'), '5', '03', '185', '07', '2020', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7491, to_date('04-07-2020', 'dd-mm-yyyy'), '6', '04', '186', '07', '2020', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7492, to_date('05-07-2020', 'dd-mm-yyyy'), '7', '05', '187', '07', '2020', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7493, to_date('06-07-2020', 'dd-mm-yyyy'), '1', '06', '188', '07', '2020', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7494, to_date('07-07-2020', 'dd-mm-yyyy'), '2', '07', '189', '07', '2020', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7495, to_date('08-07-2020', 'dd-mm-yyyy'), '3', '08', '190', '07', '2020', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7496, to_date('09-07-2020', 'dd-mm-yyyy'), '4', '09', '191', '07', '2020', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7497, to_date('10-07-2020', 'dd-mm-yyyy'), '5', '10', '192', '07', '2020', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7498, to_date('11-07-2020', 'dd-mm-yyyy'), '6', '11', '193', '07', '2020', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7499, to_date('12-07-2020', 'dd-mm-yyyy'), '7', '12', '194', '07', '2020', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7500, to_date('13-07-2020', 'dd-mm-yyyy'), '1', '13', '195', '07', '2020', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7501, to_date('14-07-2020', 'dd-mm-yyyy'), '2', '14', '196', '07', '2020', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7502, to_date('15-07-2020', 'dd-mm-yyyy'), '3', '15', '197', '07', '2020', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7503, to_date('16-07-2020', 'dd-mm-yyyy'), '4', '16', '198', '07', '2020', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7504, to_date('17-07-2020', 'dd-mm-yyyy'), '5', '17', '199', '07', '2020', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7505, to_date('18-07-2020', 'dd-mm-yyyy'), '6', '18', '200', '07', '2020', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7506, to_date('19-07-2020', 'dd-mm-yyyy'), '7', '19', '201', '07', '2020', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7507, to_date('20-07-2020', 'dd-mm-yyyy'), '1', '20', '202', '07', '2020', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7508, to_date('21-07-2020', 'dd-mm-yyyy'), '2', '21', '203', '07', '2020', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7509, to_date('22-07-2020', 'dd-mm-yyyy'), '3', '22', '204', '07', '2020', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7510, to_date('23-07-2020', 'dd-mm-yyyy'), '4', '23', '205', '07', '2020', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7511, to_date('24-07-2020', 'dd-mm-yyyy'), '5', '24', '206', '07', '2020', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7512, to_date('25-07-2020', 'dd-mm-yyyy'), '6', '25', '207', '07', '2020', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7513, to_date('26-07-2020', 'dd-mm-yyyy'), '7', '26', '208', '07', '2020', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7514, to_date('27-07-2020', 'dd-mm-yyyy'), '1', '27', '209', '07', '2020', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7515, to_date('28-07-2020', 'dd-mm-yyyy'), '2', '28', '210', '07', '2020', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7516, to_date('29-07-2020', 'dd-mm-yyyy'), '3', '29', '211', '07', '2020', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7517, to_date('30-07-2020', 'dd-mm-yyyy'), '4', '30', '212', '07', '2020', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7518, to_date('31-07-2020', 'dd-mm-yyyy'), '5', '31', '213', '07', '2020', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7519, to_date('01-08-2020', 'dd-mm-yyyy'), '6', '01', '214', '08', '2020', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7520, to_date('02-08-2020', 'dd-mm-yyyy'), '7', '02', '215', '08', '2020', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7521, to_date('03-08-2020', 'dd-mm-yyyy'), '1', '03', '216', '08', '2020', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7522, to_date('04-08-2020', 'dd-mm-yyyy'), '2', '04', '217', '08', '2020', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7523, to_date('05-08-2020', 'dd-mm-yyyy'), '3', '05', '218', '08', '2020', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7524, to_date('06-08-2020', 'dd-mm-yyyy'), '4', '06', '219', '08', '2020', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7525, to_date('07-08-2020', 'dd-mm-yyyy'), '5', '07', '220', '08', '2020', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7526, to_date('08-08-2020', 'dd-mm-yyyy'), '6', '08', '221', '08', '2020', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7527, to_date('09-08-2020', 'dd-mm-yyyy'), '7', '09', '222', '08', '2020', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7528, to_date('10-08-2020', 'dd-mm-yyyy'), '1', '10', '223', '08', '2020', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7529, to_date('11-08-2020', 'dd-mm-yyyy'), '2', '11', '224', '08', '2020', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7530, to_date('12-08-2020', 'dd-mm-yyyy'), '3', '12', '225', '08', '2020', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7531, to_date('13-08-2020', 'dd-mm-yyyy'), '4', '13', '226', '08', '2020', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7532, to_date('14-08-2020', 'dd-mm-yyyy'), '5', '14', '227', '08', '2020', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7533, to_date('15-08-2020', 'dd-mm-yyyy'), '6', '15', '228', '08', '2020', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7534, to_date('16-08-2020', 'dd-mm-yyyy'), '7', '16', '229', '08', '2020', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7535, to_date('17-08-2020', 'dd-mm-yyyy'), '1', '17', '230', '08', '2020', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7536, to_date('18-08-2020', 'dd-mm-yyyy'), '2', '18', '231', '08', '2020', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7537, to_date('19-08-2020', 'dd-mm-yyyy'), '3', '19', '232', '08', '2020', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7538, to_date('20-08-2020', 'dd-mm-yyyy'), '4', '20', '233', '08', '2020', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7539, to_date('21-08-2020', 'dd-mm-yyyy'), '5', '21', '234', '08', '2020', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7540, to_date('22-08-2020', 'dd-mm-yyyy'), '6', '22', '235', '08', '2020', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7541, to_date('23-08-2020', 'dd-mm-yyyy'), '7', '23', '236', '08', '2020', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7542, to_date('24-08-2020', 'dd-mm-yyyy'), '1', '24', '237', '08', '2020', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7543, to_date('25-08-2020', 'dd-mm-yyyy'), '2', '25', '238', '08', '2020', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7544, to_date('26-08-2020', 'dd-mm-yyyy'), '3', '26', '239', '08', '2020', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7545, to_date('27-08-2020', 'dd-mm-yyyy'), '4', '27', '240', '08', '2020', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7546, to_date('28-08-2020', 'dd-mm-yyyy'), '5', '28', '241', '08', '2020', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7547, to_date('29-08-2020', 'dd-mm-yyyy'), '6', '29', '242', '08', '2020', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7548, to_date('30-08-2020', 'dd-mm-yyyy'), '7', '30', '243', '08', '2020', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7549, to_date('31-08-2020', 'dd-mm-yyyy'), '1', '31', '244', '08', '2020', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7550, to_date('01-09-2020', 'dd-mm-yyyy'), '2', '01', '245', '09', '2020', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7551, to_date('02-09-2020', 'dd-mm-yyyy'), '3', '02', '246', '09', '2020', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7552, to_date('03-09-2020', 'dd-mm-yyyy'), '4', '03', '247', '09', '2020', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7553, to_date('04-09-2020', 'dd-mm-yyyy'), '5', '04', '248', '09', '2020', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7554, to_date('05-09-2020', 'dd-mm-yyyy'), '6', '05', '249', '09', '2020', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7555, to_date('06-09-2020', 'dd-mm-yyyy'), '7', '06', '250', '09', '2020', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7556, to_date('07-09-2020', 'dd-mm-yyyy'), '1', '07', '251', '09', '2020', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7557, to_date('08-09-2020', 'dd-mm-yyyy'), '2', '08', '252', '09', '2020', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7558, to_date('09-09-2020', 'dd-mm-yyyy'), '3', '09', '253', '09', '2020', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7559, to_date('10-09-2020', 'dd-mm-yyyy'), '4', '10', '254', '09', '2020', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7560, to_date('11-09-2020', 'dd-mm-yyyy'), '5', '11', '255', '09', '2020', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7561, to_date('12-09-2020', 'dd-mm-yyyy'), '6', '12', '256', '09', '2020', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7562, to_date('13-09-2020', 'dd-mm-yyyy'), '7', '13', '257', '09', '2020', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7563, to_date('14-09-2020', 'dd-mm-yyyy'), '1', '14', '258', '09', '2020', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7564, to_date('15-09-2020', 'dd-mm-yyyy'), '2', '15', '259', '09', '2020', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7565, to_date('16-09-2020', 'dd-mm-yyyy'), '3', '16', '260', '09', '2020', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7566, to_date('17-09-2020', 'dd-mm-yyyy'), '4', '17', '261', '09', '2020', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7567, to_date('18-09-2020', 'dd-mm-yyyy'), '5', '18', '262', '09', '2020', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7568, to_date('19-09-2020', 'dd-mm-yyyy'), '6', '19', '263', '09', '2020', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7569, to_date('20-09-2020', 'dd-mm-yyyy'), '7', '20', '264', '09', '2020', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7570, to_date('21-09-2020', 'dd-mm-yyyy'), '1', '21', '265', '09', '2020', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7571, to_date('22-09-2020', 'dd-mm-yyyy'), '2', '22', '266', '09', '2020', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7572, to_date('23-09-2020', 'dd-mm-yyyy'), '3', '23', '267', '09', '2020', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7573, to_date('24-09-2020', 'dd-mm-yyyy'), '4', '24', '268', '09', '2020', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7574, to_date('25-09-2020', 'dd-mm-yyyy'), '5', '25', '269', '09', '2020', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7575, to_date('26-09-2020', 'dd-mm-yyyy'), '6', '26', '270', '09', '2020', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7576, to_date('27-09-2020', 'dd-mm-yyyy'), '7', '27', '271', '09', '2020', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7577, to_date('28-09-2020', 'dd-mm-yyyy'), '1', '28', '272', '09', '2020', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7578, to_date('29-09-2020', 'dd-mm-yyyy'), '2', '29', '273', '09', '2020', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7579, to_date('30-09-2020', 'dd-mm-yyyy'), '3', '30', '274', '09', '2020', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7580, to_date('01-10-2020', 'dd-mm-yyyy'), '4', '01', '275', '10', '2020', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7581, to_date('02-10-2020', 'dd-mm-yyyy'), '5', '02', '276', '10', '2020', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7582, to_date('03-10-2020', 'dd-mm-yyyy'), '6', '03', '277', '10', '2020', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7583, to_date('04-10-2020', 'dd-mm-yyyy'), '7', '04', '278', '10', '2020', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7584, to_date('05-10-2020', 'dd-mm-yyyy'), '1', '05', '279', '10', '2020', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7585, to_date('06-10-2020', 'dd-mm-yyyy'), '2', '06', '280', '10', '2020', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7586, to_date('07-10-2020', 'dd-mm-yyyy'), '3', '07', '281', '10', '2020', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7587, to_date('08-10-2020', 'dd-mm-yyyy'), '4', '08', '282', '10', '2020', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7588, to_date('09-10-2020', 'dd-mm-yyyy'), '5', '09', '283', '10', '2020', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7589, to_date('10-10-2020', 'dd-mm-yyyy'), '6', '10', '284', '10', '2020', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7590, to_date('11-10-2020', 'dd-mm-yyyy'), '7', '11', '285', '10', '2020', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7591, to_date('12-10-2020', 'dd-mm-yyyy'), '1', '12', '286', '10', '2020', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7592, to_date('13-10-2020', 'dd-mm-yyyy'), '2', '13', '287', '10', '2020', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7593, to_date('14-10-2020', 'dd-mm-yyyy'), '3', '14', '288', '10', '2020', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7594, to_date('15-10-2020', 'dd-mm-yyyy'), '4', '15', '289', '10', '2020', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7595, to_date('16-10-2020', 'dd-mm-yyyy'), '5', '16', '290', '10', '2020', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7596, to_date('17-10-2020', 'dd-mm-yyyy'), '6', '17', '291', '10', '2020', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7597, to_date('18-10-2020', 'dd-mm-yyyy'), '7', '18', '292', '10', '2020', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7598, to_date('19-10-2020', 'dd-mm-yyyy'), '1', '19', '293', '10', '2020', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7599, to_date('20-10-2020', 'dd-mm-yyyy'), '2', '20', '294', '10', '2020', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7600, to_date('21-10-2020', 'dd-mm-yyyy'), '3', '21', '295', '10', '2020', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7601, to_date('22-10-2020', 'dd-mm-yyyy'), '4', '22', '296', '10', '2020', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7602, to_date('23-10-2020', 'dd-mm-yyyy'), '5', '23', '297', '10', '2020', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7603, to_date('24-10-2020', 'dd-mm-yyyy'), '6', '24', '298', '10', '2020', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7604, to_date('25-10-2020', 'dd-mm-yyyy'), '7', '25', '299', '10', '2020', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7605, to_date('26-10-2020', 'dd-mm-yyyy'), '1', '26', '300', '10', '2020', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7606, to_date('27-10-2020', 'dd-mm-yyyy'), '2', '27', '301', '10', '2020', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7607, to_date('28-10-2020', 'dd-mm-yyyy'), '3', '28', '302', '10', '2020', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7608, to_date('29-10-2020', 'dd-mm-yyyy'), '4', '29', '303', '10', '2020', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7609, to_date('30-10-2020', 'dd-mm-yyyy'), '5', '30', '304', '10', '2020', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7610, to_date('31-10-2020', 'dd-mm-yyyy'), '6', '31', '305', '10', '2020', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7611, to_date('01-11-2020', 'dd-mm-yyyy'), '7', '01', '306', '11', '2020', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7612, to_date('02-11-2020', 'dd-mm-yyyy'), '1', '02', '307', '11', '2020', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7613, to_date('03-11-2020', 'dd-mm-yyyy'), '2', '03', '308', '11', '2020', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7614, to_date('04-11-2020', 'dd-mm-yyyy'), '3', '04', '309', '11', '2020', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7615, to_date('05-11-2020', 'dd-mm-yyyy'), '4', '05', '310', '11', '2020', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7616, to_date('06-11-2020', 'dd-mm-yyyy'), '5', '06', '311', '11', '2020', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7617, to_date('07-11-2020', 'dd-mm-yyyy'), '6', '07', '312', '11', '2020', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7618, to_date('08-11-2020', 'dd-mm-yyyy'), '7', '08', '313', '11', '2020', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7619, to_date('09-11-2020', 'dd-mm-yyyy'), '1', '09', '314', '11', '2020', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7620, to_date('10-11-2020', 'dd-mm-yyyy'), '2', '10', '315', '11', '2020', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7621, to_date('11-11-2020', 'dd-mm-yyyy'), '3', '11', '316', '11', '2020', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7622, to_date('12-11-2020', 'dd-mm-yyyy'), '4', '12', '317', '11', '2020', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7623, to_date('13-11-2020', 'dd-mm-yyyy'), '5', '13', '318', '11', '2020', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7624, to_date('14-11-2020', 'dd-mm-yyyy'), '6', '14', '319', '11', '2020', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7625, to_date('15-11-2020', 'dd-mm-yyyy'), '7', '15', '320', '11', '2020', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7626, to_date('16-11-2020', 'dd-mm-yyyy'), '1', '16', '321', '11', '2020', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7627, to_date('17-11-2020', 'dd-mm-yyyy'), '2', '17', '322', '11', '2020', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7628, to_date('18-11-2020', 'dd-mm-yyyy'), '3', '18', '323', '11', '2020', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7629, to_date('19-11-2020', 'dd-mm-yyyy'), '4', '19', '324', '11', '2020', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7630, to_date('20-11-2020', 'dd-mm-yyyy'), '5', '20', '325', '11', '2020', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7631, to_date('21-11-2020', 'dd-mm-yyyy'), '6', '21', '326', '11', '2020', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7632, to_date('22-11-2020', 'dd-mm-yyyy'), '7', '22', '327', '11', '2020', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7633, to_date('23-11-2020', 'dd-mm-yyyy'), '1', '23', '328', '11', '2020', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7634, to_date('24-11-2020', 'dd-mm-yyyy'), '2', '24', '329', '11', '2020', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7635, to_date('25-11-2020', 'dd-mm-yyyy'), '3', '25', '330', '11', '2020', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7636, to_date('26-11-2020', 'dd-mm-yyyy'), '4', '26', '331', '11', '2020', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7637, to_date('27-11-2020', 'dd-mm-yyyy'), '5', '27', '332', '11', '2020', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7638, to_date('28-11-2020', 'dd-mm-yyyy'), '6', '28', '333', '11', '2020', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7639, to_date('29-11-2020', 'dd-mm-yyyy'), '7', '29', '334', '11', '2020', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7640, to_date('30-11-2020', 'dd-mm-yyyy'), '1', '30', '335', '11', '2020', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7641, to_date('01-12-2020', 'dd-mm-yyyy'), '2', '01', '336', '12', '2020', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7642, to_date('02-12-2020', 'dd-mm-yyyy'), '3', '02', '337', '12', '2020', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7643, to_date('03-12-2020', 'dd-mm-yyyy'), '4', '03', '338', '12', '2020', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7644, to_date('04-12-2020', 'dd-mm-yyyy'), '5', '04', '339', '12', '2020', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7645, to_date('05-12-2020', 'dd-mm-yyyy'), '6', '05', '340', '12', '2020', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7646, to_date('06-12-2020', 'dd-mm-yyyy'), '7', '06', '341', '12', '2020', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7647, to_date('07-12-2020', 'dd-mm-yyyy'), '1', '07', '342', '12', '2020', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7648, to_date('08-12-2020', 'dd-mm-yyyy'), '2', '08', '343', '12', '2020', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7649, to_date('09-12-2020', 'dd-mm-yyyy'), '3', '09', '344', '12', '2020', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7650, to_date('10-12-2020', 'dd-mm-yyyy'), '4', '10', '345', '12', '2020', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7651, to_date('11-12-2020', 'dd-mm-yyyy'), '5', '11', '346', '12', '2020', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7652, to_date('12-12-2020', 'dd-mm-yyyy'), '6', '12', '347', '12', '2020', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7653, to_date('13-12-2020', 'dd-mm-yyyy'), '7', '13', '348', '12', '2020', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7654, to_date('14-12-2020', 'dd-mm-yyyy'), '1', '14', '349', '12', '2020', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7655, to_date('15-12-2020', 'dd-mm-yyyy'), '2', '15', '350', '12', '2020', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7656, to_date('16-12-2020', 'dd-mm-yyyy'), '3', '16', '351', '12', '2020', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7657, to_date('17-12-2020', 'dd-mm-yyyy'), '4', '17', '352', '12', '2020', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7658, to_date('18-12-2020', 'dd-mm-yyyy'), '5', '18', '353', '12', '2020', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7659, to_date('19-12-2020', 'dd-mm-yyyy'), '6', '19', '354', '12', '2020', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7660, to_date('20-12-2020', 'dd-mm-yyyy'), '7', '20', '355', '12', '2020', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7661, to_date('21-12-2020', 'dd-mm-yyyy'), '1', '21', '356', '12', '2020', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7662, to_date('22-12-2020', 'dd-mm-yyyy'), '2', '22', '357', '12', '2020', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7663, to_date('23-12-2020', 'dd-mm-yyyy'), '3', '23', '358', '12', '2020', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7664, to_date('24-12-2020', 'dd-mm-yyyy'), '4', '24', '359', '12', '2020', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7665, to_date('25-12-2020', 'dd-mm-yyyy'), '5', '25', '360', '12', '2020', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7666, to_date('26-12-2020', 'dd-mm-yyyy'), '6', '26', '361', '12', '2020', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7667, to_date('27-12-2020', 'dd-mm-yyyy'), '7', '27', '362', '12', '2020', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7668, to_date('28-12-2020', 'dd-mm-yyyy'), '1', '28', '363', '12', '2020', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7669, to_date('29-12-2020', 'dd-mm-yyyy'), '2', '29', '364', '12', '2020', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7670, to_date('30-12-2020', 'dd-mm-yyyy'), '3', '30', '365', '12', '2020', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7671, to_date('31-12-2020', 'dd-mm-yyyy'), '4', '31', '366', '12', '2020', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7672, to_date('01-01-2021', 'dd-mm-yyyy'), '5', '01', '001', '01', '2021', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7673, to_date('02-01-2021', 'dd-mm-yyyy'), '6', '02', '002', '01', '2021', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7674, to_date('03-01-2021', 'dd-mm-yyyy'), '7', '03', '003', '01', '2021', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7675, to_date('04-01-2021', 'dd-mm-yyyy'), '1', '04', '004', '01', '2021', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7676, to_date('05-01-2021', 'dd-mm-yyyy'), '2', '05', '005', '01', '2021', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7677, to_date('06-01-2021', 'dd-mm-yyyy'), '3', '06', '006', '01', '2021', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7678, to_date('07-01-2021', 'dd-mm-yyyy'), '4', '07', '007', '01', '2021', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7679, to_date('08-01-2021', 'dd-mm-yyyy'), '5', '08', '008', '01', '2021', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7680, to_date('09-01-2021', 'dd-mm-yyyy'), '6', '09', '009', '01', '2021', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7681, to_date('10-01-2021', 'dd-mm-yyyy'), '7', '10', '010', '01', '2021', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7682, to_date('11-01-2021', 'dd-mm-yyyy'), '1', '11', '011', '01', '2021', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7683, to_date('12-01-2021', 'dd-mm-yyyy'), '2', '12', '012', '01', '2021', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7684, to_date('13-01-2021', 'dd-mm-yyyy'), '3', '13', '013', '01', '2021', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7685, to_date('14-01-2021', 'dd-mm-yyyy'), '4', '14', '014', '01', '2021', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7686, to_date('15-01-2021', 'dd-mm-yyyy'), '5', '15', '015', '01', '2021', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7687, to_date('16-01-2021', 'dd-mm-yyyy'), '6', '16', '016', '01', '2021', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7688, to_date('17-01-2021', 'dd-mm-yyyy'), '7', '17', '017', '01', '2021', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7689, to_date('18-01-2021', 'dd-mm-yyyy'), '1', '18', '018', '01', '2021', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7690, to_date('19-01-2021', 'dd-mm-yyyy'), '2', '19', '019', '01', '2021', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7691, to_date('20-01-2021', 'dd-mm-yyyy'), '3', '20', '020', '01', '2021', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7692, to_date('21-01-2021', 'dd-mm-yyyy'), '4', '21', '021', '01', '2021', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7693, to_date('22-01-2021', 'dd-mm-yyyy'), '5', '22', '022', '01', '2021', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7694, to_date('23-01-2021', 'dd-mm-yyyy'), '6', '23', '023', '01', '2021', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7695, to_date('24-01-2021', 'dd-mm-yyyy'), '7', '24', '024', '01', '2021', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7696, to_date('25-01-2021', 'dd-mm-yyyy'), '1', '25', '025', '01', '2021', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7697, to_date('26-01-2021', 'dd-mm-yyyy'), '2', '26', '026', '01', '2021', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7698, to_date('27-01-2021', 'dd-mm-yyyy'), '3', '27', '027', '01', '2021', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7699, to_date('28-01-2021', 'dd-mm-yyyy'), '4', '28', '028', '01', '2021', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7700, to_date('29-01-2021', 'dd-mm-yyyy'), '5', '29', '029', '01', '2021', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7701, to_date('30-01-2021', 'dd-mm-yyyy'), '6', '30', '030', '01', '2021', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7702, to_date('31-01-2021', 'dd-mm-yyyy'), '7', '31', '031', '01', '2021', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7703, to_date('01-02-2021', 'dd-mm-yyyy'), '1', '01', '032', '02', '2021', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7704, to_date('02-02-2021', 'dd-mm-yyyy'), '2', '02', '033', '02', '2021', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7705, to_date('03-02-2021', 'dd-mm-yyyy'), '3', '03', '034', '02', '2021', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7706, to_date('04-02-2021', 'dd-mm-yyyy'), '4', '04', '035', '02', '2021', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7707, to_date('05-02-2021', 'dd-mm-yyyy'), '5', '05', '036', '02', '2021', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7708, to_date('06-02-2021', 'dd-mm-yyyy'), '6', '06', '037', '02', '2021', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7709, to_date('07-02-2021', 'dd-mm-yyyy'), '7', '07', '038', '02', '2021', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7710, to_date('08-02-2021', 'dd-mm-yyyy'), '1', '08', '039', '02', '2021', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7711, to_date('09-02-2021', 'dd-mm-yyyy'), '2', '09', '040', '02', '2021', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7712, to_date('10-02-2021', 'dd-mm-yyyy'), '3', '10', '041', '02', '2021', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7713, to_date('11-02-2021', 'dd-mm-yyyy'), '4', '11', '042', '02', '2021', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7714, to_date('12-02-2021', 'dd-mm-yyyy'), '5', '12', '043', '02', '2021', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7715, to_date('13-02-2021', 'dd-mm-yyyy'), '6', '13', '044', '02', '2021', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7716, to_date('14-02-2021', 'dd-mm-yyyy'), '7', '14', '045', '02', '2021', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7717, to_date('15-02-2021', 'dd-mm-yyyy'), '1', '15', '046', '02', '2021', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7718, to_date('16-02-2021', 'dd-mm-yyyy'), '2', '16', '047', '02', '2021', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7719, to_date('17-02-2021', 'dd-mm-yyyy'), '3', '17', '048', '02', '2021', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7720, to_date('18-02-2021', 'dd-mm-yyyy'), '4', '18', '049', '02', '2021', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7721, to_date('19-02-2021', 'dd-mm-yyyy'), '5', '19', '050', '02', '2021', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7722, to_date('20-02-2021', 'dd-mm-yyyy'), '6', '20', '051', '02', '2021', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7723, to_date('21-02-2021', 'dd-mm-yyyy'), '7', '21', '052', '02', '2021', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7724, to_date('22-02-2021', 'dd-mm-yyyy'), '1', '22', '053', '02', '2021', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7725, to_date('23-02-2021', 'dd-mm-yyyy'), '2', '23', '054', '02', '2021', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7726, to_date('24-02-2021', 'dd-mm-yyyy'), '3', '24', '055', '02', '2021', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7727, to_date('25-02-2021', 'dd-mm-yyyy'), '4', '25', '056', '02', '2021', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7728, to_date('26-02-2021', 'dd-mm-yyyy'), '5', '26', '057', '02', '2021', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7729, to_date('27-02-2021', 'dd-mm-yyyy'), '6', '27', '058', '02', '2021', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7730, to_date('28-02-2021', 'dd-mm-yyyy'), '7', '28', '059', '02', '2021', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7731, to_date('01-03-2021', 'dd-mm-yyyy'), '1', '01', '060', '03', '2021', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7732, to_date('02-03-2021', 'dd-mm-yyyy'), '2', '02', '061', '03', '2021', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7733, to_date('03-03-2021', 'dd-mm-yyyy'), '3', '03', '062', '03', '2021', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7734, to_date('04-03-2021', 'dd-mm-yyyy'), '4', '04', '063', '03', '2021', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7735, to_date('05-03-2021', 'dd-mm-yyyy'), '5', '05', '064', '03', '2021', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7736, to_date('06-03-2021', 'dd-mm-yyyy'), '6', '06', '065', '03', '2021', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7737, to_date('07-03-2021', 'dd-mm-yyyy'), '7', '07', '066', '03', '2021', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7738, to_date('08-03-2021', 'dd-mm-yyyy'), '1', '08', '067', '03', '2021', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7739, to_date('09-03-2021', 'dd-mm-yyyy'), '2', '09', '068', '03', '2021', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7740, to_date('10-03-2021', 'dd-mm-yyyy'), '3', '10', '069', '03', '2021', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7741, to_date('11-03-2021', 'dd-mm-yyyy'), '4', '11', '070', '03', '2021', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7742, to_date('12-03-2021', 'dd-mm-yyyy'), '5', '12', '071', '03', '2021', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7743, to_date('13-03-2021', 'dd-mm-yyyy'), '6', '13', '072', '03', '2021', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7744, to_date('14-03-2021', 'dd-mm-yyyy'), '7', '14', '073', '03', '2021', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7745, to_date('15-03-2021', 'dd-mm-yyyy'), '1', '15', '074', '03', '2021', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7746, to_date('16-03-2021', 'dd-mm-yyyy'), '2', '16', '075', '03', '2021', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7747, to_date('17-03-2021', 'dd-mm-yyyy'), '3', '17', '076', '03', '2021', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7748, to_date('18-03-2021', 'dd-mm-yyyy'), '4', '18', '077', '03', '2021', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7749, to_date('19-03-2021', 'dd-mm-yyyy'), '5', '19', '078', '03', '2021', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7750, to_date('20-03-2021', 'dd-mm-yyyy'), '6', '20', '079', '03', '2021', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7751, to_date('21-03-2021', 'dd-mm-yyyy'), '7', '21', '080', '03', '2021', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7752, to_date('22-03-2021', 'dd-mm-yyyy'), '1', '22', '081', '03', '2021', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7753, to_date('23-03-2021', 'dd-mm-yyyy'), '2', '23', '082', '03', '2021', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7754, to_date('24-03-2021', 'dd-mm-yyyy'), '3', '24', '083', '03', '2021', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7755, to_date('25-03-2021', 'dd-mm-yyyy'), '4', '25', '084', '03', '2021', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7756, to_date('26-03-2021', 'dd-mm-yyyy'), '5', '26', '085', '03', '2021', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7757, to_date('27-03-2021', 'dd-mm-yyyy'), '6', '27', '086', '03', '2021', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7758, to_date('28-03-2021', 'dd-mm-yyyy'), '7', '28', '087', '03', '2021', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7759, to_date('29-03-2021', 'dd-mm-yyyy'), '1', '29', '088', '03', '2021', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7760, to_date('30-03-2021', 'dd-mm-yyyy'), '2', '30', '089', '03', '2021', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7761, to_date('31-03-2021', 'dd-mm-yyyy'), '3', '31', '090', '03', '2021', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7762, to_date('01-04-2021', 'dd-mm-yyyy'), '4', '01', '091', '04', '2021', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7763, to_date('02-04-2021', 'dd-mm-yyyy'), '5', '02', '092', '04', '2021', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7764, to_date('03-04-2021', 'dd-mm-yyyy'), '6', '03', '093', '04', '2021', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7765, to_date('04-04-2021', 'dd-mm-yyyy'), '7', '04', '094', '04', '2021', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7766, to_date('05-04-2021', 'dd-mm-yyyy'), '1', '05', '095', '04', '2021', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7767, to_date('06-04-2021', 'dd-mm-yyyy'), '2', '06', '096', '04', '2021', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7768, to_date('07-04-2021', 'dd-mm-yyyy'), '3', '07', '097', '04', '2021', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7769, to_date('08-04-2021', 'dd-mm-yyyy'), '4', '08', '098', '04', '2021', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7770, to_date('09-04-2021', 'dd-mm-yyyy'), '5', '09', '099', '04', '2021', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7771, to_date('10-04-2021', 'dd-mm-yyyy'), '6', '10', '100', '04', '2021', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7772, to_date('11-04-2021', 'dd-mm-yyyy'), '7', '11', '101', '04', '2021', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7773, to_date('12-04-2021', 'dd-mm-yyyy'), '1', '12', '102', '04', '2021', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7774, to_date('13-04-2021', 'dd-mm-yyyy'), '2', '13', '103', '04', '2021', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7775, to_date('14-04-2021', 'dd-mm-yyyy'), '3', '14', '104', '04', '2021', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7776, to_date('15-04-2021', 'dd-mm-yyyy'), '4', '15', '105', '04', '2021', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7777, to_date('16-04-2021', 'dd-mm-yyyy'), '5', '16', '106', '04', '2021', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7022, to_date('23-03-2019', 'dd-mm-yyyy'), '6', '23', '082', '03', '2019', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7023, to_date('24-03-2019', 'dd-mm-yyyy'), '7', '24', '083', '03', '2019', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7024, to_date('25-03-2019', 'dd-mm-yyyy'), '1', '25', '084', '03', '2019', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7025, to_date('26-03-2019', 'dd-mm-yyyy'), '2', '26', '085', '03', '2019', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7026, to_date('27-03-2019', 'dd-mm-yyyy'), '3', '27', '086', '03', '2019', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7027, to_date('28-03-2019', 'dd-mm-yyyy'), '4', '28', '087', '03', '2019', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7028, to_date('29-03-2019', 'dd-mm-yyyy'), '5', '29', '088', '03', '2019', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7029, to_date('30-03-2019', 'dd-mm-yyyy'), '6', '30', '089', '03', '2019', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7030, to_date('31-03-2019', 'dd-mm-yyyy'), '7', '31', '090', '03', '2019', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7031, to_date('01-04-2019', 'dd-mm-yyyy'), '1', '01', '091', '04', '2019', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7032, to_date('02-04-2019', 'dd-mm-yyyy'), '2', '02', '092', '04', '2019', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7033, to_date('03-04-2019', 'dd-mm-yyyy'), '3', '03', '093', '04', '2019', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7034, to_date('04-04-2019', 'dd-mm-yyyy'), '4', '04', '094', '04', '2019', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7035, to_date('05-04-2019', 'dd-mm-yyyy'), '5', '05', '095', '04', '2019', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7036, to_date('06-04-2019', 'dd-mm-yyyy'), '6', '06', '096', '04', '2019', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7037, to_date('07-04-2019', 'dd-mm-yyyy'), '7', '07', '097', '04', '2019', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7038, to_date('08-04-2019', 'dd-mm-yyyy'), '1', '08', '098', '04', '2019', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7039, to_date('09-04-2019', 'dd-mm-yyyy'), '2', '09', '099', '04', '2019', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7040, to_date('10-04-2019', 'dd-mm-yyyy'), '3', '10', '100', '04', '2019', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7041, to_date('11-04-2019', 'dd-mm-yyyy'), '4', '11', '101', '04', '2019', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7042, to_date('12-04-2019', 'dd-mm-yyyy'), '5', '12', '102', '04', '2019', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7043, to_date('13-04-2019', 'dd-mm-yyyy'), '6', '13', '103', '04', '2019', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7044, to_date('14-04-2019', 'dd-mm-yyyy'), '7', '14', '104', '04', '2019', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7045, to_date('15-04-2019', 'dd-mm-yyyy'), '1', '15', '105', '04', '2019', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7046, to_date('16-04-2019', 'dd-mm-yyyy'), '2', '16', '106', '04', '2019', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7047, to_date('17-04-2019', 'dd-mm-yyyy'), '3', '17', '107', '04', '2019', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7048, to_date('18-04-2019', 'dd-mm-yyyy'), '4', '18', '108', '04', '2019', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7049, to_date('19-04-2019', 'dd-mm-yyyy'), '5', '19', '109', '04', '2019', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7050, to_date('20-04-2019', 'dd-mm-yyyy'), '6', '20', '110', '04', '2019', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7051, to_date('21-04-2019', 'dd-mm-yyyy'), '7', '21', '111', '04', '2019', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7052, to_date('22-04-2019', 'dd-mm-yyyy'), '1', '22', '112', '04', '2019', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7053, to_date('23-04-2019', 'dd-mm-yyyy'), '2', '23', '113', '04', '2019', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7054, to_date('24-04-2019', 'dd-mm-yyyy'), '3', '24', '114', '04', '2019', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7055, to_date('25-04-2019', 'dd-mm-yyyy'), '4', '25', '115', '04', '2019', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7056, to_date('26-04-2019', 'dd-mm-yyyy'), '5', '26', '116', '04', '2019', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7057, to_date('27-04-2019', 'dd-mm-yyyy'), '6', '27', '117', '04', '2019', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7058, to_date('28-04-2019', 'dd-mm-yyyy'), '7', '28', '118', '04', '2019', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7059, to_date('29-04-2019', 'dd-mm-yyyy'), '1', '29', '119', '04', '2019', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7060, to_date('30-04-2019', 'dd-mm-yyyy'), '2', '30', '120', '04', '2019', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7061, to_date('01-05-2019', 'dd-mm-yyyy'), '3', '01', '121', '05', '2019', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7062, to_date('02-05-2019', 'dd-mm-yyyy'), '4', '02', '122', '05', '2019', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7063, to_date('03-05-2019', 'dd-mm-yyyy'), '5', '03', '123', '05', '2019', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7064, to_date('04-05-2019', 'dd-mm-yyyy'), '6', '04', '124', '05', '2019', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7065, to_date('05-05-2019', 'dd-mm-yyyy'), '7', '05', '125', '05', '2019', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7066, to_date('06-05-2019', 'dd-mm-yyyy'), '1', '06', '126', '05', '2019', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7067, to_date('07-05-2019', 'dd-mm-yyyy'), '2', '07', '127', '05', '2019', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7068, to_date('08-05-2019', 'dd-mm-yyyy'), '3', '08', '128', '05', '2019', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7069, to_date('09-05-2019', 'dd-mm-yyyy'), '4', '09', '129', '05', '2019', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7070, to_date('10-05-2019', 'dd-mm-yyyy'), '5', '10', '130', '05', '2019', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7071, to_date('11-05-2019', 'dd-mm-yyyy'), '6', '11', '131', '05', '2019', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7072, to_date('12-05-2019', 'dd-mm-yyyy'), '7', '12', '132', '05', '2019', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7073, to_date('13-05-2019', 'dd-mm-yyyy'), '1', '13', '133', '05', '2019', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7074, to_date('14-05-2019', 'dd-mm-yyyy'), '2', '14', '134', '05', '2019', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7075, to_date('15-05-2019', 'dd-mm-yyyy'), '3', '15', '135', '05', '2019', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7076, to_date('16-05-2019', 'dd-mm-yyyy'), '4', '16', '136', '05', '2019', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7077, to_date('17-05-2019', 'dd-mm-yyyy'), '5', '17', '137', '05', '2019', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7078, to_date('18-05-2019', 'dd-mm-yyyy'), '6', '18', '138', '05', '2019', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7079, to_date('19-05-2019', 'dd-mm-yyyy'), '7', '19', '139', '05', '2019', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7080, to_date('20-05-2019', 'dd-mm-yyyy'), '1', '20', '140', '05', '2019', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7081, to_date('21-05-2019', 'dd-mm-yyyy'), '2', '21', '141', '05', '2019', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7082, to_date('22-05-2019', 'dd-mm-yyyy'), '3', '22', '142', '05', '2019', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7083, to_date('23-05-2019', 'dd-mm-yyyy'), '4', '23', '143', '05', '2019', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7084, to_date('24-05-2019', 'dd-mm-yyyy'), '5', '24', '144', '05', '2019', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7085, to_date('25-05-2019', 'dd-mm-yyyy'), '6', '25', '145', '05', '2019', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7086, to_date('26-05-2019', 'dd-mm-yyyy'), '7', '26', '146', '05', '2019', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7087, to_date('27-05-2019', 'dd-mm-yyyy'), '1', '27', '147', '05', '2019', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7088, to_date('28-05-2019', 'dd-mm-yyyy'), '2', '28', '148', '05', '2019', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7089, to_date('29-05-2019', 'dd-mm-yyyy'), '3', '29', '149', '05', '2019', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7090, to_date('30-05-2019', 'dd-mm-yyyy'), '4', '30', '150', '05', '2019', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7091, to_date('31-05-2019', 'dd-mm-yyyy'), '5', '31', '151', '05', '2019', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7092, to_date('01-06-2019', 'dd-mm-yyyy'), '6', '01', '152', '06', '2019', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7093, to_date('02-06-2019', 'dd-mm-yyyy'), '7', '02', '153', '06', '2019', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7094, to_date('03-06-2019', 'dd-mm-yyyy'), '1', '03', '154', '06', '2019', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7095, to_date('04-06-2019', 'dd-mm-yyyy'), '2', '04', '155', '06', '2019', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7096, to_date('05-06-2019', 'dd-mm-yyyy'), '3', '05', '156', '06', '2019', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7097, to_date('06-06-2019', 'dd-mm-yyyy'), '4', '06', '157', '06', '2019', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7098, to_date('07-06-2019', 'dd-mm-yyyy'), '5', '07', '158', '06', '2019', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7099, to_date('08-06-2019', 'dd-mm-yyyy'), '6', '08', '159', '06', '2019', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7100, to_date('09-06-2019', 'dd-mm-yyyy'), '7', '09', '160', '06', '2019', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7101, to_date('10-06-2019', 'dd-mm-yyyy'), '1', '10', '161', '06', '2019', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7102, to_date('11-06-2019', 'dd-mm-yyyy'), '2', '11', '162', '06', '2019', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7103, to_date('12-06-2019', 'dd-mm-yyyy'), '3', '12', '163', '06', '2019', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7104, to_date('13-06-2019', 'dd-mm-yyyy'), '4', '13', '164', '06', '2019', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7105, to_date('14-06-2019', 'dd-mm-yyyy'), '5', '14', '165', '06', '2019', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7106, to_date('15-06-2019', 'dd-mm-yyyy'), '6', '15', '166', '06', '2019', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7107, to_date('16-06-2019', 'dd-mm-yyyy'), '7', '16', '167', '06', '2019', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7108, to_date('17-06-2019', 'dd-mm-yyyy'), '1', '17', '168', '06', '2019', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7109, to_date('18-06-2019', 'dd-mm-yyyy'), '2', '18', '169', '06', '2019', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7110, to_date('19-06-2019', 'dd-mm-yyyy'), '3', '19', '170', '06', '2019', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7111, to_date('20-06-2019', 'dd-mm-yyyy'), '4', '20', '171', '06', '2019', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7112, to_date('21-06-2019', 'dd-mm-yyyy'), '5', '21', '172', '06', '2019', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7113, to_date('22-06-2019', 'dd-mm-yyyy'), '6', '22', '173', '06', '2019', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7114, to_date('23-06-2019', 'dd-mm-yyyy'), '7', '23', '174', '06', '2019', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7115, to_date('24-06-2019', 'dd-mm-yyyy'), '1', '24', '175', '06', '2019', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7116, to_date('25-06-2019', 'dd-mm-yyyy'), '2', '25', '176', '06', '2019', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7117, to_date('26-06-2019', 'dd-mm-yyyy'), '3', '26', '177', '06', '2019', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7118, to_date('27-06-2019', 'dd-mm-yyyy'), '4', '27', '178', '06', '2019', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7119, to_date('28-06-2019', 'dd-mm-yyyy'), '5', '28', '179', '06', '2019', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7120, to_date('29-06-2019', 'dd-mm-yyyy'), '6', '29', '180', '06', '2019', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7121, to_date('30-06-2019', 'dd-mm-yyyy'), '7', '30', '181', '06', '2019', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7122, to_date('01-07-2019', 'dd-mm-yyyy'), '1', '01', '182', '07', '2019', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7123, to_date('02-07-2019', 'dd-mm-yyyy'), '2', '02', '183', '07', '2019', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7124, to_date('03-07-2019', 'dd-mm-yyyy'), '3', '03', '184', '07', '2019', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7125, to_date('04-07-2019', 'dd-mm-yyyy'), '4', '04', '185', '07', '2019', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7126, to_date('05-07-2019', 'dd-mm-yyyy'), '5', '05', '186', '07', '2019', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7127, to_date('06-07-2019', 'dd-mm-yyyy'), '6', '06', '187', '07', '2019', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7128, to_date('07-07-2019', 'dd-mm-yyyy'), '7', '07', '188', '07', '2019', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7129, to_date('08-07-2019', 'dd-mm-yyyy'), '1', '08', '189', '07', '2019', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7886, to_date('03-08-2021', 'dd-mm-yyyy'), '2', '03', '215', '08', '2021', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7887, to_date('04-08-2021', 'dd-mm-yyyy'), '3', '04', '216', '08', '2021', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7888, to_date('05-08-2021', 'dd-mm-yyyy'), '4', '05', '217', '08', '2021', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7889, to_date('06-08-2021', 'dd-mm-yyyy'), '5', '06', '218', '08', '2021', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7890, to_date('07-08-2021', 'dd-mm-yyyy'), '6', '07', '219', '08', '2021', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7891, to_date('08-08-2021', 'dd-mm-yyyy'), '7', '08', '220', '08', '2021', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7892, to_date('09-08-2021', 'dd-mm-yyyy'), '1', '09', '221', '08', '2021', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7893, to_date('10-08-2021', 'dd-mm-yyyy'), '2', '10', '222', '08', '2021', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7894, to_date('11-08-2021', 'dd-mm-yyyy'), '3', '11', '223', '08', '2021', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7895, to_date('12-08-2021', 'dd-mm-yyyy'), '4', '12', '224', '08', '2021', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7896, to_date('13-08-2021', 'dd-mm-yyyy'), '5', '13', '225', '08', '2021', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7897, to_date('14-08-2021', 'dd-mm-yyyy'), '6', '14', '226', '08', '2021', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7898, to_date('15-08-2021', 'dd-mm-yyyy'), '7', '15', '227', '08', '2021', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7899, to_date('16-08-2021', 'dd-mm-yyyy'), '1', '16', '228', '08', '2021', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7900, to_date('17-08-2021', 'dd-mm-yyyy'), '2', '17', '229', '08', '2021', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7901, to_date('18-08-2021', 'dd-mm-yyyy'), '3', '18', '230', '08', '2021', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7902, to_date('19-08-2021', 'dd-mm-yyyy'), '4', '19', '231', '08', '2021', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7903, to_date('20-08-2021', 'dd-mm-yyyy'), '5', '20', '232', '08', '2021', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7904, to_date('21-08-2021', 'dd-mm-yyyy'), '6', '21', '233', '08', '2021', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7905, to_date('22-08-2021', 'dd-mm-yyyy'), '7', '22', '234', '08', '2021', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7906, to_date('23-08-2021', 'dd-mm-yyyy'), '1', '23', '235', '08', '2021', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7907, to_date('24-08-2021', 'dd-mm-yyyy'), '2', '24', '236', '08', '2021', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7908, to_date('25-08-2021', 'dd-mm-yyyy'), '3', '25', '237', '08', '2021', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7909, to_date('26-08-2021', 'dd-mm-yyyy'), '4', '26', '238', '08', '2021', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7910, to_date('27-08-2021', 'dd-mm-yyyy'), '5', '27', '239', '08', '2021', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7911, to_date('28-08-2021', 'dd-mm-yyyy'), '6', '28', '240', '08', '2021', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7912, to_date('29-08-2021', 'dd-mm-yyyy'), '7', '29', '241', '08', '2021', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7913, to_date('30-08-2021', 'dd-mm-yyyy'), '1', '30', '242', '08', '2021', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7914, to_date('31-08-2021', 'dd-mm-yyyy'), '2', '31', '243', '08', '2021', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7915, to_date('01-09-2021', 'dd-mm-yyyy'), '3', '01', '244', '09', '2021', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7916, to_date('02-09-2021', 'dd-mm-yyyy'), '4', '02', '245', '09', '2021', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7917, to_date('03-09-2021', 'dd-mm-yyyy'), '5', '03', '246', '09', '2021', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7918, to_date('04-09-2021', 'dd-mm-yyyy'), '6', '04', '247', '09', '2021', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7919, to_date('05-09-2021', 'dd-mm-yyyy'), '7', '05', '248', '09', '2021', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7920, to_date('06-09-2021', 'dd-mm-yyyy'), '1', '06', '249', '09', '2021', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7921, to_date('07-09-2021', 'dd-mm-yyyy'), '2', '07', '250', '09', '2021', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7922, to_date('08-09-2021', 'dd-mm-yyyy'), '3', '08', '251', '09', '2021', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7923, to_date('09-09-2021', 'dd-mm-yyyy'), '4', '09', '252', '09', '2021', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7924, to_date('10-09-2021', 'dd-mm-yyyy'), '5', '10', '253', '09', '2021', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7925, to_date('11-09-2021', 'dd-mm-yyyy'), '6', '11', '254', '09', '2021', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7926, to_date('12-09-2021', 'dd-mm-yyyy'), '7', '12', '255', '09', '2021', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7927, to_date('13-09-2021', 'dd-mm-yyyy'), '1', '13', '256', '09', '2021', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7928, to_date('14-09-2021', 'dd-mm-yyyy'), '2', '14', '257', '09', '2021', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7929, to_date('15-09-2021', 'dd-mm-yyyy'), '3', '15', '258', '09', '2021', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7930, to_date('16-09-2021', 'dd-mm-yyyy'), '4', '16', '259', '09', '2021', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7931, to_date('17-09-2021', 'dd-mm-yyyy'), '5', '17', '260', '09', '2021', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7932, to_date('18-09-2021', 'dd-mm-yyyy'), '6', '18', '261', '09', '2021', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7933, to_date('19-09-2021', 'dd-mm-yyyy'), '7', '19', '262', '09', '2021', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7934, to_date('20-09-2021', 'dd-mm-yyyy'), '1', '20', '263', '09', '2021', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7935, to_date('21-09-2021', 'dd-mm-yyyy'), '2', '21', '264', '09', '2021', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7936, to_date('22-09-2021', 'dd-mm-yyyy'), '3', '22', '265', '09', '2021', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7937, to_date('23-09-2021', 'dd-mm-yyyy'), '4', '23', '266', '09', '2021', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7938, to_date('24-09-2021', 'dd-mm-yyyy'), '5', '24', '267', '09', '2021', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7939, to_date('25-09-2021', 'dd-mm-yyyy'), '6', '25', '268', '09', '2021', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7940, to_date('26-09-2021', 'dd-mm-yyyy'), '7', '26', '269', '09', '2021', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7941, to_date('27-09-2021', 'dd-mm-yyyy'), '1', '27', '270', '09', '2021', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7942, to_date('28-09-2021', 'dd-mm-yyyy'), '2', '28', '271', '09', '2021', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7943, to_date('29-09-2021', 'dd-mm-yyyy'), '3', '29', '272', '09', '2021', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7944, to_date('30-09-2021', 'dd-mm-yyyy'), '4', '30', '273', '09', '2021', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7945, to_date('01-10-2021', 'dd-mm-yyyy'), '5', '01', '274', '10', '2021', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7946, to_date('02-10-2021', 'dd-mm-yyyy'), '6', '02', '275', '10', '2021', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7947, to_date('03-10-2021', 'dd-mm-yyyy'), '7', '03', '276', '10', '2021', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7948, to_date('04-10-2021', 'dd-mm-yyyy'), '1', '04', '277', '10', '2021', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7949, to_date('05-10-2021', 'dd-mm-yyyy'), '2', '05', '278', '10', '2021', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7950, to_date('06-10-2021', 'dd-mm-yyyy'), '3', '06', '279', '10', '2021', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7951, to_date('07-10-2021', 'dd-mm-yyyy'), '4', '07', '280', '10', '2021', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7952, to_date('08-10-2021', 'dd-mm-yyyy'), '5', '08', '281', '10', '2021', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7953, to_date('09-10-2021', 'dd-mm-yyyy'), '6', '09', '282', '10', '2021', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7954, to_date('10-10-2021', 'dd-mm-yyyy'), '7', '10', '283', '10', '2021', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7955, to_date('11-10-2021', 'dd-mm-yyyy'), '1', '11', '284', '10', '2021', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7956, to_date('12-10-2021', 'dd-mm-yyyy'), '2', '12', '285', '10', '2021', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7957, to_date('13-10-2021', 'dd-mm-yyyy'), '3', '13', '286', '10', '2021', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7958, to_date('14-10-2021', 'dd-mm-yyyy'), '4', '14', '287', '10', '2021', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7959, to_date('15-10-2021', 'dd-mm-yyyy'), '5', '15', '288', '10', '2021', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7960, to_date('16-10-2021', 'dd-mm-yyyy'), '6', '16', '289', '10', '2021', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7961, to_date('17-10-2021', 'dd-mm-yyyy'), '7', '17', '290', '10', '2021', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7962, to_date('18-10-2021', 'dd-mm-yyyy'), '1', '18', '291', '10', '2021', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7963, to_date('19-10-2021', 'dd-mm-yyyy'), '2', '19', '292', '10', '2021', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7964, to_date('20-10-2021', 'dd-mm-yyyy'), '3', '20', '293', '10', '2021', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7965, to_date('21-10-2021', 'dd-mm-yyyy'), '4', '21', '294', '10', '2021', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7966, to_date('22-10-2021', 'dd-mm-yyyy'), '5', '22', '295', '10', '2021', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7967, to_date('23-10-2021', 'dd-mm-yyyy'), '6', '23', '296', '10', '2021', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7968, to_date('24-10-2021', 'dd-mm-yyyy'), '7', '24', '297', '10', '2021', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7969, to_date('25-10-2021', 'dd-mm-yyyy'), '1', '25', '298', '10', '2021', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7970, to_date('26-10-2021', 'dd-mm-yyyy'), '2', '26', '299', '10', '2021', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7971, to_date('27-10-2021', 'dd-mm-yyyy'), '3', '27', '300', '10', '2021', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7972, to_date('28-10-2021', 'dd-mm-yyyy'), '4', '28', '301', '10', '2021', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7973, to_date('29-10-2021', 'dd-mm-yyyy'), '5', '29', '302', '10', '2021', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7974, to_date('30-10-2021', 'dd-mm-yyyy'), '6', '30', '303', '10', '2021', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7975, to_date('31-10-2021', 'dd-mm-yyyy'), '7', '31', '304', '10', '2021', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7976, to_date('01-11-2021', 'dd-mm-yyyy'), '1', '01', '305', '11', '2021', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7977, to_date('02-11-2021', 'dd-mm-yyyy'), '2', '02', '306', '11', '2021', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7978, to_date('03-11-2021', 'dd-mm-yyyy'), '3', '03', '307', '11', '2021', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7979, to_date('04-11-2021', 'dd-mm-yyyy'), '4', '04', '308', '11', '2021', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7980, to_date('05-11-2021', 'dd-mm-yyyy'), '5', '05', '309', '11', '2021', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7981, to_date('06-11-2021', 'dd-mm-yyyy'), '6', '06', '310', '11', '2021', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7982, to_date('07-11-2021', 'dd-mm-yyyy'), '7', '07', '311', '11', '2021', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7983, to_date('08-11-2021', 'dd-mm-yyyy'), '1', '08', '312', '11', '2021', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7984, to_date('09-11-2021', 'dd-mm-yyyy'), '2', '09', '313', '11', '2021', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7985, to_date('10-11-2021', 'dd-mm-yyyy'), '3', '10', '314', '11', '2021', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7986, to_date('11-11-2021', 'dd-mm-yyyy'), '4', '11', '315', '11', '2021', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7987, to_date('12-11-2021', 'dd-mm-yyyy'), '5', '12', '316', '11', '2021', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7988, to_date('13-11-2021', 'dd-mm-yyyy'), '6', '13', '317', '11', '2021', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7989, to_date('14-11-2021', 'dd-mm-yyyy'), '7', '14', '318', '11', '2021', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7990, to_date('15-11-2021', 'dd-mm-yyyy'), '1', '15', '319', '11', '2021', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7991, to_date('16-11-2021', 'dd-mm-yyyy'), '2', '16', '320', '11', '2021', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7992, to_date('17-11-2021', 'dd-mm-yyyy'), '3', '17', '321', '11', '2021', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7993, to_date('18-11-2021', 'dd-mm-yyyy'), '4', '18', '322', '11', '2021', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8534, to_date('13-05-2023', 'dd-mm-yyyy'), '6', '13', '133', '05', '2023', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8535, to_date('14-05-2023', 'dd-mm-yyyy'), '7', '14', '134', '05', '2023', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8536, to_date('15-05-2023', 'dd-mm-yyyy'), '1', '15', '135', '05', '2023', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8537, to_date('16-05-2023', 'dd-mm-yyyy'), '2', '16', '136', '05', '2023', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8538, to_date('17-05-2023', 'dd-mm-yyyy'), '3', '17', '137', '05', '2023', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8539, to_date('18-05-2023', 'dd-mm-yyyy'), '4', '18', '138', '05', '2023', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8540, to_date('19-05-2023', 'dd-mm-yyyy'), '5', '19', '139', '05', '2023', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
commit;
prompt 8000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8541, to_date('20-05-2023', 'dd-mm-yyyy'), '6', '20', '140', '05', '2023', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8542, to_date('21-05-2023', 'dd-mm-yyyy'), '7', '21', '141', '05', '2023', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8543, to_date('22-05-2023', 'dd-mm-yyyy'), '1', '22', '142', '05', '2023', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8544, to_date('23-05-2023', 'dd-mm-yyyy'), '2', '23', '143', '05', '2023', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8545, to_date('24-05-2023', 'dd-mm-yyyy'), '3', '24', '144', '05', '2023', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8546, to_date('25-05-2023', 'dd-mm-yyyy'), '4', '25', '145', '05', '2023', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8547, to_date('26-05-2023', 'dd-mm-yyyy'), '5', '26', '146', '05', '2023', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8548, to_date('27-05-2023', 'dd-mm-yyyy'), '6', '27', '147', '05', '2023', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8549, to_date('28-05-2023', 'dd-mm-yyyy'), '7', '28', '148', '05', '2023', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8550, to_date('29-05-2023', 'dd-mm-yyyy'), '1', '29', '149', '05', '2023', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8551, to_date('30-05-2023', 'dd-mm-yyyy'), '2', '30', '150', '05', '2023', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8552, to_date('31-05-2023', 'dd-mm-yyyy'), '3', '31', '151', '05', '2023', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8553, to_date('01-06-2023', 'dd-mm-yyyy'), '4', '01', '152', '06', '2023', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8554, to_date('02-06-2023', 'dd-mm-yyyy'), '5', '02', '153', '06', '2023', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8555, to_date('03-06-2023', 'dd-mm-yyyy'), '6', '03', '154', '06', '2023', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8556, to_date('04-06-2023', 'dd-mm-yyyy'), '7', '04', '155', '06', '2023', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8557, to_date('05-06-2023', 'dd-mm-yyyy'), '1', '05', '156', '06', '2023', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8558, to_date('06-06-2023', 'dd-mm-yyyy'), '2', '06', '157', '06', '2023', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8559, to_date('07-06-2023', 'dd-mm-yyyy'), '3', '07', '158', '06', '2023', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8560, to_date('08-06-2023', 'dd-mm-yyyy'), '4', '08', '159', '06', '2023', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8561, to_date('09-06-2023', 'dd-mm-yyyy'), '5', '09', '160', '06', '2023', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8562, to_date('10-06-2023', 'dd-mm-yyyy'), '6', '10', '161', '06', '2023', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8563, to_date('11-06-2023', 'dd-mm-yyyy'), '7', '11', '162', '06', '2023', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8564, to_date('12-06-2023', 'dd-mm-yyyy'), '1', '12', '163', '06', '2023', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8565, to_date('13-06-2023', 'dd-mm-yyyy'), '2', '13', '164', '06', '2023', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8566, to_date('14-06-2023', 'dd-mm-yyyy'), '3', '14', '165', '06', '2023', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8567, to_date('15-06-2023', 'dd-mm-yyyy'), '4', '15', '166', '06', '2023', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8568, to_date('16-06-2023', 'dd-mm-yyyy'), '5', '16', '167', '06', '2023', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8569, to_date('17-06-2023', 'dd-mm-yyyy'), '6', '17', '168', '06', '2023', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8570, to_date('18-06-2023', 'dd-mm-yyyy'), '7', '18', '169', '06', '2023', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8571, to_date('19-06-2023', 'dd-mm-yyyy'), '1', '19', '170', '06', '2023', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8572, to_date('20-06-2023', 'dd-mm-yyyy'), '2', '20', '171', '06', '2023', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8573, to_date('21-06-2023', 'dd-mm-yyyy'), '3', '21', '172', '06', '2023', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8574, to_date('22-06-2023', 'dd-mm-yyyy'), '4', '22', '173', '06', '2023', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8575, to_date('23-06-2023', 'dd-mm-yyyy'), '5', '23', '174', '06', '2023', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8576, to_date('24-06-2023', 'dd-mm-yyyy'), '6', '24', '175', '06', '2023', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8577, to_date('25-06-2023', 'dd-mm-yyyy'), '7', '25', '176', '06', '2023', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8578, to_date('26-06-2023', 'dd-mm-yyyy'), '1', '26', '177', '06', '2023', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8579, to_date('27-06-2023', 'dd-mm-yyyy'), '2', '27', '178', '06', '2023', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8580, to_date('28-06-2023', 'dd-mm-yyyy'), '3', '28', '179', '06', '2023', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8581, to_date('29-06-2023', 'dd-mm-yyyy'), '4', '29', '180', '06', '2023', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8582, to_date('30-06-2023', 'dd-mm-yyyy'), '5', '30', '181', '06', '2023', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8583, to_date('01-07-2023', 'dd-mm-yyyy'), '6', '01', '182', '07', '2023', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8584, to_date('02-07-2023', 'dd-mm-yyyy'), '7', '02', '183', '07', '2023', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8585, to_date('03-07-2023', 'dd-mm-yyyy'), '1', '03', '184', '07', '2023', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8586, to_date('04-07-2023', 'dd-mm-yyyy'), '2', '04', '185', '07', '2023', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8587, to_date('05-07-2023', 'dd-mm-yyyy'), '3', '05', '186', '07', '2023', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8588, to_date('06-07-2023', 'dd-mm-yyyy'), '4', '06', '187', '07', '2023', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8589, to_date('07-07-2023', 'dd-mm-yyyy'), '5', '07', '188', '07', '2023', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8590, to_date('08-07-2023', 'dd-mm-yyyy'), '6', '08', '189', '07', '2023', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8591, to_date('09-07-2023', 'dd-mm-yyyy'), '7', '09', '190', '07', '2023', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8592, to_date('10-07-2023', 'dd-mm-yyyy'), '1', '10', '191', '07', '2023', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8593, to_date('11-07-2023', 'dd-mm-yyyy'), '2', '11', '192', '07', '2023', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8594, to_date('12-07-2023', 'dd-mm-yyyy'), '3', '12', '193', '07', '2023', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8595, to_date('13-07-2023', 'dd-mm-yyyy'), '4', '13', '194', '07', '2023', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8596, to_date('14-07-2023', 'dd-mm-yyyy'), '5', '14', '195', '07', '2023', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8597, to_date('15-07-2023', 'dd-mm-yyyy'), '6', '15', '196', '07', '2023', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8598, to_date('16-07-2023', 'dd-mm-yyyy'), '7', '16', '197', '07', '2023', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8599, to_date('17-07-2023', 'dd-mm-yyyy'), '1', '17', '198', '07', '2023', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8600, to_date('18-07-2023', 'dd-mm-yyyy'), '2', '18', '199', '07', '2023', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8601, to_date('19-07-2023', 'dd-mm-yyyy'), '3', '19', '200', '07', '2023', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8602, to_date('20-07-2023', 'dd-mm-yyyy'), '4', '20', '201', '07', '2023', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8603, to_date('21-07-2023', 'dd-mm-yyyy'), '5', '21', '202', '07', '2023', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8604, to_date('22-07-2023', 'dd-mm-yyyy'), '6', '22', '203', '07', '2023', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8605, to_date('23-07-2023', 'dd-mm-yyyy'), '7', '23', '204', '07', '2023', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8606, to_date('24-07-2023', 'dd-mm-yyyy'), '1', '24', '205', '07', '2023', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8607, to_date('25-07-2023', 'dd-mm-yyyy'), '2', '25', '206', '07', '2023', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8608, to_date('26-07-2023', 'dd-mm-yyyy'), '3', '26', '207', '07', '2023', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8609, to_date('27-07-2023', 'dd-mm-yyyy'), '4', '27', '208', '07', '2023', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8610, to_date('28-07-2023', 'dd-mm-yyyy'), '5', '28', '209', '07', '2023', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8611, to_date('29-07-2023', 'dd-mm-yyyy'), '6', '29', '210', '07', '2023', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8612, to_date('30-07-2023', 'dd-mm-yyyy'), '7', '30', '211', '07', '2023', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8613, to_date('31-07-2023', 'dd-mm-yyyy'), '1', '31', '212', '07', '2023', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8614, to_date('01-08-2023', 'dd-mm-yyyy'), '2', '01', '213', '08', '2023', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8615, to_date('02-08-2023', 'dd-mm-yyyy'), '3', '02', '214', '08', '2023', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8616, to_date('03-08-2023', 'dd-mm-yyyy'), '4', '03', '215', '08', '2023', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8617, to_date('04-08-2023', 'dd-mm-yyyy'), '5', '04', '216', '08', '2023', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8618, to_date('05-08-2023', 'dd-mm-yyyy'), '6', '05', '217', '08', '2023', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8619, to_date('06-08-2023', 'dd-mm-yyyy'), '7', '06', '218', '08', '2023', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8620, to_date('07-08-2023', 'dd-mm-yyyy'), '1', '07', '219', '08', '2023', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8621, to_date('08-08-2023', 'dd-mm-yyyy'), '2', '08', '220', '08', '2023', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8622, to_date('09-08-2023', 'dd-mm-yyyy'), '3', '09', '221', '08', '2023', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8623, to_date('10-08-2023', 'dd-mm-yyyy'), '4', '10', '222', '08', '2023', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8624, to_date('11-08-2023', 'dd-mm-yyyy'), '5', '11', '223', '08', '2023', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8625, to_date('12-08-2023', 'dd-mm-yyyy'), '6', '12', '224', '08', '2023', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8626, to_date('13-08-2023', 'dd-mm-yyyy'), '7', '13', '225', '08', '2023', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8627, to_date('14-08-2023', 'dd-mm-yyyy'), '1', '14', '226', '08', '2023', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8628, to_date('15-08-2023', 'dd-mm-yyyy'), '2', '15', '227', '08', '2023', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8629, to_date('16-08-2023', 'dd-mm-yyyy'), '3', '16', '228', '08', '2023', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8630, to_date('17-08-2023', 'dd-mm-yyyy'), '4', '17', '229', '08', '2023', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8631, to_date('18-08-2023', 'dd-mm-yyyy'), '5', '18', '230', '08', '2023', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8632, to_date('19-08-2023', 'dd-mm-yyyy'), '6', '19', '231', '08', '2023', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8633, to_date('20-08-2023', 'dd-mm-yyyy'), '7', '20', '232', '08', '2023', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8634, to_date('21-08-2023', 'dd-mm-yyyy'), '1', '21', '233', '08', '2023', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8635, to_date('22-08-2023', 'dd-mm-yyyy'), '2', '22', '234', '08', '2023', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8636, to_date('23-08-2023', 'dd-mm-yyyy'), '3', '23', '235', '08', '2023', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8637, to_date('24-08-2023', 'dd-mm-yyyy'), '4', '24', '236', '08', '2023', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8638, to_date('25-08-2023', 'dd-mm-yyyy'), '5', '25', '237', '08', '2023', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8639, to_date('26-08-2023', 'dd-mm-yyyy'), '6', '26', '238', '08', '2023', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8640, to_date('27-08-2023', 'dd-mm-yyyy'), '7', '27', '239', '08', '2023', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8641, to_date('28-08-2023', 'dd-mm-yyyy'), '1', '28', '240', '08', '2023', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7994, to_date('19-11-2021', 'dd-mm-yyyy'), '5', '19', '323', '11', '2021', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7995, to_date('20-11-2021', 'dd-mm-yyyy'), '6', '20', '324', '11', '2021', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7996, to_date('21-11-2021', 'dd-mm-yyyy'), '7', '21', '325', '11', '2021', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7997, to_date('22-11-2021', 'dd-mm-yyyy'), '1', '22', '326', '11', '2021', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7998, to_date('23-11-2021', 'dd-mm-yyyy'), '2', '23', '327', '11', '2021', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (7999, to_date('24-11-2021', 'dd-mm-yyyy'), '3', '24', '328', '11', '2021', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8000, to_date('25-11-2021', 'dd-mm-yyyy'), '4', '25', '329', '11', '2021', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8001, to_date('26-11-2021', 'dd-mm-yyyy'), '5', '26', '330', '11', '2021', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8002, to_date('27-11-2021', 'dd-mm-yyyy'), '6', '27', '331', '11', '2021', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8003, to_date('28-11-2021', 'dd-mm-yyyy'), '7', '28', '332', '11', '2021', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8004, to_date('29-11-2021', 'dd-mm-yyyy'), '1', '29', '333', '11', '2021', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8005, to_date('30-11-2021', 'dd-mm-yyyy'), '2', '30', '334', '11', '2021', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8006, to_date('01-12-2021', 'dd-mm-yyyy'), '3', '01', '335', '12', '2021', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8007, to_date('02-12-2021', 'dd-mm-yyyy'), '4', '02', '336', '12', '2021', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8008, to_date('03-12-2021', 'dd-mm-yyyy'), '5', '03', '337', '12', '2021', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8009, to_date('04-12-2021', 'dd-mm-yyyy'), '6', '04', '338', '12', '2021', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8010, to_date('05-12-2021', 'dd-mm-yyyy'), '7', '05', '339', '12', '2021', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8011, to_date('06-12-2021', 'dd-mm-yyyy'), '1', '06', '340', '12', '2021', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8012, to_date('07-12-2021', 'dd-mm-yyyy'), '2', '07', '341', '12', '2021', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8013, to_date('08-12-2021', 'dd-mm-yyyy'), '3', '08', '342', '12', '2021', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8014, to_date('09-12-2021', 'dd-mm-yyyy'), '4', '09', '343', '12', '2021', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8015, to_date('10-12-2021', 'dd-mm-yyyy'), '5', '10', '344', '12', '2021', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8016, to_date('11-12-2021', 'dd-mm-yyyy'), '6', '11', '345', '12', '2021', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8017, to_date('12-12-2021', 'dd-mm-yyyy'), '7', '12', '346', '12', '2021', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8018, to_date('13-12-2021', 'dd-mm-yyyy'), '1', '13', '347', '12', '2021', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8019, to_date('14-12-2021', 'dd-mm-yyyy'), '2', '14', '348', '12', '2021', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8020, to_date('15-12-2021', 'dd-mm-yyyy'), '3', '15', '349', '12', '2021', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8021, to_date('16-12-2021', 'dd-mm-yyyy'), '4', '16', '350', '12', '2021', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8022, to_date('17-12-2021', 'dd-mm-yyyy'), '5', '17', '351', '12', '2021', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8023, to_date('18-12-2021', 'dd-mm-yyyy'), '6', '18', '352', '12', '2021', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8024, to_date('19-12-2021', 'dd-mm-yyyy'), '7', '19', '353', '12', '2021', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8025, to_date('20-12-2021', 'dd-mm-yyyy'), '1', '20', '354', '12', '2021', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8026, to_date('21-12-2021', 'dd-mm-yyyy'), '2', '21', '355', '12', '2021', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8027, to_date('22-12-2021', 'dd-mm-yyyy'), '3', '22', '356', '12', '2021', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8028, to_date('23-12-2021', 'dd-mm-yyyy'), '4', '23', '357', '12', '2021', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8029, to_date('24-12-2021', 'dd-mm-yyyy'), '5', '24', '358', '12', '2021', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8030, to_date('25-12-2021', 'dd-mm-yyyy'), '6', '25', '359', '12', '2021', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8031, to_date('26-12-2021', 'dd-mm-yyyy'), '7', '26', '360', '12', '2021', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8032, to_date('27-12-2021', 'dd-mm-yyyy'), '1', '27', '361', '12', '2021', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8033, to_date('28-12-2021', 'dd-mm-yyyy'), '2', '28', '362', '12', '2021', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8034, to_date('29-12-2021', 'dd-mm-yyyy'), '3', '29', '363', '12', '2021', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8035, to_date('30-12-2021', 'dd-mm-yyyy'), '4', '30', '364', '12', '2021', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8036, to_date('31-12-2021', 'dd-mm-yyyy'), '5', '31', '365', '12', '2021', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8037, to_date('01-01-2022', 'dd-mm-yyyy'), '6', '01', '001', '01', '2022', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8038, to_date('02-01-2022', 'dd-mm-yyyy'), '7', '02', '002', '01', '2022', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8039, to_date('03-01-2022', 'dd-mm-yyyy'), '1', '03', '003', '01', '2022', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8040, to_date('04-01-2022', 'dd-mm-yyyy'), '2', '04', '004', '01', '2022', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8041, to_date('05-01-2022', 'dd-mm-yyyy'), '3', '05', '005', '01', '2022', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8042, to_date('06-01-2022', 'dd-mm-yyyy'), '4', '06', '006', '01', '2022', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8043, to_date('07-01-2022', 'dd-mm-yyyy'), '5', '07', '007', '01', '2022', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8044, to_date('08-01-2022', 'dd-mm-yyyy'), '6', '08', '008', '01', '2022', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8045, to_date('09-01-2022', 'dd-mm-yyyy'), '7', '09', '009', '01', '2022', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8046, to_date('10-01-2022', 'dd-mm-yyyy'), '1', '10', '010', '01', '2022', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8047, to_date('11-01-2022', 'dd-mm-yyyy'), '2', '11', '011', '01', '2022', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8048, to_date('12-01-2022', 'dd-mm-yyyy'), '3', '12', '012', '01', '2022', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8049, to_date('13-01-2022', 'dd-mm-yyyy'), '4', '13', '013', '01', '2022', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8050, to_date('14-01-2022', 'dd-mm-yyyy'), '5', '14', '014', '01', '2022', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8051, to_date('15-01-2022', 'dd-mm-yyyy'), '6', '15', '015', '01', '2022', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8052, to_date('16-01-2022', 'dd-mm-yyyy'), '7', '16', '016', '01', '2022', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8053, to_date('17-01-2022', 'dd-mm-yyyy'), '1', '17', '017', '01', '2022', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8054, to_date('18-01-2022', 'dd-mm-yyyy'), '2', '18', '018', '01', '2022', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8055, to_date('19-01-2022', 'dd-mm-yyyy'), '3', '19', '019', '01', '2022', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8056, to_date('20-01-2022', 'dd-mm-yyyy'), '4', '20', '020', '01', '2022', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8057, to_date('21-01-2022', 'dd-mm-yyyy'), '5', '21', '021', '01', '2022', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8058, to_date('22-01-2022', 'dd-mm-yyyy'), '6', '22', '022', '01', '2022', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8059, to_date('23-01-2022', 'dd-mm-yyyy'), '7', '23', '023', '01', '2022', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8060, to_date('24-01-2022', 'dd-mm-yyyy'), '1', '24', '024', '01', '2022', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8061, to_date('25-01-2022', 'dd-mm-yyyy'), '2', '25', '025', '01', '2022', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8062, to_date('26-01-2022', 'dd-mm-yyyy'), '3', '26', '026', '01', '2022', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8063, to_date('27-01-2022', 'dd-mm-yyyy'), '4', '27', '027', '01', '2022', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8064, to_date('28-01-2022', 'dd-mm-yyyy'), '5', '28', '028', '01', '2022', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8065, to_date('29-01-2022', 'dd-mm-yyyy'), '6', '29', '029', '01', '2022', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8066, to_date('30-01-2022', 'dd-mm-yyyy'), '7', '30', '030', '01', '2022', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8067, to_date('31-01-2022', 'dd-mm-yyyy'), '1', '31', '031', '01', '2022', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8068, to_date('01-02-2022', 'dd-mm-yyyy'), '2', '01', '032', '02', '2022', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8069, to_date('02-02-2022', 'dd-mm-yyyy'), '3', '02', '033', '02', '2022', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8070, to_date('03-02-2022', 'dd-mm-yyyy'), '4', '03', '034', '02', '2022', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8071, to_date('04-02-2022', 'dd-mm-yyyy'), '5', '04', '035', '02', '2022', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8072, to_date('05-02-2022', 'dd-mm-yyyy'), '6', '05', '036', '02', '2022', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8073, to_date('06-02-2022', 'dd-mm-yyyy'), '7', '06', '037', '02', '2022', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8074, to_date('07-02-2022', 'dd-mm-yyyy'), '1', '07', '038', '02', '2022', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8075, to_date('08-02-2022', 'dd-mm-yyyy'), '2', '08', '039', '02', '2022', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8076, to_date('09-02-2022', 'dd-mm-yyyy'), '3', '09', '040', '02', '2022', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8077, to_date('10-02-2022', 'dd-mm-yyyy'), '4', '10', '041', '02', '2022', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8078, to_date('11-02-2022', 'dd-mm-yyyy'), '5', '11', '042', '02', '2022', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8079, to_date('12-02-2022', 'dd-mm-yyyy'), '6', '12', '043', '02', '2022', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8080, to_date('13-02-2022', 'dd-mm-yyyy'), '7', '13', '044', '02', '2022', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8081, to_date('14-02-2022', 'dd-mm-yyyy'), '1', '14', '045', '02', '2022', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8082, to_date('15-02-2022', 'dd-mm-yyyy'), '2', '15', '046', '02', '2022', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8083, to_date('16-02-2022', 'dd-mm-yyyy'), '3', '16', '047', '02', '2022', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8084, to_date('17-02-2022', 'dd-mm-yyyy'), '4', '17', '048', '02', '2022', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8085, to_date('18-02-2022', 'dd-mm-yyyy'), '5', '18', '049', '02', '2022', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8086, to_date('19-02-2022', 'dd-mm-yyyy'), '6', '19', '050', '02', '2022', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8087, to_date('20-02-2022', 'dd-mm-yyyy'), '7', '20', '051', '02', '2022', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8088, to_date('21-02-2022', 'dd-mm-yyyy'), '1', '21', '052', '02', '2022', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8089, to_date('22-02-2022', 'dd-mm-yyyy'), '2', '22', '053', '02', '2022', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8090, to_date('23-02-2022', 'dd-mm-yyyy'), '3', '23', '054', '02', '2022', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8091, to_date('24-02-2022', 'dd-mm-yyyy'), '4', '24', '055', '02', '2022', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8092, to_date('25-02-2022', 'dd-mm-yyyy'), '5', '25', '056', '02', '2022', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8093, to_date('26-02-2022', 'dd-mm-yyyy'), '6', '26', '057', '02', '2022', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8094, to_date('27-02-2022', 'dd-mm-yyyy'), '7', '27', '058', '02', '2022', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8095, to_date('28-02-2022', 'dd-mm-yyyy'), '1', '28', '059', '02', '2022', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8096, to_date('01-03-2022', 'dd-mm-yyyy'), '2', '01', '060', '03', '2022', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8097, to_date('02-03-2022', 'dd-mm-yyyy'), '3', '02', '061', '03', '2022', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8098, to_date('03-03-2022', 'dd-mm-yyyy'), '4', '03', '062', '03', '2022', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8099, to_date('04-03-2022', 'dd-mm-yyyy'), '5', '04', '063', '03', '2022', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8100, to_date('05-03-2022', 'dd-mm-yyyy'), '6', '05', '064', '03', '2022', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8101, to_date('06-03-2022', 'dd-mm-yyyy'), '7', '06', '065', '03', '2022', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8102, to_date('07-03-2022', 'dd-mm-yyyy'), '1', '07', '066', '03', '2022', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8103, to_date('08-03-2022', 'dd-mm-yyyy'), '2', '08', '067', '03', '2022', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8104, to_date('09-03-2022', 'dd-mm-yyyy'), '3', '09', '068', '03', '2022', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8105, to_date('10-03-2022', 'dd-mm-yyyy'), '4', '10', '069', '03', '2022', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8106, to_date('11-03-2022', 'dd-mm-yyyy'), '5', '11', '070', '03', '2022', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8107, to_date('12-03-2022', 'dd-mm-yyyy'), '6', '12', '071', '03', '2022', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8108, to_date('13-03-2022', 'dd-mm-yyyy'), '7', '13', '072', '03', '2022', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8109, to_date('14-03-2022', 'dd-mm-yyyy'), '1', '14', '073', '03', '2022', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8110, to_date('15-03-2022', 'dd-mm-yyyy'), '2', '15', '074', '03', '2022', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8111, to_date('16-03-2022', 'dd-mm-yyyy'), '3', '16', '075', '03', '2022', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8112, to_date('17-03-2022', 'dd-mm-yyyy'), '4', '17', '076', '03', '2022', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8113, to_date('18-03-2022', 'dd-mm-yyyy'), '5', '18', '077', '03', '2022', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8114, to_date('19-03-2022', 'dd-mm-yyyy'), '6', '19', '078', '03', '2022', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8115, to_date('20-03-2022', 'dd-mm-yyyy'), '7', '20', '079', '03', '2022', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8116, to_date('21-03-2022', 'dd-mm-yyyy'), '1', '21', '080', '03', '2022', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8117, to_date('22-03-2022', 'dd-mm-yyyy'), '2', '22', '081', '03', '2022', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8118, to_date('23-03-2022', 'dd-mm-yyyy'), '3', '23', '082', '03', '2022', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8119, to_date('24-03-2022', 'dd-mm-yyyy'), '4', '24', '083', '03', '2022', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8120, to_date('25-03-2022', 'dd-mm-yyyy'), '5', '25', '084', '03', '2022', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8121, to_date('26-03-2022', 'dd-mm-yyyy'), '6', '26', '085', '03', '2022', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8122, to_date('27-03-2022', 'dd-mm-yyyy'), '7', '27', '086', '03', '2022', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8123, to_date('28-03-2022', 'dd-mm-yyyy'), '1', '28', '087', '03', '2022', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8124, to_date('29-03-2022', 'dd-mm-yyyy'), '2', '29', '088', '03', '2022', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8125, to_date('30-03-2022', 'dd-mm-yyyy'), '3', '30', '089', '03', '2022', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8126, to_date('31-03-2022', 'dd-mm-yyyy'), '4', '31', '090', '03', '2022', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8127, to_date('01-04-2022', 'dd-mm-yyyy'), '5', '01', '091', '04', '2022', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8128, to_date('02-04-2022', 'dd-mm-yyyy'), '6', '02', '092', '04', '2022', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8129, to_date('03-04-2022', 'dd-mm-yyyy'), '7', '03', '093', '04', '2022', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8130, to_date('04-04-2022', 'dd-mm-yyyy'), '1', '04', '094', '04', '2022', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8131, to_date('05-04-2022', 'dd-mm-yyyy'), '2', '05', '095', '04', '2022', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8132, to_date('06-04-2022', 'dd-mm-yyyy'), '3', '06', '096', '04', '2022', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8133, to_date('07-04-2022', 'dd-mm-yyyy'), '4', '07', '097', '04', '2022', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8134, to_date('08-04-2022', 'dd-mm-yyyy'), '5', '08', '098', '04', '2022', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8135, to_date('09-04-2022', 'dd-mm-yyyy'), '6', '09', '099', '04', '2022', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8136, to_date('10-04-2022', 'dd-mm-yyyy'), '7', '10', '100', '04', '2022', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8137, to_date('11-04-2022', 'dd-mm-yyyy'), '1', '11', '101', '04', '2022', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8138, to_date('12-04-2022', 'dd-mm-yyyy'), '2', '12', '102', '04', '2022', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8139, to_date('13-04-2022', 'dd-mm-yyyy'), '3', '13', '103', '04', '2022', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8140, to_date('14-04-2022', 'dd-mm-yyyy'), '4', '14', '104', '04', '2022', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8141, to_date('15-04-2022', 'dd-mm-yyyy'), '5', '15', '105', '04', '2022', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8142, to_date('16-04-2022', 'dd-mm-yyyy'), '6', '16', '106', '04', '2022', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8143, to_date('17-04-2022', 'dd-mm-yyyy'), '7', '17', '107', '04', '2022', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8144, to_date('18-04-2022', 'dd-mm-yyyy'), '1', '18', '108', '04', '2022', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8145, to_date('19-04-2022', 'dd-mm-yyyy'), '2', '19', '109', '04', '2022', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8146, to_date('20-04-2022', 'dd-mm-yyyy'), '3', '20', '110', '04', '2022', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8147, to_date('21-04-2022', 'dd-mm-yyyy'), '4', '21', '111', '04', '2022', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8148, to_date('22-04-2022', 'dd-mm-yyyy'), '5', '22', '112', '04', '2022', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8149, to_date('23-04-2022', 'dd-mm-yyyy'), '6', '23', '113', '04', '2022', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8150, to_date('24-04-2022', 'dd-mm-yyyy'), '7', '24', '114', '04', '2022', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8151, to_date('25-04-2022', 'dd-mm-yyyy'), '1', '25', '115', '04', '2022', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8152, to_date('26-04-2022', 'dd-mm-yyyy'), '2', '26', '116', '04', '2022', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8153, to_date('27-04-2022', 'dd-mm-yyyy'), '3', '27', '117', '04', '2022', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8154, to_date('28-04-2022', 'dd-mm-yyyy'), '4', '28', '118', '04', '2022', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8155, to_date('29-04-2022', 'dd-mm-yyyy'), '5', '29', '119', '04', '2022', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8156, to_date('30-04-2022', 'dd-mm-yyyy'), '6', '30', '120', '04', '2022', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8157, to_date('01-05-2022', 'dd-mm-yyyy'), '7', '01', '121', '05', '2022', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8158, to_date('02-05-2022', 'dd-mm-yyyy'), '1', '02', '122', '05', '2022', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8159, to_date('03-05-2022', 'dd-mm-yyyy'), '2', '03', '123', '05', '2022', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8160, to_date('04-05-2022', 'dd-mm-yyyy'), '3', '04', '124', '05', '2022', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8161, to_date('05-05-2022', 'dd-mm-yyyy'), '4', '05', '125', '05', '2022', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8162, to_date('06-05-2022', 'dd-mm-yyyy'), '5', '06', '126', '05', '2022', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8163, to_date('07-05-2022', 'dd-mm-yyyy'), '6', '07', '127', '05', '2022', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8164, to_date('08-05-2022', 'dd-mm-yyyy'), '7', '08', '128', '05', '2022', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8165, to_date('09-05-2022', 'dd-mm-yyyy'), '1', '09', '129', '05', '2022', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8166, to_date('10-05-2022', 'dd-mm-yyyy'), '2', '10', '130', '05', '2022', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8167, to_date('11-05-2022', 'dd-mm-yyyy'), '3', '11', '131', '05', '2022', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8168, to_date('12-05-2022', 'dd-mm-yyyy'), '4', '12', '132', '05', '2022', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8169, to_date('13-05-2022', 'dd-mm-yyyy'), '5', '13', '133', '05', '2022', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8170, to_date('14-05-2022', 'dd-mm-yyyy'), '6', '14', '134', '05', '2022', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8171, to_date('15-05-2022', 'dd-mm-yyyy'), '7', '15', '135', '05', '2022', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8172, to_date('16-05-2022', 'dd-mm-yyyy'), '1', '16', '136', '05', '2022', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8173, to_date('17-05-2022', 'dd-mm-yyyy'), '2', '17', '137', '05', '2022', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8174, to_date('18-05-2022', 'dd-mm-yyyy'), '3', '18', '138', '05', '2022', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8175, to_date('19-05-2022', 'dd-mm-yyyy'), '4', '19', '139', '05', '2022', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8176, to_date('20-05-2022', 'dd-mm-yyyy'), '5', '20', '140', '05', '2022', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8177, to_date('21-05-2022', 'dd-mm-yyyy'), '6', '21', '141', '05', '2022', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8178, to_date('22-05-2022', 'dd-mm-yyyy'), '7', '22', '142', '05', '2022', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8179, to_date('23-05-2022', 'dd-mm-yyyy'), '1', '23', '143', '05', '2022', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8180, to_date('24-05-2022', 'dd-mm-yyyy'), '2', '24', '144', '05', '2022', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8181, to_date('25-05-2022', 'dd-mm-yyyy'), '3', '25', '145', '05', '2022', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8182, to_date('26-05-2022', 'dd-mm-yyyy'), '4', '26', '146', '05', '2022', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8183, to_date('27-05-2022', 'dd-mm-yyyy'), '5', '27', '147', '05', '2022', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8184, to_date('28-05-2022', 'dd-mm-yyyy'), '6', '28', '148', '05', '2022', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8185, to_date('29-05-2022', 'dd-mm-yyyy'), '7', '29', '149', '05', '2022', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8186, to_date('30-05-2022', 'dd-mm-yyyy'), '1', '30', '150', '05', '2022', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8187, to_date('31-05-2022', 'dd-mm-yyyy'), '2', '31', '151', '05', '2022', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8188, to_date('01-06-2022', 'dd-mm-yyyy'), '3', '01', '152', '06', '2022', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8189, to_date('02-06-2022', 'dd-mm-yyyy'), '4', '02', '153', '06', '2022', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8190, to_date('03-06-2022', 'dd-mm-yyyy'), '5', '03', '154', '06', '2022', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8191, to_date('04-06-2022', 'dd-mm-yyyy'), '6', '04', '155', '06', '2022', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8192, to_date('05-06-2022', 'dd-mm-yyyy'), '7', '05', '156', '06', '2022', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8193, to_date('06-06-2022', 'dd-mm-yyyy'), '1', '06', '157', '06', '2022', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8194, to_date('07-06-2022', 'dd-mm-yyyy'), '2', '07', '158', '06', '2022', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8195, to_date('08-06-2022', 'dd-mm-yyyy'), '3', '08', '159', '06', '2022', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8196, to_date('09-06-2022', 'dd-mm-yyyy'), '4', '09', '160', '06', '2022', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8197, to_date('10-06-2022', 'dd-mm-yyyy'), '5', '10', '161', '06', '2022', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8198, to_date('11-06-2022', 'dd-mm-yyyy'), '6', '11', '162', '06', '2022', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8199, to_date('12-06-2022', 'dd-mm-yyyy'), '7', '12', '163', '06', '2022', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8200, to_date('13-06-2022', 'dd-mm-yyyy'), '1', '13', '164', '06', '2022', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8201, to_date('14-06-2022', 'dd-mm-yyyy'), '2', '14', '165', '06', '2022', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8202, to_date('15-06-2022', 'dd-mm-yyyy'), '3', '15', '166', '06', '2022', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8203, to_date('16-06-2022', 'dd-mm-yyyy'), '4', '16', '167', '06', '2022', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8204, to_date('17-06-2022', 'dd-mm-yyyy'), '5', '17', '168', '06', '2022', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8205, to_date('18-06-2022', 'dd-mm-yyyy'), '6', '18', '169', '06', '2022', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8206, to_date('19-06-2022', 'dd-mm-yyyy'), '7', '19', '170', '06', '2022', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8207, to_date('20-06-2022', 'dd-mm-yyyy'), '1', '20', '171', '06', '2022', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8208, to_date('21-06-2022', 'dd-mm-yyyy'), '2', '21', '172', '06', '2022', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8209, to_date('22-06-2022', 'dd-mm-yyyy'), '3', '22', '173', '06', '2022', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8210, to_date('23-06-2022', 'dd-mm-yyyy'), '4', '23', '174', '06', '2022', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8211, to_date('24-06-2022', 'dd-mm-yyyy'), '5', '24', '175', '06', '2022', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8212, to_date('25-06-2022', 'dd-mm-yyyy'), '6', '25', '176', '06', '2022', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8213, to_date('26-06-2022', 'dd-mm-yyyy'), '7', '26', '177', '06', '2022', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8214, to_date('27-06-2022', 'dd-mm-yyyy'), '1', '27', '178', '06', '2022', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8215, to_date('28-06-2022', 'dd-mm-yyyy'), '2', '28', '179', '06', '2022', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8216, to_date('29-06-2022', 'dd-mm-yyyy'), '3', '29', '180', '06', '2022', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8217, to_date('30-06-2022', 'dd-mm-yyyy'), '4', '30', '181', '06', '2022', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8218, to_date('01-07-2022', 'dd-mm-yyyy'), '5', '01', '182', '07', '2022', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8219, to_date('02-07-2022', 'dd-mm-yyyy'), '6', '02', '183', '07', '2022', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8220, to_date('03-07-2022', 'dd-mm-yyyy'), '7', '03', '184', '07', '2022', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8221, to_date('04-07-2022', 'dd-mm-yyyy'), '1', '04', '185', '07', '2022', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8222, to_date('05-07-2022', 'dd-mm-yyyy'), '2', '05', '186', '07', '2022', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8223, to_date('06-07-2022', 'dd-mm-yyyy'), '3', '06', '187', '07', '2022', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8224, to_date('07-07-2022', 'dd-mm-yyyy'), '4', '07', '188', '07', '2022', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8225, to_date('08-07-2022', 'dd-mm-yyyy'), '5', '08', '189', '07', '2022', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8226, to_date('09-07-2022', 'dd-mm-yyyy'), '6', '09', '190', '07', '2022', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8227, to_date('10-07-2022', 'dd-mm-yyyy'), '7', '10', '191', '07', '2022', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8228, to_date('11-07-2022', 'dd-mm-yyyy'), '1', '11', '192', '07', '2022', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8229, to_date('12-07-2022', 'dd-mm-yyyy'), '2', '12', '193', '07', '2022', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8230, to_date('13-07-2022', 'dd-mm-yyyy'), '3', '13', '194', '07', '2022', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8231, to_date('14-07-2022', 'dd-mm-yyyy'), '4', '14', '195', '07', '2022', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8232, to_date('15-07-2022', 'dd-mm-yyyy'), '5', '15', '196', '07', '2022', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8233, to_date('16-07-2022', 'dd-mm-yyyy'), '6', '16', '197', '07', '2022', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8234, to_date('17-07-2022', 'dd-mm-yyyy'), '7', '17', '198', '07', '2022', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8235, to_date('18-07-2022', 'dd-mm-yyyy'), '1', '18', '199', '07', '2022', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8236, to_date('19-07-2022', 'dd-mm-yyyy'), '2', '19', '200', '07', '2022', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8237, to_date('20-07-2022', 'dd-mm-yyyy'), '3', '20', '201', '07', '2022', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8238, to_date('21-07-2022', 'dd-mm-yyyy'), '4', '21', '202', '07', '2022', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8239, to_date('22-07-2022', 'dd-mm-yyyy'), '5', '22', '203', '07', '2022', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8240, to_date('23-07-2022', 'dd-mm-yyyy'), '6', '23', '204', '07', '2022', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8241, to_date('24-07-2022', 'dd-mm-yyyy'), '7', '24', '205', '07', '2022', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8242, to_date('25-07-2022', 'dd-mm-yyyy'), '1', '25', '206', '07', '2022', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8243, to_date('26-07-2022', 'dd-mm-yyyy'), '2', '26', '207', '07', '2022', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8244, to_date('27-07-2022', 'dd-mm-yyyy'), '3', '27', '208', '07', '2022', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8245, to_date('28-07-2022', 'dd-mm-yyyy'), '4', '28', '209', '07', '2022', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8246, to_date('29-07-2022', 'dd-mm-yyyy'), '5', '29', '210', '07', '2022', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8247, to_date('30-07-2022', 'dd-mm-yyyy'), '6', '30', '211', '07', '2022', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8248, to_date('31-07-2022', 'dd-mm-yyyy'), '7', '31', '212', '07', '2022', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8249, to_date('01-08-2022', 'dd-mm-yyyy'), '1', '01', '213', '08', '2022', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8250, to_date('02-08-2022', 'dd-mm-yyyy'), '2', '02', '214', '08', '2022', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8251, to_date('03-08-2022', 'dd-mm-yyyy'), '3', '03', '215', '08', '2022', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8252, to_date('04-08-2022', 'dd-mm-yyyy'), '4', '04', '216', '08', '2022', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8253, to_date('05-08-2022', 'dd-mm-yyyy'), '5', '05', '217', '08', '2022', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8254, to_date('06-08-2022', 'dd-mm-yyyy'), '6', '06', '218', '08', '2022', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8255, to_date('07-08-2022', 'dd-mm-yyyy'), '7', '07', '219', '08', '2022', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8256, to_date('08-08-2022', 'dd-mm-yyyy'), '1', '08', '220', '08', '2022', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8257, to_date('09-08-2022', 'dd-mm-yyyy'), '2', '09', '221', '08', '2022', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8258, to_date('10-08-2022', 'dd-mm-yyyy'), '3', '10', '222', '08', '2022', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8259, to_date('11-08-2022', 'dd-mm-yyyy'), '4', '11', '223', '08', '2022', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8260, to_date('12-08-2022', 'dd-mm-yyyy'), '5', '12', '224', '08', '2022', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8261, to_date('13-08-2022', 'dd-mm-yyyy'), '6', '13', '225', '08', '2022', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8262, to_date('14-08-2022', 'dd-mm-yyyy'), '7', '14', '226', '08', '2022', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8263, to_date('15-08-2022', 'dd-mm-yyyy'), '1', '15', '227', '08', '2022', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8264, to_date('16-08-2022', 'dd-mm-yyyy'), '2', '16', '228', '08', '2022', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8265, to_date('17-08-2022', 'dd-mm-yyyy'), '3', '17', '229', '08', '2022', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8266, to_date('18-08-2022', 'dd-mm-yyyy'), '4', '18', '230', '08', '2022', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8267, to_date('19-08-2022', 'dd-mm-yyyy'), '5', '19', '231', '08', '2022', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8268, to_date('20-08-2022', 'dd-mm-yyyy'), '6', '20', '232', '08', '2022', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8269, to_date('21-08-2022', 'dd-mm-yyyy'), '7', '21', '233', '08', '2022', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8270, to_date('22-08-2022', 'dd-mm-yyyy'), '1', '22', '234', '08', '2022', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8271, to_date('23-08-2022', 'dd-mm-yyyy'), '2', '23', '235', '08', '2022', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8272, to_date('24-08-2022', 'dd-mm-yyyy'), '3', '24', '236', '08', '2022', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8273, to_date('25-08-2022', 'dd-mm-yyyy'), '4', '25', '237', '08', '2022', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8274, to_date('26-08-2022', 'dd-mm-yyyy'), '5', '26', '238', '08', '2022', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8275, to_date('27-08-2022', 'dd-mm-yyyy'), '6', '27', '239', '08', '2022', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8276, to_date('28-08-2022', 'dd-mm-yyyy'), '7', '28', '240', '08', '2022', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8277, to_date('29-08-2022', 'dd-mm-yyyy'), '1', '29', '241', '08', '2022', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8278, to_date('30-08-2022', 'dd-mm-yyyy'), '2', '30', '242', '08', '2022', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8279, to_date('31-08-2022', 'dd-mm-yyyy'), '3', '31', '243', '08', '2022', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8280, to_date('01-09-2022', 'dd-mm-yyyy'), '4', '01', '244', '09', '2022', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8281, to_date('02-09-2022', 'dd-mm-yyyy'), '5', '02', '245', '09', '2022', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8282, to_date('03-09-2022', 'dd-mm-yyyy'), '6', '03', '246', '09', '2022', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8283, to_date('04-09-2022', 'dd-mm-yyyy'), '7', '04', '247', '09', '2022', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8284, to_date('05-09-2022', 'dd-mm-yyyy'), '1', '05', '248', '09', '2022', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8285, to_date('06-09-2022', 'dd-mm-yyyy'), '2', '06', '249', '09', '2022', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8286, to_date('07-09-2022', 'dd-mm-yyyy'), '3', '07', '250', '09', '2022', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8287, to_date('08-09-2022', 'dd-mm-yyyy'), '4', '08', '251', '09', '2022', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8288, to_date('09-09-2022', 'dd-mm-yyyy'), '5', '09', '252', '09', '2022', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8289, to_date('10-09-2022', 'dd-mm-yyyy'), '6', '10', '253', '09', '2022', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8290, to_date('11-09-2022', 'dd-mm-yyyy'), '7', '11', '254', '09', '2022', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8291, to_date('12-09-2022', 'dd-mm-yyyy'), '1', '12', '255', '09', '2022', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8292, to_date('13-09-2022', 'dd-mm-yyyy'), '2', '13', '256', '09', '2022', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8293, to_date('14-09-2022', 'dd-mm-yyyy'), '3', '14', '257', '09', '2022', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8294, to_date('15-09-2022', 'dd-mm-yyyy'), '4', '15', '258', '09', '2022', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8295, to_date('16-09-2022', 'dd-mm-yyyy'), '5', '16', '259', '09', '2022', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8296, to_date('17-09-2022', 'dd-mm-yyyy'), '6', '17', '260', '09', '2022', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8297, to_date('18-09-2022', 'dd-mm-yyyy'), '7', '18', '261', '09', '2022', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8298, to_date('19-09-2022', 'dd-mm-yyyy'), '1', '19', '262', '09', '2022', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8299, to_date('20-09-2022', 'dd-mm-yyyy'), '2', '20', '263', '09', '2022', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8300, to_date('21-09-2022', 'dd-mm-yyyy'), '3', '21', '264', '09', '2022', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8301, to_date('22-09-2022', 'dd-mm-yyyy'), '4', '22', '265', '09', '2022', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8302, to_date('23-09-2022', 'dd-mm-yyyy'), '5', '23', '266', '09', '2022', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8303, to_date('24-09-2022', 'dd-mm-yyyy'), '6', '24', '267', '09', '2022', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8304, to_date('25-09-2022', 'dd-mm-yyyy'), '7', '25', '268', '09', '2022', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8305, to_date('26-09-2022', 'dd-mm-yyyy'), '1', '26', '269', '09', '2022', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8306, to_date('27-09-2022', 'dd-mm-yyyy'), '2', '27', '270', '09', '2022', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8307, to_date('28-09-2022', 'dd-mm-yyyy'), '3', '28', '271', '09', '2022', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8308, to_date('29-09-2022', 'dd-mm-yyyy'), '4', '29', '272', '09', '2022', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8309, to_date('30-09-2022', 'dd-mm-yyyy'), '5', '30', '273', '09', '2022', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8310, to_date('01-10-2022', 'dd-mm-yyyy'), '6', '01', '274', '10', '2022', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8311, to_date('02-10-2022', 'dd-mm-yyyy'), '7', '02', '275', '10', '2022', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8312, to_date('03-10-2022', 'dd-mm-yyyy'), '1', '03', '276', '10', '2022', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8313, to_date('04-10-2022', 'dd-mm-yyyy'), '2', '04', '277', '10', '2022', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8314, to_date('05-10-2022', 'dd-mm-yyyy'), '3', '05', '278', '10', '2022', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8315, to_date('06-10-2022', 'dd-mm-yyyy'), '4', '06', '279', '10', '2022', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8316, to_date('07-10-2022', 'dd-mm-yyyy'), '5', '07', '280', '10', '2022', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8317, to_date('08-10-2022', 'dd-mm-yyyy'), '6', '08', '281', '10', '2022', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8318, to_date('09-10-2022', 'dd-mm-yyyy'), '7', '09', '282', '10', '2022', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8319, to_date('10-10-2022', 'dd-mm-yyyy'), '1', '10', '283', '10', '2022', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8320, to_date('11-10-2022', 'dd-mm-yyyy'), '2', '11', '284', '10', '2022', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8321, to_date('12-10-2022', 'dd-mm-yyyy'), '3', '12', '285', '10', '2022', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8322, to_date('13-10-2022', 'dd-mm-yyyy'), '4', '13', '286', '10', '2022', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8323, to_date('14-10-2022', 'dd-mm-yyyy'), '5', '14', '287', '10', '2022', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8324, to_date('15-10-2022', 'dd-mm-yyyy'), '6', '15', '288', '10', '2022', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8325, to_date('16-10-2022', 'dd-mm-yyyy'), '7', '16', '289', '10', '2022', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8326, to_date('17-10-2022', 'dd-mm-yyyy'), '1', '17', '290', '10', '2022', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8327, to_date('18-10-2022', 'dd-mm-yyyy'), '2', '18', '291', '10', '2022', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8328, to_date('19-10-2022', 'dd-mm-yyyy'), '3', '19', '292', '10', '2022', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8329, to_date('20-10-2022', 'dd-mm-yyyy'), '4', '20', '293', '10', '2022', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8330, to_date('21-10-2022', 'dd-mm-yyyy'), '5', '21', '294', '10', '2022', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8331, to_date('22-10-2022', 'dd-mm-yyyy'), '6', '22', '295', '10', '2022', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8332, to_date('23-10-2022', 'dd-mm-yyyy'), '7', '23', '296', '10', '2022', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8333, to_date('24-10-2022', 'dd-mm-yyyy'), '1', '24', '297', '10', '2022', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8334, to_date('25-10-2022', 'dd-mm-yyyy'), '2', '25', '298', '10', '2022', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8335, to_date('26-10-2022', 'dd-mm-yyyy'), '3', '26', '299', '10', '2022', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8336, to_date('27-10-2022', 'dd-mm-yyyy'), '4', '27', '300', '10', '2022', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8337, to_date('28-10-2022', 'dd-mm-yyyy'), '5', '28', '301', '10', '2022', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8338, to_date('29-10-2022', 'dd-mm-yyyy'), '6', '29', '302', '10', '2022', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8339, to_date('30-10-2022', 'dd-mm-yyyy'), '7', '30', '303', '10', '2022', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8340, to_date('31-10-2022', 'dd-mm-yyyy'), '1', '31', '304', '10', '2022', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8341, to_date('01-11-2022', 'dd-mm-yyyy'), '2', '01', '305', '11', '2022', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8342, to_date('02-11-2022', 'dd-mm-yyyy'), '3', '02', '306', '11', '2022', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8343, to_date('03-11-2022', 'dd-mm-yyyy'), '4', '03', '307', '11', '2022', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8344, to_date('04-11-2022', 'dd-mm-yyyy'), '5', '04', '308', '11', '2022', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8345, to_date('05-11-2022', 'dd-mm-yyyy'), '6', '05', '309', '11', '2022', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8346, to_date('06-11-2022', 'dd-mm-yyyy'), '7', '06', '310', '11', '2022', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8347, to_date('07-11-2022', 'dd-mm-yyyy'), '1', '07', '311', '11', '2022', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8348, to_date('08-11-2022', 'dd-mm-yyyy'), '2', '08', '312', '11', '2022', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8349, to_date('09-11-2022', 'dd-mm-yyyy'), '3', '09', '313', '11', '2022', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8350, to_date('10-11-2022', 'dd-mm-yyyy'), '4', '10', '314', '11', '2022', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8351, to_date('11-11-2022', 'dd-mm-yyyy'), '5', '11', '315', '11', '2022', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8352, to_date('12-11-2022', 'dd-mm-yyyy'), '6', '12', '316', '11', '2022', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8353, to_date('13-11-2022', 'dd-mm-yyyy'), '7', '13', '317', '11', '2022', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8354, to_date('14-11-2022', 'dd-mm-yyyy'), '1', '14', '318', '11', '2022', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8355, to_date('15-11-2022', 'dd-mm-yyyy'), '2', '15', '319', '11', '2022', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8356, to_date('16-11-2022', 'dd-mm-yyyy'), '3', '16', '320', '11', '2022', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8357, to_date('17-11-2022', 'dd-mm-yyyy'), '4', '17', '321', '11', '2022', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8358, to_date('18-11-2022', 'dd-mm-yyyy'), '5', '18', '322', '11', '2022', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8359, to_date('19-11-2022', 'dd-mm-yyyy'), '6', '19', '323', '11', '2022', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8360, to_date('20-11-2022', 'dd-mm-yyyy'), '7', '20', '324', '11', '2022', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8361, to_date('21-11-2022', 'dd-mm-yyyy'), '1', '21', '325', '11', '2022', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8362, to_date('22-11-2022', 'dd-mm-yyyy'), '2', '22', '326', '11', '2022', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8363, to_date('23-11-2022', 'dd-mm-yyyy'), '3', '23', '327', '11', '2022', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8364, to_date('24-11-2022', 'dd-mm-yyyy'), '4', '24', '328', '11', '2022', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8365, to_date('25-11-2022', 'dd-mm-yyyy'), '5', '25', '329', '11', '2022', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8366, to_date('26-11-2022', 'dd-mm-yyyy'), '6', '26', '330', '11', '2022', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8367, to_date('27-11-2022', 'dd-mm-yyyy'), '7', '27', '331', '11', '2022', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8368, to_date('28-11-2022', 'dd-mm-yyyy'), '1', '28', '332', '11', '2022', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8369, to_date('29-11-2022', 'dd-mm-yyyy'), '2', '29', '333', '11', '2022', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8370, to_date('30-11-2022', 'dd-mm-yyyy'), '3', '30', '334', '11', '2022', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8371, to_date('01-12-2022', 'dd-mm-yyyy'), '4', '01', '335', '12', '2022', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8372, to_date('02-12-2022', 'dd-mm-yyyy'), '5', '02', '336', '12', '2022', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8373, to_date('03-12-2022', 'dd-mm-yyyy'), '6', '03', '337', '12', '2022', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8374, to_date('04-12-2022', 'dd-mm-yyyy'), '7', '04', '338', '12', '2022', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8375, to_date('05-12-2022', 'dd-mm-yyyy'), '1', '05', '339', '12', '2022', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8376, to_date('06-12-2022', 'dd-mm-yyyy'), '2', '06', '340', '12', '2022', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8377, to_date('07-12-2022', 'dd-mm-yyyy'), '3', '07', '341', '12', '2022', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8378, to_date('08-12-2022', 'dd-mm-yyyy'), '4', '08', '342', '12', '2022', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8379, to_date('09-12-2022', 'dd-mm-yyyy'), '5', '09', '343', '12', '2022', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8380, to_date('10-12-2022', 'dd-mm-yyyy'), '6', '10', '344', '12', '2022', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8381, to_date('11-12-2022', 'dd-mm-yyyy'), '7', '11', '345', '12', '2022', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8382, to_date('12-12-2022', 'dd-mm-yyyy'), '1', '12', '346', '12', '2022', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8383, to_date('13-12-2022', 'dd-mm-yyyy'), '2', '13', '347', '12', '2022', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8384, to_date('14-12-2022', 'dd-mm-yyyy'), '3', '14', '348', '12', '2022', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8385, to_date('15-12-2022', 'dd-mm-yyyy'), '4', '15', '349', '12', '2022', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8386, to_date('16-12-2022', 'dd-mm-yyyy'), '5', '16', '350', '12', '2022', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8387, to_date('17-12-2022', 'dd-mm-yyyy'), '6', '17', '351', '12', '2022', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8388, to_date('18-12-2022', 'dd-mm-yyyy'), '7', '18', '352', '12', '2022', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8389, to_date('19-12-2022', 'dd-mm-yyyy'), '1', '19', '353', '12', '2022', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8390, to_date('20-12-2022', 'dd-mm-yyyy'), '2', '20', '354', '12', '2022', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8391, to_date('21-12-2022', 'dd-mm-yyyy'), '3', '21', '355', '12', '2022', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8392, to_date('22-12-2022', 'dd-mm-yyyy'), '4', '22', '356', '12', '2022', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8393, to_date('23-12-2022', 'dd-mm-yyyy'), '5', '23', '357', '12', '2022', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8394, to_date('24-12-2022', 'dd-mm-yyyy'), '6', '24', '358', '12', '2022', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8395, to_date('25-12-2022', 'dd-mm-yyyy'), '7', '25', '359', '12', '2022', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8396, to_date('26-12-2022', 'dd-mm-yyyy'), '1', '26', '360', '12', '2022', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8397, to_date('27-12-2022', 'dd-mm-yyyy'), '2', '27', '361', '12', '2022', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8398, to_date('28-12-2022', 'dd-mm-yyyy'), '3', '28', '362', '12', '2022', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8399, to_date('29-12-2022', 'dd-mm-yyyy'), '4', '29', '363', '12', '2022', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8400, to_date('30-12-2022', 'dd-mm-yyyy'), '5', '30', '364', '12', '2022', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8401, to_date('31-12-2022', 'dd-mm-yyyy'), '6', '31', '365', '12', '2022', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8402, to_date('01-01-2023', 'dd-mm-yyyy'), '7', '01', '001', '01', '2023', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8403, to_date('02-01-2023', 'dd-mm-yyyy'), '1', '02', '002', '01', '2023', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8404, to_date('03-01-2023', 'dd-mm-yyyy'), '2', '03', '003', '01', '2023', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8405, to_date('04-01-2023', 'dd-mm-yyyy'), '3', '04', '004', '01', '2023', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8406, to_date('05-01-2023', 'dd-mm-yyyy'), '4', '05', '005', '01', '2023', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8407, to_date('06-01-2023', 'dd-mm-yyyy'), '5', '06', '006', '01', '2023', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8408, to_date('07-01-2023', 'dd-mm-yyyy'), '6', '07', '007', '01', '2023', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8409, to_date('08-01-2023', 'dd-mm-yyyy'), '7', '08', '008', '01', '2023', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8410, to_date('09-01-2023', 'dd-mm-yyyy'), '1', '09', '009', '01', '2023', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8411, to_date('10-01-2023', 'dd-mm-yyyy'), '2', '10', '010', '01', '2023', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8412, to_date('11-01-2023', 'dd-mm-yyyy'), '3', '11', '011', '01', '2023', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8413, to_date('12-01-2023', 'dd-mm-yyyy'), '4', '12', '012', '01', '2023', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8414, to_date('13-01-2023', 'dd-mm-yyyy'), '5', '13', '013', '01', '2023', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8415, to_date('14-01-2023', 'dd-mm-yyyy'), '6', '14', '014', '01', '2023', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8416, to_date('15-01-2023', 'dd-mm-yyyy'), '7', '15', '015', '01', '2023', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8417, to_date('16-01-2023', 'dd-mm-yyyy'), '1', '16', '016', '01', '2023', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8418, to_date('17-01-2023', 'dd-mm-yyyy'), '2', '17', '017', '01', '2023', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8419, to_date('18-01-2023', 'dd-mm-yyyy'), '3', '18', '018', '01', '2023', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8420, to_date('19-01-2023', 'dd-mm-yyyy'), '4', '19', '019', '01', '2023', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8421, to_date('20-01-2023', 'dd-mm-yyyy'), '5', '20', '020', '01', '2023', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8422, to_date('21-01-2023', 'dd-mm-yyyy'), '6', '21', '021', '01', '2023', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8423, to_date('22-01-2023', 'dd-mm-yyyy'), '7', '22', '022', '01', '2023', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8424, to_date('23-01-2023', 'dd-mm-yyyy'), '1', '23', '023', '01', '2023', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8425, to_date('24-01-2023', 'dd-mm-yyyy'), '2', '24', '024', '01', '2023', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8426, to_date('25-01-2023', 'dd-mm-yyyy'), '3', '25', '025', '01', '2023', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8427, to_date('26-01-2023', 'dd-mm-yyyy'), '4', '26', '026', '01', '2023', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8428, to_date('27-01-2023', 'dd-mm-yyyy'), '5', '27', '027', '01', '2023', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8429, to_date('28-01-2023', 'dd-mm-yyyy'), '6', '28', '028', '01', '2023', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8430, to_date('29-01-2023', 'dd-mm-yyyy'), '7', '29', '029', '01', '2023', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8431, to_date('30-01-2023', 'dd-mm-yyyy'), '1', '30', '030', '01', '2023', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8432, to_date('31-01-2023', 'dd-mm-yyyy'), '2', '31', '031', '01', '2023', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8433, to_date('01-02-2023', 'dd-mm-yyyy'), '3', '01', '032', '02', '2023', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8434, to_date('02-02-2023', 'dd-mm-yyyy'), '4', '02', '033', '02', '2023', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8435, to_date('03-02-2023', 'dd-mm-yyyy'), '5', '03', '034', '02', '2023', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8436, to_date('04-02-2023', 'dd-mm-yyyy'), '6', '04', '035', '02', '2023', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8437, to_date('05-02-2023', 'dd-mm-yyyy'), '7', '05', '036', '02', '2023', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8438, to_date('06-02-2023', 'dd-mm-yyyy'), '1', '06', '037', '02', '2023', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8439, to_date('07-02-2023', 'dd-mm-yyyy'), '2', '07', '038', '02', '2023', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8440, to_date('08-02-2023', 'dd-mm-yyyy'), '3', '08', '039', '02', '2023', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8441, to_date('09-02-2023', 'dd-mm-yyyy'), '4', '09', '040', '02', '2023', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8442, to_date('10-02-2023', 'dd-mm-yyyy'), '5', '10', '041', '02', '2023', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8443, to_date('11-02-2023', 'dd-mm-yyyy'), '6', '11', '042', '02', '2023', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8444, to_date('12-02-2023', 'dd-mm-yyyy'), '7', '12', '043', '02', '2023', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8445, to_date('13-02-2023', 'dd-mm-yyyy'), '1', '13', '044', '02', '2023', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8446, to_date('14-02-2023', 'dd-mm-yyyy'), '2', '14', '045', '02', '2023', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8447, to_date('15-02-2023', 'dd-mm-yyyy'), '3', '15', '046', '02', '2023', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8448, to_date('16-02-2023', 'dd-mm-yyyy'), '4', '16', '047', '02', '2023', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8449, to_date('17-02-2023', 'dd-mm-yyyy'), '5', '17', '048', '02', '2023', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8450, to_date('18-02-2023', 'dd-mm-yyyy'), '6', '18', '049', '02', '2023', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8451, to_date('19-02-2023', 'dd-mm-yyyy'), '7', '19', '050', '02', '2023', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8452, to_date('20-02-2023', 'dd-mm-yyyy'), '1', '20', '051', '02', '2023', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8453, to_date('21-02-2023', 'dd-mm-yyyy'), '2', '21', '052', '02', '2023', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8454, to_date('22-02-2023', 'dd-mm-yyyy'), '3', '22', '053', '02', '2023', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8455, to_date('23-02-2023', 'dd-mm-yyyy'), '4', '23', '054', '02', '2023', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8456, to_date('24-02-2023', 'dd-mm-yyyy'), '5', '24', '055', '02', '2023', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8457, to_date('25-02-2023', 'dd-mm-yyyy'), '6', '25', '056', '02', '2023', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8458, to_date('26-02-2023', 'dd-mm-yyyy'), '7', '26', '057', '02', '2023', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8459, to_date('27-02-2023', 'dd-mm-yyyy'), '1', '27', '058', '02', '2023', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8460, to_date('28-02-2023', 'dd-mm-yyyy'), '2', '28', '059', '02', '2023', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8461, to_date('01-03-2023', 'dd-mm-yyyy'), '3', '01', '060', '03', '2023', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8462, to_date('02-03-2023', 'dd-mm-yyyy'), '4', '02', '061', '03', '2023', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8463, to_date('03-03-2023', 'dd-mm-yyyy'), '5', '03', '062', '03', '2023', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8464, to_date('04-03-2023', 'dd-mm-yyyy'), '6', '04', '063', '03', '2023', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8465, to_date('05-03-2023', 'dd-mm-yyyy'), '7', '05', '064', '03', '2023', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8466, to_date('06-03-2023', 'dd-mm-yyyy'), '1', '06', '065', '03', '2023', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8467, to_date('07-03-2023', 'dd-mm-yyyy'), '2', '07', '066', '03', '2023', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8468, to_date('08-03-2023', 'dd-mm-yyyy'), '3', '08', '067', '03', '2023', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8469, to_date('09-03-2023', 'dd-mm-yyyy'), '4', '09', '068', '03', '2023', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8470, to_date('10-03-2023', 'dd-mm-yyyy'), '5', '10', '069', '03', '2023', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8471, to_date('11-03-2023', 'dd-mm-yyyy'), '6', '11', '070', '03', '2023', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8472, to_date('12-03-2023', 'dd-mm-yyyy'), '7', '12', '071', '03', '2023', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8473, to_date('13-03-2023', 'dd-mm-yyyy'), '1', '13', '072', '03', '2023', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8474, to_date('14-03-2023', 'dd-mm-yyyy'), '2', '14', '073', '03', '2023', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8475, to_date('15-03-2023', 'dd-mm-yyyy'), '3', '15', '074', '03', '2023', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8476, to_date('16-03-2023', 'dd-mm-yyyy'), '4', '16', '075', '03', '2023', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8477, to_date('17-03-2023', 'dd-mm-yyyy'), '5', '17', '076', '03', '2023', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8478, to_date('18-03-2023', 'dd-mm-yyyy'), '6', '18', '077', '03', '2023', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8479, to_date('19-03-2023', 'dd-mm-yyyy'), '7', '19', '078', '03', '2023', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8480, to_date('20-03-2023', 'dd-mm-yyyy'), '1', '20', '079', '03', '2023', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8481, to_date('21-03-2023', 'dd-mm-yyyy'), '2', '21', '080', '03', '2023', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8482, to_date('22-03-2023', 'dd-mm-yyyy'), '3', '22', '081', '03', '2023', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8483, to_date('23-03-2023', 'dd-mm-yyyy'), '4', '23', '082', '03', '2023', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8484, to_date('24-03-2023', 'dd-mm-yyyy'), '5', '24', '083', '03', '2023', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8485, to_date('25-03-2023', 'dd-mm-yyyy'), '6', '25', '084', '03', '2023', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8486, to_date('26-03-2023', 'dd-mm-yyyy'), '7', '26', '085', '03', '2023', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8487, to_date('27-03-2023', 'dd-mm-yyyy'), '1', '27', '086', '03', '2023', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8488, to_date('28-03-2023', 'dd-mm-yyyy'), '2', '28', '087', '03', '2023', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8489, to_date('29-03-2023', 'dd-mm-yyyy'), '3', '29', '088', '03', '2023', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8490, to_date('30-03-2023', 'dd-mm-yyyy'), '4', '30', '089', '03', '2023', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8491, to_date('31-03-2023', 'dd-mm-yyyy'), '5', '31', '090', '03', '2023', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8492, to_date('01-04-2023', 'dd-mm-yyyy'), '6', '01', '091', '04', '2023', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8493, to_date('02-04-2023', 'dd-mm-yyyy'), '7', '02', '092', '04', '2023', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8494, to_date('03-04-2023', 'dd-mm-yyyy'), '1', '03', '093', '04', '2023', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8495, to_date('04-04-2023', 'dd-mm-yyyy'), '2', '04', '094', '04', '2023', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8496, to_date('05-04-2023', 'dd-mm-yyyy'), '3', '05', '095', '04', '2023', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8497, to_date('06-04-2023', 'dd-mm-yyyy'), '4', '06', '096', '04', '2023', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8498, to_date('07-04-2023', 'dd-mm-yyyy'), '5', '07', '097', '04', '2023', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8499, to_date('08-04-2023', 'dd-mm-yyyy'), '6', '08', '098', '04', '2023', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8500, to_date('09-04-2023', 'dd-mm-yyyy'), '7', '09', '099', '04', '2023', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8501, to_date('10-04-2023', 'dd-mm-yyyy'), '1', '10', '100', '04', '2023', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8502, to_date('11-04-2023', 'dd-mm-yyyy'), '2', '11', '101', '04', '2023', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8503, to_date('12-04-2023', 'dd-mm-yyyy'), '3', '12', '102', '04', '2023', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8504, to_date('13-04-2023', 'dd-mm-yyyy'), '4', '13', '103', '04', '2023', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8505, to_date('14-04-2023', 'dd-mm-yyyy'), '5', '14', '104', '04', '2023', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8506, to_date('15-04-2023', 'dd-mm-yyyy'), '6', '15', '105', '04', '2023', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8507, to_date('16-04-2023', 'dd-mm-yyyy'), '7', '16', '106', '04', '2023', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8508, to_date('17-04-2023', 'dd-mm-yyyy'), '1', '17', '107', '04', '2023', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8509, to_date('18-04-2023', 'dd-mm-yyyy'), '2', '18', '108', '04', '2023', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8510, to_date('19-04-2023', 'dd-mm-yyyy'), '3', '19', '109', '04', '2023', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8511, to_date('20-04-2023', 'dd-mm-yyyy'), '4', '20', '110', '04', '2023', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8512, to_date('21-04-2023', 'dd-mm-yyyy'), '5', '21', '111', '04', '2023', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8513, to_date('22-04-2023', 'dd-mm-yyyy'), '6', '22', '112', '04', '2023', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8514, to_date('23-04-2023', 'dd-mm-yyyy'), '7', '23', '113', '04', '2023', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8515, to_date('24-04-2023', 'dd-mm-yyyy'), '1', '24', '114', '04', '2023', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8516, to_date('25-04-2023', 'dd-mm-yyyy'), '2', '25', '115', '04', '2023', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8517, to_date('26-04-2023', 'dd-mm-yyyy'), '3', '26', '116', '04', '2023', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8518, to_date('27-04-2023', 'dd-mm-yyyy'), '4', '27', '117', '04', '2023', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8519, to_date('28-04-2023', 'dd-mm-yyyy'), '5', '28', '118', '04', '2023', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8520, to_date('29-04-2023', 'dd-mm-yyyy'), '6', '29', '119', '04', '2023', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8521, to_date('30-04-2023', 'dd-mm-yyyy'), '7', '30', '120', '04', '2023', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8522, to_date('01-05-2023', 'dd-mm-yyyy'), '1', '01', '121', '05', '2023', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8523, to_date('02-05-2023', 'dd-mm-yyyy'), '2', '02', '122', '05', '2023', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8524, to_date('03-05-2023', 'dd-mm-yyyy'), '3', '03', '123', '05', '2023', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8525, to_date('04-05-2023', 'dd-mm-yyyy'), '4', '04', '124', '05', '2023', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8526, to_date('05-05-2023', 'dd-mm-yyyy'), '5', '05', '125', '05', '2023', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8527, to_date('06-05-2023', 'dd-mm-yyyy'), '6', '06', '126', '05', '2023', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8528, to_date('07-05-2023', 'dd-mm-yyyy'), '7', '07', '127', '05', '2023', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8529, to_date('08-05-2023', 'dd-mm-yyyy'), '1', '08', '128', '05', '2023', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8530, to_date('09-05-2023', 'dd-mm-yyyy'), '2', '09', '129', '05', '2023', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8531, to_date('10-05-2023', 'dd-mm-yyyy'), '3', '10', '130', '05', '2023', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8532, to_date('11-05-2023', 'dd-mm-yyyy'), '4', '11', '131', '05', '2023', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8533, to_date('12-05-2023', 'dd-mm-yyyy'), '5', '12', '132', '05', '2023', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8750, to_date('15-12-2023', 'dd-mm-yyyy'), '5', '15', '349', '12', '2023', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8751, to_date('16-12-2023', 'dd-mm-yyyy'), '6', '16', '350', '12', '2023', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8752, to_date('17-12-2023', 'dd-mm-yyyy'), '7', '17', '351', '12', '2023', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8753, to_date('18-12-2023', 'dd-mm-yyyy'), '1', '18', '352', '12', '2023', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8754, to_date('19-12-2023', 'dd-mm-yyyy'), '2', '19', '353', '12', '2023', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8755, to_date('20-12-2023', 'dd-mm-yyyy'), '3', '20', '354', '12', '2023', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8756, to_date('21-12-2023', 'dd-mm-yyyy'), '4', '21', '355', '12', '2023', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8757, to_date('22-12-2023', 'dd-mm-yyyy'), '5', '22', '356', '12', '2023', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8758, to_date('23-12-2023', 'dd-mm-yyyy'), '6', '23', '357', '12', '2023', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8759, to_date('24-12-2023', 'dd-mm-yyyy'), '7', '24', '358', '12', '2023', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8760, to_date('25-12-2023', 'dd-mm-yyyy'), '1', '25', '359', '12', '2023', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8761, to_date('26-12-2023', 'dd-mm-yyyy'), '2', '26', '360', '12', '2023', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8762, to_date('27-12-2023', 'dd-mm-yyyy'), '3', '27', '361', '12', '2023', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8763, to_date('28-12-2023', 'dd-mm-yyyy'), '4', '28', '362', '12', '2023', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8764, to_date('29-12-2023', 'dd-mm-yyyy'), '5', '29', '363', '12', '2023', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8765, to_date('30-12-2023', 'dd-mm-yyyy'), '6', '30', '364', '12', '2023', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8766, to_date('31-12-2023', 'dd-mm-yyyy'), '7', '31', '365', '12', '2023', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8767, to_date('01-01-2024', 'dd-mm-yyyy'), '1', '01', '001', '01', '2024', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8768, to_date('02-01-2024', 'dd-mm-yyyy'), '2', '02', '002', '01', '2024', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8769, to_date('03-01-2024', 'dd-mm-yyyy'), '3', '03', '003', '01', '2024', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8770, to_date('04-01-2024', 'dd-mm-yyyy'), '4', '04', '004', '01', '2024', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8771, to_date('05-01-2024', 'dd-mm-yyyy'), '5', '05', '005', '01', '2024', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8772, to_date('06-01-2024', 'dd-mm-yyyy'), '6', '06', '006', '01', '2024', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8773, to_date('07-01-2024', 'dd-mm-yyyy'), '7', '07', '007', '01', '2024', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8774, to_date('08-01-2024', 'dd-mm-yyyy'), '1', '08', '008', '01', '2024', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8775, to_date('09-01-2024', 'dd-mm-yyyy'), '2', '09', '009', '01', '2024', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8776, to_date('10-01-2024', 'dd-mm-yyyy'), '3', '10', '010', '01', '2024', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8777, to_date('11-01-2024', 'dd-mm-yyyy'), '4', '11', '011', '01', '2024', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8778, to_date('12-01-2024', 'dd-mm-yyyy'), '5', '12', '012', '01', '2024', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8779, to_date('13-01-2024', 'dd-mm-yyyy'), '6', '13', '013', '01', '2024', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8780, to_date('14-01-2024', 'dd-mm-yyyy'), '7', '14', '014', '01', '2024', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8781, to_date('15-01-2024', 'dd-mm-yyyy'), '1', '15', '015', '01', '2024', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8782, to_date('16-01-2024', 'dd-mm-yyyy'), '2', '16', '016', '01', '2024', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8783, to_date('17-01-2024', 'dd-mm-yyyy'), '3', '17', '017', '01', '2024', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8784, to_date('18-01-2024', 'dd-mm-yyyy'), '4', '18', '018', '01', '2024', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8785, to_date('19-01-2024', 'dd-mm-yyyy'), '5', '19', '019', '01', '2024', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8786, to_date('20-01-2024', 'dd-mm-yyyy'), '6', '20', '020', '01', '2024', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8787, to_date('21-01-2024', 'dd-mm-yyyy'), '7', '21', '021', '01', '2024', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8788, to_date('22-01-2024', 'dd-mm-yyyy'), '1', '22', '022', '01', '2024', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8789, to_date('23-01-2024', 'dd-mm-yyyy'), '2', '23', '023', '01', '2024', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8790, to_date('24-01-2024', 'dd-mm-yyyy'), '3', '24', '024', '01', '2024', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8791, to_date('25-01-2024', 'dd-mm-yyyy'), '4', '25', '025', '01', '2024', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8792, to_date('26-01-2024', 'dd-mm-yyyy'), '5', '26', '026', '01', '2024', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8793, to_date('27-01-2024', 'dd-mm-yyyy'), '6', '27', '027', '01', '2024', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8794, to_date('28-01-2024', 'dd-mm-yyyy'), '7', '28', '028', '01', '2024', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8795, to_date('29-01-2024', 'dd-mm-yyyy'), '1', '29', '029', '01', '2024', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8796, to_date('30-01-2024', 'dd-mm-yyyy'), '2', '30', '030', '01', '2024', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8797, to_date('31-01-2024', 'dd-mm-yyyy'), '3', '31', '031', '01', '2024', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8798, to_date('01-02-2024', 'dd-mm-yyyy'), '4', '01', '032', '02', '2024', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8799, to_date('02-02-2024', 'dd-mm-yyyy'), '5', '02', '033', '02', '2024', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8800, to_date('03-02-2024', 'dd-mm-yyyy'), '6', '03', '034', '02', '2024', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8801, to_date('04-02-2024', 'dd-mm-yyyy'), '7', '04', '035', '02', '2024', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8802, to_date('05-02-2024', 'dd-mm-yyyy'), '1', '05', '036', '02', '2024', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8803, to_date('06-02-2024', 'dd-mm-yyyy'), '2', '06', '037', '02', '2024', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8804, to_date('07-02-2024', 'dd-mm-yyyy'), '3', '07', '038', '02', '2024', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8805, to_date('08-02-2024', 'dd-mm-yyyy'), '4', '08', '039', '02', '2024', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8806, to_date('09-02-2024', 'dd-mm-yyyy'), '5', '09', '040', '02', '2024', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8807, to_date('10-02-2024', 'dd-mm-yyyy'), '6', '10', '041', '02', '2024', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8808, to_date('11-02-2024', 'dd-mm-yyyy'), '7', '11', '042', '02', '2024', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8809, to_date('12-02-2024', 'dd-mm-yyyy'), '1', '12', '043', '02', '2024', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8810, to_date('13-02-2024', 'dd-mm-yyyy'), '2', '13', '044', '02', '2024', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8811, to_date('14-02-2024', 'dd-mm-yyyy'), '3', '14', '045', '02', '2024', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8812, to_date('15-02-2024', 'dd-mm-yyyy'), '4', '15', '046', '02', '2024', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8813, to_date('16-02-2024', 'dd-mm-yyyy'), '5', '16', '047', '02', '2024', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8814, to_date('17-02-2024', 'dd-mm-yyyy'), '6', '17', '048', '02', '2024', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8815, to_date('18-02-2024', 'dd-mm-yyyy'), '7', '18', '049', '02', '2024', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8816, to_date('19-02-2024', 'dd-mm-yyyy'), '1', '19', '050', '02', '2024', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8817, to_date('20-02-2024', 'dd-mm-yyyy'), '2', '20', '051', '02', '2024', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8818, to_date('21-02-2024', 'dd-mm-yyyy'), '3', '21', '052', '02', '2024', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8819, to_date('22-02-2024', 'dd-mm-yyyy'), '4', '22', '053', '02', '2024', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8820, to_date('23-02-2024', 'dd-mm-yyyy'), '5', '23', '054', '02', '2024', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8821, to_date('24-02-2024', 'dd-mm-yyyy'), '6', '24', '055', '02', '2024', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8822, to_date('25-02-2024', 'dd-mm-yyyy'), '7', '25', '056', '02', '2024', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8823, to_date('26-02-2024', 'dd-mm-yyyy'), '1', '26', '057', '02', '2024', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8824, to_date('27-02-2024', 'dd-mm-yyyy'), '2', '27', '058', '02', '2024', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8825, to_date('28-02-2024', 'dd-mm-yyyy'), '3', '28', '059', '02', '2024', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8826, to_date('29-02-2024', 'dd-mm-yyyy'), '4', '29', '060', '02', '2024', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8827, to_date('01-03-2024', 'dd-mm-yyyy'), '5', '01', '061', '03', '2024', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8828, to_date('02-03-2024', 'dd-mm-yyyy'), '6', '02', '062', '03', '2024', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8829, to_date('03-03-2024', 'dd-mm-yyyy'), '7', '03', '063', '03', '2024', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8830, to_date('04-03-2024', 'dd-mm-yyyy'), '1', '04', '064', '03', '2024', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8831, to_date('05-03-2024', 'dd-mm-yyyy'), '2', '05', '065', '03', '2024', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8832, to_date('06-03-2024', 'dd-mm-yyyy'), '3', '06', '066', '03', '2024', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8833, to_date('07-03-2024', 'dd-mm-yyyy'), '4', '07', '067', '03', '2024', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8834, to_date('08-03-2024', 'dd-mm-yyyy'), '5', '08', '068', '03', '2024', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8835, to_date('09-03-2024', 'dd-mm-yyyy'), '6', '09', '069', '03', '2024', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8836, to_date('10-03-2024', 'dd-mm-yyyy'), '7', '10', '070', '03', '2024', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8837, to_date('11-03-2024', 'dd-mm-yyyy'), '1', '11', '071', '03', '2024', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8838, to_date('12-03-2024', 'dd-mm-yyyy'), '2', '12', '072', '03', '2024', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8839, to_date('13-03-2024', 'dd-mm-yyyy'), '3', '13', '073', '03', '2024', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8840, to_date('14-03-2024', 'dd-mm-yyyy'), '4', '14', '074', '03', '2024', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8841, to_date('15-03-2024', 'dd-mm-yyyy'), '5', '15', '075', '03', '2024', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8842, to_date('16-03-2024', 'dd-mm-yyyy'), '6', '16', '076', '03', '2024', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8843, to_date('17-03-2024', 'dd-mm-yyyy'), '7', '17', '077', '03', '2024', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8844, to_date('18-03-2024', 'dd-mm-yyyy'), '1', '18', '078', '03', '2024', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8845, to_date('19-03-2024', 'dd-mm-yyyy'), '2', '19', '079', '03', '2024', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8846, to_date('20-03-2024', 'dd-mm-yyyy'), '3', '20', '080', '03', '2024', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8847, to_date('21-03-2024', 'dd-mm-yyyy'), '4', '21', '081', '03', '2024', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8848, to_date('22-03-2024', 'dd-mm-yyyy'), '5', '22', '082', '03', '2024', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8849, to_date('23-03-2024', 'dd-mm-yyyy'), '6', '23', '083', '03', '2024', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8850, to_date('24-03-2024', 'dd-mm-yyyy'), '7', '24', '084', '03', '2024', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8851, to_date('25-03-2024', 'dd-mm-yyyy'), '1', '25', '085', '03', '2024', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8852, to_date('26-03-2024', 'dd-mm-yyyy'), '2', '26', '086', '03', '2024', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8853, to_date('27-03-2024', 'dd-mm-yyyy'), '3', '27', '087', '03', '2024', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8854, to_date('28-03-2024', 'dd-mm-yyyy'), '4', '28', '088', '03', '2024', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8855, to_date('29-03-2024', 'dd-mm-yyyy'), '5', '29', '089', '03', '2024', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8856, to_date('30-03-2024', 'dd-mm-yyyy'), '6', '30', '090', '03', '2024', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8857, to_date('31-03-2024', 'dd-mm-yyyy'), '7', '31', '091', '03', '2024', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8858, to_date('01-04-2024', 'dd-mm-yyyy'), '1', '01', '092', '04', '2024', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8859, to_date('02-04-2024', 'dd-mm-yyyy'), '2', '02', '093', '04', '2024', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8860, to_date('03-04-2024', 'dd-mm-yyyy'), '3', '03', '094', '04', '2024', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8861, to_date('04-04-2024', 'dd-mm-yyyy'), '4', '04', '095', '04', '2024', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8862, to_date('05-04-2024', 'dd-mm-yyyy'), '5', '05', '096', '04', '2024', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8863, to_date('06-04-2024', 'dd-mm-yyyy'), '6', '06', '097', '04', '2024', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8864, to_date('07-04-2024', 'dd-mm-yyyy'), '7', '07', '098', '04', '2024', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8865, to_date('08-04-2024', 'dd-mm-yyyy'), '1', '08', '099', '04', '2024', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8866, to_date('09-04-2024', 'dd-mm-yyyy'), '2', '09', '100', '04', '2024', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8867, to_date('10-04-2024', 'dd-mm-yyyy'), '3', '10', '101', '04', '2024', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8868, to_date('11-04-2024', 'dd-mm-yyyy'), '4', '11', '102', '04', '2024', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8869, to_date('12-04-2024', 'dd-mm-yyyy'), '5', '12', '103', '04', '2024', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8870, to_date('13-04-2024', 'dd-mm-yyyy'), '6', '13', '104', '04', '2024', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8871, to_date('14-04-2024', 'dd-mm-yyyy'), '7', '14', '105', '04', '2024', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8872, to_date('15-04-2024', 'dd-mm-yyyy'), '1', '15', '106', '04', '2024', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8873, to_date('16-04-2024', 'dd-mm-yyyy'), '2', '16', '107', '04', '2024', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8874, to_date('17-04-2024', 'dd-mm-yyyy'), '3', '17', '108', '04', '2024', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8875, to_date('18-04-2024', 'dd-mm-yyyy'), '4', '18', '109', '04', '2024', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8876, to_date('19-04-2024', 'dd-mm-yyyy'), '5', '19', '110', '04', '2024', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8877, to_date('20-04-2024', 'dd-mm-yyyy'), '6', '20', '111', '04', '2024', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8878, to_date('21-04-2024', 'dd-mm-yyyy'), '7', '21', '112', '04', '2024', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8879, to_date('22-04-2024', 'dd-mm-yyyy'), '1', '22', '113', '04', '2024', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8880, to_date('23-04-2024', 'dd-mm-yyyy'), '2', '23', '114', '04', '2024', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8881, to_date('24-04-2024', 'dd-mm-yyyy'), '3', '24', '115', '04', '2024', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8882, to_date('25-04-2024', 'dd-mm-yyyy'), '4', '25', '116', '04', '2024', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8883, to_date('26-04-2024', 'dd-mm-yyyy'), '5', '26', '117', '04', '2024', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8884, to_date('27-04-2024', 'dd-mm-yyyy'), '6', '27', '118', '04', '2024', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8885, to_date('28-04-2024', 'dd-mm-yyyy'), '7', '28', '119', '04', '2024', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8886, to_date('29-04-2024', 'dd-mm-yyyy'), '1', '29', '120', '04', '2024', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8887, to_date('30-04-2024', 'dd-mm-yyyy'), '2', '30', '121', '04', '2024', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8888, to_date('01-05-2024', 'dd-mm-yyyy'), '3', '01', '122', '05', '2024', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8889, to_date('02-05-2024', 'dd-mm-yyyy'), '4', '02', '123', '05', '2024', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8890, to_date('03-05-2024', 'dd-mm-yyyy'), '5', '03', '124', '05', '2024', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8891, to_date('04-05-2024', 'dd-mm-yyyy'), '6', '04', '125', '05', '2024', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8892, to_date('05-05-2024', 'dd-mm-yyyy'), '7', '05', '126', '05', '2024', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8893, to_date('06-05-2024', 'dd-mm-yyyy'), '1', '06', '127', '05', '2024', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8894, to_date('07-05-2024', 'dd-mm-yyyy'), '2', '07', '128', '05', '2024', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8895, to_date('08-05-2024', 'dd-mm-yyyy'), '3', '08', '129', '05', '2024', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8896, to_date('09-05-2024', 'dd-mm-yyyy'), '4', '09', '130', '05', '2024', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8897, to_date('10-05-2024', 'dd-mm-yyyy'), '5', '10', '131', '05', '2024', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8898, to_date('11-05-2024', 'dd-mm-yyyy'), '6', '11', '132', '05', '2024', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8899, to_date('12-05-2024', 'dd-mm-yyyy'), '7', '12', '133', '05', '2024', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8900, to_date('13-05-2024', 'dd-mm-yyyy'), '1', '13', '134', '05', '2024', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8901, to_date('14-05-2024', 'dd-mm-yyyy'), '2', '14', '135', '05', '2024', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8902, to_date('15-05-2024', 'dd-mm-yyyy'), '3', '15', '136', '05', '2024', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8903, to_date('16-05-2024', 'dd-mm-yyyy'), '4', '16', '137', '05', '2024', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8904, to_date('17-05-2024', 'dd-mm-yyyy'), '5', '17', '138', '05', '2024', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8905, to_date('18-05-2024', 'dd-mm-yyyy'), '6', '18', '139', '05', '2024', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8906, to_date('19-05-2024', 'dd-mm-yyyy'), '7', '19', '140', '05', '2024', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8907, to_date('20-05-2024', 'dd-mm-yyyy'), '1', '20', '141', '05', '2024', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8908, to_date('21-05-2024', 'dd-mm-yyyy'), '2', '21', '142', '05', '2024', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8909, to_date('22-05-2024', 'dd-mm-yyyy'), '3', '22', '143', '05', '2024', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8910, to_date('23-05-2024', 'dd-mm-yyyy'), '4', '23', '144', '05', '2024', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8911, to_date('24-05-2024', 'dd-mm-yyyy'), '5', '24', '145', '05', '2024', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8912, to_date('25-05-2024', 'dd-mm-yyyy'), '6', '25', '146', '05', '2024', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8913, to_date('26-05-2024', 'dd-mm-yyyy'), '7', '26', '147', '05', '2024', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8914, to_date('27-05-2024', 'dd-mm-yyyy'), '1', '27', '148', '05', '2024', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8915, to_date('28-05-2024', 'dd-mm-yyyy'), '2', '28', '149', '05', '2024', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8916, to_date('29-05-2024', 'dd-mm-yyyy'), '3', '29', '150', '05', '2024', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8917, to_date('30-05-2024', 'dd-mm-yyyy'), '4', '30', '151', '05', '2024', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8918, to_date('31-05-2024', 'dd-mm-yyyy'), '5', '31', '152', '05', '2024', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8919, to_date('01-06-2024', 'dd-mm-yyyy'), '6', '01', '153', '06', '2024', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8920, to_date('02-06-2024', 'dd-mm-yyyy'), '7', '02', '154', '06', '2024', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8921, to_date('03-06-2024', 'dd-mm-yyyy'), '1', '03', '155', '06', '2024', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8922, to_date('04-06-2024', 'dd-mm-yyyy'), '2', '04', '156', '06', '2024', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8923, to_date('05-06-2024', 'dd-mm-yyyy'), '3', '05', '157', '06', '2024', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8924, to_date('06-06-2024', 'dd-mm-yyyy'), '4', '06', '158', '06', '2024', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8925, to_date('07-06-2024', 'dd-mm-yyyy'), '5', '07', '159', '06', '2024', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8926, to_date('08-06-2024', 'dd-mm-yyyy'), '6', '08', '160', '06', '2024', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8927, to_date('09-06-2024', 'dd-mm-yyyy'), '7', '09', '161', '06', '2024', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8928, to_date('10-06-2024', 'dd-mm-yyyy'), '1', '10', '162', '06', '2024', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8929, to_date('11-06-2024', 'dd-mm-yyyy'), '2', '11', '163', '06', '2024', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8930, to_date('12-06-2024', 'dd-mm-yyyy'), '3', '12', '164', '06', '2024', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8931, to_date('13-06-2024', 'dd-mm-yyyy'), '4', '13', '165', '06', '2024', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8932, to_date('14-06-2024', 'dd-mm-yyyy'), '5', '14', '166', '06', '2024', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8933, to_date('15-06-2024', 'dd-mm-yyyy'), '6', '15', '167', '06', '2024', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8934, to_date('16-06-2024', 'dd-mm-yyyy'), '7', '16', '168', '06', '2024', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8935, to_date('17-06-2024', 'dd-mm-yyyy'), '1', '17', '169', '06', '2024', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8936, to_date('18-06-2024', 'dd-mm-yyyy'), '2', '18', '170', '06', '2024', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8937, to_date('19-06-2024', 'dd-mm-yyyy'), '3', '19', '171', '06', '2024', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8938, to_date('20-06-2024', 'dd-mm-yyyy'), '4', '20', '172', '06', '2024', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8939, to_date('21-06-2024', 'dd-mm-yyyy'), '5', '21', '173', '06', '2024', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8940, to_date('22-06-2024', 'dd-mm-yyyy'), '6', '22', '174', '06', '2024', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8941, to_date('23-06-2024', 'dd-mm-yyyy'), '7', '23', '175', '06', '2024', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8942, to_date('24-06-2024', 'dd-mm-yyyy'), '1', '24', '176', '06', '2024', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8943, to_date('25-06-2024', 'dd-mm-yyyy'), '2', '25', '177', '06', '2024', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8944, to_date('26-06-2024', 'dd-mm-yyyy'), '3', '26', '178', '06', '2024', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8945, to_date('27-06-2024', 'dd-mm-yyyy'), '4', '27', '179', '06', '2024', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8946, to_date('28-06-2024', 'dd-mm-yyyy'), '5', '28', '180', '06', '2024', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8947, to_date('29-06-2024', 'dd-mm-yyyy'), '6', '29', '181', '06', '2024', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8948, to_date('30-06-2024', 'dd-mm-yyyy'), '7', '30', '182', '06', '2024', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8949, to_date('01-07-2024', 'dd-mm-yyyy'), '1', '01', '183', '07', '2024', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8950, to_date('02-07-2024', 'dd-mm-yyyy'), '2', '02', '184', '07', '2024', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8951, to_date('03-07-2024', 'dd-mm-yyyy'), '3', '03', '185', '07', '2024', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8952, to_date('04-07-2024', 'dd-mm-yyyy'), '4', '04', '186', '07', '2024', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8953, to_date('05-07-2024', 'dd-mm-yyyy'), '5', '05', '187', '07', '2024', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8954, to_date('06-07-2024', 'dd-mm-yyyy'), '6', '06', '188', '07', '2024', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8955, to_date('07-07-2024', 'dd-mm-yyyy'), '7', '07', '189', '07', '2024', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8956, to_date('08-07-2024', 'dd-mm-yyyy'), '1', '08', '190', '07', '2024', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8957, to_date('09-07-2024', 'dd-mm-yyyy'), '2', '09', '191', '07', '2024', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8958, to_date('10-07-2024', 'dd-mm-yyyy'), '3', '10', '192', '07', '2024', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8959, to_date('11-07-2024', 'dd-mm-yyyy'), '4', '11', '193', '07', '2024', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8960, to_date('12-07-2024', 'dd-mm-yyyy'), '5', '12', '194', '07', '2024', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8961, to_date('13-07-2024', 'dd-mm-yyyy'), '6', '13', '195', '07', '2024', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8962, to_date('14-07-2024', 'dd-mm-yyyy'), '7', '14', '196', '07', '2024', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8963, to_date('15-07-2024', 'dd-mm-yyyy'), '1', '15', '197', '07', '2024', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8964, to_date('16-07-2024', 'dd-mm-yyyy'), '2', '16', '198', '07', '2024', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8965, to_date('17-07-2024', 'dd-mm-yyyy'), '3', '17', '199', '07', '2024', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9398, to_date('23-09-2025', 'dd-mm-yyyy'), '2', '23', '266', '09', '2025', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9399, to_date('24-09-2025', 'dd-mm-yyyy'), '3', '24', '267', '09', '2025', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9400, to_date('25-09-2025', 'dd-mm-yyyy'), '4', '25', '268', '09', '2025', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9401, to_date('26-09-2025', 'dd-mm-yyyy'), '5', '26', '269', '09', '2025', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9402, to_date('27-09-2025', 'dd-mm-yyyy'), '6', '27', '270', '09', '2025', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9403, to_date('28-09-2025', 'dd-mm-yyyy'), '7', '28', '271', '09', '2025', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9404, to_date('29-09-2025', 'dd-mm-yyyy'), '1', '29', '272', '09', '2025', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9405, to_date('30-09-2025', 'dd-mm-yyyy'), '2', '30', '273', '09', '2025', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9406, to_date('01-10-2025', 'dd-mm-yyyy'), '3', '01', '274', '10', '2025', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9407, to_date('02-10-2025', 'dd-mm-yyyy'), '4', '02', '275', '10', '2025', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9408, to_date('03-10-2025', 'dd-mm-yyyy'), '5', '03', '276', '10', '2025', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9409, to_date('04-10-2025', 'dd-mm-yyyy'), '6', '04', '277', '10', '2025', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9410, to_date('05-10-2025', 'dd-mm-yyyy'), '7', '05', '278', '10', '2025', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9411, to_date('06-10-2025', 'dd-mm-yyyy'), '1', '06', '279', '10', '2025', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9412, to_date('07-10-2025', 'dd-mm-yyyy'), '2', '07', '280', '10', '2025', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9413, to_date('08-10-2025', 'dd-mm-yyyy'), '3', '08', '281', '10', '2025', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9414, to_date('09-10-2025', 'dd-mm-yyyy'), '4', '09', '282', '10', '2025', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9415, to_date('10-10-2025', 'dd-mm-yyyy'), '5', '10', '283', '10', '2025', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9416, to_date('11-10-2025', 'dd-mm-yyyy'), '6', '11', '284', '10', '2025', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9417, to_date('12-10-2025', 'dd-mm-yyyy'), '7', '12', '285', '10', '2025', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9418, to_date('13-10-2025', 'dd-mm-yyyy'), '1', '13', '286', '10', '2025', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9419, to_date('14-10-2025', 'dd-mm-yyyy'), '2', '14', '287', '10', '2025', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9420, to_date('15-10-2025', 'dd-mm-yyyy'), '3', '15', '288', '10', '2025', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9421, to_date('16-10-2025', 'dd-mm-yyyy'), '4', '16', '289', '10', '2025', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9422, to_date('17-10-2025', 'dd-mm-yyyy'), '5', '17', '290', '10', '2025', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9423, to_date('18-10-2025', 'dd-mm-yyyy'), '6', '18', '291', '10', '2025', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9424, to_date('19-10-2025', 'dd-mm-yyyy'), '7', '19', '292', '10', '2025', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9425, to_date('20-10-2025', 'dd-mm-yyyy'), '1', '20', '293', '10', '2025', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9426, to_date('21-10-2025', 'dd-mm-yyyy'), '2', '21', '294', '10', '2025', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9427, to_date('22-10-2025', 'dd-mm-yyyy'), '3', '22', '295', '10', '2025', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9428, to_date('23-10-2025', 'dd-mm-yyyy'), '4', '23', '296', '10', '2025', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9429, to_date('24-10-2025', 'dd-mm-yyyy'), '5', '24', '297', '10', '2025', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9430, to_date('25-10-2025', 'dd-mm-yyyy'), '6', '25', '298', '10', '2025', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9431, to_date('26-10-2025', 'dd-mm-yyyy'), '7', '26', '299', '10', '2025', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9432, to_date('27-10-2025', 'dd-mm-yyyy'), '1', '27', '300', '10', '2025', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9433, to_date('28-10-2025', 'dd-mm-yyyy'), '2', '28', '301', '10', '2025', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9434, to_date('29-10-2025', 'dd-mm-yyyy'), '3', '29', '302', '10', '2025', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9435, to_date('30-10-2025', 'dd-mm-yyyy'), '4', '30', '303', '10', '2025', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9436, to_date('31-10-2025', 'dd-mm-yyyy'), '5', '31', '304', '10', '2025', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9437, to_date('01-11-2025', 'dd-mm-yyyy'), '6', '01', '305', '11', '2025', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9438, to_date('02-11-2025', 'dd-mm-yyyy'), '7', '02', '306', '11', '2025', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9439, to_date('03-11-2025', 'dd-mm-yyyy'), '1', '03', '307', '11', '2025', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9440, to_date('04-11-2025', 'dd-mm-yyyy'), '2', '04', '308', '11', '2025', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9441, to_date('05-11-2025', 'dd-mm-yyyy'), '3', '05', '309', '11', '2025', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9442, to_date('06-11-2025', 'dd-mm-yyyy'), '4', '06', '310', '11', '2025', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9443, to_date('07-11-2025', 'dd-mm-yyyy'), '5', '07', '311', '11', '2025', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9444, to_date('08-11-2025', 'dd-mm-yyyy'), '6', '08', '312', '11', '2025', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9445, to_date('09-11-2025', 'dd-mm-yyyy'), '7', '09', '313', '11', '2025', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9446, to_date('10-11-2025', 'dd-mm-yyyy'), '1', '10', '314', '11', '2025', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9447, to_date('11-11-2025', 'dd-mm-yyyy'), '2', '11', '315', '11', '2025', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9448, to_date('12-11-2025', 'dd-mm-yyyy'), '3', '12', '316', '11', '2025', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9449, to_date('13-11-2025', 'dd-mm-yyyy'), '4', '13', '317', '11', '2025', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9450, to_date('14-11-2025', 'dd-mm-yyyy'), '5', '14', '318', '11', '2025', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9451, to_date('15-11-2025', 'dd-mm-yyyy'), '6', '15', '319', '11', '2025', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9452, to_date('16-11-2025', 'dd-mm-yyyy'), '7', '16', '320', '11', '2025', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9453, to_date('17-11-2025', 'dd-mm-yyyy'), '1', '17', '321', '11', '2025', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9454, to_date('18-11-2025', 'dd-mm-yyyy'), '2', '18', '322', '11', '2025', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9455, to_date('19-11-2025', 'dd-mm-yyyy'), '3', '19', '323', '11', '2025', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9456, to_date('20-11-2025', 'dd-mm-yyyy'), '4', '20', '324', '11', '2025', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9457, to_date('21-11-2025', 'dd-mm-yyyy'), '5', '21', '325', '11', '2025', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9458, to_date('22-11-2025', 'dd-mm-yyyy'), '6', '22', '326', '11', '2025', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9459, to_date('23-11-2025', 'dd-mm-yyyy'), '7', '23', '327', '11', '2025', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9460, to_date('24-11-2025', 'dd-mm-yyyy'), '1', '24', '328', '11', '2025', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9461, to_date('25-11-2025', 'dd-mm-yyyy'), '2', '25', '329', '11', '2025', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9462, to_date('26-11-2025', 'dd-mm-yyyy'), '3', '26', '330', '11', '2025', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9463, to_date('27-11-2025', 'dd-mm-yyyy'), '4', '27', '331', '11', '2025', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9464, to_date('28-11-2025', 'dd-mm-yyyy'), '5', '28', '332', '11', '2025', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9465, to_date('29-11-2025', 'dd-mm-yyyy'), '6', '29', '333', '11', '2025', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9466, to_date('30-11-2025', 'dd-mm-yyyy'), '7', '30', '334', '11', '2025', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9467, to_date('01-12-2025', 'dd-mm-yyyy'), '1', '01', '335', '12', '2025', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9468, to_date('02-12-2025', 'dd-mm-yyyy'), '2', '02', '336', '12', '2025', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9469, to_date('03-12-2025', 'dd-mm-yyyy'), '3', '03', '337', '12', '2025', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9470, to_date('04-12-2025', 'dd-mm-yyyy'), '4', '04', '338', '12', '2025', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9471, to_date('05-12-2025', 'dd-mm-yyyy'), '5', '05', '339', '12', '2025', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9472, to_date('06-12-2025', 'dd-mm-yyyy'), '6', '06', '340', '12', '2025', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9473, to_date('07-12-2025', 'dd-mm-yyyy'), '7', '07', '341', '12', '2025', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9474, to_date('08-12-2025', 'dd-mm-yyyy'), '1', '08', '342', '12', '2025', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9475, to_date('09-12-2025', 'dd-mm-yyyy'), '2', '09', '343', '12', '2025', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9476, to_date('10-12-2025', 'dd-mm-yyyy'), '3', '10', '344', '12', '2025', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9477, to_date('11-12-2025', 'dd-mm-yyyy'), '4', '11', '345', '12', '2025', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9478, to_date('12-12-2025', 'dd-mm-yyyy'), '5', '12', '346', '12', '2025', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9479, to_date('13-12-2025', 'dd-mm-yyyy'), '6', '13', '347', '12', '2025', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9480, to_date('14-12-2025', 'dd-mm-yyyy'), '7', '14', '348', '12', '2025', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9481, to_date('15-12-2025', 'dd-mm-yyyy'), '1', '15', '349', '12', '2025', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9482, to_date('16-12-2025', 'dd-mm-yyyy'), '2', '16', '350', '12', '2025', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9483, to_date('17-12-2025', 'dd-mm-yyyy'), '3', '17', '351', '12', '2025', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9484, to_date('18-12-2025', 'dd-mm-yyyy'), '4', '18', '352', '12', '2025', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9485, to_date('19-12-2025', 'dd-mm-yyyy'), '5', '19', '353', '12', '2025', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9486, to_date('20-12-2025', 'dd-mm-yyyy'), '6', '20', '354', '12', '2025', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9487, to_date('21-12-2025', 'dd-mm-yyyy'), '7', '21', '355', '12', '2025', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9488, to_date('22-12-2025', 'dd-mm-yyyy'), '1', '22', '356', '12', '2025', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9489, to_date('23-12-2025', 'dd-mm-yyyy'), '2', '23', '357', '12', '2025', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9490, to_date('24-12-2025', 'dd-mm-yyyy'), '3', '24', '358', '12', '2025', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9491, to_date('25-12-2025', 'dd-mm-yyyy'), '4', '25', '359', '12', '2025', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9492, to_date('26-12-2025', 'dd-mm-yyyy'), '5', '26', '360', '12', '2025', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9493, to_date('27-12-2025', 'dd-mm-yyyy'), '6', '27', '361', '12', '2025', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9494, to_date('28-12-2025', 'dd-mm-yyyy'), '7', '28', '362', '12', '2025', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9495, to_date('29-12-2025', 'dd-mm-yyyy'), '1', '29', '363', '12', '2025', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9496, to_date('30-12-2025', 'dd-mm-yyyy'), '2', '30', '364', '12', '2025', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9497, to_date('31-12-2025', 'dd-mm-yyyy'), '3', '31', '365', '12', '2025', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9498, to_date('01-01-2026', 'dd-mm-yyyy'), '4', '01', '001', '01', '2026', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9499, to_date('02-01-2026', 'dd-mm-yyyy'), '5', '02', '002', '01', '2026', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9500, to_date('03-01-2026', 'dd-mm-yyyy'), '6', '03', '003', '01', '2026', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9501, to_date('04-01-2026', 'dd-mm-yyyy'), '7', '04', '004', '01', '2026', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9502, to_date('05-01-2026', 'dd-mm-yyyy'), '1', '05', '005', '01', '2026', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9503, to_date('06-01-2026', 'dd-mm-yyyy'), '2', '06', '006', '01', '2026', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9504, to_date('07-01-2026', 'dd-mm-yyyy'), '3', '07', '007', '01', '2026', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9505, to_date('08-01-2026', 'dd-mm-yyyy'), '4', '08', '008', '01', '2026', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8966, to_date('18-07-2024', 'dd-mm-yyyy'), '4', '18', '200', '07', '2024', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8967, to_date('19-07-2024', 'dd-mm-yyyy'), '5', '19', '201', '07', '2024', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8968, to_date('20-07-2024', 'dd-mm-yyyy'), '6', '20', '202', '07', '2024', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8969, to_date('21-07-2024', 'dd-mm-yyyy'), '7', '21', '203', '07', '2024', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8970, to_date('22-07-2024', 'dd-mm-yyyy'), '1', '22', '204', '07', '2024', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8971, to_date('23-07-2024', 'dd-mm-yyyy'), '2', '23', '205', '07', '2024', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8972, to_date('24-07-2024', 'dd-mm-yyyy'), '3', '24', '206', '07', '2024', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8973, to_date('25-07-2024', 'dd-mm-yyyy'), '4', '25', '207', '07', '2024', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8974, to_date('26-07-2024', 'dd-mm-yyyy'), '5', '26', '208', '07', '2024', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8975, to_date('27-07-2024', 'dd-mm-yyyy'), '6', '27', '209', '07', '2024', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8976, to_date('28-07-2024', 'dd-mm-yyyy'), '7', '28', '210', '07', '2024', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8977, to_date('29-07-2024', 'dd-mm-yyyy'), '1', '29', '211', '07', '2024', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8978, to_date('30-07-2024', 'dd-mm-yyyy'), '2', '30', '212', '07', '2024', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8979, to_date('31-07-2024', 'dd-mm-yyyy'), '3', '31', '213', '07', '2024', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8980, to_date('01-08-2024', 'dd-mm-yyyy'), '4', '01', '214', '08', '2024', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8981, to_date('02-08-2024', 'dd-mm-yyyy'), '5', '02', '215', '08', '2024', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8982, to_date('03-08-2024', 'dd-mm-yyyy'), '6', '03', '216', '08', '2024', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8983, to_date('04-08-2024', 'dd-mm-yyyy'), '7', '04', '217', '08', '2024', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8984, to_date('05-08-2024', 'dd-mm-yyyy'), '1', '05', '218', '08', '2024', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8985, to_date('06-08-2024', 'dd-mm-yyyy'), '2', '06', '219', '08', '2024', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8986, to_date('07-08-2024', 'dd-mm-yyyy'), '3', '07', '220', '08', '2024', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8987, to_date('08-08-2024', 'dd-mm-yyyy'), '4', '08', '221', '08', '2024', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8988, to_date('09-08-2024', 'dd-mm-yyyy'), '5', '09', '222', '08', '2024', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8989, to_date('10-08-2024', 'dd-mm-yyyy'), '6', '10', '223', '08', '2024', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8990, to_date('11-08-2024', 'dd-mm-yyyy'), '7', '11', '224', '08', '2024', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8991, to_date('12-08-2024', 'dd-mm-yyyy'), '1', '12', '225', '08', '2024', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8992, to_date('13-08-2024', 'dd-mm-yyyy'), '2', '13', '226', '08', '2024', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8993, to_date('14-08-2024', 'dd-mm-yyyy'), '3', '14', '227', '08', '2024', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8994, to_date('15-08-2024', 'dd-mm-yyyy'), '4', '15', '228', '08', '2024', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8995, to_date('16-08-2024', 'dd-mm-yyyy'), '5', '16', '229', '08', '2024', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8996, to_date('17-08-2024', 'dd-mm-yyyy'), '6', '17', '230', '08', '2024', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8997, to_date('18-08-2024', 'dd-mm-yyyy'), '7', '18', '231', '08', '2024', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8998, to_date('19-08-2024', 'dd-mm-yyyy'), '1', '19', '232', '08', '2024', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8999, to_date('20-08-2024', 'dd-mm-yyyy'), '2', '20', '233', '08', '2024', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9000, to_date('21-08-2024', 'dd-mm-yyyy'), '3', '21', '234', '08', '2024', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
commit;
prompt 9000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9001, to_date('22-08-2024', 'dd-mm-yyyy'), '4', '22', '235', '08', '2024', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9002, to_date('23-08-2024', 'dd-mm-yyyy'), '5', '23', '236', '08', '2024', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9003, to_date('24-08-2024', 'dd-mm-yyyy'), '6', '24', '237', '08', '2024', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9004, to_date('25-08-2024', 'dd-mm-yyyy'), '7', '25', '238', '08', '2024', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9005, to_date('26-08-2024', 'dd-mm-yyyy'), '1', '26', '239', '08', '2024', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9006, to_date('27-08-2024', 'dd-mm-yyyy'), '2', '27', '240', '08', '2024', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9007, to_date('28-08-2024', 'dd-mm-yyyy'), '3', '28', '241', '08', '2024', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9008, to_date('29-08-2024', 'dd-mm-yyyy'), '4', '29', '242', '08', '2024', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9009, to_date('30-08-2024', 'dd-mm-yyyy'), '5', '30', '243', '08', '2024', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9010, to_date('31-08-2024', 'dd-mm-yyyy'), '6', '31', '244', '08', '2024', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9011, to_date('01-09-2024', 'dd-mm-yyyy'), '7', '01', '245', '09', '2024', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9012, to_date('02-09-2024', 'dd-mm-yyyy'), '1', '02', '246', '09', '2024', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9013, to_date('03-09-2024', 'dd-mm-yyyy'), '2', '03', '247', '09', '2024', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9014, to_date('04-09-2024', 'dd-mm-yyyy'), '3', '04', '248', '09', '2024', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9015, to_date('05-09-2024', 'dd-mm-yyyy'), '4', '05', '249', '09', '2024', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9016, to_date('06-09-2024', 'dd-mm-yyyy'), '5', '06', '250', '09', '2024', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9017, to_date('07-09-2024', 'dd-mm-yyyy'), '6', '07', '251', '09', '2024', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9018, to_date('08-09-2024', 'dd-mm-yyyy'), '7', '08', '252', '09', '2024', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9019, to_date('09-09-2024', 'dd-mm-yyyy'), '1', '09', '253', '09', '2024', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9020, to_date('10-09-2024', 'dd-mm-yyyy'), '2', '10', '254', '09', '2024', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9021, to_date('11-09-2024', 'dd-mm-yyyy'), '3', '11', '255', '09', '2024', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9022, to_date('12-09-2024', 'dd-mm-yyyy'), '4', '12', '256', '09', '2024', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9023, to_date('13-09-2024', 'dd-mm-yyyy'), '5', '13', '257', '09', '2024', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9024, to_date('14-09-2024', 'dd-mm-yyyy'), '6', '14', '258', '09', '2024', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9025, to_date('15-09-2024', 'dd-mm-yyyy'), '7', '15', '259', '09', '2024', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9026, to_date('16-09-2024', 'dd-mm-yyyy'), '1', '16', '260', '09', '2024', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9027, to_date('17-09-2024', 'dd-mm-yyyy'), '2', '17', '261', '09', '2024', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9028, to_date('18-09-2024', 'dd-mm-yyyy'), '3', '18', '262', '09', '2024', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9029, to_date('19-09-2024', 'dd-mm-yyyy'), '4', '19', '263', '09', '2024', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9030, to_date('20-09-2024', 'dd-mm-yyyy'), '5', '20', '264', '09', '2024', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9031, to_date('21-09-2024', 'dd-mm-yyyy'), '6', '21', '265', '09', '2024', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9032, to_date('22-09-2024', 'dd-mm-yyyy'), '7', '22', '266', '09', '2024', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9033, to_date('23-09-2024', 'dd-mm-yyyy'), '1', '23', '267', '09', '2024', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9034, to_date('24-09-2024', 'dd-mm-yyyy'), '2', '24', '268', '09', '2024', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9035, to_date('25-09-2024', 'dd-mm-yyyy'), '3', '25', '269', '09', '2024', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9036, to_date('26-09-2024', 'dd-mm-yyyy'), '4', '26', '270', '09', '2024', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9037, to_date('27-09-2024', 'dd-mm-yyyy'), '5', '27', '271', '09', '2024', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9038, to_date('28-09-2024', 'dd-mm-yyyy'), '6', '28', '272', '09', '2024', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9039, to_date('29-09-2024', 'dd-mm-yyyy'), '7', '29', '273', '09', '2024', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9040, to_date('30-09-2024', 'dd-mm-yyyy'), '1', '30', '274', '09', '2024', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9041, to_date('01-10-2024', 'dd-mm-yyyy'), '2', '01', '275', '10', '2024', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9042, to_date('02-10-2024', 'dd-mm-yyyy'), '3', '02', '276', '10', '2024', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9043, to_date('03-10-2024', 'dd-mm-yyyy'), '4', '03', '277', '10', '2024', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9044, to_date('04-10-2024', 'dd-mm-yyyy'), '5', '04', '278', '10', '2024', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9045, to_date('05-10-2024', 'dd-mm-yyyy'), '6', '05', '279', '10', '2024', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9046, to_date('06-10-2024', 'dd-mm-yyyy'), '7', '06', '280', '10', '2024', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9047, to_date('07-10-2024', 'dd-mm-yyyy'), '1', '07', '281', '10', '2024', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9048, to_date('08-10-2024', 'dd-mm-yyyy'), '2', '08', '282', '10', '2024', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9049, to_date('09-10-2024', 'dd-mm-yyyy'), '3', '09', '283', '10', '2024', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9050, to_date('10-10-2024', 'dd-mm-yyyy'), '4', '10', '284', '10', '2024', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9051, to_date('11-10-2024', 'dd-mm-yyyy'), '5', '11', '285', '10', '2024', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9052, to_date('12-10-2024', 'dd-mm-yyyy'), '6', '12', '286', '10', '2024', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9053, to_date('13-10-2024', 'dd-mm-yyyy'), '7', '13', '287', '10', '2024', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9054, to_date('14-10-2024', 'dd-mm-yyyy'), '1', '14', '288', '10', '2024', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9055, to_date('15-10-2024', 'dd-mm-yyyy'), '2', '15', '289', '10', '2024', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9056, to_date('16-10-2024', 'dd-mm-yyyy'), '3', '16', '290', '10', '2024', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9057, to_date('17-10-2024', 'dd-mm-yyyy'), '4', '17', '291', '10', '2024', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9058, to_date('18-10-2024', 'dd-mm-yyyy'), '5', '18', '292', '10', '2024', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9059, to_date('19-10-2024', 'dd-mm-yyyy'), '6', '19', '293', '10', '2024', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9060, to_date('20-10-2024', 'dd-mm-yyyy'), '7', '20', '294', '10', '2024', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9061, to_date('21-10-2024', 'dd-mm-yyyy'), '1', '21', '295', '10', '2024', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9062, to_date('22-10-2024', 'dd-mm-yyyy'), '2', '22', '296', '10', '2024', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9063, to_date('23-10-2024', 'dd-mm-yyyy'), '3', '23', '297', '10', '2024', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9064, to_date('24-10-2024', 'dd-mm-yyyy'), '4', '24', '298', '10', '2024', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9065, to_date('25-10-2024', 'dd-mm-yyyy'), '5', '25', '299', '10', '2024', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9066, to_date('26-10-2024', 'dd-mm-yyyy'), '6', '26', '300', '10', '2024', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9067, to_date('27-10-2024', 'dd-mm-yyyy'), '7', '27', '301', '10', '2024', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9068, to_date('28-10-2024', 'dd-mm-yyyy'), '1', '28', '302', '10', '2024', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9069, to_date('29-10-2024', 'dd-mm-yyyy'), '2', '29', '303', '10', '2024', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9070, to_date('30-10-2024', 'dd-mm-yyyy'), '3', '30', '304', '10', '2024', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9071, to_date('31-10-2024', 'dd-mm-yyyy'), '4', '31', '305', '10', '2024', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9072, to_date('01-11-2024', 'dd-mm-yyyy'), '5', '01', '306', '11', '2024', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9073, to_date('02-11-2024', 'dd-mm-yyyy'), '6', '02', '307', '11', '2024', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9074, to_date('03-11-2024', 'dd-mm-yyyy'), '7', '03', '308', '11', '2024', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9075, to_date('04-11-2024', 'dd-mm-yyyy'), '1', '04', '309', '11', '2024', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9076, to_date('05-11-2024', 'dd-mm-yyyy'), '2', '05', '310', '11', '2024', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9077, to_date('06-11-2024', 'dd-mm-yyyy'), '3', '06', '311', '11', '2024', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9078, to_date('07-11-2024', 'dd-mm-yyyy'), '4', '07', '312', '11', '2024', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9079, to_date('08-11-2024', 'dd-mm-yyyy'), '5', '08', '313', '11', '2024', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9080, to_date('09-11-2024', 'dd-mm-yyyy'), '6', '09', '314', '11', '2024', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9081, to_date('10-11-2024', 'dd-mm-yyyy'), '7', '10', '315', '11', '2024', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9082, to_date('11-11-2024', 'dd-mm-yyyy'), '1', '11', '316', '11', '2024', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9083, to_date('12-11-2024', 'dd-mm-yyyy'), '2', '12', '317', '11', '2024', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9084, to_date('13-11-2024', 'dd-mm-yyyy'), '3', '13', '318', '11', '2024', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9085, to_date('14-11-2024', 'dd-mm-yyyy'), '4', '14', '319', '11', '2024', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9086, to_date('15-11-2024', 'dd-mm-yyyy'), '5', '15', '320', '11', '2024', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9087, to_date('16-11-2024', 'dd-mm-yyyy'), '6', '16', '321', '11', '2024', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9088, to_date('17-11-2024', 'dd-mm-yyyy'), '7', '17', '322', '11', '2024', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9089, to_date('18-11-2024', 'dd-mm-yyyy'), '1', '18', '323', '11', '2024', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9090, to_date('19-11-2024', 'dd-mm-yyyy'), '2', '19', '324', '11', '2024', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9091, to_date('20-11-2024', 'dd-mm-yyyy'), '3', '20', '325', '11', '2024', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9092, to_date('21-11-2024', 'dd-mm-yyyy'), '4', '21', '326', '11', '2024', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9093, to_date('22-11-2024', 'dd-mm-yyyy'), '5', '22', '327', '11', '2024', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9094, to_date('23-11-2024', 'dd-mm-yyyy'), '6', '23', '328', '11', '2024', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9095, to_date('24-11-2024', 'dd-mm-yyyy'), '7', '24', '329', '11', '2024', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9096, to_date('25-11-2024', 'dd-mm-yyyy'), '1', '25', '330', '11', '2024', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9097, to_date('26-11-2024', 'dd-mm-yyyy'), '2', '26', '331', '11', '2024', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9098, to_date('27-11-2024', 'dd-mm-yyyy'), '3', '27', '332', '11', '2024', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9099, to_date('28-11-2024', 'dd-mm-yyyy'), '4', '28', '333', '11', '2024', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9100, to_date('29-11-2024', 'dd-mm-yyyy'), '5', '29', '334', '11', '2024', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9101, to_date('30-11-2024', 'dd-mm-yyyy'), '6', '30', '335', '11', '2024', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9102, to_date('01-12-2024', 'dd-mm-yyyy'), '7', '01', '336', '12', '2024', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9103, to_date('02-12-2024', 'dd-mm-yyyy'), '1', '02', '337', '12', '2024', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9104, to_date('03-12-2024', 'dd-mm-yyyy'), '2', '03', '338', '12', '2024', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9105, to_date('04-12-2024', 'dd-mm-yyyy'), '3', '04', '339', '12', '2024', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9106, to_date('05-12-2024', 'dd-mm-yyyy'), '4', '05', '340', '12', '2024', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9107, to_date('06-12-2024', 'dd-mm-yyyy'), '5', '06', '341', '12', '2024', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9108, to_date('07-12-2024', 'dd-mm-yyyy'), '6', '07', '342', '12', '2024', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9109, to_date('08-12-2024', 'dd-mm-yyyy'), '7', '08', '343', '12', '2024', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9110, to_date('09-12-2024', 'dd-mm-yyyy'), '1', '09', '344', '12', '2024', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9111, to_date('10-12-2024', 'dd-mm-yyyy'), '2', '10', '345', '12', '2024', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9112, to_date('11-12-2024', 'dd-mm-yyyy'), '3', '11', '346', '12', '2024', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9113, to_date('12-12-2024', 'dd-mm-yyyy'), '4', '12', '347', '12', '2024', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9114, to_date('13-12-2024', 'dd-mm-yyyy'), '5', '13', '348', '12', '2024', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9115, to_date('14-12-2024', 'dd-mm-yyyy'), '6', '14', '349', '12', '2024', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9116, to_date('15-12-2024', 'dd-mm-yyyy'), '7', '15', '350', '12', '2024', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9117, to_date('16-12-2024', 'dd-mm-yyyy'), '1', '16', '351', '12', '2024', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9118, to_date('17-12-2024', 'dd-mm-yyyy'), '2', '17', '352', '12', '2024', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9119, to_date('18-12-2024', 'dd-mm-yyyy'), '3', '18', '353', '12', '2024', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9120, to_date('19-12-2024', 'dd-mm-yyyy'), '4', '19', '354', '12', '2024', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9121, to_date('20-12-2024', 'dd-mm-yyyy'), '5', '20', '355', '12', '2024', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9122, to_date('21-12-2024', 'dd-mm-yyyy'), '6', '21', '356', '12', '2024', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9123, to_date('22-12-2024', 'dd-mm-yyyy'), '7', '22', '357', '12', '2024', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9124, to_date('23-12-2024', 'dd-mm-yyyy'), '1', '23', '358', '12', '2024', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9125, to_date('24-12-2024', 'dd-mm-yyyy'), '2', '24', '359', '12', '2024', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9126, to_date('25-12-2024', 'dd-mm-yyyy'), '3', '25', '360', '12', '2024', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9127, to_date('26-12-2024', 'dd-mm-yyyy'), '4', '26', '361', '12', '2024', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9128, to_date('27-12-2024', 'dd-mm-yyyy'), '5', '27', '362', '12', '2024', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9129, to_date('28-12-2024', 'dd-mm-yyyy'), '6', '28', '363', '12', '2024', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9130, to_date('29-12-2024', 'dd-mm-yyyy'), '7', '29', '364', '12', '2024', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9131, to_date('30-12-2024', 'dd-mm-yyyy'), '1', '30', '365', '12', '2024', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9132, to_date('31-12-2024', 'dd-mm-yyyy'), '2', '31', '366', '12', '2024', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9133, to_date('01-01-2025', 'dd-mm-yyyy'), '3', '01', '001', '01', '2025', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9134, to_date('02-01-2025', 'dd-mm-yyyy'), '4', '02', '002', '01', '2025', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9135, to_date('03-01-2025', 'dd-mm-yyyy'), '5', '03', '003', '01', '2025', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9136, to_date('04-01-2025', 'dd-mm-yyyy'), '6', '04', '004', '01', '2025', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9137, to_date('05-01-2025', 'dd-mm-yyyy'), '7', '05', '005', '01', '2025', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9138, to_date('06-01-2025', 'dd-mm-yyyy'), '1', '06', '006', '01', '2025', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9139, to_date('07-01-2025', 'dd-mm-yyyy'), '2', '07', '007', '01', '2025', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9140, to_date('08-01-2025', 'dd-mm-yyyy'), '3', '08', '008', '01', '2025', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9141, to_date('09-01-2025', 'dd-mm-yyyy'), '4', '09', '009', '01', '2025', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9142, to_date('10-01-2025', 'dd-mm-yyyy'), '5', '10', '010', '01', '2025', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9143, to_date('11-01-2025', 'dd-mm-yyyy'), '6', '11', '011', '01', '2025', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9144, to_date('12-01-2025', 'dd-mm-yyyy'), '7', '12', '012', '01', '2025', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9145, to_date('13-01-2025', 'dd-mm-yyyy'), '1', '13', '013', '01', '2025', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9146, to_date('14-01-2025', 'dd-mm-yyyy'), '2', '14', '014', '01', '2025', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9147, to_date('15-01-2025', 'dd-mm-yyyy'), '3', '15', '015', '01', '2025', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9148, to_date('16-01-2025', 'dd-mm-yyyy'), '4', '16', '016', '01', '2025', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9149, to_date('17-01-2025', 'dd-mm-yyyy'), '5', '17', '017', '01', '2025', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9150, to_date('18-01-2025', 'dd-mm-yyyy'), '6', '18', '018', '01', '2025', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9151, to_date('19-01-2025', 'dd-mm-yyyy'), '7', '19', '019', '01', '2025', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9152, to_date('20-01-2025', 'dd-mm-yyyy'), '1', '20', '020', '01', '2025', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9153, to_date('21-01-2025', 'dd-mm-yyyy'), '2', '21', '021', '01', '2025', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9154, to_date('22-01-2025', 'dd-mm-yyyy'), '3', '22', '022', '01', '2025', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9155, to_date('23-01-2025', 'dd-mm-yyyy'), '4', '23', '023', '01', '2025', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9156, to_date('24-01-2025', 'dd-mm-yyyy'), '5', '24', '024', '01', '2025', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9157, to_date('25-01-2025', 'dd-mm-yyyy'), '6', '25', '025', '01', '2025', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9158, to_date('26-01-2025', 'dd-mm-yyyy'), '7', '26', '026', '01', '2025', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9159, to_date('27-01-2025', 'dd-mm-yyyy'), '1', '27', '027', '01', '2025', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9160, to_date('28-01-2025', 'dd-mm-yyyy'), '2', '28', '028', '01', '2025', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9161, to_date('29-01-2025', 'dd-mm-yyyy'), '3', '29', '029', '01', '2025', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9162, to_date('30-01-2025', 'dd-mm-yyyy'), '4', '30', '030', '01', '2025', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9163, to_date('31-01-2025', 'dd-mm-yyyy'), '5', '31', '031', '01', '2025', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9164, to_date('01-02-2025', 'dd-mm-yyyy'), '6', '01', '032', '02', '2025', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9165, to_date('02-02-2025', 'dd-mm-yyyy'), '7', '02', '033', '02', '2025', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9166, to_date('03-02-2025', 'dd-mm-yyyy'), '1', '03', '034', '02', '2025', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9167, to_date('04-02-2025', 'dd-mm-yyyy'), '2', '04', '035', '02', '2025', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9168, to_date('05-02-2025', 'dd-mm-yyyy'), '3', '05', '036', '02', '2025', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9169, to_date('06-02-2025', 'dd-mm-yyyy'), '4', '06', '037', '02', '2025', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9170, to_date('07-02-2025', 'dd-mm-yyyy'), '5', '07', '038', '02', '2025', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9171, to_date('08-02-2025', 'dd-mm-yyyy'), '6', '08', '039', '02', '2025', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9172, to_date('09-02-2025', 'dd-mm-yyyy'), '7', '09', '040', '02', '2025', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9173, to_date('10-02-2025', 'dd-mm-yyyy'), '1', '10', '041', '02', '2025', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9174, to_date('11-02-2025', 'dd-mm-yyyy'), '2', '11', '042', '02', '2025', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9175, to_date('12-02-2025', 'dd-mm-yyyy'), '3', '12', '043', '02', '2025', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9176, to_date('13-02-2025', 'dd-mm-yyyy'), '4', '13', '044', '02', '2025', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9177, to_date('14-02-2025', 'dd-mm-yyyy'), '5', '14', '045', '02', '2025', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9178, to_date('15-02-2025', 'dd-mm-yyyy'), '6', '15', '046', '02', '2025', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9179, to_date('16-02-2025', 'dd-mm-yyyy'), '7', '16', '047', '02', '2025', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9180, to_date('17-02-2025', 'dd-mm-yyyy'), '1', '17', '048', '02', '2025', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9181, to_date('18-02-2025', 'dd-mm-yyyy'), '2', '18', '049', '02', '2025', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9182, to_date('19-02-2025', 'dd-mm-yyyy'), '3', '19', '050', '02', '2025', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9183, to_date('20-02-2025', 'dd-mm-yyyy'), '4', '20', '051', '02', '2025', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9184, to_date('21-02-2025', 'dd-mm-yyyy'), '5', '21', '052', '02', '2025', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9185, to_date('22-02-2025', 'dd-mm-yyyy'), '6', '22', '053', '02', '2025', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9186, to_date('23-02-2025', 'dd-mm-yyyy'), '7', '23', '054', '02', '2025', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9187, to_date('24-02-2025', 'dd-mm-yyyy'), '1', '24', '055', '02', '2025', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9188, to_date('25-02-2025', 'dd-mm-yyyy'), '2', '25', '056', '02', '2025', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9189, to_date('26-02-2025', 'dd-mm-yyyy'), '3', '26', '057', '02', '2025', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9190, to_date('27-02-2025', 'dd-mm-yyyy'), '4', '27', '058', '02', '2025', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9191, to_date('28-02-2025', 'dd-mm-yyyy'), '5', '28', '059', '02', '2025', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9192, to_date('01-03-2025', 'dd-mm-yyyy'), '6', '01', '060', '03', '2025', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9193, to_date('02-03-2025', 'dd-mm-yyyy'), '7', '02', '061', '03', '2025', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9194, to_date('03-03-2025', 'dd-mm-yyyy'), '1', '03', '062', '03', '2025', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9195, to_date('04-03-2025', 'dd-mm-yyyy'), '2', '04', '063', '03', '2025', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9196, to_date('05-03-2025', 'dd-mm-yyyy'), '3', '05', '064', '03', '2025', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9197, to_date('06-03-2025', 'dd-mm-yyyy'), '4', '06', '065', '03', '2025', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9198, to_date('07-03-2025', 'dd-mm-yyyy'), '5', '07', '066', '03', '2025', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9199, to_date('08-03-2025', 'dd-mm-yyyy'), '6', '08', '067', '03', '2025', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9200, to_date('09-03-2025', 'dd-mm-yyyy'), '7', '09', '068', '03', '2025', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9201, to_date('10-03-2025', 'dd-mm-yyyy'), '1', '10', '069', '03', '2025', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9202, to_date('11-03-2025', 'dd-mm-yyyy'), '2', '11', '070', '03', '2025', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9203, to_date('12-03-2025', 'dd-mm-yyyy'), '3', '12', '071', '03', '2025', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9204, to_date('13-03-2025', 'dd-mm-yyyy'), '4', '13', '072', '03', '2025', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9205, to_date('14-03-2025', 'dd-mm-yyyy'), '5', '14', '073', '03', '2025', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9206, to_date('15-03-2025', 'dd-mm-yyyy'), '6', '15', '074', '03', '2025', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9207, to_date('16-03-2025', 'dd-mm-yyyy'), '7', '16', '075', '03', '2025', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9208, to_date('17-03-2025', 'dd-mm-yyyy'), '1', '17', '076', '03', '2025', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9209, to_date('18-03-2025', 'dd-mm-yyyy'), '2', '18', '077', '03', '2025', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9210, to_date('19-03-2025', 'dd-mm-yyyy'), '3', '19', '078', '03', '2025', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9211, to_date('20-03-2025', 'dd-mm-yyyy'), '4', '20', '079', '03', '2025', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9212, to_date('21-03-2025', 'dd-mm-yyyy'), '5', '21', '080', '03', '2025', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9213, to_date('22-03-2025', 'dd-mm-yyyy'), '6', '22', '081', '03', '2025', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9214, to_date('23-03-2025', 'dd-mm-yyyy'), '7', '23', '082', '03', '2025', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9215, to_date('24-03-2025', 'dd-mm-yyyy'), '1', '24', '083', '03', '2025', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9216, to_date('25-03-2025', 'dd-mm-yyyy'), '2', '25', '084', '03', '2025', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9217, to_date('26-03-2025', 'dd-mm-yyyy'), '3', '26', '085', '03', '2025', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9218, to_date('27-03-2025', 'dd-mm-yyyy'), '4', '27', '086', '03', '2025', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9219, to_date('28-03-2025', 'dd-mm-yyyy'), '5', '28', '087', '03', '2025', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9220, to_date('29-03-2025', 'dd-mm-yyyy'), '6', '29', '088', '03', '2025', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9221, to_date('30-03-2025', 'dd-mm-yyyy'), '7', '30', '089', '03', '2025', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9222, to_date('31-03-2025', 'dd-mm-yyyy'), '1', '31', '090', '03', '2025', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9223, to_date('01-04-2025', 'dd-mm-yyyy'), '2', '01', '091', '04', '2025', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9224, to_date('02-04-2025', 'dd-mm-yyyy'), '3', '02', '092', '04', '2025', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9225, to_date('03-04-2025', 'dd-mm-yyyy'), '4', '03', '093', '04', '2025', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9226, to_date('04-04-2025', 'dd-mm-yyyy'), '5', '04', '094', '04', '2025', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9227, to_date('05-04-2025', 'dd-mm-yyyy'), '6', '05', '095', '04', '2025', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9228, to_date('06-04-2025', 'dd-mm-yyyy'), '7', '06', '096', '04', '2025', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9229, to_date('07-04-2025', 'dd-mm-yyyy'), '1', '07', '097', '04', '2025', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9230, to_date('08-04-2025', 'dd-mm-yyyy'), '2', '08', '098', '04', '2025', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9231, to_date('09-04-2025', 'dd-mm-yyyy'), '3', '09', '099', '04', '2025', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9232, to_date('10-04-2025', 'dd-mm-yyyy'), '4', '10', '100', '04', '2025', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9233, to_date('11-04-2025', 'dd-mm-yyyy'), '5', '11', '101', '04', '2025', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9234, to_date('12-04-2025', 'dd-mm-yyyy'), '6', '12', '102', '04', '2025', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9235, to_date('13-04-2025', 'dd-mm-yyyy'), '7', '13', '103', '04', '2025', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9236, to_date('14-04-2025', 'dd-mm-yyyy'), '1', '14', '104', '04', '2025', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9237, to_date('15-04-2025', 'dd-mm-yyyy'), '2', '15', '105', '04', '2025', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9238, to_date('16-04-2025', 'dd-mm-yyyy'), '3', '16', '106', '04', '2025', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9239, to_date('17-04-2025', 'dd-mm-yyyy'), '4', '17', '107', '04', '2025', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9240, to_date('18-04-2025', 'dd-mm-yyyy'), '5', '18', '108', '04', '2025', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9241, to_date('19-04-2025', 'dd-mm-yyyy'), '6', '19', '109', '04', '2025', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9242, to_date('20-04-2025', 'dd-mm-yyyy'), '7', '20', '110', '04', '2025', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9243, to_date('21-04-2025', 'dd-mm-yyyy'), '1', '21', '111', '04', '2025', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9244, to_date('22-04-2025', 'dd-mm-yyyy'), '2', '22', '112', '04', '2025', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9245, to_date('23-04-2025', 'dd-mm-yyyy'), '3', '23', '113', '04', '2025', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9246, to_date('24-04-2025', 'dd-mm-yyyy'), '4', '24', '114', '04', '2025', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9247, to_date('25-04-2025', 'dd-mm-yyyy'), '5', '25', '115', '04', '2025', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9248, to_date('26-04-2025', 'dd-mm-yyyy'), '6', '26', '116', '04', '2025', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9249, to_date('27-04-2025', 'dd-mm-yyyy'), '7', '27', '117', '04', '2025', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9250, to_date('28-04-2025', 'dd-mm-yyyy'), '1', '28', '118', '04', '2025', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9251, to_date('29-04-2025', 'dd-mm-yyyy'), '2', '29', '119', '04', '2025', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9252, to_date('30-04-2025', 'dd-mm-yyyy'), '3', '30', '120', '04', '2025', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9253, to_date('01-05-2025', 'dd-mm-yyyy'), '4', '01', '121', '05', '2025', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9254, to_date('02-05-2025', 'dd-mm-yyyy'), '5', '02', '122', '05', '2025', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9255, to_date('03-05-2025', 'dd-mm-yyyy'), '6', '03', '123', '05', '2025', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9256, to_date('04-05-2025', 'dd-mm-yyyy'), '7', '04', '124', '05', '2025', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9257, to_date('05-05-2025', 'dd-mm-yyyy'), '1', '05', '125', '05', '2025', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9258, to_date('06-05-2025', 'dd-mm-yyyy'), '2', '06', '126', '05', '2025', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9259, to_date('07-05-2025', 'dd-mm-yyyy'), '3', '07', '127', '05', '2025', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9260, to_date('08-05-2025', 'dd-mm-yyyy'), '4', '08', '128', '05', '2025', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9261, to_date('09-05-2025', 'dd-mm-yyyy'), '5', '09', '129', '05', '2025', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9262, to_date('10-05-2025', 'dd-mm-yyyy'), '6', '10', '130', '05', '2025', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9263, to_date('11-05-2025', 'dd-mm-yyyy'), '7', '11', '131', '05', '2025', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9264, to_date('12-05-2025', 'dd-mm-yyyy'), '1', '12', '132', '05', '2025', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9265, to_date('13-05-2025', 'dd-mm-yyyy'), '2', '13', '133', '05', '2025', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9266, to_date('14-05-2025', 'dd-mm-yyyy'), '3', '14', '134', '05', '2025', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9267, to_date('15-05-2025', 'dd-mm-yyyy'), '4', '15', '135', '05', '2025', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9268, to_date('16-05-2025', 'dd-mm-yyyy'), '5', '16', '136', '05', '2025', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9269, to_date('17-05-2025', 'dd-mm-yyyy'), '6', '17', '137', '05', '2025', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9270, to_date('18-05-2025', 'dd-mm-yyyy'), '7', '18', '138', '05', '2025', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9271, to_date('19-05-2025', 'dd-mm-yyyy'), '1', '19', '139', '05', '2025', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9272, to_date('20-05-2025', 'dd-mm-yyyy'), '2', '20', '140', '05', '2025', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9273, to_date('21-05-2025', 'dd-mm-yyyy'), '3', '21', '141', '05', '2025', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9274, to_date('22-05-2025', 'dd-mm-yyyy'), '4', '22', '142', '05', '2025', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9275, to_date('23-05-2025', 'dd-mm-yyyy'), '5', '23', '143', '05', '2025', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9276, to_date('24-05-2025', 'dd-mm-yyyy'), '6', '24', '144', '05', '2025', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9277, to_date('25-05-2025', 'dd-mm-yyyy'), '7', '25', '145', '05', '2025', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9278, to_date('26-05-2025', 'dd-mm-yyyy'), '1', '26', '146', '05', '2025', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9279, to_date('27-05-2025', 'dd-mm-yyyy'), '2', '27', '147', '05', '2025', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9280, to_date('28-05-2025', 'dd-mm-yyyy'), '3', '28', '148', '05', '2025', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9281, to_date('29-05-2025', 'dd-mm-yyyy'), '4', '29', '149', '05', '2025', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9282, to_date('30-05-2025', 'dd-mm-yyyy'), '5', '30', '150', '05', '2025', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9283, to_date('31-05-2025', 'dd-mm-yyyy'), '6', '31', '151', '05', '2025', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9284, to_date('01-06-2025', 'dd-mm-yyyy'), '7', '01', '152', '06', '2025', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9285, to_date('02-06-2025', 'dd-mm-yyyy'), '1', '02', '153', '06', '2025', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9286, to_date('03-06-2025', 'dd-mm-yyyy'), '2', '03', '154', '06', '2025', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9287, to_date('04-06-2025', 'dd-mm-yyyy'), '3', '04', '155', '06', '2025', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9288, to_date('05-06-2025', 'dd-mm-yyyy'), '4', '05', '156', '06', '2025', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9289, to_date('06-06-2025', 'dd-mm-yyyy'), '5', '06', '157', '06', '2025', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9290, to_date('07-06-2025', 'dd-mm-yyyy'), '6', '07', '158', '06', '2025', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9291, to_date('08-06-2025', 'dd-mm-yyyy'), '7', '08', '159', '06', '2025', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9292, to_date('09-06-2025', 'dd-mm-yyyy'), '1', '09', '160', '06', '2025', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9293, to_date('10-06-2025', 'dd-mm-yyyy'), '2', '10', '161', '06', '2025', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9294, to_date('11-06-2025', 'dd-mm-yyyy'), '3', '11', '162', '06', '2025', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9295, to_date('12-06-2025', 'dd-mm-yyyy'), '4', '12', '163', '06', '2025', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9296, to_date('13-06-2025', 'dd-mm-yyyy'), '5', '13', '164', '06', '2025', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9297, to_date('14-06-2025', 'dd-mm-yyyy'), '6', '14', '165', '06', '2025', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9298, to_date('15-06-2025', 'dd-mm-yyyy'), '7', '15', '166', '06', '2025', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9299, to_date('16-06-2025', 'dd-mm-yyyy'), '1', '16', '167', '06', '2025', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9300, to_date('17-06-2025', 'dd-mm-yyyy'), '2', '17', '168', '06', '2025', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9301, to_date('18-06-2025', 'dd-mm-yyyy'), '3', '18', '169', '06', '2025', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9302, to_date('19-06-2025', 'dd-mm-yyyy'), '4', '19', '170', '06', '2025', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9303, to_date('20-06-2025', 'dd-mm-yyyy'), '5', '20', '171', '06', '2025', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9304, to_date('21-06-2025', 'dd-mm-yyyy'), '6', '21', '172', '06', '2025', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9305, to_date('22-06-2025', 'dd-mm-yyyy'), '7', '22', '173', '06', '2025', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9306, to_date('23-06-2025', 'dd-mm-yyyy'), '1', '23', '174', '06', '2025', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9307, to_date('24-06-2025', 'dd-mm-yyyy'), '2', '24', '175', '06', '2025', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9308, to_date('25-06-2025', 'dd-mm-yyyy'), '3', '25', '176', '06', '2025', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9309, to_date('26-06-2025', 'dd-mm-yyyy'), '4', '26', '177', '06', '2025', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9310, to_date('27-06-2025', 'dd-mm-yyyy'), '5', '27', '178', '06', '2025', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9311, to_date('28-06-2025', 'dd-mm-yyyy'), '6', '28', '179', '06', '2025', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9312, to_date('29-06-2025', 'dd-mm-yyyy'), '7', '29', '180', '06', '2025', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9313, to_date('30-06-2025', 'dd-mm-yyyy'), '1', '30', '181', '06', '2025', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9314, to_date('01-07-2025', 'dd-mm-yyyy'), '2', '01', '182', '07', '2025', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9315, to_date('02-07-2025', 'dd-mm-yyyy'), '3', '02', '183', '07', '2025', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9316, to_date('03-07-2025', 'dd-mm-yyyy'), '4', '03', '184', '07', '2025', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9317, to_date('04-07-2025', 'dd-mm-yyyy'), '5', '04', '185', '07', '2025', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9318, to_date('05-07-2025', 'dd-mm-yyyy'), '6', '05', '186', '07', '2025', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9319, to_date('06-07-2025', 'dd-mm-yyyy'), '7', '06', '187', '07', '2025', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9320, to_date('07-07-2025', 'dd-mm-yyyy'), '1', '07', '188', '07', '2025', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9321, to_date('08-07-2025', 'dd-mm-yyyy'), '2', '08', '189', '07', '2025', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9322, to_date('09-07-2025', 'dd-mm-yyyy'), '3', '09', '190', '07', '2025', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9323, to_date('10-07-2025', 'dd-mm-yyyy'), '4', '10', '191', '07', '2025', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9324, to_date('11-07-2025', 'dd-mm-yyyy'), '5', '11', '192', '07', '2025', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9325, to_date('12-07-2025', 'dd-mm-yyyy'), '6', '12', '193', '07', '2025', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9326, to_date('13-07-2025', 'dd-mm-yyyy'), '7', '13', '194', '07', '2025', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9327, to_date('14-07-2025', 'dd-mm-yyyy'), '1', '14', '195', '07', '2025', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9328, to_date('15-07-2025', 'dd-mm-yyyy'), '2', '15', '196', '07', '2025', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9329, to_date('16-07-2025', 'dd-mm-yyyy'), '3', '16', '197', '07', '2025', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9330, to_date('17-07-2025', 'dd-mm-yyyy'), '4', '17', '198', '07', '2025', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9331, to_date('18-07-2025', 'dd-mm-yyyy'), '5', '18', '199', '07', '2025', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9332, to_date('19-07-2025', 'dd-mm-yyyy'), '6', '19', '200', '07', '2025', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9333, to_date('20-07-2025', 'dd-mm-yyyy'), '7', '20', '201', '07', '2025', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9334, to_date('21-07-2025', 'dd-mm-yyyy'), '1', '21', '202', '07', '2025', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9335, to_date('22-07-2025', 'dd-mm-yyyy'), '2', '22', '203', '07', '2025', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9336, to_date('23-07-2025', 'dd-mm-yyyy'), '3', '23', '204', '07', '2025', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9337, to_date('24-07-2025', 'dd-mm-yyyy'), '4', '24', '205', '07', '2025', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9338, to_date('25-07-2025', 'dd-mm-yyyy'), '5', '25', '206', '07', '2025', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9339, to_date('26-07-2025', 'dd-mm-yyyy'), '6', '26', '207', '07', '2025', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9340, to_date('27-07-2025', 'dd-mm-yyyy'), '7', '27', '208', '07', '2025', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9341, to_date('28-07-2025', 'dd-mm-yyyy'), '1', '28', '209', '07', '2025', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9342, to_date('29-07-2025', 'dd-mm-yyyy'), '2', '29', '210', '07', '2025', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9343, to_date('30-07-2025', 'dd-mm-yyyy'), '3', '30', '211', '07', '2025', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9344, to_date('31-07-2025', 'dd-mm-yyyy'), '4', '31', '212', '07', '2025', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9345, to_date('01-08-2025', 'dd-mm-yyyy'), '5', '01', '213', '08', '2025', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9346, to_date('02-08-2025', 'dd-mm-yyyy'), '6', '02', '214', '08', '2025', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9347, to_date('03-08-2025', 'dd-mm-yyyy'), '7', '03', '215', '08', '2025', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9348, to_date('04-08-2025', 'dd-mm-yyyy'), '1', '04', '216', '08', '2025', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9349, to_date('05-08-2025', 'dd-mm-yyyy'), '2', '05', '217', '08', '2025', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9350, to_date('06-08-2025', 'dd-mm-yyyy'), '3', '06', '218', '08', '2025', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9351, to_date('07-08-2025', 'dd-mm-yyyy'), '4', '07', '219', '08', '2025', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9352, to_date('08-08-2025', 'dd-mm-yyyy'), '5', '08', '220', '08', '2025', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9353, to_date('09-08-2025', 'dd-mm-yyyy'), '6', '09', '221', '08', '2025', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9354, to_date('10-08-2025', 'dd-mm-yyyy'), '7', '10', '222', '08', '2025', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9355, to_date('11-08-2025', 'dd-mm-yyyy'), '1', '11', '223', '08', '2025', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9356, to_date('12-08-2025', 'dd-mm-yyyy'), '2', '12', '224', '08', '2025', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9357, to_date('13-08-2025', 'dd-mm-yyyy'), '3', '13', '225', '08', '2025', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9358, to_date('14-08-2025', 'dd-mm-yyyy'), '4', '14', '226', '08', '2025', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9359, to_date('15-08-2025', 'dd-mm-yyyy'), '5', '15', '227', '08', '2025', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9360, to_date('16-08-2025', 'dd-mm-yyyy'), '6', '16', '228', '08', '2025', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9361, to_date('17-08-2025', 'dd-mm-yyyy'), '7', '17', '229', '08', '2025', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9362, to_date('18-08-2025', 'dd-mm-yyyy'), '1', '18', '230', '08', '2025', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9363, to_date('19-08-2025', 'dd-mm-yyyy'), '2', '19', '231', '08', '2025', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9364, to_date('20-08-2025', 'dd-mm-yyyy'), '3', '20', '232', '08', '2025', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9365, to_date('21-08-2025', 'dd-mm-yyyy'), '4', '21', '233', '08', '2025', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9366, to_date('22-08-2025', 'dd-mm-yyyy'), '5', '22', '234', '08', '2025', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9367, to_date('23-08-2025', 'dd-mm-yyyy'), '6', '23', '235', '08', '2025', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9368, to_date('24-08-2025', 'dd-mm-yyyy'), '7', '24', '236', '08', '2025', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9369, to_date('25-08-2025', 'dd-mm-yyyy'), '1', '25', '237', '08', '2025', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9370, to_date('26-08-2025', 'dd-mm-yyyy'), '2', '26', '238', '08', '2025', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9371, to_date('27-08-2025', 'dd-mm-yyyy'), '3', '27', '239', '08', '2025', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9372, to_date('28-08-2025', 'dd-mm-yyyy'), '4', '28', '240', '08', '2025', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9373, to_date('29-08-2025', 'dd-mm-yyyy'), '5', '29', '241', '08', '2025', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9374, to_date('30-08-2025', 'dd-mm-yyyy'), '6', '30', '242', '08', '2025', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9375, to_date('31-08-2025', 'dd-mm-yyyy'), '7', '31', '243', '08', '2025', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9376, to_date('01-09-2025', 'dd-mm-yyyy'), '1', '01', '244', '09', '2025', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9377, to_date('02-09-2025', 'dd-mm-yyyy'), '2', '02', '245', '09', '2025', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9378, to_date('03-09-2025', 'dd-mm-yyyy'), '3', '03', '246', '09', '2025', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9379, to_date('04-09-2025', 'dd-mm-yyyy'), '4', '04', '247', '09', '2025', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9380, to_date('05-09-2025', 'dd-mm-yyyy'), '5', '05', '248', '09', '2025', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9381, to_date('06-09-2025', 'dd-mm-yyyy'), '6', '06', '249', '09', '2025', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9382, to_date('07-09-2025', 'dd-mm-yyyy'), '7', '07', '250', '09', '2025', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9383, to_date('08-09-2025', 'dd-mm-yyyy'), '1', '08', '251', '09', '2025', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9384, to_date('09-09-2025', 'dd-mm-yyyy'), '2', '09', '252', '09', '2025', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9385, to_date('10-09-2025', 'dd-mm-yyyy'), '3', '10', '253', '09', '2025', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9386, to_date('11-09-2025', 'dd-mm-yyyy'), '4', '11', '254', '09', '2025', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9387, to_date('12-09-2025', 'dd-mm-yyyy'), '5', '12', '255', '09', '2025', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9388, to_date('13-09-2025', 'dd-mm-yyyy'), '6', '13', '256', '09', '2025', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9389, to_date('14-09-2025', 'dd-mm-yyyy'), '7', '14', '257', '09', '2025', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9390, to_date('15-09-2025', 'dd-mm-yyyy'), '1', '15', '258', '09', '2025', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9391, to_date('16-09-2025', 'dd-mm-yyyy'), '2', '16', '259', '09', '2025', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9392, to_date('17-09-2025', 'dd-mm-yyyy'), '3', '17', '260', '09', '2025', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9393, to_date('18-09-2025', 'dd-mm-yyyy'), '4', '18', '261', '09', '2025', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9394, to_date('19-09-2025', 'dd-mm-yyyy'), '5', '19', '262', '09', '2025', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9395, to_date('20-09-2025', 'dd-mm-yyyy'), '6', '20', '263', '09', '2025', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9396, to_date('21-09-2025', 'dd-mm-yyyy'), '7', '21', '264', '09', '2025', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9397, to_date('22-09-2025', 'dd-mm-yyyy'), '1', '22', '265', '09', '2025', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8642, to_date('29-08-2023', 'dd-mm-yyyy'), '2', '29', '241', '08', '2023', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8643, to_date('30-08-2023', 'dd-mm-yyyy'), '3', '30', '242', '08', '2023', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8644, to_date('31-08-2023', 'dd-mm-yyyy'), '4', '31', '243', '08', '2023', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8645, to_date('01-09-2023', 'dd-mm-yyyy'), '5', '01', '244', '09', '2023', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8646, to_date('02-09-2023', 'dd-mm-yyyy'), '6', '02', '245', '09', '2023', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8647, to_date('03-09-2023', 'dd-mm-yyyy'), '7', '03', '246', '09', '2023', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8648, to_date('04-09-2023', 'dd-mm-yyyy'), '1', '04', '247', '09', '2023', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8649, to_date('05-09-2023', 'dd-mm-yyyy'), '2', '05', '248', '09', '2023', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8650, to_date('06-09-2023', 'dd-mm-yyyy'), '3', '06', '249', '09', '2023', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8651, to_date('07-09-2023', 'dd-mm-yyyy'), '4', '07', '250', '09', '2023', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8652, to_date('08-09-2023', 'dd-mm-yyyy'), '5', '08', '251', '09', '2023', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8653, to_date('09-09-2023', 'dd-mm-yyyy'), '6', '09', '252', '09', '2023', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8654, to_date('10-09-2023', 'dd-mm-yyyy'), '7', '10', '253', '09', '2023', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8655, to_date('11-09-2023', 'dd-mm-yyyy'), '1', '11', '254', '09', '2023', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8656, to_date('12-09-2023', 'dd-mm-yyyy'), '2', '12', '255', '09', '2023', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8657, to_date('13-09-2023', 'dd-mm-yyyy'), '3', '13', '256', '09', '2023', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8658, to_date('14-09-2023', 'dd-mm-yyyy'), '4', '14', '257', '09', '2023', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8659, to_date('15-09-2023', 'dd-mm-yyyy'), '5', '15', '258', '09', '2023', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8660, to_date('16-09-2023', 'dd-mm-yyyy'), '6', '16', '259', '09', '2023', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8661, to_date('17-09-2023', 'dd-mm-yyyy'), '7', '17', '260', '09', '2023', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8662, to_date('18-09-2023', 'dd-mm-yyyy'), '1', '18', '261', '09', '2023', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8663, to_date('19-09-2023', 'dd-mm-yyyy'), '2', '19', '262', '09', '2023', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8664, to_date('20-09-2023', 'dd-mm-yyyy'), '3', '20', '263', '09', '2023', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8665, to_date('21-09-2023', 'dd-mm-yyyy'), '4', '21', '264', '09', '2023', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8666, to_date('22-09-2023', 'dd-mm-yyyy'), '5', '22', '265', '09', '2023', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8667, to_date('23-09-2023', 'dd-mm-yyyy'), '6', '23', '266', '09', '2023', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8668, to_date('24-09-2023', 'dd-mm-yyyy'), '7', '24', '267', '09', '2023', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8669, to_date('25-09-2023', 'dd-mm-yyyy'), '1', '25', '268', '09', '2023', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8670, to_date('26-09-2023', 'dd-mm-yyyy'), '2', '26', '269', '09', '2023', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8671, to_date('27-09-2023', 'dd-mm-yyyy'), '3', '27', '270', '09', '2023', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8672, to_date('28-09-2023', 'dd-mm-yyyy'), '4', '28', '271', '09', '2023', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8673, to_date('29-09-2023', 'dd-mm-yyyy'), '5', '29', '272', '09', '2023', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8674, to_date('30-09-2023', 'dd-mm-yyyy'), '6', '30', '273', '09', '2023', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8675, to_date('01-10-2023', 'dd-mm-yyyy'), '7', '01', '274', '10', '2023', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8676, to_date('02-10-2023', 'dd-mm-yyyy'), '1', '02', '275', '10', '2023', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8677, to_date('03-10-2023', 'dd-mm-yyyy'), '2', '03', '276', '10', '2023', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8678, to_date('04-10-2023', 'dd-mm-yyyy'), '3', '04', '277', '10', '2023', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8679, to_date('05-10-2023', 'dd-mm-yyyy'), '4', '05', '278', '10', '2023', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8680, to_date('06-10-2023', 'dd-mm-yyyy'), '5', '06', '279', '10', '2023', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8681, to_date('07-10-2023', 'dd-mm-yyyy'), '6', '07', '280', '10', '2023', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8682, to_date('08-10-2023', 'dd-mm-yyyy'), '7', '08', '281', '10', '2023', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8683, to_date('09-10-2023', 'dd-mm-yyyy'), '1', '09', '282', '10', '2023', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8684, to_date('10-10-2023', 'dd-mm-yyyy'), '2', '10', '283', '10', '2023', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8685, to_date('11-10-2023', 'dd-mm-yyyy'), '3', '11', '284', '10', '2023', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8686, to_date('12-10-2023', 'dd-mm-yyyy'), '4', '12', '285', '10', '2023', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8687, to_date('13-10-2023', 'dd-mm-yyyy'), '5', '13', '286', '10', '2023', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8688, to_date('14-10-2023', 'dd-mm-yyyy'), '6', '14', '287', '10', '2023', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8689, to_date('15-10-2023', 'dd-mm-yyyy'), '7', '15', '288', '10', '2023', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8690, to_date('16-10-2023', 'dd-mm-yyyy'), '1', '16', '289', '10', '2023', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8691, to_date('17-10-2023', 'dd-mm-yyyy'), '2', '17', '290', '10', '2023', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8692, to_date('18-10-2023', 'dd-mm-yyyy'), '3', '18', '291', '10', '2023', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8693, to_date('19-10-2023', 'dd-mm-yyyy'), '4', '19', '292', '10', '2023', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8694, to_date('20-10-2023', 'dd-mm-yyyy'), '5', '20', '293', '10', '2023', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8695, to_date('21-10-2023', 'dd-mm-yyyy'), '6', '21', '294', '10', '2023', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8696, to_date('22-10-2023', 'dd-mm-yyyy'), '7', '22', '295', '10', '2023', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8697, to_date('23-10-2023', 'dd-mm-yyyy'), '1', '23', '296', '10', '2023', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8698, to_date('24-10-2023', 'dd-mm-yyyy'), '2', '24', '297', '10', '2023', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8699, to_date('25-10-2023', 'dd-mm-yyyy'), '3', '25', '298', '10', '2023', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8700, to_date('26-10-2023', 'dd-mm-yyyy'), '4', '26', '299', '10', '2023', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8701, to_date('27-10-2023', 'dd-mm-yyyy'), '5', '27', '300', '10', '2023', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8702, to_date('28-10-2023', 'dd-mm-yyyy'), '6', '28', '301', '10', '2023', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8703, to_date('29-10-2023', 'dd-mm-yyyy'), '7', '29', '302', '10', '2023', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8704, to_date('30-10-2023', 'dd-mm-yyyy'), '1', '30', '303', '10', '2023', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8705, to_date('31-10-2023', 'dd-mm-yyyy'), '2', '31', '304', '10', '2023', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8706, to_date('01-11-2023', 'dd-mm-yyyy'), '3', '01', '305', '11', '2023', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8707, to_date('02-11-2023', 'dd-mm-yyyy'), '4', '02', '306', '11', '2023', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8708, to_date('03-11-2023', 'dd-mm-yyyy'), '5', '03', '307', '11', '2023', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8709, to_date('04-11-2023', 'dd-mm-yyyy'), '6', '04', '308', '11', '2023', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8710, to_date('05-11-2023', 'dd-mm-yyyy'), '7', '05', '309', '11', '2023', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8711, to_date('06-11-2023', 'dd-mm-yyyy'), '1', '06', '310', '11', '2023', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8712, to_date('07-11-2023', 'dd-mm-yyyy'), '2', '07', '311', '11', '2023', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8713, to_date('08-11-2023', 'dd-mm-yyyy'), '3', '08', '312', '11', '2023', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8714, to_date('09-11-2023', 'dd-mm-yyyy'), '4', '09', '313', '11', '2023', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8715, to_date('10-11-2023', 'dd-mm-yyyy'), '5', '10', '314', '11', '2023', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8716, to_date('11-11-2023', 'dd-mm-yyyy'), '6', '11', '315', '11', '2023', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8717, to_date('12-11-2023', 'dd-mm-yyyy'), '7', '12', '316', '11', '2023', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8718, to_date('13-11-2023', 'dd-mm-yyyy'), '1', '13', '317', '11', '2023', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8719, to_date('14-11-2023', 'dd-mm-yyyy'), '2', '14', '318', '11', '2023', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8720, to_date('15-11-2023', 'dd-mm-yyyy'), '3', '15', '319', '11', '2023', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8721, to_date('16-11-2023', 'dd-mm-yyyy'), '4', '16', '320', '11', '2023', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8722, to_date('17-11-2023', 'dd-mm-yyyy'), '5', '17', '321', '11', '2023', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8723, to_date('18-11-2023', 'dd-mm-yyyy'), '6', '18', '322', '11', '2023', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8724, to_date('19-11-2023', 'dd-mm-yyyy'), '7', '19', '323', '11', '2023', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8725, to_date('20-11-2023', 'dd-mm-yyyy'), '1', '20', '324', '11', '2023', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8726, to_date('21-11-2023', 'dd-mm-yyyy'), '2', '21', '325', '11', '2023', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8727, to_date('22-11-2023', 'dd-mm-yyyy'), '3', '22', '326', '11', '2023', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8728, to_date('23-11-2023', 'dd-mm-yyyy'), '4', '23', '327', '11', '2023', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8729, to_date('24-11-2023', 'dd-mm-yyyy'), '5', '24', '328', '11', '2023', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8730, to_date('25-11-2023', 'dd-mm-yyyy'), '6', '25', '329', '11', '2023', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8731, to_date('26-11-2023', 'dd-mm-yyyy'), '7', '26', '330', '11', '2023', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8732, to_date('27-11-2023', 'dd-mm-yyyy'), '1', '27', '331', '11', '2023', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8733, to_date('28-11-2023', 'dd-mm-yyyy'), '2', '28', '332', '11', '2023', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8734, to_date('29-11-2023', 'dd-mm-yyyy'), '3', '29', '333', '11', '2023', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8735, to_date('30-11-2023', 'dd-mm-yyyy'), '4', '30', '334', '11', '2023', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8736, to_date('01-12-2023', 'dd-mm-yyyy'), '5', '01', '335', '12', '2023', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8737, to_date('02-12-2023', 'dd-mm-yyyy'), '6', '02', '336', '12', '2023', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8738, to_date('03-12-2023', 'dd-mm-yyyy'), '7', '03', '337', '12', '2023', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8739, to_date('04-12-2023', 'dd-mm-yyyy'), '1', '04', '338', '12', '2023', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8740, to_date('05-12-2023', 'dd-mm-yyyy'), '2', '05', '339', '12', '2023', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8741, to_date('06-12-2023', 'dd-mm-yyyy'), '3', '06', '340', '12', '2023', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8742, to_date('07-12-2023', 'dd-mm-yyyy'), '4', '07', '341', '12', '2023', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8743, to_date('08-12-2023', 'dd-mm-yyyy'), '5', '08', '342', '12', '2023', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8744, to_date('09-12-2023', 'dd-mm-yyyy'), '6', '09', '343', '12', '2023', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8745, to_date('10-12-2023', 'dd-mm-yyyy'), '7', '10', '344', '12', '2023', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8746, to_date('11-12-2023', 'dd-mm-yyyy'), '1', '11', '345', '12', '2023', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8747, to_date('12-12-2023', 'dd-mm-yyyy'), '2', '12', '346', '12', '2023', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8748, to_date('13-12-2023', 'dd-mm-yyyy'), '3', '13', '347', '12', '2023', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (8749, to_date('14-12-2023', 'dd-mm-yyyy'), '4', '14', '348', '12', '2023', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9506, to_date('09-01-2026', 'dd-mm-yyyy'), '5', '09', '009', '01', '2026', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9507, to_date('10-01-2026', 'dd-mm-yyyy'), '6', '10', '010', '01', '2026', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9508, to_date('11-01-2026', 'dd-mm-yyyy'), '7', '11', '011', '01', '2026', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9509, to_date('12-01-2026', 'dd-mm-yyyy'), '1', '12', '012', '01', '2026', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9510, to_date('13-01-2026', 'dd-mm-yyyy'), '2', '13', '013', '01', '2026', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9511, to_date('14-01-2026', 'dd-mm-yyyy'), '3', '14', '014', '01', '2026', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9512, to_date('15-01-2026', 'dd-mm-yyyy'), '4', '15', '015', '01', '2026', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9513, to_date('16-01-2026', 'dd-mm-yyyy'), '5', '16', '016', '01', '2026', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9514, to_date('17-01-2026', 'dd-mm-yyyy'), '6', '17', '017', '01', '2026', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9515, to_date('18-01-2026', 'dd-mm-yyyy'), '7', '18', '018', '01', '2026', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9516, to_date('19-01-2026', 'dd-mm-yyyy'), '1', '19', '019', '01', '2026', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9517, to_date('20-01-2026', 'dd-mm-yyyy'), '2', '20', '020', '01', '2026', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9518, to_date('21-01-2026', 'dd-mm-yyyy'), '3', '21', '021', '01', '2026', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9519, to_date('22-01-2026', 'dd-mm-yyyy'), '4', '22', '022', '01', '2026', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9520, to_date('23-01-2026', 'dd-mm-yyyy'), '5', '23', '023', '01', '2026', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9521, to_date('24-01-2026', 'dd-mm-yyyy'), '6', '24', '024', '01', '2026', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9522, to_date('25-01-2026', 'dd-mm-yyyy'), '7', '25', '025', '01', '2026', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9523, to_date('26-01-2026', 'dd-mm-yyyy'), '1', '26', '026', '01', '2026', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9524, to_date('27-01-2026', 'dd-mm-yyyy'), '2', '27', '027', '01', '2026', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9525, to_date('28-01-2026', 'dd-mm-yyyy'), '3', '28', '028', '01', '2026', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9526, to_date('29-01-2026', 'dd-mm-yyyy'), '4', '29', '029', '01', '2026', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9527, to_date('30-01-2026', 'dd-mm-yyyy'), '5', '30', '030', '01', '2026', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9528, to_date('31-01-2026', 'dd-mm-yyyy'), '6', '31', '031', '01', '2026', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9529, to_date('01-02-2026', 'dd-mm-yyyy'), '7', '01', '032', '02', '2026', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9530, to_date('02-02-2026', 'dd-mm-yyyy'), '1', '02', '033', '02', '2026', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9531, to_date('03-02-2026', 'dd-mm-yyyy'), '2', '03', '034', '02', '2026', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9532, to_date('04-02-2026', 'dd-mm-yyyy'), '3', '04', '035', '02', '2026', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9533, to_date('05-02-2026', 'dd-mm-yyyy'), '4', '05', '036', '02', '2026', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9534, to_date('06-02-2026', 'dd-mm-yyyy'), '5', '06', '037', '02', '2026', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9535, to_date('07-02-2026', 'dd-mm-yyyy'), '6', '07', '038', '02', '2026', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9536, to_date('08-02-2026', 'dd-mm-yyyy'), '7', '08', '039', '02', '2026', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9537, to_date('09-02-2026', 'dd-mm-yyyy'), '1', '09', '040', '02', '2026', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9538, to_date('10-02-2026', 'dd-mm-yyyy'), '2', '10', '041', '02', '2026', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9539, to_date('11-02-2026', 'dd-mm-yyyy'), '3', '11', '042', '02', '2026', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9540, to_date('12-02-2026', 'dd-mm-yyyy'), '4', '12', '043', '02', '2026', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9541, to_date('13-02-2026', 'dd-mm-yyyy'), '5', '13', '044', '02', '2026', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9542, to_date('14-02-2026', 'dd-mm-yyyy'), '6', '14', '045', '02', '2026', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9543, to_date('15-02-2026', 'dd-mm-yyyy'), '7', '15', '046', '02', '2026', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9544, to_date('16-02-2026', 'dd-mm-yyyy'), '1', '16', '047', '02', '2026', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9545, to_date('17-02-2026', 'dd-mm-yyyy'), '2', '17', '048', '02', '2026', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9546, to_date('18-02-2026', 'dd-mm-yyyy'), '3', '18', '049', '02', '2026', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9547, to_date('19-02-2026', 'dd-mm-yyyy'), '4', '19', '050', '02', '2026', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9548, to_date('20-02-2026', 'dd-mm-yyyy'), '5', '20', '051', '02', '2026', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9549, to_date('21-02-2026', 'dd-mm-yyyy'), '6', '21', '052', '02', '2026', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9550, to_date('22-02-2026', 'dd-mm-yyyy'), '7', '22', '053', '02', '2026', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9551, to_date('23-02-2026', 'dd-mm-yyyy'), '1', '23', '054', '02', '2026', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9552, to_date('24-02-2026', 'dd-mm-yyyy'), '2', '24', '055', '02', '2026', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9553, to_date('25-02-2026', 'dd-mm-yyyy'), '3', '25', '056', '02', '2026', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9554, to_date('26-02-2026', 'dd-mm-yyyy'), '4', '26', '057', '02', '2026', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9555, to_date('27-02-2026', 'dd-mm-yyyy'), '5', '27', '058', '02', '2026', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9556, to_date('28-02-2026', 'dd-mm-yyyy'), '6', '28', '059', '02', '2026', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9557, to_date('01-03-2026', 'dd-mm-yyyy'), '7', '01', '060', '03', '2026', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9558, to_date('02-03-2026', 'dd-mm-yyyy'), '1', '02', '061', '03', '2026', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9559, to_date('03-03-2026', 'dd-mm-yyyy'), '2', '03', '062', '03', '2026', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9560, to_date('04-03-2026', 'dd-mm-yyyy'), '3', '04', '063', '03', '2026', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9561, to_date('05-03-2026', 'dd-mm-yyyy'), '4', '05', '064', '03', '2026', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9562, to_date('06-03-2026', 'dd-mm-yyyy'), '5', '06', '065', '03', '2026', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9563, to_date('07-03-2026', 'dd-mm-yyyy'), '6', '07', '066', '03', '2026', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9564, to_date('08-03-2026', 'dd-mm-yyyy'), '7', '08', '067', '03', '2026', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9565, to_date('09-03-2026', 'dd-mm-yyyy'), '1', '09', '068', '03', '2026', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9566, to_date('10-03-2026', 'dd-mm-yyyy'), '2', '10', '069', '03', '2026', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9567, to_date('11-03-2026', 'dd-mm-yyyy'), '3', '11', '070', '03', '2026', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9568, to_date('12-03-2026', 'dd-mm-yyyy'), '4', '12', '071', '03', '2026', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9569, to_date('13-03-2026', 'dd-mm-yyyy'), '5', '13', '072', '03', '2026', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9570, to_date('14-03-2026', 'dd-mm-yyyy'), '6', '14', '073', '03', '2026', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9571, to_date('15-03-2026', 'dd-mm-yyyy'), '7', '15', '074', '03', '2026', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9572, to_date('16-03-2026', 'dd-mm-yyyy'), '1', '16', '075', '03', '2026', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9573, to_date('17-03-2026', 'dd-mm-yyyy'), '2', '17', '076', '03', '2026', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9574, to_date('18-03-2026', 'dd-mm-yyyy'), '3', '18', '077', '03', '2026', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9575, to_date('19-03-2026', 'dd-mm-yyyy'), '4', '19', '078', '03', '2026', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9576, to_date('20-03-2026', 'dd-mm-yyyy'), '5', '20', '079', '03', '2026', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9577, to_date('21-03-2026', 'dd-mm-yyyy'), '6', '21', '080', '03', '2026', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9578, to_date('22-03-2026', 'dd-mm-yyyy'), '7', '22', '081', '03', '2026', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9579, to_date('23-03-2026', 'dd-mm-yyyy'), '1', '23', '082', '03', '2026', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9580, to_date('24-03-2026', 'dd-mm-yyyy'), '2', '24', '083', '03', '2026', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9581, to_date('25-03-2026', 'dd-mm-yyyy'), '3', '25', '084', '03', '2026', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9582, to_date('26-03-2026', 'dd-mm-yyyy'), '4', '26', '085', '03', '2026', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9583, to_date('27-03-2026', 'dd-mm-yyyy'), '5', '27', '086', '03', '2026', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9584, to_date('28-03-2026', 'dd-mm-yyyy'), '6', '28', '087', '03', '2026', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9585, to_date('29-03-2026', 'dd-mm-yyyy'), '7', '29', '088', '03', '2026', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9586, to_date('30-03-2026', 'dd-mm-yyyy'), '1', '30', '089', '03', '2026', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9587, to_date('31-03-2026', 'dd-mm-yyyy'), '2', '31', '090', '03', '2026', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9588, to_date('01-04-2026', 'dd-mm-yyyy'), '3', '01', '091', '04', '2026', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9589, to_date('02-04-2026', 'dd-mm-yyyy'), '4', '02', '092', '04', '2026', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9590, to_date('03-04-2026', 'dd-mm-yyyy'), '5', '03', '093', '04', '2026', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9591, to_date('04-04-2026', 'dd-mm-yyyy'), '6', '04', '094', '04', '2026', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9592, to_date('05-04-2026', 'dd-mm-yyyy'), '7', '05', '095', '04', '2026', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9593, to_date('06-04-2026', 'dd-mm-yyyy'), '1', '06', '096', '04', '2026', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9594, to_date('07-04-2026', 'dd-mm-yyyy'), '2', '07', '097', '04', '2026', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9595, to_date('08-04-2026', 'dd-mm-yyyy'), '3', '08', '098', '04', '2026', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9596, to_date('09-04-2026', 'dd-mm-yyyy'), '4', '09', '099', '04', '2026', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9597, to_date('10-04-2026', 'dd-mm-yyyy'), '5', '10', '100', '04', '2026', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9598, to_date('11-04-2026', 'dd-mm-yyyy'), '6', '11', '101', '04', '2026', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9599, to_date('12-04-2026', 'dd-mm-yyyy'), '7', '12', '102', '04', '2026', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9600, to_date('13-04-2026', 'dd-mm-yyyy'), '1', '13', '103', '04', '2026', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9601, to_date('14-04-2026', 'dd-mm-yyyy'), '2', '14', '104', '04', '2026', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9602, to_date('15-04-2026', 'dd-mm-yyyy'), '3', '15', '105', '04', '2026', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9603, to_date('16-04-2026', 'dd-mm-yyyy'), '4', '16', '106', '04', '2026', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9604, to_date('17-04-2026', 'dd-mm-yyyy'), '5', '17', '107', '04', '2026', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9605, to_date('18-04-2026', 'dd-mm-yyyy'), '6', '18', '108', '04', '2026', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9606, to_date('19-04-2026', 'dd-mm-yyyy'), '7', '19', '109', '04', '2026', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9607, to_date('20-04-2026', 'dd-mm-yyyy'), '1', '20', '110', '04', '2026', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9608, to_date('21-04-2026', 'dd-mm-yyyy'), '2', '21', '111', '04', '2026', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9609, to_date('22-04-2026', 'dd-mm-yyyy'), '3', '22', '112', '04', '2026', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9610, to_date('23-04-2026', 'dd-mm-yyyy'), '4', '23', '113', '04', '2026', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9611, to_date('24-04-2026', 'dd-mm-yyyy'), '5', '24', '114', '04', '2026', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9612, to_date('25-04-2026', 'dd-mm-yyyy'), '6', '25', '115', '04', '2026', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9613, to_date('26-04-2026', 'dd-mm-yyyy'), '7', '26', '116', '04', '2026', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10151, to_date('16-10-2027', 'dd-mm-yyyy'), '6', '16', '289', '10', '2027', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10152, to_date('17-10-2027', 'dd-mm-yyyy'), '7', '17', '290', '10', '2027', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10153, to_date('18-10-2027', 'dd-mm-yyyy'), '1', '18', '291', '10', '2027', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10154, to_date('19-10-2027', 'dd-mm-yyyy'), '2', '19', '292', '10', '2027', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10155, to_date('20-10-2027', 'dd-mm-yyyy'), '3', '20', '293', '10', '2027', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10156, to_date('21-10-2027', 'dd-mm-yyyy'), '4', '21', '294', '10', '2027', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10157, to_date('22-10-2027', 'dd-mm-yyyy'), '5', '22', '295', '10', '2027', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10158, to_date('23-10-2027', 'dd-mm-yyyy'), '6', '23', '296', '10', '2027', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10159, to_date('24-10-2027', 'dd-mm-yyyy'), '7', '24', '297', '10', '2027', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10160, to_date('25-10-2027', 'dd-mm-yyyy'), '1', '25', '298', '10', '2027', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10161, to_date('26-10-2027', 'dd-mm-yyyy'), '2', '26', '299', '10', '2027', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10162, to_date('27-10-2027', 'dd-mm-yyyy'), '3', '27', '300', '10', '2027', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10163, to_date('28-10-2027', 'dd-mm-yyyy'), '4', '28', '301', '10', '2027', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10164, to_date('29-10-2027', 'dd-mm-yyyy'), '5', '29', '302', '10', '2027', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10165, to_date('30-10-2027', 'dd-mm-yyyy'), '6', '30', '303', '10', '2027', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10166, to_date('31-10-2027', 'dd-mm-yyyy'), '7', '31', '304', '10', '2027', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10167, to_date('01-11-2027', 'dd-mm-yyyy'), '1', '01', '305', '11', '2027', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10168, to_date('02-11-2027', 'dd-mm-yyyy'), '2', '02', '306', '11', '2027', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10169, to_date('03-11-2027', 'dd-mm-yyyy'), '3', '03', '307', '11', '2027', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10170, to_date('04-11-2027', 'dd-mm-yyyy'), '4', '04', '308', '11', '2027', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10171, to_date('05-11-2027', 'dd-mm-yyyy'), '5', '05', '309', '11', '2027', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10172, to_date('06-11-2027', 'dd-mm-yyyy'), '6', '06', '310', '11', '2027', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10173, to_date('07-11-2027', 'dd-mm-yyyy'), '7', '07', '311', '11', '2027', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10174, to_date('08-11-2027', 'dd-mm-yyyy'), '1', '08', '312', '11', '2027', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10175, to_date('09-11-2027', 'dd-mm-yyyy'), '2', '09', '313', '11', '2027', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10176, to_date('10-11-2027', 'dd-mm-yyyy'), '3', '10', '314', '11', '2027', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10177, to_date('11-11-2027', 'dd-mm-yyyy'), '4', '11', '315', '11', '2027', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10178, to_date('12-11-2027', 'dd-mm-yyyy'), '5', '12', '316', '11', '2027', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10179, to_date('13-11-2027', 'dd-mm-yyyy'), '6', '13', '317', '11', '2027', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10180, to_date('14-11-2027', 'dd-mm-yyyy'), '7', '14', '318', '11', '2027', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10181, to_date('15-11-2027', 'dd-mm-yyyy'), '1', '15', '319', '11', '2027', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10182, to_date('16-11-2027', 'dd-mm-yyyy'), '2', '16', '320', '11', '2027', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10183, to_date('17-11-2027', 'dd-mm-yyyy'), '3', '17', '321', '11', '2027', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10184, to_date('18-11-2027', 'dd-mm-yyyy'), '4', '18', '322', '11', '2027', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10185, to_date('19-11-2027', 'dd-mm-yyyy'), '5', '19', '323', '11', '2027', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10186, to_date('20-11-2027', 'dd-mm-yyyy'), '6', '20', '324', '11', '2027', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10187, to_date('21-11-2027', 'dd-mm-yyyy'), '7', '21', '325', '11', '2027', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10188, to_date('22-11-2027', 'dd-mm-yyyy'), '1', '22', '326', '11', '2027', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10189, to_date('23-11-2027', 'dd-mm-yyyy'), '2', '23', '327', '11', '2027', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10190, to_date('24-11-2027', 'dd-mm-yyyy'), '3', '24', '328', '11', '2027', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10191, to_date('25-11-2027', 'dd-mm-yyyy'), '4', '25', '329', '11', '2027', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10192, to_date('26-11-2027', 'dd-mm-yyyy'), '5', '26', '330', '11', '2027', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10193, to_date('27-11-2027', 'dd-mm-yyyy'), '6', '27', '331', '11', '2027', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10194, to_date('28-11-2027', 'dd-mm-yyyy'), '7', '28', '332', '11', '2027', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10195, to_date('29-11-2027', 'dd-mm-yyyy'), '1', '29', '333', '11', '2027', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10196, to_date('30-11-2027', 'dd-mm-yyyy'), '2', '30', '334', '11', '2027', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10197, to_date('01-12-2027', 'dd-mm-yyyy'), '3', '01', '335', '12', '2027', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10198, to_date('02-12-2027', 'dd-mm-yyyy'), '4', '02', '336', '12', '2027', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10199, to_date('03-12-2027', 'dd-mm-yyyy'), '5', '03', '337', '12', '2027', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10200, to_date('04-12-2027', 'dd-mm-yyyy'), '6', '04', '338', '12', '2027', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10201, to_date('05-12-2027', 'dd-mm-yyyy'), '7', '05', '339', '12', '2027', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10202, to_date('06-12-2027', 'dd-mm-yyyy'), '1', '06', '340', '12', '2027', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10203, to_date('07-12-2027', 'dd-mm-yyyy'), '2', '07', '341', '12', '2027', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10204, to_date('08-12-2027', 'dd-mm-yyyy'), '3', '08', '342', '12', '2027', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10205, to_date('09-12-2027', 'dd-mm-yyyy'), '4', '09', '343', '12', '2027', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10206, to_date('10-12-2027', 'dd-mm-yyyy'), '5', '10', '344', '12', '2027', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10207, to_date('11-12-2027', 'dd-mm-yyyy'), '6', '11', '345', '12', '2027', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10208, to_date('12-12-2027', 'dd-mm-yyyy'), '7', '12', '346', '12', '2027', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10209, to_date('13-12-2027', 'dd-mm-yyyy'), '1', '13', '347', '12', '2027', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10210, to_date('14-12-2027', 'dd-mm-yyyy'), '2', '14', '348', '12', '2027', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10211, to_date('15-12-2027', 'dd-mm-yyyy'), '3', '15', '349', '12', '2027', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10212, to_date('16-12-2027', 'dd-mm-yyyy'), '4', '16', '350', '12', '2027', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10213, to_date('17-12-2027', 'dd-mm-yyyy'), '5', '17', '351', '12', '2027', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10214, to_date('18-12-2027', 'dd-mm-yyyy'), '6', '18', '352', '12', '2027', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10215, to_date('19-12-2027', 'dd-mm-yyyy'), '7', '19', '353', '12', '2027', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10216, to_date('20-12-2027', 'dd-mm-yyyy'), '1', '20', '354', '12', '2027', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10217, to_date('21-12-2027', 'dd-mm-yyyy'), '2', '21', '355', '12', '2027', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10218, to_date('22-12-2027', 'dd-mm-yyyy'), '3', '22', '356', '12', '2027', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10219, to_date('23-12-2027', 'dd-mm-yyyy'), '4', '23', '357', '12', '2027', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10220, to_date('24-12-2027', 'dd-mm-yyyy'), '5', '24', '358', '12', '2027', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10221, to_date('25-12-2027', 'dd-mm-yyyy'), '6', '25', '359', '12', '2027', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10222, to_date('26-12-2027', 'dd-mm-yyyy'), '7', '26', '360', '12', '2027', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10223, to_date('27-12-2027', 'dd-mm-yyyy'), '1', '27', '361', '12', '2027', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10224, to_date('28-12-2027', 'dd-mm-yyyy'), '2', '28', '362', '12', '2027', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10225, to_date('29-12-2027', 'dd-mm-yyyy'), '3', '29', '363', '12', '2027', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10226, to_date('30-12-2027', 'dd-mm-yyyy'), '4', '30', '364', '12', '2027', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10227, to_date('31-12-2027', 'dd-mm-yyyy'), '5', '31', '365', '12', '2027', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10228, to_date('01-01-2028', 'dd-mm-yyyy'), '6', '01', '001', '01', '2028', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10229, to_date('02-01-2028', 'dd-mm-yyyy'), '7', '02', '002', '01', '2028', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10230, to_date('03-01-2028', 'dd-mm-yyyy'), '1', '03', '003', '01', '2028', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10231, to_date('04-01-2028', 'dd-mm-yyyy'), '2', '04', '004', '01', '2028', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10232, to_date('05-01-2028', 'dd-mm-yyyy'), '3', '05', '005', '01', '2028', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10233, to_date('06-01-2028', 'dd-mm-yyyy'), '4', '06', '006', '01', '2028', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10234, to_date('07-01-2028', 'dd-mm-yyyy'), '5', '07', '007', '01', '2028', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10235, to_date('08-01-2028', 'dd-mm-yyyy'), '6', '08', '008', '01', '2028', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10236, to_date('09-01-2028', 'dd-mm-yyyy'), '7', '09', '009', '01', '2028', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10237, to_date('10-01-2028', 'dd-mm-yyyy'), '1', '10', '010', '01', '2028', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10238, to_date('11-01-2028', 'dd-mm-yyyy'), '2', '11', '011', '01', '2028', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10239, to_date('12-01-2028', 'dd-mm-yyyy'), '3', '12', '012', '01', '2028', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10240, to_date('13-01-2028', 'dd-mm-yyyy'), '4', '13', '013', '01', '2028', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10241, to_date('14-01-2028', 'dd-mm-yyyy'), '5', '14', '014', '01', '2028', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10242, to_date('15-01-2028', 'dd-mm-yyyy'), '6', '15', '015', '01', '2028', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10243, to_date('16-01-2028', 'dd-mm-yyyy'), '7', '16', '016', '01', '2028', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10244, to_date('17-01-2028', 'dd-mm-yyyy'), '1', '17', '017', '01', '2028', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10245, to_date('18-01-2028', 'dd-mm-yyyy'), '2', '18', '018', '01', '2028', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10246, to_date('19-01-2028', 'dd-mm-yyyy'), '3', '19', '019', '01', '2028', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10247, to_date('20-01-2028', 'dd-mm-yyyy'), '4', '20', '020', '01', '2028', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10248, to_date('21-01-2028', 'dd-mm-yyyy'), '5', '21', '021', '01', '2028', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10249, to_date('22-01-2028', 'dd-mm-yyyy'), '6', '22', '022', '01', '2028', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10250, to_date('23-01-2028', 'dd-mm-yyyy'), '7', '23', '023', '01', '2028', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10251, to_date('24-01-2028', 'dd-mm-yyyy'), '1', '24', '024', '01', '2028', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10252, to_date('25-01-2028', 'dd-mm-yyyy'), '2', '25', '025', '01', '2028', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10253, to_date('26-01-2028', 'dd-mm-yyyy'), '3', '26', '026', '01', '2028', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10254, to_date('27-01-2028', 'dd-mm-yyyy'), '4', '27', '027', '01', '2028', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10255, to_date('28-01-2028', 'dd-mm-yyyy'), '5', '28', '028', '01', '2028', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10256, to_date('29-01-2028', 'dd-mm-yyyy'), '6', '29', '029', '01', '2028', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9614, to_date('27-04-2026', 'dd-mm-yyyy'), '1', '27', '117', '04', '2026', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9615, to_date('28-04-2026', 'dd-mm-yyyy'), '2', '28', '118', '04', '2026', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9616, to_date('29-04-2026', 'dd-mm-yyyy'), '3', '29', '119', '04', '2026', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9617, to_date('30-04-2026', 'dd-mm-yyyy'), '4', '30', '120', '04', '2026', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9618, to_date('01-05-2026', 'dd-mm-yyyy'), '5', '01', '121', '05', '2026', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9619, to_date('02-05-2026', 'dd-mm-yyyy'), '6', '02', '122', '05', '2026', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9620, to_date('03-05-2026', 'dd-mm-yyyy'), '7', '03', '123', '05', '2026', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9621, to_date('04-05-2026', 'dd-mm-yyyy'), '1', '04', '124', '05', '2026', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9622, to_date('05-05-2026', 'dd-mm-yyyy'), '2', '05', '125', '05', '2026', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9623, to_date('06-05-2026', 'dd-mm-yyyy'), '3', '06', '126', '05', '2026', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9624, to_date('07-05-2026', 'dd-mm-yyyy'), '4', '07', '127', '05', '2026', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9625, to_date('08-05-2026', 'dd-mm-yyyy'), '5', '08', '128', '05', '2026', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9626, to_date('09-05-2026', 'dd-mm-yyyy'), '6', '09', '129', '05', '2026', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9627, to_date('10-05-2026', 'dd-mm-yyyy'), '7', '10', '130', '05', '2026', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9628, to_date('11-05-2026', 'dd-mm-yyyy'), '1', '11', '131', '05', '2026', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9629, to_date('12-05-2026', 'dd-mm-yyyy'), '2', '12', '132', '05', '2026', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9630, to_date('13-05-2026', 'dd-mm-yyyy'), '3', '13', '133', '05', '2026', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9631, to_date('14-05-2026', 'dd-mm-yyyy'), '4', '14', '134', '05', '2026', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9632, to_date('15-05-2026', 'dd-mm-yyyy'), '5', '15', '135', '05', '2026', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9633, to_date('16-05-2026', 'dd-mm-yyyy'), '6', '16', '136', '05', '2026', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9634, to_date('17-05-2026', 'dd-mm-yyyy'), '7', '17', '137', '05', '2026', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9635, to_date('18-05-2026', 'dd-mm-yyyy'), '1', '18', '138', '05', '2026', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9636, to_date('19-05-2026', 'dd-mm-yyyy'), '2', '19', '139', '05', '2026', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9637, to_date('20-05-2026', 'dd-mm-yyyy'), '3', '20', '140', '05', '2026', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9638, to_date('21-05-2026', 'dd-mm-yyyy'), '4', '21', '141', '05', '2026', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9639, to_date('22-05-2026', 'dd-mm-yyyy'), '5', '22', '142', '05', '2026', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9640, to_date('23-05-2026', 'dd-mm-yyyy'), '6', '23', '143', '05', '2026', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9641, to_date('24-05-2026', 'dd-mm-yyyy'), '7', '24', '144', '05', '2026', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9642, to_date('25-05-2026', 'dd-mm-yyyy'), '1', '25', '145', '05', '2026', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9643, to_date('26-05-2026', 'dd-mm-yyyy'), '2', '26', '146', '05', '2026', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9644, to_date('27-05-2026', 'dd-mm-yyyy'), '3', '27', '147', '05', '2026', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9645, to_date('28-05-2026', 'dd-mm-yyyy'), '4', '28', '148', '05', '2026', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9646, to_date('29-05-2026', 'dd-mm-yyyy'), '5', '29', '149', '05', '2026', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9647, to_date('30-05-2026', 'dd-mm-yyyy'), '6', '30', '150', '05', '2026', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9648, to_date('31-05-2026', 'dd-mm-yyyy'), '7', '31', '151', '05', '2026', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9649, to_date('01-06-2026', 'dd-mm-yyyy'), '1', '01', '152', '06', '2026', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9650, to_date('02-06-2026', 'dd-mm-yyyy'), '2', '02', '153', '06', '2026', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9651, to_date('03-06-2026', 'dd-mm-yyyy'), '3', '03', '154', '06', '2026', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9652, to_date('04-06-2026', 'dd-mm-yyyy'), '4', '04', '155', '06', '2026', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9653, to_date('05-06-2026', 'dd-mm-yyyy'), '5', '05', '156', '06', '2026', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9654, to_date('06-06-2026', 'dd-mm-yyyy'), '6', '06', '157', '06', '2026', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9655, to_date('07-06-2026', 'dd-mm-yyyy'), '7', '07', '158', '06', '2026', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9656, to_date('08-06-2026', 'dd-mm-yyyy'), '1', '08', '159', '06', '2026', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9657, to_date('09-06-2026', 'dd-mm-yyyy'), '2', '09', '160', '06', '2026', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9658, to_date('10-06-2026', 'dd-mm-yyyy'), '3', '10', '161', '06', '2026', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9659, to_date('11-06-2026', 'dd-mm-yyyy'), '4', '11', '162', '06', '2026', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9660, to_date('12-06-2026', 'dd-mm-yyyy'), '5', '12', '163', '06', '2026', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9661, to_date('13-06-2026', 'dd-mm-yyyy'), '6', '13', '164', '06', '2026', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9662, to_date('14-06-2026', 'dd-mm-yyyy'), '7', '14', '165', '06', '2026', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9663, to_date('15-06-2026', 'dd-mm-yyyy'), '1', '15', '166', '06', '2026', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9664, to_date('16-06-2026', 'dd-mm-yyyy'), '2', '16', '167', '06', '2026', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9665, to_date('17-06-2026', 'dd-mm-yyyy'), '3', '17', '168', '06', '2026', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9666, to_date('18-06-2026', 'dd-mm-yyyy'), '4', '18', '169', '06', '2026', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9667, to_date('19-06-2026', 'dd-mm-yyyy'), '5', '19', '170', '06', '2026', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9668, to_date('20-06-2026', 'dd-mm-yyyy'), '6', '20', '171', '06', '2026', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9669, to_date('21-06-2026', 'dd-mm-yyyy'), '7', '21', '172', '06', '2026', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9670, to_date('22-06-2026', 'dd-mm-yyyy'), '1', '22', '173', '06', '2026', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9671, to_date('23-06-2026', 'dd-mm-yyyy'), '2', '23', '174', '06', '2026', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9672, to_date('24-06-2026', 'dd-mm-yyyy'), '3', '24', '175', '06', '2026', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9673, to_date('25-06-2026', 'dd-mm-yyyy'), '4', '25', '176', '06', '2026', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9674, to_date('26-06-2026', 'dd-mm-yyyy'), '5', '26', '177', '06', '2026', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9675, to_date('27-06-2026', 'dd-mm-yyyy'), '6', '27', '178', '06', '2026', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9676, to_date('28-06-2026', 'dd-mm-yyyy'), '7', '28', '179', '06', '2026', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9677, to_date('29-06-2026', 'dd-mm-yyyy'), '1', '29', '180', '06', '2026', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9678, to_date('30-06-2026', 'dd-mm-yyyy'), '2', '30', '181', '06', '2026', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9679, to_date('01-07-2026', 'dd-mm-yyyy'), '3', '01', '182', '07', '2026', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9680, to_date('02-07-2026', 'dd-mm-yyyy'), '4', '02', '183', '07', '2026', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9681, to_date('03-07-2026', 'dd-mm-yyyy'), '5', '03', '184', '07', '2026', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9682, to_date('04-07-2026', 'dd-mm-yyyy'), '6', '04', '185', '07', '2026', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9683, to_date('05-07-2026', 'dd-mm-yyyy'), '7', '05', '186', '07', '2026', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9684, to_date('06-07-2026', 'dd-mm-yyyy'), '1', '06', '187', '07', '2026', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9685, to_date('07-07-2026', 'dd-mm-yyyy'), '2', '07', '188', '07', '2026', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9686, to_date('08-07-2026', 'dd-mm-yyyy'), '3', '08', '189', '07', '2026', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9687, to_date('09-07-2026', 'dd-mm-yyyy'), '4', '09', '190', '07', '2026', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9688, to_date('10-07-2026', 'dd-mm-yyyy'), '5', '10', '191', '07', '2026', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9689, to_date('11-07-2026', 'dd-mm-yyyy'), '6', '11', '192', '07', '2026', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9690, to_date('12-07-2026', 'dd-mm-yyyy'), '7', '12', '193', '07', '2026', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9691, to_date('13-07-2026', 'dd-mm-yyyy'), '1', '13', '194', '07', '2026', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9692, to_date('14-07-2026', 'dd-mm-yyyy'), '2', '14', '195', '07', '2026', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9693, to_date('15-07-2026', 'dd-mm-yyyy'), '3', '15', '196', '07', '2026', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9694, to_date('16-07-2026', 'dd-mm-yyyy'), '4', '16', '197', '07', '2026', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9695, to_date('17-07-2026', 'dd-mm-yyyy'), '5', '17', '198', '07', '2026', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9696, to_date('18-07-2026', 'dd-mm-yyyy'), '6', '18', '199', '07', '2026', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9697, to_date('19-07-2026', 'dd-mm-yyyy'), '7', '19', '200', '07', '2026', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9698, to_date('20-07-2026', 'dd-mm-yyyy'), '1', '20', '201', '07', '2026', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9699, to_date('21-07-2026', 'dd-mm-yyyy'), '2', '21', '202', '07', '2026', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9700, to_date('22-07-2026', 'dd-mm-yyyy'), '3', '22', '203', '07', '2026', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9701, to_date('23-07-2026', 'dd-mm-yyyy'), '4', '23', '204', '07', '2026', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9702, to_date('24-07-2026', 'dd-mm-yyyy'), '5', '24', '205', '07', '2026', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9703, to_date('25-07-2026', 'dd-mm-yyyy'), '6', '25', '206', '07', '2026', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9704, to_date('26-07-2026', 'dd-mm-yyyy'), '7', '26', '207', '07', '2026', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9705, to_date('27-07-2026', 'dd-mm-yyyy'), '1', '27', '208', '07', '2026', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9706, to_date('28-07-2026', 'dd-mm-yyyy'), '2', '28', '209', '07', '2026', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9707, to_date('29-07-2026', 'dd-mm-yyyy'), '3', '29', '210', '07', '2026', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9708, to_date('30-07-2026', 'dd-mm-yyyy'), '4', '30', '211', '07', '2026', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9709, to_date('31-07-2026', 'dd-mm-yyyy'), '5', '31', '212', '07', '2026', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9710, to_date('01-08-2026', 'dd-mm-yyyy'), '6', '01', '213', '08', '2026', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9711, to_date('02-08-2026', 'dd-mm-yyyy'), '7', '02', '214', '08', '2026', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9712, to_date('03-08-2026', 'dd-mm-yyyy'), '1', '03', '215', '08', '2026', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9713, to_date('04-08-2026', 'dd-mm-yyyy'), '2', '04', '216', '08', '2026', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9714, to_date('05-08-2026', 'dd-mm-yyyy'), '3', '05', '217', '08', '2026', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9715, to_date('06-08-2026', 'dd-mm-yyyy'), '4', '06', '218', '08', '2026', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9716, to_date('07-08-2026', 'dd-mm-yyyy'), '5', '07', '219', '08', '2026', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9717, to_date('08-08-2026', 'dd-mm-yyyy'), '6', '08', '220', '08', '2026', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9718, to_date('09-08-2026', 'dd-mm-yyyy'), '7', '09', '221', '08', '2026', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9719, to_date('10-08-2026', 'dd-mm-yyyy'), '1', '10', '222', '08', '2026', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9720, to_date('11-08-2026', 'dd-mm-yyyy'), '2', '11', '223', '08', '2026', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9721, to_date('12-08-2026', 'dd-mm-yyyy'), '3', '12', '224', '08', '2026', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9722, to_date('13-08-2026', 'dd-mm-yyyy'), '4', '13', '225', '08', '2026', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9723, to_date('14-08-2026', 'dd-mm-yyyy'), '5', '14', '226', '08', '2026', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9724, to_date('15-08-2026', 'dd-mm-yyyy'), '6', '15', '227', '08', '2026', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9725, to_date('16-08-2026', 'dd-mm-yyyy'), '7', '16', '228', '08', '2026', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9726, to_date('17-08-2026', 'dd-mm-yyyy'), '1', '17', '229', '08', '2026', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9727, to_date('18-08-2026', 'dd-mm-yyyy'), '2', '18', '230', '08', '2026', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9728, to_date('19-08-2026', 'dd-mm-yyyy'), '3', '19', '231', '08', '2026', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9729, to_date('20-08-2026', 'dd-mm-yyyy'), '4', '20', '232', '08', '2026', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9730, to_date('21-08-2026', 'dd-mm-yyyy'), '5', '21', '233', '08', '2026', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9731, to_date('22-08-2026', 'dd-mm-yyyy'), '6', '22', '234', '08', '2026', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9732, to_date('23-08-2026', 'dd-mm-yyyy'), '7', '23', '235', '08', '2026', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9733, to_date('24-08-2026', 'dd-mm-yyyy'), '1', '24', '236', '08', '2026', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9734, to_date('25-08-2026', 'dd-mm-yyyy'), '2', '25', '237', '08', '2026', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9735, to_date('26-08-2026', 'dd-mm-yyyy'), '3', '26', '238', '08', '2026', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9736, to_date('27-08-2026', 'dd-mm-yyyy'), '4', '27', '239', '08', '2026', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9737, to_date('28-08-2026', 'dd-mm-yyyy'), '5', '28', '240', '08', '2026', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9738, to_date('29-08-2026', 'dd-mm-yyyy'), '6', '29', '241', '08', '2026', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9739, to_date('30-08-2026', 'dd-mm-yyyy'), '7', '30', '242', '08', '2026', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9740, to_date('31-08-2026', 'dd-mm-yyyy'), '1', '31', '243', '08', '2026', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9741, to_date('01-09-2026', 'dd-mm-yyyy'), '2', '01', '244', '09', '2026', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9742, to_date('02-09-2026', 'dd-mm-yyyy'), '3', '02', '245', '09', '2026', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9743, to_date('03-09-2026', 'dd-mm-yyyy'), '4', '03', '246', '09', '2026', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9744, to_date('04-09-2026', 'dd-mm-yyyy'), '5', '04', '247', '09', '2026', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9745, to_date('05-09-2026', 'dd-mm-yyyy'), '6', '05', '248', '09', '2026', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9746, to_date('06-09-2026', 'dd-mm-yyyy'), '7', '06', '249', '09', '2026', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9747, to_date('07-09-2026', 'dd-mm-yyyy'), '1', '07', '250', '09', '2026', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9748, to_date('08-09-2026', 'dd-mm-yyyy'), '2', '08', '251', '09', '2026', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9749, to_date('09-09-2026', 'dd-mm-yyyy'), '3', '09', '252', '09', '2026', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9750, to_date('10-09-2026', 'dd-mm-yyyy'), '4', '10', '253', '09', '2026', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9751, to_date('11-09-2026', 'dd-mm-yyyy'), '5', '11', '254', '09', '2026', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9752, to_date('12-09-2026', 'dd-mm-yyyy'), '6', '12', '255', '09', '2026', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9753, to_date('13-09-2026', 'dd-mm-yyyy'), '7', '13', '256', '09', '2026', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9754, to_date('14-09-2026', 'dd-mm-yyyy'), '1', '14', '257', '09', '2026', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9755, to_date('15-09-2026', 'dd-mm-yyyy'), '2', '15', '258', '09', '2026', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9756, to_date('16-09-2026', 'dd-mm-yyyy'), '3', '16', '259', '09', '2026', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9757, to_date('17-09-2026', 'dd-mm-yyyy'), '4', '17', '260', '09', '2026', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9758, to_date('18-09-2026', 'dd-mm-yyyy'), '5', '18', '261', '09', '2026', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9759, to_date('19-09-2026', 'dd-mm-yyyy'), '6', '19', '262', '09', '2026', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9760, to_date('20-09-2026', 'dd-mm-yyyy'), '7', '20', '263', '09', '2026', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9761, to_date('21-09-2026', 'dd-mm-yyyy'), '1', '21', '264', '09', '2026', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9762, to_date('22-09-2026', 'dd-mm-yyyy'), '2', '22', '265', '09', '2026', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9763, to_date('23-09-2026', 'dd-mm-yyyy'), '3', '23', '266', '09', '2026', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9764, to_date('24-09-2026', 'dd-mm-yyyy'), '4', '24', '267', '09', '2026', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9765, to_date('25-09-2026', 'dd-mm-yyyy'), '5', '25', '268', '09', '2026', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9766, to_date('26-09-2026', 'dd-mm-yyyy'), '6', '26', '269', '09', '2026', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9767, to_date('27-09-2026', 'dd-mm-yyyy'), '7', '27', '270', '09', '2026', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9768, to_date('28-09-2026', 'dd-mm-yyyy'), '1', '28', '271', '09', '2026', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9769, to_date('29-09-2026', 'dd-mm-yyyy'), '2', '29', '272', '09', '2026', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9770, to_date('30-09-2026', 'dd-mm-yyyy'), '3', '30', '273', '09', '2026', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9771, to_date('01-10-2026', 'dd-mm-yyyy'), '4', '01', '274', '10', '2026', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9772, to_date('02-10-2026', 'dd-mm-yyyy'), '5', '02', '275', '10', '2026', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9773, to_date('03-10-2026', 'dd-mm-yyyy'), '6', '03', '276', '10', '2026', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9774, to_date('04-10-2026', 'dd-mm-yyyy'), '7', '04', '277', '10', '2026', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9775, to_date('05-10-2026', 'dd-mm-yyyy'), '1', '05', '278', '10', '2026', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9776, to_date('06-10-2026', 'dd-mm-yyyy'), '2', '06', '279', '10', '2026', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9777, to_date('07-10-2026', 'dd-mm-yyyy'), '3', '07', '280', '10', '2026', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9778, to_date('08-10-2026', 'dd-mm-yyyy'), '4', '08', '281', '10', '2026', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9779, to_date('09-10-2026', 'dd-mm-yyyy'), '5', '09', '282', '10', '2026', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9780, to_date('10-10-2026', 'dd-mm-yyyy'), '6', '10', '283', '10', '2026', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9781, to_date('11-10-2026', 'dd-mm-yyyy'), '7', '11', '284', '10', '2026', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9782, to_date('12-10-2026', 'dd-mm-yyyy'), '1', '12', '285', '10', '2026', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9783, to_date('13-10-2026', 'dd-mm-yyyy'), '2', '13', '286', '10', '2026', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9784, to_date('14-10-2026', 'dd-mm-yyyy'), '3', '14', '287', '10', '2026', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9785, to_date('15-10-2026', 'dd-mm-yyyy'), '4', '15', '288', '10', '2026', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9786, to_date('16-10-2026', 'dd-mm-yyyy'), '5', '16', '289', '10', '2026', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9787, to_date('17-10-2026', 'dd-mm-yyyy'), '6', '17', '290', '10', '2026', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9788, to_date('18-10-2026', 'dd-mm-yyyy'), '7', '18', '291', '10', '2026', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9789, to_date('19-10-2026', 'dd-mm-yyyy'), '1', '19', '292', '10', '2026', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9790, to_date('20-10-2026', 'dd-mm-yyyy'), '2', '20', '293', '10', '2026', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9791, to_date('21-10-2026', 'dd-mm-yyyy'), '3', '21', '294', '10', '2026', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9792, to_date('22-10-2026', 'dd-mm-yyyy'), '4', '22', '295', '10', '2026', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9793, to_date('23-10-2026', 'dd-mm-yyyy'), '5', '23', '296', '10', '2026', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9794, to_date('24-10-2026', 'dd-mm-yyyy'), '6', '24', '297', '10', '2026', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9795, to_date('25-10-2026', 'dd-mm-yyyy'), '7', '25', '298', '10', '2026', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9796, to_date('26-10-2026', 'dd-mm-yyyy'), '1', '26', '299', '10', '2026', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9797, to_date('27-10-2026', 'dd-mm-yyyy'), '2', '27', '300', '10', '2026', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9798, to_date('28-10-2026', 'dd-mm-yyyy'), '3', '28', '301', '10', '2026', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9799, to_date('29-10-2026', 'dd-mm-yyyy'), '4', '29', '302', '10', '2026', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9800, to_date('30-10-2026', 'dd-mm-yyyy'), '5', '30', '303', '10', '2026', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9801, to_date('31-10-2026', 'dd-mm-yyyy'), '6', '31', '304', '10', '2026', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9802, to_date('01-11-2026', 'dd-mm-yyyy'), '7', '01', '305', '11', '2026', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9803, to_date('02-11-2026', 'dd-mm-yyyy'), '1', '02', '306', '11', '2026', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9804, to_date('03-11-2026', 'dd-mm-yyyy'), '2', '03', '307', '11', '2026', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9805, to_date('04-11-2026', 'dd-mm-yyyy'), '3', '04', '308', '11', '2026', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9806, to_date('05-11-2026', 'dd-mm-yyyy'), '4', '05', '309', '11', '2026', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9807, to_date('06-11-2026', 'dd-mm-yyyy'), '5', '06', '310', '11', '2026', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9808, to_date('07-11-2026', 'dd-mm-yyyy'), '6', '07', '311', '11', '2026', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9809, to_date('08-11-2026', 'dd-mm-yyyy'), '7', '08', '312', '11', '2026', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9810, to_date('09-11-2026', 'dd-mm-yyyy'), '1', '09', '313', '11', '2026', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9811, to_date('10-11-2026', 'dd-mm-yyyy'), '2', '10', '314', '11', '2026', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9812, to_date('11-11-2026', 'dd-mm-yyyy'), '3', '11', '315', '11', '2026', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9813, to_date('12-11-2026', 'dd-mm-yyyy'), '4', '12', '316', '11', '2026', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9814, to_date('13-11-2026', 'dd-mm-yyyy'), '5', '13', '317', '11', '2026', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9815, to_date('14-11-2026', 'dd-mm-yyyy'), '6', '14', '318', '11', '2026', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9816, to_date('15-11-2026', 'dd-mm-yyyy'), '7', '15', '319', '11', '2026', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9817, to_date('16-11-2026', 'dd-mm-yyyy'), '1', '16', '320', '11', '2026', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9818, to_date('17-11-2026', 'dd-mm-yyyy'), '2', '17', '321', '11', '2026', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9819, to_date('18-11-2026', 'dd-mm-yyyy'), '3', '18', '322', '11', '2026', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9820, to_date('19-11-2026', 'dd-mm-yyyy'), '4', '19', '323', '11', '2026', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9821, to_date('20-11-2026', 'dd-mm-yyyy'), '5', '20', '324', '11', '2026', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9822, to_date('21-11-2026', 'dd-mm-yyyy'), '6', '21', '325', '11', '2026', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9823, to_date('22-11-2026', 'dd-mm-yyyy'), '7', '22', '326', '11', '2026', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9824, to_date('23-11-2026', 'dd-mm-yyyy'), '1', '23', '327', '11', '2026', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9825, to_date('24-11-2026', 'dd-mm-yyyy'), '2', '24', '328', '11', '2026', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9826, to_date('25-11-2026', 'dd-mm-yyyy'), '3', '25', '329', '11', '2026', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9827, to_date('26-11-2026', 'dd-mm-yyyy'), '4', '26', '330', '11', '2026', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9828, to_date('27-11-2026', 'dd-mm-yyyy'), '5', '27', '331', '11', '2026', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9829, to_date('28-11-2026', 'dd-mm-yyyy'), '6', '28', '332', '11', '2026', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9830, to_date('29-11-2026', 'dd-mm-yyyy'), '7', '29', '333', '11', '2026', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9831, to_date('30-11-2026', 'dd-mm-yyyy'), '1', '30', '334', '11', '2026', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9832, to_date('01-12-2026', 'dd-mm-yyyy'), '2', '01', '335', '12', '2026', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9833, to_date('02-12-2026', 'dd-mm-yyyy'), '3', '02', '336', '12', '2026', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9834, to_date('03-12-2026', 'dd-mm-yyyy'), '4', '03', '337', '12', '2026', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9835, to_date('04-12-2026', 'dd-mm-yyyy'), '5', '04', '338', '12', '2026', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9836, to_date('05-12-2026', 'dd-mm-yyyy'), '6', '05', '339', '12', '2026', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9837, to_date('06-12-2026', 'dd-mm-yyyy'), '7', '06', '340', '12', '2026', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9838, to_date('07-12-2026', 'dd-mm-yyyy'), '1', '07', '341', '12', '2026', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9839, to_date('08-12-2026', 'dd-mm-yyyy'), '2', '08', '342', '12', '2026', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9840, to_date('09-12-2026', 'dd-mm-yyyy'), '3', '09', '343', '12', '2026', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9841, to_date('10-12-2026', 'dd-mm-yyyy'), '4', '10', '344', '12', '2026', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9842, to_date('11-12-2026', 'dd-mm-yyyy'), '5', '11', '345', '12', '2026', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9843, to_date('12-12-2026', 'dd-mm-yyyy'), '6', '12', '346', '12', '2026', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9844, to_date('13-12-2026', 'dd-mm-yyyy'), '7', '13', '347', '12', '2026', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9845, to_date('14-12-2026', 'dd-mm-yyyy'), '1', '14', '348', '12', '2026', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9846, to_date('15-12-2026', 'dd-mm-yyyy'), '2', '15', '349', '12', '2026', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9847, to_date('16-12-2026', 'dd-mm-yyyy'), '3', '16', '350', '12', '2026', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9848, to_date('17-12-2026', 'dd-mm-yyyy'), '4', '17', '351', '12', '2026', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9849, to_date('18-12-2026', 'dd-mm-yyyy'), '5', '18', '352', '12', '2026', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9850, to_date('19-12-2026', 'dd-mm-yyyy'), '6', '19', '353', '12', '2026', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9851, to_date('20-12-2026', 'dd-mm-yyyy'), '7', '20', '354', '12', '2026', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9852, to_date('21-12-2026', 'dd-mm-yyyy'), '1', '21', '355', '12', '2026', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9853, to_date('22-12-2026', 'dd-mm-yyyy'), '2', '22', '356', '12', '2026', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9854, to_date('23-12-2026', 'dd-mm-yyyy'), '3', '23', '357', '12', '2026', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9855, to_date('24-12-2026', 'dd-mm-yyyy'), '4', '24', '358', '12', '2026', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9856, to_date('25-12-2026', 'dd-mm-yyyy'), '5', '25', '359', '12', '2026', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9857, to_date('26-12-2026', 'dd-mm-yyyy'), '6', '26', '360', '12', '2026', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9858, to_date('27-12-2026', 'dd-mm-yyyy'), '7', '27', '361', '12', '2026', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9859, to_date('28-12-2026', 'dd-mm-yyyy'), '1', '28', '362', '12', '2026', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9860, to_date('29-12-2026', 'dd-mm-yyyy'), '2', '29', '363', '12', '2026', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9861, to_date('30-12-2026', 'dd-mm-yyyy'), '3', '30', '364', '12', '2026', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9862, to_date('31-12-2026', 'dd-mm-yyyy'), '4', '31', '365', '12', '2026', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9863, to_date('01-01-2027', 'dd-mm-yyyy'), '5', '01', '001', '01', '2027', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9864, to_date('02-01-2027', 'dd-mm-yyyy'), '6', '02', '002', '01', '2027', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9865, to_date('03-01-2027', 'dd-mm-yyyy'), '7', '03', '003', '01', '2027', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9866, to_date('04-01-2027', 'dd-mm-yyyy'), '1', '04', '004', '01', '2027', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9867, to_date('05-01-2027', 'dd-mm-yyyy'), '2', '05', '005', '01', '2027', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9868, to_date('06-01-2027', 'dd-mm-yyyy'), '3', '06', '006', '01', '2027', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9869, to_date('07-01-2027', 'dd-mm-yyyy'), '4', '07', '007', '01', '2027', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9870, to_date('08-01-2027', 'dd-mm-yyyy'), '5', '08', '008', '01', '2027', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9871, to_date('09-01-2027', 'dd-mm-yyyy'), '6', '09', '009', '01', '2027', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9872, to_date('10-01-2027', 'dd-mm-yyyy'), '7', '10', '010', '01', '2027', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9873, to_date('11-01-2027', 'dd-mm-yyyy'), '1', '11', '011', '01', '2027', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9874, to_date('12-01-2027', 'dd-mm-yyyy'), '2', '12', '012', '01', '2027', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9875, to_date('13-01-2027', 'dd-mm-yyyy'), '3', '13', '013', '01', '2027', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9876, to_date('14-01-2027', 'dd-mm-yyyy'), '4', '14', '014', '01', '2027', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9877, to_date('15-01-2027', 'dd-mm-yyyy'), '5', '15', '015', '01', '2027', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9878, to_date('16-01-2027', 'dd-mm-yyyy'), '6', '16', '016', '01', '2027', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9879, to_date('17-01-2027', 'dd-mm-yyyy'), '7', '17', '017', '01', '2027', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9880, to_date('18-01-2027', 'dd-mm-yyyy'), '1', '18', '018', '01', '2027', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9881, to_date('19-01-2027', 'dd-mm-yyyy'), '2', '19', '019', '01', '2027', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9882, to_date('20-01-2027', 'dd-mm-yyyy'), '3', '20', '020', '01', '2027', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9883, to_date('21-01-2027', 'dd-mm-yyyy'), '4', '21', '021', '01', '2027', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9884, to_date('22-01-2027', 'dd-mm-yyyy'), '5', '22', '022', '01', '2027', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9885, to_date('23-01-2027', 'dd-mm-yyyy'), '6', '23', '023', '01', '2027', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9886, to_date('24-01-2027', 'dd-mm-yyyy'), '7', '24', '024', '01', '2027', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9887, to_date('25-01-2027', 'dd-mm-yyyy'), '1', '25', '025', '01', '2027', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9888, to_date('26-01-2027', 'dd-mm-yyyy'), '2', '26', '026', '01', '2027', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9889, to_date('27-01-2027', 'dd-mm-yyyy'), '3', '27', '027', '01', '2027', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9890, to_date('28-01-2027', 'dd-mm-yyyy'), '4', '28', '028', '01', '2027', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9891, to_date('29-01-2027', 'dd-mm-yyyy'), '5', '29', '029', '01', '2027', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9892, to_date('30-01-2027', 'dd-mm-yyyy'), '6', '30', '030', '01', '2027', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9893, to_date('31-01-2027', 'dd-mm-yyyy'), '7', '31', '031', '01', '2027', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9894, to_date('01-02-2027', 'dd-mm-yyyy'), '1', '01', '032', '02', '2027', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
commit;
prompt 10000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9895, to_date('02-02-2027', 'dd-mm-yyyy'), '2', '02', '033', '02', '2027', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9896, to_date('03-02-2027', 'dd-mm-yyyy'), '3', '03', '034', '02', '2027', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9897, to_date('04-02-2027', 'dd-mm-yyyy'), '4', '04', '035', '02', '2027', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9898, to_date('05-02-2027', 'dd-mm-yyyy'), '5', '05', '036', '02', '2027', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9899, to_date('06-02-2027', 'dd-mm-yyyy'), '6', '06', '037', '02', '2027', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9900, to_date('07-02-2027', 'dd-mm-yyyy'), '7', '07', '038', '02', '2027', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9901, to_date('08-02-2027', 'dd-mm-yyyy'), '1', '08', '039', '02', '2027', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9902, to_date('09-02-2027', 'dd-mm-yyyy'), '2', '09', '040', '02', '2027', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9903, to_date('10-02-2027', 'dd-mm-yyyy'), '3', '10', '041', '02', '2027', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9904, to_date('11-02-2027', 'dd-mm-yyyy'), '4', '11', '042', '02', '2027', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9905, to_date('12-02-2027', 'dd-mm-yyyy'), '5', '12', '043', '02', '2027', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9906, to_date('13-02-2027', 'dd-mm-yyyy'), '6', '13', '044', '02', '2027', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9907, to_date('14-02-2027', 'dd-mm-yyyy'), '7', '14', '045', '02', '2027', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9908, to_date('15-02-2027', 'dd-mm-yyyy'), '1', '15', '046', '02', '2027', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9909, to_date('16-02-2027', 'dd-mm-yyyy'), '2', '16', '047', '02', '2027', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9910, to_date('17-02-2027', 'dd-mm-yyyy'), '3', '17', '048', '02', '2027', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9911, to_date('18-02-2027', 'dd-mm-yyyy'), '4', '18', '049', '02', '2027', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9912, to_date('19-02-2027', 'dd-mm-yyyy'), '5', '19', '050', '02', '2027', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9913, to_date('20-02-2027', 'dd-mm-yyyy'), '6', '20', '051', '02', '2027', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9914, to_date('21-02-2027', 'dd-mm-yyyy'), '7', '21', '052', '02', '2027', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9915, to_date('22-02-2027', 'dd-mm-yyyy'), '1', '22', '053', '02', '2027', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9916, to_date('23-02-2027', 'dd-mm-yyyy'), '2', '23', '054', '02', '2027', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9917, to_date('24-02-2027', 'dd-mm-yyyy'), '3', '24', '055', '02', '2027', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9918, to_date('25-02-2027', 'dd-mm-yyyy'), '4', '25', '056', '02', '2027', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9919, to_date('26-02-2027', 'dd-mm-yyyy'), '5', '26', '057', '02', '2027', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9920, to_date('27-02-2027', 'dd-mm-yyyy'), '6', '27', '058', '02', '2027', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9921, to_date('28-02-2027', 'dd-mm-yyyy'), '7', '28', '059', '02', '2027', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9922, to_date('01-03-2027', 'dd-mm-yyyy'), '1', '01', '060', '03', '2027', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9923, to_date('02-03-2027', 'dd-mm-yyyy'), '2', '02', '061', '03', '2027', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9924, to_date('03-03-2027', 'dd-mm-yyyy'), '3', '03', '062', '03', '2027', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9925, to_date('04-03-2027', 'dd-mm-yyyy'), '4', '04', '063', '03', '2027', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9926, to_date('05-03-2027', 'dd-mm-yyyy'), '5', '05', '064', '03', '2027', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9927, to_date('06-03-2027', 'dd-mm-yyyy'), '6', '06', '065', '03', '2027', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9928, to_date('07-03-2027', 'dd-mm-yyyy'), '7', '07', '066', '03', '2027', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9929, to_date('08-03-2027', 'dd-mm-yyyy'), '1', '08', '067', '03', '2027', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9930, to_date('09-03-2027', 'dd-mm-yyyy'), '2', '09', '068', '03', '2027', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9931, to_date('10-03-2027', 'dd-mm-yyyy'), '3', '10', '069', '03', '2027', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9932, to_date('11-03-2027', 'dd-mm-yyyy'), '4', '11', '070', '03', '2027', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9933, to_date('12-03-2027', 'dd-mm-yyyy'), '5', '12', '071', '03', '2027', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9934, to_date('13-03-2027', 'dd-mm-yyyy'), '6', '13', '072', '03', '2027', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9935, to_date('14-03-2027', 'dd-mm-yyyy'), '7', '14', '073', '03', '2027', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9936, to_date('15-03-2027', 'dd-mm-yyyy'), '1', '15', '074', '03', '2027', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9937, to_date('16-03-2027', 'dd-mm-yyyy'), '2', '16', '075', '03', '2027', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9938, to_date('17-03-2027', 'dd-mm-yyyy'), '3', '17', '076', '03', '2027', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9939, to_date('18-03-2027', 'dd-mm-yyyy'), '4', '18', '077', '03', '2027', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9940, to_date('19-03-2027', 'dd-mm-yyyy'), '5', '19', '078', '03', '2027', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9941, to_date('20-03-2027', 'dd-mm-yyyy'), '6', '20', '079', '03', '2027', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9942, to_date('21-03-2027', 'dd-mm-yyyy'), '7', '21', '080', '03', '2027', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9943, to_date('22-03-2027', 'dd-mm-yyyy'), '1', '22', '081', '03', '2027', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9944, to_date('23-03-2027', 'dd-mm-yyyy'), '2', '23', '082', '03', '2027', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9945, to_date('24-03-2027', 'dd-mm-yyyy'), '3', '24', '083', '03', '2027', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9946, to_date('25-03-2027', 'dd-mm-yyyy'), '4', '25', '084', '03', '2027', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9947, to_date('26-03-2027', 'dd-mm-yyyy'), '5', '26', '085', '03', '2027', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9948, to_date('27-03-2027', 'dd-mm-yyyy'), '6', '27', '086', '03', '2027', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9949, to_date('28-03-2027', 'dd-mm-yyyy'), '7', '28', '087', '03', '2027', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9950, to_date('29-03-2027', 'dd-mm-yyyy'), '1', '29', '088', '03', '2027', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9951, to_date('30-03-2027', 'dd-mm-yyyy'), '2', '30', '089', '03', '2027', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9952, to_date('31-03-2027', 'dd-mm-yyyy'), '3', '31', '090', '03', '2027', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9953, to_date('01-04-2027', 'dd-mm-yyyy'), '4', '01', '091', '04', '2027', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9954, to_date('02-04-2027', 'dd-mm-yyyy'), '5', '02', '092', '04', '2027', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9955, to_date('03-04-2027', 'dd-mm-yyyy'), '6', '03', '093', '04', '2027', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9956, to_date('04-04-2027', 'dd-mm-yyyy'), '7', '04', '094', '04', '2027', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9957, to_date('05-04-2027', 'dd-mm-yyyy'), '1', '05', '095', '04', '2027', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9958, to_date('06-04-2027', 'dd-mm-yyyy'), '2', '06', '096', '04', '2027', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9959, to_date('07-04-2027', 'dd-mm-yyyy'), '3', '07', '097', '04', '2027', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9960, to_date('08-04-2027', 'dd-mm-yyyy'), '4', '08', '098', '04', '2027', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9961, to_date('09-04-2027', 'dd-mm-yyyy'), '5', '09', '099', '04', '2027', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9962, to_date('10-04-2027', 'dd-mm-yyyy'), '6', '10', '100', '04', '2027', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9963, to_date('11-04-2027', 'dd-mm-yyyy'), '7', '11', '101', '04', '2027', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9964, to_date('12-04-2027', 'dd-mm-yyyy'), '1', '12', '102', '04', '2027', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9965, to_date('13-04-2027', 'dd-mm-yyyy'), '2', '13', '103', '04', '2027', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9966, to_date('14-04-2027', 'dd-mm-yyyy'), '3', '14', '104', '04', '2027', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9967, to_date('15-04-2027', 'dd-mm-yyyy'), '4', '15', '105', '04', '2027', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9968, to_date('16-04-2027', 'dd-mm-yyyy'), '5', '16', '106', '04', '2027', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9969, to_date('17-04-2027', 'dd-mm-yyyy'), '6', '17', '107', '04', '2027', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9970, to_date('18-04-2027', 'dd-mm-yyyy'), '7', '18', '108', '04', '2027', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9971, to_date('19-04-2027', 'dd-mm-yyyy'), '1', '19', '109', '04', '2027', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9972, to_date('20-04-2027', 'dd-mm-yyyy'), '2', '20', '110', '04', '2027', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9973, to_date('21-04-2027', 'dd-mm-yyyy'), '3', '21', '111', '04', '2027', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9974, to_date('22-04-2027', 'dd-mm-yyyy'), '4', '22', '112', '04', '2027', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9975, to_date('23-04-2027', 'dd-mm-yyyy'), '5', '23', '113', '04', '2027', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9976, to_date('24-04-2027', 'dd-mm-yyyy'), '6', '24', '114', '04', '2027', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9977, to_date('25-04-2027', 'dd-mm-yyyy'), '7', '25', '115', '04', '2027', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9978, to_date('26-04-2027', 'dd-mm-yyyy'), '1', '26', '116', '04', '2027', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9979, to_date('27-04-2027', 'dd-mm-yyyy'), '2', '27', '117', '04', '2027', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9980, to_date('28-04-2027', 'dd-mm-yyyy'), '3', '28', '118', '04', '2027', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9981, to_date('29-04-2027', 'dd-mm-yyyy'), '4', '29', '119', '04', '2027', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9982, to_date('30-04-2027', 'dd-mm-yyyy'), '5', '30', '120', '04', '2027', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9983, to_date('01-05-2027', 'dd-mm-yyyy'), '6', '01', '121', '05', '2027', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9984, to_date('02-05-2027', 'dd-mm-yyyy'), '7', '02', '122', '05', '2027', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9985, to_date('03-05-2027', 'dd-mm-yyyy'), '1', '03', '123', '05', '2027', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9986, to_date('04-05-2027', 'dd-mm-yyyy'), '2', '04', '124', '05', '2027', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9987, to_date('05-05-2027', 'dd-mm-yyyy'), '3', '05', '125', '05', '2027', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9988, to_date('06-05-2027', 'dd-mm-yyyy'), '4', '06', '126', '05', '2027', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9989, to_date('07-05-2027', 'dd-mm-yyyy'), '5', '07', '127', '05', '2027', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9990, to_date('08-05-2027', 'dd-mm-yyyy'), '6', '08', '128', '05', '2027', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9991, to_date('09-05-2027', 'dd-mm-yyyy'), '7', '09', '129', '05', '2027', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9992, to_date('10-05-2027', 'dd-mm-yyyy'), '1', '10', '130', '05', '2027', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9993, to_date('11-05-2027', 'dd-mm-yyyy'), '2', '11', '131', '05', '2027', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9994, to_date('12-05-2027', 'dd-mm-yyyy'), '3', '12', '132', '05', '2027', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9995, to_date('13-05-2027', 'dd-mm-yyyy'), '4', '13', '133', '05', '2027', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9996, to_date('14-05-2027', 'dd-mm-yyyy'), '5', '14', '134', '05', '2027', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9997, to_date('15-05-2027', 'dd-mm-yyyy'), '6', '15', '135', '05', '2027', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9998, to_date('16-05-2027', 'dd-mm-yyyy'), '7', '16', '136', '05', '2027', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (9999, to_date('17-05-2027', 'dd-mm-yyyy'), '1', '17', '137', '05', '2027', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10000, to_date('18-05-2027', 'dd-mm-yyyy'), '2', '18', '138', '05', '2027', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10001, to_date('19-05-2027', 'dd-mm-yyyy'), '3', '19', '139', '05', '2027', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10002, to_date('20-05-2027', 'dd-mm-yyyy'), '4', '20', '140', '05', '2027', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10003, to_date('21-05-2027', 'dd-mm-yyyy'), '5', '21', '141', '05', '2027', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10004, to_date('22-05-2027', 'dd-mm-yyyy'), '6', '22', '142', '05', '2027', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10005, to_date('23-05-2027', 'dd-mm-yyyy'), '7', '23', '143', '05', '2027', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10006, to_date('24-05-2027', 'dd-mm-yyyy'), '1', '24', '144', '05', '2027', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10007, to_date('25-05-2027', 'dd-mm-yyyy'), '2', '25', '145', '05', '2027', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10008, to_date('26-05-2027', 'dd-mm-yyyy'), '3', '26', '146', '05', '2027', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10009, to_date('27-05-2027', 'dd-mm-yyyy'), '4', '27', '147', '05', '2027', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10010, to_date('28-05-2027', 'dd-mm-yyyy'), '5', '28', '148', '05', '2027', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10011, to_date('29-05-2027', 'dd-mm-yyyy'), '6', '29', '149', '05', '2027', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10012, to_date('30-05-2027', 'dd-mm-yyyy'), '7', '30', '150', '05', '2027', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10013, to_date('31-05-2027', 'dd-mm-yyyy'), '1', '31', '151', '05', '2027', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10014, to_date('01-06-2027', 'dd-mm-yyyy'), '2', '01', '152', '06', '2027', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10015, to_date('02-06-2027', 'dd-mm-yyyy'), '3', '02', '153', '06', '2027', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10016, to_date('03-06-2027', 'dd-mm-yyyy'), '4', '03', '154', '06', '2027', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10017, to_date('04-06-2027', 'dd-mm-yyyy'), '5', '04', '155', '06', '2027', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10018, to_date('05-06-2027', 'dd-mm-yyyy'), '6', '05', '156', '06', '2027', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10019, to_date('06-06-2027', 'dd-mm-yyyy'), '7', '06', '157', '06', '2027', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10020, to_date('07-06-2027', 'dd-mm-yyyy'), '1', '07', '158', '06', '2027', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10021, to_date('08-06-2027', 'dd-mm-yyyy'), '2', '08', '159', '06', '2027', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10022, to_date('09-06-2027', 'dd-mm-yyyy'), '3', '09', '160', '06', '2027', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10023, to_date('10-06-2027', 'dd-mm-yyyy'), '4', '10', '161', '06', '2027', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10024, to_date('11-06-2027', 'dd-mm-yyyy'), '5', '11', '162', '06', '2027', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10025, to_date('12-06-2027', 'dd-mm-yyyy'), '6', '12', '163', '06', '2027', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10026, to_date('13-06-2027', 'dd-mm-yyyy'), '7', '13', '164', '06', '2027', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10027, to_date('14-06-2027', 'dd-mm-yyyy'), '1', '14', '165', '06', '2027', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10028, to_date('15-06-2027', 'dd-mm-yyyy'), '2', '15', '166', '06', '2027', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10029, to_date('16-06-2027', 'dd-mm-yyyy'), '3', '16', '167', '06', '2027', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10030, to_date('17-06-2027', 'dd-mm-yyyy'), '4', '17', '168', '06', '2027', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10031, to_date('18-06-2027', 'dd-mm-yyyy'), '5', '18', '169', '06', '2027', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10032, to_date('19-06-2027', 'dd-mm-yyyy'), '6', '19', '170', '06', '2027', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10033, to_date('20-06-2027', 'dd-mm-yyyy'), '7', '20', '171', '06', '2027', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10034, to_date('21-06-2027', 'dd-mm-yyyy'), '1', '21', '172', '06', '2027', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10035, to_date('22-06-2027', 'dd-mm-yyyy'), '2', '22', '173', '06', '2027', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10036, to_date('23-06-2027', 'dd-mm-yyyy'), '3', '23', '174', '06', '2027', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10037, to_date('24-06-2027', 'dd-mm-yyyy'), '4', '24', '175', '06', '2027', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10038, to_date('25-06-2027', 'dd-mm-yyyy'), '5', '25', '176', '06', '2027', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10039, to_date('26-06-2027', 'dd-mm-yyyy'), '6', '26', '177', '06', '2027', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10040, to_date('27-06-2027', 'dd-mm-yyyy'), '7', '27', '178', '06', '2027', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10041, to_date('28-06-2027', 'dd-mm-yyyy'), '1', '28', '179', '06', '2027', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10042, to_date('29-06-2027', 'dd-mm-yyyy'), '2', '29', '180', '06', '2027', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10043, to_date('30-06-2027', 'dd-mm-yyyy'), '3', '30', '181', '06', '2027', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10044, to_date('01-07-2027', 'dd-mm-yyyy'), '4', '01', '182', '07', '2027', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10045, to_date('02-07-2027', 'dd-mm-yyyy'), '5', '02', '183', '07', '2027', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10046, to_date('03-07-2027', 'dd-mm-yyyy'), '6', '03', '184', '07', '2027', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10047, to_date('04-07-2027', 'dd-mm-yyyy'), '7', '04', '185', '07', '2027', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10048, to_date('05-07-2027', 'dd-mm-yyyy'), '1', '05', '186', '07', '2027', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10049, to_date('06-07-2027', 'dd-mm-yyyy'), '2', '06', '187', '07', '2027', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10050, to_date('07-07-2027', 'dd-mm-yyyy'), '3', '07', '188', '07', '2027', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10051, to_date('08-07-2027', 'dd-mm-yyyy'), '4', '08', '189', '07', '2027', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10052, to_date('09-07-2027', 'dd-mm-yyyy'), '5', '09', '190', '07', '2027', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10053, to_date('10-07-2027', 'dd-mm-yyyy'), '6', '10', '191', '07', '2027', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10054, to_date('11-07-2027', 'dd-mm-yyyy'), '7', '11', '192', '07', '2027', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10055, to_date('12-07-2027', 'dd-mm-yyyy'), '1', '12', '193', '07', '2027', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10056, to_date('13-07-2027', 'dd-mm-yyyy'), '2', '13', '194', '07', '2027', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10057, to_date('14-07-2027', 'dd-mm-yyyy'), '3', '14', '195', '07', '2027', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10058, to_date('15-07-2027', 'dd-mm-yyyy'), '4', '15', '196', '07', '2027', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10059, to_date('16-07-2027', 'dd-mm-yyyy'), '5', '16', '197', '07', '2027', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10060, to_date('17-07-2027', 'dd-mm-yyyy'), '6', '17', '198', '07', '2027', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10061, to_date('18-07-2027', 'dd-mm-yyyy'), '7', '18', '199', '07', '2027', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10062, to_date('19-07-2027', 'dd-mm-yyyy'), '1', '19', '200', '07', '2027', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10063, to_date('20-07-2027', 'dd-mm-yyyy'), '2', '20', '201', '07', '2027', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10064, to_date('21-07-2027', 'dd-mm-yyyy'), '3', '21', '202', '07', '2027', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10065, to_date('22-07-2027', 'dd-mm-yyyy'), '4', '22', '203', '07', '2027', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10066, to_date('23-07-2027', 'dd-mm-yyyy'), '5', '23', '204', '07', '2027', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10067, to_date('24-07-2027', 'dd-mm-yyyy'), '6', '24', '205', '07', '2027', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10068, to_date('25-07-2027', 'dd-mm-yyyy'), '7', '25', '206', '07', '2027', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10069, to_date('26-07-2027', 'dd-mm-yyyy'), '1', '26', '207', '07', '2027', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10070, to_date('27-07-2027', 'dd-mm-yyyy'), '2', '27', '208', '07', '2027', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10071, to_date('28-07-2027', 'dd-mm-yyyy'), '3', '28', '209', '07', '2027', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10072, to_date('29-07-2027', 'dd-mm-yyyy'), '4', '29', '210', '07', '2027', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10073, to_date('30-07-2027', 'dd-mm-yyyy'), '5', '30', '211', '07', '2027', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10074, to_date('31-07-2027', 'dd-mm-yyyy'), '6', '31', '212', '07', '2027', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10075, to_date('01-08-2027', 'dd-mm-yyyy'), '7', '01', '213', '08', '2027', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10076, to_date('02-08-2027', 'dd-mm-yyyy'), '1', '02', '214', '08', '2027', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10077, to_date('03-08-2027', 'dd-mm-yyyy'), '2', '03', '215', '08', '2027', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10078, to_date('04-08-2027', 'dd-mm-yyyy'), '3', '04', '216', '08', '2027', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10079, to_date('05-08-2027', 'dd-mm-yyyy'), '4', '05', '217', '08', '2027', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10080, to_date('06-08-2027', 'dd-mm-yyyy'), '5', '06', '218', '08', '2027', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10081, to_date('07-08-2027', 'dd-mm-yyyy'), '6', '07', '219', '08', '2027', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10082, to_date('08-08-2027', 'dd-mm-yyyy'), '7', '08', '220', '08', '2027', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10083, to_date('09-08-2027', 'dd-mm-yyyy'), '1', '09', '221', '08', '2027', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10084, to_date('10-08-2027', 'dd-mm-yyyy'), '2', '10', '222', '08', '2027', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10085, to_date('11-08-2027', 'dd-mm-yyyy'), '3', '11', '223', '08', '2027', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10086, to_date('12-08-2027', 'dd-mm-yyyy'), '4', '12', '224', '08', '2027', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10087, to_date('13-08-2027', 'dd-mm-yyyy'), '5', '13', '225', '08', '2027', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10088, to_date('14-08-2027', 'dd-mm-yyyy'), '6', '14', '226', '08', '2027', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10089, to_date('15-08-2027', 'dd-mm-yyyy'), '7', '15', '227', '08', '2027', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10090, to_date('16-08-2027', 'dd-mm-yyyy'), '1', '16', '228', '08', '2027', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10091, to_date('17-08-2027', 'dd-mm-yyyy'), '2', '17', '229', '08', '2027', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10092, to_date('18-08-2027', 'dd-mm-yyyy'), '3', '18', '230', '08', '2027', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10093, to_date('19-08-2027', 'dd-mm-yyyy'), '4', '19', '231', '08', '2027', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10094, to_date('20-08-2027', 'dd-mm-yyyy'), '5', '20', '232', '08', '2027', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10095, to_date('21-08-2027', 'dd-mm-yyyy'), '6', '21', '233', '08', '2027', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10096, to_date('22-08-2027', 'dd-mm-yyyy'), '7', '22', '234', '08', '2027', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10097, to_date('23-08-2027', 'dd-mm-yyyy'), '1', '23', '235', '08', '2027', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10098, to_date('24-08-2027', 'dd-mm-yyyy'), '2', '24', '236', '08', '2027', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10099, to_date('25-08-2027', 'dd-mm-yyyy'), '3', '25', '237', '08', '2027', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10100, to_date('26-08-2027', 'dd-mm-yyyy'), '4', '26', '238', '08', '2027', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10101, to_date('27-08-2027', 'dd-mm-yyyy'), '5', '27', '239', '08', '2027', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10102, to_date('28-08-2027', 'dd-mm-yyyy'), '6', '28', '240', '08', '2027', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10103, to_date('29-08-2027', 'dd-mm-yyyy'), '7', '29', '241', '08', '2027', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10104, to_date('30-08-2027', 'dd-mm-yyyy'), '1', '30', '242', '08', '2027', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10105, to_date('31-08-2027', 'dd-mm-yyyy'), '2', '31', '243', '08', '2027', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10106, to_date('01-09-2027', 'dd-mm-yyyy'), '3', '01', '244', '09', '2027', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10107, to_date('02-09-2027', 'dd-mm-yyyy'), '4', '02', '245', '09', '2027', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10108, to_date('03-09-2027', 'dd-mm-yyyy'), '5', '03', '246', '09', '2027', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10109, to_date('04-09-2027', 'dd-mm-yyyy'), '6', '04', '247', '09', '2027', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10110, to_date('05-09-2027', 'dd-mm-yyyy'), '7', '05', '248', '09', '2027', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10111, to_date('06-09-2027', 'dd-mm-yyyy'), '1', '06', '249', '09', '2027', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10112, to_date('07-09-2027', 'dd-mm-yyyy'), '2', '07', '250', '09', '2027', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10113, to_date('08-09-2027', 'dd-mm-yyyy'), '3', '08', '251', '09', '2027', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10114, to_date('09-09-2027', 'dd-mm-yyyy'), '4', '09', '252', '09', '2027', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10115, to_date('10-09-2027', 'dd-mm-yyyy'), '5', '10', '253', '09', '2027', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10116, to_date('11-09-2027', 'dd-mm-yyyy'), '6', '11', '254', '09', '2027', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10117, to_date('12-09-2027', 'dd-mm-yyyy'), '7', '12', '255', '09', '2027', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10118, to_date('13-09-2027', 'dd-mm-yyyy'), '1', '13', '256', '09', '2027', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10119, to_date('14-09-2027', 'dd-mm-yyyy'), '2', '14', '257', '09', '2027', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10120, to_date('15-09-2027', 'dd-mm-yyyy'), '3', '15', '258', '09', '2027', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10121, to_date('16-09-2027', 'dd-mm-yyyy'), '4', '16', '259', '09', '2027', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10122, to_date('17-09-2027', 'dd-mm-yyyy'), '5', '17', '260', '09', '2027', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10123, to_date('18-09-2027', 'dd-mm-yyyy'), '6', '18', '261', '09', '2027', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10124, to_date('19-09-2027', 'dd-mm-yyyy'), '7', '19', '262', '09', '2027', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10125, to_date('20-09-2027', 'dd-mm-yyyy'), '1', '20', '263', '09', '2027', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10126, to_date('21-09-2027', 'dd-mm-yyyy'), '2', '21', '264', '09', '2027', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10127, to_date('22-09-2027', 'dd-mm-yyyy'), '3', '22', '265', '09', '2027', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10128, to_date('23-09-2027', 'dd-mm-yyyy'), '4', '23', '266', '09', '2027', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10129, to_date('24-09-2027', 'dd-mm-yyyy'), '5', '24', '267', '09', '2027', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10130, to_date('25-09-2027', 'dd-mm-yyyy'), '6', '25', '268', '09', '2027', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10131, to_date('26-09-2027', 'dd-mm-yyyy'), '7', '26', '269', '09', '2027', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10132, to_date('27-09-2027', 'dd-mm-yyyy'), '1', '27', '270', '09', '2027', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10133, to_date('28-09-2027', 'dd-mm-yyyy'), '2', '28', '271', '09', '2027', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10134, to_date('29-09-2027', 'dd-mm-yyyy'), '3', '29', '272', '09', '2027', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10135, to_date('30-09-2027', 'dd-mm-yyyy'), '4', '30', '273', '09', '2027', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10136, to_date('01-10-2027', 'dd-mm-yyyy'), '5', '01', '274', '10', '2027', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10137, to_date('02-10-2027', 'dd-mm-yyyy'), '6', '02', '275', '10', '2027', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10138, to_date('03-10-2027', 'dd-mm-yyyy'), '7', '03', '276', '10', '2027', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10139, to_date('04-10-2027', 'dd-mm-yyyy'), '1', '04', '277', '10', '2027', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10140, to_date('05-10-2027', 'dd-mm-yyyy'), '2', '05', '278', '10', '2027', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10141, to_date('06-10-2027', 'dd-mm-yyyy'), '3', '06', '279', '10', '2027', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10142, to_date('07-10-2027', 'dd-mm-yyyy'), '4', '07', '280', '10', '2027', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10143, to_date('08-10-2027', 'dd-mm-yyyy'), '5', '08', '281', '10', '2027', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10144, to_date('09-10-2027', 'dd-mm-yyyy'), '6', '09', '282', '10', '2027', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10145, to_date('10-10-2027', 'dd-mm-yyyy'), '7', '10', '283', '10', '2027', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10146, to_date('11-10-2027', 'dd-mm-yyyy'), '1', '11', '284', '10', '2027', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10147, to_date('12-10-2027', 'dd-mm-yyyy'), '2', '12', '285', '10', '2027', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10148, to_date('13-10-2027', 'dd-mm-yyyy'), '3', '13', '286', '10', '2027', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10149, to_date('14-10-2027', 'dd-mm-yyyy'), '4', '14', '287', '10', '2027', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10150, to_date('15-10-2027', 'dd-mm-yyyy'), '5', '15', '288', '10', '2027', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10363, to_date('15-05-2028', 'dd-mm-yyyy'), '1', '15', '136', '05', '2028', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10364, to_date('16-05-2028', 'dd-mm-yyyy'), '2', '16', '137', '05', '2028', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10365, to_date('17-05-2028', 'dd-mm-yyyy'), '3', '17', '138', '05', '2028', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10366, to_date('18-05-2028', 'dd-mm-yyyy'), '4', '18', '139', '05', '2028', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10367, to_date('19-05-2028', 'dd-mm-yyyy'), '5', '19', '140', '05', '2028', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10368, to_date('20-05-2028', 'dd-mm-yyyy'), '6', '20', '141', '05', '2028', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10369, to_date('21-05-2028', 'dd-mm-yyyy'), '7', '21', '142', '05', '2028', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10370, to_date('22-05-2028', 'dd-mm-yyyy'), '1', '22', '143', '05', '2028', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10371, to_date('23-05-2028', 'dd-mm-yyyy'), '2', '23', '144', '05', '2028', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10372, to_date('24-05-2028', 'dd-mm-yyyy'), '3', '24', '145', '05', '2028', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10373, to_date('25-05-2028', 'dd-mm-yyyy'), '4', '25', '146', '05', '2028', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10374, to_date('26-05-2028', 'dd-mm-yyyy'), '5', '26', '147', '05', '2028', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10375, to_date('27-05-2028', 'dd-mm-yyyy'), '6', '27', '148', '05', '2028', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10376, to_date('28-05-2028', 'dd-mm-yyyy'), '7', '28', '149', '05', '2028', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10377, to_date('29-05-2028', 'dd-mm-yyyy'), '1', '29', '150', '05', '2028', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10378, to_date('30-05-2028', 'dd-mm-yyyy'), '2', '30', '151', '05', '2028', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10379, to_date('31-05-2028', 'dd-mm-yyyy'), '3', '31', '152', '05', '2028', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10380, to_date('01-06-2028', 'dd-mm-yyyy'), '4', '01', '153', '06', '2028', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10381, to_date('02-06-2028', 'dd-mm-yyyy'), '5', '02', '154', '06', '2028', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10382, to_date('03-06-2028', 'dd-mm-yyyy'), '6', '03', '155', '06', '2028', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10383, to_date('04-06-2028', 'dd-mm-yyyy'), '7', '04', '156', '06', '2028', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10384, to_date('05-06-2028', 'dd-mm-yyyy'), '1', '05', '157', '06', '2028', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10385, to_date('06-06-2028', 'dd-mm-yyyy'), '2', '06', '158', '06', '2028', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10386, to_date('07-06-2028', 'dd-mm-yyyy'), '3', '07', '159', '06', '2028', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10387, to_date('08-06-2028', 'dd-mm-yyyy'), '4', '08', '160', '06', '2028', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10388, to_date('09-06-2028', 'dd-mm-yyyy'), '5', '09', '161', '06', '2028', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10389, to_date('10-06-2028', 'dd-mm-yyyy'), '6', '10', '162', '06', '2028', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10390, to_date('11-06-2028', 'dd-mm-yyyy'), '7', '11', '163', '06', '2028', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10391, to_date('12-06-2028', 'dd-mm-yyyy'), '1', '12', '164', '06', '2028', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10392, to_date('13-06-2028', 'dd-mm-yyyy'), '2', '13', '165', '06', '2028', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10393, to_date('14-06-2028', 'dd-mm-yyyy'), '3', '14', '166', '06', '2028', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10394, to_date('15-06-2028', 'dd-mm-yyyy'), '4', '15', '167', '06', '2028', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10395, to_date('16-06-2028', 'dd-mm-yyyy'), '5', '16', '168', '06', '2028', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10396, to_date('17-06-2028', 'dd-mm-yyyy'), '6', '17', '169', '06', '2028', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10397, to_date('18-06-2028', 'dd-mm-yyyy'), '7', '18', '170', '06', '2028', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10398, to_date('19-06-2028', 'dd-mm-yyyy'), '1', '19', '171', '06', '2028', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10399, to_date('20-06-2028', 'dd-mm-yyyy'), '2', '20', '172', '06', '2028', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10400, to_date('21-06-2028', 'dd-mm-yyyy'), '3', '21', '173', '06', '2028', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10401, to_date('22-06-2028', 'dd-mm-yyyy'), '4', '22', '174', '06', '2028', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10402, to_date('23-06-2028', 'dd-mm-yyyy'), '5', '23', '175', '06', '2028', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10403, to_date('24-06-2028', 'dd-mm-yyyy'), '6', '24', '176', '06', '2028', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10404, to_date('25-06-2028', 'dd-mm-yyyy'), '7', '25', '177', '06', '2028', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10405, to_date('26-06-2028', 'dd-mm-yyyy'), '1', '26', '178', '06', '2028', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10406, to_date('27-06-2028', 'dd-mm-yyyy'), '2', '27', '179', '06', '2028', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10407, to_date('28-06-2028', 'dd-mm-yyyy'), '3', '28', '180', '06', '2028', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10408, to_date('29-06-2028', 'dd-mm-yyyy'), '4', '29', '181', '06', '2028', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10409, to_date('30-06-2028', 'dd-mm-yyyy'), '5', '30', '182', '06', '2028', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10410, to_date('01-07-2028', 'dd-mm-yyyy'), '6', '01', '183', '07', '2028', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10411, to_date('02-07-2028', 'dd-mm-yyyy'), '7', '02', '184', '07', '2028', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10412, to_date('03-07-2028', 'dd-mm-yyyy'), '1', '03', '185', '07', '2028', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10413, to_date('04-07-2028', 'dd-mm-yyyy'), '2', '04', '186', '07', '2028', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10414, to_date('05-07-2028', 'dd-mm-yyyy'), '3', '05', '187', '07', '2028', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10415, to_date('06-07-2028', 'dd-mm-yyyy'), '4', '06', '188', '07', '2028', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10416, to_date('07-07-2028', 'dd-mm-yyyy'), '5', '07', '189', '07', '2028', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10417, to_date('08-07-2028', 'dd-mm-yyyy'), '6', '08', '190', '07', '2028', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10418, to_date('09-07-2028', 'dd-mm-yyyy'), '7', '09', '191', '07', '2028', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10419, to_date('10-07-2028', 'dd-mm-yyyy'), '1', '10', '192', '07', '2028', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10420, to_date('11-07-2028', 'dd-mm-yyyy'), '2', '11', '193', '07', '2028', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10421, to_date('12-07-2028', 'dd-mm-yyyy'), '3', '12', '194', '07', '2028', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10422, to_date('13-07-2028', 'dd-mm-yyyy'), '4', '13', '195', '07', '2028', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10423, to_date('14-07-2028', 'dd-mm-yyyy'), '5', '14', '196', '07', '2028', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10424, to_date('15-07-2028', 'dd-mm-yyyy'), '6', '15', '197', '07', '2028', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10425, to_date('16-07-2028', 'dd-mm-yyyy'), '7', '16', '198', '07', '2028', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10426, to_date('17-07-2028', 'dd-mm-yyyy'), '1', '17', '199', '07', '2028', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10427, to_date('18-07-2028', 'dd-mm-yyyy'), '2', '18', '200', '07', '2028', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10428, to_date('19-07-2028', 'dd-mm-yyyy'), '3', '19', '201', '07', '2028', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10429, to_date('20-07-2028', 'dd-mm-yyyy'), '4', '20', '202', '07', '2028', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10430, to_date('21-07-2028', 'dd-mm-yyyy'), '5', '21', '203', '07', '2028', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10431, to_date('22-07-2028', 'dd-mm-yyyy'), '6', '22', '204', '07', '2028', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10432, to_date('23-07-2028', 'dd-mm-yyyy'), '7', '23', '205', '07', '2028', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10433, to_date('24-07-2028', 'dd-mm-yyyy'), '1', '24', '206', '07', '2028', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10434, to_date('25-07-2028', 'dd-mm-yyyy'), '2', '25', '207', '07', '2028', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10435, to_date('26-07-2028', 'dd-mm-yyyy'), '3', '26', '208', '07', '2028', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10436, to_date('27-07-2028', 'dd-mm-yyyy'), '4', '27', '209', '07', '2028', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10437, to_date('28-07-2028', 'dd-mm-yyyy'), '5', '28', '210', '07', '2028', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10438, to_date('29-07-2028', 'dd-mm-yyyy'), '6', '29', '211', '07', '2028', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10439, to_date('30-07-2028', 'dd-mm-yyyy'), '7', '30', '212', '07', '2028', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10440, to_date('31-07-2028', 'dd-mm-yyyy'), '1', '31', '213', '07', '2028', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10441, to_date('01-08-2028', 'dd-mm-yyyy'), '2', '01', '214', '08', '2028', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10442, to_date('02-08-2028', 'dd-mm-yyyy'), '3', '02', '215', '08', '2028', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10443, to_date('03-08-2028', 'dd-mm-yyyy'), '4', '03', '216', '08', '2028', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10444, to_date('04-08-2028', 'dd-mm-yyyy'), '5', '04', '217', '08', '2028', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10445, to_date('05-08-2028', 'dd-mm-yyyy'), '6', '05', '218', '08', '2028', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10446, to_date('06-08-2028', 'dd-mm-yyyy'), '7', '06', '219', '08', '2028', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10447, to_date('07-08-2028', 'dd-mm-yyyy'), '1', '07', '220', '08', '2028', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10448, to_date('08-08-2028', 'dd-mm-yyyy'), '2', '08', '221', '08', '2028', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10449, to_date('09-08-2028', 'dd-mm-yyyy'), '3', '09', '222', '08', '2028', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10450, to_date('10-08-2028', 'dd-mm-yyyy'), '4', '10', '223', '08', '2028', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10451, to_date('11-08-2028', 'dd-mm-yyyy'), '5', '11', '224', '08', '2028', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10452, to_date('12-08-2028', 'dd-mm-yyyy'), '6', '12', '225', '08', '2028', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10453, to_date('13-08-2028', 'dd-mm-yyyy'), '7', '13', '226', '08', '2028', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10454, to_date('14-08-2028', 'dd-mm-yyyy'), '1', '14', '227', '08', '2028', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10455, to_date('15-08-2028', 'dd-mm-yyyy'), '2', '15', '228', '08', '2028', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10456, to_date('16-08-2028', 'dd-mm-yyyy'), '3', '16', '229', '08', '2028', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10457, to_date('17-08-2028', 'dd-mm-yyyy'), '4', '17', '230', '08', '2028', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10458, to_date('18-08-2028', 'dd-mm-yyyy'), '5', '18', '231', '08', '2028', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10459, to_date('19-08-2028', 'dd-mm-yyyy'), '6', '19', '232', '08', '2028', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10460, to_date('20-08-2028', 'dd-mm-yyyy'), '7', '20', '233', '08', '2028', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10461, to_date('21-08-2028', 'dd-mm-yyyy'), '1', '21', '234', '08', '2028', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10462, to_date('22-08-2028', 'dd-mm-yyyy'), '2', '22', '235', '08', '2028', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10463, to_date('23-08-2028', 'dd-mm-yyyy'), '3', '23', '236', '08', '2028', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10464, to_date('24-08-2028', 'dd-mm-yyyy'), '4', '24', '237', '08', '2028', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10465, to_date('25-08-2028', 'dd-mm-yyyy'), '5', '25', '238', '08', '2028', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10466, to_date('26-08-2028', 'dd-mm-yyyy'), '6', '26', '239', '08', '2028', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10467, to_date('27-08-2028', 'dd-mm-yyyy'), '7', '27', '240', '08', '2028', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10468, to_date('28-08-2028', 'dd-mm-yyyy'), '1', '28', '241', '08', '2028', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10469, to_date('29-08-2028', 'dd-mm-yyyy'), '2', '29', '242', '08', '2028', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10470, to_date('30-08-2028', 'dd-mm-yyyy'), '3', '30', '243', '08', '2028', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10471, to_date('31-08-2028', 'dd-mm-yyyy'), '4', '31', '244', '08', '2028', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10472, to_date('01-09-2028', 'dd-mm-yyyy'), '5', '01', '245', '09', '2028', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10473, to_date('02-09-2028', 'dd-mm-yyyy'), '6', '02', '246', '09', '2028', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10474, to_date('03-09-2028', 'dd-mm-yyyy'), '7', '03', '247', '09', '2028', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10475, to_date('04-09-2028', 'dd-mm-yyyy'), '1', '04', '248', '09', '2028', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10476, to_date('05-09-2028', 'dd-mm-yyyy'), '2', '05', '249', '09', '2028', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10477, to_date('06-09-2028', 'dd-mm-yyyy'), '3', '06', '250', '09', '2028', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10478, to_date('07-09-2028', 'dd-mm-yyyy'), '4', '07', '251', '09', '2028', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10479, to_date('08-09-2028', 'dd-mm-yyyy'), '5', '08', '252', '09', '2028', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10480, to_date('09-09-2028', 'dd-mm-yyyy'), '6', '09', '253', '09', '2028', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10481, to_date('10-09-2028', 'dd-mm-yyyy'), '7', '10', '254', '09', '2028', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10482, to_date('11-09-2028', 'dd-mm-yyyy'), '1', '11', '255', '09', '2028', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10483, to_date('12-09-2028', 'dd-mm-yyyy'), '2', '12', '256', '09', '2028', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10484, to_date('13-09-2028', 'dd-mm-yyyy'), '3', '13', '257', '09', '2028', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10485, to_date('14-09-2028', 'dd-mm-yyyy'), '4', '14', '258', '09', '2028', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10486, to_date('15-09-2028', 'dd-mm-yyyy'), '5', '15', '259', '09', '2028', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10487, to_date('16-09-2028', 'dd-mm-yyyy'), '6', '16', '260', '09', '2028', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10488, to_date('17-09-2028', 'dd-mm-yyyy'), '7', '17', '261', '09', '2028', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10489, to_date('18-09-2028', 'dd-mm-yyyy'), '1', '18', '262', '09', '2028', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10490, to_date('19-09-2028', 'dd-mm-yyyy'), '2', '19', '263', '09', '2028', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10491, to_date('20-09-2028', 'dd-mm-yyyy'), '3', '20', '264', '09', '2028', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10492, to_date('21-09-2028', 'dd-mm-yyyy'), '4', '21', '265', '09', '2028', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10493, to_date('22-09-2028', 'dd-mm-yyyy'), '5', '22', '266', '09', '2028', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10494, to_date('23-09-2028', 'dd-mm-yyyy'), '6', '23', '267', '09', '2028', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10495, to_date('24-09-2028', 'dd-mm-yyyy'), '7', '24', '268', '09', '2028', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10496, to_date('25-09-2028', 'dd-mm-yyyy'), '1', '25', '269', '09', '2028', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10497, to_date('26-09-2028', 'dd-mm-yyyy'), '2', '26', '270', '09', '2028', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10498, to_date('27-09-2028', 'dd-mm-yyyy'), '3', '27', '271', '09', '2028', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10499, to_date('28-09-2028', 'dd-mm-yyyy'), '4', '28', '272', '09', '2028', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10500, to_date('29-09-2028', 'dd-mm-yyyy'), '5', '29', '273', '09', '2028', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10501, to_date('30-09-2028', 'dd-mm-yyyy'), '6', '30', '274', '09', '2028', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10502, to_date('01-10-2028', 'dd-mm-yyyy'), '7', '01', '275', '10', '2028', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10503, to_date('02-10-2028', 'dd-mm-yyyy'), '1', '02', '276', '10', '2028', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10504, to_date('03-10-2028', 'dd-mm-yyyy'), '2', '03', '277', '10', '2028', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10505, to_date('04-10-2028', 'dd-mm-yyyy'), '3', '04', '278', '10', '2028', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10506, to_date('05-10-2028', 'dd-mm-yyyy'), '4', '05', '279', '10', '2028', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10507, to_date('06-10-2028', 'dd-mm-yyyy'), '5', '06', '280', '10', '2028', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10508, to_date('07-10-2028', 'dd-mm-yyyy'), '6', '07', '281', '10', '2028', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10509, to_date('08-10-2028', 'dd-mm-yyyy'), '7', '08', '282', '10', '2028', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10510, to_date('09-10-2028', 'dd-mm-yyyy'), '1', '09', '283', '10', '2028', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10511, to_date('10-10-2028', 'dd-mm-yyyy'), '2', '10', '284', '10', '2028', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10512, to_date('11-10-2028', 'dd-mm-yyyy'), '3', '11', '285', '10', '2028', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10513, to_date('12-10-2028', 'dd-mm-yyyy'), '4', '12', '286', '10', '2028', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10514, to_date('13-10-2028', 'dd-mm-yyyy'), '5', '13', '287', '10', '2028', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10515, to_date('14-10-2028', 'dd-mm-yyyy'), '6', '14', '288', '10', '2028', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10516, to_date('15-10-2028', 'dd-mm-yyyy'), '7', '15', '289', '10', '2028', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10517, to_date('16-10-2028', 'dd-mm-yyyy'), '1', '16', '290', '10', '2028', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10518, to_date('17-10-2028', 'dd-mm-yyyy'), '2', '17', '291', '10', '2028', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10519, to_date('18-10-2028', 'dd-mm-yyyy'), '3', '18', '292', '10', '2028', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10520, to_date('19-10-2028', 'dd-mm-yyyy'), '4', '19', '293', '10', '2028', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10521, to_date('20-10-2028', 'dd-mm-yyyy'), '5', '20', '294', '10', '2028', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10522, to_date('21-10-2028', 'dd-mm-yyyy'), '6', '21', '295', '10', '2028', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10523, to_date('22-10-2028', 'dd-mm-yyyy'), '7', '22', '296', '10', '2028', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10524, to_date('23-10-2028', 'dd-mm-yyyy'), '1', '23', '297', '10', '2028', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10525, to_date('24-10-2028', 'dd-mm-yyyy'), '2', '24', '298', '10', '2028', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10526, to_date('25-10-2028', 'dd-mm-yyyy'), '3', '25', '299', '10', '2028', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10527, to_date('26-10-2028', 'dd-mm-yyyy'), '4', '26', '300', '10', '2028', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10528, to_date('27-10-2028', 'dd-mm-yyyy'), '5', '27', '301', '10', '2028', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10529, to_date('28-10-2028', 'dd-mm-yyyy'), '6', '28', '302', '10', '2028', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10530, to_date('29-10-2028', 'dd-mm-yyyy'), '7', '29', '303', '10', '2028', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10531, to_date('30-10-2028', 'dd-mm-yyyy'), '1', '30', '304', '10', '2028', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10532, to_date('31-10-2028', 'dd-mm-yyyy'), '2', '31', '305', '10', '2028', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10533, to_date('01-11-2028', 'dd-mm-yyyy'), '3', '01', '306', '11', '2028', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10534, to_date('02-11-2028', 'dd-mm-yyyy'), '4', '02', '307', '11', '2028', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10535, to_date('03-11-2028', 'dd-mm-yyyy'), '5', '03', '308', '11', '2028', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10536, to_date('04-11-2028', 'dd-mm-yyyy'), '6', '04', '309', '11', '2028', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10537, to_date('05-11-2028', 'dd-mm-yyyy'), '7', '05', '310', '11', '2028', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10538, to_date('06-11-2028', 'dd-mm-yyyy'), '1', '06', '311', '11', '2028', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10539, to_date('07-11-2028', 'dd-mm-yyyy'), '2', '07', '312', '11', '2028', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10540, to_date('08-11-2028', 'dd-mm-yyyy'), '3', '08', '313', '11', '2028', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10541, to_date('09-11-2028', 'dd-mm-yyyy'), '4', '09', '314', '11', '2028', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10542, to_date('10-11-2028', 'dd-mm-yyyy'), '5', '10', '315', '11', '2028', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10543, to_date('11-11-2028', 'dd-mm-yyyy'), '6', '11', '316', '11', '2028', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10544, to_date('12-11-2028', 'dd-mm-yyyy'), '7', '12', '317', '11', '2028', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10545, to_date('13-11-2028', 'dd-mm-yyyy'), '1', '13', '318', '11', '2028', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10546, to_date('14-11-2028', 'dd-mm-yyyy'), '2', '14', '319', '11', '2028', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10547, to_date('15-11-2028', 'dd-mm-yyyy'), '3', '15', '320', '11', '2028', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10548, to_date('16-11-2028', 'dd-mm-yyyy'), '4', '16', '321', '11', '2028', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10549, to_date('17-11-2028', 'dd-mm-yyyy'), '5', '17', '322', '11', '2028', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10550, to_date('18-11-2028', 'dd-mm-yyyy'), '6', '18', '323', '11', '2028', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10551, to_date('19-11-2028', 'dd-mm-yyyy'), '7', '19', '324', '11', '2028', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10552, to_date('20-11-2028', 'dd-mm-yyyy'), '1', '20', '325', '11', '2028', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10553, to_date('21-11-2028', 'dd-mm-yyyy'), '2', '21', '326', '11', '2028', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10554, to_date('22-11-2028', 'dd-mm-yyyy'), '3', '22', '327', '11', '2028', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10555, to_date('23-11-2028', 'dd-mm-yyyy'), '4', '23', '328', '11', '2028', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10556, to_date('24-11-2028', 'dd-mm-yyyy'), '5', '24', '329', '11', '2028', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10557, to_date('25-11-2028', 'dd-mm-yyyy'), '6', '25', '330', '11', '2028', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10558, to_date('26-11-2028', 'dd-mm-yyyy'), '7', '26', '331', '11', '2028', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10559, to_date('27-11-2028', 'dd-mm-yyyy'), '1', '27', '332', '11', '2028', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10560, to_date('28-11-2028', 'dd-mm-yyyy'), '2', '28', '333', '11', '2028', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10561, to_date('29-11-2028', 'dd-mm-yyyy'), '3', '29', '334', '11', '2028', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10562, to_date('30-11-2028', 'dd-mm-yyyy'), '4', '30', '335', '11', '2028', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10563, to_date('01-12-2028', 'dd-mm-yyyy'), '5', '01', '336', '12', '2028', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10564, to_date('02-12-2028', 'dd-mm-yyyy'), '6', '02', '337', '12', '2028', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10565, to_date('03-12-2028', 'dd-mm-yyyy'), '7', '03', '338', '12', '2028', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10566, to_date('04-12-2028', 'dd-mm-yyyy'), '1', '04', '339', '12', '2028', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10567, to_date('05-12-2028', 'dd-mm-yyyy'), '2', '05', '340', '12', '2028', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10568, to_date('06-12-2028', 'dd-mm-yyyy'), '3', '06', '341', '12', '2028', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10569, to_date('07-12-2028', 'dd-mm-yyyy'), '4', '07', '342', '12', '2028', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10570, to_date('08-12-2028', 'dd-mm-yyyy'), '5', '08', '343', '12', '2028', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10571, to_date('09-12-2028', 'dd-mm-yyyy'), '6', '09', '344', '12', '2028', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10572, to_date('10-12-2028', 'dd-mm-yyyy'), '7', '10', '345', '12', '2028', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10573, to_date('11-12-2028', 'dd-mm-yyyy'), '1', '11', '346', '12', '2028', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10574, to_date('12-12-2028', 'dd-mm-yyyy'), '2', '12', '347', '12', '2028', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10999, to_date('10-02-2030', 'dd-mm-yyyy'), '7', '10', '041', '02', '2030', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11000, to_date('11-02-2030', 'dd-mm-yyyy'), '1', '11', '042', '02', '2030', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11001, to_date('12-02-2030', 'dd-mm-yyyy'), '2', '12', '043', '02', '2030', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11002, to_date('13-02-2030', 'dd-mm-yyyy'), '3', '13', '044', '02', '2030', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11003, to_date('14-02-2030', 'dd-mm-yyyy'), '4', '14', '045', '02', '2030', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11004, to_date('15-02-2030', 'dd-mm-yyyy'), '5', '15', '046', '02', '2030', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11005, to_date('16-02-2030', 'dd-mm-yyyy'), '6', '16', '047', '02', '2030', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11006, to_date('17-02-2030', 'dd-mm-yyyy'), '7', '17', '048', '02', '2030', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11007, to_date('18-02-2030', 'dd-mm-yyyy'), '1', '18', '049', '02', '2030', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11008, to_date('19-02-2030', 'dd-mm-yyyy'), '2', '19', '050', '02', '2030', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11009, to_date('20-02-2030', 'dd-mm-yyyy'), '3', '20', '051', '02', '2030', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11010, to_date('21-02-2030', 'dd-mm-yyyy'), '4', '21', '052', '02', '2030', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11011, to_date('22-02-2030', 'dd-mm-yyyy'), '5', '22', '053', '02', '2030', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11012, to_date('23-02-2030', 'dd-mm-yyyy'), '6', '23', '054', '02', '2030', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11013, to_date('24-02-2030', 'dd-mm-yyyy'), '7', '24', '055', '02', '2030', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11014, to_date('25-02-2030', 'dd-mm-yyyy'), '1', '25', '056', '02', '2030', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11015, to_date('26-02-2030', 'dd-mm-yyyy'), '2', '26', '057', '02', '2030', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11016, to_date('27-02-2030', 'dd-mm-yyyy'), '3', '27', '058', '02', '2030', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11017, to_date('28-02-2030', 'dd-mm-yyyy'), '4', '28', '059', '02', '2030', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11018, to_date('01-03-2030', 'dd-mm-yyyy'), '5', '01', '060', '03', '2030', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11019, to_date('02-03-2030', 'dd-mm-yyyy'), '6', '02', '061', '03', '2030', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11020, to_date('03-03-2030', 'dd-mm-yyyy'), '7', '03', '062', '03', '2030', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11021, to_date('04-03-2030', 'dd-mm-yyyy'), '1', '04', '063', '03', '2030', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11022, to_date('05-03-2030', 'dd-mm-yyyy'), '2', '05', '064', '03', '2030', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11023, to_date('06-03-2030', 'dd-mm-yyyy'), '3', '06', '065', '03', '2030', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11024, to_date('07-03-2030', 'dd-mm-yyyy'), '4', '07', '066', '03', '2030', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11025, to_date('08-03-2030', 'dd-mm-yyyy'), '5', '08', '067', '03', '2030', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11026, to_date('09-03-2030', 'dd-mm-yyyy'), '6', '09', '068', '03', '2030', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11027, to_date('10-03-2030', 'dd-mm-yyyy'), '7', '10', '069', '03', '2030', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11028, to_date('11-03-2030', 'dd-mm-yyyy'), '1', '11', '070', '03', '2030', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11029, to_date('12-03-2030', 'dd-mm-yyyy'), '2', '12', '071', '03', '2030', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11030, to_date('13-03-2030', 'dd-mm-yyyy'), '3', '13', '072', '03', '2030', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11031, to_date('14-03-2030', 'dd-mm-yyyy'), '4', '14', '073', '03', '2030', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11032, to_date('15-03-2030', 'dd-mm-yyyy'), '5', '15', '074', '03', '2030', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11033, to_date('16-03-2030', 'dd-mm-yyyy'), '6', '16', '075', '03', '2030', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11034, to_date('17-03-2030', 'dd-mm-yyyy'), '7', '17', '076', '03', '2030', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11035, to_date('18-03-2030', 'dd-mm-yyyy'), '1', '18', '077', '03', '2030', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11036, to_date('19-03-2030', 'dd-mm-yyyy'), '2', '19', '078', '03', '2030', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11037, to_date('20-03-2030', 'dd-mm-yyyy'), '3', '20', '079', '03', '2030', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11038, to_date('21-03-2030', 'dd-mm-yyyy'), '4', '21', '080', '03', '2030', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11039, to_date('22-03-2030', 'dd-mm-yyyy'), '5', '22', '081', '03', '2030', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11040, to_date('23-03-2030', 'dd-mm-yyyy'), '6', '23', '082', '03', '2030', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11041, to_date('24-03-2030', 'dd-mm-yyyy'), '7', '24', '083', '03', '2030', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11042, to_date('25-03-2030', 'dd-mm-yyyy'), '1', '25', '084', '03', '2030', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11043, to_date('26-03-2030', 'dd-mm-yyyy'), '2', '26', '085', '03', '2030', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11044, to_date('27-03-2030', 'dd-mm-yyyy'), '3', '27', '086', '03', '2030', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11045, to_date('28-03-2030', 'dd-mm-yyyy'), '4', '28', '087', '03', '2030', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11046, to_date('29-03-2030', 'dd-mm-yyyy'), '5', '29', '088', '03', '2030', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11047, to_date('30-03-2030', 'dd-mm-yyyy'), '6', '30', '089', '03', '2030', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11048, to_date('31-03-2030', 'dd-mm-yyyy'), '7', '31', '090', '03', '2030', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11049, to_date('01-04-2030', 'dd-mm-yyyy'), '1', '01', '091', '04', '2030', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11050, to_date('02-04-2030', 'dd-mm-yyyy'), '2', '02', '092', '04', '2030', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11051, to_date('03-04-2030', 'dd-mm-yyyy'), '3', '03', '093', '04', '2030', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11052, to_date('04-04-2030', 'dd-mm-yyyy'), '4', '04', '094', '04', '2030', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11053, to_date('05-04-2030', 'dd-mm-yyyy'), '5', '05', '095', '04', '2030', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11054, to_date('06-04-2030', 'dd-mm-yyyy'), '6', '06', '096', '04', '2030', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11055, to_date('07-04-2030', 'dd-mm-yyyy'), '7', '07', '097', '04', '2030', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11056, to_date('08-04-2030', 'dd-mm-yyyy'), '1', '08', '098', '04', '2030', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11057, to_date('09-04-2030', 'dd-mm-yyyy'), '2', '09', '099', '04', '2030', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11058, to_date('10-04-2030', 'dd-mm-yyyy'), '3', '10', '100', '04', '2030', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11059, to_date('11-04-2030', 'dd-mm-yyyy'), '4', '11', '101', '04', '2030', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11060, to_date('12-04-2030', 'dd-mm-yyyy'), '5', '12', '102', '04', '2030', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11061, to_date('13-04-2030', 'dd-mm-yyyy'), '6', '13', '103', '04', '2030', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11062, to_date('14-04-2030', 'dd-mm-yyyy'), '7', '14', '104', '04', '2030', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11063, to_date('15-04-2030', 'dd-mm-yyyy'), '1', '15', '105', '04', '2030', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11064, to_date('16-04-2030', 'dd-mm-yyyy'), '2', '16', '106', '04', '2030', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11065, to_date('17-04-2030', 'dd-mm-yyyy'), '3', '17', '107', '04', '2030', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11066, to_date('18-04-2030', 'dd-mm-yyyy'), '4', '18', '108', '04', '2030', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11067, to_date('19-04-2030', 'dd-mm-yyyy'), '5', '19', '109', '04', '2030', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11068, to_date('20-04-2030', 'dd-mm-yyyy'), '6', '20', '110', '04', '2030', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11069, to_date('21-04-2030', 'dd-mm-yyyy'), '7', '21', '111', '04', '2030', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11070, to_date('22-04-2030', 'dd-mm-yyyy'), '1', '22', '112', '04', '2030', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11071, to_date('23-04-2030', 'dd-mm-yyyy'), '2', '23', '113', '04', '2030', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11072, to_date('24-04-2030', 'dd-mm-yyyy'), '3', '24', '114', '04', '2030', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11073, to_date('25-04-2030', 'dd-mm-yyyy'), '4', '25', '115', '04', '2030', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11074, to_date('26-04-2030', 'dd-mm-yyyy'), '5', '26', '116', '04', '2030', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11075, to_date('27-04-2030', 'dd-mm-yyyy'), '6', '27', '117', '04', '2030', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11076, to_date('28-04-2030', 'dd-mm-yyyy'), '7', '28', '118', '04', '2030', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11077, to_date('29-04-2030', 'dd-mm-yyyy'), '1', '29', '119', '04', '2030', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11078, to_date('30-04-2030', 'dd-mm-yyyy'), '2', '30', '120', '04', '2030', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11079, to_date('01-05-2030', 'dd-mm-yyyy'), '3', '01', '121', '05', '2030', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11080, to_date('02-05-2030', 'dd-mm-yyyy'), '4', '02', '122', '05', '2030', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11081, to_date('03-05-2030', 'dd-mm-yyyy'), '5', '03', '123', '05', '2030', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11082, to_date('04-05-2030', 'dd-mm-yyyy'), '6', '04', '124', '05', '2030', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11083, to_date('05-05-2030', 'dd-mm-yyyy'), '7', '05', '125', '05', '2030', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11084, to_date('06-05-2030', 'dd-mm-yyyy'), '1', '06', '126', '05', '2030', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11085, to_date('07-05-2030', 'dd-mm-yyyy'), '2', '07', '127', '05', '2030', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11086, to_date('08-05-2030', 'dd-mm-yyyy'), '3', '08', '128', '05', '2030', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11087, to_date('09-05-2030', 'dd-mm-yyyy'), '4', '09', '129', '05', '2030', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11088, to_date('10-05-2030', 'dd-mm-yyyy'), '5', '10', '130', '05', '2030', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11089, to_date('11-05-2030', 'dd-mm-yyyy'), '6', '11', '131', '05', '2030', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11090, to_date('12-05-2030', 'dd-mm-yyyy'), '7', '12', '132', '05', '2030', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11091, to_date('13-05-2030', 'dd-mm-yyyy'), '1', '13', '133', '05', '2030', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11092, to_date('14-05-2030', 'dd-mm-yyyy'), '2', '14', '134', '05', '2030', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11093, to_date('15-05-2030', 'dd-mm-yyyy'), '3', '15', '135', '05', '2030', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11094, to_date('16-05-2030', 'dd-mm-yyyy'), '4', '16', '136', '05', '2030', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11095, to_date('17-05-2030', 'dd-mm-yyyy'), '5', '17', '137', '05', '2030', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11096, to_date('18-05-2030', 'dd-mm-yyyy'), '6', '18', '138', '05', '2030', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11097, to_date('19-05-2030', 'dd-mm-yyyy'), '7', '19', '139', '05', '2030', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11098, to_date('20-05-2030', 'dd-mm-yyyy'), '1', '20', '140', '05', '2030', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11099, to_date('21-05-2030', 'dd-mm-yyyy'), '2', '21', '141', '05', '2030', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11100, to_date('22-05-2030', 'dd-mm-yyyy'), '3', '22', '142', '05', '2030', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11101, to_date('23-05-2030', 'dd-mm-yyyy'), '4', '23', '143', '05', '2030', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11102, to_date('24-05-2030', 'dd-mm-yyyy'), '5', '24', '144', '05', '2030', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11103, to_date('25-05-2030', 'dd-mm-yyyy'), '6', '25', '145', '05', '2030', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11104, to_date('26-05-2030', 'dd-mm-yyyy'), '7', '26', '146', '05', '2030', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10575, to_date('13-12-2028', 'dd-mm-yyyy'), '3', '13', '348', '12', '2028', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10576, to_date('14-12-2028', 'dd-mm-yyyy'), '4', '14', '349', '12', '2028', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10577, to_date('15-12-2028', 'dd-mm-yyyy'), '5', '15', '350', '12', '2028', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10578, to_date('16-12-2028', 'dd-mm-yyyy'), '6', '16', '351', '12', '2028', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10579, to_date('17-12-2028', 'dd-mm-yyyy'), '7', '17', '352', '12', '2028', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10580, to_date('18-12-2028', 'dd-mm-yyyy'), '1', '18', '353', '12', '2028', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10581, to_date('19-12-2028', 'dd-mm-yyyy'), '2', '19', '354', '12', '2028', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10582, to_date('20-12-2028', 'dd-mm-yyyy'), '3', '20', '355', '12', '2028', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10583, to_date('21-12-2028', 'dd-mm-yyyy'), '4', '21', '356', '12', '2028', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10584, to_date('22-12-2028', 'dd-mm-yyyy'), '5', '22', '357', '12', '2028', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10585, to_date('23-12-2028', 'dd-mm-yyyy'), '6', '23', '358', '12', '2028', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10586, to_date('24-12-2028', 'dd-mm-yyyy'), '7', '24', '359', '12', '2028', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10587, to_date('25-12-2028', 'dd-mm-yyyy'), '1', '25', '360', '12', '2028', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10588, to_date('26-12-2028', 'dd-mm-yyyy'), '2', '26', '361', '12', '2028', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10589, to_date('27-12-2028', 'dd-mm-yyyy'), '3', '27', '362', '12', '2028', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10590, to_date('28-12-2028', 'dd-mm-yyyy'), '4', '28', '363', '12', '2028', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10591, to_date('29-12-2028', 'dd-mm-yyyy'), '5', '29', '364', '12', '2028', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10592, to_date('30-12-2028', 'dd-mm-yyyy'), '6', '30', '365', '12', '2028', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10593, to_date('31-12-2028', 'dd-mm-yyyy'), '7', '31', '366', '12', '2028', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10594, to_date('01-01-2029', 'dd-mm-yyyy'), '1', '01', '001', '01', '2029', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10595, to_date('02-01-2029', 'dd-mm-yyyy'), '2', '02', '002', '01', '2029', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10596, to_date('03-01-2029', 'dd-mm-yyyy'), '3', '03', '003', '01', '2029', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10597, to_date('04-01-2029', 'dd-mm-yyyy'), '4', '04', '004', '01', '2029', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10598, to_date('05-01-2029', 'dd-mm-yyyy'), '5', '05', '005', '01', '2029', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10599, to_date('06-01-2029', 'dd-mm-yyyy'), '6', '06', '006', '01', '2029', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10600, to_date('07-01-2029', 'dd-mm-yyyy'), '7', '07', '007', '01', '2029', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10601, to_date('08-01-2029', 'dd-mm-yyyy'), '1', '08', '008', '01', '2029', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10602, to_date('09-01-2029', 'dd-mm-yyyy'), '2', '09', '009', '01', '2029', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10603, to_date('10-01-2029', 'dd-mm-yyyy'), '3', '10', '010', '01', '2029', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10604, to_date('11-01-2029', 'dd-mm-yyyy'), '4', '11', '011', '01', '2029', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10605, to_date('12-01-2029', 'dd-mm-yyyy'), '5', '12', '012', '01', '2029', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10606, to_date('13-01-2029', 'dd-mm-yyyy'), '6', '13', '013', '01', '2029', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10607, to_date('14-01-2029', 'dd-mm-yyyy'), '7', '14', '014', '01', '2029', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10608, to_date('15-01-2029', 'dd-mm-yyyy'), '1', '15', '015', '01', '2029', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10609, to_date('16-01-2029', 'dd-mm-yyyy'), '2', '16', '016', '01', '2029', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10610, to_date('17-01-2029', 'dd-mm-yyyy'), '3', '17', '017', '01', '2029', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10611, to_date('18-01-2029', 'dd-mm-yyyy'), '4', '18', '018', '01', '2029', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10612, to_date('19-01-2029', 'dd-mm-yyyy'), '5', '19', '019', '01', '2029', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10613, to_date('20-01-2029', 'dd-mm-yyyy'), '6', '20', '020', '01', '2029', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10614, to_date('21-01-2029', 'dd-mm-yyyy'), '7', '21', '021', '01', '2029', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10615, to_date('22-01-2029', 'dd-mm-yyyy'), '1', '22', '022', '01', '2029', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10616, to_date('23-01-2029', 'dd-mm-yyyy'), '2', '23', '023', '01', '2029', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10617, to_date('24-01-2029', 'dd-mm-yyyy'), '3', '24', '024', '01', '2029', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10618, to_date('25-01-2029', 'dd-mm-yyyy'), '4', '25', '025', '01', '2029', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10619, to_date('26-01-2029', 'dd-mm-yyyy'), '5', '26', '026', '01', '2029', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10620, to_date('27-01-2029', 'dd-mm-yyyy'), '6', '27', '027', '01', '2029', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10621, to_date('28-01-2029', 'dd-mm-yyyy'), '7', '28', '028', '01', '2029', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10622, to_date('29-01-2029', 'dd-mm-yyyy'), '1', '29', '029', '01', '2029', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10623, to_date('30-01-2029', 'dd-mm-yyyy'), '2', '30', '030', '01', '2029', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10624, to_date('31-01-2029', 'dd-mm-yyyy'), '3', '31', '031', '01', '2029', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10625, to_date('01-02-2029', 'dd-mm-yyyy'), '4', '01', '032', '02', '2029', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10626, to_date('02-02-2029', 'dd-mm-yyyy'), '5', '02', '033', '02', '2029', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10627, to_date('03-02-2029', 'dd-mm-yyyy'), '6', '03', '034', '02', '2029', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10628, to_date('04-02-2029', 'dd-mm-yyyy'), '7', '04', '035', '02', '2029', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10629, to_date('05-02-2029', 'dd-mm-yyyy'), '1', '05', '036', '02', '2029', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10630, to_date('06-02-2029', 'dd-mm-yyyy'), '2', '06', '037', '02', '2029', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10631, to_date('07-02-2029', 'dd-mm-yyyy'), '3', '07', '038', '02', '2029', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10632, to_date('08-02-2029', 'dd-mm-yyyy'), '4', '08', '039', '02', '2029', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10633, to_date('09-02-2029', 'dd-mm-yyyy'), '5', '09', '040', '02', '2029', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10634, to_date('10-02-2029', 'dd-mm-yyyy'), '6', '10', '041', '02', '2029', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10635, to_date('11-02-2029', 'dd-mm-yyyy'), '7', '11', '042', '02', '2029', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10636, to_date('12-02-2029', 'dd-mm-yyyy'), '1', '12', '043', '02', '2029', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10637, to_date('13-02-2029', 'dd-mm-yyyy'), '2', '13', '044', '02', '2029', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10638, to_date('14-02-2029', 'dd-mm-yyyy'), '3', '14', '045', '02', '2029', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10639, to_date('15-02-2029', 'dd-mm-yyyy'), '4', '15', '046', '02', '2029', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10640, to_date('16-02-2029', 'dd-mm-yyyy'), '5', '16', '047', '02', '2029', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10641, to_date('17-02-2029', 'dd-mm-yyyy'), '6', '17', '048', '02', '2029', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10642, to_date('18-02-2029', 'dd-mm-yyyy'), '7', '18', '049', '02', '2029', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10643, to_date('19-02-2029', 'dd-mm-yyyy'), '1', '19', '050', '02', '2029', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10644, to_date('20-02-2029', 'dd-mm-yyyy'), '2', '20', '051', '02', '2029', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10645, to_date('21-02-2029', 'dd-mm-yyyy'), '3', '21', '052', '02', '2029', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10646, to_date('22-02-2029', 'dd-mm-yyyy'), '4', '22', '053', '02', '2029', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10647, to_date('23-02-2029', 'dd-mm-yyyy'), '5', '23', '054', '02', '2029', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10648, to_date('24-02-2029', 'dd-mm-yyyy'), '6', '24', '055', '02', '2029', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10649, to_date('25-02-2029', 'dd-mm-yyyy'), '7', '25', '056', '02', '2029', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10650, to_date('26-02-2029', 'dd-mm-yyyy'), '1', '26', '057', '02', '2029', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10651, to_date('27-02-2029', 'dd-mm-yyyy'), '2', '27', '058', '02', '2029', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10652, to_date('28-02-2029', 'dd-mm-yyyy'), '3', '28', '059', '02', '2029', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10653, to_date('01-03-2029', 'dd-mm-yyyy'), '4', '01', '060', '03', '2029', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10654, to_date('02-03-2029', 'dd-mm-yyyy'), '5', '02', '061', '03', '2029', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10655, to_date('03-03-2029', 'dd-mm-yyyy'), '6', '03', '062', '03', '2029', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10656, to_date('04-03-2029', 'dd-mm-yyyy'), '7', '04', '063', '03', '2029', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10657, to_date('05-03-2029', 'dd-mm-yyyy'), '1', '05', '064', '03', '2029', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10658, to_date('06-03-2029', 'dd-mm-yyyy'), '2', '06', '065', '03', '2029', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10659, to_date('07-03-2029', 'dd-mm-yyyy'), '3', '07', '066', '03', '2029', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10660, to_date('08-03-2029', 'dd-mm-yyyy'), '4', '08', '067', '03', '2029', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10661, to_date('09-03-2029', 'dd-mm-yyyy'), '5', '09', '068', '03', '2029', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10662, to_date('10-03-2029', 'dd-mm-yyyy'), '6', '10', '069', '03', '2029', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10663, to_date('11-03-2029', 'dd-mm-yyyy'), '7', '11', '070', '03', '2029', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10664, to_date('12-03-2029', 'dd-mm-yyyy'), '1', '12', '071', '03', '2029', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10665, to_date('13-03-2029', 'dd-mm-yyyy'), '2', '13', '072', '03', '2029', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10666, to_date('14-03-2029', 'dd-mm-yyyy'), '3', '14', '073', '03', '2029', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10667, to_date('15-03-2029', 'dd-mm-yyyy'), '4', '15', '074', '03', '2029', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10668, to_date('16-03-2029', 'dd-mm-yyyy'), '5', '16', '075', '03', '2029', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10669, to_date('17-03-2029', 'dd-mm-yyyy'), '6', '17', '076', '03', '2029', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10670, to_date('18-03-2029', 'dd-mm-yyyy'), '7', '18', '077', '03', '2029', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10671, to_date('19-03-2029', 'dd-mm-yyyy'), '1', '19', '078', '03', '2029', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10672, to_date('20-03-2029', 'dd-mm-yyyy'), '2', '20', '079', '03', '2029', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10673, to_date('21-03-2029', 'dd-mm-yyyy'), '3', '21', '080', '03', '2029', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10674, to_date('22-03-2029', 'dd-mm-yyyy'), '4', '22', '081', '03', '2029', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10675, to_date('23-03-2029', 'dd-mm-yyyy'), '5', '23', '082', '03', '2029', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10676, to_date('24-03-2029', 'dd-mm-yyyy'), '6', '24', '083', '03', '2029', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10677, to_date('25-03-2029', 'dd-mm-yyyy'), '7', '25', '084', '03', '2029', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10678, to_date('26-03-2029', 'dd-mm-yyyy'), '1', '26', '085', '03', '2029', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10679, to_date('27-03-2029', 'dd-mm-yyyy'), '2', '27', '086', '03', '2029', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10680, to_date('28-03-2029', 'dd-mm-yyyy'), '3', '28', '087', '03', '2029', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10681, to_date('29-03-2029', 'dd-mm-yyyy'), '4', '29', '088', '03', '2029', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10682, to_date('30-03-2029', 'dd-mm-yyyy'), '5', '30', '089', '03', '2029', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10683, to_date('31-03-2029', 'dd-mm-yyyy'), '6', '31', '090', '03', '2029', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10684, to_date('01-04-2029', 'dd-mm-yyyy'), '7', '01', '091', '04', '2029', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10685, to_date('02-04-2029', 'dd-mm-yyyy'), '1', '02', '092', '04', '2029', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10686, to_date('03-04-2029', 'dd-mm-yyyy'), '2', '03', '093', '04', '2029', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10687, to_date('04-04-2029', 'dd-mm-yyyy'), '3', '04', '094', '04', '2029', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10688, to_date('05-04-2029', 'dd-mm-yyyy'), '4', '05', '095', '04', '2029', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10689, to_date('06-04-2029', 'dd-mm-yyyy'), '5', '06', '096', '04', '2029', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10690, to_date('07-04-2029', 'dd-mm-yyyy'), '6', '07', '097', '04', '2029', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10691, to_date('08-04-2029', 'dd-mm-yyyy'), '7', '08', '098', '04', '2029', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10692, to_date('09-04-2029', 'dd-mm-yyyy'), '1', '09', '099', '04', '2029', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10693, to_date('10-04-2029', 'dd-mm-yyyy'), '2', '10', '100', '04', '2029', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10694, to_date('11-04-2029', 'dd-mm-yyyy'), '3', '11', '101', '04', '2029', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10695, to_date('12-04-2029', 'dd-mm-yyyy'), '4', '12', '102', '04', '2029', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10696, to_date('13-04-2029', 'dd-mm-yyyy'), '5', '13', '103', '04', '2029', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10697, to_date('14-04-2029', 'dd-mm-yyyy'), '6', '14', '104', '04', '2029', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10698, to_date('15-04-2029', 'dd-mm-yyyy'), '7', '15', '105', '04', '2029', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10699, to_date('16-04-2029', 'dd-mm-yyyy'), '1', '16', '106', '04', '2029', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10700, to_date('17-04-2029', 'dd-mm-yyyy'), '2', '17', '107', '04', '2029', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10701, to_date('18-04-2029', 'dd-mm-yyyy'), '3', '18', '108', '04', '2029', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10702, to_date('19-04-2029', 'dd-mm-yyyy'), '4', '19', '109', '04', '2029', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10703, to_date('20-04-2029', 'dd-mm-yyyy'), '5', '20', '110', '04', '2029', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10704, to_date('21-04-2029', 'dd-mm-yyyy'), '6', '21', '111', '04', '2029', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10705, to_date('22-04-2029', 'dd-mm-yyyy'), '7', '22', '112', '04', '2029', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10706, to_date('23-04-2029', 'dd-mm-yyyy'), '1', '23', '113', '04', '2029', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10707, to_date('24-04-2029', 'dd-mm-yyyy'), '2', '24', '114', '04', '2029', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10708, to_date('25-04-2029', 'dd-mm-yyyy'), '3', '25', '115', '04', '2029', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10709, to_date('26-04-2029', 'dd-mm-yyyy'), '4', '26', '116', '04', '2029', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10710, to_date('27-04-2029', 'dd-mm-yyyy'), '5', '27', '117', '04', '2029', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10711, to_date('28-04-2029', 'dd-mm-yyyy'), '6', '28', '118', '04', '2029', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10712, to_date('29-04-2029', 'dd-mm-yyyy'), '7', '29', '119', '04', '2029', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10713, to_date('30-04-2029', 'dd-mm-yyyy'), '1', '30', '120', '04', '2029', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10714, to_date('01-05-2029', 'dd-mm-yyyy'), '2', '01', '121', '05', '2029', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10715, to_date('02-05-2029', 'dd-mm-yyyy'), '3', '02', '122', '05', '2029', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10716, to_date('03-05-2029', 'dd-mm-yyyy'), '4', '03', '123', '05', '2029', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10717, to_date('04-05-2029', 'dd-mm-yyyy'), '5', '04', '124', '05', '2029', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10718, to_date('05-05-2029', 'dd-mm-yyyy'), '6', '05', '125', '05', '2029', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10719, to_date('06-05-2029', 'dd-mm-yyyy'), '7', '06', '126', '05', '2029', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10720, to_date('07-05-2029', 'dd-mm-yyyy'), '1', '07', '127', '05', '2029', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10721, to_date('08-05-2029', 'dd-mm-yyyy'), '2', '08', '128', '05', '2029', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10722, to_date('09-05-2029', 'dd-mm-yyyy'), '3', '09', '129', '05', '2029', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10723, to_date('10-05-2029', 'dd-mm-yyyy'), '4', '10', '130', '05', '2029', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10724, to_date('11-05-2029', 'dd-mm-yyyy'), '5', '11', '131', '05', '2029', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10725, to_date('12-05-2029', 'dd-mm-yyyy'), '6', '12', '132', '05', '2029', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10726, to_date('13-05-2029', 'dd-mm-yyyy'), '7', '13', '133', '05', '2029', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10727, to_date('14-05-2029', 'dd-mm-yyyy'), '1', '14', '134', '05', '2029', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10728, to_date('15-05-2029', 'dd-mm-yyyy'), '2', '15', '135', '05', '2029', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10729, to_date('16-05-2029', 'dd-mm-yyyy'), '3', '16', '136', '05', '2029', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10730, to_date('17-05-2029', 'dd-mm-yyyy'), '4', '17', '137', '05', '2029', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10731, to_date('18-05-2029', 'dd-mm-yyyy'), '5', '18', '138', '05', '2029', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10732, to_date('19-05-2029', 'dd-mm-yyyy'), '6', '19', '139', '05', '2029', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10733, to_date('20-05-2029', 'dd-mm-yyyy'), '7', '20', '140', '05', '2029', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10734, to_date('21-05-2029', 'dd-mm-yyyy'), '1', '21', '141', '05', '2029', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10735, to_date('22-05-2029', 'dd-mm-yyyy'), '2', '22', '142', '05', '2029', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10736, to_date('23-05-2029', 'dd-mm-yyyy'), '3', '23', '143', '05', '2029', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10737, to_date('24-05-2029', 'dd-mm-yyyy'), '4', '24', '144', '05', '2029', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10738, to_date('25-05-2029', 'dd-mm-yyyy'), '5', '25', '145', '05', '2029', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10739, to_date('26-05-2029', 'dd-mm-yyyy'), '6', '26', '146', '05', '2029', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10740, to_date('27-05-2029', 'dd-mm-yyyy'), '7', '27', '147', '05', '2029', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10741, to_date('28-05-2029', 'dd-mm-yyyy'), '1', '28', '148', '05', '2029', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10742, to_date('29-05-2029', 'dd-mm-yyyy'), '2', '29', '149', '05', '2029', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10743, to_date('30-05-2029', 'dd-mm-yyyy'), '3', '30', '150', '05', '2029', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10744, to_date('31-05-2029', 'dd-mm-yyyy'), '4', '31', '151', '05', '2029', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10745, to_date('01-06-2029', 'dd-mm-yyyy'), '5', '01', '152', '06', '2029', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10746, to_date('02-06-2029', 'dd-mm-yyyy'), '6', '02', '153', '06', '2029', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10747, to_date('03-06-2029', 'dd-mm-yyyy'), '7', '03', '154', '06', '2029', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10748, to_date('04-06-2029', 'dd-mm-yyyy'), '1', '04', '155', '06', '2029', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10749, to_date('05-06-2029', 'dd-mm-yyyy'), '2', '05', '156', '06', '2029', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10750, to_date('06-06-2029', 'dd-mm-yyyy'), '3', '06', '157', '06', '2029', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10751, to_date('07-06-2029', 'dd-mm-yyyy'), '4', '07', '158', '06', '2029', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10752, to_date('08-06-2029', 'dd-mm-yyyy'), '5', '08', '159', '06', '2029', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10753, to_date('09-06-2029', 'dd-mm-yyyy'), '6', '09', '160', '06', '2029', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10754, to_date('10-06-2029', 'dd-mm-yyyy'), '7', '10', '161', '06', '2029', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10755, to_date('11-06-2029', 'dd-mm-yyyy'), '1', '11', '162', '06', '2029', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10756, to_date('12-06-2029', 'dd-mm-yyyy'), '2', '12', '163', '06', '2029', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10757, to_date('13-06-2029', 'dd-mm-yyyy'), '3', '13', '164', '06', '2029', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10758, to_date('14-06-2029', 'dd-mm-yyyy'), '4', '14', '165', '06', '2029', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10759, to_date('15-06-2029', 'dd-mm-yyyy'), '5', '15', '166', '06', '2029', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10760, to_date('16-06-2029', 'dd-mm-yyyy'), '6', '16', '167', '06', '2029', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10761, to_date('17-06-2029', 'dd-mm-yyyy'), '7', '17', '168', '06', '2029', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10762, to_date('18-06-2029', 'dd-mm-yyyy'), '1', '18', '169', '06', '2029', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10763, to_date('19-06-2029', 'dd-mm-yyyy'), '2', '19', '170', '06', '2029', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10764, to_date('20-06-2029', 'dd-mm-yyyy'), '3', '20', '171', '06', '2029', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10765, to_date('21-06-2029', 'dd-mm-yyyy'), '4', '21', '172', '06', '2029', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10766, to_date('22-06-2029', 'dd-mm-yyyy'), '5', '22', '173', '06', '2029', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10767, to_date('23-06-2029', 'dd-mm-yyyy'), '6', '23', '174', '06', '2029', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10768, to_date('24-06-2029', 'dd-mm-yyyy'), '7', '24', '175', '06', '2029', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10769, to_date('25-06-2029', 'dd-mm-yyyy'), '1', '25', '176', '06', '2029', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10770, to_date('26-06-2029', 'dd-mm-yyyy'), '2', '26', '177', '06', '2029', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10771, to_date('27-06-2029', 'dd-mm-yyyy'), '3', '27', '178', '06', '2029', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10772, to_date('28-06-2029', 'dd-mm-yyyy'), '4', '28', '179', '06', '2029', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10773, to_date('29-06-2029', 'dd-mm-yyyy'), '5', '29', '180', '06', '2029', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10774, to_date('30-06-2029', 'dd-mm-yyyy'), '6', '30', '181', '06', '2029', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10775, to_date('01-07-2029', 'dd-mm-yyyy'), '7', '01', '182', '07', '2029', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10776, to_date('02-07-2029', 'dd-mm-yyyy'), '1', '02', '183', '07', '2029', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10777, to_date('03-07-2029', 'dd-mm-yyyy'), '2', '03', '184', '07', '2029', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10778, to_date('04-07-2029', 'dd-mm-yyyy'), '3', '04', '185', '07', '2029', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10779, to_date('05-07-2029', 'dd-mm-yyyy'), '4', '05', '186', '07', '2029', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10780, to_date('06-07-2029', 'dd-mm-yyyy'), '5', '06', '187', '07', '2029', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10781, to_date('07-07-2029', 'dd-mm-yyyy'), '6', '07', '188', '07', '2029', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10782, to_date('08-07-2029', 'dd-mm-yyyy'), '7', '08', '189', '07', '2029', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10783, to_date('09-07-2029', 'dd-mm-yyyy'), '1', '09', '190', '07', '2029', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10784, to_date('10-07-2029', 'dd-mm-yyyy'), '2', '10', '191', '07', '2029', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10785, to_date('11-07-2029', 'dd-mm-yyyy'), '3', '11', '192', '07', '2029', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10786, to_date('12-07-2029', 'dd-mm-yyyy'), '4', '12', '193', '07', '2029', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10787, to_date('13-07-2029', 'dd-mm-yyyy'), '5', '13', '194', '07', '2029', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10788, to_date('14-07-2029', 'dd-mm-yyyy'), '6', '14', '195', '07', '2029', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10789, to_date('15-07-2029', 'dd-mm-yyyy'), '7', '15', '196', '07', '2029', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10790, to_date('16-07-2029', 'dd-mm-yyyy'), '1', '16', '197', '07', '2029', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10791, to_date('17-07-2029', 'dd-mm-yyyy'), '2', '17', '198', '07', '2029', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10792, to_date('18-07-2029', 'dd-mm-yyyy'), '3', '18', '199', '07', '2029', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10793, to_date('19-07-2029', 'dd-mm-yyyy'), '4', '19', '200', '07', '2029', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10794, to_date('20-07-2029', 'dd-mm-yyyy'), '5', '20', '201', '07', '2029', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10795, to_date('21-07-2029', 'dd-mm-yyyy'), '6', '21', '202', '07', '2029', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10796, to_date('22-07-2029', 'dd-mm-yyyy'), '7', '22', '203', '07', '2029', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10797, to_date('23-07-2029', 'dd-mm-yyyy'), '1', '23', '204', '07', '2029', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10798, to_date('24-07-2029', 'dd-mm-yyyy'), '2', '24', '205', '07', '2029', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10799, to_date('25-07-2029', 'dd-mm-yyyy'), '3', '25', '206', '07', '2029', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10800, to_date('26-07-2029', 'dd-mm-yyyy'), '4', '26', '207', '07', '2029', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10801, to_date('27-07-2029', 'dd-mm-yyyy'), '5', '27', '208', '07', '2029', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10802, to_date('28-07-2029', 'dd-mm-yyyy'), '6', '28', '209', '07', '2029', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10803, to_date('29-07-2029', 'dd-mm-yyyy'), '7', '29', '210', '07', '2029', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10804, to_date('30-07-2029', 'dd-mm-yyyy'), '1', '30', '211', '07', '2029', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10805, to_date('31-07-2029', 'dd-mm-yyyy'), '2', '31', '212', '07', '2029', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10806, to_date('01-08-2029', 'dd-mm-yyyy'), '3', '01', '213', '08', '2029', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10807, to_date('02-08-2029', 'dd-mm-yyyy'), '4', '02', '214', '08', '2029', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10808, to_date('03-08-2029', 'dd-mm-yyyy'), '5', '03', '215', '08', '2029', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10809, to_date('04-08-2029', 'dd-mm-yyyy'), '6', '04', '216', '08', '2029', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10810, to_date('05-08-2029', 'dd-mm-yyyy'), '7', '05', '217', '08', '2029', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10811, to_date('06-08-2029', 'dd-mm-yyyy'), '1', '06', '218', '08', '2029', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10812, to_date('07-08-2029', 'dd-mm-yyyy'), '2', '07', '219', '08', '2029', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10813, to_date('08-08-2029', 'dd-mm-yyyy'), '3', '08', '220', '08', '2029', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10814, to_date('09-08-2029', 'dd-mm-yyyy'), '4', '09', '221', '08', '2029', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10815, to_date('10-08-2029', 'dd-mm-yyyy'), '5', '10', '222', '08', '2029', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10816, to_date('11-08-2029', 'dd-mm-yyyy'), '6', '11', '223', '08', '2029', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10817, to_date('12-08-2029', 'dd-mm-yyyy'), '7', '12', '224', '08', '2029', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10818, to_date('13-08-2029', 'dd-mm-yyyy'), '1', '13', '225', '08', '2029', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10819, to_date('14-08-2029', 'dd-mm-yyyy'), '2', '14', '226', '08', '2029', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10820, to_date('15-08-2029', 'dd-mm-yyyy'), '3', '15', '227', '08', '2029', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10821, to_date('16-08-2029', 'dd-mm-yyyy'), '4', '16', '228', '08', '2029', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10822, to_date('17-08-2029', 'dd-mm-yyyy'), '5', '17', '229', '08', '2029', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10823, to_date('18-08-2029', 'dd-mm-yyyy'), '6', '18', '230', '08', '2029', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10824, to_date('19-08-2029', 'dd-mm-yyyy'), '7', '19', '231', '08', '2029', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10825, to_date('20-08-2029', 'dd-mm-yyyy'), '1', '20', '232', '08', '2029', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10826, to_date('21-08-2029', 'dd-mm-yyyy'), '2', '21', '233', '08', '2029', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10827, to_date('22-08-2029', 'dd-mm-yyyy'), '3', '22', '234', '08', '2029', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10828, to_date('23-08-2029', 'dd-mm-yyyy'), '4', '23', '235', '08', '2029', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10829, to_date('24-08-2029', 'dd-mm-yyyy'), '5', '24', '236', '08', '2029', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10830, to_date('25-08-2029', 'dd-mm-yyyy'), '6', '25', '237', '08', '2029', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10831, to_date('26-08-2029', 'dd-mm-yyyy'), '7', '26', '238', '08', '2029', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10832, to_date('27-08-2029', 'dd-mm-yyyy'), '1', '27', '239', '08', '2029', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10833, to_date('28-08-2029', 'dd-mm-yyyy'), '2', '28', '240', '08', '2029', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10834, to_date('29-08-2029', 'dd-mm-yyyy'), '3', '29', '241', '08', '2029', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10835, to_date('30-08-2029', 'dd-mm-yyyy'), '4', '30', '242', '08', '2029', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10836, to_date('31-08-2029', 'dd-mm-yyyy'), '5', '31', '243', '08', '2029', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10837, to_date('01-09-2029', 'dd-mm-yyyy'), '6', '01', '244', '09', '2029', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10838, to_date('02-09-2029', 'dd-mm-yyyy'), '7', '02', '245', '09', '2029', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10839, to_date('03-09-2029', 'dd-mm-yyyy'), '1', '03', '246', '09', '2029', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10840, to_date('04-09-2029', 'dd-mm-yyyy'), '2', '04', '247', '09', '2029', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10841, to_date('05-09-2029', 'dd-mm-yyyy'), '3', '05', '248', '09', '2029', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10842, to_date('06-09-2029', 'dd-mm-yyyy'), '4', '06', '249', '09', '2029', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10843, to_date('07-09-2029', 'dd-mm-yyyy'), '5', '07', '250', '09', '2029', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10844, to_date('08-09-2029', 'dd-mm-yyyy'), '6', '08', '251', '09', '2029', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10845, to_date('09-09-2029', 'dd-mm-yyyy'), '7', '09', '252', '09', '2029', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10846, to_date('10-09-2029', 'dd-mm-yyyy'), '1', '10', '253', '09', '2029', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10847, to_date('11-09-2029', 'dd-mm-yyyy'), '2', '11', '254', '09', '2029', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10848, to_date('12-09-2029', 'dd-mm-yyyy'), '3', '12', '255', '09', '2029', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10849, to_date('13-09-2029', 'dd-mm-yyyy'), '4', '13', '256', '09', '2029', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10850, to_date('14-09-2029', 'dd-mm-yyyy'), '5', '14', '257', '09', '2029', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10851, to_date('15-09-2029', 'dd-mm-yyyy'), '6', '15', '258', '09', '2029', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10852, to_date('16-09-2029', 'dd-mm-yyyy'), '7', '16', '259', '09', '2029', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10853, to_date('17-09-2029', 'dd-mm-yyyy'), '1', '17', '260', '09', '2029', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10854, to_date('18-09-2029', 'dd-mm-yyyy'), '2', '18', '261', '09', '2029', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10855, to_date('19-09-2029', 'dd-mm-yyyy'), '3', '19', '262', '09', '2029', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10856, to_date('20-09-2029', 'dd-mm-yyyy'), '4', '20', '263', '09', '2029', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10857, to_date('21-09-2029', 'dd-mm-yyyy'), '5', '21', '264', '09', '2029', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10858, to_date('22-09-2029', 'dd-mm-yyyy'), '6', '22', '265', '09', '2029', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10859, to_date('23-09-2029', 'dd-mm-yyyy'), '7', '23', '266', '09', '2029', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10860, to_date('24-09-2029', 'dd-mm-yyyy'), '1', '24', '267', '09', '2029', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10861, to_date('25-09-2029', 'dd-mm-yyyy'), '2', '25', '268', '09', '2029', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10862, to_date('26-09-2029', 'dd-mm-yyyy'), '3', '26', '269', '09', '2029', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10863, to_date('27-09-2029', 'dd-mm-yyyy'), '4', '27', '270', '09', '2029', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10864, to_date('28-09-2029', 'dd-mm-yyyy'), '5', '28', '271', '09', '2029', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10865, to_date('29-09-2029', 'dd-mm-yyyy'), '6', '29', '272', '09', '2029', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10866, to_date('30-09-2029', 'dd-mm-yyyy'), '7', '30', '273', '09', '2029', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10867, to_date('01-10-2029', 'dd-mm-yyyy'), '1', '01', '274', '10', '2029', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10868, to_date('02-10-2029', 'dd-mm-yyyy'), '2', '02', '275', '10', '2029', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10869, to_date('03-10-2029', 'dd-mm-yyyy'), '3', '03', '276', '10', '2029', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10870, to_date('04-10-2029', 'dd-mm-yyyy'), '4', '04', '277', '10', '2029', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10871, to_date('05-10-2029', 'dd-mm-yyyy'), '5', '05', '278', '10', '2029', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10872, to_date('06-10-2029', 'dd-mm-yyyy'), '6', '06', '279', '10', '2029', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10873, to_date('07-10-2029', 'dd-mm-yyyy'), '7', '07', '280', '10', '2029', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10874, to_date('08-10-2029', 'dd-mm-yyyy'), '1', '08', '281', '10', '2029', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10875, to_date('09-10-2029', 'dd-mm-yyyy'), '2', '09', '282', '10', '2029', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10876, to_date('10-10-2029', 'dd-mm-yyyy'), '3', '10', '283', '10', '2029', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10877, to_date('11-10-2029', 'dd-mm-yyyy'), '4', '11', '284', '10', '2029', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10878, to_date('12-10-2029', 'dd-mm-yyyy'), '5', '12', '285', '10', '2029', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10879, to_date('13-10-2029', 'dd-mm-yyyy'), '6', '13', '286', '10', '2029', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10880, to_date('14-10-2029', 'dd-mm-yyyy'), '7', '14', '287', '10', '2029', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10881, to_date('15-10-2029', 'dd-mm-yyyy'), '1', '15', '288', '10', '2029', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10882, to_date('16-10-2029', 'dd-mm-yyyy'), '2', '16', '289', '10', '2029', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10883, to_date('17-10-2029', 'dd-mm-yyyy'), '3', '17', '290', '10', '2029', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10884, to_date('18-10-2029', 'dd-mm-yyyy'), '4', '18', '291', '10', '2029', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10885, to_date('19-10-2029', 'dd-mm-yyyy'), '5', '19', '292', '10', '2029', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10886, to_date('20-10-2029', 'dd-mm-yyyy'), '6', '20', '293', '10', '2029', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10887, to_date('21-10-2029', 'dd-mm-yyyy'), '7', '21', '294', '10', '2029', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10888, to_date('22-10-2029', 'dd-mm-yyyy'), '1', '22', '295', '10', '2029', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10889, to_date('23-10-2029', 'dd-mm-yyyy'), '2', '23', '296', '10', '2029', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10890, to_date('24-10-2029', 'dd-mm-yyyy'), '3', '24', '297', '10', '2029', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10891, to_date('25-10-2029', 'dd-mm-yyyy'), '4', '25', '298', '10', '2029', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10892, to_date('26-10-2029', 'dd-mm-yyyy'), '5', '26', '299', '10', '2029', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10893, to_date('27-10-2029', 'dd-mm-yyyy'), '6', '27', '300', '10', '2029', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10894, to_date('28-10-2029', 'dd-mm-yyyy'), '7', '28', '301', '10', '2029', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10895, to_date('29-10-2029', 'dd-mm-yyyy'), '1', '29', '302', '10', '2029', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10896, to_date('30-10-2029', 'dd-mm-yyyy'), '2', '30', '303', '10', '2029', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10897, to_date('31-10-2029', 'dd-mm-yyyy'), '3', '31', '304', '10', '2029', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10898, to_date('01-11-2029', 'dd-mm-yyyy'), '4', '01', '305', '11', '2029', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10899, to_date('02-11-2029', 'dd-mm-yyyy'), '5', '02', '306', '11', '2029', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10900, to_date('03-11-2029', 'dd-mm-yyyy'), '6', '03', '307', '11', '2029', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10901, to_date('04-11-2029', 'dd-mm-yyyy'), '7', '04', '308', '11', '2029', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10902, to_date('05-11-2029', 'dd-mm-yyyy'), '1', '05', '309', '11', '2029', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10903, to_date('06-11-2029', 'dd-mm-yyyy'), '2', '06', '310', '11', '2029', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10904, to_date('07-11-2029', 'dd-mm-yyyy'), '3', '07', '311', '11', '2029', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10905, to_date('08-11-2029', 'dd-mm-yyyy'), '4', '08', '312', '11', '2029', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10906, to_date('09-11-2029', 'dd-mm-yyyy'), '5', '09', '313', '11', '2029', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10907, to_date('10-11-2029', 'dd-mm-yyyy'), '6', '10', '314', '11', '2029', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10908, to_date('11-11-2029', 'dd-mm-yyyy'), '7', '11', '315', '11', '2029', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10909, to_date('12-11-2029', 'dd-mm-yyyy'), '1', '12', '316', '11', '2029', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10910, to_date('13-11-2029', 'dd-mm-yyyy'), '2', '13', '317', '11', '2029', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10911, to_date('14-11-2029', 'dd-mm-yyyy'), '3', '14', '318', '11', '2029', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10912, to_date('15-11-2029', 'dd-mm-yyyy'), '4', '15', '319', '11', '2029', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10913, to_date('16-11-2029', 'dd-mm-yyyy'), '5', '16', '320', '11', '2029', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10914, to_date('17-11-2029', 'dd-mm-yyyy'), '6', '17', '321', '11', '2029', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10915, to_date('18-11-2029', 'dd-mm-yyyy'), '7', '18', '322', '11', '2029', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10916, to_date('19-11-2029', 'dd-mm-yyyy'), '1', '19', '323', '11', '2029', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10917, to_date('20-11-2029', 'dd-mm-yyyy'), '2', '20', '324', '11', '2029', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10918, to_date('21-11-2029', 'dd-mm-yyyy'), '3', '21', '325', '11', '2029', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10919, to_date('22-11-2029', 'dd-mm-yyyy'), '4', '22', '326', '11', '2029', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10920, to_date('23-11-2029', 'dd-mm-yyyy'), '5', '23', '327', '11', '2029', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10921, to_date('24-11-2029', 'dd-mm-yyyy'), '6', '24', '328', '11', '2029', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10922, to_date('25-11-2029', 'dd-mm-yyyy'), '7', '25', '329', '11', '2029', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10923, to_date('26-11-2029', 'dd-mm-yyyy'), '1', '26', '330', '11', '2029', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10924, to_date('27-11-2029', 'dd-mm-yyyy'), '2', '27', '331', '11', '2029', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10925, to_date('28-11-2029', 'dd-mm-yyyy'), '3', '28', '332', '11', '2029', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10926, to_date('29-11-2029', 'dd-mm-yyyy'), '4', '29', '333', '11', '2029', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10927, to_date('30-11-2029', 'dd-mm-yyyy'), '5', '30', '334', '11', '2029', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10928, to_date('01-12-2029', 'dd-mm-yyyy'), '6', '01', '335', '12', '2029', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10929, to_date('02-12-2029', 'dd-mm-yyyy'), '7', '02', '336', '12', '2029', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10930, to_date('03-12-2029', 'dd-mm-yyyy'), '1', '03', '337', '12', '2029', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10931, to_date('04-12-2029', 'dd-mm-yyyy'), '2', '04', '338', '12', '2029', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10932, to_date('05-12-2029', 'dd-mm-yyyy'), '3', '05', '339', '12', '2029', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10933, to_date('06-12-2029', 'dd-mm-yyyy'), '4', '06', '340', '12', '2029', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10934, to_date('07-12-2029', 'dd-mm-yyyy'), '5', '07', '341', '12', '2029', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10935, to_date('08-12-2029', 'dd-mm-yyyy'), '6', '08', '342', '12', '2029', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10936, to_date('09-12-2029', 'dd-mm-yyyy'), '7', '09', '343', '12', '2029', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10937, to_date('10-12-2029', 'dd-mm-yyyy'), '1', '10', '344', '12', '2029', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10938, to_date('11-12-2029', 'dd-mm-yyyy'), '2', '11', '345', '12', '2029', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10939, to_date('12-12-2029', 'dd-mm-yyyy'), '3', '12', '346', '12', '2029', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10940, to_date('13-12-2029', 'dd-mm-yyyy'), '4', '13', '347', '12', '2029', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10941, to_date('14-12-2029', 'dd-mm-yyyy'), '5', '14', '348', '12', '2029', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10942, to_date('15-12-2029', 'dd-mm-yyyy'), '6', '15', '349', '12', '2029', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10943, to_date('16-12-2029', 'dd-mm-yyyy'), '7', '16', '350', '12', '2029', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10944, to_date('17-12-2029', 'dd-mm-yyyy'), '1', '17', '351', '12', '2029', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10945, to_date('18-12-2029', 'dd-mm-yyyy'), '2', '18', '352', '12', '2029', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10946, to_date('19-12-2029', 'dd-mm-yyyy'), '3', '19', '353', '12', '2029', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10947, to_date('20-12-2029', 'dd-mm-yyyy'), '4', '20', '354', '12', '2029', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10948, to_date('21-12-2029', 'dd-mm-yyyy'), '5', '21', '355', '12', '2029', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10949, to_date('22-12-2029', 'dd-mm-yyyy'), '6', '22', '356', '12', '2029', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10950, to_date('23-12-2029', 'dd-mm-yyyy'), '7', '23', '357', '12', '2029', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10951, to_date('24-12-2029', 'dd-mm-yyyy'), '1', '24', '358', '12', '2029', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10952, to_date('25-12-2029', 'dd-mm-yyyy'), '2', '25', '359', '12', '2029', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10953, to_date('26-12-2029', 'dd-mm-yyyy'), '3', '26', '360', '12', '2029', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10954, to_date('27-12-2029', 'dd-mm-yyyy'), '4', '27', '361', '12', '2029', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10955, to_date('28-12-2029', 'dd-mm-yyyy'), '5', '28', '362', '12', '2029', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10956, to_date('29-12-2029', 'dd-mm-yyyy'), '6', '29', '363', '12', '2029', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10957, to_date('30-12-2029', 'dd-mm-yyyy'), '7', '30', '364', '12', '2029', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10958, to_date('31-12-2029', 'dd-mm-yyyy'), '1', '31', '365', '12', '2029', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10959, to_date('01-01-2030', 'dd-mm-yyyy'), '2', '01', '001', '01', '2030', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10960, to_date('02-01-2030', 'dd-mm-yyyy'), '3', '02', '002', '01', '2030', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10961, to_date('03-01-2030', 'dd-mm-yyyy'), '4', '03', '003', '01', '2030', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10962, to_date('04-01-2030', 'dd-mm-yyyy'), '5', '04', '004', '01', '2030', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10963, to_date('05-01-2030', 'dd-mm-yyyy'), '6', '05', '005', '01', '2030', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10964, to_date('06-01-2030', 'dd-mm-yyyy'), '7', '06', '006', '01', '2030', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10965, to_date('07-01-2030', 'dd-mm-yyyy'), '1', '07', '007', '01', '2030', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10966, to_date('08-01-2030', 'dd-mm-yyyy'), '2', '08', '008', '01', '2030', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10967, to_date('09-01-2030', 'dd-mm-yyyy'), '3', '09', '009', '01', '2030', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10968, to_date('10-01-2030', 'dd-mm-yyyy'), '4', '10', '010', '01', '2030', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10969, to_date('11-01-2030', 'dd-mm-yyyy'), '5', '11', '011', '01', '2030', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10970, to_date('12-01-2030', 'dd-mm-yyyy'), '6', '12', '012', '01', '2030', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10971, to_date('13-01-2030', 'dd-mm-yyyy'), '7', '13', '013', '01', '2030', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10972, to_date('14-01-2030', 'dd-mm-yyyy'), '1', '14', '014', '01', '2030', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10973, to_date('15-01-2030', 'dd-mm-yyyy'), '2', '15', '015', '01', '2030', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10974, to_date('16-01-2030', 'dd-mm-yyyy'), '3', '16', '016', '01', '2030', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10975, to_date('17-01-2030', 'dd-mm-yyyy'), '4', '17', '017', '01', '2030', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10976, to_date('18-01-2030', 'dd-mm-yyyy'), '5', '18', '018', '01', '2030', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10977, to_date('19-01-2030', 'dd-mm-yyyy'), '6', '19', '019', '01', '2030', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10978, to_date('20-01-2030', 'dd-mm-yyyy'), '7', '20', '020', '01', '2030', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10979, to_date('21-01-2030', 'dd-mm-yyyy'), '1', '21', '021', '01', '2030', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10980, to_date('22-01-2030', 'dd-mm-yyyy'), '2', '22', '022', '01', '2030', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10981, to_date('23-01-2030', 'dd-mm-yyyy'), '3', '23', '023', '01', '2030', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10982, to_date('24-01-2030', 'dd-mm-yyyy'), '4', '24', '024', '01', '2030', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10983, to_date('25-01-2030', 'dd-mm-yyyy'), '5', '25', '025', '01', '2030', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10984, to_date('26-01-2030', 'dd-mm-yyyy'), '6', '26', '026', '01', '2030', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10985, to_date('27-01-2030', 'dd-mm-yyyy'), '7', '27', '027', '01', '2030', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10986, to_date('28-01-2030', 'dd-mm-yyyy'), '1', '28', '028', '01', '2030', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10987, to_date('29-01-2030', 'dd-mm-yyyy'), '2', '29', '029', '01', '2030', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10988, to_date('30-01-2030', 'dd-mm-yyyy'), '3', '30', '030', '01', '2030', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10989, to_date('31-01-2030', 'dd-mm-yyyy'), '4', '31', '031', '01', '2030', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10990, to_date('01-02-2030', 'dd-mm-yyyy'), '5', '01', '032', '02', '2030', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10991, to_date('02-02-2030', 'dd-mm-yyyy'), '6', '02', '033', '02', '2030', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10992, to_date('03-02-2030', 'dd-mm-yyyy'), '7', '03', '034', '02', '2030', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10993, to_date('04-02-2030', 'dd-mm-yyyy'), '1', '04', '035', '02', '2030', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10994, to_date('05-02-2030', 'dd-mm-yyyy'), '2', '05', '036', '02', '2030', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10995, to_date('06-02-2030', 'dd-mm-yyyy'), '3', '06', '037', '02', '2030', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10996, to_date('07-02-2030', 'dd-mm-yyyy'), '4', '07', '038', '02', '2030', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10997, to_date('08-02-2030', 'dd-mm-yyyy'), '5', '08', '039', '02', '2030', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10998, to_date('09-02-2030', 'dd-mm-yyyy'), '6', '09', '040', '02', '2030', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10257, to_date('30-01-2028', 'dd-mm-yyyy'), '7', '30', '030', '01', '2028', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10258, to_date('31-01-2028', 'dd-mm-yyyy'), '1', '31', '031', '01', '2028', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
commit;
prompt 11000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10259, to_date('01-02-2028', 'dd-mm-yyyy'), '2', '01', '032', '02', '2028', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10260, to_date('02-02-2028', 'dd-mm-yyyy'), '3', '02', '033', '02', '2028', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10261, to_date('03-02-2028', 'dd-mm-yyyy'), '4', '03', '034', '02', '2028', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10262, to_date('04-02-2028', 'dd-mm-yyyy'), '5', '04', '035', '02', '2028', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10263, to_date('05-02-2028', 'dd-mm-yyyy'), '6', '05', '036', '02', '2028', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10264, to_date('06-02-2028', 'dd-mm-yyyy'), '7', '06', '037', '02', '2028', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10265, to_date('07-02-2028', 'dd-mm-yyyy'), '1', '07', '038', '02', '2028', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10266, to_date('08-02-2028', 'dd-mm-yyyy'), '2', '08', '039', '02', '2028', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10267, to_date('09-02-2028', 'dd-mm-yyyy'), '3', '09', '040', '02', '2028', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10268, to_date('10-02-2028', 'dd-mm-yyyy'), '4', '10', '041', '02', '2028', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10269, to_date('11-02-2028', 'dd-mm-yyyy'), '5', '11', '042', '02', '2028', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10270, to_date('12-02-2028', 'dd-mm-yyyy'), '6', '12', '043', '02', '2028', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10271, to_date('13-02-2028', 'dd-mm-yyyy'), '7', '13', '044', '02', '2028', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10272, to_date('14-02-2028', 'dd-mm-yyyy'), '1', '14', '045', '02', '2028', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10273, to_date('15-02-2028', 'dd-mm-yyyy'), '2', '15', '046', '02', '2028', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10274, to_date('16-02-2028', 'dd-mm-yyyy'), '3', '16', '047', '02', '2028', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10275, to_date('17-02-2028', 'dd-mm-yyyy'), '4', '17', '048', '02', '2028', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10276, to_date('18-02-2028', 'dd-mm-yyyy'), '5', '18', '049', '02', '2028', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10277, to_date('19-02-2028', 'dd-mm-yyyy'), '6', '19', '050', '02', '2028', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10278, to_date('20-02-2028', 'dd-mm-yyyy'), '7', '20', '051', '02', '2028', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10279, to_date('21-02-2028', 'dd-mm-yyyy'), '1', '21', '052', '02', '2028', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10280, to_date('22-02-2028', 'dd-mm-yyyy'), '2', '22', '053', '02', '2028', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10281, to_date('23-02-2028', 'dd-mm-yyyy'), '3', '23', '054', '02', '2028', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10282, to_date('24-02-2028', 'dd-mm-yyyy'), '4', '24', '055', '02', '2028', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10283, to_date('25-02-2028', 'dd-mm-yyyy'), '5', '25', '056', '02', '2028', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10284, to_date('26-02-2028', 'dd-mm-yyyy'), '6', '26', '057', '02', '2028', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10285, to_date('27-02-2028', 'dd-mm-yyyy'), '7', '27', '058', '02', '2028', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10286, to_date('28-02-2028', 'dd-mm-yyyy'), '1', '28', '059', '02', '2028', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10287, to_date('29-02-2028', 'dd-mm-yyyy'), '2', '29', '060', '02', '2028', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10288, to_date('01-03-2028', 'dd-mm-yyyy'), '3', '01', '061', '03', '2028', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10289, to_date('02-03-2028', 'dd-mm-yyyy'), '4', '02', '062', '03', '2028', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10290, to_date('03-03-2028', 'dd-mm-yyyy'), '5', '03', '063', '03', '2028', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10291, to_date('04-03-2028', 'dd-mm-yyyy'), '6', '04', '064', '03', '2028', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10292, to_date('05-03-2028', 'dd-mm-yyyy'), '7', '05', '065', '03', '2028', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10293, to_date('06-03-2028', 'dd-mm-yyyy'), '1', '06', '066', '03', '2028', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10294, to_date('07-03-2028', 'dd-mm-yyyy'), '2', '07', '067', '03', '2028', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10295, to_date('08-03-2028', 'dd-mm-yyyy'), '3', '08', '068', '03', '2028', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10296, to_date('09-03-2028', 'dd-mm-yyyy'), '4', '09', '069', '03', '2028', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10297, to_date('10-03-2028', 'dd-mm-yyyy'), '5', '10', '070', '03', '2028', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10298, to_date('11-03-2028', 'dd-mm-yyyy'), '6', '11', '071', '03', '2028', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10299, to_date('12-03-2028', 'dd-mm-yyyy'), '7', '12', '072', '03', '2028', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10300, to_date('13-03-2028', 'dd-mm-yyyy'), '1', '13', '073', '03', '2028', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10301, to_date('14-03-2028', 'dd-mm-yyyy'), '2', '14', '074', '03', '2028', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10302, to_date('15-03-2028', 'dd-mm-yyyy'), '3', '15', '075', '03', '2028', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10303, to_date('16-03-2028', 'dd-mm-yyyy'), '4', '16', '076', '03', '2028', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10304, to_date('17-03-2028', 'dd-mm-yyyy'), '5', '17', '077', '03', '2028', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10305, to_date('18-03-2028', 'dd-mm-yyyy'), '6', '18', '078', '03', '2028', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10306, to_date('19-03-2028', 'dd-mm-yyyy'), '7', '19', '079', '03', '2028', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10307, to_date('20-03-2028', 'dd-mm-yyyy'), '1', '20', '080', '03', '2028', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10308, to_date('21-03-2028', 'dd-mm-yyyy'), '2', '21', '081', '03', '2028', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10309, to_date('22-03-2028', 'dd-mm-yyyy'), '3', '22', '082', '03', '2028', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10310, to_date('23-03-2028', 'dd-mm-yyyy'), '4', '23', '083', '03', '2028', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10311, to_date('24-03-2028', 'dd-mm-yyyy'), '5', '24', '084', '03', '2028', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10312, to_date('25-03-2028', 'dd-mm-yyyy'), '6', '25', '085', '03', '2028', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10313, to_date('26-03-2028', 'dd-mm-yyyy'), '7', '26', '086', '03', '2028', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10314, to_date('27-03-2028', 'dd-mm-yyyy'), '1', '27', '087', '03', '2028', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10315, to_date('28-03-2028', 'dd-mm-yyyy'), '2', '28', '088', '03', '2028', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10316, to_date('29-03-2028', 'dd-mm-yyyy'), '3', '29', '089', '03', '2028', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10317, to_date('30-03-2028', 'dd-mm-yyyy'), '4', '30', '090', '03', '2028', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10318, to_date('31-03-2028', 'dd-mm-yyyy'), '5', '31', '091', '03', '2028', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10319, to_date('01-04-2028', 'dd-mm-yyyy'), '6', '01', '092', '04', '2028', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10320, to_date('02-04-2028', 'dd-mm-yyyy'), '7', '02', '093', '04', '2028', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10321, to_date('03-04-2028', 'dd-mm-yyyy'), '1', '03', '094', '04', '2028', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10322, to_date('04-04-2028', 'dd-mm-yyyy'), '2', '04', '095', '04', '2028', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10323, to_date('05-04-2028', 'dd-mm-yyyy'), '3', '05', '096', '04', '2028', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10324, to_date('06-04-2028', 'dd-mm-yyyy'), '4', '06', '097', '04', '2028', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10325, to_date('07-04-2028', 'dd-mm-yyyy'), '5', '07', '098', '04', '2028', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10326, to_date('08-04-2028', 'dd-mm-yyyy'), '6', '08', '099', '04', '2028', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10327, to_date('09-04-2028', 'dd-mm-yyyy'), '7', '09', '100', '04', '2028', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10328, to_date('10-04-2028', 'dd-mm-yyyy'), '1', '10', '101', '04', '2028', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10329, to_date('11-04-2028', 'dd-mm-yyyy'), '2', '11', '102', '04', '2028', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10330, to_date('12-04-2028', 'dd-mm-yyyy'), '3', '12', '103', '04', '2028', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10331, to_date('13-04-2028', 'dd-mm-yyyy'), '4', '13', '104', '04', '2028', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10332, to_date('14-04-2028', 'dd-mm-yyyy'), '5', '14', '105', '04', '2028', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10333, to_date('15-04-2028', 'dd-mm-yyyy'), '6', '15', '106', '04', '2028', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10334, to_date('16-04-2028', 'dd-mm-yyyy'), '7', '16', '107', '04', '2028', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10335, to_date('17-04-2028', 'dd-mm-yyyy'), '1', '17', '108', '04', '2028', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10336, to_date('18-04-2028', 'dd-mm-yyyy'), '2', '18', '109', '04', '2028', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10337, to_date('19-04-2028', 'dd-mm-yyyy'), '3', '19', '110', '04', '2028', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10338, to_date('20-04-2028', 'dd-mm-yyyy'), '4', '20', '111', '04', '2028', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10339, to_date('21-04-2028', 'dd-mm-yyyy'), '5', '21', '112', '04', '2028', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10340, to_date('22-04-2028', 'dd-mm-yyyy'), '6', '22', '113', '04', '2028', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10341, to_date('23-04-2028', 'dd-mm-yyyy'), '7', '23', '114', '04', '2028', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10342, to_date('24-04-2028', 'dd-mm-yyyy'), '1', '24', '115', '04', '2028', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10343, to_date('25-04-2028', 'dd-mm-yyyy'), '2', '25', '116', '04', '2028', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10344, to_date('26-04-2028', 'dd-mm-yyyy'), '3', '26', '117', '04', '2028', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10345, to_date('27-04-2028', 'dd-mm-yyyy'), '4', '27', '118', '04', '2028', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10346, to_date('28-04-2028', 'dd-mm-yyyy'), '5', '28', '119', '04', '2028', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10347, to_date('29-04-2028', 'dd-mm-yyyy'), '6', '29', '120', '04', '2028', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10348, to_date('30-04-2028', 'dd-mm-yyyy'), '7', '30', '121', '04', '2028', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10349, to_date('01-05-2028', 'dd-mm-yyyy'), '1', '01', '122', '05', '2028', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10350, to_date('02-05-2028', 'dd-mm-yyyy'), '2', '02', '123', '05', '2028', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10351, to_date('03-05-2028', 'dd-mm-yyyy'), '3', '03', '124', '05', '2028', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10352, to_date('04-05-2028', 'dd-mm-yyyy'), '4', '04', '125', '05', '2028', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10353, to_date('05-05-2028', 'dd-mm-yyyy'), '5', '05', '126', '05', '2028', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10354, to_date('06-05-2028', 'dd-mm-yyyy'), '6', '06', '127', '05', '2028', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10355, to_date('07-05-2028', 'dd-mm-yyyy'), '7', '07', '128', '05', '2028', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10356, to_date('08-05-2028', 'dd-mm-yyyy'), '1', '08', '129', '05', '2028', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10357, to_date('09-05-2028', 'dd-mm-yyyy'), '2', '09', '130', '05', '2028', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10358, to_date('10-05-2028', 'dd-mm-yyyy'), '3', '10', '131', '05', '2028', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10359, to_date('11-05-2028', 'dd-mm-yyyy'), '4', '11', '132', '05', '2028', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10360, to_date('12-05-2028', 'dd-mm-yyyy'), '5', '12', '133', '05', '2028', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10361, to_date('13-05-2028', 'dd-mm-yyyy'), '6', '13', '134', '05', '2028', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (10362, to_date('14-05-2028', 'dd-mm-yyyy'), '7', '14', '135', '05', '2028', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11105, to_date('27-05-2030', 'dd-mm-yyyy'), '1', '27', '147', '05', '2030', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11106, to_date('28-05-2030', 'dd-mm-yyyy'), '2', '28', '148', '05', '2030', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11107, to_date('29-05-2030', 'dd-mm-yyyy'), '3', '29', '149', '05', '2030', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11108, to_date('30-05-2030', 'dd-mm-yyyy'), '4', '30', '150', '05', '2030', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11109, to_date('31-05-2030', 'dd-mm-yyyy'), '5', '31', '151', '05', '2030', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11110, to_date('01-06-2030', 'dd-mm-yyyy'), '6', '01', '152', '06', '2030', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11111, to_date('02-06-2030', 'dd-mm-yyyy'), '7', '02', '153', '06', '2030', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11112, to_date('03-06-2030', 'dd-mm-yyyy'), '1', '03', '154', '06', '2030', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11113, to_date('04-06-2030', 'dd-mm-yyyy'), '2', '04', '155', '06', '2030', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11114, to_date('05-06-2030', 'dd-mm-yyyy'), '3', '05', '156', '06', '2030', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11115, to_date('06-06-2030', 'dd-mm-yyyy'), '4', '06', '157', '06', '2030', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11116, to_date('07-06-2030', 'dd-mm-yyyy'), '5', '07', '158', '06', '2030', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11117, to_date('08-06-2030', 'dd-mm-yyyy'), '6', '08', '159', '06', '2030', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11118, to_date('09-06-2030', 'dd-mm-yyyy'), '7', '09', '160', '06', '2030', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11119, to_date('10-06-2030', 'dd-mm-yyyy'), '1', '10', '161', '06', '2030', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11120, to_date('11-06-2030', 'dd-mm-yyyy'), '2', '11', '162', '06', '2030', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11121, to_date('12-06-2030', 'dd-mm-yyyy'), '3', '12', '163', '06', '2030', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11122, to_date('13-06-2030', 'dd-mm-yyyy'), '4', '13', '164', '06', '2030', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11123, to_date('14-06-2030', 'dd-mm-yyyy'), '5', '14', '165', '06', '2030', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11124, to_date('15-06-2030', 'dd-mm-yyyy'), '6', '15', '166', '06', '2030', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11125, to_date('16-06-2030', 'dd-mm-yyyy'), '7', '16', '167', '06', '2030', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11126, to_date('17-06-2030', 'dd-mm-yyyy'), '1', '17', '168', '06', '2030', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11127, to_date('18-06-2030', 'dd-mm-yyyy'), '2', '18', '169', '06', '2030', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11128, to_date('19-06-2030', 'dd-mm-yyyy'), '3', '19', '170', '06', '2030', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11129, to_date('20-06-2030', 'dd-mm-yyyy'), '4', '20', '171', '06', '2030', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11130, to_date('21-06-2030', 'dd-mm-yyyy'), '5', '21', '172', '06', '2030', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11131, to_date('22-06-2030', 'dd-mm-yyyy'), '6', '22', '173', '06', '2030', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11132, to_date('23-06-2030', 'dd-mm-yyyy'), '7', '23', '174', '06', '2030', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11133, to_date('24-06-2030', 'dd-mm-yyyy'), '1', '24', '175', '06', '2030', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11134, to_date('25-06-2030', 'dd-mm-yyyy'), '2', '25', '176', '06', '2030', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11135, to_date('26-06-2030', 'dd-mm-yyyy'), '3', '26', '177', '06', '2030', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11136, to_date('27-06-2030', 'dd-mm-yyyy'), '4', '27', '178', '06', '2030', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11137, to_date('28-06-2030', 'dd-mm-yyyy'), '5', '28', '179', '06', '2030', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11138, to_date('29-06-2030', 'dd-mm-yyyy'), '6', '29', '180', '06', '2030', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11139, to_date('30-06-2030', 'dd-mm-yyyy'), '7', '30', '181', '06', '2030', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11140, to_date('01-07-2030', 'dd-mm-yyyy'), '1', '01', '182', '07', '2030', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11141, to_date('02-07-2030', 'dd-mm-yyyy'), '2', '02', '183', '07', '2030', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11142, to_date('03-07-2030', 'dd-mm-yyyy'), '3', '03', '184', '07', '2030', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11143, to_date('04-07-2030', 'dd-mm-yyyy'), '4', '04', '185', '07', '2030', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11144, to_date('05-07-2030', 'dd-mm-yyyy'), '5', '05', '186', '07', '2030', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11145, to_date('06-07-2030', 'dd-mm-yyyy'), '6', '06', '187', '07', '2030', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11146, to_date('07-07-2030', 'dd-mm-yyyy'), '7', '07', '188', '07', '2030', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11147, to_date('08-07-2030', 'dd-mm-yyyy'), '1', '08', '189', '07', '2030', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11148, to_date('09-07-2030', 'dd-mm-yyyy'), '2', '09', '190', '07', '2030', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11149, to_date('10-07-2030', 'dd-mm-yyyy'), '3', '10', '191', '07', '2030', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11150, to_date('11-07-2030', 'dd-mm-yyyy'), '4', '11', '192', '07', '2030', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11151, to_date('12-07-2030', 'dd-mm-yyyy'), '5', '12', '193', '07', '2030', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11152, to_date('13-07-2030', 'dd-mm-yyyy'), '6', '13', '194', '07', '2030', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11153, to_date('14-07-2030', 'dd-mm-yyyy'), '7', '14', '195', '07', '2030', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11154, to_date('15-07-2030', 'dd-mm-yyyy'), '1', '15', '196', '07', '2030', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11155, to_date('16-07-2030', 'dd-mm-yyyy'), '2', '16', '197', '07', '2030', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11156, to_date('17-07-2030', 'dd-mm-yyyy'), '3', '17', '198', '07', '2030', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11157, to_date('18-07-2030', 'dd-mm-yyyy'), '4', '18', '199', '07', '2030', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11158, to_date('19-07-2030', 'dd-mm-yyyy'), '5', '19', '200', '07', '2030', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11159, to_date('20-07-2030', 'dd-mm-yyyy'), '6', '20', '201', '07', '2030', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11160, to_date('21-07-2030', 'dd-mm-yyyy'), '7', '21', '202', '07', '2030', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11161, to_date('22-07-2030', 'dd-mm-yyyy'), '1', '22', '203', '07', '2030', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11162, to_date('23-07-2030', 'dd-mm-yyyy'), '2', '23', '204', '07', '2030', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11163, to_date('24-07-2030', 'dd-mm-yyyy'), '3', '24', '205', '07', '2030', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11164, to_date('25-07-2030', 'dd-mm-yyyy'), '4', '25', '206', '07', '2030', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11165, to_date('26-07-2030', 'dd-mm-yyyy'), '5', '26', '207', '07', '2030', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11166, to_date('27-07-2030', 'dd-mm-yyyy'), '6', '27', '208', '07', '2030', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11167, to_date('28-07-2030', 'dd-mm-yyyy'), '7', '28', '209', '07', '2030', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11168, to_date('29-07-2030', 'dd-mm-yyyy'), '1', '29', '210', '07', '2030', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11169, to_date('30-07-2030', 'dd-mm-yyyy'), '2', '30', '211', '07', '2030', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11170, to_date('31-07-2030', 'dd-mm-yyyy'), '3', '31', '212', '07', '2030', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11171, to_date('01-08-2030', 'dd-mm-yyyy'), '4', '01', '213', '08', '2030', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11172, to_date('02-08-2030', 'dd-mm-yyyy'), '5', '02', '214', '08', '2030', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11173, to_date('03-08-2030', 'dd-mm-yyyy'), '6', '03', '215', '08', '2030', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11174, to_date('04-08-2030', 'dd-mm-yyyy'), '7', '04', '216', '08', '2030', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11175, to_date('05-08-2030', 'dd-mm-yyyy'), '1', '05', '217', '08', '2030', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11176, to_date('06-08-2030', 'dd-mm-yyyy'), '2', '06', '218', '08', '2030', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11177, to_date('07-08-2030', 'dd-mm-yyyy'), '3', '07', '219', '08', '2030', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11178, to_date('08-08-2030', 'dd-mm-yyyy'), '4', '08', '220', '08', '2030', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11179, to_date('09-08-2030', 'dd-mm-yyyy'), '5', '09', '221', '08', '2030', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11180, to_date('10-08-2030', 'dd-mm-yyyy'), '6', '10', '222', '08', '2030', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11181, to_date('11-08-2030', 'dd-mm-yyyy'), '7', '11', '223', '08', '2030', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11182, to_date('12-08-2030', 'dd-mm-yyyy'), '1', '12', '224', '08', '2030', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11183, to_date('13-08-2030', 'dd-mm-yyyy'), '2', '13', '225', '08', '2030', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11184, to_date('14-08-2030', 'dd-mm-yyyy'), '3', '14', '226', '08', '2030', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11185, to_date('15-08-2030', 'dd-mm-yyyy'), '4', '15', '227', '08', '2030', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11186, to_date('16-08-2030', 'dd-mm-yyyy'), '5', '16', '228', '08', '2030', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11187, to_date('17-08-2030', 'dd-mm-yyyy'), '6', '17', '229', '08', '2030', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11188, to_date('18-08-2030', 'dd-mm-yyyy'), '7', '18', '230', '08', '2030', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11189, to_date('19-08-2030', 'dd-mm-yyyy'), '1', '19', '231', '08', '2030', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11190, to_date('20-08-2030', 'dd-mm-yyyy'), '2', '20', '232', '08', '2030', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11191, to_date('21-08-2030', 'dd-mm-yyyy'), '3', '21', '233', '08', '2030', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11192, to_date('22-08-2030', 'dd-mm-yyyy'), '4', '22', '234', '08', '2030', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11193, to_date('23-08-2030', 'dd-mm-yyyy'), '5', '23', '235', '08', '2030', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11194, to_date('24-08-2030', 'dd-mm-yyyy'), '6', '24', '236', '08', '2030', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11195, to_date('25-08-2030', 'dd-mm-yyyy'), '7', '25', '237', '08', '2030', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11196, to_date('26-08-2030', 'dd-mm-yyyy'), '1', '26', '238', '08', '2030', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11197, to_date('27-08-2030', 'dd-mm-yyyy'), '2', '27', '239', '08', '2030', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11198, to_date('28-08-2030', 'dd-mm-yyyy'), '3', '28', '240', '08', '2030', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11199, to_date('29-08-2030', 'dd-mm-yyyy'), '4', '29', '241', '08', '2030', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11200, to_date('30-08-2030', 'dd-mm-yyyy'), '5', '30', '242', '08', '2030', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11201, to_date('31-08-2030', 'dd-mm-yyyy'), '6', '31', '243', '08', '2030', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11202, to_date('01-09-2030', 'dd-mm-yyyy'), '7', '01', '244', '09', '2030', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11203, to_date('02-09-2030', 'dd-mm-yyyy'), '1', '02', '245', '09', '2030', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11204, to_date('03-09-2030', 'dd-mm-yyyy'), '2', '03', '246', '09', '2030', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11205, to_date('04-09-2030', 'dd-mm-yyyy'), '3', '04', '247', '09', '2030', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11206, to_date('05-09-2030', 'dd-mm-yyyy'), '4', '05', '248', '09', '2030', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11207, to_date('06-09-2030', 'dd-mm-yyyy'), '5', '06', '249', '09', '2030', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11208, to_date('07-09-2030', 'dd-mm-yyyy'), '6', '07', '250', '09', '2030', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11209, to_date('08-09-2030', 'dd-mm-yyyy'), '7', '08', '251', '09', '2030', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11210, to_date('09-09-2030', 'dd-mm-yyyy'), '1', '09', '252', '09', '2030', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11741, to_date('22-02-2032', 'dd-mm-yyyy'), '7', '22', '053', '02', '2032', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11742, to_date('23-02-2032', 'dd-mm-yyyy'), '1', '23', '054', '02', '2032', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11743, to_date('24-02-2032', 'dd-mm-yyyy'), '2', '24', '055', '02', '2032', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11744, to_date('25-02-2032', 'dd-mm-yyyy'), '3', '25', '056', '02', '2032', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11745, to_date('26-02-2032', 'dd-mm-yyyy'), '4', '26', '057', '02', '2032', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11746, to_date('27-02-2032', 'dd-mm-yyyy'), '5', '27', '058', '02', '2032', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11747, to_date('28-02-2032', 'dd-mm-yyyy'), '6', '28', '059', '02', '2032', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11748, to_date('29-02-2032', 'dd-mm-yyyy'), '7', '29', '060', '02', '2032', '09', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11749, to_date('01-03-2032', 'dd-mm-yyyy'), '1', '01', '061', '03', '2032', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11750, to_date('02-03-2032', 'dd-mm-yyyy'), '2', '02', '062', '03', '2032', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11751, to_date('03-03-2032', 'dd-mm-yyyy'), '3', '03', '063', '03', '2032', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11752, to_date('04-03-2032', 'dd-mm-yyyy'), '4', '04', '064', '03', '2032', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11753, to_date('05-03-2032', 'dd-mm-yyyy'), '5', '05', '065', '03', '2032', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11754, to_date('06-03-2032', 'dd-mm-yyyy'), '6', '06', '066', '03', '2032', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11755, to_date('07-03-2032', 'dd-mm-yyyy'), '7', '07', '067', '03', '2032', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11756, to_date('08-03-2032', 'dd-mm-yyyy'), '1', '08', '068', '03', '2032', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11757, to_date('09-03-2032', 'dd-mm-yyyy'), '2', '09', '069', '03', '2032', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11758, to_date('10-03-2032', 'dd-mm-yyyy'), '3', '10', '070', '03', '2032', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11759, to_date('11-03-2032', 'dd-mm-yyyy'), '4', '11', '071', '03', '2032', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11760, to_date('12-03-2032', 'dd-mm-yyyy'), '5', '12', '072', '03', '2032', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11761, to_date('13-03-2032', 'dd-mm-yyyy'), '6', '13', '073', '03', '2032', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11762, to_date('14-03-2032', 'dd-mm-yyyy'), '7', '14', '074', '03', '2032', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11763, to_date('15-03-2032', 'dd-mm-yyyy'), '1', '15', '075', '03', '2032', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11764, to_date('16-03-2032', 'dd-mm-yyyy'), '2', '16', '076', '03', '2032', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11765, to_date('17-03-2032', 'dd-mm-yyyy'), '3', '17', '077', '03', '2032', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11766, to_date('18-03-2032', 'dd-mm-yyyy'), '4', '18', '078', '03', '2032', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11767, to_date('19-03-2032', 'dd-mm-yyyy'), '5', '19', '079', '03', '2032', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11768, to_date('20-03-2032', 'dd-mm-yyyy'), '6', '20', '080', '03', '2032', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11769, to_date('21-03-2032', 'dd-mm-yyyy'), '7', '21', '081', '03', '2032', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11770, to_date('22-03-2032', 'dd-mm-yyyy'), '1', '22', '082', '03', '2032', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11771, to_date('23-03-2032', 'dd-mm-yyyy'), '2', '23', '083', '03', '2032', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11772, to_date('24-03-2032', 'dd-mm-yyyy'), '3', '24', '084', '03', '2032', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11773, to_date('25-03-2032', 'dd-mm-yyyy'), '4', '25', '085', '03', '2032', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11774, to_date('26-03-2032', 'dd-mm-yyyy'), '5', '26', '086', '03', '2032', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11775, to_date('27-03-2032', 'dd-mm-yyyy'), '6', '27', '087', '03', '2032', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11776, to_date('28-03-2032', 'dd-mm-yyyy'), '7', '28', '088', '03', '2032', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11777, to_date('29-03-2032', 'dd-mm-yyyy'), '1', '29', '089', '03', '2032', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11778, to_date('30-03-2032', 'dd-mm-yyyy'), '2', '30', '090', '03', '2032', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11779, to_date('31-03-2032', 'dd-mm-yyyy'), '3', '31', '091', '03', '2032', '14', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11780, to_date('01-04-2032', 'dd-mm-yyyy'), '4', '01', '092', '04', '2032', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11781, to_date('02-04-2032', 'dd-mm-yyyy'), '5', '02', '093', '04', '2032', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11782, to_date('03-04-2032', 'dd-mm-yyyy'), '6', '03', '094', '04', '2032', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11783, to_date('04-04-2032', 'dd-mm-yyyy'), '7', '04', '095', '04', '2032', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11784, to_date('05-04-2032', 'dd-mm-yyyy'), '1', '05', '096', '04', '2032', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11785, to_date('06-04-2032', 'dd-mm-yyyy'), '2', '06', '097', '04', '2032', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11786, to_date('07-04-2032', 'dd-mm-yyyy'), '3', '07', '098', '04', '2032', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11787, to_date('08-04-2032', 'dd-mm-yyyy'), '4', '08', '099', '04', '2032', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11788, to_date('09-04-2032', 'dd-mm-yyyy'), '5', '09', '100', '04', '2032', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11789, to_date('10-04-2032', 'dd-mm-yyyy'), '6', '10', '101', '04', '2032', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11790, to_date('11-04-2032', 'dd-mm-yyyy'), '7', '11', '102', '04', '2032', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11791, to_date('12-04-2032', 'dd-mm-yyyy'), '1', '12', '103', '04', '2032', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11792, to_date('13-04-2032', 'dd-mm-yyyy'), '2', '13', '104', '04', '2032', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11793, to_date('14-04-2032', 'dd-mm-yyyy'), '3', '14', '105', '04', '2032', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11794, to_date('15-04-2032', 'dd-mm-yyyy'), '4', '15', '106', '04', '2032', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11795, to_date('16-04-2032', 'dd-mm-yyyy'), '5', '16', '107', '04', '2032', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11796, to_date('17-04-2032', 'dd-mm-yyyy'), '6', '17', '108', '04', '2032', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11797, to_date('18-04-2032', 'dd-mm-yyyy'), '7', '18', '109', '04', '2032', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11798, to_date('19-04-2032', 'dd-mm-yyyy'), '1', '19', '110', '04', '2032', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11799, to_date('20-04-2032', 'dd-mm-yyyy'), '2', '20', '111', '04', '2032', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11800, to_date('21-04-2032', 'dd-mm-yyyy'), '3', '21', '112', '04', '2032', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11801, to_date('22-04-2032', 'dd-mm-yyyy'), '4', '22', '113', '04', '2032', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11802, to_date('23-04-2032', 'dd-mm-yyyy'), '5', '23', '114', '04', '2032', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11803, to_date('24-04-2032', 'dd-mm-yyyy'), '6', '24', '115', '04', '2032', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11804, to_date('25-04-2032', 'dd-mm-yyyy'), '7', '25', '116', '04', '2032', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11805, to_date('26-04-2032', 'dd-mm-yyyy'), '1', '26', '117', '04', '2032', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11806, to_date('27-04-2032', 'dd-mm-yyyy'), '2', '27', '118', '04', '2032', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11807, to_date('28-04-2032', 'dd-mm-yyyy'), '3', '28', '119', '04', '2032', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11808, to_date('29-04-2032', 'dd-mm-yyyy'), '4', '29', '120', '04', '2032', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11809, to_date('30-04-2032', 'dd-mm-yyyy'), '5', '30', '121', '04', '2032', '18', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11810, to_date('01-05-2032', 'dd-mm-yyyy'), '6', '01', '122', '05', '2032', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11811, to_date('02-05-2032', 'dd-mm-yyyy'), '7', '02', '123', '05', '2032', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11812, to_date('03-05-2032', 'dd-mm-yyyy'), '1', '03', '124', '05', '2032', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11813, to_date('04-05-2032', 'dd-mm-yyyy'), '2', '04', '125', '05', '2032', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11814, to_date('05-05-2032', 'dd-mm-yyyy'), '3', '05', '126', '05', '2032', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11815, to_date('06-05-2032', 'dd-mm-yyyy'), '4', '06', '127', '05', '2032', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11816, to_date('07-05-2032', 'dd-mm-yyyy'), '5', '07', '128', '05', '2032', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11817, to_date('08-05-2032', 'dd-mm-yyyy'), '6', '08', '129', '05', '2032', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11818, to_date('09-05-2032', 'dd-mm-yyyy'), '7', '09', '130', '05', '2032', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11819, to_date('10-05-2032', 'dd-mm-yyyy'), '1', '10', '131', '05', '2032', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11820, to_date('11-05-2032', 'dd-mm-yyyy'), '2', '11', '132', '05', '2032', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11821, to_date('12-05-2032', 'dd-mm-yyyy'), '3', '12', '133', '05', '2032', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11822, to_date('13-05-2032', 'dd-mm-yyyy'), '4', '13', '134', '05', '2032', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11823, to_date('14-05-2032', 'dd-mm-yyyy'), '5', '14', '135', '05', '2032', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11824, to_date('15-05-2032', 'dd-mm-yyyy'), '6', '15', '136', '05', '2032', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11825, to_date('16-05-2032', 'dd-mm-yyyy'), '7', '16', '137', '05', '2032', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11826, to_date('17-05-2032', 'dd-mm-yyyy'), '1', '17', '138', '05', '2032', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11827, to_date('18-05-2032', 'dd-mm-yyyy'), '2', '18', '139', '05', '2032', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11828, to_date('19-05-2032', 'dd-mm-yyyy'), '3', '19', '140', '05', '2032', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11829, to_date('20-05-2032', 'dd-mm-yyyy'), '4', '20', '141', '05', '2032', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11830, to_date('21-05-2032', 'dd-mm-yyyy'), '5', '21', '142', '05', '2032', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11831, to_date('22-05-2032', 'dd-mm-yyyy'), '6', '22', '143', '05', '2032', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11832, to_date('23-05-2032', 'dd-mm-yyyy'), '7', '23', '144', '05', '2032', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11833, to_date('24-05-2032', 'dd-mm-yyyy'), '1', '24', '145', '05', '2032', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11834, to_date('25-05-2032', 'dd-mm-yyyy'), '2', '25', '146', '05', '2032', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11835, to_date('26-05-2032', 'dd-mm-yyyy'), '3', '26', '147', '05', '2032', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11836, to_date('27-05-2032', 'dd-mm-yyyy'), '4', '27', '148', '05', '2032', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11837, to_date('28-05-2032', 'dd-mm-yyyy'), '5', '28', '149', '05', '2032', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11838, to_date('29-05-2032', 'dd-mm-yyyy'), '6', '29', '150', '05', '2032', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11839, to_date('30-05-2032', 'dd-mm-yyyy'), '7', '30', '151', '05', '2032', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11840, to_date('31-05-2032', 'dd-mm-yyyy'), '1', '31', '152', '05', '2032', '23', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11841, to_date('01-06-2032', 'dd-mm-yyyy'), '2', '01', '153', '06', '2032', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11842, to_date('02-06-2032', 'dd-mm-yyyy'), '3', '02', '154', '06', '2032', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11843, to_date('03-06-2032', 'dd-mm-yyyy'), '4', '03', '155', '06', '2032', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11844, to_date('04-06-2032', 'dd-mm-yyyy'), '5', '04', '156', '06', '2032', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11845, to_date('05-06-2032', 'dd-mm-yyyy'), '6', '05', '157', '06', '2032', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11846, to_date('06-06-2032', 'dd-mm-yyyy'), '7', '06', '158', '06', '2032', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11211, to_date('10-09-2030', 'dd-mm-yyyy'), '2', '10', '253', '09', '2030', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11212, to_date('11-09-2030', 'dd-mm-yyyy'), '3', '11', '254', '09', '2030', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11213, to_date('12-09-2030', 'dd-mm-yyyy'), '4', '12', '255', '09', '2030', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11214, to_date('13-09-2030', 'dd-mm-yyyy'), '5', '13', '256', '09', '2030', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11215, to_date('14-09-2030', 'dd-mm-yyyy'), '6', '14', '257', '09', '2030', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11216, to_date('15-09-2030', 'dd-mm-yyyy'), '7', '15', '258', '09', '2030', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11217, to_date('16-09-2030', 'dd-mm-yyyy'), '1', '16', '259', '09', '2030', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11218, to_date('17-09-2030', 'dd-mm-yyyy'), '2', '17', '260', '09', '2030', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11219, to_date('18-09-2030', 'dd-mm-yyyy'), '3', '18', '261', '09', '2030', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11220, to_date('19-09-2030', 'dd-mm-yyyy'), '4', '19', '262', '09', '2030', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11221, to_date('20-09-2030', 'dd-mm-yyyy'), '5', '20', '263', '09', '2030', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11222, to_date('21-09-2030', 'dd-mm-yyyy'), '6', '21', '264', '09', '2030', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11223, to_date('22-09-2030', 'dd-mm-yyyy'), '7', '22', '265', '09', '2030', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11224, to_date('23-09-2030', 'dd-mm-yyyy'), '1', '23', '266', '09', '2030', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11225, to_date('24-09-2030', 'dd-mm-yyyy'), '2', '24', '267', '09', '2030', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11226, to_date('25-09-2030', 'dd-mm-yyyy'), '3', '25', '268', '09', '2030', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11227, to_date('26-09-2030', 'dd-mm-yyyy'), '4', '26', '269', '09', '2030', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11228, to_date('27-09-2030', 'dd-mm-yyyy'), '5', '27', '270', '09', '2030', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11229, to_date('28-09-2030', 'dd-mm-yyyy'), '6', '28', '271', '09', '2030', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11230, to_date('29-09-2030', 'dd-mm-yyyy'), '7', '29', '272', '09', '2030', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11231, to_date('30-09-2030', 'dd-mm-yyyy'), '1', '30', '273', '09', '2030', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11232, to_date('01-10-2030', 'dd-mm-yyyy'), '2', '01', '274', '10', '2030', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11233, to_date('02-10-2030', 'dd-mm-yyyy'), '3', '02', '275', '10', '2030', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11234, to_date('03-10-2030', 'dd-mm-yyyy'), '4', '03', '276', '10', '2030', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11235, to_date('04-10-2030', 'dd-mm-yyyy'), '5', '04', '277', '10', '2030', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11236, to_date('05-10-2030', 'dd-mm-yyyy'), '6', '05', '278', '10', '2030', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11237, to_date('06-10-2030', 'dd-mm-yyyy'), '7', '06', '279', '10', '2030', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11238, to_date('07-10-2030', 'dd-mm-yyyy'), '1', '07', '280', '10', '2030', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11239, to_date('08-10-2030', 'dd-mm-yyyy'), '2', '08', '281', '10', '2030', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11240, to_date('09-10-2030', 'dd-mm-yyyy'), '3', '09', '282', '10', '2030', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11241, to_date('10-10-2030', 'dd-mm-yyyy'), '4', '10', '283', '10', '2030', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11242, to_date('11-10-2030', 'dd-mm-yyyy'), '5', '11', '284', '10', '2030', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11243, to_date('12-10-2030', 'dd-mm-yyyy'), '6', '12', '285', '10', '2030', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11244, to_date('13-10-2030', 'dd-mm-yyyy'), '7', '13', '286', '10', '2030', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11245, to_date('14-10-2030', 'dd-mm-yyyy'), '1', '14', '287', '10', '2030', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11246, to_date('15-10-2030', 'dd-mm-yyyy'), '2', '15', '288', '10', '2030', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11247, to_date('16-10-2030', 'dd-mm-yyyy'), '3', '16', '289', '10', '2030', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11248, to_date('17-10-2030', 'dd-mm-yyyy'), '4', '17', '290', '10', '2030', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11249, to_date('18-10-2030', 'dd-mm-yyyy'), '5', '18', '291', '10', '2030', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11250, to_date('19-10-2030', 'dd-mm-yyyy'), '6', '19', '292', '10', '2030', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11251, to_date('20-10-2030', 'dd-mm-yyyy'), '7', '20', '293', '10', '2030', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11252, to_date('21-10-2030', 'dd-mm-yyyy'), '1', '21', '294', '10', '2030', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11253, to_date('22-10-2030', 'dd-mm-yyyy'), '2', '22', '295', '10', '2030', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11254, to_date('23-10-2030', 'dd-mm-yyyy'), '3', '23', '296', '10', '2030', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11255, to_date('24-10-2030', 'dd-mm-yyyy'), '4', '24', '297', '10', '2030', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11256, to_date('25-10-2030', 'dd-mm-yyyy'), '5', '25', '298', '10', '2030', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11257, to_date('26-10-2030', 'dd-mm-yyyy'), '6', '26', '299', '10', '2030', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11258, to_date('27-10-2030', 'dd-mm-yyyy'), '7', '27', '300', '10', '2030', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11259, to_date('28-10-2030', 'dd-mm-yyyy'), '1', '28', '301', '10', '2030', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11260, to_date('29-10-2030', 'dd-mm-yyyy'), '2', '29', '302', '10', '2030', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11261, to_date('30-10-2030', 'dd-mm-yyyy'), '3', '30', '303', '10', '2030', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11262, to_date('31-10-2030', 'dd-mm-yyyy'), '4', '31', '304', '10', '2030', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11263, to_date('01-11-2030', 'dd-mm-yyyy'), '5', '01', '305', '11', '2030', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11264, to_date('02-11-2030', 'dd-mm-yyyy'), '6', '02', '306', '11', '2030', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11265, to_date('03-11-2030', 'dd-mm-yyyy'), '7', '03', '307', '11', '2030', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11266, to_date('04-11-2030', 'dd-mm-yyyy'), '1', '04', '308', '11', '2030', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11267, to_date('05-11-2030', 'dd-mm-yyyy'), '2', '05', '309', '11', '2030', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11268, to_date('06-11-2030', 'dd-mm-yyyy'), '3', '06', '310', '11', '2030', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11269, to_date('07-11-2030', 'dd-mm-yyyy'), '4', '07', '311', '11', '2030', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11270, to_date('08-11-2030', 'dd-mm-yyyy'), '5', '08', '312', '11', '2030', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11271, to_date('09-11-2030', 'dd-mm-yyyy'), '6', '09', '313', '11', '2030', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11272, to_date('10-11-2030', 'dd-mm-yyyy'), '7', '10', '314', '11', '2030', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11273, to_date('11-11-2030', 'dd-mm-yyyy'), '1', '11', '315', '11', '2030', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11274, to_date('12-11-2030', 'dd-mm-yyyy'), '2', '12', '316', '11', '2030', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11275, to_date('13-11-2030', 'dd-mm-yyyy'), '3', '13', '317', '11', '2030', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11276, to_date('14-11-2030', 'dd-mm-yyyy'), '4', '14', '318', '11', '2030', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11277, to_date('15-11-2030', 'dd-mm-yyyy'), '5', '15', '319', '11', '2030', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11278, to_date('16-11-2030', 'dd-mm-yyyy'), '6', '16', '320', '11', '2030', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11279, to_date('17-11-2030', 'dd-mm-yyyy'), '7', '17', '321', '11', '2030', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11280, to_date('18-11-2030', 'dd-mm-yyyy'), '1', '18', '322', '11', '2030', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11281, to_date('19-11-2030', 'dd-mm-yyyy'), '2', '19', '323', '11', '2030', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11282, to_date('20-11-2030', 'dd-mm-yyyy'), '3', '20', '324', '11', '2030', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11283, to_date('21-11-2030', 'dd-mm-yyyy'), '4', '21', '325', '11', '2030', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11284, to_date('22-11-2030', 'dd-mm-yyyy'), '5', '22', '326', '11', '2030', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11285, to_date('23-11-2030', 'dd-mm-yyyy'), '6', '23', '327', '11', '2030', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11286, to_date('24-11-2030', 'dd-mm-yyyy'), '7', '24', '328', '11', '2030', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11287, to_date('25-11-2030', 'dd-mm-yyyy'), '1', '25', '329', '11', '2030', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11288, to_date('26-11-2030', 'dd-mm-yyyy'), '2', '26', '330', '11', '2030', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11289, to_date('27-11-2030', 'dd-mm-yyyy'), '3', '27', '331', '11', '2030', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11290, to_date('28-11-2030', 'dd-mm-yyyy'), '4', '28', '332', '11', '2030', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11291, to_date('29-11-2030', 'dd-mm-yyyy'), '5', '29', '333', '11', '2030', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11292, to_date('30-11-2030', 'dd-mm-yyyy'), '6', '30', '334', '11', '2030', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11293, to_date('01-12-2030', 'dd-mm-yyyy'), '7', '01', '335', '12', '2030', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11294, to_date('02-12-2030', 'dd-mm-yyyy'), '1', '02', '336', '12', '2030', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11295, to_date('03-12-2030', 'dd-mm-yyyy'), '2', '03', '337', '12', '2030', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11296, to_date('04-12-2030', 'dd-mm-yyyy'), '3', '04', '338', '12', '2030', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11297, to_date('05-12-2030', 'dd-mm-yyyy'), '4', '05', '339', '12', '2030', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11298, to_date('06-12-2030', 'dd-mm-yyyy'), '5', '06', '340', '12', '2030', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11299, to_date('07-12-2030', 'dd-mm-yyyy'), '6', '07', '341', '12', '2030', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11300, to_date('08-12-2030', 'dd-mm-yyyy'), '7', '08', '342', '12', '2030', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11301, to_date('09-12-2030', 'dd-mm-yyyy'), '1', '09', '343', '12', '2030', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11302, to_date('10-12-2030', 'dd-mm-yyyy'), '2', '10', '344', '12', '2030', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11303, to_date('11-12-2030', 'dd-mm-yyyy'), '3', '11', '345', '12', '2030', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11304, to_date('12-12-2030', 'dd-mm-yyyy'), '4', '12', '346', '12', '2030', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11305, to_date('13-12-2030', 'dd-mm-yyyy'), '5', '13', '347', '12', '2030', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11306, to_date('14-12-2030', 'dd-mm-yyyy'), '6', '14', '348', '12', '2030', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11307, to_date('15-12-2030', 'dd-mm-yyyy'), '7', '15', '349', '12', '2030', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11308, to_date('16-12-2030', 'dd-mm-yyyy'), '1', '16', '350', '12', '2030', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11309, to_date('17-12-2030', 'dd-mm-yyyy'), '2', '17', '351', '12', '2030', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11310, to_date('18-12-2030', 'dd-mm-yyyy'), '3', '18', '352', '12', '2030', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11311, to_date('19-12-2030', 'dd-mm-yyyy'), '4', '19', '353', '12', '2030', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11312, to_date('20-12-2030', 'dd-mm-yyyy'), '5', '20', '354', '12', '2030', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11313, to_date('21-12-2030', 'dd-mm-yyyy'), '6', '21', '355', '12', '2030', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11314, to_date('22-12-2030', 'dd-mm-yyyy'), '7', '22', '356', '12', '2030', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11315, to_date('23-12-2030', 'dd-mm-yyyy'), '1', '23', '357', '12', '2030', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11316, to_date('24-12-2030', 'dd-mm-yyyy'), '2', '24', '358', '12', '2030', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11317, to_date('25-12-2030', 'dd-mm-yyyy'), '3', '25', '359', '12', '2030', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11318, to_date('26-12-2030', 'dd-mm-yyyy'), '4', '26', '360', '12', '2030', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11319, to_date('27-12-2030', 'dd-mm-yyyy'), '5', '27', '361', '12', '2030', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11320, to_date('28-12-2030', 'dd-mm-yyyy'), '6', '28', '362', '12', '2030', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11321, to_date('29-12-2030', 'dd-mm-yyyy'), '7', '29', '363', '12', '2030', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11322, to_date('30-12-2030', 'dd-mm-yyyy'), '1', '30', '364', '12', '2030', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11323, to_date('31-12-2030', 'dd-mm-yyyy'), '2', '31', '365', '12', '2030', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11324, to_date('01-01-2031', 'dd-mm-yyyy'), '3', '01', '001', '01', '2031', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11325, to_date('02-01-2031', 'dd-mm-yyyy'), '4', '02', '002', '01', '2031', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11326, to_date('03-01-2031', 'dd-mm-yyyy'), '5', '03', '003', '01', '2031', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11327, to_date('04-01-2031', 'dd-mm-yyyy'), '6', '04', '004', '01', '2031', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11328, to_date('05-01-2031', 'dd-mm-yyyy'), '7', '05', '005', '01', '2031', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11329, to_date('06-01-2031', 'dd-mm-yyyy'), '1', '06', '006', '01', '2031', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11330, to_date('07-01-2031', 'dd-mm-yyyy'), '2', '07', '007', '01', '2031', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11331, to_date('08-01-2031', 'dd-mm-yyyy'), '3', '08', '008', '01', '2031', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11332, to_date('09-01-2031', 'dd-mm-yyyy'), '4', '09', '009', '01', '2031', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11333, to_date('10-01-2031', 'dd-mm-yyyy'), '5', '10', '010', '01', '2031', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11334, to_date('11-01-2031', 'dd-mm-yyyy'), '6', '11', '011', '01', '2031', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11335, to_date('12-01-2031', 'dd-mm-yyyy'), '7', '12', '012', '01', '2031', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11336, to_date('13-01-2031', 'dd-mm-yyyy'), '1', '13', '013', '01', '2031', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11337, to_date('14-01-2031', 'dd-mm-yyyy'), '2', '14', '014', '01', '2031', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11338, to_date('15-01-2031', 'dd-mm-yyyy'), '3', '15', '015', '01', '2031', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11339, to_date('16-01-2031', 'dd-mm-yyyy'), '4', '16', '016', '01', '2031', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11340, to_date('17-01-2031', 'dd-mm-yyyy'), '5', '17', '017', '01', '2031', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11341, to_date('18-01-2031', 'dd-mm-yyyy'), '6', '18', '018', '01', '2031', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11342, to_date('19-01-2031', 'dd-mm-yyyy'), '7', '19', '019', '01', '2031', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11343, to_date('20-01-2031', 'dd-mm-yyyy'), '1', '20', '020', '01', '2031', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11344, to_date('21-01-2031', 'dd-mm-yyyy'), '2', '21', '021', '01', '2031', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11345, to_date('22-01-2031', 'dd-mm-yyyy'), '3', '22', '022', '01', '2031', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11346, to_date('23-01-2031', 'dd-mm-yyyy'), '4', '23', '023', '01', '2031', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11347, to_date('24-01-2031', 'dd-mm-yyyy'), '5', '24', '024', '01', '2031', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11348, to_date('25-01-2031', 'dd-mm-yyyy'), '6', '25', '025', '01', '2031', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11349, to_date('26-01-2031', 'dd-mm-yyyy'), '7', '26', '026', '01', '2031', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11350, to_date('27-01-2031', 'dd-mm-yyyy'), '1', '27', '027', '01', '2031', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11351, to_date('28-01-2031', 'dd-mm-yyyy'), '2', '28', '028', '01', '2031', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11352, to_date('29-01-2031', 'dd-mm-yyyy'), '3', '29', '029', '01', '2031', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11353, to_date('30-01-2031', 'dd-mm-yyyy'), '4', '30', '030', '01', '2031', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11354, to_date('31-01-2031', 'dd-mm-yyyy'), '5', '31', '031', '01', '2031', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11355, to_date('01-02-2031', 'dd-mm-yyyy'), '6', '01', '032', '02', '2031', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11356, to_date('02-02-2031', 'dd-mm-yyyy'), '7', '02', '033', '02', '2031', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11357, to_date('03-02-2031', 'dd-mm-yyyy'), '1', '03', '034', '02', '2031', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11358, to_date('04-02-2031', 'dd-mm-yyyy'), '2', '04', '035', '02', '2031', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11359, to_date('05-02-2031', 'dd-mm-yyyy'), '3', '05', '036', '02', '2031', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11360, to_date('06-02-2031', 'dd-mm-yyyy'), '4', '06', '037', '02', '2031', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11361, to_date('07-02-2031', 'dd-mm-yyyy'), '5', '07', '038', '02', '2031', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11362, to_date('08-02-2031', 'dd-mm-yyyy'), '6', '08', '039', '02', '2031', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11363, to_date('09-02-2031', 'dd-mm-yyyy'), '7', '09', '040', '02', '2031', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11364, to_date('10-02-2031', 'dd-mm-yyyy'), '1', '10', '041', '02', '2031', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11365, to_date('11-02-2031', 'dd-mm-yyyy'), '2', '11', '042', '02', '2031', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11366, to_date('12-02-2031', 'dd-mm-yyyy'), '3', '12', '043', '02', '2031', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11367, to_date('13-02-2031', 'dd-mm-yyyy'), '4', '13', '044', '02', '2031', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11368, to_date('14-02-2031', 'dd-mm-yyyy'), '5', '14', '045', '02', '2031', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11369, to_date('15-02-2031', 'dd-mm-yyyy'), '6', '15', '046', '02', '2031', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11370, to_date('16-02-2031', 'dd-mm-yyyy'), '7', '16', '047', '02', '2031', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11371, to_date('17-02-2031', 'dd-mm-yyyy'), '1', '17', '048', '02', '2031', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11372, to_date('18-02-2031', 'dd-mm-yyyy'), '2', '18', '049', '02', '2031', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11373, to_date('19-02-2031', 'dd-mm-yyyy'), '3', '19', '050', '02', '2031', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11374, to_date('20-02-2031', 'dd-mm-yyyy'), '4', '20', '051', '02', '2031', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11375, to_date('21-02-2031', 'dd-mm-yyyy'), '5', '21', '052', '02', '2031', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11376, to_date('22-02-2031', 'dd-mm-yyyy'), '6', '22', '053', '02', '2031', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11377, to_date('23-02-2031', 'dd-mm-yyyy'), '7', '23', '054', '02', '2031', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11378, to_date('24-02-2031', 'dd-mm-yyyy'), '1', '24', '055', '02', '2031', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11379, to_date('25-02-2031', 'dd-mm-yyyy'), '2', '25', '056', '02', '2031', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11380, to_date('26-02-2031', 'dd-mm-yyyy'), '3', '26', '057', '02', '2031', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11381, to_date('27-02-2031', 'dd-mm-yyyy'), '4', '27', '058', '02', '2031', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11382, to_date('28-02-2031', 'dd-mm-yyyy'), '5', '28', '059', '02', '2031', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11383, to_date('01-03-2031', 'dd-mm-yyyy'), '6', '01', '060', '03', '2031', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11384, to_date('02-03-2031', 'dd-mm-yyyy'), '7', '02', '061', '03', '2031', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11385, to_date('03-03-2031', 'dd-mm-yyyy'), '1', '03', '062', '03', '2031', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11386, to_date('04-03-2031', 'dd-mm-yyyy'), '2', '04', '063', '03', '2031', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11387, to_date('05-03-2031', 'dd-mm-yyyy'), '3', '05', '064', '03', '2031', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11388, to_date('06-03-2031', 'dd-mm-yyyy'), '4', '06', '065', '03', '2031', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11389, to_date('07-03-2031', 'dd-mm-yyyy'), '5', '07', '066', '03', '2031', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11390, to_date('08-03-2031', 'dd-mm-yyyy'), '6', '08', '067', '03', '2031', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11391, to_date('09-03-2031', 'dd-mm-yyyy'), '7', '09', '068', '03', '2031', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11392, to_date('10-03-2031', 'dd-mm-yyyy'), '1', '10', '069', '03', '2031', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11393, to_date('11-03-2031', 'dd-mm-yyyy'), '2', '11', '070', '03', '2031', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11394, to_date('12-03-2031', 'dd-mm-yyyy'), '3', '12', '071', '03', '2031', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11395, to_date('13-03-2031', 'dd-mm-yyyy'), '4', '13', '072', '03', '2031', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11396, to_date('14-03-2031', 'dd-mm-yyyy'), '5', '14', '073', '03', '2031', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11397, to_date('15-03-2031', 'dd-mm-yyyy'), '6', '15', '074', '03', '2031', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11398, to_date('16-03-2031', 'dd-mm-yyyy'), '7', '16', '075', '03', '2031', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11399, to_date('17-03-2031', 'dd-mm-yyyy'), '1', '17', '076', '03', '2031', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11400, to_date('18-03-2031', 'dd-mm-yyyy'), '2', '18', '077', '03', '2031', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11401, to_date('19-03-2031', 'dd-mm-yyyy'), '3', '19', '078', '03', '2031', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11402, to_date('20-03-2031', 'dd-mm-yyyy'), '4', '20', '079', '03', '2031', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11403, to_date('21-03-2031', 'dd-mm-yyyy'), '5', '21', '080', '03', '2031', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11404, to_date('22-03-2031', 'dd-mm-yyyy'), '6', '22', '081', '03', '2031', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11405, to_date('23-03-2031', 'dd-mm-yyyy'), '7', '23', '082', '03', '2031', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11406, to_date('24-03-2031', 'dd-mm-yyyy'), '1', '24', '083', '03', '2031', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11407, to_date('25-03-2031', 'dd-mm-yyyy'), '2', '25', '084', '03', '2031', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11408, to_date('26-03-2031', 'dd-mm-yyyy'), '3', '26', '085', '03', '2031', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11409, to_date('27-03-2031', 'dd-mm-yyyy'), '4', '27', '086', '03', '2031', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11410, to_date('28-03-2031', 'dd-mm-yyyy'), '5', '28', '087', '03', '2031', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11411, to_date('29-03-2031', 'dd-mm-yyyy'), '6', '29', '088', '03', '2031', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11412, to_date('30-03-2031', 'dd-mm-yyyy'), '7', '30', '089', '03', '2031', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11413, to_date('31-03-2031', 'dd-mm-yyyy'), '1', '31', '090', '03', '2031', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11414, to_date('01-04-2031', 'dd-mm-yyyy'), '2', '01', '091', '04', '2031', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11415, to_date('02-04-2031', 'dd-mm-yyyy'), '3', '02', '092', '04', '2031', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11416, to_date('03-04-2031', 'dd-mm-yyyy'), '4', '03', '093', '04', '2031', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11417, to_date('04-04-2031', 'dd-mm-yyyy'), '5', '04', '094', '04', '2031', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11418, to_date('05-04-2031', 'dd-mm-yyyy'), '6', '05', '095', '04', '2031', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11419, to_date('06-04-2031', 'dd-mm-yyyy'), '7', '06', '096', '04', '2031', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11420, to_date('07-04-2031', 'dd-mm-yyyy'), '1', '07', '097', '04', '2031', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11421, to_date('08-04-2031', 'dd-mm-yyyy'), '2', '08', '098', '04', '2031', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11422, to_date('09-04-2031', 'dd-mm-yyyy'), '3', '09', '099', '04', '2031', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11423, to_date('10-04-2031', 'dd-mm-yyyy'), '4', '10', '100', '04', '2031', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11424, to_date('11-04-2031', 'dd-mm-yyyy'), '5', '11', '101', '04', '2031', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11425, to_date('12-04-2031', 'dd-mm-yyyy'), '6', '12', '102', '04', '2031', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11426, to_date('13-04-2031', 'dd-mm-yyyy'), '7', '13', '103', '04', '2031', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11427, to_date('14-04-2031', 'dd-mm-yyyy'), '1', '14', '104', '04', '2031', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11428, to_date('15-04-2031', 'dd-mm-yyyy'), '2', '15', '105', '04', '2031', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11429, to_date('16-04-2031', 'dd-mm-yyyy'), '3', '16', '106', '04', '2031', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11430, to_date('17-04-2031', 'dd-mm-yyyy'), '4', '17', '107', '04', '2031', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11431, to_date('18-04-2031', 'dd-mm-yyyy'), '5', '18', '108', '04', '2031', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11432, to_date('19-04-2031', 'dd-mm-yyyy'), '6', '19', '109', '04', '2031', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11433, to_date('20-04-2031', 'dd-mm-yyyy'), '7', '20', '110', '04', '2031', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11434, to_date('21-04-2031', 'dd-mm-yyyy'), '1', '21', '111', '04', '2031', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11435, to_date('22-04-2031', 'dd-mm-yyyy'), '2', '22', '112', '04', '2031', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11436, to_date('23-04-2031', 'dd-mm-yyyy'), '3', '23', '113', '04', '2031', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11437, to_date('24-04-2031', 'dd-mm-yyyy'), '4', '24', '114', '04', '2031', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11438, to_date('25-04-2031', 'dd-mm-yyyy'), '5', '25', '115', '04', '2031', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11439, to_date('26-04-2031', 'dd-mm-yyyy'), '6', '26', '116', '04', '2031', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11440, to_date('27-04-2031', 'dd-mm-yyyy'), '7', '27', '117', '04', '2031', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11441, to_date('28-04-2031', 'dd-mm-yyyy'), '1', '28', '118', '04', '2031', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11442, to_date('29-04-2031', 'dd-mm-yyyy'), '2', '29', '119', '04', '2031', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11443, to_date('30-04-2031', 'dd-mm-yyyy'), '3', '30', '120', '04', '2031', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11444, to_date('01-05-2031', 'dd-mm-yyyy'), '4', '01', '121', '05', '2031', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11445, to_date('02-05-2031', 'dd-mm-yyyy'), '5', '02', '122', '05', '2031', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11446, to_date('03-05-2031', 'dd-mm-yyyy'), '6', '03', '123', '05', '2031', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11447, to_date('04-05-2031', 'dd-mm-yyyy'), '7', '04', '124', '05', '2031', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11448, to_date('05-05-2031', 'dd-mm-yyyy'), '1', '05', '125', '05', '2031', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11449, to_date('06-05-2031', 'dd-mm-yyyy'), '2', '06', '126', '05', '2031', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11450, to_date('07-05-2031', 'dd-mm-yyyy'), '3', '07', '127', '05', '2031', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11451, to_date('08-05-2031', 'dd-mm-yyyy'), '4', '08', '128', '05', '2031', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11452, to_date('09-05-2031', 'dd-mm-yyyy'), '5', '09', '129', '05', '2031', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11453, to_date('10-05-2031', 'dd-mm-yyyy'), '6', '10', '130', '05', '2031', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11454, to_date('11-05-2031', 'dd-mm-yyyy'), '7', '11', '131', '05', '2031', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11455, to_date('12-05-2031', 'dd-mm-yyyy'), '1', '12', '132', '05', '2031', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11456, to_date('13-05-2031', 'dd-mm-yyyy'), '2', '13', '133', '05', '2031', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11457, to_date('14-05-2031', 'dd-mm-yyyy'), '3', '14', '134', '05', '2031', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11458, to_date('15-05-2031', 'dd-mm-yyyy'), '4', '15', '135', '05', '2031', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11459, to_date('16-05-2031', 'dd-mm-yyyy'), '5', '16', '136', '05', '2031', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11460, to_date('17-05-2031', 'dd-mm-yyyy'), '6', '17', '137', '05', '2031', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11461, to_date('18-05-2031', 'dd-mm-yyyy'), '7', '18', '138', '05', '2031', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11462, to_date('19-05-2031', 'dd-mm-yyyy'), '1', '19', '139', '05', '2031', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11463, to_date('20-05-2031', 'dd-mm-yyyy'), '2', '20', '140', '05', '2031', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11464, to_date('21-05-2031', 'dd-mm-yyyy'), '3', '21', '141', '05', '2031', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11465, to_date('22-05-2031', 'dd-mm-yyyy'), '4', '22', '142', '05', '2031', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11466, to_date('23-05-2031', 'dd-mm-yyyy'), '5', '23', '143', '05', '2031', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11467, to_date('24-05-2031', 'dd-mm-yyyy'), '6', '24', '144', '05', '2031', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11468, to_date('25-05-2031', 'dd-mm-yyyy'), '7', '25', '145', '05', '2031', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11469, to_date('26-05-2031', 'dd-mm-yyyy'), '1', '26', '146', '05', '2031', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11470, to_date('27-05-2031', 'dd-mm-yyyy'), '2', '27', '147', '05', '2031', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11471, to_date('28-05-2031', 'dd-mm-yyyy'), '3', '28', '148', '05', '2031', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11472, to_date('29-05-2031', 'dd-mm-yyyy'), '4', '29', '149', '05', '2031', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11473, to_date('30-05-2031', 'dd-mm-yyyy'), '5', '30', '150', '05', '2031', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11474, to_date('31-05-2031', 'dd-mm-yyyy'), '6', '31', '151', '05', '2031', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11475, to_date('01-06-2031', 'dd-mm-yyyy'), '7', '01', '152', '06', '2031', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11476, to_date('02-06-2031', 'dd-mm-yyyy'), '1', '02', '153', '06', '2031', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11477, to_date('03-06-2031', 'dd-mm-yyyy'), '2', '03', '154', '06', '2031', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11478, to_date('04-06-2031', 'dd-mm-yyyy'), '3', '04', '155', '06', '2031', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11479, to_date('05-06-2031', 'dd-mm-yyyy'), '4', '05', '156', '06', '2031', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11480, to_date('06-06-2031', 'dd-mm-yyyy'), '5', '06', '157', '06', '2031', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11481, to_date('07-06-2031', 'dd-mm-yyyy'), '6', '07', '158', '06', '2031', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11482, to_date('08-06-2031', 'dd-mm-yyyy'), '7', '08', '159', '06', '2031', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11483, to_date('09-06-2031', 'dd-mm-yyyy'), '1', '09', '160', '06', '2031', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11484, to_date('10-06-2031', 'dd-mm-yyyy'), '2', '10', '161', '06', '2031', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11485, to_date('11-06-2031', 'dd-mm-yyyy'), '3', '11', '162', '06', '2031', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11486, to_date('12-06-2031', 'dd-mm-yyyy'), '4', '12', '163', '06', '2031', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11487, to_date('13-06-2031', 'dd-mm-yyyy'), '5', '13', '164', '06', '2031', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11488, to_date('14-06-2031', 'dd-mm-yyyy'), '6', '14', '165', '06', '2031', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11489, to_date('15-06-2031', 'dd-mm-yyyy'), '7', '15', '166', '06', '2031', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11490, to_date('16-06-2031', 'dd-mm-yyyy'), '1', '16', '167', '06', '2031', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11491, to_date('17-06-2031', 'dd-mm-yyyy'), '2', '17', '168', '06', '2031', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11492, to_date('18-06-2031', 'dd-mm-yyyy'), '3', '18', '169', '06', '2031', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11493, to_date('19-06-2031', 'dd-mm-yyyy'), '4', '19', '170', '06', '2031', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11494, to_date('20-06-2031', 'dd-mm-yyyy'), '5', '20', '171', '06', '2031', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11495, to_date('21-06-2031', 'dd-mm-yyyy'), '6', '21', '172', '06', '2031', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11496, to_date('22-06-2031', 'dd-mm-yyyy'), '7', '22', '173', '06', '2031', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11497, to_date('23-06-2031', 'dd-mm-yyyy'), '1', '23', '174', '06', '2031', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11498, to_date('24-06-2031', 'dd-mm-yyyy'), '2', '24', '175', '06', '2031', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11499, to_date('25-06-2031', 'dd-mm-yyyy'), '3', '25', '176', '06', '2031', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11500, to_date('26-06-2031', 'dd-mm-yyyy'), '4', '26', '177', '06', '2031', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11501, to_date('27-06-2031', 'dd-mm-yyyy'), '5', '27', '178', '06', '2031', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11502, to_date('28-06-2031', 'dd-mm-yyyy'), '6', '28', '179', '06', '2031', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11503, to_date('29-06-2031', 'dd-mm-yyyy'), '7', '29', '180', '06', '2031', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11504, to_date('30-06-2031', 'dd-mm-yyyy'), '1', '30', '181', '06', '2031', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11505, to_date('01-07-2031', 'dd-mm-yyyy'), '2', '01', '182', '07', '2031', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11506, to_date('02-07-2031', 'dd-mm-yyyy'), '3', '02', '183', '07', '2031', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11507, to_date('03-07-2031', 'dd-mm-yyyy'), '4', '03', '184', '07', '2031', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11508, to_date('04-07-2031', 'dd-mm-yyyy'), '5', '04', '185', '07', '2031', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11509, to_date('05-07-2031', 'dd-mm-yyyy'), '6', '05', '186', '07', '2031', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11510, to_date('06-07-2031', 'dd-mm-yyyy'), '7', '06', '187', '07', '2031', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11511, to_date('07-07-2031', 'dd-mm-yyyy'), '1', '07', '188', '07', '2031', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11512, to_date('08-07-2031', 'dd-mm-yyyy'), '2', '08', '189', '07', '2031', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11513, to_date('09-07-2031', 'dd-mm-yyyy'), '3', '09', '190', '07', '2031', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11514, to_date('10-07-2031', 'dd-mm-yyyy'), '4', '10', '191', '07', '2031', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11515, to_date('11-07-2031', 'dd-mm-yyyy'), '5', '11', '192', '07', '2031', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11516, to_date('12-07-2031', 'dd-mm-yyyy'), '6', '12', '193', '07', '2031', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11517, to_date('13-07-2031', 'dd-mm-yyyy'), '7', '13', '194', '07', '2031', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11518, to_date('14-07-2031', 'dd-mm-yyyy'), '1', '14', '195', '07', '2031', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11519, to_date('15-07-2031', 'dd-mm-yyyy'), '2', '15', '196', '07', '2031', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11520, to_date('16-07-2031', 'dd-mm-yyyy'), '3', '16', '197', '07', '2031', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11521, to_date('17-07-2031', 'dd-mm-yyyy'), '4', '17', '198', '07', '2031', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11522, to_date('18-07-2031', 'dd-mm-yyyy'), '5', '18', '199', '07', '2031', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11523, to_date('19-07-2031', 'dd-mm-yyyy'), '6', '19', '200', '07', '2031', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11524, to_date('20-07-2031', 'dd-mm-yyyy'), '7', '20', '201', '07', '2031', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11525, to_date('21-07-2031', 'dd-mm-yyyy'), '1', '21', '202', '07', '2031', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11526, to_date('22-07-2031', 'dd-mm-yyyy'), '2', '22', '203', '07', '2031', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11527, to_date('23-07-2031', 'dd-mm-yyyy'), '3', '23', '204', '07', '2031', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11528, to_date('24-07-2031', 'dd-mm-yyyy'), '4', '24', '205', '07', '2031', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11529, to_date('25-07-2031', 'dd-mm-yyyy'), '5', '25', '206', '07', '2031', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11530, to_date('26-07-2031', 'dd-mm-yyyy'), '6', '26', '207', '07', '2031', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11531, to_date('27-07-2031', 'dd-mm-yyyy'), '7', '27', '208', '07', '2031', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11532, to_date('28-07-2031', 'dd-mm-yyyy'), '1', '28', '209', '07', '2031', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11533, to_date('29-07-2031', 'dd-mm-yyyy'), '2', '29', '210', '07', '2031', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11534, to_date('30-07-2031', 'dd-mm-yyyy'), '3', '30', '211', '07', '2031', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11535, to_date('31-07-2031', 'dd-mm-yyyy'), '4', '31', '212', '07', '2031', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11536, to_date('01-08-2031', 'dd-mm-yyyy'), '5', '01', '213', '08', '2031', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11537, to_date('02-08-2031', 'dd-mm-yyyy'), '6', '02', '214', '08', '2031', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11538, to_date('03-08-2031', 'dd-mm-yyyy'), '7', '03', '215', '08', '2031', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11539, to_date('04-08-2031', 'dd-mm-yyyy'), '1', '04', '216', '08', '2031', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11540, to_date('05-08-2031', 'dd-mm-yyyy'), '2', '05', '217', '08', '2031', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11541, to_date('06-08-2031', 'dd-mm-yyyy'), '3', '06', '218', '08', '2031', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11542, to_date('07-08-2031', 'dd-mm-yyyy'), '4', '07', '219', '08', '2031', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11543, to_date('08-08-2031', 'dd-mm-yyyy'), '5', '08', '220', '08', '2031', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11544, to_date('09-08-2031', 'dd-mm-yyyy'), '6', '09', '221', '08', '2031', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11545, to_date('10-08-2031', 'dd-mm-yyyy'), '7', '10', '222', '08', '2031', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11546, to_date('11-08-2031', 'dd-mm-yyyy'), '1', '11', '223', '08', '2031', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11547, to_date('12-08-2031', 'dd-mm-yyyy'), '2', '12', '224', '08', '2031', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11548, to_date('13-08-2031', 'dd-mm-yyyy'), '3', '13', '225', '08', '2031', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11549, to_date('14-08-2031', 'dd-mm-yyyy'), '4', '14', '226', '08', '2031', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11550, to_date('15-08-2031', 'dd-mm-yyyy'), '5', '15', '227', '08', '2031', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11551, to_date('16-08-2031', 'dd-mm-yyyy'), '6', '16', '228', '08', '2031', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11552, to_date('17-08-2031', 'dd-mm-yyyy'), '7', '17', '229', '08', '2031', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11553, to_date('18-08-2031', 'dd-mm-yyyy'), '1', '18', '230', '08', '2031', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11554, to_date('19-08-2031', 'dd-mm-yyyy'), '2', '19', '231', '08', '2031', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11555, to_date('20-08-2031', 'dd-mm-yyyy'), '3', '20', '232', '08', '2031', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11556, to_date('21-08-2031', 'dd-mm-yyyy'), '4', '21', '233', '08', '2031', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11557, to_date('22-08-2031', 'dd-mm-yyyy'), '5', '22', '234', '08', '2031', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11558, to_date('23-08-2031', 'dd-mm-yyyy'), '6', '23', '235', '08', '2031', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11559, to_date('24-08-2031', 'dd-mm-yyyy'), '7', '24', '236', '08', '2031', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11560, to_date('25-08-2031', 'dd-mm-yyyy'), '1', '25', '237', '08', '2031', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11561, to_date('26-08-2031', 'dd-mm-yyyy'), '2', '26', '238', '08', '2031', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11562, to_date('27-08-2031', 'dd-mm-yyyy'), '3', '27', '239', '08', '2031', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11563, to_date('28-08-2031', 'dd-mm-yyyy'), '4', '28', '240', '08', '2031', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11564, to_date('29-08-2031', 'dd-mm-yyyy'), '5', '29', '241', '08', '2031', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11565, to_date('30-08-2031', 'dd-mm-yyyy'), '6', '30', '242', '08', '2031', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11566, to_date('31-08-2031', 'dd-mm-yyyy'), '7', '31', '243', '08', '2031', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11567, to_date('01-09-2031', 'dd-mm-yyyy'), '1', '01', '244', '09', '2031', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11568, to_date('02-09-2031', 'dd-mm-yyyy'), '2', '02', '245', '09', '2031', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11569, to_date('03-09-2031', 'dd-mm-yyyy'), '3', '03', '246', '09', '2031', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11570, to_date('04-09-2031', 'dd-mm-yyyy'), '4', '04', '247', '09', '2031', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11571, to_date('05-09-2031', 'dd-mm-yyyy'), '5', '05', '248', '09', '2031', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11572, to_date('06-09-2031', 'dd-mm-yyyy'), '6', '06', '249', '09', '2031', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11573, to_date('07-09-2031', 'dd-mm-yyyy'), '7', '07', '250', '09', '2031', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11574, to_date('08-09-2031', 'dd-mm-yyyy'), '1', '08', '251', '09', '2031', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11575, to_date('09-09-2031', 'dd-mm-yyyy'), '2', '09', '252', '09', '2031', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11576, to_date('10-09-2031', 'dd-mm-yyyy'), '3', '10', '253', '09', '2031', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11577, to_date('11-09-2031', 'dd-mm-yyyy'), '4', '11', '254', '09', '2031', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11578, to_date('12-09-2031', 'dd-mm-yyyy'), '5', '12', '255', '09', '2031', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11579, to_date('13-09-2031', 'dd-mm-yyyy'), '6', '13', '256', '09', '2031', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11580, to_date('14-09-2031', 'dd-mm-yyyy'), '7', '14', '257', '09', '2031', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11581, to_date('15-09-2031', 'dd-mm-yyyy'), '1', '15', '258', '09', '2031', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11582, to_date('16-09-2031', 'dd-mm-yyyy'), '2', '16', '259', '09', '2031', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11583, to_date('17-09-2031', 'dd-mm-yyyy'), '3', '17', '260', '09', '2031', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11584, to_date('18-09-2031', 'dd-mm-yyyy'), '4', '18', '261', '09', '2031', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11585, to_date('19-09-2031', 'dd-mm-yyyy'), '5', '19', '262', '09', '2031', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11586, to_date('20-09-2031', 'dd-mm-yyyy'), '6', '20', '263', '09', '2031', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11587, to_date('21-09-2031', 'dd-mm-yyyy'), '7', '21', '264', '09', '2031', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11588, to_date('22-09-2031', 'dd-mm-yyyy'), '1', '22', '265', '09', '2031', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11589, to_date('23-09-2031', 'dd-mm-yyyy'), '2', '23', '266', '09', '2031', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11590, to_date('24-09-2031', 'dd-mm-yyyy'), '3', '24', '267', '09', '2031', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11591, to_date('25-09-2031', 'dd-mm-yyyy'), '4', '25', '268', '09', '2031', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11592, to_date('26-09-2031', 'dd-mm-yyyy'), '5', '26', '269', '09', '2031', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11593, to_date('27-09-2031', 'dd-mm-yyyy'), '6', '27', '270', '09', '2031', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11594, to_date('28-09-2031', 'dd-mm-yyyy'), '7', '28', '271', '09', '2031', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11595, to_date('29-09-2031', 'dd-mm-yyyy'), '1', '29', '272', '09', '2031', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11596, to_date('30-09-2031', 'dd-mm-yyyy'), '2', '30', '273', '09', '2031', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11597, to_date('01-10-2031', 'dd-mm-yyyy'), '3', '01', '274', '10', '2031', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11598, to_date('02-10-2031', 'dd-mm-yyyy'), '4', '02', '275', '10', '2031', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11599, to_date('03-10-2031', 'dd-mm-yyyy'), '5', '03', '276', '10', '2031', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11600, to_date('04-10-2031', 'dd-mm-yyyy'), '6', '04', '277', '10', '2031', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11601, to_date('05-10-2031', 'dd-mm-yyyy'), '7', '05', '278', '10', '2031', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11602, to_date('06-10-2031', 'dd-mm-yyyy'), '1', '06', '279', '10', '2031', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11603, to_date('07-10-2031', 'dd-mm-yyyy'), '2', '07', '280', '10', '2031', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11604, to_date('08-10-2031', 'dd-mm-yyyy'), '3', '08', '281', '10', '2031', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11605, to_date('09-10-2031', 'dd-mm-yyyy'), '4', '09', '282', '10', '2031', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11606, to_date('10-10-2031', 'dd-mm-yyyy'), '5', '10', '283', '10', '2031', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11607, to_date('11-10-2031', 'dd-mm-yyyy'), '6', '11', '284', '10', '2031', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11608, to_date('12-10-2031', 'dd-mm-yyyy'), '7', '12', '285', '10', '2031', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11609, to_date('13-10-2031', 'dd-mm-yyyy'), '1', '13', '286', '10', '2031', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11610, to_date('14-10-2031', 'dd-mm-yyyy'), '2', '14', '287', '10', '2031', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11611, to_date('15-10-2031', 'dd-mm-yyyy'), '3', '15', '288', '10', '2031', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11612, to_date('16-10-2031', 'dd-mm-yyyy'), '4', '16', '289', '10', '2031', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11613, to_date('17-10-2031', 'dd-mm-yyyy'), '5', '17', '290', '10', '2031', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11614, to_date('18-10-2031', 'dd-mm-yyyy'), '6', '18', '291', '10', '2031', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11615, to_date('19-10-2031', 'dd-mm-yyyy'), '7', '19', '292', '10', '2031', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11616, to_date('20-10-2031', 'dd-mm-yyyy'), '1', '20', '293', '10', '2031', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11617, to_date('21-10-2031', 'dd-mm-yyyy'), '2', '21', '294', '10', '2031', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11618, to_date('22-10-2031', 'dd-mm-yyyy'), '3', '22', '295', '10', '2031', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11619, to_date('23-10-2031', 'dd-mm-yyyy'), '4', '23', '296', '10', '2031', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11620, to_date('24-10-2031', 'dd-mm-yyyy'), '5', '24', '297', '10', '2031', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11621, to_date('25-10-2031', 'dd-mm-yyyy'), '6', '25', '298', '10', '2031', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11622, to_date('26-10-2031', 'dd-mm-yyyy'), '7', '26', '299', '10', '2031', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11623, to_date('27-10-2031', 'dd-mm-yyyy'), '1', '27', '300', '10', '2031', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11624, to_date('28-10-2031', 'dd-mm-yyyy'), '2', '28', '301', '10', '2031', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11625, to_date('29-10-2031', 'dd-mm-yyyy'), '3', '29', '302', '10', '2031', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11626, to_date('30-10-2031', 'dd-mm-yyyy'), '4', '30', '303', '10', '2031', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11627, to_date('31-10-2031', 'dd-mm-yyyy'), '5', '31', '304', '10', '2031', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11628, to_date('01-11-2031', 'dd-mm-yyyy'), '6', '01', '305', '11', '2031', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11629, to_date('02-11-2031', 'dd-mm-yyyy'), '7', '02', '306', '11', '2031', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11630, to_date('03-11-2031', 'dd-mm-yyyy'), '1', '03', '307', '11', '2031', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11631, to_date('04-11-2031', 'dd-mm-yyyy'), '2', '04', '308', '11', '2031', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11632, to_date('05-11-2031', 'dd-mm-yyyy'), '3', '05', '309', '11', '2031', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11633, to_date('06-11-2031', 'dd-mm-yyyy'), '4', '06', '310', '11', '2031', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11634, to_date('07-11-2031', 'dd-mm-yyyy'), '5', '07', '311', '11', '2031', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11635, to_date('08-11-2031', 'dd-mm-yyyy'), '6', '08', '312', '11', '2031', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11636, to_date('09-11-2031', 'dd-mm-yyyy'), '7', '09', '313', '11', '2031', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11637, to_date('10-11-2031', 'dd-mm-yyyy'), '1', '10', '314', '11', '2031', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11638, to_date('11-11-2031', 'dd-mm-yyyy'), '2', '11', '315', '11', '2031', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11639, to_date('12-11-2031', 'dd-mm-yyyy'), '3', '12', '316', '11', '2031', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11640, to_date('13-11-2031', 'dd-mm-yyyy'), '4', '13', '317', '11', '2031', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11641, to_date('14-11-2031', 'dd-mm-yyyy'), '5', '14', '318', '11', '2031', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11642, to_date('15-11-2031', 'dd-mm-yyyy'), '6', '15', '319', '11', '2031', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11643, to_date('16-11-2031', 'dd-mm-yyyy'), '7', '16', '320', '11', '2031', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11644, to_date('17-11-2031', 'dd-mm-yyyy'), '1', '17', '321', '11', '2031', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11645, to_date('18-11-2031', 'dd-mm-yyyy'), '2', '18', '322', '11', '2031', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11646, to_date('19-11-2031', 'dd-mm-yyyy'), '3', '19', '323', '11', '2031', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11647, to_date('20-11-2031', 'dd-mm-yyyy'), '4', '20', '324', '11', '2031', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11648, to_date('21-11-2031', 'dd-mm-yyyy'), '5', '21', '325', '11', '2031', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11649, to_date('22-11-2031', 'dd-mm-yyyy'), '6', '22', '326', '11', '2031', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11650, to_date('23-11-2031', 'dd-mm-yyyy'), '7', '23', '327', '11', '2031', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11651, to_date('24-11-2031', 'dd-mm-yyyy'), '1', '24', '328', '11', '2031', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11652, to_date('25-11-2031', 'dd-mm-yyyy'), '2', '25', '329', '11', '2031', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11653, to_date('26-11-2031', 'dd-mm-yyyy'), '3', '26', '330', '11', '2031', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11654, to_date('27-11-2031', 'dd-mm-yyyy'), '4', '27', '331', '11', '2031', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11655, to_date('28-11-2031', 'dd-mm-yyyy'), '5', '28', '332', '11', '2031', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11656, to_date('29-11-2031', 'dd-mm-yyyy'), '6', '29', '333', '11', '2031', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11657, to_date('30-11-2031', 'dd-mm-yyyy'), '7', '30', '334', '11', '2031', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11658, to_date('01-12-2031', 'dd-mm-yyyy'), '1', '01', '335', '12', '2031', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11659, to_date('02-12-2031', 'dd-mm-yyyy'), '2', '02', '336', '12', '2031', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11660, to_date('03-12-2031', 'dd-mm-yyyy'), '3', '03', '337', '12', '2031', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11661, to_date('04-12-2031', 'dd-mm-yyyy'), '4', '04', '338', '12', '2031', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11662, to_date('05-12-2031', 'dd-mm-yyyy'), '5', '05', '339', '12', '2031', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11663, to_date('06-12-2031', 'dd-mm-yyyy'), '6', '06', '340', '12', '2031', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11664, to_date('07-12-2031', 'dd-mm-yyyy'), '7', '07', '341', '12', '2031', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11665, to_date('08-12-2031', 'dd-mm-yyyy'), '1', '08', '342', '12', '2031', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11666, to_date('09-12-2031', 'dd-mm-yyyy'), '2', '09', '343', '12', '2031', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11667, to_date('10-12-2031', 'dd-mm-yyyy'), '3', '10', '344', '12', '2031', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11668, to_date('11-12-2031', 'dd-mm-yyyy'), '4', '11', '345', '12', '2031', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11669, to_date('12-12-2031', 'dd-mm-yyyy'), '5', '12', '346', '12', '2031', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11670, to_date('13-12-2031', 'dd-mm-yyyy'), '6', '13', '347', '12', '2031', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11671, to_date('14-12-2031', 'dd-mm-yyyy'), '7', '14', '348', '12', '2031', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11672, to_date('15-12-2031', 'dd-mm-yyyy'), '1', '15', '349', '12', '2031', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11673, to_date('16-12-2031', 'dd-mm-yyyy'), '2', '16', '350', '12', '2031', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11674, to_date('17-12-2031', 'dd-mm-yyyy'), '3', '17', '351', '12', '2031', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11675, to_date('18-12-2031', 'dd-mm-yyyy'), '4', '18', '352', '12', '2031', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11676, to_date('19-12-2031', 'dd-mm-yyyy'), '5', '19', '353', '12', '2031', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11677, to_date('20-12-2031', 'dd-mm-yyyy'), '6', '20', '354', '12', '2031', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11678, to_date('21-12-2031', 'dd-mm-yyyy'), '7', '21', '355', '12', '2031', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11679, to_date('22-12-2031', 'dd-mm-yyyy'), '1', '22', '356', '12', '2031', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11680, to_date('23-12-2031', 'dd-mm-yyyy'), '2', '23', '357', '12', '2031', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11681, to_date('24-12-2031', 'dd-mm-yyyy'), '3', '24', '358', '12', '2031', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11682, to_date('25-12-2031', 'dd-mm-yyyy'), '4', '25', '359', '12', '2031', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11683, to_date('26-12-2031', 'dd-mm-yyyy'), '5', '26', '360', '12', '2031', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11684, to_date('27-12-2031', 'dd-mm-yyyy'), '6', '27', '361', '12', '2031', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11685, to_date('28-12-2031', 'dd-mm-yyyy'), '7', '28', '362', '12', '2031', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11686, to_date('29-12-2031', 'dd-mm-yyyy'), '1', '29', '363', '12', '2031', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11687, to_date('30-12-2031', 'dd-mm-yyyy'), '2', '30', '364', '12', '2031', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11688, to_date('31-12-2031', 'dd-mm-yyyy'), '3', '31', '365', '12', '2031', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11689, to_date('01-01-2032', 'dd-mm-yyyy'), '4', '01', '001', '01', '2032', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11690, to_date('02-01-2032', 'dd-mm-yyyy'), '5', '02', '002', '01', '2032', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11691, to_date('03-01-2032', 'dd-mm-yyyy'), '6', '03', '003', '01', '2032', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11692, to_date('04-01-2032', 'dd-mm-yyyy'), '7', '04', '004', '01', '2032', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11693, to_date('05-01-2032', 'dd-mm-yyyy'), '1', '05', '005', '01', '2032', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11694, to_date('06-01-2032', 'dd-mm-yyyy'), '2', '06', '006', '01', '2032', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11695, to_date('07-01-2032', 'dd-mm-yyyy'), '3', '07', '007', '01', '2032', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11696, to_date('08-01-2032', 'dd-mm-yyyy'), '4', '08', '008', '01', '2032', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11697, to_date('09-01-2032', 'dd-mm-yyyy'), '5', '09', '009', '01', '2032', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11698, to_date('10-01-2032', 'dd-mm-yyyy'), '6', '10', '010', '01', '2032', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11699, to_date('11-01-2032', 'dd-mm-yyyy'), '7', '11', '011', '01', '2032', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11700, to_date('12-01-2032', 'dd-mm-yyyy'), '1', '12', '012', '01', '2032', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11701, to_date('13-01-2032', 'dd-mm-yyyy'), '2', '13', '013', '01', '2032', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11702, to_date('14-01-2032', 'dd-mm-yyyy'), '3', '14', '014', '01', '2032', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11703, to_date('15-01-2032', 'dd-mm-yyyy'), '4', '15', '015', '01', '2032', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11704, to_date('16-01-2032', 'dd-mm-yyyy'), '5', '16', '016', '01', '2032', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11705, to_date('17-01-2032', 'dd-mm-yyyy'), '6', '17', '017', '01', '2032', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11706, to_date('18-01-2032', 'dd-mm-yyyy'), '7', '18', '018', '01', '2032', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11707, to_date('19-01-2032', 'dd-mm-yyyy'), '1', '19', '019', '01', '2032', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11708, to_date('20-01-2032', 'dd-mm-yyyy'), '2', '20', '020', '01', '2032', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11709, to_date('21-01-2032', 'dd-mm-yyyy'), '3', '21', '021', '01', '2032', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11710, to_date('22-01-2032', 'dd-mm-yyyy'), '4', '22', '022', '01', '2032', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11711, to_date('23-01-2032', 'dd-mm-yyyy'), '5', '23', '023', '01', '2032', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11712, to_date('24-01-2032', 'dd-mm-yyyy'), '6', '24', '024', '01', '2032', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11713, to_date('25-01-2032', 'dd-mm-yyyy'), '7', '25', '025', '01', '2032', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11714, to_date('26-01-2032', 'dd-mm-yyyy'), '1', '26', '026', '01', '2032', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11715, to_date('27-01-2032', 'dd-mm-yyyy'), '2', '27', '027', '01', '2032', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11716, to_date('28-01-2032', 'dd-mm-yyyy'), '3', '28', '028', '01', '2032', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11717, to_date('29-01-2032', 'dd-mm-yyyy'), '4', '29', '029', '01', '2032', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11718, to_date('30-01-2032', 'dd-mm-yyyy'), '5', '30', '030', '01', '2032', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11719, to_date('31-01-2032', 'dd-mm-yyyy'), '6', '31', '031', '01', '2032', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11720, to_date('01-02-2032', 'dd-mm-yyyy'), '7', '01', '032', '02', '2032', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11721, to_date('02-02-2032', 'dd-mm-yyyy'), '1', '02', '033', '02', '2032', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11722, to_date('03-02-2032', 'dd-mm-yyyy'), '2', '03', '034', '02', '2032', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11723, to_date('04-02-2032', 'dd-mm-yyyy'), '3', '04', '035', '02', '2032', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11724, to_date('05-02-2032', 'dd-mm-yyyy'), '4', '05', '036', '02', '2032', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11725, to_date('06-02-2032', 'dd-mm-yyyy'), '5', '06', '037', '02', '2032', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11726, to_date('07-02-2032', 'dd-mm-yyyy'), '6', '07', '038', '02', '2032', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11727, to_date('08-02-2032', 'dd-mm-yyyy'), '7', '08', '039', '02', '2032', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11728, to_date('09-02-2032', 'dd-mm-yyyy'), '1', '09', '040', '02', '2032', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11729, to_date('10-02-2032', 'dd-mm-yyyy'), '2', '10', '041', '02', '2032', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11730, to_date('11-02-2032', 'dd-mm-yyyy'), '3', '11', '042', '02', '2032', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11731, to_date('12-02-2032', 'dd-mm-yyyy'), '4', '12', '043', '02', '2032', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11732, to_date('13-02-2032', 'dd-mm-yyyy'), '5', '13', '044', '02', '2032', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11733, to_date('14-02-2032', 'dd-mm-yyyy'), '6', '14', '045', '02', '2032', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11734, to_date('15-02-2032', 'dd-mm-yyyy'), '7', '15', '046', '02', '2032', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11735, to_date('16-02-2032', 'dd-mm-yyyy'), '1', '16', '047', '02', '2032', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11736, to_date('17-02-2032', 'dd-mm-yyyy'), '2', '17', '048', '02', '2032', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11737, to_date('18-02-2032', 'dd-mm-yyyy'), '3', '18', '049', '02', '2032', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11738, to_date('19-02-2032', 'dd-mm-yyyy'), '4', '19', '050', '02', '2032', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11739, to_date('20-02-2032', 'dd-mm-yyyy'), '5', '20', '051', '02', '2032', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11740, to_date('21-02-2032', 'dd-mm-yyyy'), '6', '21', '052', '02', '2032', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11953, to_date('21-09-2032', 'dd-mm-yyyy'), '2', '21', '265', '09', '2032', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11954, to_date('22-09-2032', 'dd-mm-yyyy'), '3', '22', '266', '09', '2032', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11955, to_date('23-09-2032', 'dd-mm-yyyy'), '4', '23', '267', '09', '2032', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11956, to_date('24-09-2032', 'dd-mm-yyyy'), '5', '24', '268', '09', '2032', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11957, to_date('25-09-2032', 'dd-mm-yyyy'), '6', '25', '269', '09', '2032', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11958, to_date('26-09-2032', 'dd-mm-yyyy'), '7', '26', '270', '09', '2032', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11959, to_date('27-09-2032', 'dd-mm-yyyy'), '1', '27', '271', '09', '2032', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11960, to_date('28-09-2032', 'dd-mm-yyyy'), '2', '28', '272', '09', '2032', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11961, to_date('29-09-2032', 'dd-mm-yyyy'), '3', '29', '273', '09', '2032', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11962, to_date('30-09-2032', 'dd-mm-yyyy'), '4', '30', '274', '09', '2032', '40', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11963, to_date('01-10-2032', 'dd-mm-yyyy'), '5', '01', '275', '10', '2032', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11964, to_date('02-10-2032', 'dd-mm-yyyy'), '6', '02', '276', '10', '2032', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11965, to_date('03-10-2032', 'dd-mm-yyyy'), '7', '03', '277', '10', '2032', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11966, to_date('04-10-2032', 'dd-mm-yyyy'), '1', '04', '278', '10', '2032', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11967, to_date('05-10-2032', 'dd-mm-yyyy'), '2', '05', '279', '10', '2032', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11968, to_date('06-10-2032', 'dd-mm-yyyy'), '3', '06', '280', '10', '2032', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11969, to_date('07-10-2032', 'dd-mm-yyyy'), '4', '07', '281', '10', '2032', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11970, to_date('08-10-2032', 'dd-mm-yyyy'), '5', '08', '282', '10', '2032', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11971, to_date('09-10-2032', 'dd-mm-yyyy'), '6', '09', '283', '10', '2032', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11972, to_date('10-10-2032', 'dd-mm-yyyy'), '7', '10', '284', '10', '2032', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11973, to_date('11-10-2032', 'dd-mm-yyyy'), '1', '11', '285', '10', '2032', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11974, to_date('12-10-2032', 'dd-mm-yyyy'), '2', '12', '286', '10', '2032', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11975, to_date('13-10-2032', 'dd-mm-yyyy'), '3', '13', '287', '10', '2032', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11976, to_date('14-10-2032', 'dd-mm-yyyy'), '4', '14', '288', '10', '2032', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11977, to_date('15-10-2032', 'dd-mm-yyyy'), '5', '15', '289', '10', '2032', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11978, to_date('16-10-2032', 'dd-mm-yyyy'), '6', '16', '290', '10', '2032', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11979, to_date('17-10-2032', 'dd-mm-yyyy'), '7', '17', '291', '10', '2032', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11980, to_date('18-10-2032', 'dd-mm-yyyy'), '1', '18', '292', '10', '2032', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11981, to_date('19-10-2032', 'dd-mm-yyyy'), '2', '19', '293', '10', '2032', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11982, to_date('20-10-2032', 'dd-mm-yyyy'), '3', '20', '294', '10', '2032', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11983, to_date('21-10-2032', 'dd-mm-yyyy'), '4', '21', '295', '10', '2032', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11984, to_date('22-10-2032', 'dd-mm-yyyy'), '5', '22', '296', '10', '2032', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11985, to_date('23-10-2032', 'dd-mm-yyyy'), '6', '23', '297', '10', '2032', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11986, to_date('24-10-2032', 'dd-mm-yyyy'), '7', '24', '298', '10', '2032', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11987, to_date('25-10-2032', 'dd-mm-yyyy'), '1', '25', '299', '10', '2032', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11988, to_date('26-10-2032', 'dd-mm-yyyy'), '2', '26', '300', '10', '2032', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11989, to_date('27-10-2032', 'dd-mm-yyyy'), '3', '27', '301', '10', '2032', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11990, to_date('28-10-2032', 'dd-mm-yyyy'), '4', '28', '302', '10', '2032', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11991, to_date('29-10-2032', 'dd-mm-yyyy'), '5', '29', '303', '10', '2032', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11992, to_date('30-10-2032', 'dd-mm-yyyy'), '6', '30', '304', '10', '2032', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11993, to_date('31-10-2032', 'dd-mm-yyyy'), '7', '31', '305', '10', '2032', '44', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11994, to_date('01-11-2032', 'dd-mm-yyyy'), '1', '01', '306', '11', '2032', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11995, to_date('02-11-2032', 'dd-mm-yyyy'), '2', '02', '307', '11', '2032', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11996, to_date('03-11-2032', 'dd-mm-yyyy'), '3', '03', '308', '11', '2032', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11997, to_date('04-11-2032', 'dd-mm-yyyy'), '4', '04', '309', '11', '2032', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11998, to_date('05-11-2032', 'dd-mm-yyyy'), '5', '05', '310', '11', '2032', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11999, to_date('06-11-2032', 'dd-mm-yyyy'), '6', '06', '311', '11', '2032', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12000, to_date('07-11-2032', 'dd-mm-yyyy'), '7', '07', '312', '11', '2032', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12001, to_date('08-11-2032', 'dd-mm-yyyy'), '1', '08', '313', '11', '2032', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12002, to_date('09-11-2032', 'dd-mm-yyyy'), '2', '09', '314', '11', '2032', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12003, to_date('10-11-2032', 'dd-mm-yyyy'), '3', '10', '315', '11', '2032', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12004, to_date('11-11-2032', 'dd-mm-yyyy'), '4', '11', '316', '11', '2032', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12005, to_date('12-11-2032', 'dd-mm-yyyy'), '5', '12', '317', '11', '2032', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12006, to_date('13-11-2032', 'dd-mm-yyyy'), '6', '13', '318', '11', '2032', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12007, to_date('14-11-2032', 'dd-mm-yyyy'), '7', '14', '319', '11', '2032', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12008, to_date('15-11-2032', 'dd-mm-yyyy'), '1', '15', '320', '11', '2032', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12009, to_date('16-11-2032', 'dd-mm-yyyy'), '2', '16', '321', '11', '2032', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12010, to_date('17-11-2032', 'dd-mm-yyyy'), '3', '17', '322', '11', '2032', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12011, to_date('18-11-2032', 'dd-mm-yyyy'), '4', '18', '323', '11', '2032', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12012, to_date('19-11-2032', 'dd-mm-yyyy'), '5', '19', '324', '11', '2032', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12013, to_date('20-11-2032', 'dd-mm-yyyy'), '6', '20', '325', '11', '2032', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12014, to_date('21-11-2032', 'dd-mm-yyyy'), '7', '21', '326', '11', '2032', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12015, to_date('22-11-2032', 'dd-mm-yyyy'), '1', '22', '327', '11', '2032', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12016, to_date('23-11-2032', 'dd-mm-yyyy'), '2', '23', '328', '11', '2032', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12017, to_date('24-11-2032', 'dd-mm-yyyy'), '3', '24', '329', '11', '2032', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12018, to_date('25-11-2032', 'dd-mm-yyyy'), '4', '25', '330', '11', '2032', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12019, to_date('26-11-2032', 'dd-mm-yyyy'), '5', '26', '331', '11', '2032', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12020, to_date('27-11-2032', 'dd-mm-yyyy'), '6', '27', '332', '11', '2032', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12021, to_date('28-11-2032', 'dd-mm-yyyy'), '7', '28', '333', '11', '2032', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12022, to_date('29-11-2032', 'dd-mm-yyyy'), '1', '29', '334', '11', '2032', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12023, to_date('30-11-2032', 'dd-mm-yyyy'), '2', '30', '335', '11', '2032', '49', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12024, to_date('01-12-2032', 'dd-mm-yyyy'), '3', '01', '336', '12', '2032', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12025, to_date('02-12-2032', 'dd-mm-yyyy'), '4', '02', '337', '12', '2032', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12026, to_date('03-12-2032', 'dd-mm-yyyy'), '5', '03', '338', '12', '2032', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12027, to_date('04-12-2032', 'dd-mm-yyyy'), '6', '04', '339', '12', '2032', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12028, to_date('05-12-2032', 'dd-mm-yyyy'), '7', '05', '340', '12', '2032', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12029, to_date('06-12-2032', 'dd-mm-yyyy'), '1', '06', '341', '12', '2032', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12030, to_date('07-12-2032', 'dd-mm-yyyy'), '2', '07', '342', '12', '2032', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12031, to_date('08-12-2032', 'dd-mm-yyyy'), '3', '08', '343', '12', '2032', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12032, to_date('09-12-2032', 'dd-mm-yyyy'), '4', '09', '344', '12', '2032', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12033, to_date('10-12-2032', 'dd-mm-yyyy'), '5', '10', '345', '12', '2032', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12034, to_date('11-12-2032', 'dd-mm-yyyy'), '6', '11', '346', '12', '2032', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12035, to_date('12-12-2032', 'dd-mm-yyyy'), '7', '12', '347', '12', '2032', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12036, to_date('13-12-2032', 'dd-mm-yyyy'), '1', '13', '348', '12', '2032', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12037, to_date('14-12-2032', 'dd-mm-yyyy'), '2', '14', '349', '12', '2032', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12038, to_date('15-12-2032', 'dd-mm-yyyy'), '3', '15', '350', '12', '2032', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12039, to_date('16-12-2032', 'dd-mm-yyyy'), '4', '16', '351', '12', '2032', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12040, to_date('17-12-2032', 'dd-mm-yyyy'), '5', '17', '352', '12', '2032', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12041, to_date('18-12-2032', 'dd-mm-yyyy'), '6', '18', '353', '12', '2032', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12042, to_date('19-12-2032', 'dd-mm-yyyy'), '7', '19', '354', '12', '2032', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12043, to_date('20-12-2032', 'dd-mm-yyyy'), '1', '20', '355', '12', '2032', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12044, to_date('21-12-2032', 'dd-mm-yyyy'), '2', '21', '356', '12', '2032', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12045, to_date('22-12-2032', 'dd-mm-yyyy'), '3', '22', '357', '12', '2032', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12046, to_date('23-12-2032', 'dd-mm-yyyy'), '4', '23', '358', '12', '2032', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12047, to_date('24-12-2032', 'dd-mm-yyyy'), '5', '24', '359', '12', '2032', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12048, to_date('25-12-2032', 'dd-mm-yyyy'), '6', '25', '360', '12', '2032', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12049, to_date('26-12-2032', 'dd-mm-yyyy'), '7', '26', '361', '12', '2032', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12050, to_date('27-12-2032', 'dd-mm-yyyy'), '1', '27', '362', '12', '2032', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12051, to_date('28-12-2032', 'dd-mm-yyyy'), '2', '28', '363', '12', '2032', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12052, to_date('29-12-2032', 'dd-mm-yyyy'), '3', '29', '364', '12', '2032', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12053, to_date('30-12-2032', 'dd-mm-yyyy'), '4', '30', '365', '12', '2032', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12054, to_date('31-12-2032', 'dd-mm-yyyy'), '5', '31', '366', '12', '2032', '53', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12055, to_date('01-01-2033', 'dd-mm-yyyy'), '6', '01', '001', '01', '2033', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12056, to_date('02-01-2033', 'dd-mm-yyyy'), '7', '02', '002', '01', '2033', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12057, to_date('03-01-2033', 'dd-mm-yyyy'), '1', '03', '003', '01', '2033', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12058, to_date('04-01-2033', 'dd-mm-yyyy'), '2', '04', '004', '01', '2033', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12059, to_date('05-01-2033', 'dd-mm-yyyy'), '3', '05', '005', '01', '2033', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12060, to_date('06-01-2033', 'dd-mm-yyyy'), '4', '06', '006', '01', '2033', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12061, to_date('07-01-2033', 'dd-mm-yyyy'), '5', '07', '007', '01', '2033', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12062, to_date('08-01-2033', 'dd-mm-yyyy'), '6', '08', '008', '01', '2033', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12063, to_date('09-01-2033', 'dd-mm-yyyy'), '7', '09', '009', '01', '2033', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12064, to_date('10-01-2033', 'dd-mm-yyyy'), '1', '10', '010', '01', '2033', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12065, to_date('11-01-2033', 'dd-mm-yyyy'), '2', '11', '011', '01', '2033', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12066, to_date('12-01-2033', 'dd-mm-yyyy'), '3', '12', '012', '01', '2033', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12067, to_date('13-01-2033', 'dd-mm-yyyy'), '4', '13', '013', '01', '2033', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12068, to_date('14-01-2033', 'dd-mm-yyyy'), '5', '14', '014', '01', '2033', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12069, to_date('15-01-2033', 'dd-mm-yyyy'), '6', '15', '015', '01', '2033', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12070, to_date('16-01-2033', 'dd-mm-yyyy'), '7', '16', '016', '01', '2033', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12071, to_date('17-01-2033', 'dd-mm-yyyy'), '1', '17', '017', '01', '2033', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12072, to_date('18-01-2033', 'dd-mm-yyyy'), '2', '18', '018', '01', '2033', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12073, to_date('19-01-2033', 'dd-mm-yyyy'), '3', '19', '019', '01', '2033', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12074, to_date('20-01-2033', 'dd-mm-yyyy'), '4', '20', '020', '01', '2033', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12075, to_date('21-01-2033', 'dd-mm-yyyy'), '5', '21', '021', '01', '2033', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12076, to_date('22-01-2033', 'dd-mm-yyyy'), '6', '22', '022', '01', '2033', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12077, to_date('23-01-2033', 'dd-mm-yyyy'), '7', '23', '023', '01', '2033', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12078, to_date('24-01-2033', 'dd-mm-yyyy'), '1', '24', '024', '01', '2033', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12079, to_date('25-01-2033', 'dd-mm-yyyy'), '2', '25', '025', '01', '2033', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12080, to_date('26-01-2033', 'dd-mm-yyyy'), '3', '26', '026', '01', '2033', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12081, to_date('27-01-2033', 'dd-mm-yyyy'), '4', '27', '027', '01', '2033', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12082, to_date('28-01-2033', 'dd-mm-yyyy'), '5', '28', '028', '01', '2033', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12083, to_date('29-01-2033', 'dd-mm-yyyy'), '6', '29', '029', '01', '2033', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12084, to_date('30-01-2033', 'dd-mm-yyyy'), '7', '30', '030', '01', '2033', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12085, to_date('31-01-2033', 'dd-mm-yyyy'), '1', '31', '031', '01', '2033', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12086, to_date('01-02-2033', 'dd-mm-yyyy'), '2', '01', '032', '02', '2033', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12087, to_date('02-02-2033', 'dd-mm-yyyy'), '3', '02', '033', '02', '2033', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12088, to_date('03-02-2033', 'dd-mm-yyyy'), '4', '03', '034', '02', '2033', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12089, to_date('04-02-2033', 'dd-mm-yyyy'), '5', '04', '035', '02', '2033', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12090, to_date('05-02-2033', 'dd-mm-yyyy'), '6', '05', '036', '02', '2033', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12091, to_date('06-02-2033', 'dd-mm-yyyy'), '7', '06', '037', '02', '2033', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12092, to_date('07-02-2033', 'dd-mm-yyyy'), '1', '07', '038', '02', '2033', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12093, to_date('08-02-2033', 'dd-mm-yyyy'), '2', '08', '039', '02', '2033', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12094, to_date('09-02-2033', 'dd-mm-yyyy'), '3', '09', '040', '02', '2033', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12095, to_date('10-02-2033', 'dd-mm-yyyy'), '4', '10', '041', '02', '2033', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12096, to_date('11-02-2033', 'dd-mm-yyyy'), '5', '11', '042', '02', '2033', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12097, to_date('12-02-2033', 'dd-mm-yyyy'), '6', '12', '043', '02', '2033', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12098, to_date('13-02-2033', 'dd-mm-yyyy'), '7', '13', '044', '02', '2033', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12099, to_date('14-02-2033', 'dd-mm-yyyy'), '1', '14', '045', '02', '2033', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12100, to_date('15-02-2033', 'dd-mm-yyyy'), '2', '15', '046', '02', '2033', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12101, to_date('16-02-2033', 'dd-mm-yyyy'), '3', '16', '047', '02', '2033', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12102, to_date('17-02-2033', 'dd-mm-yyyy'), '4', '17', '048', '02', '2033', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12103, to_date('18-02-2033', 'dd-mm-yyyy'), '5', '18', '049', '02', '2033', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12104, to_date('19-02-2033', 'dd-mm-yyyy'), '6', '19', '050', '02', '2033', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12105, to_date('20-02-2033', 'dd-mm-yyyy'), '7', '20', '051', '02', '2033', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12106, to_date('21-02-2033', 'dd-mm-yyyy'), '1', '21', '052', '02', '2033', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
commit;
prompt 12000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12107, to_date('22-02-2033', 'dd-mm-yyyy'), '2', '22', '053', '02', '2033', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12108, to_date('23-02-2033', 'dd-mm-yyyy'), '3', '23', '054', '02', '2033', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12109, to_date('24-02-2033', 'dd-mm-yyyy'), '4', '24', '055', '02', '2033', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12110, to_date('25-02-2033', 'dd-mm-yyyy'), '5', '25', '056', '02', '2033', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12111, to_date('26-02-2033', 'dd-mm-yyyy'), '6', '26', '057', '02', '2033', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12112, to_date('27-02-2033', 'dd-mm-yyyy'), '7', '27', '058', '02', '2033', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12113, to_date('28-02-2033', 'dd-mm-yyyy'), '1', '28', '059', '02', '2033', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12114, to_date('01-03-2033', 'dd-mm-yyyy'), '2', '01', '060', '03', '2033', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12115, to_date('02-03-2033', 'dd-mm-yyyy'), '3', '02', '061', '03', '2033', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12116, to_date('03-03-2033', 'dd-mm-yyyy'), '4', '03', '062', '03', '2033', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12117, to_date('04-03-2033', 'dd-mm-yyyy'), '5', '04', '063', '03', '2033', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12118, to_date('05-03-2033', 'dd-mm-yyyy'), '6', '05', '064', '03', '2033', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12119, to_date('06-03-2033', 'dd-mm-yyyy'), '7', '06', '065', '03', '2033', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12120, to_date('07-03-2033', 'dd-mm-yyyy'), '1', '07', '066', '03', '2033', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12121, to_date('08-03-2033', 'dd-mm-yyyy'), '2', '08', '067', '03', '2033', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12122, to_date('09-03-2033', 'dd-mm-yyyy'), '3', '09', '068', '03', '2033', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12123, to_date('10-03-2033', 'dd-mm-yyyy'), '4', '10', '069', '03', '2033', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12124, to_date('11-03-2033', 'dd-mm-yyyy'), '5', '11', '070', '03', '2033', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12125, to_date('12-03-2033', 'dd-mm-yyyy'), '6', '12', '071', '03', '2033', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12126, to_date('13-03-2033', 'dd-mm-yyyy'), '7', '13', '072', '03', '2033', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12127, to_date('14-03-2033', 'dd-mm-yyyy'), '1', '14', '073', '03', '2033', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12128, to_date('15-03-2033', 'dd-mm-yyyy'), '2', '15', '074', '03', '2033', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12129, to_date('16-03-2033', 'dd-mm-yyyy'), '3', '16', '075', '03', '2033', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12130, to_date('17-03-2033', 'dd-mm-yyyy'), '4', '17', '076', '03', '2033', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12131, to_date('18-03-2033', 'dd-mm-yyyy'), '5', '18', '077', '03', '2033', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12132, to_date('19-03-2033', 'dd-mm-yyyy'), '6', '19', '078', '03', '2033', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12133, to_date('20-03-2033', 'dd-mm-yyyy'), '7', '20', '079', '03', '2033', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12134, to_date('21-03-2033', 'dd-mm-yyyy'), '1', '21', '080', '03', '2033', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12135, to_date('22-03-2033', 'dd-mm-yyyy'), '2', '22', '081', '03', '2033', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12136, to_date('23-03-2033', 'dd-mm-yyyy'), '3', '23', '082', '03', '2033', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12137, to_date('24-03-2033', 'dd-mm-yyyy'), '4', '24', '083', '03', '2033', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12138, to_date('25-03-2033', 'dd-mm-yyyy'), '5', '25', '084', '03', '2033', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12139, to_date('26-03-2033', 'dd-mm-yyyy'), '6', '26', '085', '03', '2033', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12140, to_date('27-03-2033', 'dd-mm-yyyy'), '7', '27', '086', '03', '2033', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12141, to_date('28-03-2033', 'dd-mm-yyyy'), '1', '28', '087', '03', '2033', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12142, to_date('29-03-2033', 'dd-mm-yyyy'), '2', '29', '088', '03', '2033', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12143, to_date('30-03-2033', 'dd-mm-yyyy'), '3', '30', '089', '03', '2033', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12144, to_date('31-03-2033', 'dd-mm-yyyy'), '4', '31', '090', '03', '2033', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12145, to_date('01-04-2033', 'dd-mm-yyyy'), '5', '01', '091', '04', '2033', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12146, to_date('02-04-2033', 'dd-mm-yyyy'), '6', '02', '092', '04', '2033', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12147, to_date('03-04-2033', 'dd-mm-yyyy'), '7', '03', '093', '04', '2033', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12148, to_date('04-04-2033', 'dd-mm-yyyy'), '1', '04', '094', '04', '2033', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12149, to_date('05-04-2033', 'dd-mm-yyyy'), '2', '05', '095', '04', '2033', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12150, to_date('06-04-2033', 'dd-mm-yyyy'), '3', '06', '096', '04', '2033', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12151, to_date('07-04-2033', 'dd-mm-yyyy'), '4', '07', '097', '04', '2033', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12152, to_date('08-04-2033', 'dd-mm-yyyy'), '5', '08', '098', '04', '2033', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12153, to_date('09-04-2033', 'dd-mm-yyyy'), '6', '09', '099', '04', '2033', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12154, to_date('10-04-2033', 'dd-mm-yyyy'), '7', '10', '100', '04', '2033', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12155, to_date('11-04-2033', 'dd-mm-yyyy'), '1', '11', '101', '04', '2033', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12156, to_date('12-04-2033', 'dd-mm-yyyy'), '2', '12', '102', '04', '2033', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12157, to_date('13-04-2033', 'dd-mm-yyyy'), '3', '13', '103', '04', '2033', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12158, to_date('14-04-2033', 'dd-mm-yyyy'), '4', '14', '104', '04', '2033', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12159, to_date('15-04-2033', 'dd-mm-yyyy'), '5', '15', '105', '04', '2033', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12160, to_date('16-04-2033', 'dd-mm-yyyy'), '6', '16', '106', '04', '2033', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12161, to_date('17-04-2033', 'dd-mm-yyyy'), '7', '17', '107', '04', '2033', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12162, to_date('18-04-2033', 'dd-mm-yyyy'), '1', '18', '108', '04', '2033', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12163, to_date('19-04-2033', 'dd-mm-yyyy'), '2', '19', '109', '04', '2033', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12164, to_date('20-04-2033', 'dd-mm-yyyy'), '3', '20', '110', '04', '2033', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12589, to_date('19-06-2034', 'dd-mm-yyyy'), '1', '19', '170', '06', '2034', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12590, to_date('20-06-2034', 'dd-mm-yyyy'), '2', '20', '171', '06', '2034', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12591, to_date('21-06-2034', 'dd-mm-yyyy'), '3', '21', '172', '06', '2034', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12592, to_date('22-06-2034', 'dd-mm-yyyy'), '4', '22', '173', '06', '2034', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12593, to_date('23-06-2034', 'dd-mm-yyyy'), '5', '23', '174', '06', '2034', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12594, to_date('24-06-2034', 'dd-mm-yyyy'), '6', '24', '175', '06', '2034', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12595, to_date('25-06-2034', 'dd-mm-yyyy'), '7', '25', '176', '06', '2034', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12596, to_date('26-06-2034', 'dd-mm-yyyy'), '1', '26', '177', '06', '2034', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12597, to_date('27-06-2034', 'dd-mm-yyyy'), '2', '27', '178', '06', '2034', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12598, to_date('28-06-2034', 'dd-mm-yyyy'), '3', '28', '179', '06', '2034', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12599, to_date('29-06-2034', 'dd-mm-yyyy'), '4', '29', '180', '06', '2034', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12600, to_date('30-06-2034', 'dd-mm-yyyy'), '5', '30', '181', '06', '2034', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12601, to_date('01-07-2034', 'dd-mm-yyyy'), '6', '01', '182', '07', '2034', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12602, to_date('02-07-2034', 'dd-mm-yyyy'), '7', '02', '183', '07', '2034', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12603, to_date('03-07-2034', 'dd-mm-yyyy'), '1', '03', '184', '07', '2034', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12604, to_date('04-07-2034', 'dd-mm-yyyy'), '2', '04', '185', '07', '2034', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12605, to_date('05-07-2034', 'dd-mm-yyyy'), '3', '05', '186', '07', '2034', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12606, to_date('06-07-2034', 'dd-mm-yyyy'), '4', '06', '187', '07', '2034', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12607, to_date('07-07-2034', 'dd-mm-yyyy'), '5', '07', '188', '07', '2034', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12608, to_date('08-07-2034', 'dd-mm-yyyy'), '6', '08', '189', '07', '2034', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12609, to_date('09-07-2034', 'dd-mm-yyyy'), '7', '09', '190', '07', '2034', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12610, to_date('10-07-2034', 'dd-mm-yyyy'), '1', '10', '191', '07', '2034', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12611, to_date('11-07-2034', 'dd-mm-yyyy'), '2', '11', '192', '07', '2034', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12612, to_date('12-07-2034', 'dd-mm-yyyy'), '3', '12', '193', '07', '2034', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12613, to_date('13-07-2034', 'dd-mm-yyyy'), '4', '13', '194', '07', '2034', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12614, to_date('14-07-2034', 'dd-mm-yyyy'), '5', '14', '195', '07', '2034', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12615, to_date('15-07-2034', 'dd-mm-yyyy'), '6', '15', '196', '07', '2034', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12616, to_date('16-07-2034', 'dd-mm-yyyy'), '7', '16', '197', '07', '2034', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12617, to_date('17-07-2034', 'dd-mm-yyyy'), '1', '17', '198', '07', '2034', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12618, to_date('18-07-2034', 'dd-mm-yyyy'), '2', '18', '199', '07', '2034', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12619, to_date('19-07-2034', 'dd-mm-yyyy'), '3', '19', '200', '07', '2034', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12620, to_date('20-07-2034', 'dd-mm-yyyy'), '4', '20', '201', '07', '2034', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12621, to_date('21-07-2034', 'dd-mm-yyyy'), '5', '21', '202', '07', '2034', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12622, to_date('22-07-2034', 'dd-mm-yyyy'), '6', '22', '203', '07', '2034', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12623, to_date('23-07-2034', 'dd-mm-yyyy'), '7', '23', '204', '07', '2034', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12624, to_date('24-07-2034', 'dd-mm-yyyy'), '1', '24', '205', '07', '2034', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12625, to_date('25-07-2034', 'dd-mm-yyyy'), '2', '25', '206', '07', '2034', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12626, to_date('26-07-2034', 'dd-mm-yyyy'), '3', '26', '207', '07', '2034', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12627, to_date('27-07-2034', 'dd-mm-yyyy'), '4', '27', '208', '07', '2034', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12628, to_date('28-07-2034', 'dd-mm-yyyy'), '5', '28', '209', '07', '2034', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12629, to_date('29-07-2034', 'dd-mm-yyyy'), '6', '29', '210', '07', '2034', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12630, to_date('30-07-2034', 'dd-mm-yyyy'), '7', '30', '211', '07', '2034', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12631, to_date('31-07-2034', 'dd-mm-yyyy'), '1', '31', '212', '07', '2034', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12632, to_date('01-08-2034', 'dd-mm-yyyy'), '2', '01', '213', '08', '2034', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12633, to_date('02-08-2034', 'dd-mm-yyyy'), '3', '02', '214', '08', '2034', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12634, to_date('03-08-2034', 'dd-mm-yyyy'), '4', '03', '215', '08', '2034', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12635, to_date('04-08-2034', 'dd-mm-yyyy'), '5', '04', '216', '08', '2034', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12636, to_date('05-08-2034', 'dd-mm-yyyy'), '6', '05', '217', '08', '2034', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12637, to_date('06-08-2034', 'dd-mm-yyyy'), '7', '06', '218', '08', '2034', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12638, to_date('07-08-2034', 'dd-mm-yyyy'), '1', '07', '219', '08', '2034', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12639, to_date('08-08-2034', 'dd-mm-yyyy'), '2', '08', '220', '08', '2034', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12640, to_date('09-08-2034', 'dd-mm-yyyy'), '3', '09', '221', '08', '2034', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12641, to_date('10-08-2034', 'dd-mm-yyyy'), '4', '10', '222', '08', '2034', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12642, to_date('11-08-2034', 'dd-mm-yyyy'), '5', '11', '223', '08', '2034', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12643, to_date('12-08-2034', 'dd-mm-yyyy'), '6', '12', '224', '08', '2034', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12644, to_date('13-08-2034', 'dd-mm-yyyy'), '7', '13', '225', '08', '2034', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12645, to_date('14-08-2034', 'dd-mm-yyyy'), '1', '14', '226', '08', '2034', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12646, to_date('15-08-2034', 'dd-mm-yyyy'), '2', '15', '227', '08', '2034', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12647, to_date('16-08-2034', 'dd-mm-yyyy'), '3', '16', '228', '08', '2034', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12648, to_date('17-08-2034', 'dd-mm-yyyy'), '4', '17', '229', '08', '2034', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12649, to_date('18-08-2034', 'dd-mm-yyyy'), '5', '18', '230', '08', '2034', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12650, to_date('19-08-2034', 'dd-mm-yyyy'), '6', '19', '231', '08', '2034', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12651, to_date('20-08-2034', 'dd-mm-yyyy'), '7', '20', '232', '08', '2034', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12652, to_date('21-08-2034', 'dd-mm-yyyy'), '1', '21', '233', '08', '2034', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12653, to_date('22-08-2034', 'dd-mm-yyyy'), '2', '22', '234', '08', '2034', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12654, to_date('23-08-2034', 'dd-mm-yyyy'), '3', '23', '235', '08', '2034', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12655, to_date('24-08-2034', 'dd-mm-yyyy'), '4', '24', '236', '08', '2034', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12656, to_date('25-08-2034', 'dd-mm-yyyy'), '5', '25', '237', '08', '2034', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12657, to_date('26-08-2034', 'dd-mm-yyyy'), '6', '26', '238', '08', '2034', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12658, to_date('27-08-2034', 'dd-mm-yyyy'), '7', '27', '239', '08', '2034', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12659, to_date('28-08-2034', 'dd-mm-yyyy'), '1', '28', '240', '08', '2034', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12660, to_date('29-08-2034', 'dd-mm-yyyy'), '2', '29', '241', '08', '2034', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12661, to_date('30-08-2034', 'dd-mm-yyyy'), '3', '30', '242', '08', '2034', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12662, to_date('31-08-2034', 'dd-mm-yyyy'), '4', '31', '243', '08', '2034', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12663, to_date('01-09-2034', 'dd-mm-yyyy'), '5', '01', '244', '09', '2034', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12664, to_date('02-09-2034', 'dd-mm-yyyy'), '6', '02', '245', '09', '2034', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12665, to_date('03-09-2034', 'dd-mm-yyyy'), '7', '03', '246', '09', '2034', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12666, to_date('04-09-2034', 'dd-mm-yyyy'), '1', '04', '247', '09', '2034', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12667, to_date('05-09-2034', 'dd-mm-yyyy'), '2', '05', '248', '09', '2034', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12668, to_date('06-09-2034', 'dd-mm-yyyy'), '3', '06', '249', '09', '2034', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12669, to_date('07-09-2034', 'dd-mm-yyyy'), '4', '07', '250', '09', '2034', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12670, to_date('08-09-2034', 'dd-mm-yyyy'), '5', '08', '251', '09', '2034', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12671, to_date('09-09-2034', 'dd-mm-yyyy'), '6', '09', '252', '09', '2034', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12672, to_date('10-09-2034', 'dd-mm-yyyy'), '7', '10', '253', '09', '2034', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12673, to_date('11-09-2034', 'dd-mm-yyyy'), '1', '11', '254', '09', '2034', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12674, to_date('12-09-2034', 'dd-mm-yyyy'), '2', '12', '255', '09', '2034', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12675, to_date('13-09-2034', 'dd-mm-yyyy'), '3', '13', '256', '09', '2034', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12676, to_date('14-09-2034', 'dd-mm-yyyy'), '4', '14', '257', '09', '2034', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12677, to_date('15-09-2034', 'dd-mm-yyyy'), '5', '15', '258', '09', '2034', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12678, to_date('16-09-2034', 'dd-mm-yyyy'), '6', '16', '259', '09', '2034', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12679, to_date('17-09-2034', 'dd-mm-yyyy'), '7', '17', '260', '09', '2034', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12680, to_date('18-09-2034', 'dd-mm-yyyy'), '1', '18', '261', '09', '2034', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12681, to_date('19-09-2034', 'dd-mm-yyyy'), '2', '19', '262', '09', '2034', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12682, to_date('20-09-2034', 'dd-mm-yyyy'), '3', '20', '263', '09', '2034', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12683, to_date('21-09-2034', 'dd-mm-yyyy'), '4', '21', '264', '09', '2034', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12684, to_date('22-09-2034', 'dd-mm-yyyy'), '5', '22', '265', '09', '2034', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12685, to_date('23-09-2034', 'dd-mm-yyyy'), '6', '23', '266', '09', '2034', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12686, to_date('24-09-2034', 'dd-mm-yyyy'), '7', '24', '267', '09', '2034', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12687, to_date('25-09-2034', 'dd-mm-yyyy'), '1', '25', '268', '09', '2034', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12688, to_date('26-09-2034', 'dd-mm-yyyy'), '2', '26', '269', '09', '2034', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12689, to_date('27-09-2034', 'dd-mm-yyyy'), '3', '27', '270', '09', '2034', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12690, to_date('28-09-2034', 'dd-mm-yyyy'), '4', '28', '271', '09', '2034', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12691, to_date('29-09-2034', 'dd-mm-yyyy'), '5', '29', '272', '09', '2034', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12692, to_date('30-09-2034', 'dd-mm-yyyy'), '6', '30', '273', '09', '2034', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12693, to_date('01-10-2034', 'dd-mm-yyyy'), '7', '01', '274', '10', '2034', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12694, to_date('02-10-2034', 'dd-mm-yyyy'), '1', '02', '275', '10', '2034', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12165, to_date('21-04-2033', 'dd-mm-yyyy'), '4', '21', '111', '04', '2033', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12166, to_date('22-04-2033', 'dd-mm-yyyy'), '5', '22', '112', '04', '2033', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12167, to_date('23-04-2033', 'dd-mm-yyyy'), '6', '23', '113', '04', '2033', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12168, to_date('24-04-2033', 'dd-mm-yyyy'), '7', '24', '114', '04', '2033', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12169, to_date('25-04-2033', 'dd-mm-yyyy'), '1', '25', '115', '04', '2033', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12170, to_date('26-04-2033', 'dd-mm-yyyy'), '2', '26', '116', '04', '2033', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12171, to_date('27-04-2033', 'dd-mm-yyyy'), '3', '27', '117', '04', '2033', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12172, to_date('28-04-2033', 'dd-mm-yyyy'), '4', '28', '118', '04', '2033', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12173, to_date('29-04-2033', 'dd-mm-yyyy'), '5', '29', '119', '04', '2033', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12174, to_date('30-04-2033', 'dd-mm-yyyy'), '6', '30', '120', '04', '2033', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12175, to_date('01-05-2033', 'dd-mm-yyyy'), '7', '01', '121', '05', '2033', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12176, to_date('02-05-2033', 'dd-mm-yyyy'), '1', '02', '122', '05', '2033', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12177, to_date('03-05-2033', 'dd-mm-yyyy'), '2', '03', '123', '05', '2033', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12178, to_date('04-05-2033', 'dd-mm-yyyy'), '3', '04', '124', '05', '2033', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12179, to_date('05-05-2033', 'dd-mm-yyyy'), '4', '05', '125', '05', '2033', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12180, to_date('06-05-2033', 'dd-mm-yyyy'), '5', '06', '126', '05', '2033', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12181, to_date('07-05-2033', 'dd-mm-yyyy'), '6', '07', '127', '05', '2033', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12182, to_date('08-05-2033', 'dd-mm-yyyy'), '7', '08', '128', '05', '2033', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12183, to_date('09-05-2033', 'dd-mm-yyyy'), '1', '09', '129', '05', '2033', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12184, to_date('10-05-2033', 'dd-mm-yyyy'), '2', '10', '130', '05', '2033', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12185, to_date('11-05-2033', 'dd-mm-yyyy'), '3', '11', '131', '05', '2033', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12186, to_date('12-05-2033', 'dd-mm-yyyy'), '4', '12', '132', '05', '2033', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12187, to_date('13-05-2033', 'dd-mm-yyyy'), '5', '13', '133', '05', '2033', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12188, to_date('14-05-2033', 'dd-mm-yyyy'), '6', '14', '134', '05', '2033', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12189, to_date('15-05-2033', 'dd-mm-yyyy'), '7', '15', '135', '05', '2033', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12190, to_date('16-05-2033', 'dd-mm-yyyy'), '1', '16', '136', '05', '2033', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12191, to_date('17-05-2033', 'dd-mm-yyyy'), '2', '17', '137', '05', '2033', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12192, to_date('18-05-2033', 'dd-mm-yyyy'), '3', '18', '138', '05', '2033', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12193, to_date('19-05-2033', 'dd-mm-yyyy'), '4', '19', '139', '05', '2033', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12194, to_date('20-05-2033', 'dd-mm-yyyy'), '5', '20', '140', '05', '2033', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12195, to_date('21-05-2033', 'dd-mm-yyyy'), '6', '21', '141', '05', '2033', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12196, to_date('22-05-2033', 'dd-mm-yyyy'), '7', '22', '142', '05', '2033', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12197, to_date('23-05-2033', 'dd-mm-yyyy'), '1', '23', '143', '05', '2033', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12198, to_date('24-05-2033', 'dd-mm-yyyy'), '2', '24', '144', '05', '2033', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12199, to_date('25-05-2033', 'dd-mm-yyyy'), '3', '25', '145', '05', '2033', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12200, to_date('26-05-2033', 'dd-mm-yyyy'), '4', '26', '146', '05', '2033', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12201, to_date('27-05-2033', 'dd-mm-yyyy'), '5', '27', '147', '05', '2033', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12202, to_date('28-05-2033', 'dd-mm-yyyy'), '6', '28', '148', '05', '2033', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12203, to_date('29-05-2033', 'dd-mm-yyyy'), '7', '29', '149', '05', '2033', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12204, to_date('30-05-2033', 'dd-mm-yyyy'), '1', '30', '150', '05', '2033', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12205, to_date('31-05-2033', 'dd-mm-yyyy'), '2', '31', '151', '05', '2033', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12206, to_date('01-06-2033', 'dd-mm-yyyy'), '3', '01', '152', '06', '2033', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12207, to_date('02-06-2033', 'dd-mm-yyyy'), '4', '02', '153', '06', '2033', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12208, to_date('03-06-2033', 'dd-mm-yyyy'), '5', '03', '154', '06', '2033', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12209, to_date('04-06-2033', 'dd-mm-yyyy'), '6', '04', '155', '06', '2033', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12210, to_date('05-06-2033', 'dd-mm-yyyy'), '7', '05', '156', '06', '2033', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12211, to_date('06-06-2033', 'dd-mm-yyyy'), '1', '06', '157', '06', '2033', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12212, to_date('07-06-2033', 'dd-mm-yyyy'), '2', '07', '158', '06', '2033', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12213, to_date('08-06-2033', 'dd-mm-yyyy'), '3', '08', '159', '06', '2033', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12214, to_date('09-06-2033', 'dd-mm-yyyy'), '4', '09', '160', '06', '2033', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12215, to_date('10-06-2033', 'dd-mm-yyyy'), '5', '10', '161', '06', '2033', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12216, to_date('11-06-2033', 'dd-mm-yyyy'), '6', '11', '162', '06', '2033', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12217, to_date('12-06-2033', 'dd-mm-yyyy'), '7', '12', '163', '06', '2033', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12218, to_date('13-06-2033', 'dd-mm-yyyy'), '1', '13', '164', '06', '2033', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12219, to_date('14-06-2033', 'dd-mm-yyyy'), '2', '14', '165', '06', '2033', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12220, to_date('15-06-2033', 'dd-mm-yyyy'), '3', '15', '166', '06', '2033', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12221, to_date('16-06-2033', 'dd-mm-yyyy'), '4', '16', '167', '06', '2033', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12222, to_date('17-06-2033', 'dd-mm-yyyy'), '5', '17', '168', '06', '2033', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12223, to_date('18-06-2033', 'dd-mm-yyyy'), '6', '18', '169', '06', '2033', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12224, to_date('19-06-2033', 'dd-mm-yyyy'), '7', '19', '170', '06', '2033', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12225, to_date('20-06-2033', 'dd-mm-yyyy'), '1', '20', '171', '06', '2033', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12226, to_date('21-06-2033', 'dd-mm-yyyy'), '2', '21', '172', '06', '2033', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12227, to_date('22-06-2033', 'dd-mm-yyyy'), '3', '22', '173', '06', '2033', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12228, to_date('23-06-2033', 'dd-mm-yyyy'), '4', '23', '174', '06', '2033', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12229, to_date('24-06-2033', 'dd-mm-yyyy'), '5', '24', '175', '06', '2033', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12230, to_date('25-06-2033', 'dd-mm-yyyy'), '6', '25', '176', '06', '2033', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12231, to_date('26-06-2033', 'dd-mm-yyyy'), '7', '26', '177', '06', '2033', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12232, to_date('27-06-2033', 'dd-mm-yyyy'), '1', '27', '178', '06', '2033', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12233, to_date('28-06-2033', 'dd-mm-yyyy'), '2', '28', '179', '06', '2033', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12234, to_date('29-06-2033', 'dd-mm-yyyy'), '3', '29', '180', '06', '2033', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12235, to_date('30-06-2033', 'dd-mm-yyyy'), '4', '30', '181', '06', '2033', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12236, to_date('01-07-2033', 'dd-mm-yyyy'), '5', '01', '182', '07', '2033', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12237, to_date('02-07-2033', 'dd-mm-yyyy'), '6', '02', '183', '07', '2033', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12238, to_date('03-07-2033', 'dd-mm-yyyy'), '7', '03', '184', '07', '2033', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12239, to_date('04-07-2033', 'dd-mm-yyyy'), '1', '04', '185', '07', '2033', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12240, to_date('05-07-2033', 'dd-mm-yyyy'), '2', '05', '186', '07', '2033', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12241, to_date('06-07-2033', 'dd-mm-yyyy'), '3', '06', '187', '07', '2033', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12242, to_date('07-07-2033', 'dd-mm-yyyy'), '4', '07', '188', '07', '2033', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12243, to_date('08-07-2033', 'dd-mm-yyyy'), '5', '08', '189', '07', '2033', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12244, to_date('09-07-2033', 'dd-mm-yyyy'), '6', '09', '190', '07', '2033', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12245, to_date('10-07-2033', 'dd-mm-yyyy'), '7', '10', '191', '07', '2033', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12246, to_date('11-07-2033', 'dd-mm-yyyy'), '1', '11', '192', '07', '2033', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12247, to_date('12-07-2033', 'dd-mm-yyyy'), '2', '12', '193', '07', '2033', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12248, to_date('13-07-2033', 'dd-mm-yyyy'), '3', '13', '194', '07', '2033', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12249, to_date('14-07-2033', 'dd-mm-yyyy'), '4', '14', '195', '07', '2033', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12250, to_date('15-07-2033', 'dd-mm-yyyy'), '5', '15', '196', '07', '2033', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12251, to_date('16-07-2033', 'dd-mm-yyyy'), '6', '16', '197', '07', '2033', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12252, to_date('17-07-2033', 'dd-mm-yyyy'), '7', '17', '198', '07', '2033', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12253, to_date('18-07-2033', 'dd-mm-yyyy'), '1', '18', '199', '07', '2033', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12254, to_date('19-07-2033', 'dd-mm-yyyy'), '2', '19', '200', '07', '2033', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12255, to_date('20-07-2033', 'dd-mm-yyyy'), '3', '20', '201', '07', '2033', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12256, to_date('21-07-2033', 'dd-mm-yyyy'), '4', '21', '202', '07', '2033', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12257, to_date('22-07-2033', 'dd-mm-yyyy'), '5', '22', '203', '07', '2033', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12258, to_date('23-07-2033', 'dd-mm-yyyy'), '6', '23', '204', '07', '2033', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12259, to_date('24-07-2033', 'dd-mm-yyyy'), '7', '24', '205', '07', '2033', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12260, to_date('25-07-2033', 'dd-mm-yyyy'), '1', '25', '206', '07', '2033', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12261, to_date('26-07-2033', 'dd-mm-yyyy'), '2', '26', '207', '07', '2033', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12262, to_date('27-07-2033', 'dd-mm-yyyy'), '3', '27', '208', '07', '2033', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12263, to_date('28-07-2033', 'dd-mm-yyyy'), '4', '28', '209', '07', '2033', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12264, to_date('29-07-2033', 'dd-mm-yyyy'), '5', '29', '210', '07', '2033', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12265, to_date('30-07-2033', 'dd-mm-yyyy'), '6', '30', '211', '07', '2033', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12266, to_date('31-07-2033', 'dd-mm-yyyy'), '7', '31', '212', '07', '2033', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12267, to_date('01-08-2033', 'dd-mm-yyyy'), '1', '01', '213', '08', '2033', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12268, to_date('02-08-2033', 'dd-mm-yyyy'), '2', '02', '214', '08', '2033', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12269, to_date('03-08-2033', 'dd-mm-yyyy'), '3', '03', '215', '08', '2033', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12270, to_date('04-08-2033', 'dd-mm-yyyy'), '4', '04', '216', '08', '2033', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12271, to_date('05-08-2033', 'dd-mm-yyyy'), '5', '05', '217', '08', '2033', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12272, to_date('06-08-2033', 'dd-mm-yyyy'), '6', '06', '218', '08', '2033', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12273, to_date('07-08-2033', 'dd-mm-yyyy'), '7', '07', '219', '08', '2033', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12274, to_date('08-08-2033', 'dd-mm-yyyy'), '1', '08', '220', '08', '2033', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12275, to_date('09-08-2033', 'dd-mm-yyyy'), '2', '09', '221', '08', '2033', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12276, to_date('10-08-2033', 'dd-mm-yyyy'), '3', '10', '222', '08', '2033', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12277, to_date('11-08-2033', 'dd-mm-yyyy'), '4', '11', '223', '08', '2033', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12278, to_date('12-08-2033', 'dd-mm-yyyy'), '5', '12', '224', '08', '2033', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12279, to_date('13-08-2033', 'dd-mm-yyyy'), '6', '13', '225', '08', '2033', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12280, to_date('14-08-2033', 'dd-mm-yyyy'), '7', '14', '226', '08', '2033', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12281, to_date('15-08-2033', 'dd-mm-yyyy'), '1', '15', '227', '08', '2033', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12282, to_date('16-08-2033', 'dd-mm-yyyy'), '2', '16', '228', '08', '2033', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12283, to_date('17-08-2033', 'dd-mm-yyyy'), '3', '17', '229', '08', '2033', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12284, to_date('18-08-2033', 'dd-mm-yyyy'), '4', '18', '230', '08', '2033', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12285, to_date('19-08-2033', 'dd-mm-yyyy'), '5', '19', '231', '08', '2033', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12286, to_date('20-08-2033', 'dd-mm-yyyy'), '6', '20', '232', '08', '2033', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12287, to_date('21-08-2033', 'dd-mm-yyyy'), '7', '21', '233', '08', '2033', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12288, to_date('22-08-2033', 'dd-mm-yyyy'), '1', '22', '234', '08', '2033', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12289, to_date('23-08-2033', 'dd-mm-yyyy'), '2', '23', '235', '08', '2033', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12290, to_date('24-08-2033', 'dd-mm-yyyy'), '3', '24', '236', '08', '2033', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12291, to_date('25-08-2033', 'dd-mm-yyyy'), '4', '25', '237', '08', '2033', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12292, to_date('26-08-2033', 'dd-mm-yyyy'), '5', '26', '238', '08', '2033', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12293, to_date('27-08-2033', 'dd-mm-yyyy'), '6', '27', '239', '08', '2033', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12294, to_date('28-08-2033', 'dd-mm-yyyy'), '7', '28', '240', '08', '2033', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12295, to_date('29-08-2033', 'dd-mm-yyyy'), '1', '29', '241', '08', '2033', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12296, to_date('30-08-2033', 'dd-mm-yyyy'), '2', '30', '242', '08', '2033', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12297, to_date('31-08-2033', 'dd-mm-yyyy'), '3', '31', '243', '08', '2033', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12298, to_date('01-09-2033', 'dd-mm-yyyy'), '4', '01', '244', '09', '2033', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12299, to_date('02-09-2033', 'dd-mm-yyyy'), '5', '02', '245', '09', '2033', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12300, to_date('03-09-2033', 'dd-mm-yyyy'), '6', '03', '246', '09', '2033', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12301, to_date('04-09-2033', 'dd-mm-yyyy'), '7', '04', '247', '09', '2033', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12302, to_date('05-09-2033', 'dd-mm-yyyy'), '1', '05', '248', '09', '2033', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12303, to_date('06-09-2033', 'dd-mm-yyyy'), '2', '06', '249', '09', '2033', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12304, to_date('07-09-2033', 'dd-mm-yyyy'), '3', '07', '250', '09', '2033', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12305, to_date('08-09-2033', 'dd-mm-yyyy'), '4', '08', '251', '09', '2033', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12306, to_date('09-09-2033', 'dd-mm-yyyy'), '5', '09', '252', '09', '2033', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12307, to_date('10-09-2033', 'dd-mm-yyyy'), '6', '10', '253', '09', '2033', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12308, to_date('11-09-2033', 'dd-mm-yyyy'), '7', '11', '254', '09', '2033', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12309, to_date('12-09-2033', 'dd-mm-yyyy'), '1', '12', '255', '09', '2033', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12310, to_date('13-09-2033', 'dd-mm-yyyy'), '2', '13', '256', '09', '2033', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12311, to_date('14-09-2033', 'dd-mm-yyyy'), '3', '14', '257', '09', '2033', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12312, to_date('15-09-2033', 'dd-mm-yyyy'), '4', '15', '258', '09', '2033', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12313, to_date('16-09-2033', 'dd-mm-yyyy'), '5', '16', '259', '09', '2033', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12314, to_date('17-09-2033', 'dd-mm-yyyy'), '6', '17', '260', '09', '2033', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12315, to_date('18-09-2033', 'dd-mm-yyyy'), '7', '18', '261', '09', '2033', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12316, to_date('19-09-2033', 'dd-mm-yyyy'), '1', '19', '262', '09', '2033', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12317, to_date('20-09-2033', 'dd-mm-yyyy'), '2', '20', '263', '09', '2033', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12318, to_date('21-09-2033', 'dd-mm-yyyy'), '3', '21', '264', '09', '2033', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12319, to_date('22-09-2033', 'dd-mm-yyyy'), '4', '22', '265', '09', '2033', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12320, to_date('23-09-2033', 'dd-mm-yyyy'), '5', '23', '266', '09', '2033', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12321, to_date('24-09-2033', 'dd-mm-yyyy'), '6', '24', '267', '09', '2033', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12322, to_date('25-09-2033', 'dd-mm-yyyy'), '7', '25', '268', '09', '2033', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12323, to_date('26-09-2033', 'dd-mm-yyyy'), '1', '26', '269', '09', '2033', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12324, to_date('27-09-2033', 'dd-mm-yyyy'), '2', '27', '270', '09', '2033', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12325, to_date('28-09-2033', 'dd-mm-yyyy'), '3', '28', '271', '09', '2033', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12326, to_date('29-09-2033', 'dd-mm-yyyy'), '4', '29', '272', '09', '2033', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12327, to_date('30-09-2033', 'dd-mm-yyyy'), '5', '30', '273', '09', '2033', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12328, to_date('01-10-2033', 'dd-mm-yyyy'), '6', '01', '274', '10', '2033', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12329, to_date('02-10-2033', 'dd-mm-yyyy'), '7', '02', '275', '10', '2033', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12330, to_date('03-10-2033', 'dd-mm-yyyy'), '1', '03', '276', '10', '2033', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12331, to_date('04-10-2033', 'dd-mm-yyyy'), '2', '04', '277', '10', '2033', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12332, to_date('05-10-2033', 'dd-mm-yyyy'), '3', '05', '278', '10', '2033', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12333, to_date('06-10-2033', 'dd-mm-yyyy'), '4', '06', '279', '10', '2033', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12334, to_date('07-10-2033', 'dd-mm-yyyy'), '5', '07', '280', '10', '2033', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12335, to_date('08-10-2033', 'dd-mm-yyyy'), '6', '08', '281', '10', '2033', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12336, to_date('09-10-2033', 'dd-mm-yyyy'), '7', '09', '282', '10', '2033', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12337, to_date('10-10-2033', 'dd-mm-yyyy'), '1', '10', '283', '10', '2033', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12338, to_date('11-10-2033', 'dd-mm-yyyy'), '2', '11', '284', '10', '2033', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12339, to_date('12-10-2033', 'dd-mm-yyyy'), '3', '12', '285', '10', '2033', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12340, to_date('13-10-2033', 'dd-mm-yyyy'), '4', '13', '286', '10', '2033', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12341, to_date('14-10-2033', 'dd-mm-yyyy'), '5', '14', '287', '10', '2033', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12342, to_date('15-10-2033', 'dd-mm-yyyy'), '6', '15', '288', '10', '2033', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12343, to_date('16-10-2033', 'dd-mm-yyyy'), '7', '16', '289', '10', '2033', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12344, to_date('17-10-2033', 'dd-mm-yyyy'), '1', '17', '290', '10', '2033', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12345, to_date('18-10-2033', 'dd-mm-yyyy'), '2', '18', '291', '10', '2033', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12346, to_date('19-10-2033', 'dd-mm-yyyy'), '3', '19', '292', '10', '2033', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12347, to_date('20-10-2033', 'dd-mm-yyyy'), '4', '20', '293', '10', '2033', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12348, to_date('21-10-2033', 'dd-mm-yyyy'), '5', '21', '294', '10', '2033', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12349, to_date('22-10-2033', 'dd-mm-yyyy'), '6', '22', '295', '10', '2033', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12350, to_date('23-10-2033', 'dd-mm-yyyy'), '7', '23', '296', '10', '2033', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12351, to_date('24-10-2033', 'dd-mm-yyyy'), '1', '24', '297', '10', '2033', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12352, to_date('25-10-2033', 'dd-mm-yyyy'), '2', '25', '298', '10', '2033', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12353, to_date('26-10-2033', 'dd-mm-yyyy'), '3', '26', '299', '10', '2033', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12354, to_date('27-10-2033', 'dd-mm-yyyy'), '4', '27', '300', '10', '2033', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12355, to_date('28-10-2033', 'dd-mm-yyyy'), '5', '28', '301', '10', '2033', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12356, to_date('29-10-2033', 'dd-mm-yyyy'), '6', '29', '302', '10', '2033', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12357, to_date('30-10-2033', 'dd-mm-yyyy'), '7', '30', '303', '10', '2033', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12358, to_date('31-10-2033', 'dd-mm-yyyy'), '1', '31', '304', '10', '2033', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12359, to_date('01-11-2033', 'dd-mm-yyyy'), '2', '01', '305', '11', '2033', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12360, to_date('02-11-2033', 'dd-mm-yyyy'), '3', '02', '306', '11', '2033', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12361, to_date('03-11-2033', 'dd-mm-yyyy'), '4', '03', '307', '11', '2033', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12362, to_date('04-11-2033', 'dd-mm-yyyy'), '5', '04', '308', '11', '2033', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12363, to_date('05-11-2033', 'dd-mm-yyyy'), '6', '05', '309', '11', '2033', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12364, to_date('06-11-2033', 'dd-mm-yyyy'), '7', '06', '310', '11', '2033', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12365, to_date('07-11-2033', 'dd-mm-yyyy'), '1', '07', '311', '11', '2033', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12366, to_date('08-11-2033', 'dd-mm-yyyy'), '2', '08', '312', '11', '2033', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12367, to_date('09-11-2033', 'dd-mm-yyyy'), '3', '09', '313', '11', '2033', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12368, to_date('10-11-2033', 'dd-mm-yyyy'), '4', '10', '314', '11', '2033', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12369, to_date('11-11-2033', 'dd-mm-yyyy'), '5', '11', '315', '11', '2033', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12370, to_date('12-11-2033', 'dd-mm-yyyy'), '6', '12', '316', '11', '2033', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12371, to_date('13-11-2033', 'dd-mm-yyyy'), '7', '13', '317', '11', '2033', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12372, to_date('14-11-2033', 'dd-mm-yyyy'), '1', '14', '318', '11', '2033', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12373, to_date('15-11-2033', 'dd-mm-yyyy'), '2', '15', '319', '11', '2033', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12374, to_date('16-11-2033', 'dd-mm-yyyy'), '3', '16', '320', '11', '2033', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12375, to_date('17-11-2033', 'dd-mm-yyyy'), '4', '17', '321', '11', '2033', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12376, to_date('18-11-2033', 'dd-mm-yyyy'), '5', '18', '322', '11', '2033', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12377, to_date('19-11-2033', 'dd-mm-yyyy'), '6', '19', '323', '11', '2033', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12378, to_date('20-11-2033', 'dd-mm-yyyy'), '7', '20', '324', '11', '2033', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12379, to_date('21-11-2033', 'dd-mm-yyyy'), '1', '21', '325', '11', '2033', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12380, to_date('22-11-2033', 'dd-mm-yyyy'), '2', '22', '326', '11', '2033', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12381, to_date('23-11-2033', 'dd-mm-yyyy'), '3', '23', '327', '11', '2033', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12382, to_date('24-11-2033', 'dd-mm-yyyy'), '4', '24', '328', '11', '2033', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12383, to_date('25-11-2033', 'dd-mm-yyyy'), '5', '25', '329', '11', '2033', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12384, to_date('26-11-2033', 'dd-mm-yyyy'), '6', '26', '330', '11', '2033', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12385, to_date('27-11-2033', 'dd-mm-yyyy'), '7', '27', '331', '11', '2033', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12386, to_date('28-11-2033', 'dd-mm-yyyy'), '1', '28', '332', '11', '2033', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12387, to_date('29-11-2033', 'dd-mm-yyyy'), '2', '29', '333', '11', '2033', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12388, to_date('30-11-2033', 'dd-mm-yyyy'), '3', '30', '334', '11', '2033', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12389, to_date('01-12-2033', 'dd-mm-yyyy'), '4', '01', '335', '12', '2033', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12390, to_date('02-12-2033', 'dd-mm-yyyy'), '5', '02', '336', '12', '2033', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12391, to_date('03-12-2033', 'dd-mm-yyyy'), '6', '03', '337', '12', '2033', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12392, to_date('04-12-2033', 'dd-mm-yyyy'), '7', '04', '338', '12', '2033', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12393, to_date('05-12-2033', 'dd-mm-yyyy'), '1', '05', '339', '12', '2033', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12394, to_date('06-12-2033', 'dd-mm-yyyy'), '2', '06', '340', '12', '2033', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12395, to_date('07-12-2033', 'dd-mm-yyyy'), '3', '07', '341', '12', '2033', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12396, to_date('08-12-2033', 'dd-mm-yyyy'), '4', '08', '342', '12', '2033', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12397, to_date('09-12-2033', 'dd-mm-yyyy'), '5', '09', '343', '12', '2033', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12398, to_date('10-12-2033', 'dd-mm-yyyy'), '6', '10', '344', '12', '2033', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12399, to_date('11-12-2033', 'dd-mm-yyyy'), '7', '11', '345', '12', '2033', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12400, to_date('12-12-2033', 'dd-mm-yyyy'), '1', '12', '346', '12', '2033', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12401, to_date('13-12-2033', 'dd-mm-yyyy'), '2', '13', '347', '12', '2033', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12402, to_date('14-12-2033', 'dd-mm-yyyy'), '3', '14', '348', '12', '2033', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12403, to_date('15-12-2033', 'dd-mm-yyyy'), '4', '15', '349', '12', '2033', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12404, to_date('16-12-2033', 'dd-mm-yyyy'), '5', '16', '350', '12', '2033', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12405, to_date('17-12-2033', 'dd-mm-yyyy'), '6', '17', '351', '12', '2033', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12406, to_date('18-12-2033', 'dd-mm-yyyy'), '7', '18', '352', '12', '2033', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12407, to_date('19-12-2033', 'dd-mm-yyyy'), '1', '19', '353', '12', '2033', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12408, to_date('20-12-2033', 'dd-mm-yyyy'), '2', '20', '354', '12', '2033', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12409, to_date('21-12-2033', 'dd-mm-yyyy'), '3', '21', '355', '12', '2033', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12410, to_date('22-12-2033', 'dd-mm-yyyy'), '4', '22', '356', '12', '2033', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12411, to_date('23-12-2033', 'dd-mm-yyyy'), '5', '23', '357', '12', '2033', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12412, to_date('24-12-2033', 'dd-mm-yyyy'), '6', '24', '358', '12', '2033', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12413, to_date('25-12-2033', 'dd-mm-yyyy'), '7', '25', '359', '12', '2033', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12414, to_date('26-12-2033', 'dd-mm-yyyy'), '1', '26', '360', '12', '2033', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12415, to_date('27-12-2033', 'dd-mm-yyyy'), '2', '27', '361', '12', '2033', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12416, to_date('28-12-2033', 'dd-mm-yyyy'), '3', '28', '362', '12', '2033', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12417, to_date('29-12-2033', 'dd-mm-yyyy'), '4', '29', '363', '12', '2033', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12418, to_date('30-12-2033', 'dd-mm-yyyy'), '5', '30', '364', '12', '2033', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12419, to_date('31-12-2033', 'dd-mm-yyyy'), '6', '31', '365', '12', '2033', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12420, to_date('01-01-2034', 'dd-mm-yyyy'), '7', '01', '001', '01', '2034', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12421, to_date('02-01-2034', 'dd-mm-yyyy'), '1', '02', '002', '01', '2034', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12422, to_date('03-01-2034', 'dd-mm-yyyy'), '2', '03', '003', '01', '2034', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12423, to_date('04-01-2034', 'dd-mm-yyyy'), '3', '04', '004', '01', '2034', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12424, to_date('05-01-2034', 'dd-mm-yyyy'), '4', '05', '005', '01', '2034', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12425, to_date('06-01-2034', 'dd-mm-yyyy'), '5', '06', '006', '01', '2034', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12426, to_date('07-01-2034', 'dd-mm-yyyy'), '6', '07', '007', '01', '2034', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12427, to_date('08-01-2034', 'dd-mm-yyyy'), '7', '08', '008', '01', '2034', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12428, to_date('09-01-2034', 'dd-mm-yyyy'), '1', '09', '009', '01', '2034', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12429, to_date('10-01-2034', 'dd-mm-yyyy'), '2', '10', '010', '01', '2034', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12430, to_date('11-01-2034', 'dd-mm-yyyy'), '3', '11', '011', '01', '2034', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12431, to_date('12-01-2034', 'dd-mm-yyyy'), '4', '12', '012', '01', '2034', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12432, to_date('13-01-2034', 'dd-mm-yyyy'), '5', '13', '013', '01', '2034', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12433, to_date('14-01-2034', 'dd-mm-yyyy'), '6', '14', '014', '01', '2034', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12434, to_date('15-01-2034', 'dd-mm-yyyy'), '7', '15', '015', '01', '2034', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12435, to_date('16-01-2034', 'dd-mm-yyyy'), '1', '16', '016', '01', '2034', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12436, to_date('17-01-2034', 'dd-mm-yyyy'), '2', '17', '017', '01', '2034', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12437, to_date('18-01-2034', 'dd-mm-yyyy'), '3', '18', '018', '01', '2034', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12438, to_date('19-01-2034', 'dd-mm-yyyy'), '4', '19', '019', '01', '2034', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12439, to_date('20-01-2034', 'dd-mm-yyyy'), '5', '20', '020', '01', '2034', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12440, to_date('21-01-2034', 'dd-mm-yyyy'), '6', '21', '021', '01', '2034', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12441, to_date('22-01-2034', 'dd-mm-yyyy'), '7', '22', '022', '01', '2034', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12442, to_date('23-01-2034', 'dd-mm-yyyy'), '1', '23', '023', '01', '2034', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12443, to_date('24-01-2034', 'dd-mm-yyyy'), '2', '24', '024', '01', '2034', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12444, to_date('25-01-2034', 'dd-mm-yyyy'), '3', '25', '025', '01', '2034', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12445, to_date('26-01-2034', 'dd-mm-yyyy'), '4', '26', '026', '01', '2034', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12446, to_date('27-01-2034', 'dd-mm-yyyy'), '5', '27', '027', '01', '2034', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12447, to_date('28-01-2034', 'dd-mm-yyyy'), '6', '28', '028', '01', '2034', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12448, to_date('29-01-2034', 'dd-mm-yyyy'), '7', '29', '029', '01', '2034', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12449, to_date('30-01-2034', 'dd-mm-yyyy'), '1', '30', '030', '01', '2034', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12450, to_date('31-01-2034', 'dd-mm-yyyy'), '2', '31', '031', '01', '2034', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12451, to_date('01-02-2034', 'dd-mm-yyyy'), '3', '01', '032', '02', '2034', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12452, to_date('02-02-2034', 'dd-mm-yyyy'), '4', '02', '033', '02', '2034', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12453, to_date('03-02-2034', 'dd-mm-yyyy'), '5', '03', '034', '02', '2034', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12454, to_date('04-02-2034', 'dd-mm-yyyy'), '6', '04', '035', '02', '2034', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12455, to_date('05-02-2034', 'dd-mm-yyyy'), '7', '05', '036', '02', '2034', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12456, to_date('06-02-2034', 'dd-mm-yyyy'), '1', '06', '037', '02', '2034', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12457, to_date('07-02-2034', 'dd-mm-yyyy'), '2', '07', '038', '02', '2034', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12458, to_date('08-02-2034', 'dd-mm-yyyy'), '3', '08', '039', '02', '2034', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12459, to_date('09-02-2034', 'dd-mm-yyyy'), '4', '09', '040', '02', '2034', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12460, to_date('10-02-2034', 'dd-mm-yyyy'), '5', '10', '041', '02', '2034', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12461, to_date('11-02-2034', 'dd-mm-yyyy'), '6', '11', '042', '02', '2034', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12462, to_date('12-02-2034', 'dd-mm-yyyy'), '7', '12', '043', '02', '2034', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12463, to_date('13-02-2034', 'dd-mm-yyyy'), '1', '13', '044', '02', '2034', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12464, to_date('14-02-2034', 'dd-mm-yyyy'), '2', '14', '045', '02', '2034', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12465, to_date('15-02-2034', 'dd-mm-yyyy'), '3', '15', '046', '02', '2034', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12466, to_date('16-02-2034', 'dd-mm-yyyy'), '4', '16', '047', '02', '2034', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12467, to_date('17-02-2034', 'dd-mm-yyyy'), '5', '17', '048', '02', '2034', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12468, to_date('18-02-2034', 'dd-mm-yyyy'), '6', '18', '049', '02', '2034', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12469, to_date('19-02-2034', 'dd-mm-yyyy'), '7', '19', '050', '02', '2034', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12470, to_date('20-02-2034', 'dd-mm-yyyy'), '1', '20', '051', '02', '2034', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12471, to_date('21-02-2034', 'dd-mm-yyyy'), '2', '21', '052', '02', '2034', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12472, to_date('22-02-2034', 'dd-mm-yyyy'), '3', '22', '053', '02', '2034', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12473, to_date('23-02-2034', 'dd-mm-yyyy'), '4', '23', '054', '02', '2034', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12474, to_date('24-02-2034', 'dd-mm-yyyy'), '5', '24', '055', '02', '2034', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12475, to_date('25-02-2034', 'dd-mm-yyyy'), '6', '25', '056', '02', '2034', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12476, to_date('26-02-2034', 'dd-mm-yyyy'), '7', '26', '057', '02', '2034', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12477, to_date('27-02-2034', 'dd-mm-yyyy'), '1', '27', '058', '02', '2034', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12478, to_date('28-02-2034', 'dd-mm-yyyy'), '2', '28', '059', '02', '2034', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12479, to_date('01-03-2034', 'dd-mm-yyyy'), '3', '01', '060', '03', '2034', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12480, to_date('02-03-2034', 'dd-mm-yyyy'), '4', '02', '061', '03', '2034', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12481, to_date('03-03-2034', 'dd-mm-yyyy'), '5', '03', '062', '03', '2034', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12482, to_date('04-03-2034', 'dd-mm-yyyy'), '6', '04', '063', '03', '2034', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12483, to_date('05-03-2034', 'dd-mm-yyyy'), '7', '05', '064', '03', '2034', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12484, to_date('06-03-2034', 'dd-mm-yyyy'), '1', '06', '065', '03', '2034', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12485, to_date('07-03-2034', 'dd-mm-yyyy'), '2', '07', '066', '03', '2034', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12486, to_date('08-03-2034', 'dd-mm-yyyy'), '3', '08', '067', '03', '2034', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12487, to_date('09-03-2034', 'dd-mm-yyyy'), '4', '09', '068', '03', '2034', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12488, to_date('10-03-2034', 'dd-mm-yyyy'), '5', '10', '069', '03', '2034', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12489, to_date('11-03-2034', 'dd-mm-yyyy'), '6', '11', '070', '03', '2034', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12490, to_date('12-03-2034', 'dd-mm-yyyy'), '7', '12', '071', '03', '2034', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12491, to_date('13-03-2034', 'dd-mm-yyyy'), '1', '13', '072', '03', '2034', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12492, to_date('14-03-2034', 'dd-mm-yyyy'), '2', '14', '073', '03', '2034', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12493, to_date('15-03-2034', 'dd-mm-yyyy'), '3', '15', '074', '03', '2034', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12494, to_date('16-03-2034', 'dd-mm-yyyy'), '4', '16', '075', '03', '2034', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12495, to_date('17-03-2034', 'dd-mm-yyyy'), '5', '17', '076', '03', '2034', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12496, to_date('18-03-2034', 'dd-mm-yyyy'), '6', '18', '077', '03', '2034', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12497, to_date('19-03-2034', 'dd-mm-yyyy'), '7', '19', '078', '03', '2034', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12498, to_date('20-03-2034', 'dd-mm-yyyy'), '1', '20', '079', '03', '2034', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12499, to_date('21-03-2034', 'dd-mm-yyyy'), '2', '21', '080', '03', '2034', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12500, to_date('22-03-2034', 'dd-mm-yyyy'), '3', '22', '081', '03', '2034', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12501, to_date('23-03-2034', 'dd-mm-yyyy'), '4', '23', '082', '03', '2034', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12502, to_date('24-03-2034', 'dd-mm-yyyy'), '5', '24', '083', '03', '2034', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12503, to_date('25-03-2034', 'dd-mm-yyyy'), '6', '25', '084', '03', '2034', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12504, to_date('26-03-2034', 'dd-mm-yyyy'), '7', '26', '085', '03', '2034', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12505, to_date('27-03-2034', 'dd-mm-yyyy'), '1', '27', '086', '03', '2034', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12506, to_date('28-03-2034', 'dd-mm-yyyy'), '2', '28', '087', '03', '2034', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12507, to_date('29-03-2034', 'dd-mm-yyyy'), '3', '29', '088', '03', '2034', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12508, to_date('30-03-2034', 'dd-mm-yyyy'), '4', '30', '089', '03', '2034', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12509, to_date('31-03-2034', 'dd-mm-yyyy'), '5', '31', '090', '03', '2034', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12510, to_date('01-04-2034', 'dd-mm-yyyy'), '6', '01', '091', '04', '2034', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12511, to_date('02-04-2034', 'dd-mm-yyyy'), '7', '02', '092', '04', '2034', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12512, to_date('03-04-2034', 'dd-mm-yyyy'), '1', '03', '093', '04', '2034', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12513, to_date('04-04-2034', 'dd-mm-yyyy'), '2', '04', '094', '04', '2034', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12514, to_date('05-04-2034', 'dd-mm-yyyy'), '3', '05', '095', '04', '2034', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12515, to_date('06-04-2034', 'dd-mm-yyyy'), '4', '06', '096', '04', '2034', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12516, to_date('07-04-2034', 'dd-mm-yyyy'), '5', '07', '097', '04', '2034', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12517, to_date('08-04-2034', 'dd-mm-yyyy'), '6', '08', '098', '04', '2034', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12518, to_date('09-04-2034', 'dd-mm-yyyy'), '7', '09', '099', '04', '2034', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12519, to_date('10-04-2034', 'dd-mm-yyyy'), '1', '10', '100', '04', '2034', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12520, to_date('11-04-2034', 'dd-mm-yyyy'), '2', '11', '101', '04', '2034', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12521, to_date('12-04-2034', 'dd-mm-yyyy'), '3', '12', '102', '04', '2034', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12522, to_date('13-04-2034', 'dd-mm-yyyy'), '4', '13', '103', '04', '2034', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12523, to_date('14-04-2034', 'dd-mm-yyyy'), '5', '14', '104', '04', '2034', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12524, to_date('15-04-2034', 'dd-mm-yyyy'), '6', '15', '105', '04', '2034', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12525, to_date('16-04-2034', 'dd-mm-yyyy'), '7', '16', '106', '04', '2034', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12526, to_date('17-04-2034', 'dd-mm-yyyy'), '1', '17', '107', '04', '2034', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12527, to_date('18-04-2034', 'dd-mm-yyyy'), '2', '18', '108', '04', '2034', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12528, to_date('19-04-2034', 'dd-mm-yyyy'), '3', '19', '109', '04', '2034', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12529, to_date('20-04-2034', 'dd-mm-yyyy'), '4', '20', '110', '04', '2034', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12530, to_date('21-04-2034', 'dd-mm-yyyy'), '5', '21', '111', '04', '2034', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12531, to_date('22-04-2034', 'dd-mm-yyyy'), '6', '22', '112', '04', '2034', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12532, to_date('23-04-2034', 'dd-mm-yyyy'), '7', '23', '113', '04', '2034', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12533, to_date('24-04-2034', 'dd-mm-yyyy'), '1', '24', '114', '04', '2034', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12534, to_date('25-04-2034', 'dd-mm-yyyy'), '2', '25', '115', '04', '2034', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12535, to_date('26-04-2034', 'dd-mm-yyyy'), '3', '26', '116', '04', '2034', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12536, to_date('27-04-2034', 'dd-mm-yyyy'), '4', '27', '117', '04', '2034', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12537, to_date('28-04-2034', 'dd-mm-yyyy'), '5', '28', '118', '04', '2034', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12538, to_date('29-04-2034', 'dd-mm-yyyy'), '6', '29', '119', '04', '2034', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12539, to_date('30-04-2034', 'dd-mm-yyyy'), '7', '30', '120', '04', '2034', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12540, to_date('01-05-2034', 'dd-mm-yyyy'), '1', '01', '121', '05', '2034', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12541, to_date('02-05-2034', 'dd-mm-yyyy'), '2', '02', '122', '05', '2034', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12542, to_date('03-05-2034', 'dd-mm-yyyy'), '3', '03', '123', '05', '2034', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12543, to_date('04-05-2034', 'dd-mm-yyyy'), '4', '04', '124', '05', '2034', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12544, to_date('05-05-2034', 'dd-mm-yyyy'), '5', '05', '125', '05', '2034', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12545, to_date('06-05-2034', 'dd-mm-yyyy'), '6', '06', '126', '05', '2034', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12546, to_date('07-05-2034', 'dd-mm-yyyy'), '7', '07', '127', '05', '2034', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12547, to_date('08-05-2034', 'dd-mm-yyyy'), '1', '08', '128', '05', '2034', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12548, to_date('09-05-2034', 'dd-mm-yyyy'), '2', '09', '129', '05', '2034', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12549, to_date('10-05-2034', 'dd-mm-yyyy'), '3', '10', '130', '05', '2034', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12550, to_date('11-05-2034', 'dd-mm-yyyy'), '4', '11', '131', '05', '2034', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12551, to_date('12-05-2034', 'dd-mm-yyyy'), '5', '12', '132', '05', '2034', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12552, to_date('13-05-2034', 'dd-mm-yyyy'), '6', '13', '133', '05', '2034', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12553, to_date('14-05-2034', 'dd-mm-yyyy'), '7', '14', '134', '05', '2034', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12554, to_date('15-05-2034', 'dd-mm-yyyy'), '1', '15', '135', '05', '2034', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12555, to_date('16-05-2034', 'dd-mm-yyyy'), '2', '16', '136', '05', '2034', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12556, to_date('17-05-2034', 'dd-mm-yyyy'), '3', '17', '137', '05', '2034', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12557, to_date('18-05-2034', 'dd-mm-yyyy'), '4', '18', '138', '05', '2034', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12558, to_date('19-05-2034', 'dd-mm-yyyy'), '5', '19', '139', '05', '2034', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12559, to_date('20-05-2034', 'dd-mm-yyyy'), '6', '20', '140', '05', '2034', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12560, to_date('21-05-2034', 'dd-mm-yyyy'), '7', '21', '141', '05', '2034', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12561, to_date('22-05-2034', 'dd-mm-yyyy'), '1', '22', '142', '05', '2034', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12562, to_date('23-05-2034', 'dd-mm-yyyy'), '2', '23', '143', '05', '2034', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12563, to_date('24-05-2034', 'dd-mm-yyyy'), '3', '24', '144', '05', '2034', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12564, to_date('25-05-2034', 'dd-mm-yyyy'), '4', '25', '145', '05', '2034', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12565, to_date('26-05-2034', 'dd-mm-yyyy'), '5', '26', '146', '05', '2034', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12566, to_date('27-05-2034', 'dd-mm-yyyy'), '6', '27', '147', '05', '2034', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12567, to_date('28-05-2034', 'dd-mm-yyyy'), '7', '28', '148', '05', '2034', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12568, to_date('29-05-2034', 'dd-mm-yyyy'), '1', '29', '149', '05', '2034', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12569, to_date('30-05-2034', 'dd-mm-yyyy'), '2', '30', '150', '05', '2034', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12570, to_date('31-05-2034', 'dd-mm-yyyy'), '3', '31', '151', '05', '2034', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12571, to_date('01-06-2034', 'dd-mm-yyyy'), '4', '01', '152', '06', '2034', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12572, to_date('02-06-2034', 'dd-mm-yyyy'), '5', '02', '153', '06', '2034', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12573, to_date('03-06-2034', 'dd-mm-yyyy'), '6', '03', '154', '06', '2034', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12574, to_date('04-06-2034', 'dd-mm-yyyy'), '7', '04', '155', '06', '2034', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12575, to_date('05-06-2034', 'dd-mm-yyyy'), '1', '05', '156', '06', '2034', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12576, to_date('06-06-2034', 'dd-mm-yyyy'), '2', '06', '157', '06', '2034', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12577, to_date('07-06-2034', 'dd-mm-yyyy'), '3', '07', '158', '06', '2034', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12578, to_date('08-06-2034', 'dd-mm-yyyy'), '4', '08', '159', '06', '2034', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12579, to_date('09-06-2034', 'dd-mm-yyyy'), '5', '09', '160', '06', '2034', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12580, to_date('10-06-2034', 'dd-mm-yyyy'), '6', '10', '161', '06', '2034', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12581, to_date('11-06-2034', 'dd-mm-yyyy'), '7', '11', '162', '06', '2034', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12582, to_date('12-06-2034', 'dd-mm-yyyy'), '1', '12', '163', '06', '2034', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12583, to_date('13-06-2034', 'dd-mm-yyyy'), '2', '13', '164', '06', '2034', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12584, to_date('14-06-2034', 'dd-mm-yyyy'), '3', '14', '165', '06', '2034', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12585, to_date('15-06-2034', 'dd-mm-yyyy'), '4', '15', '166', '06', '2034', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12586, to_date('16-06-2034', 'dd-mm-yyyy'), '5', '16', '167', '06', '2034', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12587, to_date('17-06-2034', 'dd-mm-yyyy'), '6', '17', '168', '06', '2034', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12588, to_date('18-06-2034', 'dd-mm-yyyy'), '7', '18', '169', '06', '2034', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11847, to_date('07-06-2032', 'dd-mm-yyyy'), '1', '07', '159', '06', '2032', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11848, to_date('08-06-2032', 'dd-mm-yyyy'), '2', '08', '160', '06', '2032', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11849, to_date('09-06-2032', 'dd-mm-yyyy'), '3', '09', '161', '06', '2032', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11850, to_date('10-06-2032', 'dd-mm-yyyy'), '4', '10', '162', '06', '2032', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11851, to_date('11-06-2032', 'dd-mm-yyyy'), '5', '11', '163', '06', '2032', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11852, to_date('12-06-2032', 'dd-mm-yyyy'), '6', '12', '164', '06', '2032', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11853, to_date('13-06-2032', 'dd-mm-yyyy'), '7', '13', '165', '06', '2032', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11854, to_date('14-06-2032', 'dd-mm-yyyy'), '1', '14', '166', '06', '2032', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11855, to_date('15-06-2032', 'dd-mm-yyyy'), '2', '15', '167', '06', '2032', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11856, to_date('16-06-2032', 'dd-mm-yyyy'), '3', '16', '168', '06', '2032', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11857, to_date('17-06-2032', 'dd-mm-yyyy'), '4', '17', '169', '06', '2032', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11858, to_date('18-06-2032', 'dd-mm-yyyy'), '5', '18', '170', '06', '2032', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11859, to_date('19-06-2032', 'dd-mm-yyyy'), '6', '19', '171', '06', '2032', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11860, to_date('20-06-2032', 'dd-mm-yyyy'), '7', '20', '172', '06', '2032', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11861, to_date('21-06-2032', 'dd-mm-yyyy'), '1', '21', '173', '06', '2032', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11862, to_date('22-06-2032', 'dd-mm-yyyy'), '2', '22', '174', '06', '2032', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11863, to_date('23-06-2032', 'dd-mm-yyyy'), '3', '23', '175', '06', '2032', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11864, to_date('24-06-2032', 'dd-mm-yyyy'), '4', '24', '176', '06', '2032', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11865, to_date('25-06-2032', 'dd-mm-yyyy'), '5', '25', '177', '06', '2032', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11866, to_date('26-06-2032', 'dd-mm-yyyy'), '6', '26', '178', '06', '2032', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11867, to_date('27-06-2032', 'dd-mm-yyyy'), '7', '27', '179', '06', '2032', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11868, to_date('28-06-2032', 'dd-mm-yyyy'), '1', '28', '180', '06', '2032', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11869, to_date('29-06-2032', 'dd-mm-yyyy'), '2', '29', '181', '06', '2032', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11870, to_date('30-06-2032', 'dd-mm-yyyy'), '3', '30', '182', '06', '2032', '27', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11871, to_date('01-07-2032', 'dd-mm-yyyy'), '4', '01', '183', '07', '2032', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11872, to_date('02-07-2032', 'dd-mm-yyyy'), '5', '02', '184', '07', '2032', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11873, to_date('03-07-2032', 'dd-mm-yyyy'), '6', '03', '185', '07', '2032', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11874, to_date('04-07-2032', 'dd-mm-yyyy'), '7', '04', '186', '07', '2032', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11875, to_date('05-07-2032', 'dd-mm-yyyy'), '1', '05', '187', '07', '2032', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11876, to_date('06-07-2032', 'dd-mm-yyyy'), '2', '06', '188', '07', '2032', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11877, to_date('07-07-2032', 'dd-mm-yyyy'), '3', '07', '189', '07', '2032', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11878, to_date('08-07-2032', 'dd-mm-yyyy'), '4', '08', '190', '07', '2032', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11879, to_date('09-07-2032', 'dd-mm-yyyy'), '5', '09', '191', '07', '2032', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11880, to_date('10-07-2032', 'dd-mm-yyyy'), '6', '10', '192', '07', '2032', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11881, to_date('11-07-2032', 'dd-mm-yyyy'), '7', '11', '193', '07', '2032', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11882, to_date('12-07-2032', 'dd-mm-yyyy'), '1', '12', '194', '07', '2032', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11883, to_date('13-07-2032', 'dd-mm-yyyy'), '2', '13', '195', '07', '2032', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11884, to_date('14-07-2032', 'dd-mm-yyyy'), '3', '14', '196', '07', '2032', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11885, to_date('15-07-2032', 'dd-mm-yyyy'), '4', '15', '197', '07', '2032', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11886, to_date('16-07-2032', 'dd-mm-yyyy'), '5', '16', '198', '07', '2032', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11887, to_date('17-07-2032', 'dd-mm-yyyy'), '6', '17', '199', '07', '2032', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11888, to_date('18-07-2032', 'dd-mm-yyyy'), '7', '18', '200', '07', '2032', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11889, to_date('19-07-2032', 'dd-mm-yyyy'), '1', '19', '201', '07', '2032', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11890, to_date('20-07-2032', 'dd-mm-yyyy'), '2', '20', '202', '07', '2032', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11891, to_date('21-07-2032', 'dd-mm-yyyy'), '3', '21', '203', '07', '2032', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11892, to_date('22-07-2032', 'dd-mm-yyyy'), '4', '22', '204', '07', '2032', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11893, to_date('23-07-2032', 'dd-mm-yyyy'), '5', '23', '205', '07', '2032', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11894, to_date('24-07-2032', 'dd-mm-yyyy'), '6', '24', '206', '07', '2032', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11895, to_date('25-07-2032', 'dd-mm-yyyy'), '7', '25', '207', '07', '2032', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11896, to_date('26-07-2032', 'dd-mm-yyyy'), '1', '26', '208', '07', '2032', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11897, to_date('27-07-2032', 'dd-mm-yyyy'), '2', '27', '209', '07', '2032', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11898, to_date('28-07-2032', 'dd-mm-yyyy'), '3', '28', '210', '07', '2032', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11899, to_date('29-07-2032', 'dd-mm-yyyy'), '4', '29', '211', '07', '2032', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11900, to_date('30-07-2032', 'dd-mm-yyyy'), '5', '30', '212', '07', '2032', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11901, to_date('31-07-2032', 'dd-mm-yyyy'), '6', '31', '213', '07', '2032', '31', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11902, to_date('01-08-2032', 'dd-mm-yyyy'), '7', '01', '214', '08', '2032', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11903, to_date('02-08-2032', 'dd-mm-yyyy'), '1', '02', '215', '08', '2032', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11904, to_date('03-08-2032', 'dd-mm-yyyy'), '2', '03', '216', '08', '2032', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11905, to_date('04-08-2032', 'dd-mm-yyyy'), '3', '04', '217', '08', '2032', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11906, to_date('05-08-2032', 'dd-mm-yyyy'), '4', '05', '218', '08', '2032', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11907, to_date('06-08-2032', 'dd-mm-yyyy'), '5', '06', '219', '08', '2032', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11908, to_date('07-08-2032', 'dd-mm-yyyy'), '6', '07', '220', '08', '2032', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11909, to_date('08-08-2032', 'dd-mm-yyyy'), '7', '08', '221', '08', '2032', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11910, to_date('09-08-2032', 'dd-mm-yyyy'), '1', '09', '222', '08', '2032', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11911, to_date('10-08-2032', 'dd-mm-yyyy'), '2', '10', '223', '08', '2032', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11912, to_date('11-08-2032', 'dd-mm-yyyy'), '3', '11', '224', '08', '2032', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11913, to_date('12-08-2032', 'dd-mm-yyyy'), '4', '12', '225', '08', '2032', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11914, to_date('13-08-2032', 'dd-mm-yyyy'), '5', '13', '226', '08', '2032', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11915, to_date('14-08-2032', 'dd-mm-yyyy'), '6', '14', '227', '08', '2032', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11916, to_date('15-08-2032', 'dd-mm-yyyy'), '7', '15', '228', '08', '2032', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11917, to_date('16-08-2032', 'dd-mm-yyyy'), '1', '16', '229', '08', '2032', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11918, to_date('17-08-2032', 'dd-mm-yyyy'), '2', '17', '230', '08', '2032', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11919, to_date('18-08-2032', 'dd-mm-yyyy'), '3', '18', '231', '08', '2032', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11920, to_date('19-08-2032', 'dd-mm-yyyy'), '4', '19', '232', '08', '2032', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11921, to_date('20-08-2032', 'dd-mm-yyyy'), '5', '20', '233', '08', '2032', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11922, to_date('21-08-2032', 'dd-mm-yyyy'), '6', '21', '234', '08', '2032', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11923, to_date('22-08-2032', 'dd-mm-yyyy'), '7', '22', '235', '08', '2032', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11924, to_date('23-08-2032', 'dd-mm-yyyy'), '1', '23', '236', '08', '2032', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11925, to_date('24-08-2032', 'dd-mm-yyyy'), '2', '24', '237', '08', '2032', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11926, to_date('25-08-2032', 'dd-mm-yyyy'), '3', '25', '238', '08', '2032', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11927, to_date('26-08-2032', 'dd-mm-yyyy'), '4', '26', '239', '08', '2032', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11928, to_date('27-08-2032', 'dd-mm-yyyy'), '5', '27', '240', '08', '2032', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11929, to_date('28-08-2032', 'dd-mm-yyyy'), '6', '28', '241', '08', '2032', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11930, to_date('29-08-2032', 'dd-mm-yyyy'), '7', '29', '242', '08', '2032', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11931, to_date('30-08-2032', 'dd-mm-yyyy'), '1', '30', '243', '08', '2032', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11932, to_date('31-08-2032', 'dd-mm-yyyy'), '2', '31', '244', '08', '2032', '36', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11933, to_date('01-09-2032', 'dd-mm-yyyy'), '3', '01', '245', '09', '2032', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11934, to_date('02-09-2032', 'dd-mm-yyyy'), '4', '02', '246', '09', '2032', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11935, to_date('03-09-2032', 'dd-mm-yyyy'), '5', '03', '247', '09', '2032', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11936, to_date('04-09-2032', 'dd-mm-yyyy'), '6', '04', '248', '09', '2032', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11937, to_date('05-09-2032', 'dd-mm-yyyy'), '7', '05', '249', '09', '2032', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11938, to_date('06-09-2032', 'dd-mm-yyyy'), '1', '06', '250', '09', '2032', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11939, to_date('07-09-2032', 'dd-mm-yyyy'), '2', '07', '251', '09', '2032', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11940, to_date('08-09-2032', 'dd-mm-yyyy'), '3', '08', '252', '09', '2032', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11941, to_date('09-09-2032', 'dd-mm-yyyy'), '4', '09', '253', '09', '2032', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11942, to_date('10-09-2032', 'dd-mm-yyyy'), '5', '10', '254', '09', '2032', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11943, to_date('11-09-2032', 'dd-mm-yyyy'), '6', '11', '255', '09', '2032', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11944, to_date('12-09-2032', 'dd-mm-yyyy'), '7', '12', '256', '09', '2032', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11945, to_date('13-09-2032', 'dd-mm-yyyy'), '1', '13', '257', '09', '2032', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11946, to_date('14-09-2032', 'dd-mm-yyyy'), '2', '14', '258', '09', '2032', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11947, to_date('15-09-2032', 'dd-mm-yyyy'), '3', '15', '259', '09', '2032', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11948, to_date('16-09-2032', 'dd-mm-yyyy'), '4', '16', '260', '09', '2032', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11949, to_date('17-09-2032', 'dd-mm-yyyy'), '5', '17', '261', '09', '2032', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11950, to_date('18-09-2032', 'dd-mm-yyyy'), '6', '18', '262', '09', '2032', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11951, to_date('19-09-2032', 'dd-mm-yyyy'), '7', '19', '263', '09', '2032', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (11952, to_date('20-09-2032', 'dd-mm-yyyy'), '1', '20', '264', '09', '2032', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20963, to_date('23-05-2057', 'dd-mm-yyyy'), '3', '23', '143', '05', '2057', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20964, to_date('24-05-2057', 'dd-mm-yyyy'), '4', '24', '144', '05', '2057', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20965, to_date('25-05-2057', 'dd-mm-yyyy'), '5', '25', '145', '05', '2057', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20966, to_date('26-05-2057', 'dd-mm-yyyy'), '6', '26', '146', '05', '2057', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20967, to_date('27-05-2057', 'dd-mm-yyyy'), '7', '27', '147', '05', '2057', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20968, to_date('28-05-2057', 'dd-mm-yyyy'), '1', '28', '148', '05', '2057', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20969, to_date('29-05-2057', 'dd-mm-yyyy'), '2', '29', '149', '05', '2057', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20970, to_date('30-05-2057', 'dd-mm-yyyy'), '3', '30', '150', '05', '2057', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20971, to_date('31-05-2057', 'dd-mm-yyyy'), '4', '31', '151', '05', '2057', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20972, to_date('01-06-2057', 'dd-mm-yyyy'), '5', '01', '152', '06', '2057', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20973, to_date('02-06-2057', 'dd-mm-yyyy'), '6', '02', '153', '06', '2057', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20974, to_date('03-06-2057', 'dd-mm-yyyy'), '7', '03', '154', '06', '2057', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20975, to_date('04-06-2057', 'dd-mm-yyyy'), '1', '04', '155', '06', '2057', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20976, to_date('05-06-2057', 'dd-mm-yyyy'), '2', '05', '156', '06', '2057', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20977, to_date('06-06-2057', 'dd-mm-yyyy'), '3', '06', '157', '06', '2057', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20978, to_date('07-06-2057', 'dd-mm-yyyy'), '4', '07', '158', '06', '2057', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20979, to_date('08-06-2057', 'dd-mm-yyyy'), '5', '08', '159', '06', '2057', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20980, to_date('09-06-2057', 'dd-mm-yyyy'), '6', '09', '160', '06', '2057', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20981, to_date('10-06-2057', 'dd-mm-yyyy'), '7', '10', '161', '06', '2057', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20982, to_date('11-06-2057', 'dd-mm-yyyy'), '1', '11', '162', '06', '2057', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20983, to_date('12-06-2057', 'dd-mm-yyyy'), '2', '12', '163', '06', '2057', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20984, to_date('13-06-2057', 'dd-mm-yyyy'), '3', '13', '164', '06', '2057', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20985, to_date('14-06-2057', 'dd-mm-yyyy'), '4', '14', '165', '06', '2057', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20986, to_date('15-06-2057', 'dd-mm-yyyy'), '5', '15', '166', '06', '2057', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20987, to_date('16-06-2057', 'dd-mm-yyyy'), '6', '16', '167', '06', '2057', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20988, to_date('17-06-2057', 'dd-mm-yyyy'), '7', '17', '168', '06', '2057', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20989, to_date('18-06-2057', 'dd-mm-yyyy'), '1', '18', '169', '06', '2057', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20990, to_date('19-06-2057', 'dd-mm-yyyy'), '2', '19', '170', '06', '2057', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20991, to_date('20-06-2057', 'dd-mm-yyyy'), '3', '20', '171', '06', '2057', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20992, to_date('21-06-2057', 'dd-mm-yyyy'), '4', '21', '172', '06', '2057', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20993, to_date('22-06-2057', 'dd-mm-yyyy'), '5', '22', '173', '06', '2057', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20994, to_date('23-06-2057', 'dd-mm-yyyy'), '6', '23', '174', '06', '2057', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20995, to_date('24-06-2057', 'dd-mm-yyyy'), '7', '24', '175', '06', '2057', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20996, to_date('25-06-2057', 'dd-mm-yyyy'), '1', '25', '176', '06', '2057', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20997, to_date('26-06-2057', 'dd-mm-yyyy'), '2', '26', '177', '06', '2057', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20998, to_date('27-06-2057', 'dd-mm-yyyy'), '3', '27', '178', '06', '2057', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20999, to_date('28-06-2057', 'dd-mm-yyyy'), '4', '28', '179', '06', '2057', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21000, to_date('29-06-2057', 'dd-mm-yyyy'), '5', '29', '180', '06', '2057', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21001, to_date('30-06-2057', 'dd-mm-yyyy'), '6', '30', '181', '06', '2057', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21002, to_date('01-07-2057', 'dd-mm-yyyy'), '7', '01', '182', '07', '2057', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21003, to_date('02-07-2057', 'dd-mm-yyyy'), '1', '02', '183', '07', '2057', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21004, to_date('03-07-2057', 'dd-mm-yyyy'), '2', '03', '184', '07', '2057', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21005, to_date('04-07-2057', 'dd-mm-yyyy'), '3', '04', '185', '07', '2057', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21006, to_date('05-07-2057', 'dd-mm-yyyy'), '4', '05', '186', '07', '2057', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21007, to_date('06-07-2057', 'dd-mm-yyyy'), '5', '06', '187', '07', '2057', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21008, to_date('07-07-2057', 'dd-mm-yyyy'), '6', '07', '188', '07', '2057', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21009, to_date('08-07-2057', 'dd-mm-yyyy'), '7', '08', '189', '07', '2057', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21010, to_date('09-07-2057', 'dd-mm-yyyy'), '1', '09', '190', '07', '2057', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21011, to_date('10-07-2057', 'dd-mm-yyyy'), '2', '10', '191', '07', '2057', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21012, to_date('11-07-2057', 'dd-mm-yyyy'), '3', '11', '192', '07', '2057', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21013, to_date('12-07-2057', 'dd-mm-yyyy'), '4', '12', '193', '07', '2057', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21014, to_date('13-07-2057', 'dd-mm-yyyy'), '5', '13', '194', '07', '2057', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21015, to_date('14-07-2057', 'dd-mm-yyyy'), '6', '14', '195', '07', '2057', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21016, to_date('15-07-2057', 'dd-mm-yyyy'), '7', '15', '196', '07', '2057', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21017, to_date('16-07-2057', 'dd-mm-yyyy'), '1', '16', '197', '07', '2057', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21018, to_date('17-07-2057', 'dd-mm-yyyy'), '2', '17', '198', '07', '2057', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21019, to_date('18-07-2057', 'dd-mm-yyyy'), '3', '18', '199', '07', '2057', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21020, to_date('19-07-2057', 'dd-mm-yyyy'), '4', '19', '200', '07', '2057', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21021, to_date('20-07-2057', 'dd-mm-yyyy'), '5', '20', '201', '07', '2057', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21022, to_date('21-07-2057', 'dd-mm-yyyy'), '6', '21', '202', '07', '2057', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21023, to_date('22-07-2057', 'dd-mm-yyyy'), '7', '22', '203', '07', '2057', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21024, to_date('23-07-2057', 'dd-mm-yyyy'), '1', '23', '204', '07', '2057', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21025, to_date('24-07-2057', 'dd-mm-yyyy'), '2', '24', '205', '07', '2057', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21026, to_date('25-07-2057', 'dd-mm-yyyy'), '3', '25', '206', '07', '2057', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21027, to_date('26-07-2057', 'dd-mm-yyyy'), '4', '26', '207', '07', '2057', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21028, to_date('27-07-2057', 'dd-mm-yyyy'), '5', '27', '208', '07', '2057', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21029, to_date('28-07-2057', 'dd-mm-yyyy'), '6', '28', '209', '07', '2057', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21030, to_date('29-07-2057', 'dd-mm-yyyy'), '7', '29', '210', '07', '2057', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21031, to_date('30-07-2057', 'dd-mm-yyyy'), '1', '30', '211', '07', '2057', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21032, to_date('31-07-2057', 'dd-mm-yyyy'), '2', '31', '212', '07', '2057', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21033, to_date('01-08-2057', 'dd-mm-yyyy'), '3', '01', '213', '08', '2057', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21034, to_date('02-08-2057', 'dd-mm-yyyy'), '4', '02', '214', '08', '2057', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21035, to_date('03-08-2057', 'dd-mm-yyyy'), '5', '03', '215', '08', '2057', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21036, to_date('04-08-2057', 'dd-mm-yyyy'), '6', '04', '216', '08', '2057', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21037, to_date('05-08-2057', 'dd-mm-yyyy'), '7', '05', '217', '08', '2057', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21038, to_date('06-08-2057', 'dd-mm-yyyy'), '1', '06', '218', '08', '2057', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21039, to_date('07-08-2057', 'dd-mm-yyyy'), '2', '07', '219', '08', '2057', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21040, to_date('08-08-2057', 'dd-mm-yyyy'), '3', '08', '220', '08', '2057', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21041, to_date('09-08-2057', 'dd-mm-yyyy'), '4', '09', '221', '08', '2057', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21042, to_date('10-08-2057', 'dd-mm-yyyy'), '5', '10', '222', '08', '2057', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21043, to_date('11-08-2057', 'dd-mm-yyyy'), '6', '11', '223', '08', '2057', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21044, to_date('12-08-2057', 'dd-mm-yyyy'), '7', '12', '224', '08', '2057', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21045, to_date('13-08-2057', 'dd-mm-yyyy'), '1', '13', '225', '08', '2057', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21046, to_date('14-08-2057', 'dd-mm-yyyy'), '2', '14', '226', '08', '2057', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21047, to_date('15-08-2057', 'dd-mm-yyyy'), '3', '15', '227', '08', '2057', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21048, to_date('16-08-2057', 'dd-mm-yyyy'), '4', '16', '228', '08', '2057', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21049, to_date('17-08-2057', 'dd-mm-yyyy'), '5', '17', '229', '08', '2057', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21050, to_date('18-08-2057', 'dd-mm-yyyy'), '6', '18', '230', '08', '2057', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21051, to_date('19-08-2057', 'dd-mm-yyyy'), '7', '19', '231', '08', '2057', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21052, to_date('20-08-2057', 'dd-mm-yyyy'), '1', '20', '232', '08', '2057', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21053, to_date('21-08-2057', 'dd-mm-yyyy'), '2', '21', '233', '08', '2057', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21054, to_date('22-08-2057', 'dd-mm-yyyy'), '3', '22', '234', '08', '2057', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21055, to_date('23-08-2057', 'dd-mm-yyyy'), '4', '23', '235', '08', '2057', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21056, to_date('24-08-2057', 'dd-mm-yyyy'), '5', '24', '236', '08', '2057', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21057, to_date('25-08-2057', 'dd-mm-yyyy'), '6', '25', '237', '08', '2057', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21058, to_date('26-08-2057', 'dd-mm-yyyy'), '7', '26', '238', '08', '2057', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21059, to_date('27-08-2057', 'dd-mm-yyyy'), '1', '27', '239', '08', '2057', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21060, to_date('28-08-2057', 'dd-mm-yyyy'), '2', '28', '240', '08', '2057', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21061, to_date('29-08-2057', 'dd-mm-yyyy'), '3', '29', '241', '08', '2057', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21062, to_date('30-08-2057', 'dd-mm-yyyy'), '4', '30', '242', '08', '2057', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21063, to_date('31-08-2057', 'dd-mm-yyyy'), '5', '31', '243', '08', '2057', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21064, to_date('01-09-2057', 'dd-mm-yyyy'), '6', '01', '244', '09', '2057', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21065, to_date('02-09-2057', 'dd-mm-yyyy'), '7', '02', '245', '09', '2057', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21066, to_date('03-09-2057', 'dd-mm-yyyy'), '1', '03', '246', '09', '2057', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21067, to_date('04-09-2057', 'dd-mm-yyyy'), '2', '04', '247', '09', '2057', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21068, to_date('05-09-2057', 'dd-mm-yyyy'), '3', '05', '248', '09', '2057', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22553, to_date('29-09-2061', 'dd-mm-yyyy'), '4', '29', '272', '09', '2061', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22554, to_date('30-09-2061', 'dd-mm-yyyy'), '5', '30', '273', '09', '2061', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22555, to_date('01-10-2061', 'dd-mm-yyyy'), '6', '01', '274', '10', '2061', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22556, to_date('02-10-2061', 'dd-mm-yyyy'), '7', '02', '275', '10', '2061', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22557, to_date('03-10-2061', 'dd-mm-yyyy'), '1', '03', '276', '10', '2061', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22558, to_date('04-10-2061', 'dd-mm-yyyy'), '2', '04', '277', '10', '2061', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22559, to_date('05-10-2061', 'dd-mm-yyyy'), '3', '05', '278', '10', '2061', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22560, to_date('06-10-2061', 'dd-mm-yyyy'), '4', '06', '279', '10', '2061', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22561, to_date('07-10-2061', 'dd-mm-yyyy'), '5', '07', '280', '10', '2061', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22562, to_date('08-10-2061', 'dd-mm-yyyy'), '6', '08', '281', '10', '2061', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22563, to_date('09-10-2061', 'dd-mm-yyyy'), '7', '09', '282', '10', '2061', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22564, to_date('10-10-2061', 'dd-mm-yyyy'), '1', '10', '283', '10', '2061', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22565, to_date('11-10-2061', 'dd-mm-yyyy'), '2', '11', '284', '10', '2061', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22566, to_date('12-10-2061', 'dd-mm-yyyy'), '3', '12', '285', '10', '2061', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22567, to_date('13-10-2061', 'dd-mm-yyyy'), '4', '13', '286', '10', '2061', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22568, to_date('14-10-2061', 'dd-mm-yyyy'), '5', '14', '287', '10', '2061', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22569, to_date('15-10-2061', 'dd-mm-yyyy'), '6', '15', '288', '10', '2061', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22570, to_date('16-10-2061', 'dd-mm-yyyy'), '7', '16', '289', '10', '2061', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22571, to_date('17-10-2061', 'dd-mm-yyyy'), '1', '17', '290', '10', '2061', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22572, to_date('18-10-2061', 'dd-mm-yyyy'), '2', '18', '291', '10', '2061', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22573, to_date('19-10-2061', 'dd-mm-yyyy'), '3', '19', '292', '10', '2061', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22574, to_date('20-10-2061', 'dd-mm-yyyy'), '4', '20', '293', '10', '2061', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22575, to_date('21-10-2061', 'dd-mm-yyyy'), '5', '21', '294', '10', '2061', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22576, to_date('22-10-2061', 'dd-mm-yyyy'), '6', '22', '295', '10', '2061', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22577, to_date('23-10-2061', 'dd-mm-yyyy'), '7', '23', '296', '10', '2061', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22578, to_date('24-10-2061', 'dd-mm-yyyy'), '1', '24', '297', '10', '2061', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22579, to_date('25-10-2061', 'dd-mm-yyyy'), '2', '25', '298', '10', '2061', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22580, to_date('26-10-2061', 'dd-mm-yyyy'), '3', '26', '299', '10', '2061', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22581, to_date('27-10-2061', 'dd-mm-yyyy'), '4', '27', '300', '10', '2061', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22582, to_date('28-10-2061', 'dd-mm-yyyy'), '5', '28', '301', '10', '2061', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22583, to_date('29-10-2061', 'dd-mm-yyyy'), '6', '29', '302', '10', '2061', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22584, to_date('30-10-2061', 'dd-mm-yyyy'), '7', '30', '303', '10', '2061', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22585, to_date('31-10-2061', 'dd-mm-yyyy'), '1', '31', '304', '10', '2061', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22586, to_date('01-11-2061', 'dd-mm-yyyy'), '2', '01', '305', '11', '2061', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22587, to_date('02-11-2061', 'dd-mm-yyyy'), '3', '02', '306', '11', '2061', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22588, to_date('03-11-2061', 'dd-mm-yyyy'), '4', '03', '307', '11', '2061', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22589, to_date('04-11-2061', 'dd-mm-yyyy'), '5', '04', '308', '11', '2061', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22590, to_date('05-11-2061', 'dd-mm-yyyy'), '6', '05', '309', '11', '2061', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22591, to_date('06-11-2061', 'dd-mm-yyyy'), '7', '06', '310', '11', '2061', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22592, to_date('07-11-2061', 'dd-mm-yyyy'), '1', '07', '311', '11', '2061', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22593, to_date('08-11-2061', 'dd-mm-yyyy'), '2', '08', '312', '11', '2061', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22594, to_date('09-11-2061', 'dd-mm-yyyy'), '3', '09', '313', '11', '2061', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22595, to_date('10-11-2061', 'dd-mm-yyyy'), '4', '10', '314', '11', '2061', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22596, to_date('11-11-2061', 'dd-mm-yyyy'), '5', '11', '315', '11', '2061', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22597, to_date('12-11-2061', 'dd-mm-yyyy'), '6', '12', '316', '11', '2061', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22598, to_date('13-11-2061', 'dd-mm-yyyy'), '7', '13', '317', '11', '2061', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22599, to_date('14-11-2061', 'dd-mm-yyyy'), '1', '14', '318', '11', '2061', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22600, to_date('15-11-2061', 'dd-mm-yyyy'), '2', '15', '319', '11', '2061', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22601, to_date('16-11-2061', 'dd-mm-yyyy'), '3', '16', '320', '11', '2061', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22602, to_date('17-11-2061', 'dd-mm-yyyy'), '4', '17', '321', '11', '2061', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22603, to_date('18-11-2061', 'dd-mm-yyyy'), '5', '18', '322', '11', '2061', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22604, to_date('19-11-2061', 'dd-mm-yyyy'), '6', '19', '323', '11', '2061', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22605, to_date('20-11-2061', 'dd-mm-yyyy'), '7', '20', '324', '11', '2061', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22606, to_date('21-11-2061', 'dd-mm-yyyy'), '1', '21', '325', '11', '2061', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22607, to_date('22-11-2061', 'dd-mm-yyyy'), '2', '22', '326', '11', '2061', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22608, to_date('23-11-2061', 'dd-mm-yyyy'), '3', '23', '327', '11', '2061', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22609, to_date('24-11-2061', 'dd-mm-yyyy'), '4', '24', '328', '11', '2061', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22610, to_date('25-11-2061', 'dd-mm-yyyy'), '5', '25', '329', '11', '2061', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22611, to_date('26-11-2061', 'dd-mm-yyyy'), '6', '26', '330', '11', '2061', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22612, to_date('27-11-2061', 'dd-mm-yyyy'), '7', '27', '331', '11', '2061', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22613, to_date('28-11-2061', 'dd-mm-yyyy'), '1', '28', '332', '11', '2061', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22614, to_date('29-11-2061', 'dd-mm-yyyy'), '2', '29', '333', '11', '2061', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22615, to_date('30-11-2061', 'dd-mm-yyyy'), '3', '30', '334', '11', '2061', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22616, to_date('01-12-2061', 'dd-mm-yyyy'), '4', '01', '335', '12', '2061', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22617, to_date('02-12-2061', 'dd-mm-yyyy'), '5', '02', '336', '12', '2061', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22618, to_date('03-12-2061', 'dd-mm-yyyy'), '6', '03', '337', '12', '2061', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22619, to_date('04-12-2061', 'dd-mm-yyyy'), '7', '04', '338', '12', '2061', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22620, to_date('05-12-2061', 'dd-mm-yyyy'), '1', '05', '339', '12', '2061', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22621, to_date('06-12-2061', 'dd-mm-yyyy'), '2', '06', '340', '12', '2061', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22622, to_date('07-12-2061', 'dd-mm-yyyy'), '3', '07', '341', '12', '2061', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22623, to_date('08-12-2061', 'dd-mm-yyyy'), '4', '08', '342', '12', '2061', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22624, to_date('09-12-2061', 'dd-mm-yyyy'), '5', '09', '343', '12', '2061', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22625, to_date('10-12-2061', 'dd-mm-yyyy'), '6', '10', '344', '12', '2061', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22626, to_date('11-12-2061', 'dd-mm-yyyy'), '7', '11', '345', '12', '2061', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22627, to_date('12-12-2061', 'dd-mm-yyyy'), '1', '12', '346', '12', '2061', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22628, to_date('13-12-2061', 'dd-mm-yyyy'), '2', '13', '347', '12', '2061', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22629, to_date('14-12-2061', 'dd-mm-yyyy'), '3', '14', '348', '12', '2061', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22630, to_date('15-12-2061', 'dd-mm-yyyy'), '4', '15', '349', '12', '2061', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22631, to_date('16-12-2061', 'dd-mm-yyyy'), '5', '16', '350', '12', '2061', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22632, to_date('17-12-2061', 'dd-mm-yyyy'), '6', '17', '351', '12', '2061', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22633, to_date('18-12-2061', 'dd-mm-yyyy'), '7', '18', '352', '12', '2061', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22634, to_date('19-12-2061', 'dd-mm-yyyy'), '1', '19', '353', '12', '2061', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22635, to_date('20-12-2061', 'dd-mm-yyyy'), '2', '20', '354', '12', '2061', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22636, to_date('21-12-2061', 'dd-mm-yyyy'), '3', '21', '355', '12', '2061', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22637, to_date('22-12-2061', 'dd-mm-yyyy'), '4', '22', '356', '12', '2061', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22638, to_date('23-12-2061', 'dd-mm-yyyy'), '5', '23', '357', '12', '2061', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22639, to_date('24-12-2061', 'dd-mm-yyyy'), '6', '24', '358', '12', '2061', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22640, to_date('25-12-2061', 'dd-mm-yyyy'), '7', '25', '359', '12', '2061', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22641, to_date('26-12-2061', 'dd-mm-yyyy'), '1', '26', '360', '12', '2061', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22642, to_date('27-12-2061', 'dd-mm-yyyy'), '2', '27', '361', '12', '2061', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22643, to_date('28-12-2061', 'dd-mm-yyyy'), '3', '28', '362', '12', '2061', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22644, to_date('29-12-2061', 'dd-mm-yyyy'), '4', '29', '363', '12', '2061', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22645, to_date('30-12-2061', 'dd-mm-yyyy'), '5', '30', '364', '12', '2061', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22646, to_date('31-12-2061', 'dd-mm-yyyy'), '6', '31', '365', '12', '2061', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22647, to_date('01-01-2062', 'dd-mm-yyyy'), '7', '01', '001', '01', '2062', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22648, to_date('02-01-2062', 'dd-mm-yyyy'), '1', '02', '002', '01', '2062', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22649, to_date('03-01-2062', 'dd-mm-yyyy'), '2', '03', '003', '01', '2062', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22650, to_date('04-01-2062', 'dd-mm-yyyy'), '3', '04', '004', '01', '2062', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22651, to_date('05-01-2062', 'dd-mm-yyyy'), '4', '05', '005', '01', '2062', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22652, to_date('06-01-2062', 'dd-mm-yyyy'), '5', '06', '006', '01', '2062', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22653, to_date('07-01-2062', 'dd-mm-yyyy'), '6', '07', '007', '01', '2062', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22654, to_date('08-01-2062', 'dd-mm-yyyy'), '7', '08', '008', '01', '2062', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22655, to_date('09-01-2062', 'dd-mm-yyyy'), '1', '09', '009', '01', '2062', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22656, to_date('10-01-2062', 'dd-mm-yyyy'), '2', '10', '010', '01', '2062', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22657, to_date('11-01-2062', 'dd-mm-yyyy'), '3', '11', '011', '01', '2062', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22658, to_date('12-01-2062', 'dd-mm-yyyy'), '4', '12', '012', '01', '2062', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24143, to_date('05-02-2066', 'dd-mm-yyyy'), '5', '05', '036', '02', '2066', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24144, to_date('06-02-2066', 'dd-mm-yyyy'), '6', '06', '037', '02', '2066', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24145, to_date('07-02-2066', 'dd-mm-yyyy'), '7', '07', '038', '02', '2066', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24146, to_date('08-02-2066', 'dd-mm-yyyy'), '1', '08', '039', '02', '2066', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24147, to_date('09-02-2066', 'dd-mm-yyyy'), '2', '09', '040', '02', '2066', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24148, to_date('10-02-2066', 'dd-mm-yyyy'), '3', '10', '041', '02', '2066', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24149, to_date('11-02-2066', 'dd-mm-yyyy'), '4', '11', '042', '02', '2066', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24150, to_date('12-02-2066', 'dd-mm-yyyy'), '5', '12', '043', '02', '2066', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24151, to_date('13-02-2066', 'dd-mm-yyyy'), '6', '13', '044', '02', '2066', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24152, to_date('14-02-2066', 'dd-mm-yyyy'), '7', '14', '045', '02', '2066', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24153, to_date('15-02-2066', 'dd-mm-yyyy'), '1', '15', '046', '02', '2066', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24154, to_date('16-02-2066', 'dd-mm-yyyy'), '2', '16', '047', '02', '2066', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24155, to_date('17-02-2066', 'dd-mm-yyyy'), '3', '17', '048', '02', '2066', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24156, to_date('18-02-2066', 'dd-mm-yyyy'), '4', '18', '049', '02', '2066', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24157, to_date('19-02-2066', 'dd-mm-yyyy'), '5', '19', '050', '02', '2066', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24158, to_date('20-02-2066', 'dd-mm-yyyy'), '6', '20', '051', '02', '2066', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24159, to_date('21-02-2066', 'dd-mm-yyyy'), '7', '21', '052', '02', '2066', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24160, to_date('22-02-2066', 'dd-mm-yyyy'), '1', '22', '053', '02', '2066', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24161, to_date('23-02-2066', 'dd-mm-yyyy'), '2', '23', '054', '02', '2066', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24162, to_date('24-02-2066', 'dd-mm-yyyy'), '3', '24', '055', '02', '2066', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24163, to_date('25-02-2066', 'dd-mm-yyyy'), '4', '25', '056', '02', '2066', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24164, to_date('26-02-2066', 'dd-mm-yyyy'), '5', '26', '057', '02', '2066', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24165, to_date('27-02-2066', 'dd-mm-yyyy'), '6', '27', '058', '02', '2066', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24166, to_date('28-02-2066', 'dd-mm-yyyy'), '7', '28', '059', '02', '2066', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24167, to_date('01-03-2066', 'dd-mm-yyyy'), '1', '01', '060', '03', '2066', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24168, to_date('02-03-2066', 'dd-mm-yyyy'), '2', '02', '061', '03', '2066', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24169, to_date('03-03-2066', 'dd-mm-yyyy'), '3', '03', '062', '03', '2066', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24170, to_date('04-03-2066', 'dd-mm-yyyy'), '4', '04', '063', '03', '2066', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24171, to_date('05-03-2066', 'dd-mm-yyyy'), '5', '05', '064', '03', '2066', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24172, to_date('06-03-2066', 'dd-mm-yyyy'), '6', '06', '065', '03', '2066', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24173, to_date('07-03-2066', 'dd-mm-yyyy'), '7', '07', '066', '03', '2066', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24174, to_date('08-03-2066', 'dd-mm-yyyy'), '1', '08', '067', '03', '2066', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24175, to_date('09-03-2066', 'dd-mm-yyyy'), '2', '09', '068', '03', '2066', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24176, to_date('10-03-2066', 'dd-mm-yyyy'), '3', '10', '069', '03', '2066', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24177, to_date('11-03-2066', 'dd-mm-yyyy'), '4', '11', '070', '03', '2066', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24178, to_date('12-03-2066', 'dd-mm-yyyy'), '5', '12', '071', '03', '2066', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24179, to_date('13-03-2066', 'dd-mm-yyyy'), '6', '13', '072', '03', '2066', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24180, to_date('14-03-2066', 'dd-mm-yyyy'), '7', '14', '073', '03', '2066', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24181, to_date('15-03-2066', 'dd-mm-yyyy'), '1', '15', '074', '03', '2066', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24182, to_date('16-03-2066', 'dd-mm-yyyy'), '2', '16', '075', '03', '2066', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24183, to_date('17-03-2066', 'dd-mm-yyyy'), '3', '17', '076', '03', '2066', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24184, to_date('18-03-2066', 'dd-mm-yyyy'), '4', '18', '077', '03', '2066', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24185, to_date('19-03-2066', 'dd-mm-yyyy'), '5', '19', '078', '03', '2066', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24186, to_date('20-03-2066', 'dd-mm-yyyy'), '6', '20', '079', '03', '2066', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24187, to_date('21-03-2066', 'dd-mm-yyyy'), '7', '21', '080', '03', '2066', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24188, to_date('22-03-2066', 'dd-mm-yyyy'), '1', '22', '081', '03', '2066', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24189, to_date('23-03-2066', 'dd-mm-yyyy'), '2', '23', '082', '03', '2066', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24190, to_date('24-03-2066', 'dd-mm-yyyy'), '3', '24', '083', '03', '2066', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24191, to_date('25-03-2066', 'dd-mm-yyyy'), '4', '25', '084', '03', '2066', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24192, to_date('26-03-2066', 'dd-mm-yyyy'), '5', '26', '085', '03', '2066', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24193, to_date('27-03-2066', 'dd-mm-yyyy'), '6', '27', '086', '03', '2066', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24194, to_date('28-03-2066', 'dd-mm-yyyy'), '7', '28', '087', '03', '2066', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24195, to_date('29-03-2066', 'dd-mm-yyyy'), '1', '29', '088', '03', '2066', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24196, to_date('30-03-2066', 'dd-mm-yyyy'), '2', '30', '089', '03', '2066', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24197, to_date('31-03-2066', 'dd-mm-yyyy'), '3', '31', '090', '03', '2066', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24198, to_date('01-04-2066', 'dd-mm-yyyy'), '4', '01', '091', '04', '2066', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24199, to_date('02-04-2066', 'dd-mm-yyyy'), '5', '02', '092', '04', '2066', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24200, to_date('03-04-2066', 'dd-mm-yyyy'), '6', '03', '093', '04', '2066', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24201, to_date('04-04-2066', 'dd-mm-yyyy'), '7', '04', '094', '04', '2066', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24202, to_date('05-04-2066', 'dd-mm-yyyy'), '1', '05', '095', '04', '2066', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24203, to_date('06-04-2066', 'dd-mm-yyyy'), '2', '06', '096', '04', '2066', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24204, to_date('07-04-2066', 'dd-mm-yyyy'), '3', '07', '097', '04', '2066', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24205, to_date('08-04-2066', 'dd-mm-yyyy'), '4', '08', '098', '04', '2066', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24206, to_date('09-04-2066', 'dd-mm-yyyy'), '5', '09', '099', '04', '2066', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24207, to_date('10-04-2066', 'dd-mm-yyyy'), '6', '10', '100', '04', '2066', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24208, to_date('11-04-2066', 'dd-mm-yyyy'), '7', '11', '101', '04', '2066', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24209, to_date('12-04-2066', 'dd-mm-yyyy'), '1', '12', '102', '04', '2066', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24210, to_date('13-04-2066', 'dd-mm-yyyy'), '2', '13', '103', '04', '2066', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24211, to_date('14-04-2066', 'dd-mm-yyyy'), '3', '14', '104', '04', '2066', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24212, to_date('15-04-2066', 'dd-mm-yyyy'), '4', '15', '105', '04', '2066', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24213, to_date('16-04-2066', 'dd-mm-yyyy'), '5', '16', '106', '04', '2066', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24214, to_date('17-04-2066', 'dd-mm-yyyy'), '6', '17', '107', '04', '2066', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24215, to_date('18-04-2066', 'dd-mm-yyyy'), '7', '18', '108', '04', '2066', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24216, to_date('19-04-2066', 'dd-mm-yyyy'), '1', '19', '109', '04', '2066', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24217, to_date('20-04-2066', 'dd-mm-yyyy'), '2', '20', '110', '04', '2066', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24218, to_date('21-04-2066', 'dd-mm-yyyy'), '3', '21', '111', '04', '2066', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24219, to_date('22-04-2066', 'dd-mm-yyyy'), '4', '22', '112', '04', '2066', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24220, to_date('23-04-2066', 'dd-mm-yyyy'), '5', '23', '113', '04', '2066', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24221, to_date('24-04-2066', 'dd-mm-yyyy'), '6', '24', '114', '04', '2066', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24222, to_date('25-04-2066', 'dd-mm-yyyy'), '7', '25', '115', '04', '2066', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24223, to_date('26-04-2066', 'dd-mm-yyyy'), '1', '26', '116', '04', '2066', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24224, to_date('27-04-2066', 'dd-mm-yyyy'), '2', '27', '117', '04', '2066', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24225, to_date('28-04-2066', 'dd-mm-yyyy'), '3', '28', '118', '04', '2066', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24226, to_date('29-04-2066', 'dd-mm-yyyy'), '4', '29', '119', '04', '2066', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24227, to_date('30-04-2066', 'dd-mm-yyyy'), '5', '30', '120', '04', '2066', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24228, to_date('01-05-2066', 'dd-mm-yyyy'), '6', '01', '121', '05', '2066', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24229, to_date('02-05-2066', 'dd-mm-yyyy'), '7', '02', '122', '05', '2066', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24230, to_date('03-05-2066', 'dd-mm-yyyy'), '1', '03', '123', '05', '2066', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24231, to_date('04-05-2066', 'dd-mm-yyyy'), '2', '04', '124', '05', '2066', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24232, to_date('05-05-2066', 'dd-mm-yyyy'), '3', '05', '125', '05', '2066', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24233, to_date('06-05-2066', 'dd-mm-yyyy'), '4', '06', '126', '05', '2066', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24234, to_date('07-05-2066', 'dd-mm-yyyy'), '5', '07', '127', '05', '2066', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24235, to_date('08-05-2066', 'dd-mm-yyyy'), '6', '08', '128', '05', '2066', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24236, to_date('09-05-2066', 'dd-mm-yyyy'), '7', '09', '129', '05', '2066', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
commit;
prompt 13000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24237, to_date('10-05-2066', 'dd-mm-yyyy'), '1', '10', '130', '05', '2066', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24238, to_date('11-05-2066', 'dd-mm-yyyy'), '2', '11', '131', '05', '2066', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24239, to_date('12-05-2066', 'dd-mm-yyyy'), '3', '12', '132', '05', '2066', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24240, to_date('13-05-2066', 'dd-mm-yyyy'), '4', '13', '133', '05', '2066', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24241, to_date('14-05-2066', 'dd-mm-yyyy'), '5', '14', '134', '05', '2066', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24242, to_date('15-05-2066', 'dd-mm-yyyy'), '6', '15', '135', '05', '2066', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24243, to_date('16-05-2066', 'dd-mm-yyyy'), '7', '16', '136', '05', '2066', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24244, to_date('17-05-2066', 'dd-mm-yyyy'), '1', '17', '137', '05', '2066', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24245, to_date('18-05-2066', 'dd-mm-yyyy'), '2', '18', '138', '05', '2066', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24246, to_date('19-05-2066', 'dd-mm-yyyy'), '3', '19', '139', '05', '2066', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24247, to_date('20-05-2066', 'dd-mm-yyyy'), '4', '20', '140', '05', '2066', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24248, to_date('21-05-2066', 'dd-mm-yyyy'), '5', '21', '141', '05', '2066', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25627, to_date('28-02-2070', 'dd-mm-yyyy'), '5', '28', '059', '02', '2070', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25628, to_date('01-03-2070', 'dd-mm-yyyy'), '6', '01', '060', '03', '2070', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25629, to_date('02-03-2070', 'dd-mm-yyyy'), '7', '02', '061', '03', '2070', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25630, to_date('03-03-2070', 'dd-mm-yyyy'), '1', '03', '062', '03', '2070', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25631, to_date('04-03-2070', 'dd-mm-yyyy'), '2', '04', '063', '03', '2070', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25632, to_date('05-03-2070', 'dd-mm-yyyy'), '3', '05', '064', '03', '2070', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25633, to_date('06-03-2070', 'dd-mm-yyyy'), '4', '06', '065', '03', '2070', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25634, to_date('07-03-2070', 'dd-mm-yyyy'), '5', '07', '066', '03', '2070', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25635, to_date('08-03-2070', 'dd-mm-yyyy'), '6', '08', '067', '03', '2070', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25636, to_date('09-03-2070', 'dd-mm-yyyy'), '7', '09', '068', '03', '2070', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25637, to_date('10-03-2070', 'dd-mm-yyyy'), '1', '10', '069', '03', '2070', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25638, to_date('11-03-2070', 'dd-mm-yyyy'), '2', '11', '070', '03', '2070', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25639, to_date('12-03-2070', 'dd-mm-yyyy'), '3', '12', '071', '03', '2070', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25640, to_date('13-03-2070', 'dd-mm-yyyy'), '4', '13', '072', '03', '2070', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25641, to_date('14-03-2070', 'dd-mm-yyyy'), '5', '14', '073', '03', '2070', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25642, to_date('15-03-2070', 'dd-mm-yyyy'), '6', '15', '074', '03', '2070', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25643, to_date('16-03-2070', 'dd-mm-yyyy'), '7', '16', '075', '03', '2070', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25644, to_date('17-03-2070', 'dd-mm-yyyy'), '1', '17', '076', '03', '2070', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25645, to_date('18-03-2070', 'dd-mm-yyyy'), '2', '18', '077', '03', '2070', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25646, to_date('19-03-2070', 'dd-mm-yyyy'), '3', '19', '078', '03', '2070', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25647, to_date('20-03-2070', 'dd-mm-yyyy'), '4', '20', '079', '03', '2070', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25648, to_date('21-03-2070', 'dd-mm-yyyy'), '5', '21', '080', '03', '2070', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25649, to_date('22-03-2070', 'dd-mm-yyyy'), '6', '22', '081', '03', '2070', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25650, to_date('23-03-2070', 'dd-mm-yyyy'), '7', '23', '082', '03', '2070', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25651, to_date('24-03-2070', 'dd-mm-yyyy'), '1', '24', '083', '03', '2070', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25652, to_date('25-03-2070', 'dd-mm-yyyy'), '2', '25', '084', '03', '2070', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25653, to_date('26-03-2070', 'dd-mm-yyyy'), '3', '26', '085', '03', '2070', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25654, to_date('27-03-2070', 'dd-mm-yyyy'), '4', '27', '086', '03', '2070', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25655, to_date('28-03-2070', 'dd-mm-yyyy'), '5', '28', '087', '03', '2070', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25656, to_date('29-03-2070', 'dd-mm-yyyy'), '6', '29', '088', '03', '2070', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25657, to_date('30-03-2070', 'dd-mm-yyyy'), '7', '30', '089', '03', '2070', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25658, to_date('31-03-2070', 'dd-mm-yyyy'), '1', '31', '090', '03', '2070', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25659, to_date('01-04-2070', 'dd-mm-yyyy'), '2', '01', '091', '04', '2070', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25660, to_date('02-04-2070', 'dd-mm-yyyy'), '3', '02', '092', '04', '2070', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25661, to_date('03-04-2070', 'dd-mm-yyyy'), '4', '03', '093', '04', '2070', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25662, to_date('04-04-2070', 'dd-mm-yyyy'), '5', '04', '094', '04', '2070', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25663, to_date('05-04-2070', 'dd-mm-yyyy'), '6', '05', '095', '04', '2070', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25664, to_date('06-04-2070', 'dd-mm-yyyy'), '7', '06', '096', '04', '2070', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25665, to_date('07-04-2070', 'dd-mm-yyyy'), '1', '07', '097', '04', '2070', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25666, to_date('08-04-2070', 'dd-mm-yyyy'), '2', '08', '098', '04', '2070', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25667, to_date('09-04-2070', 'dd-mm-yyyy'), '3', '09', '099', '04', '2070', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25668, to_date('10-04-2070', 'dd-mm-yyyy'), '4', '10', '100', '04', '2070', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25669, to_date('11-04-2070', 'dd-mm-yyyy'), '5', '11', '101', '04', '2070', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25670, to_date('12-04-2070', 'dd-mm-yyyy'), '6', '12', '102', '04', '2070', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25671, to_date('13-04-2070', 'dd-mm-yyyy'), '7', '13', '103', '04', '2070', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25672, to_date('14-04-2070', 'dd-mm-yyyy'), '1', '14', '104', '04', '2070', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25673, to_date('15-04-2070', 'dd-mm-yyyy'), '2', '15', '105', '04', '2070', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25674, to_date('16-04-2070', 'dd-mm-yyyy'), '3', '16', '106', '04', '2070', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25675, to_date('17-04-2070', 'dd-mm-yyyy'), '4', '17', '107', '04', '2070', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25676, to_date('18-04-2070', 'dd-mm-yyyy'), '5', '18', '108', '04', '2070', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25677, to_date('19-04-2070', 'dd-mm-yyyy'), '6', '19', '109', '04', '2070', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25678, to_date('20-04-2070', 'dd-mm-yyyy'), '7', '20', '110', '04', '2070', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25679, to_date('21-04-2070', 'dd-mm-yyyy'), '1', '21', '111', '04', '2070', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25680, to_date('22-04-2070', 'dd-mm-yyyy'), '2', '22', '112', '04', '2070', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25681, to_date('23-04-2070', 'dd-mm-yyyy'), '3', '23', '113', '04', '2070', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25682, to_date('24-04-2070', 'dd-mm-yyyy'), '4', '24', '114', '04', '2070', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25683, to_date('25-04-2070', 'dd-mm-yyyy'), '5', '25', '115', '04', '2070', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25684, to_date('26-04-2070', 'dd-mm-yyyy'), '6', '26', '116', '04', '2070', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25685, to_date('27-04-2070', 'dd-mm-yyyy'), '7', '27', '117', '04', '2070', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25686, to_date('28-04-2070', 'dd-mm-yyyy'), '1', '28', '118', '04', '2070', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25687, to_date('29-04-2070', 'dd-mm-yyyy'), '2', '29', '119', '04', '2070', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25688, to_date('30-04-2070', 'dd-mm-yyyy'), '3', '30', '120', '04', '2070', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25689, to_date('01-05-2070', 'dd-mm-yyyy'), '4', '01', '121', '05', '2070', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25690, to_date('02-05-2070', 'dd-mm-yyyy'), '5', '02', '122', '05', '2070', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25691, to_date('03-05-2070', 'dd-mm-yyyy'), '6', '03', '123', '05', '2070', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25692, to_date('04-05-2070', 'dd-mm-yyyy'), '7', '04', '124', '05', '2070', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25693, to_date('05-05-2070', 'dd-mm-yyyy'), '1', '05', '125', '05', '2070', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25694, to_date('06-05-2070', 'dd-mm-yyyy'), '2', '06', '126', '05', '2070', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25695, to_date('07-05-2070', 'dd-mm-yyyy'), '3', '07', '127', '05', '2070', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25696, to_date('08-05-2070', 'dd-mm-yyyy'), '4', '08', '128', '05', '2070', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25697, to_date('09-05-2070', 'dd-mm-yyyy'), '5', '09', '129', '05', '2070', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25698, to_date('10-05-2070', 'dd-mm-yyyy'), '6', '10', '130', '05', '2070', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25699, to_date('11-05-2070', 'dd-mm-yyyy'), '7', '11', '131', '05', '2070', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25700, to_date('12-05-2070', 'dd-mm-yyyy'), '1', '12', '132', '05', '2070', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25701, to_date('13-05-2070', 'dd-mm-yyyy'), '2', '13', '133', '05', '2070', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25702, to_date('14-05-2070', 'dd-mm-yyyy'), '3', '14', '134', '05', '2070', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25703, to_date('15-05-2070', 'dd-mm-yyyy'), '4', '15', '135', '05', '2070', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25704, to_date('16-05-2070', 'dd-mm-yyyy'), '5', '16', '136', '05', '2070', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25705, to_date('17-05-2070', 'dd-mm-yyyy'), '6', '17', '137', '05', '2070', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25706, to_date('18-05-2070', 'dd-mm-yyyy'), '7', '18', '138', '05', '2070', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25707, to_date('19-05-2070', 'dd-mm-yyyy'), '1', '19', '139', '05', '2070', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25708, to_date('20-05-2070', 'dd-mm-yyyy'), '2', '20', '140', '05', '2070', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25709, to_date('21-05-2070', 'dd-mm-yyyy'), '3', '21', '141', '05', '2070', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25710, to_date('22-05-2070', 'dd-mm-yyyy'), '4', '22', '142', '05', '2070', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25711, to_date('23-05-2070', 'dd-mm-yyyy'), '5', '23', '143', '05', '2070', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25712, to_date('24-05-2070', 'dd-mm-yyyy'), '6', '24', '144', '05', '2070', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25713, to_date('25-05-2070', 'dd-mm-yyyy'), '7', '25', '145', '05', '2070', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25714, to_date('26-05-2070', 'dd-mm-yyyy'), '1', '26', '146', '05', '2070', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25715, to_date('27-05-2070', 'dd-mm-yyyy'), '2', '27', '147', '05', '2070', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25716, to_date('28-05-2070', 'dd-mm-yyyy'), '3', '28', '148', '05', '2070', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25717, to_date('29-05-2070', 'dd-mm-yyyy'), '4', '29', '149', '05', '2070', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25718, to_date('30-05-2070', 'dd-mm-yyyy'), '5', '30', '150', '05', '2070', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25719, to_date('31-05-2070', 'dd-mm-yyyy'), '6', '31', '151', '05', '2070', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25720, to_date('01-06-2070', 'dd-mm-yyyy'), '7', '01', '152', '06', '2070', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25721, to_date('02-06-2070', 'dd-mm-yyyy'), '1', '02', '153', '06', '2070', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25722, to_date('03-06-2070', 'dd-mm-yyyy'), '2', '03', '154', '06', '2070', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25723, to_date('04-06-2070', 'dd-mm-yyyy'), '3', '04', '155', '06', '2070', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25724, to_date('05-06-2070', 'dd-mm-yyyy'), '4', '05', '156', '06', '2070', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25725, to_date('06-06-2070', 'dd-mm-yyyy'), '5', '06', '157', '06', '2070', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25726, to_date('07-06-2070', 'dd-mm-yyyy'), '6', '07', '158', '06', '2070', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25727, to_date('08-06-2070', 'dd-mm-yyyy'), '7', '08', '159', '06', '2070', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25728, to_date('09-06-2070', 'dd-mm-yyyy'), '1', '09', '160', '06', '2070', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25729, to_date('10-06-2070', 'dd-mm-yyyy'), '2', '10', '161', '06', '2070', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25730, to_date('11-06-2070', 'dd-mm-yyyy'), '3', '11', '162', '06', '2070', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25731, to_date('12-06-2070', 'dd-mm-yyyy'), '4', '12', '163', '06', '2070', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25732, to_date('13-06-2070', 'dd-mm-yyyy'), '5', '13', '164', '06', '2070', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25733, to_date('14-06-2070', 'dd-mm-yyyy'), '6', '14', '165', '06', '2070', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25734, to_date('15-06-2070', 'dd-mm-yyyy'), '7', '15', '166', '06', '2070', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25735, to_date('16-06-2070', 'dd-mm-yyyy'), '1', '16', '167', '06', '2070', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25736, to_date('17-06-2070', 'dd-mm-yyyy'), '2', '17', '168', '06', '2070', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25737, to_date('18-06-2070', 'dd-mm-yyyy'), '3', '18', '169', '06', '2070', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25738, to_date('19-06-2070', 'dd-mm-yyyy'), '4', '19', '170', '06', '2070', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25739, to_date('20-06-2070', 'dd-mm-yyyy'), '5', '20', '171', '06', '2070', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25740, to_date('21-06-2070', 'dd-mm-yyyy'), '6', '21', '172', '06', '2070', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25741, to_date('22-06-2070', 'dd-mm-yyyy'), '7', '22', '173', '06', '2070', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25742, to_date('23-06-2070', 'dd-mm-yyyy'), '1', '23', '174', '06', '2070', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25743, to_date('24-06-2070', 'dd-mm-yyyy'), '2', '24', '175', '06', '2070', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25744, to_date('25-06-2070', 'dd-mm-yyyy'), '3', '25', '176', '06', '2070', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25745, to_date('26-06-2070', 'dd-mm-yyyy'), '4', '26', '177', '06', '2070', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25746, to_date('27-06-2070', 'dd-mm-yyyy'), '5', '27', '178', '06', '2070', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25747, to_date('28-06-2070', 'dd-mm-yyyy'), '6', '28', '179', '06', '2070', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25748, to_date('29-06-2070', 'dd-mm-yyyy'), '7', '29', '180', '06', '2070', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25749, to_date('30-06-2070', 'dd-mm-yyyy'), '1', '30', '181', '06', '2070', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25750, to_date('01-07-2070', 'dd-mm-yyyy'), '2', '01', '182', '07', '2070', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25751, to_date('02-07-2070', 'dd-mm-yyyy'), '3', '02', '183', '07', '2070', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25752, to_date('03-07-2070', 'dd-mm-yyyy'), '4', '03', '184', '07', '2070', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25753, to_date('04-07-2070', 'dd-mm-yyyy'), '5', '04', '185', '07', '2070', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25754, to_date('05-07-2070', 'dd-mm-yyyy'), '6', '05', '186', '07', '2070', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25755, to_date('06-07-2070', 'dd-mm-yyyy'), '7', '06', '187', '07', '2070', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25756, to_date('07-07-2070', 'dd-mm-yyyy'), '1', '07', '188', '07', '2070', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25757, to_date('08-07-2070', 'dd-mm-yyyy'), '2', '08', '189', '07', '2070', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25758, to_date('09-07-2070', 'dd-mm-yyyy'), '3', '09', '190', '07', '2070', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25759, to_date('10-07-2070', 'dd-mm-yyyy'), '4', '10', '191', '07', '2070', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25760, to_date('11-07-2070', 'dd-mm-yyyy'), '5', '11', '192', '07', '2070', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25761, to_date('12-07-2070', 'dd-mm-yyyy'), '6', '12', '193', '07', '2070', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25762, to_date('13-07-2070', 'dd-mm-yyyy'), '7', '13', '194', '07', '2070', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25763, to_date('14-07-2070', 'dd-mm-yyyy'), '1', '14', '195', '07', '2070', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25764, to_date('15-07-2070', 'dd-mm-yyyy'), '2', '15', '196', '07', '2070', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25765, to_date('16-07-2070', 'dd-mm-yyyy'), '3', '16', '197', '07', '2070', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25766, to_date('17-07-2070', 'dd-mm-yyyy'), '4', '17', '198', '07', '2070', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25767, to_date('18-07-2070', 'dd-mm-yyyy'), '5', '18', '199', '07', '2070', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25768, to_date('19-07-2070', 'dd-mm-yyyy'), '6', '19', '200', '07', '2070', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25769, to_date('20-07-2070', 'dd-mm-yyyy'), '7', '20', '201', '07', '2070', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25770, to_date('21-07-2070', 'dd-mm-yyyy'), '1', '21', '202', '07', '2070', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25771, to_date('22-07-2070', 'dd-mm-yyyy'), '2', '22', '203', '07', '2070', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25772, to_date('23-07-2070', 'dd-mm-yyyy'), '3', '23', '204', '07', '2070', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25773, to_date('24-07-2070', 'dd-mm-yyyy'), '4', '24', '205', '07', '2070', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25774, to_date('25-07-2070', 'dd-mm-yyyy'), '5', '25', '206', '07', '2070', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25775, to_date('26-07-2070', 'dd-mm-yyyy'), '6', '26', '207', '07', '2070', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25776, to_date('27-07-2070', 'dd-mm-yyyy'), '7', '27', '208', '07', '2070', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25777, to_date('28-07-2070', 'dd-mm-yyyy'), '1', '28', '209', '07', '2070', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25778, to_date('29-07-2070', 'dd-mm-yyyy'), '2', '29', '210', '07', '2070', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25779, to_date('30-07-2070', 'dd-mm-yyyy'), '3', '30', '211', '07', '2070', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25780, to_date('31-07-2070', 'dd-mm-yyyy'), '4', '31', '212', '07', '2070', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25781, to_date('01-08-2070', 'dd-mm-yyyy'), '5', '01', '213', '08', '2070', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25782, to_date('02-08-2070', 'dd-mm-yyyy'), '6', '02', '214', '08', '2070', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25783, to_date('03-08-2070', 'dd-mm-yyyy'), '7', '03', '215', '08', '2070', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25784, to_date('04-08-2070', 'dd-mm-yyyy'), '1', '04', '216', '08', '2070', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25785, to_date('05-08-2070', 'dd-mm-yyyy'), '2', '05', '217', '08', '2070', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25786, to_date('06-08-2070', 'dd-mm-yyyy'), '3', '06', '218', '08', '2070', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25787, to_date('07-08-2070', 'dd-mm-yyyy'), '4', '07', '219', '08', '2070', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25788, to_date('08-08-2070', 'dd-mm-yyyy'), '5', '08', '220', '08', '2070', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25789, to_date('09-08-2070', 'dd-mm-yyyy'), '6', '09', '221', '08', '2070', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25790, to_date('10-08-2070', 'dd-mm-yyyy'), '7', '10', '222', '08', '2070', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25791, to_date('11-08-2070', 'dd-mm-yyyy'), '1', '11', '223', '08', '2070', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25792, to_date('12-08-2070', 'dd-mm-yyyy'), '2', '12', '224', '08', '2070', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25793, to_date('13-08-2070', 'dd-mm-yyyy'), '3', '13', '225', '08', '2070', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25794, to_date('14-08-2070', 'dd-mm-yyyy'), '4', '14', '226', '08', '2070', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25795, to_date('15-08-2070', 'dd-mm-yyyy'), '5', '15', '227', '08', '2070', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25796, to_date('16-08-2070', 'dd-mm-yyyy'), '6', '16', '228', '08', '2070', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25797, to_date('17-08-2070', 'dd-mm-yyyy'), '7', '17', '229', '08', '2070', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25798, to_date('18-08-2070', 'dd-mm-yyyy'), '1', '18', '230', '08', '2070', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25799, to_date('19-08-2070', 'dd-mm-yyyy'), '2', '19', '231', '08', '2070', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25800, to_date('20-08-2070', 'dd-mm-yyyy'), '3', '20', '232', '08', '2070', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25801, to_date('21-08-2070', 'dd-mm-yyyy'), '4', '21', '233', '08', '2070', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25802, to_date('22-08-2070', 'dd-mm-yyyy'), '5', '22', '234', '08', '2070', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25803, to_date('23-08-2070', 'dd-mm-yyyy'), '6', '23', '235', '08', '2070', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25804, to_date('24-08-2070', 'dd-mm-yyyy'), '7', '24', '236', '08', '2070', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25805, to_date('25-08-2070', 'dd-mm-yyyy'), '1', '25', '237', '08', '2070', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25806, to_date('26-08-2070', 'dd-mm-yyyy'), '2', '26', '238', '08', '2070', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25807, to_date('27-08-2070', 'dd-mm-yyyy'), '3', '27', '239', '08', '2070', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25808, to_date('28-08-2070', 'dd-mm-yyyy'), '4', '28', '240', '08', '2070', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25809, to_date('29-08-2070', 'dd-mm-yyyy'), '5', '29', '241', '08', '2070', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25810, to_date('30-08-2070', 'dd-mm-yyyy'), '6', '30', '242', '08', '2070', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25811, to_date('31-08-2070', 'dd-mm-yyyy'), '7', '31', '243', '08', '2070', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25812, to_date('01-09-2070', 'dd-mm-yyyy'), '1', '01', '244', '09', '2070', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25813, to_date('02-09-2070', 'dd-mm-yyyy'), '2', '02', '245', '09', '2070', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25814, to_date('03-09-2070', 'dd-mm-yyyy'), '3', '03', '246', '09', '2070', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25815, to_date('04-09-2070', 'dd-mm-yyyy'), '4', '04', '247', '09', '2070', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25816, to_date('05-09-2070', 'dd-mm-yyyy'), '5', '05', '248', '09', '2070', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25817, to_date('06-09-2070', 'dd-mm-yyyy'), '6', '06', '249', '09', '2070', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25818, to_date('07-09-2070', 'dd-mm-yyyy'), '7', '07', '250', '09', '2070', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25819, to_date('08-09-2070', 'dd-mm-yyyy'), '1', '08', '251', '09', '2070', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25820, to_date('09-09-2070', 'dd-mm-yyyy'), '2', '09', '252', '09', '2070', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25821, to_date('10-09-2070', 'dd-mm-yyyy'), '3', '10', '253', '09', '2070', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25822, to_date('11-09-2070', 'dd-mm-yyyy'), '4', '11', '254', '09', '2070', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25823, to_date('12-09-2070', 'dd-mm-yyyy'), '5', '12', '255', '09', '2070', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25824, to_date('13-09-2070', 'dd-mm-yyyy'), '6', '13', '256', '09', '2070', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25825, to_date('14-09-2070', 'dd-mm-yyyy'), '7', '14', '257', '09', '2070', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25826, to_date('15-09-2070', 'dd-mm-yyyy'), '1', '15', '258', '09', '2070', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25827, to_date('16-09-2070', 'dd-mm-yyyy'), '2', '16', '259', '09', '2070', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25828, to_date('17-09-2070', 'dd-mm-yyyy'), '3', '17', '260', '09', '2070', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25829, to_date('18-09-2070', 'dd-mm-yyyy'), '4', '18', '261', '09', '2070', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25830, to_date('19-09-2070', 'dd-mm-yyyy'), '5', '19', '262', '09', '2070', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25831, to_date('20-09-2070', 'dd-mm-yyyy'), '6', '20', '263', '09', '2070', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25832, to_date('21-09-2070', 'dd-mm-yyyy'), '7', '21', '264', '09', '2070', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25833, to_date('22-09-2070', 'dd-mm-yyyy'), '1', '22', '265', '09', '2070', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25834, to_date('23-09-2070', 'dd-mm-yyyy'), '2', '23', '266', '09', '2070', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25835, to_date('24-09-2070', 'dd-mm-yyyy'), '3', '24', '267', '09', '2070', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25836, to_date('25-09-2070', 'dd-mm-yyyy'), '4', '25', '268', '09', '2070', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25837, to_date('26-09-2070', 'dd-mm-yyyy'), '5', '26', '269', '09', '2070', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25838, to_date('27-09-2070', 'dd-mm-yyyy'), '6', '27', '270', '09', '2070', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25839, to_date('28-09-2070', 'dd-mm-yyyy'), '7', '28', '271', '09', '2070', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25840, to_date('29-09-2070', 'dd-mm-yyyy'), '1', '29', '272', '09', '2070', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25841, to_date('30-09-2070', 'dd-mm-yyyy'), '2', '30', '273', '09', '2070', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25842, to_date('01-10-2070', 'dd-mm-yyyy'), '3', '01', '274', '10', '2070', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25843, to_date('02-10-2070', 'dd-mm-yyyy'), '4', '02', '275', '10', '2070', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25844, to_date('03-10-2070', 'dd-mm-yyyy'), '5', '03', '276', '10', '2070', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25845, to_date('04-10-2070', 'dd-mm-yyyy'), '6', '04', '277', '10', '2070', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25846, to_date('05-10-2070', 'dd-mm-yyyy'), '7', '05', '278', '10', '2070', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25847, to_date('06-10-2070', 'dd-mm-yyyy'), '1', '06', '279', '10', '2070', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25848, to_date('07-10-2070', 'dd-mm-yyyy'), '2', '07', '280', '10', '2070', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25849, to_date('08-10-2070', 'dd-mm-yyyy'), '3', '08', '281', '10', '2070', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25850, to_date('09-10-2070', 'dd-mm-yyyy'), '4', '09', '282', '10', '2070', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25851, to_date('10-10-2070', 'dd-mm-yyyy'), '5', '10', '283', '10', '2070', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25852, to_date('11-10-2070', 'dd-mm-yyyy'), '6', '11', '284', '10', '2070', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25853, to_date('12-10-2070', 'dd-mm-yyyy'), '7', '12', '285', '10', '2070', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25854, to_date('13-10-2070', 'dd-mm-yyyy'), '1', '13', '286', '10', '2070', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25855, to_date('14-10-2070', 'dd-mm-yyyy'), '2', '14', '287', '10', '2070', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25856, to_date('15-10-2070', 'dd-mm-yyyy'), '3', '15', '288', '10', '2070', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25857, to_date('16-10-2070', 'dd-mm-yyyy'), '4', '16', '289', '10', '2070', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25858, to_date('17-10-2070', 'dd-mm-yyyy'), '5', '17', '290', '10', '2070', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25859, to_date('18-10-2070', 'dd-mm-yyyy'), '6', '18', '291', '10', '2070', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25860, to_date('19-10-2070', 'dd-mm-yyyy'), '7', '19', '292', '10', '2070', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25861, to_date('20-10-2070', 'dd-mm-yyyy'), '1', '20', '293', '10', '2070', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25862, to_date('21-10-2070', 'dd-mm-yyyy'), '2', '21', '294', '10', '2070', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25863, to_date('22-10-2070', 'dd-mm-yyyy'), '3', '22', '295', '10', '2070', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25864, to_date('23-10-2070', 'dd-mm-yyyy'), '4', '23', '296', '10', '2070', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25865, to_date('24-10-2070', 'dd-mm-yyyy'), '5', '24', '297', '10', '2070', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25866, to_date('25-10-2070', 'dd-mm-yyyy'), '6', '25', '298', '10', '2070', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25867, to_date('26-10-2070', 'dd-mm-yyyy'), '7', '26', '299', '10', '2070', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25868, to_date('27-10-2070', 'dd-mm-yyyy'), '1', '27', '300', '10', '2070', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25869, to_date('28-10-2070', 'dd-mm-yyyy'), '2', '28', '301', '10', '2070', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25870, to_date('29-10-2070', 'dd-mm-yyyy'), '3', '29', '302', '10', '2070', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25871, to_date('30-10-2070', 'dd-mm-yyyy'), '4', '30', '303', '10', '2070', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25872, to_date('31-10-2070', 'dd-mm-yyyy'), '5', '31', '304', '10', '2070', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25873, to_date('01-11-2070', 'dd-mm-yyyy'), '6', '01', '305', '11', '2070', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25874, to_date('02-11-2070', 'dd-mm-yyyy'), '7', '02', '306', '11', '2070', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25875, to_date('03-11-2070', 'dd-mm-yyyy'), '1', '03', '307', '11', '2070', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25876, to_date('04-11-2070', 'dd-mm-yyyy'), '2', '04', '308', '11', '2070', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25877, to_date('05-11-2070', 'dd-mm-yyyy'), '3', '05', '309', '11', '2070', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25878, to_date('06-11-2070', 'dd-mm-yyyy'), '4', '06', '310', '11', '2070', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25879, to_date('07-11-2070', 'dd-mm-yyyy'), '5', '07', '311', '11', '2070', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25880, to_date('08-11-2070', 'dd-mm-yyyy'), '6', '08', '312', '11', '2070', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25881, to_date('09-11-2070', 'dd-mm-yyyy'), '7', '09', '313', '11', '2070', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25882, to_date('10-11-2070', 'dd-mm-yyyy'), '1', '10', '314', '11', '2070', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25883, to_date('11-11-2070', 'dd-mm-yyyy'), '2', '11', '315', '11', '2070', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25884, to_date('12-11-2070', 'dd-mm-yyyy'), '3', '12', '316', '11', '2070', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25885, to_date('13-11-2070', 'dd-mm-yyyy'), '4', '13', '317', '11', '2070', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25886, to_date('14-11-2070', 'dd-mm-yyyy'), '5', '14', '318', '11', '2070', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25887, to_date('15-11-2070', 'dd-mm-yyyy'), '6', '15', '319', '11', '2070', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25888, to_date('16-11-2070', 'dd-mm-yyyy'), '7', '16', '320', '11', '2070', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25889, to_date('17-11-2070', 'dd-mm-yyyy'), '1', '17', '321', '11', '2070', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25890, to_date('18-11-2070', 'dd-mm-yyyy'), '2', '18', '322', '11', '2070', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25891, to_date('19-11-2070', 'dd-mm-yyyy'), '3', '19', '323', '11', '2070', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25892, to_date('20-11-2070', 'dd-mm-yyyy'), '4', '20', '324', '11', '2070', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25893, to_date('21-11-2070', 'dd-mm-yyyy'), '5', '21', '325', '11', '2070', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25894, to_date('22-11-2070', 'dd-mm-yyyy'), '6', '22', '326', '11', '2070', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25895, to_date('23-11-2070', 'dd-mm-yyyy'), '7', '23', '327', '11', '2070', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25896, to_date('24-11-2070', 'dd-mm-yyyy'), '1', '24', '328', '11', '2070', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25897, to_date('25-11-2070', 'dd-mm-yyyy'), '2', '25', '329', '11', '2070', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25898, to_date('26-11-2070', 'dd-mm-yyyy'), '3', '26', '330', '11', '2070', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25899, to_date('27-11-2070', 'dd-mm-yyyy'), '4', '27', '331', '11', '2070', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25900, to_date('28-11-2070', 'dd-mm-yyyy'), '5', '28', '332', '11', '2070', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25901, to_date('29-11-2070', 'dd-mm-yyyy'), '6', '29', '333', '11', '2070', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25902, to_date('30-11-2070', 'dd-mm-yyyy'), '7', '30', '334', '11', '2070', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25903, to_date('01-12-2070', 'dd-mm-yyyy'), '1', '01', '335', '12', '2070', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25904, to_date('02-12-2070', 'dd-mm-yyyy'), '2', '02', '336', '12', '2070', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25905, to_date('03-12-2070', 'dd-mm-yyyy'), '3', '03', '337', '12', '2070', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25906, to_date('04-12-2070', 'dd-mm-yyyy'), '4', '04', '338', '12', '2070', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25907, to_date('05-12-2070', 'dd-mm-yyyy'), '5', '05', '339', '12', '2070', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25908, to_date('06-12-2070', 'dd-mm-yyyy'), '6', '06', '340', '12', '2070', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25909, to_date('07-12-2070', 'dd-mm-yyyy'), '7', '07', '341', '12', '2070', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25910, to_date('08-12-2070', 'dd-mm-yyyy'), '1', '08', '342', '12', '2070', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25911, to_date('09-12-2070', 'dd-mm-yyyy'), '2', '09', '343', '12', '2070', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25912, to_date('10-12-2070', 'dd-mm-yyyy'), '3', '10', '344', '12', '2070', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25913, to_date('11-12-2070', 'dd-mm-yyyy'), '4', '11', '345', '12', '2070', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25914, to_date('12-12-2070', 'dd-mm-yyyy'), '5', '12', '346', '12', '2070', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25915, to_date('13-12-2070', 'dd-mm-yyyy'), '6', '13', '347', '12', '2070', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25916, to_date('14-12-2070', 'dd-mm-yyyy'), '7', '14', '348', '12', '2070', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25917, to_date('15-12-2070', 'dd-mm-yyyy'), '1', '15', '349', '12', '2070', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25918, to_date('16-12-2070', 'dd-mm-yyyy'), '2', '16', '350', '12', '2070', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25919, to_date('17-12-2070', 'dd-mm-yyyy'), '3', '17', '351', '12', '2070', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25920, to_date('18-12-2070', 'dd-mm-yyyy'), '4', '18', '352', '12', '2070', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25921, to_date('19-12-2070', 'dd-mm-yyyy'), '5', '19', '353', '12', '2070', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25922, to_date('20-12-2070', 'dd-mm-yyyy'), '6', '20', '354', '12', '2070', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25923, to_date('21-12-2070', 'dd-mm-yyyy'), '7', '21', '355', '12', '2070', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25924, to_date('22-12-2070', 'dd-mm-yyyy'), '1', '22', '356', '12', '2070', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25925, to_date('23-12-2070', 'dd-mm-yyyy'), '2', '23', '357', '12', '2070', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25926, to_date('24-12-2070', 'dd-mm-yyyy'), '3', '24', '358', '12', '2070', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25927, to_date('25-12-2070', 'dd-mm-yyyy'), '4', '25', '359', '12', '2070', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25928, to_date('26-12-2070', 'dd-mm-yyyy'), '5', '26', '360', '12', '2070', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25929, to_date('27-12-2070', 'dd-mm-yyyy'), '6', '27', '361', '12', '2070', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25930, to_date('28-12-2070', 'dd-mm-yyyy'), '7', '28', '362', '12', '2070', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25931, to_date('29-12-2070', 'dd-mm-yyyy'), '1', '29', '363', '12', '2070', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25932, to_date('30-12-2070', 'dd-mm-yyyy'), '2', '30', '364', '12', '2070', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25933, to_date('31-12-2070', 'dd-mm-yyyy'), '3', '31', '365', '12', '2070', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25934, to_date('01-01-2071', 'dd-mm-yyyy'), '4', '01', '001', '01', '2071', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25935, to_date('02-01-2071', 'dd-mm-yyyy'), '5', '02', '002', '01', '2071', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25936, to_date('03-01-2071', 'dd-mm-yyyy'), '6', '03', '003', '01', '2071', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25937, to_date('04-01-2071', 'dd-mm-yyyy'), '7', '04', '004', '01', '2071', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25938, to_date('05-01-2071', 'dd-mm-yyyy'), '1', '05', '005', '01', '2071', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25939, to_date('06-01-2071', 'dd-mm-yyyy'), '2', '06', '006', '01', '2071', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25940, to_date('07-01-2071', 'dd-mm-yyyy'), '3', '07', '007', '01', '2071', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25941, to_date('08-01-2071', 'dd-mm-yyyy'), '4', '08', '008', '01', '2071', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25942, to_date('09-01-2071', 'dd-mm-yyyy'), '5', '09', '009', '01', '2071', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25943, to_date('10-01-2071', 'dd-mm-yyyy'), '6', '10', '010', '01', '2071', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25944, to_date('11-01-2071', 'dd-mm-yyyy'), '7', '11', '011', '01', '2071', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25945, to_date('12-01-2071', 'dd-mm-yyyy'), '1', '12', '012', '01', '2071', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25946, to_date('13-01-2071', 'dd-mm-yyyy'), '2', '13', '013', '01', '2071', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25947, to_date('14-01-2071', 'dd-mm-yyyy'), '3', '14', '014', '01', '2071', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25948, to_date('15-01-2071', 'dd-mm-yyyy'), '4', '15', '015', '01', '2071', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25949, to_date('16-01-2071', 'dd-mm-yyyy'), '5', '16', '016', '01', '2071', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25950, to_date('17-01-2071', 'dd-mm-yyyy'), '6', '17', '017', '01', '2071', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25951, to_date('18-01-2071', 'dd-mm-yyyy'), '7', '18', '018', '01', '2071', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25952, to_date('19-01-2071', 'dd-mm-yyyy'), '1', '19', '019', '01', '2071', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25953, to_date('20-01-2071', 'dd-mm-yyyy'), '2', '20', '020', '01', '2071', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25954, to_date('21-01-2071', 'dd-mm-yyyy'), '3', '21', '021', '01', '2071', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25955, to_date('22-01-2071', 'dd-mm-yyyy'), '4', '22', '022', '01', '2071', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25956, to_date('23-01-2071', 'dd-mm-yyyy'), '5', '23', '023', '01', '2071', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25957, to_date('24-01-2071', 'dd-mm-yyyy'), '6', '24', '024', '01', '2071', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25958, to_date('25-01-2071', 'dd-mm-yyyy'), '7', '25', '025', '01', '2071', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25959, to_date('26-01-2071', 'dd-mm-yyyy'), '1', '26', '026', '01', '2071', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25960, to_date('27-01-2071', 'dd-mm-yyyy'), '2', '27', '027', '01', '2071', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25961, to_date('28-01-2071', 'dd-mm-yyyy'), '3', '28', '028', '01', '2071', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25962, to_date('29-01-2071', 'dd-mm-yyyy'), '4', '29', '029', '01', '2071', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25963, to_date('30-01-2071', 'dd-mm-yyyy'), '5', '30', '030', '01', '2071', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25964, to_date('31-01-2071', 'dd-mm-yyyy'), '6', '31', '031', '01', '2071', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25965, to_date('01-02-2071', 'dd-mm-yyyy'), '7', '01', '032', '02', '2071', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25966, to_date('02-02-2071', 'dd-mm-yyyy'), '1', '02', '033', '02', '2071', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25967, to_date('03-02-2071', 'dd-mm-yyyy'), '2', '03', '034', '02', '2071', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25968, to_date('04-02-2071', 'dd-mm-yyyy'), '3', '04', '035', '02', '2071', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25969, to_date('05-02-2071', 'dd-mm-yyyy'), '4', '05', '036', '02', '2071', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25970, to_date('06-02-2071', 'dd-mm-yyyy'), '5', '06', '037', '02', '2071', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25971, to_date('07-02-2071', 'dd-mm-yyyy'), '6', '07', '038', '02', '2071', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25972, to_date('08-02-2071', 'dd-mm-yyyy'), '7', '08', '039', '02', '2071', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25973, to_date('09-02-2071', 'dd-mm-yyyy'), '1', '09', '040', '02', '2071', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25974, to_date('10-02-2071', 'dd-mm-yyyy'), '2', '10', '041', '02', '2071', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25975, to_date('11-02-2071', 'dd-mm-yyyy'), '3', '11', '042', '02', '2071', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25976, to_date('12-02-2071', 'dd-mm-yyyy'), '4', '12', '043', '02', '2071', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25977, to_date('13-02-2071', 'dd-mm-yyyy'), '5', '13', '044', '02', '2071', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25978, to_date('14-02-2071', 'dd-mm-yyyy'), '6', '14', '045', '02', '2071', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25979, to_date('15-02-2071', 'dd-mm-yyyy'), '7', '15', '046', '02', '2071', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25980, to_date('16-02-2071', 'dd-mm-yyyy'), '1', '16', '047', '02', '2071', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25981, to_date('17-02-2071', 'dd-mm-yyyy'), '2', '17', '048', '02', '2071', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25982, to_date('18-02-2071', 'dd-mm-yyyy'), '3', '18', '049', '02', '2071', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25983, to_date('19-02-2071', 'dd-mm-yyyy'), '4', '19', '050', '02', '2071', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25984, to_date('20-02-2071', 'dd-mm-yyyy'), '5', '20', '051', '02', '2071', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25985, to_date('21-02-2071', 'dd-mm-yyyy'), '6', '21', '052', '02', '2071', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25986, to_date('22-02-2071', 'dd-mm-yyyy'), '7', '22', '053', '02', '2071', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25987, to_date('23-02-2071', 'dd-mm-yyyy'), '1', '23', '054', '02', '2071', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25988, to_date('24-02-2071', 'dd-mm-yyyy'), '2', '24', '055', '02', '2071', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25989, to_date('25-02-2071', 'dd-mm-yyyy'), '3', '25', '056', '02', '2071', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25990, to_date('26-02-2071', 'dd-mm-yyyy'), '4', '26', '057', '02', '2071', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25991, to_date('27-02-2071', 'dd-mm-yyyy'), '5', '27', '058', '02', '2071', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25992, to_date('28-02-2071', 'dd-mm-yyyy'), '6', '28', '059', '02', '2071', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25993, to_date('01-03-2071', 'dd-mm-yyyy'), '7', '01', '060', '03', '2071', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25994, to_date('02-03-2071', 'dd-mm-yyyy'), '1', '02', '061', '03', '2071', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25995, to_date('03-03-2071', 'dd-mm-yyyy'), '2', '03', '062', '03', '2071', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25996, to_date('04-03-2071', 'dd-mm-yyyy'), '3', '04', '063', '03', '2071', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25997, to_date('05-03-2071', 'dd-mm-yyyy'), '4', '05', '064', '03', '2071', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25998, to_date('06-03-2071', 'dd-mm-yyyy'), '5', '06', '065', '03', '2071', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25999, to_date('07-03-2071', 'dd-mm-yyyy'), '6', '07', '066', '03', '2071', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26000, to_date('08-03-2071', 'dd-mm-yyyy'), '7', '08', '067', '03', '2071', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26001, to_date('09-03-2071', 'dd-mm-yyyy'), '1', '09', '068', '03', '2071', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26002, to_date('10-03-2071', 'dd-mm-yyyy'), '2', '10', '069', '03', '2071', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26003, to_date('11-03-2071', 'dd-mm-yyyy'), '3', '11', '070', '03', '2071', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26004, to_date('12-03-2071', 'dd-mm-yyyy'), '4', '12', '071', '03', '2071', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26005, to_date('13-03-2071', 'dd-mm-yyyy'), '5', '13', '072', '03', '2071', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26006, to_date('14-03-2071', 'dd-mm-yyyy'), '6', '14', '073', '03', '2071', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26007, to_date('15-03-2071', 'dd-mm-yyyy'), '7', '15', '074', '03', '2071', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26008, to_date('16-03-2071', 'dd-mm-yyyy'), '1', '16', '075', '03', '2071', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26009, to_date('17-03-2071', 'dd-mm-yyyy'), '2', '17', '076', '03', '2071', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26010, to_date('18-03-2071', 'dd-mm-yyyy'), '3', '18', '077', '03', '2071', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26011, to_date('19-03-2071', 'dd-mm-yyyy'), '4', '19', '078', '03', '2071', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26012, to_date('20-03-2071', 'dd-mm-yyyy'), '5', '20', '079', '03', '2071', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26013, to_date('21-03-2071', 'dd-mm-yyyy'), '6', '21', '080', '03', '2071', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26014, to_date('22-03-2071', 'dd-mm-yyyy'), '7', '22', '081', '03', '2071', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26015, to_date('23-03-2071', 'dd-mm-yyyy'), '1', '23', '082', '03', '2071', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26016, to_date('24-03-2071', 'dd-mm-yyyy'), '2', '24', '083', '03', '2071', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26017, to_date('25-03-2071', 'dd-mm-yyyy'), '3', '25', '084', '03', '2071', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26018, to_date('26-03-2071', 'dd-mm-yyyy'), '4', '26', '085', '03', '2071', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26019, to_date('27-03-2071', 'dd-mm-yyyy'), '5', '27', '086', '03', '2071', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26020, to_date('28-03-2071', 'dd-mm-yyyy'), '6', '28', '087', '03', '2071', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26021, to_date('29-03-2071', 'dd-mm-yyyy'), '7', '29', '088', '03', '2071', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26022, to_date('30-03-2071', 'dd-mm-yyyy'), '1', '30', '089', '03', '2071', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26023, to_date('31-03-2071', 'dd-mm-yyyy'), '2', '31', '090', '03', '2071', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26024, to_date('01-04-2071', 'dd-mm-yyyy'), '3', '01', '091', '04', '2071', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26025, to_date('02-04-2071', 'dd-mm-yyyy'), '4', '02', '092', '04', '2071', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26026, to_date('03-04-2071', 'dd-mm-yyyy'), '5', '03', '093', '04', '2071', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26027, to_date('04-04-2071', 'dd-mm-yyyy'), '6', '04', '094', '04', '2071', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26028, to_date('05-04-2071', 'dd-mm-yyyy'), '7', '05', '095', '04', '2071', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26029, to_date('06-04-2071', 'dd-mm-yyyy'), '1', '06', '096', '04', '2071', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26030, to_date('07-04-2071', 'dd-mm-yyyy'), '2', '07', '097', '04', '2071', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26031, to_date('08-04-2071', 'dd-mm-yyyy'), '3', '08', '098', '04', '2071', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26032, to_date('09-04-2071', 'dd-mm-yyyy'), '4', '09', '099', '04', '2071', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26033, to_date('10-04-2071', 'dd-mm-yyyy'), '5', '10', '100', '04', '2071', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26034, to_date('11-04-2071', 'dd-mm-yyyy'), '6', '11', '101', '04', '2071', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26035, to_date('12-04-2071', 'dd-mm-yyyy'), '7', '12', '102', '04', '2071', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26036, to_date('13-04-2071', 'dd-mm-yyyy'), '1', '13', '103', '04', '2071', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26037, to_date('14-04-2071', 'dd-mm-yyyy'), '2', '14', '104', '04', '2071', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26038, to_date('15-04-2071', 'dd-mm-yyyy'), '3', '15', '105', '04', '2071', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26039, to_date('16-04-2071', 'dd-mm-yyyy'), '4', '16', '106', '04', '2071', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26040, to_date('17-04-2071', 'dd-mm-yyyy'), '5', '17', '107', '04', '2071', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26041, to_date('18-04-2071', 'dd-mm-yyyy'), '6', '18', '108', '04', '2071', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26042, to_date('19-04-2071', 'dd-mm-yyyy'), '7', '19', '109', '04', '2071', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26043, to_date('20-04-2071', 'dd-mm-yyyy'), '1', '20', '110', '04', '2071', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26044, to_date('21-04-2071', 'dd-mm-yyyy'), '2', '21', '111', '04', '2071', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26045, to_date('22-04-2071', 'dd-mm-yyyy'), '3', '22', '112', '04', '2071', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26046, to_date('23-04-2071', 'dd-mm-yyyy'), '4', '23', '113', '04', '2071', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26047, to_date('24-04-2071', 'dd-mm-yyyy'), '5', '24', '114', '04', '2071', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26048, to_date('25-04-2071', 'dd-mm-yyyy'), '6', '25', '115', '04', '2071', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26049, to_date('26-04-2071', 'dd-mm-yyyy'), '7', '26', '116', '04', '2071', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26050, to_date('27-04-2071', 'dd-mm-yyyy'), '1', '27', '117', '04', '2071', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19479, to_date('30-04-2053', 'dd-mm-yyyy'), '3', '30', '120', '04', '2053', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19480, to_date('01-05-2053', 'dd-mm-yyyy'), '4', '01', '121', '05', '2053', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19481, to_date('02-05-2053', 'dd-mm-yyyy'), '5', '02', '122', '05', '2053', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19482, to_date('03-05-2053', 'dd-mm-yyyy'), '6', '03', '123', '05', '2053', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19483, to_date('04-05-2053', 'dd-mm-yyyy'), '7', '04', '124', '05', '2053', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19484, to_date('05-05-2053', 'dd-mm-yyyy'), '1', '05', '125', '05', '2053', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19485, to_date('06-05-2053', 'dd-mm-yyyy'), '2', '06', '126', '05', '2053', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19486, to_date('07-05-2053', 'dd-mm-yyyy'), '3', '07', '127', '05', '2053', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19487, to_date('08-05-2053', 'dd-mm-yyyy'), '4', '08', '128', '05', '2053', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19488, to_date('09-05-2053', 'dd-mm-yyyy'), '5', '09', '129', '05', '2053', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19489, to_date('10-05-2053', 'dd-mm-yyyy'), '6', '10', '130', '05', '2053', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19490, to_date('11-05-2053', 'dd-mm-yyyy'), '7', '11', '131', '05', '2053', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19491, to_date('12-05-2053', 'dd-mm-yyyy'), '1', '12', '132', '05', '2053', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19492, to_date('13-05-2053', 'dd-mm-yyyy'), '2', '13', '133', '05', '2053', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19493, to_date('14-05-2053', 'dd-mm-yyyy'), '3', '14', '134', '05', '2053', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19494, to_date('15-05-2053', 'dd-mm-yyyy'), '4', '15', '135', '05', '2053', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19495, to_date('16-05-2053', 'dd-mm-yyyy'), '5', '16', '136', '05', '2053', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19496, to_date('17-05-2053', 'dd-mm-yyyy'), '6', '17', '137', '05', '2053', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19497, to_date('18-05-2053', 'dd-mm-yyyy'), '7', '18', '138', '05', '2053', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19498, to_date('19-05-2053', 'dd-mm-yyyy'), '1', '19', '139', '05', '2053', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19499, to_date('20-05-2053', 'dd-mm-yyyy'), '2', '20', '140', '05', '2053', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19500, to_date('21-05-2053', 'dd-mm-yyyy'), '3', '21', '141', '05', '2053', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19501, to_date('22-05-2053', 'dd-mm-yyyy'), '4', '22', '142', '05', '2053', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19502, to_date('23-05-2053', 'dd-mm-yyyy'), '5', '23', '143', '05', '2053', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19503, to_date('24-05-2053', 'dd-mm-yyyy'), '6', '24', '144', '05', '2053', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19504, to_date('25-05-2053', 'dd-mm-yyyy'), '7', '25', '145', '05', '2053', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19505, to_date('26-05-2053', 'dd-mm-yyyy'), '1', '26', '146', '05', '2053', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19506, to_date('27-05-2053', 'dd-mm-yyyy'), '2', '27', '147', '05', '2053', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19507, to_date('28-05-2053', 'dd-mm-yyyy'), '3', '28', '148', '05', '2053', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19508, to_date('29-05-2053', 'dd-mm-yyyy'), '4', '29', '149', '05', '2053', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19509, to_date('30-05-2053', 'dd-mm-yyyy'), '5', '30', '150', '05', '2053', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19510, to_date('31-05-2053', 'dd-mm-yyyy'), '6', '31', '151', '05', '2053', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19511, to_date('01-06-2053', 'dd-mm-yyyy'), '7', '01', '152', '06', '2053', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19512, to_date('02-06-2053', 'dd-mm-yyyy'), '1', '02', '153', '06', '2053', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19513, to_date('03-06-2053', 'dd-mm-yyyy'), '2', '03', '154', '06', '2053', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19514, to_date('04-06-2053', 'dd-mm-yyyy'), '3', '04', '155', '06', '2053', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19515, to_date('05-06-2053', 'dd-mm-yyyy'), '4', '05', '156', '06', '2053', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19516, to_date('06-06-2053', 'dd-mm-yyyy'), '5', '06', '157', '06', '2053', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19517, to_date('07-06-2053', 'dd-mm-yyyy'), '6', '07', '158', '06', '2053', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19518, to_date('08-06-2053', 'dd-mm-yyyy'), '7', '08', '159', '06', '2053', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19519, to_date('09-06-2053', 'dd-mm-yyyy'), '1', '09', '160', '06', '2053', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19520, to_date('10-06-2053', 'dd-mm-yyyy'), '2', '10', '161', '06', '2053', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19521, to_date('11-06-2053', 'dd-mm-yyyy'), '3', '11', '162', '06', '2053', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19522, to_date('12-06-2053', 'dd-mm-yyyy'), '4', '12', '163', '06', '2053', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19523, to_date('13-06-2053', 'dd-mm-yyyy'), '5', '13', '164', '06', '2053', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19524, to_date('14-06-2053', 'dd-mm-yyyy'), '6', '14', '165', '06', '2053', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19525, to_date('15-06-2053', 'dd-mm-yyyy'), '7', '15', '166', '06', '2053', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19526, to_date('16-06-2053', 'dd-mm-yyyy'), '1', '16', '167', '06', '2053', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19527, to_date('17-06-2053', 'dd-mm-yyyy'), '2', '17', '168', '06', '2053', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19528, to_date('18-06-2053', 'dd-mm-yyyy'), '3', '18', '169', '06', '2053', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19529, to_date('19-06-2053', 'dd-mm-yyyy'), '4', '19', '170', '06', '2053', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19530, to_date('20-06-2053', 'dd-mm-yyyy'), '5', '20', '171', '06', '2053', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19531, to_date('21-06-2053', 'dd-mm-yyyy'), '6', '21', '172', '06', '2053', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19532, to_date('22-06-2053', 'dd-mm-yyyy'), '7', '22', '173', '06', '2053', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19533, to_date('23-06-2053', 'dd-mm-yyyy'), '1', '23', '174', '06', '2053', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19534, to_date('24-06-2053', 'dd-mm-yyyy'), '2', '24', '175', '06', '2053', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19535, to_date('25-06-2053', 'dd-mm-yyyy'), '3', '25', '176', '06', '2053', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19536, to_date('26-06-2053', 'dd-mm-yyyy'), '4', '26', '177', '06', '2053', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19537, to_date('27-06-2053', 'dd-mm-yyyy'), '5', '27', '178', '06', '2053', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19538, to_date('28-06-2053', 'dd-mm-yyyy'), '6', '28', '179', '06', '2053', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19539, to_date('29-06-2053', 'dd-mm-yyyy'), '7', '29', '180', '06', '2053', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19540, to_date('30-06-2053', 'dd-mm-yyyy'), '1', '30', '181', '06', '2053', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19541, to_date('01-07-2053', 'dd-mm-yyyy'), '2', '01', '182', '07', '2053', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19542, to_date('02-07-2053', 'dd-mm-yyyy'), '3', '02', '183', '07', '2053', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19543, to_date('03-07-2053', 'dd-mm-yyyy'), '4', '03', '184', '07', '2053', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19544, to_date('04-07-2053', 'dd-mm-yyyy'), '5', '04', '185', '07', '2053', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19545, to_date('05-07-2053', 'dd-mm-yyyy'), '6', '05', '186', '07', '2053', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19546, to_date('06-07-2053', 'dd-mm-yyyy'), '7', '06', '187', '07', '2053', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19547, to_date('07-07-2053', 'dd-mm-yyyy'), '1', '07', '188', '07', '2053', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19548, to_date('08-07-2053', 'dd-mm-yyyy'), '2', '08', '189', '07', '2053', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19549, to_date('09-07-2053', 'dd-mm-yyyy'), '3', '09', '190', '07', '2053', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19550, to_date('10-07-2053', 'dd-mm-yyyy'), '4', '10', '191', '07', '2053', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19551, to_date('11-07-2053', 'dd-mm-yyyy'), '5', '11', '192', '07', '2053', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19552, to_date('12-07-2053', 'dd-mm-yyyy'), '6', '12', '193', '07', '2053', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19553, to_date('13-07-2053', 'dd-mm-yyyy'), '7', '13', '194', '07', '2053', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19554, to_date('14-07-2053', 'dd-mm-yyyy'), '1', '14', '195', '07', '2053', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19555, to_date('15-07-2053', 'dd-mm-yyyy'), '2', '15', '196', '07', '2053', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19556, to_date('16-07-2053', 'dd-mm-yyyy'), '3', '16', '197', '07', '2053', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19557, to_date('17-07-2053', 'dd-mm-yyyy'), '4', '17', '198', '07', '2053', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19558, to_date('18-07-2053', 'dd-mm-yyyy'), '5', '18', '199', '07', '2053', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19559, to_date('19-07-2053', 'dd-mm-yyyy'), '6', '19', '200', '07', '2053', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19560, to_date('20-07-2053', 'dd-mm-yyyy'), '7', '20', '201', '07', '2053', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19561, to_date('21-07-2053', 'dd-mm-yyyy'), '1', '21', '202', '07', '2053', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19562, to_date('22-07-2053', 'dd-mm-yyyy'), '2', '22', '203', '07', '2053', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19563, to_date('23-07-2053', 'dd-mm-yyyy'), '3', '23', '204', '07', '2053', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19564, to_date('24-07-2053', 'dd-mm-yyyy'), '4', '24', '205', '07', '2053', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19565, to_date('25-07-2053', 'dd-mm-yyyy'), '5', '25', '206', '07', '2053', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19566, to_date('26-07-2053', 'dd-mm-yyyy'), '6', '26', '207', '07', '2053', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19567, to_date('27-07-2053', 'dd-mm-yyyy'), '7', '27', '208', '07', '2053', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19568, to_date('28-07-2053', 'dd-mm-yyyy'), '1', '28', '209', '07', '2053', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19569, to_date('29-07-2053', 'dd-mm-yyyy'), '2', '29', '210', '07', '2053', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19570, to_date('30-07-2053', 'dd-mm-yyyy'), '3', '30', '211', '07', '2053', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19571, to_date('31-07-2053', 'dd-mm-yyyy'), '4', '31', '212', '07', '2053', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19572, to_date('01-08-2053', 'dd-mm-yyyy'), '5', '01', '213', '08', '2053', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19573, to_date('02-08-2053', 'dd-mm-yyyy'), '6', '02', '214', '08', '2053', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19574, to_date('03-08-2053', 'dd-mm-yyyy'), '7', '03', '215', '08', '2053', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19575, to_date('04-08-2053', 'dd-mm-yyyy'), '1', '04', '216', '08', '2053', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19576, to_date('05-08-2053', 'dd-mm-yyyy'), '2', '05', '217', '08', '2053', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19577, to_date('06-08-2053', 'dd-mm-yyyy'), '3', '06', '218', '08', '2053', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19578, to_date('07-08-2053', 'dd-mm-yyyy'), '4', '07', '219', '08', '2053', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19579, to_date('08-08-2053', 'dd-mm-yyyy'), '5', '08', '220', '08', '2053', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19580, to_date('09-08-2053', 'dd-mm-yyyy'), '6', '09', '221', '08', '2053', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19581, to_date('10-08-2053', 'dd-mm-yyyy'), '7', '10', '222', '08', '2053', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19582, to_date('11-08-2053', 'dd-mm-yyyy'), '1', '11', '223', '08', '2053', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19583, to_date('12-08-2053', 'dd-mm-yyyy'), '2', '12', '224', '08', '2053', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19584, to_date('13-08-2053', 'dd-mm-yyyy'), '3', '13', '225', '08', '2053', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21069, to_date('06-09-2057', 'dd-mm-yyyy'), '4', '06', '249', '09', '2057', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21070, to_date('07-09-2057', 'dd-mm-yyyy'), '5', '07', '250', '09', '2057', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21071, to_date('08-09-2057', 'dd-mm-yyyy'), '6', '08', '251', '09', '2057', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21072, to_date('09-09-2057', 'dd-mm-yyyy'), '7', '09', '252', '09', '2057', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21073, to_date('10-09-2057', 'dd-mm-yyyy'), '1', '10', '253', '09', '2057', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21074, to_date('11-09-2057', 'dd-mm-yyyy'), '2', '11', '254', '09', '2057', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21075, to_date('12-09-2057', 'dd-mm-yyyy'), '3', '12', '255', '09', '2057', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21076, to_date('13-09-2057', 'dd-mm-yyyy'), '4', '13', '256', '09', '2057', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21077, to_date('14-09-2057', 'dd-mm-yyyy'), '5', '14', '257', '09', '2057', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21078, to_date('15-09-2057', 'dd-mm-yyyy'), '6', '15', '258', '09', '2057', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21079, to_date('16-09-2057', 'dd-mm-yyyy'), '7', '16', '259', '09', '2057', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21080, to_date('17-09-2057', 'dd-mm-yyyy'), '1', '17', '260', '09', '2057', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21081, to_date('18-09-2057', 'dd-mm-yyyy'), '2', '18', '261', '09', '2057', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21082, to_date('19-09-2057', 'dd-mm-yyyy'), '3', '19', '262', '09', '2057', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21083, to_date('20-09-2057', 'dd-mm-yyyy'), '4', '20', '263', '09', '2057', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21084, to_date('21-09-2057', 'dd-mm-yyyy'), '5', '21', '264', '09', '2057', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21085, to_date('22-09-2057', 'dd-mm-yyyy'), '6', '22', '265', '09', '2057', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21086, to_date('23-09-2057', 'dd-mm-yyyy'), '7', '23', '266', '09', '2057', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21087, to_date('24-09-2057', 'dd-mm-yyyy'), '1', '24', '267', '09', '2057', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21088, to_date('25-09-2057', 'dd-mm-yyyy'), '2', '25', '268', '09', '2057', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21089, to_date('26-09-2057', 'dd-mm-yyyy'), '3', '26', '269', '09', '2057', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21090, to_date('27-09-2057', 'dd-mm-yyyy'), '4', '27', '270', '09', '2057', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21091, to_date('28-09-2057', 'dd-mm-yyyy'), '5', '28', '271', '09', '2057', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21092, to_date('29-09-2057', 'dd-mm-yyyy'), '6', '29', '272', '09', '2057', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21093, to_date('30-09-2057', 'dd-mm-yyyy'), '7', '30', '273', '09', '2057', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21094, to_date('01-10-2057', 'dd-mm-yyyy'), '1', '01', '274', '10', '2057', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21095, to_date('02-10-2057', 'dd-mm-yyyy'), '2', '02', '275', '10', '2057', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21096, to_date('03-10-2057', 'dd-mm-yyyy'), '3', '03', '276', '10', '2057', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21097, to_date('04-10-2057', 'dd-mm-yyyy'), '4', '04', '277', '10', '2057', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21098, to_date('05-10-2057', 'dd-mm-yyyy'), '5', '05', '278', '10', '2057', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21099, to_date('06-10-2057', 'dd-mm-yyyy'), '6', '06', '279', '10', '2057', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21100, to_date('07-10-2057', 'dd-mm-yyyy'), '7', '07', '280', '10', '2057', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21101, to_date('08-10-2057', 'dd-mm-yyyy'), '1', '08', '281', '10', '2057', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21102, to_date('09-10-2057', 'dd-mm-yyyy'), '2', '09', '282', '10', '2057', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21103, to_date('10-10-2057', 'dd-mm-yyyy'), '3', '10', '283', '10', '2057', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21104, to_date('11-10-2057', 'dd-mm-yyyy'), '4', '11', '284', '10', '2057', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21105, to_date('12-10-2057', 'dd-mm-yyyy'), '5', '12', '285', '10', '2057', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21106, to_date('13-10-2057', 'dd-mm-yyyy'), '6', '13', '286', '10', '2057', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21107, to_date('14-10-2057', 'dd-mm-yyyy'), '7', '14', '287', '10', '2057', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21108, to_date('15-10-2057', 'dd-mm-yyyy'), '1', '15', '288', '10', '2057', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21109, to_date('16-10-2057', 'dd-mm-yyyy'), '2', '16', '289', '10', '2057', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21110, to_date('17-10-2057', 'dd-mm-yyyy'), '3', '17', '290', '10', '2057', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21111, to_date('18-10-2057', 'dd-mm-yyyy'), '4', '18', '291', '10', '2057', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21112, to_date('19-10-2057', 'dd-mm-yyyy'), '5', '19', '292', '10', '2057', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21113, to_date('20-10-2057', 'dd-mm-yyyy'), '6', '20', '293', '10', '2057', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21114, to_date('21-10-2057', 'dd-mm-yyyy'), '7', '21', '294', '10', '2057', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21115, to_date('22-10-2057', 'dd-mm-yyyy'), '1', '22', '295', '10', '2057', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21116, to_date('23-10-2057', 'dd-mm-yyyy'), '2', '23', '296', '10', '2057', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21117, to_date('24-10-2057', 'dd-mm-yyyy'), '3', '24', '297', '10', '2057', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21118, to_date('25-10-2057', 'dd-mm-yyyy'), '4', '25', '298', '10', '2057', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21119, to_date('26-10-2057', 'dd-mm-yyyy'), '5', '26', '299', '10', '2057', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21120, to_date('27-10-2057', 'dd-mm-yyyy'), '6', '27', '300', '10', '2057', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21121, to_date('28-10-2057', 'dd-mm-yyyy'), '7', '28', '301', '10', '2057', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21122, to_date('29-10-2057', 'dd-mm-yyyy'), '1', '29', '302', '10', '2057', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21123, to_date('30-10-2057', 'dd-mm-yyyy'), '2', '30', '303', '10', '2057', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21124, to_date('31-10-2057', 'dd-mm-yyyy'), '3', '31', '304', '10', '2057', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21125, to_date('01-11-2057', 'dd-mm-yyyy'), '4', '01', '305', '11', '2057', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21126, to_date('02-11-2057', 'dd-mm-yyyy'), '5', '02', '306', '11', '2057', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21127, to_date('03-11-2057', 'dd-mm-yyyy'), '6', '03', '307', '11', '2057', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21128, to_date('04-11-2057', 'dd-mm-yyyy'), '7', '04', '308', '11', '2057', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21129, to_date('05-11-2057', 'dd-mm-yyyy'), '1', '05', '309', '11', '2057', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21130, to_date('06-11-2057', 'dd-mm-yyyy'), '2', '06', '310', '11', '2057', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21131, to_date('07-11-2057', 'dd-mm-yyyy'), '3', '07', '311', '11', '2057', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21132, to_date('08-11-2057', 'dd-mm-yyyy'), '4', '08', '312', '11', '2057', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21133, to_date('09-11-2057', 'dd-mm-yyyy'), '5', '09', '313', '11', '2057', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21134, to_date('10-11-2057', 'dd-mm-yyyy'), '6', '10', '314', '11', '2057', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21135, to_date('11-11-2057', 'dd-mm-yyyy'), '7', '11', '315', '11', '2057', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21136, to_date('12-11-2057', 'dd-mm-yyyy'), '1', '12', '316', '11', '2057', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21137, to_date('13-11-2057', 'dd-mm-yyyy'), '2', '13', '317', '11', '2057', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21138, to_date('14-11-2057', 'dd-mm-yyyy'), '3', '14', '318', '11', '2057', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21139, to_date('15-11-2057', 'dd-mm-yyyy'), '4', '15', '319', '11', '2057', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21140, to_date('16-11-2057', 'dd-mm-yyyy'), '5', '16', '320', '11', '2057', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21141, to_date('17-11-2057', 'dd-mm-yyyy'), '6', '17', '321', '11', '2057', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21142, to_date('18-11-2057', 'dd-mm-yyyy'), '7', '18', '322', '11', '2057', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21143, to_date('19-11-2057', 'dd-mm-yyyy'), '1', '19', '323', '11', '2057', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21144, to_date('20-11-2057', 'dd-mm-yyyy'), '2', '20', '324', '11', '2057', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21145, to_date('21-11-2057', 'dd-mm-yyyy'), '3', '21', '325', '11', '2057', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21146, to_date('22-11-2057', 'dd-mm-yyyy'), '4', '22', '326', '11', '2057', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21147, to_date('23-11-2057', 'dd-mm-yyyy'), '5', '23', '327', '11', '2057', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21148, to_date('24-11-2057', 'dd-mm-yyyy'), '6', '24', '328', '11', '2057', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21149, to_date('25-11-2057', 'dd-mm-yyyy'), '7', '25', '329', '11', '2057', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21150, to_date('26-11-2057', 'dd-mm-yyyy'), '1', '26', '330', '11', '2057', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21151, to_date('27-11-2057', 'dd-mm-yyyy'), '2', '27', '331', '11', '2057', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21152, to_date('28-11-2057', 'dd-mm-yyyy'), '3', '28', '332', '11', '2057', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21153, to_date('29-11-2057', 'dd-mm-yyyy'), '4', '29', '333', '11', '2057', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21154, to_date('30-11-2057', 'dd-mm-yyyy'), '5', '30', '334', '11', '2057', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21155, to_date('01-12-2057', 'dd-mm-yyyy'), '6', '01', '335', '12', '2057', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21156, to_date('02-12-2057', 'dd-mm-yyyy'), '7', '02', '336', '12', '2057', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21157, to_date('03-12-2057', 'dd-mm-yyyy'), '1', '03', '337', '12', '2057', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21158, to_date('04-12-2057', 'dd-mm-yyyy'), '2', '04', '338', '12', '2057', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21159, to_date('05-12-2057', 'dd-mm-yyyy'), '3', '05', '339', '12', '2057', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21160, to_date('06-12-2057', 'dd-mm-yyyy'), '4', '06', '340', '12', '2057', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21161, to_date('07-12-2057', 'dd-mm-yyyy'), '5', '07', '341', '12', '2057', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21162, to_date('08-12-2057', 'dd-mm-yyyy'), '6', '08', '342', '12', '2057', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21163, to_date('09-12-2057', 'dd-mm-yyyy'), '7', '09', '343', '12', '2057', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21164, to_date('10-12-2057', 'dd-mm-yyyy'), '1', '10', '344', '12', '2057', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21165, to_date('11-12-2057', 'dd-mm-yyyy'), '2', '11', '345', '12', '2057', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21166, to_date('12-12-2057', 'dd-mm-yyyy'), '3', '12', '346', '12', '2057', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21167, to_date('13-12-2057', 'dd-mm-yyyy'), '4', '13', '347', '12', '2057', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21168, to_date('14-12-2057', 'dd-mm-yyyy'), '5', '14', '348', '12', '2057', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21169, to_date('15-12-2057', 'dd-mm-yyyy'), '6', '15', '349', '12', '2057', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21170, to_date('16-12-2057', 'dd-mm-yyyy'), '7', '16', '350', '12', '2057', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21171, to_date('17-12-2057', 'dd-mm-yyyy'), '1', '17', '351', '12', '2057', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21172, to_date('18-12-2057', 'dd-mm-yyyy'), '2', '18', '352', '12', '2057', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21173, to_date('19-12-2057', 'dd-mm-yyyy'), '3', '19', '353', '12', '2057', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21174, to_date('20-12-2057', 'dd-mm-yyyy'), '4', '20', '354', '12', '2057', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22659, to_date('13-01-2062', 'dd-mm-yyyy'), '5', '13', '013', '01', '2062', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22660, to_date('14-01-2062', 'dd-mm-yyyy'), '6', '14', '014', '01', '2062', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22661, to_date('15-01-2062', 'dd-mm-yyyy'), '7', '15', '015', '01', '2062', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22662, to_date('16-01-2062', 'dd-mm-yyyy'), '1', '16', '016', '01', '2062', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22663, to_date('17-01-2062', 'dd-mm-yyyy'), '2', '17', '017', '01', '2062', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22664, to_date('18-01-2062', 'dd-mm-yyyy'), '3', '18', '018', '01', '2062', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22665, to_date('19-01-2062', 'dd-mm-yyyy'), '4', '19', '019', '01', '2062', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22666, to_date('20-01-2062', 'dd-mm-yyyy'), '5', '20', '020', '01', '2062', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22667, to_date('21-01-2062', 'dd-mm-yyyy'), '6', '21', '021', '01', '2062', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22668, to_date('22-01-2062', 'dd-mm-yyyy'), '7', '22', '022', '01', '2062', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22669, to_date('23-01-2062', 'dd-mm-yyyy'), '1', '23', '023', '01', '2062', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22670, to_date('24-01-2062', 'dd-mm-yyyy'), '2', '24', '024', '01', '2062', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22671, to_date('25-01-2062', 'dd-mm-yyyy'), '3', '25', '025', '01', '2062', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22672, to_date('26-01-2062', 'dd-mm-yyyy'), '4', '26', '026', '01', '2062', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22673, to_date('27-01-2062', 'dd-mm-yyyy'), '5', '27', '027', '01', '2062', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22674, to_date('28-01-2062', 'dd-mm-yyyy'), '6', '28', '028', '01', '2062', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22675, to_date('29-01-2062', 'dd-mm-yyyy'), '7', '29', '029', '01', '2062', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22676, to_date('30-01-2062', 'dd-mm-yyyy'), '1', '30', '030', '01', '2062', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22677, to_date('31-01-2062', 'dd-mm-yyyy'), '2', '31', '031', '01', '2062', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22678, to_date('01-02-2062', 'dd-mm-yyyy'), '3', '01', '032', '02', '2062', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22679, to_date('02-02-2062', 'dd-mm-yyyy'), '4', '02', '033', '02', '2062', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22680, to_date('03-02-2062', 'dd-mm-yyyy'), '5', '03', '034', '02', '2062', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22681, to_date('04-02-2062', 'dd-mm-yyyy'), '6', '04', '035', '02', '2062', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22682, to_date('05-02-2062', 'dd-mm-yyyy'), '7', '05', '036', '02', '2062', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22683, to_date('06-02-2062', 'dd-mm-yyyy'), '1', '06', '037', '02', '2062', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22684, to_date('07-02-2062', 'dd-mm-yyyy'), '2', '07', '038', '02', '2062', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22685, to_date('08-02-2062', 'dd-mm-yyyy'), '3', '08', '039', '02', '2062', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22686, to_date('09-02-2062', 'dd-mm-yyyy'), '4', '09', '040', '02', '2062', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22687, to_date('10-02-2062', 'dd-mm-yyyy'), '5', '10', '041', '02', '2062', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22688, to_date('11-02-2062', 'dd-mm-yyyy'), '6', '11', '042', '02', '2062', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22689, to_date('12-02-2062', 'dd-mm-yyyy'), '7', '12', '043', '02', '2062', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22690, to_date('13-02-2062', 'dd-mm-yyyy'), '1', '13', '044', '02', '2062', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22691, to_date('14-02-2062', 'dd-mm-yyyy'), '2', '14', '045', '02', '2062', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22692, to_date('15-02-2062', 'dd-mm-yyyy'), '3', '15', '046', '02', '2062', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22693, to_date('16-02-2062', 'dd-mm-yyyy'), '4', '16', '047', '02', '2062', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22694, to_date('17-02-2062', 'dd-mm-yyyy'), '5', '17', '048', '02', '2062', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22695, to_date('18-02-2062', 'dd-mm-yyyy'), '6', '18', '049', '02', '2062', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22696, to_date('19-02-2062', 'dd-mm-yyyy'), '7', '19', '050', '02', '2062', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22697, to_date('20-02-2062', 'dd-mm-yyyy'), '1', '20', '051', '02', '2062', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22698, to_date('21-02-2062', 'dd-mm-yyyy'), '2', '21', '052', '02', '2062', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22699, to_date('22-02-2062', 'dd-mm-yyyy'), '3', '22', '053', '02', '2062', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22700, to_date('23-02-2062', 'dd-mm-yyyy'), '4', '23', '054', '02', '2062', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22701, to_date('24-02-2062', 'dd-mm-yyyy'), '5', '24', '055', '02', '2062', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22702, to_date('25-02-2062', 'dd-mm-yyyy'), '6', '25', '056', '02', '2062', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22703, to_date('26-02-2062', 'dd-mm-yyyy'), '7', '26', '057', '02', '2062', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22704, to_date('27-02-2062', 'dd-mm-yyyy'), '1', '27', '058', '02', '2062', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22705, to_date('28-02-2062', 'dd-mm-yyyy'), '2', '28', '059', '02', '2062', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22706, to_date('01-03-2062', 'dd-mm-yyyy'), '3', '01', '060', '03', '2062', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22707, to_date('02-03-2062', 'dd-mm-yyyy'), '4', '02', '061', '03', '2062', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22708, to_date('03-03-2062', 'dd-mm-yyyy'), '5', '03', '062', '03', '2062', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22709, to_date('04-03-2062', 'dd-mm-yyyy'), '6', '04', '063', '03', '2062', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22710, to_date('05-03-2062', 'dd-mm-yyyy'), '7', '05', '064', '03', '2062', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22711, to_date('06-03-2062', 'dd-mm-yyyy'), '1', '06', '065', '03', '2062', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22712, to_date('07-03-2062', 'dd-mm-yyyy'), '2', '07', '066', '03', '2062', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22713, to_date('08-03-2062', 'dd-mm-yyyy'), '3', '08', '067', '03', '2062', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22714, to_date('09-03-2062', 'dd-mm-yyyy'), '4', '09', '068', '03', '2062', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22715, to_date('10-03-2062', 'dd-mm-yyyy'), '5', '10', '069', '03', '2062', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22716, to_date('11-03-2062', 'dd-mm-yyyy'), '6', '11', '070', '03', '2062', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22717, to_date('12-03-2062', 'dd-mm-yyyy'), '7', '12', '071', '03', '2062', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22718, to_date('13-03-2062', 'dd-mm-yyyy'), '1', '13', '072', '03', '2062', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22719, to_date('14-03-2062', 'dd-mm-yyyy'), '2', '14', '073', '03', '2062', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22720, to_date('15-03-2062', 'dd-mm-yyyy'), '3', '15', '074', '03', '2062', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22721, to_date('16-03-2062', 'dd-mm-yyyy'), '4', '16', '075', '03', '2062', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22722, to_date('17-03-2062', 'dd-mm-yyyy'), '5', '17', '076', '03', '2062', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22723, to_date('18-03-2062', 'dd-mm-yyyy'), '6', '18', '077', '03', '2062', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22724, to_date('19-03-2062', 'dd-mm-yyyy'), '7', '19', '078', '03', '2062', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22725, to_date('20-03-2062', 'dd-mm-yyyy'), '1', '20', '079', '03', '2062', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22726, to_date('21-03-2062', 'dd-mm-yyyy'), '2', '21', '080', '03', '2062', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22727, to_date('22-03-2062', 'dd-mm-yyyy'), '3', '22', '081', '03', '2062', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22728, to_date('23-03-2062', 'dd-mm-yyyy'), '4', '23', '082', '03', '2062', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22729, to_date('24-03-2062', 'dd-mm-yyyy'), '5', '24', '083', '03', '2062', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22730, to_date('25-03-2062', 'dd-mm-yyyy'), '6', '25', '084', '03', '2062', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22731, to_date('26-03-2062', 'dd-mm-yyyy'), '7', '26', '085', '03', '2062', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22732, to_date('27-03-2062', 'dd-mm-yyyy'), '1', '27', '086', '03', '2062', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22733, to_date('28-03-2062', 'dd-mm-yyyy'), '2', '28', '087', '03', '2062', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22734, to_date('29-03-2062', 'dd-mm-yyyy'), '3', '29', '088', '03', '2062', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22735, to_date('30-03-2062', 'dd-mm-yyyy'), '4', '30', '089', '03', '2062', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22736, to_date('31-03-2062', 'dd-mm-yyyy'), '5', '31', '090', '03', '2062', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22737, to_date('01-04-2062', 'dd-mm-yyyy'), '6', '01', '091', '04', '2062', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22738, to_date('02-04-2062', 'dd-mm-yyyy'), '7', '02', '092', '04', '2062', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22739, to_date('03-04-2062', 'dd-mm-yyyy'), '1', '03', '093', '04', '2062', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22740, to_date('04-04-2062', 'dd-mm-yyyy'), '2', '04', '094', '04', '2062', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22741, to_date('05-04-2062', 'dd-mm-yyyy'), '3', '05', '095', '04', '2062', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22742, to_date('06-04-2062', 'dd-mm-yyyy'), '4', '06', '096', '04', '2062', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22743, to_date('07-04-2062', 'dd-mm-yyyy'), '5', '07', '097', '04', '2062', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22744, to_date('08-04-2062', 'dd-mm-yyyy'), '6', '08', '098', '04', '2062', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22745, to_date('09-04-2062', 'dd-mm-yyyy'), '7', '09', '099', '04', '2062', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22746, to_date('10-04-2062', 'dd-mm-yyyy'), '1', '10', '100', '04', '2062', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22747, to_date('11-04-2062', 'dd-mm-yyyy'), '2', '11', '101', '04', '2062', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22748, to_date('12-04-2062', 'dd-mm-yyyy'), '3', '12', '102', '04', '2062', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22749, to_date('13-04-2062', 'dd-mm-yyyy'), '4', '13', '103', '04', '2062', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22750, to_date('14-04-2062', 'dd-mm-yyyy'), '5', '14', '104', '04', '2062', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22751, to_date('15-04-2062', 'dd-mm-yyyy'), '6', '15', '105', '04', '2062', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22752, to_date('16-04-2062', 'dd-mm-yyyy'), '7', '16', '106', '04', '2062', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22753, to_date('17-04-2062', 'dd-mm-yyyy'), '1', '17', '107', '04', '2062', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22754, to_date('18-04-2062', 'dd-mm-yyyy'), '2', '18', '108', '04', '2062', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22755, to_date('19-04-2062', 'dd-mm-yyyy'), '3', '19', '109', '04', '2062', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22756, to_date('20-04-2062', 'dd-mm-yyyy'), '4', '20', '110', '04', '2062', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22757, to_date('21-04-2062', 'dd-mm-yyyy'), '5', '21', '111', '04', '2062', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22758, to_date('22-04-2062', 'dd-mm-yyyy'), '6', '22', '112', '04', '2062', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22759, to_date('23-04-2062', 'dd-mm-yyyy'), '7', '23', '113', '04', '2062', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22760, to_date('24-04-2062', 'dd-mm-yyyy'), '1', '24', '114', '04', '2062', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22761, to_date('25-04-2062', 'dd-mm-yyyy'), '2', '25', '115', '04', '2062', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22762, to_date('26-04-2062', 'dd-mm-yyyy'), '3', '26', '116', '04', '2062', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22763, to_date('27-04-2062', 'dd-mm-yyyy'), '4', '27', '117', '04', '2062', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22764, to_date('28-04-2062', 'dd-mm-yyyy'), '5', '28', '118', '04', '2062', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24249, to_date('22-05-2066', 'dd-mm-yyyy'), '6', '22', '142', '05', '2066', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24250, to_date('23-05-2066', 'dd-mm-yyyy'), '7', '23', '143', '05', '2066', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24251, to_date('24-05-2066', 'dd-mm-yyyy'), '1', '24', '144', '05', '2066', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24252, to_date('25-05-2066', 'dd-mm-yyyy'), '2', '25', '145', '05', '2066', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24253, to_date('26-05-2066', 'dd-mm-yyyy'), '3', '26', '146', '05', '2066', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24254, to_date('27-05-2066', 'dd-mm-yyyy'), '4', '27', '147', '05', '2066', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24255, to_date('28-05-2066', 'dd-mm-yyyy'), '5', '28', '148', '05', '2066', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24256, to_date('29-05-2066', 'dd-mm-yyyy'), '6', '29', '149', '05', '2066', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24257, to_date('30-05-2066', 'dd-mm-yyyy'), '7', '30', '150', '05', '2066', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24258, to_date('31-05-2066', 'dd-mm-yyyy'), '1', '31', '151', '05', '2066', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24259, to_date('01-06-2066', 'dd-mm-yyyy'), '2', '01', '152', '06', '2066', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24260, to_date('02-06-2066', 'dd-mm-yyyy'), '3', '02', '153', '06', '2066', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24261, to_date('03-06-2066', 'dd-mm-yyyy'), '4', '03', '154', '06', '2066', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24262, to_date('04-06-2066', 'dd-mm-yyyy'), '5', '04', '155', '06', '2066', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24263, to_date('05-06-2066', 'dd-mm-yyyy'), '6', '05', '156', '06', '2066', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24264, to_date('06-06-2066', 'dd-mm-yyyy'), '7', '06', '157', '06', '2066', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24265, to_date('07-06-2066', 'dd-mm-yyyy'), '1', '07', '158', '06', '2066', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24266, to_date('08-06-2066', 'dd-mm-yyyy'), '2', '08', '159', '06', '2066', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24267, to_date('09-06-2066', 'dd-mm-yyyy'), '3', '09', '160', '06', '2066', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24268, to_date('10-06-2066', 'dd-mm-yyyy'), '4', '10', '161', '06', '2066', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24269, to_date('11-06-2066', 'dd-mm-yyyy'), '5', '11', '162', '06', '2066', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24270, to_date('12-06-2066', 'dd-mm-yyyy'), '6', '12', '163', '06', '2066', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24271, to_date('13-06-2066', 'dd-mm-yyyy'), '7', '13', '164', '06', '2066', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24272, to_date('14-06-2066', 'dd-mm-yyyy'), '1', '14', '165', '06', '2066', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24273, to_date('15-06-2066', 'dd-mm-yyyy'), '2', '15', '166', '06', '2066', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24274, to_date('16-06-2066', 'dd-mm-yyyy'), '3', '16', '167', '06', '2066', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24275, to_date('17-06-2066', 'dd-mm-yyyy'), '4', '17', '168', '06', '2066', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24276, to_date('18-06-2066', 'dd-mm-yyyy'), '5', '18', '169', '06', '2066', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24277, to_date('19-06-2066', 'dd-mm-yyyy'), '6', '19', '170', '06', '2066', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24278, to_date('20-06-2066', 'dd-mm-yyyy'), '7', '20', '171', '06', '2066', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24279, to_date('21-06-2066', 'dd-mm-yyyy'), '1', '21', '172', '06', '2066', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24280, to_date('22-06-2066', 'dd-mm-yyyy'), '2', '22', '173', '06', '2066', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24281, to_date('23-06-2066', 'dd-mm-yyyy'), '3', '23', '174', '06', '2066', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24282, to_date('24-06-2066', 'dd-mm-yyyy'), '4', '24', '175', '06', '2066', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24283, to_date('25-06-2066', 'dd-mm-yyyy'), '5', '25', '176', '06', '2066', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24284, to_date('26-06-2066', 'dd-mm-yyyy'), '6', '26', '177', '06', '2066', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24285, to_date('27-06-2066', 'dd-mm-yyyy'), '7', '27', '178', '06', '2066', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24286, to_date('28-06-2066', 'dd-mm-yyyy'), '1', '28', '179', '06', '2066', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24287, to_date('29-06-2066', 'dd-mm-yyyy'), '2', '29', '180', '06', '2066', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24288, to_date('30-06-2066', 'dd-mm-yyyy'), '3', '30', '181', '06', '2066', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24289, to_date('01-07-2066', 'dd-mm-yyyy'), '4', '01', '182', '07', '2066', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24290, to_date('02-07-2066', 'dd-mm-yyyy'), '5', '02', '183', '07', '2066', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24291, to_date('03-07-2066', 'dd-mm-yyyy'), '6', '03', '184', '07', '2066', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24292, to_date('04-07-2066', 'dd-mm-yyyy'), '7', '04', '185', '07', '2066', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24293, to_date('05-07-2066', 'dd-mm-yyyy'), '1', '05', '186', '07', '2066', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24294, to_date('06-07-2066', 'dd-mm-yyyy'), '2', '06', '187', '07', '2066', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24295, to_date('07-07-2066', 'dd-mm-yyyy'), '3', '07', '188', '07', '2066', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24296, to_date('08-07-2066', 'dd-mm-yyyy'), '4', '08', '189', '07', '2066', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24297, to_date('09-07-2066', 'dd-mm-yyyy'), '5', '09', '190', '07', '2066', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24298, to_date('10-07-2066', 'dd-mm-yyyy'), '6', '10', '191', '07', '2066', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24299, to_date('11-07-2066', 'dd-mm-yyyy'), '7', '11', '192', '07', '2066', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24300, to_date('12-07-2066', 'dd-mm-yyyy'), '1', '12', '193', '07', '2066', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24301, to_date('13-07-2066', 'dd-mm-yyyy'), '2', '13', '194', '07', '2066', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24302, to_date('14-07-2066', 'dd-mm-yyyy'), '3', '14', '195', '07', '2066', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24303, to_date('15-07-2066', 'dd-mm-yyyy'), '4', '15', '196', '07', '2066', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24304, to_date('16-07-2066', 'dd-mm-yyyy'), '5', '16', '197', '07', '2066', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24305, to_date('17-07-2066', 'dd-mm-yyyy'), '6', '17', '198', '07', '2066', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24306, to_date('18-07-2066', 'dd-mm-yyyy'), '7', '18', '199', '07', '2066', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24307, to_date('19-07-2066', 'dd-mm-yyyy'), '1', '19', '200', '07', '2066', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24308, to_date('20-07-2066', 'dd-mm-yyyy'), '2', '20', '201', '07', '2066', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24309, to_date('21-07-2066', 'dd-mm-yyyy'), '3', '21', '202', '07', '2066', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24310, to_date('22-07-2066', 'dd-mm-yyyy'), '4', '22', '203', '07', '2066', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24311, to_date('23-07-2066', 'dd-mm-yyyy'), '5', '23', '204', '07', '2066', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24312, to_date('24-07-2066', 'dd-mm-yyyy'), '6', '24', '205', '07', '2066', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24313, to_date('25-07-2066', 'dd-mm-yyyy'), '7', '25', '206', '07', '2066', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24314, to_date('26-07-2066', 'dd-mm-yyyy'), '1', '26', '207', '07', '2066', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24315, to_date('27-07-2066', 'dd-mm-yyyy'), '2', '27', '208', '07', '2066', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24316, to_date('28-07-2066', 'dd-mm-yyyy'), '3', '28', '209', '07', '2066', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24317, to_date('29-07-2066', 'dd-mm-yyyy'), '4', '29', '210', '07', '2066', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24318, to_date('30-07-2066', 'dd-mm-yyyy'), '5', '30', '211', '07', '2066', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24319, to_date('31-07-2066', 'dd-mm-yyyy'), '6', '31', '212', '07', '2066', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24320, to_date('01-08-2066', 'dd-mm-yyyy'), '7', '01', '213', '08', '2066', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24321, to_date('02-08-2066', 'dd-mm-yyyy'), '1', '02', '214', '08', '2066', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24322, to_date('03-08-2066', 'dd-mm-yyyy'), '2', '03', '215', '08', '2066', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24323, to_date('04-08-2066', 'dd-mm-yyyy'), '3', '04', '216', '08', '2066', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24324, to_date('05-08-2066', 'dd-mm-yyyy'), '4', '05', '217', '08', '2066', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24325, to_date('06-08-2066', 'dd-mm-yyyy'), '5', '06', '218', '08', '2066', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24326, to_date('07-08-2066', 'dd-mm-yyyy'), '6', '07', '219', '08', '2066', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24327, to_date('08-08-2066', 'dd-mm-yyyy'), '7', '08', '220', '08', '2066', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24328, to_date('09-08-2066', 'dd-mm-yyyy'), '1', '09', '221', '08', '2066', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24329, to_date('10-08-2066', 'dd-mm-yyyy'), '2', '10', '222', '08', '2066', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24330, to_date('11-08-2066', 'dd-mm-yyyy'), '3', '11', '223', '08', '2066', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24331, to_date('12-08-2066', 'dd-mm-yyyy'), '4', '12', '224', '08', '2066', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24332, to_date('13-08-2066', 'dd-mm-yyyy'), '5', '13', '225', '08', '2066', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24333, to_date('14-08-2066', 'dd-mm-yyyy'), '6', '14', '226', '08', '2066', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24334, to_date('15-08-2066', 'dd-mm-yyyy'), '7', '15', '227', '08', '2066', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24335, to_date('16-08-2066', 'dd-mm-yyyy'), '1', '16', '228', '08', '2066', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24336, to_date('17-08-2066', 'dd-mm-yyyy'), '2', '17', '229', '08', '2066', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24337, to_date('18-08-2066', 'dd-mm-yyyy'), '3', '18', '230', '08', '2066', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24338, to_date('19-08-2066', 'dd-mm-yyyy'), '4', '19', '231', '08', '2066', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24339, to_date('20-08-2066', 'dd-mm-yyyy'), '5', '20', '232', '08', '2066', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24340, to_date('21-08-2066', 'dd-mm-yyyy'), '6', '21', '233', '08', '2066', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24341, to_date('22-08-2066', 'dd-mm-yyyy'), '7', '22', '234', '08', '2066', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24342, to_date('23-08-2066', 'dd-mm-yyyy'), '1', '23', '235', '08', '2066', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24343, to_date('24-08-2066', 'dd-mm-yyyy'), '2', '24', '236', '08', '2066', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24344, to_date('25-08-2066', 'dd-mm-yyyy'), '3', '25', '237', '08', '2066', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24345, to_date('26-08-2066', 'dd-mm-yyyy'), '4', '26', '238', '08', '2066', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24346, to_date('27-08-2066', 'dd-mm-yyyy'), '5', '27', '239', '08', '2066', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24347, to_date('28-08-2066', 'dd-mm-yyyy'), '6', '28', '240', '08', '2066', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24348, to_date('29-08-2066', 'dd-mm-yyyy'), '7', '29', '241', '08', '2066', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24349, to_date('30-08-2066', 'dd-mm-yyyy'), '1', '30', '242', '08', '2066', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24350, to_date('31-08-2066', 'dd-mm-yyyy'), '2', '31', '243', '08', '2066', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24351, to_date('01-09-2066', 'dd-mm-yyyy'), '3', '01', '244', '09', '2066', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24352, to_date('02-09-2066', 'dd-mm-yyyy'), '4', '02', '245', '09', '2066', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24353, to_date('03-09-2066', 'dd-mm-yyyy'), '5', '03', '246', '09', '2066', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24354, to_date('04-09-2066', 'dd-mm-yyyy'), '6', '04', '247', '09', '2066', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19585, to_date('14-08-2053', 'dd-mm-yyyy'), '4', '14', '226', '08', '2053', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19586, to_date('15-08-2053', 'dd-mm-yyyy'), '5', '15', '227', '08', '2053', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19587, to_date('16-08-2053', 'dd-mm-yyyy'), '6', '16', '228', '08', '2053', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19588, to_date('17-08-2053', 'dd-mm-yyyy'), '7', '17', '229', '08', '2053', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19589, to_date('18-08-2053', 'dd-mm-yyyy'), '1', '18', '230', '08', '2053', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19590, to_date('19-08-2053', 'dd-mm-yyyy'), '2', '19', '231', '08', '2053', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19591, to_date('20-08-2053', 'dd-mm-yyyy'), '3', '20', '232', '08', '2053', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19592, to_date('21-08-2053', 'dd-mm-yyyy'), '4', '21', '233', '08', '2053', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19593, to_date('22-08-2053', 'dd-mm-yyyy'), '5', '22', '234', '08', '2053', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19594, to_date('23-08-2053', 'dd-mm-yyyy'), '6', '23', '235', '08', '2053', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19595, to_date('24-08-2053', 'dd-mm-yyyy'), '7', '24', '236', '08', '2053', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19596, to_date('25-08-2053', 'dd-mm-yyyy'), '1', '25', '237', '08', '2053', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19597, to_date('26-08-2053', 'dd-mm-yyyy'), '2', '26', '238', '08', '2053', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19598, to_date('27-08-2053', 'dd-mm-yyyy'), '3', '27', '239', '08', '2053', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19599, to_date('28-08-2053', 'dd-mm-yyyy'), '4', '28', '240', '08', '2053', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19600, to_date('29-08-2053', 'dd-mm-yyyy'), '5', '29', '241', '08', '2053', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19601, to_date('30-08-2053', 'dd-mm-yyyy'), '6', '30', '242', '08', '2053', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19602, to_date('31-08-2053', 'dd-mm-yyyy'), '7', '31', '243', '08', '2053', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19603, to_date('01-09-2053', 'dd-mm-yyyy'), '1', '01', '244', '09', '2053', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19604, to_date('02-09-2053', 'dd-mm-yyyy'), '2', '02', '245', '09', '2053', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19605, to_date('03-09-2053', 'dd-mm-yyyy'), '3', '03', '246', '09', '2053', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19606, to_date('04-09-2053', 'dd-mm-yyyy'), '4', '04', '247', '09', '2053', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19607, to_date('05-09-2053', 'dd-mm-yyyy'), '5', '05', '248', '09', '2053', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19608, to_date('06-09-2053', 'dd-mm-yyyy'), '6', '06', '249', '09', '2053', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19609, to_date('07-09-2053', 'dd-mm-yyyy'), '7', '07', '250', '09', '2053', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19610, to_date('08-09-2053', 'dd-mm-yyyy'), '1', '08', '251', '09', '2053', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19611, to_date('09-09-2053', 'dd-mm-yyyy'), '2', '09', '252', '09', '2053', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19612, to_date('10-09-2053', 'dd-mm-yyyy'), '3', '10', '253', '09', '2053', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19613, to_date('11-09-2053', 'dd-mm-yyyy'), '4', '11', '254', '09', '2053', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19614, to_date('12-09-2053', 'dd-mm-yyyy'), '5', '12', '255', '09', '2053', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19615, to_date('13-09-2053', 'dd-mm-yyyy'), '6', '13', '256', '09', '2053', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19616, to_date('14-09-2053', 'dd-mm-yyyy'), '7', '14', '257', '09', '2053', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19617, to_date('15-09-2053', 'dd-mm-yyyy'), '1', '15', '258', '09', '2053', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19618, to_date('16-09-2053', 'dd-mm-yyyy'), '2', '16', '259', '09', '2053', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19619, to_date('17-09-2053', 'dd-mm-yyyy'), '3', '17', '260', '09', '2053', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19620, to_date('18-09-2053', 'dd-mm-yyyy'), '4', '18', '261', '09', '2053', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19621, to_date('19-09-2053', 'dd-mm-yyyy'), '5', '19', '262', '09', '2053', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19622, to_date('20-09-2053', 'dd-mm-yyyy'), '6', '20', '263', '09', '2053', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19623, to_date('21-09-2053', 'dd-mm-yyyy'), '7', '21', '264', '09', '2053', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19624, to_date('22-09-2053', 'dd-mm-yyyy'), '1', '22', '265', '09', '2053', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19625, to_date('23-09-2053', 'dd-mm-yyyy'), '2', '23', '266', '09', '2053', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19626, to_date('24-09-2053', 'dd-mm-yyyy'), '3', '24', '267', '09', '2053', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19627, to_date('25-09-2053', 'dd-mm-yyyy'), '4', '25', '268', '09', '2053', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19628, to_date('26-09-2053', 'dd-mm-yyyy'), '5', '26', '269', '09', '2053', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19629, to_date('27-09-2053', 'dd-mm-yyyy'), '6', '27', '270', '09', '2053', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19630, to_date('28-09-2053', 'dd-mm-yyyy'), '7', '28', '271', '09', '2053', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19631, to_date('29-09-2053', 'dd-mm-yyyy'), '1', '29', '272', '09', '2053', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19632, to_date('30-09-2053', 'dd-mm-yyyy'), '2', '30', '273', '09', '2053', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19633, to_date('01-10-2053', 'dd-mm-yyyy'), '3', '01', '274', '10', '2053', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19634, to_date('02-10-2053', 'dd-mm-yyyy'), '4', '02', '275', '10', '2053', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19635, to_date('03-10-2053', 'dd-mm-yyyy'), '5', '03', '276', '10', '2053', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19636, to_date('04-10-2053', 'dd-mm-yyyy'), '6', '04', '277', '10', '2053', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19637, to_date('05-10-2053', 'dd-mm-yyyy'), '7', '05', '278', '10', '2053', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19638, to_date('06-10-2053', 'dd-mm-yyyy'), '1', '06', '279', '10', '2053', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19639, to_date('07-10-2053', 'dd-mm-yyyy'), '2', '07', '280', '10', '2053', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19640, to_date('08-10-2053', 'dd-mm-yyyy'), '3', '08', '281', '10', '2053', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19641, to_date('09-10-2053', 'dd-mm-yyyy'), '4', '09', '282', '10', '2053', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19642, to_date('10-10-2053', 'dd-mm-yyyy'), '5', '10', '283', '10', '2053', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19643, to_date('11-10-2053', 'dd-mm-yyyy'), '6', '11', '284', '10', '2053', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19644, to_date('12-10-2053', 'dd-mm-yyyy'), '7', '12', '285', '10', '2053', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19645, to_date('13-10-2053', 'dd-mm-yyyy'), '1', '13', '286', '10', '2053', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19646, to_date('14-10-2053', 'dd-mm-yyyy'), '2', '14', '287', '10', '2053', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19647, to_date('15-10-2053', 'dd-mm-yyyy'), '3', '15', '288', '10', '2053', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19648, to_date('16-10-2053', 'dd-mm-yyyy'), '4', '16', '289', '10', '2053', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19649, to_date('17-10-2053', 'dd-mm-yyyy'), '5', '17', '290', '10', '2053', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19650, to_date('18-10-2053', 'dd-mm-yyyy'), '6', '18', '291', '10', '2053', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19651, to_date('19-10-2053', 'dd-mm-yyyy'), '7', '19', '292', '10', '2053', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19652, to_date('20-10-2053', 'dd-mm-yyyy'), '1', '20', '293', '10', '2053', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19653, to_date('21-10-2053', 'dd-mm-yyyy'), '2', '21', '294', '10', '2053', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19654, to_date('22-10-2053', 'dd-mm-yyyy'), '3', '22', '295', '10', '2053', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19655, to_date('23-10-2053', 'dd-mm-yyyy'), '4', '23', '296', '10', '2053', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19656, to_date('24-10-2053', 'dd-mm-yyyy'), '5', '24', '297', '10', '2053', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19657, to_date('25-10-2053', 'dd-mm-yyyy'), '6', '25', '298', '10', '2053', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19658, to_date('26-10-2053', 'dd-mm-yyyy'), '7', '26', '299', '10', '2053', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19659, to_date('27-10-2053', 'dd-mm-yyyy'), '1', '27', '300', '10', '2053', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19660, to_date('28-10-2053', 'dd-mm-yyyy'), '2', '28', '301', '10', '2053', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19661, to_date('29-10-2053', 'dd-mm-yyyy'), '3', '29', '302', '10', '2053', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19662, to_date('30-10-2053', 'dd-mm-yyyy'), '4', '30', '303', '10', '2053', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19663, to_date('31-10-2053', 'dd-mm-yyyy'), '5', '31', '304', '10', '2053', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19664, to_date('01-11-2053', 'dd-mm-yyyy'), '6', '01', '305', '11', '2053', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19665, to_date('02-11-2053', 'dd-mm-yyyy'), '7', '02', '306', '11', '2053', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19666, to_date('03-11-2053', 'dd-mm-yyyy'), '1', '03', '307', '11', '2053', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19667, to_date('04-11-2053', 'dd-mm-yyyy'), '2', '04', '308', '11', '2053', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19668, to_date('05-11-2053', 'dd-mm-yyyy'), '3', '05', '309', '11', '2053', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19669, to_date('06-11-2053', 'dd-mm-yyyy'), '4', '06', '310', '11', '2053', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19670, to_date('07-11-2053', 'dd-mm-yyyy'), '5', '07', '311', '11', '2053', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19671, to_date('08-11-2053', 'dd-mm-yyyy'), '6', '08', '312', '11', '2053', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19672, to_date('09-11-2053', 'dd-mm-yyyy'), '7', '09', '313', '11', '2053', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19673, to_date('10-11-2053', 'dd-mm-yyyy'), '1', '10', '314', '11', '2053', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19674, to_date('11-11-2053', 'dd-mm-yyyy'), '2', '11', '315', '11', '2053', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19675, to_date('12-11-2053', 'dd-mm-yyyy'), '3', '12', '316', '11', '2053', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19676, to_date('13-11-2053', 'dd-mm-yyyy'), '4', '13', '317', '11', '2053', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19677, to_date('14-11-2053', 'dd-mm-yyyy'), '5', '14', '318', '11', '2053', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19678, to_date('15-11-2053', 'dd-mm-yyyy'), '6', '15', '319', '11', '2053', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19679, to_date('16-11-2053', 'dd-mm-yyyy'), '7', '16', '320', '11', '2053', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19680, to_date('17-11-2053', 'dd-mm-yyyy'), '1', '17', '321', '11', '2053', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19681, to_date('18-11-2053', 'dd-mm-yyyy'), '2', '18', '322', '11', '2053', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19682, to_date('19-11-2053', 'dd-mm-yyyy'), '3', '19', '323', '11', '2053', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19683, to_date('20-11-2053', 'dd-mm-yyyy'), '4', '20', '324', '11', '2053', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19684, to_date('21-11-2053', 'dd-mm-yyyy'), '5', '21', '325', '11', '2053', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19685, to_date('22-11-2053', 'dd-mm-yyyy'), '6', '22', '326', '11', '2053', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19686, to_date('23-11-2053', 'dd-mm-yyyy'), '7', '23', '327', '11', '2053', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19687, to_date('24-11-2053', 'dd-mm-yyyy'), '1', '24', '328', '11', '2053', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19688, to_date('25-11-2053', 'dd-mm-yyyy'), '2', '25', '329', '11', '2053', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19689, to_date('26-11-2053', 'dd-mm-yyyy'), '3', '26', '330', '11', '2053', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19690, to_date('27-11-2053', 'dd-mm-yyyy'), '4', '27', '331', '11', '2053', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21175, to_date('21-12-2057', 'dd-mm-yyyy'), '5', '21', '355', '12', '2057', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21176, to_date('22-12-2057', 'dd-mm-yyyy'), '6', '22', '356', '12', '2057', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21177, to_date('23-12-2057', 'dd-mm-yyyy'), '7', '23', '357', '12', '2057', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21178, to_date('24-12-2057', 'dd-mm-yyyy'), '1', '24', '358', '12', '2057', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21179, to_date('25-12-2057', 'dd-mm-yyyy'), '2', '25', '359', '12', '2057', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21180, to_date('26-12-2057', 'dd-mm-yyyy'), '3', '26', '360', '12', '2057', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21181, to_date('27-12-2057', 'dd-mm-yyyy'), '4', '27', '361', '12', '2057', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21182, to_date('28-12-2057', 'dd-mm-yyyy'), '5', '28', '362', '12', '2057', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21183, to_date('29-12-2057', 'dd-mm-yyyy'), '6', '29', '363', '12', '2057', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21184, to_date('30-12-2057', 'dd-mm-yyyy'), '7', '30', '364', '12', '2057', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21185, to_date('31-12-2057', 'dd-mm-yyyy'), '1', '31', '365', '12', '2057', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21186, to_date('01-01-2058', 'dd-mm-yyyy'), '2', '01', '001', '01', '2058', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21187, to_date('02-01-2058', 'dd-mm-yyyy'), '3', '02', '002', '01', '2058', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21188, to_date('03-01-2058', 'dd-mm-yyyy'), '4', '03', '003', '01', '2058', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21189, to_date('04-01-2058', 'dd-mm-yyyy'), '5', '04', '004', '01', '2058', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21190, to_date('05-01-2058', 'dd-mm-yyyy'), '6', '05', '005', '01', '2058', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21191, to_date('06-01-2058', 'dd-mm-yyyy'), '7', '06', '006', '01', '2058', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21192, to_date('07-01-2058', 'dd-mm-yyyy'), '1', '07', '007', '01', '2058', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21193, to_date('08-01-2058', 'dd-mm-yyyy'), '2', '08', '008', '01', '2058', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21194, to_date('09-01-2058', 'dd-mm-yyyy'), '3', '09', '009', '01', '2058', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21195, to_date('10-01-2058', 'dd-mm-yyyy'), '4', '10', '010', '01', '2058', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21196, to_date('11-01-2058', 'dd-mm-yyyy'), '5', '11', '011', '01', '2058', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21197, to_date('12-01-2058', 'dd-mm-yyyy'), '6', '12', '012', '01', '2058', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21198, to_date('13-01-2058', 'dd-mm-yyyy'), '7', '13', '013', '01', '2058', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21199, to_date('14-01-2058', 'dd-mm-yyyy'), '1', '14', '014', '01', '2058', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21200, to_date('15-01-2058', 'dd-mm-yyyy'), '2', '15', '015', '01', '2058', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21201, to_date('16-01-2058', 'dd-mm-yyyy'), '3', '16', '016', '01', '2058', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21202, to_date('17-01-2058', 'dd-mm-yyyy'), '4', '17', '017', '01', '2058', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21203, to_date('18-01-2058', 'dd-mm-yyyy'), '5', '18', '018', '01', '2058', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21204, to_date('19-01-2058', 'dd-mm-yyyy'), '6', '19', '019', '01', '2058', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21205, to_date('20-01-2058', 'dd-mm-yyyy'), '7', '20', '020', '01', '2058', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21206, to_date('21-01-2058', 'dd-mm-yyyy'), '1', '21', '021', '01', '2058', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21207, to_date('22-01-2058', 'dd-mm-yyyy'), '2', '22', '022', '01', '2058', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21208, to_date('23-01-2058', 'dd-mm-yyyy'), '3', '23', '023', '01', '2058', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
commit;
prompt 14000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21209, to_date('24-01-2058', 'dd-mm-yyyy'), '4', '24', '024', '01', '2058', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21210, to_date('25-01-2058', 'dd-mm-yyyy'), '5', '25', '025', '01', '2058', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21211, to_date('26-01-2058', 'dd-mm-yyyy'), '6', '26', '026', '01', '2058', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21212, to_date('27-01-2058', 'dd-mm-yyyy'), '7', '27', '027', '01', '2058', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21213, to_date('28-01-2058', 'dd-mm-yyyy'), '1', '28', '028', '01', '2058', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21214, to_date('29-01-2058', 'dd-mm-yyyy'), '2', '29', '029', '01', '2058', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21215, to_date('30-01-2058', 'dd-mm-yyyy'), '3', '30', '030', '01', '2058', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21216, to_date('31-01-2058', 'dd-mm-yyyy'), '4', '31', '031', '01', '2058', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21217, to_date('01-02-2058', 'dd-mm-yyyy'), '5', '01', '032', '02', '2058', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21218, to_date('02-02-2058', 'dd-mm-yyyy'), '6', '02', '033', '02', '2058', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21219, to_date('03-02-2058', 'dd-mm-yyyy'), '7', '03', '034', '02', '2058', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21220, to_date('04-02-2058', 'dd-mm-yyyy'), '1', '04', '035', '02', '2058', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21221, to_date('05-02-2058', 'dd-mm-yyyy'), '2', '05', '036', '02', '2058', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21222, to_date('06-02-2058', 'dd-mm-yyyy'), '3', '06', '037', '02', '2058', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21223, to_date('07-02-2058', 'dd-mm-yyyy'), '4', '07', '038', '02', '2058', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21224, to_date('08-02-2058', 'dd-mm-yyyy'), '5', '08', '039', '02', '2058', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21225, to_date('09-02-2058', 'dd-mm-yyyy'), '6', '09', '040', '02', '2058', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21226, to_date('10-02-2058', 'dd-mm-yyyy'), '7', '10', '041', '02', '2058', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21227, to_date('11-02-2058', 'dd-mm-yyyy'), '1', '11', '042', '02', '2058', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21228, to_date('12-02-2058', 'dd-mm-yyyy'), '2', '12', '043', '02', '2058', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21229, to_date('13-02-2058', 'dd-mm-yyyy'), '3', '13', '044', '02', '2058', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21230, to_date('14-02-2058', 'dd-mm-yyyy'), '4', '14', '045', '02', '2058', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21231, to_date('15-02-2058', 'dd-mm-yyyy'), '5', '15', '046', '02', '2058', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21232, to_date('16-02-2058', 'dd-mm-yyyy'), '6', '16', '047', '02', '2058', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21233, to_date('17-02-2058', 'dd-mm-yyyy'), '7', '17', '048', '02', '2058', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21234, to_date('18-02-2058', 'dd-mm-yyyy'), '1', '18', '049', '02', '2058', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21235, to_date('19-02-2058', 'dd-mm-yyyy'), '2', '19', '050', '02', '2058', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21236, to_date('20-02-2058', 'dd-mm-yyyy'), '3', '20', '051', '02', '2058', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21237, to_date('21-02-2058', 'dd-mm-yyyy'), '4', '21', '052', '02', '2058', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21238, to_date('22-02-2058', 'dd-mm-yyyy'), '5', '22', '053', '02', '2058', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21239, to_date('23-02-2058', 'dd-mm-yyyy'), '6', '23', '054', '02', '2058', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21240, to_date('24-02-2058', 'dd-mm-yyyy'), '7', '24', '055', '02', '2058', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21241, to_date('25-02-2058', 'dd-mm-yyyy'), '1', '25', '056', '02', '2058', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21242, to_date('26-02-2058', 'dd-mm-yyyy'), '2', '26', '057', '02', '2058', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21243, to_date('27-02-2058', 'dd-mm-yyyy'), '3', '27', '058', '02', '2058', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21244, to_date('28-02-2058', 'dd-mm-yyyy'), '4', '28', '059', '02', '2058', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21245, to_date('01-03-2058', 'dd-mm-yyyy'), '5', '01', '060', '03', '2058', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21246, to_date('02-03-2058', 'dd-mm-yyyy'), '6', '02', '061', '03', '2058', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21247, to_date('03-03-2058', 'dd-mm-yyyy'), '7', '03', '062', '03', '2058', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21248, to_date('04-03-2058', 'dd-mm-yyyy'), '1', '04', '063', '03', '2058', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21249, to_date('05-03-2058', 'dd-mm-yyyy'), '2', '05', '064', '03', '2058', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21250, to_date('06-03-2058', 'dd-mm-yyyy'), '3', '06', '065', '03', '2058', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21251, to_date('07-03-2058', 'dd-mm-yyyy'), '4', '07', '066', '03', '2058', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21252, to_date('08-03-2058', 'dd-mm-yyyy'), '5', '08', '067', '03', '2058', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21253, to_date('09-03-2058', 'dd-mm-yyyy'), '6', '09', '068', '03', '2058', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21254, to_date('10-03-2058', 'dd-mm-yyyy'), '7', '10', '069', '03', '2058', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21255, to_date('11-03-2058', 'dd-mm-yyyy'), '1', '11', '070', '03', '2058', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21256, to_date('12-03-2058', 'dd-mm-yyyy'), '2', '12', '071', '03', '2058', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21257, to_date('13-03-2058', 'dd-mm-yyyy'), '3', '13', '072', '03', '2058', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21258, to_date('14-03-2058', 'dd-mm-yyyy'), '4', '14', '073', '03', '2058', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21259, to_date('15-03-2058', 'dd-mm-yyyy'), '5', '15', '074', '03', '2058', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21260, to_date('16-03-2058', 'dd-mm-yyyy'), '6', '16', '075', '03', '2058', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21261, to_date('17-03-2058', 'dd-mm-yyyy'), '7', '17', '076', '03', '2058', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21262, to_date('18-03-2058', 'dd-mm-yyyy'), '1', '18', '077', '03', '2058', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21263, to_date('19-03-2058', 'dd-mm-yyyy'), '2', '19', '078', '03', '2058', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21264, to_date('20-03-2058', 'dd-mm-yyyy'), '3', '20', '079', '03', '2058', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21265, to_date('21-03-2058', 'dd-mm-yyyy'), '4', '21', '080', '03', '2058', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21266, to_date('22-03-2058', 'dd-mm-yyyy'), '5', '22', '081', '03', '2058', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21267, to_date('23-03-2058', 'dd-mm-yyyy'), '6', '23', '082', '03', '2058', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21268, to_date('24-03-2058', 'dd-mm-yyyy'), '7', '24', '083', '03', '2058', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21269, to_date('25-03-2058', 'dd-mm-yyyy'), '1', '25', '084', '03', '2058', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21270, to_date('26-03-2058', 'dd-mm-yyyy'), '2', '26', '085', '03', '2058', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21271, to_date('27-03-2058', 'dd-mm-yyyy'), '3', '27', '086', '03', '2058', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21272, to_date('28-03-2058', 'dd-mm-yyyy'), '4', '28', '087', '03', '2058', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21273, to_date('29-03-2058', 'dd-mm-yyyy'), '5', '29', '088', '03', '2058', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21274, to_date('30-03-2058', 'dd-mm-yyyy'), '6', '30', '089', '03', '2058', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21275, to_date('31-03-2058', 'dd-mm-yyyy'), '7', '31', '090', '03', '2058', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21276, to_date('01-04-2058', 'dd-mm-yyyy'), '1', '01', '091', '04', '2058', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21277, to_date('02-04-2058', 'dd-mm-yyyy'), '2', '02', '092', '04', '2058', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21278, to_date('03-04-2058', 'dd-mm-yyyy'), '3', '03', '093', '04', '2058', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21279, to_date('04-04-2058', 'dd-mm-yyyy'), '4', '04', '094', '04', '2058', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21280, to_date('05-04-2058', 'dd-mm-yyyy'), '5', '05', '095', '04', '2058', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22765, to_date('29-04-2062', 'dd-mm-yyyy'), '6', '29', '119', '04', '2062', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22766, to_date('30-04-2062', 'dd-mm-yyyy'), '7', '30', '120', '04', '2062', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22767, to_date('01-05-2062', 'dd-mm-yyyy'), '1', '01', '121', '05', '2062', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22768, to_date('02-05-2062', 'dd-mm-yyyy'), '2', '02', '122', '05', '2062', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22769, to_date('03-05-2062', 'dd-mm-yyyy'), '3', '03', '123', '05', '2062', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22770, to_date('04-05-2062', 'dd-mm-yyyy'), '4', '04', '124', '05', '2062', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22771, to_date('05-05-2062', 'dd-mm-yyyy'), '5', '05', '125', '05', '2062', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22772, to_date('06-05-2062', 'dd-mm-yyyy'), '6', '06', '126', '05', '2062', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22773, to_date('07-05-2062', 'dd-mm-yyyy'), '7', '07', '127', '05', '2062', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22774, to_date('08-05-2062', 'dd-mm-yyyy'), '1', '08', '128', '05', '2062', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22775, to_date('09-05-2062', 'dd-mm-yyyy'), '2', '09', '129', '05', '2062', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22776, to_date('10-05-2062', 'dd-mm-yyyy'), '3', '10', '130', '05', '2062', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22777, to_date('11-05-2062', 'dd-mm-yyyy'), '4', '11', '131', '05', '2062', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22778, to_date('12-05-2062', 'dd-mm-yyyy'), '5', '12', '132', '05', '2062', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22779, to_date('13-05-2062', 'dd-mm-yyyy'), '6', '13', '133', '05', '2062', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22780, to_date('14-05-2062', 'dd-mm-yyyy'), '7', '14', '134', '05', '2062', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22781, to_date('15-05-2062', 'dd-mm-yyyy'), '1', '15', '135', '05', '2062', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22782, to_date('16-05-2062', 'dd-mm-yyyy'), '2', '16', '136', '05', '2062', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22783, to_date('17-05-2062', 'dd-mm-yyyy'), '3', '17', '137', '05', '2062', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22784, to_date('18-05-2062', 'dd-mm-yyyy'), '4', '18', '138', '05', '2062', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22785, to_date('19-05-2062', 'dd-mm-yyyy'), '5', '19', '139', '05', '2062', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22786, to_date('20-05-2062', 'dd-mm-yyyy'), '6', '20', '140', '05', '2062', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22787, to_date('21-05-2062', 'dd-mm-yyyy'), '7', '21', '141', '05', '2062', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22788, to_date('22-05-2062', 'dd-mm-yyyy'), '1', '22', '142', '05', '2062', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22789, to_date('23-05-2062', 'dd-mm-yyyy'), '2', '23', '143', '05', '2062', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22790, to_date('24-05-2062', 'dd-mm-yyyy'), '3', '24', '144', '05', '2062', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22791, to_date('25-05-2062', 'dd-mm-yyyy'), '4', '25', '145', '05', '2062', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22792, to_date('26-05-2062', 'dd-mm-yyyy'), '5', '26', '146', '05', '2062', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22793, to_date('27-05-2062', 'dd-mm-yyyy'), '6', '27', '147', '05', '2062', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22794, to_date('28-05-2062', 'dd-mm-yyyy'), '7', '28', '148', '05', '2062', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22795, to_date('29-05-2062', 'dd-mm-yyyy'), '1', '29', '149', '05', '2062', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22796, to_date('30-05-2062', 'dd-mm-yyyy'), '2', '30', '150', '05', '2062', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22797, to_date('31-05-2062', 'dd-mm-yyyy'), '3', '31', '151', '05', '2062', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22798, to_date('01-06-2062', 'dd-mm-yyyy'), '4', '01', '152', '06', '2062', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22799, to_date('02-06-2062', 'dd-mm-yyyy'), '5', '02', '153', '06', '2062', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22800, to_date('03-06-2062', 'dd-mm-yyyy'), '6', '03', '154', '06', '2062', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22801, to_date('04-06-2062', 'dd-mm-yyyy'), '7', '04', '155', '06', '2062', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22802, to_date('05-06-2062', 'dd-mm-yyyy'), '1', '05', '156', '06', '2062', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22803, to_date('06-06-2062', 'dd-mm-yyyy'), '2', '06', '157', '06', '2062', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22804, to_date('07-06-2062', 'dd-mm-yyyy'), '3', '07', '158', '06', '2062', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22805, to_date('08-06-2062', 'dd-mm-yyyy'), '4', '08', '159', '06', '2062', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22806, to_date('09-06-2062', 'dd-mm-yyyy'), '5', '09', '160', '06', '2062', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22807, to_date('10-06-2062', 'dd-mm-yyyy'), '6', '10', '161', '06', '2062', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22808, to_date('11-06-2062', 'dd-mm-yyyy'), '7', '11', '162', '06', '2062', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22809, to_date('12-06-2062', 'dd-mm-yyyy'), '1', '12', '163', '06', '2062', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22810, to_date('13-06-2062', 'dd-mm-yyyy'), '2', '13', '164', '06', '2062', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22811, to_date('14-06-2062', 'dd-mm-yyyy'), '3', '14', '165', '06', '2062', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22812, to_date('15-06-2062', 'dd-mm-yyyy'), '4', '15', '166', '06', '2062', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22813, to_date('16-06-2062', 'dd-mm-yyyy'), '5', '16', '167', '06', '2062', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22814, to_date('17-06-2062', 'dd-mm-yyyy'), '6', '17', '168', '06', '2062', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22815, to_date('18-06-2062', 'dd-mm-yyyy'), '7', '18', '169', '06', '2062', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22816, to_date('19-06-2062', 'dd-mm-yyyy'), '1', '19', '170', '06', '2062', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22817, to_date('20-06-2062', 'dd-mm-yyyy'), '2', '20', '171', '06', '2062', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22818, to_date('21-06-2062', 'dd-mm-yyyy'), '3', '21', '172', '06', '2062', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22819, to_date('22-06-2062', 'dd-mm-yyyy'), '4', '22', '173', '06', '2062', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22820, to_date('23-06-2062', 'dd-mm-yyyy'), '5', '23', '174', '06', '2062', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22821, to_date('24-06-2062', 'dd-mm-yyyy'), '6', '24', '175', '06', '2062', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22822, to_date('25-06-2062', 'dd-mm-yyyy'), '7', '25', '176', '06', '2062', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22823, to_date('26-06-2062', 'dd-mm-yyyy'), '1', '26', '177', '06', '2062', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22824, to_date('27-06-2062', 'dd-mm-yyyy'), '2', '27', '178', '06', '2062', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22825, to_date('28-06-2062', 'dd-mm-yyyy'), '3', '28', '179', '06', '2062', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22826, to_date('29-06-2062', 'dd-mm-yyyy'), '4', '29', '180', '06', '2062', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22827, to_date('30-06-2062', 'dd-mm-yyyy'), '5', '30', '181', '06', '2062', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22828, to_date('01-07-2062', 'dd-mm-yyyy'), '6', '01', '182', '07', '2062', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22829, to_date('02-07-2062', 'dd-mm-yyyy'), '7', '02', '183', '07', '2062', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22830, to_date('03-07-2062', 'dd-mm-yyyy'), '1', '03', '184', '07', '2062', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22831, to_date('04-07-2062', 'dd-mm-yyyy'), '2', '04', '185', '07', '2062', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22832, to_date('05-07-2062', 'dd-mm-yyyy'), '3', '05', '186', '07', '2062', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22833, to_date('06-07-2062', 'dd-mm-yyyy'), '4', '06', '187', '07', '2062', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22834, to_date('07-07-2062', 'dd-mm-yyyy'), '5', '07', '188', '07', '2062', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22835, to_date('08-07-2062', 'dd-mm-yyyy'), '6', '08', '189', '07', '2062', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22836, to_date('09-07-2062', 'dd-mm-yyyy'), '7', '09', '190', '07', '2062', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22837, to_date('10-07-2062', 'dd-mm-yyyy'), '1', '10', '191', '07', '2062', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22838, to_date('11-07-2062', 'dd-mm-yyyy'), '2', '11', '192', '07', '2062', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22839, to_date('12-07-2062', 'dd-mm-yyyy'), '3', '12', '193', '07', '2062', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22840, to_date('13-07-2062', 'dd-mm-yyyy'), '4', '13', '194', '07', '2062', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22841, to_date('14-07-2062', 'dd-mm-yyyy'), '5', '14', '195', '07', '2062', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22842, to_date('15-07-2062', 'dd-mm-yyyy'), '6', '15', '196', '07', '2062', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22843, to_date('16-07-2062', 'dd-mm-yyyy'), '7', '16', '197', '07', '2062', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22844, to_date('17-07-2062', 'dd-mm-yyyy'), '1', '17', '198', '07', '2062', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22845, to_date('18-07-2062', 'dd-mm-yyyy'), '2', '18', '199', '07', '2062', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22846, to_date('19-07-2062', 'dd-mm-yyyy'), '3', '19', '200', '07', '2062', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22847, to_date('20-07-2062', 'dd-mm-yyyy'), '4', '20', '201', '07', '2062', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22848, to_date('21-07-2062', 'dd-mm-yyyy'), '5', '21', '202', '07', '2062', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22849, to_date('22-07-2062', 'dd-mm-yyyy'), '6', '22', '203', '07', '2062', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22850, to_date('23-07-2062', 'dd-mm-yyyy'), '7', '23', '204', '07', '2062', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22851, to_date('24-07-2062', 'dd-mm-yyyy'), '1', '24', '205', '07', '2062', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22852, to_date('25-07-2062', 'dd-mm-yyyy'), '2', '25', '206', '07', '2062', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22853, to_date('26-07-2062', 'dd-mm-yyyy'), '3', '26', '207', '07', '2062', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22854, to_date('27-07-2062', 'dd-mm-yyyy'), '4', '27', '208', '07', '2062', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22855, to_date('28-07-2062', 'dd-mm-yyyy'), '5', '28', '209', '07', '2062', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22856, to_date('29-07-2062', 'dd-mm-yyyy'), '6', '29', '210', '07', '2062', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22857, to_date('30-07-2062', 'dd-mm-yyyy'), '7', '30', '211', '07', '2062', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22858, to_date('31-07-2062', 'dd-mm-yyyy'), '1', '31', '212', '07', '2062', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22859, to_date('01-08-2062', 'dd-mm-yyyy'), '2', '01', '213', '08', '2062', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22860, to_date('02-08-2062', 'dd-mm-yyyy'), '3', '02', '214', '08', '2062', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22861, to_date('03-08-2062', 'dd-mm-yyyy'), '4', '03', '215', '08', '2062', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22862, to_date('04-08-2062', 'dd-mm-yyyy'), '5', '04', '216', '08', '2062', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22863, to_date('05-08-2062', 'dd-mm-yyyy'), '6', '05', '217', '08', '2062', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22864, to_date('06-08-2062', 'dd-mm-yyyy'), '7', '06', '218', '08', '2062', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22865, to_date('07-08-2062', 'dd-mm-yyyy'), '1', '07', '219', '08', '2062', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22866, to_date('08-08-2062', 'dd-mm-yyyy'), '2', '08', '220', '08', '2062', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22867, to_date('09-08-2062', 'dd-mm-yyyy'), '3', '09', '221', '08', '2062', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22868, to_date('10-08-2062', 'dd-mm-yyyy'), '4', '10', '222', '08', '2062', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22869, to_date('11-08-2062', 'dd-mm-yyyy'), '5', '11', '223', '08', '2062', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22870, to_date('12-08-2062', 'dd-mm-yyyy'), '6', '12', '224', '08', '2062', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24355, to_date('05-09-2066', 'dd-mm-yyyy'), '7', '05', '248', '09', '2066', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24356, to_date('06-09-2066', 'dd-mm-yyyy'), '1', '06', '249', '09', '2066', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24357, to_date('07-09-2066', 'dd-mm-yyyy'), '2', '07', '250', '09', '2066', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24358, to_date('08-09-2066', 'dd-mm-yyyy'), '3', '08', '251', '09', '2066', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24359, to_date('09-09-2066', 'dd-mm-yyyy'), '4', '09', '252', '09', '2066', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24360, to_date('10-09-2066', 'dd-mm-yyyy'), '5', '10', '253', '09', '2066', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24361, to_date('11-09-2066', 'dd-mm-yyyy'), '6', '11', '254', '09', '2066', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24362, to_date('12-09-2066', 'dd-mm-yyyy'), '7', '12', '255', '09', '2066', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24363, to_date('13-09-2066', 'dd-mm-yyyy'), '1', '13', '256', '09', '2066', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24364, to_date('14-09-2066', 'dd-mm-yyyy'), '2', '14', '257', '09', '2066', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24365, to_date('15-09-2066', 'dd-mm-yyyy'), '3', '15', '258', '09', '2066', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24366, to_date('16-09-2066', 'dd-mm-yyyy'), '4', '16', '259', '09', '2066', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24367, to_date('17-09-2066', 'dd-mm-yyyy'), '5', '17', '260', '09', '2066', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24368, to_date('18-09-2066', 'dd-mm-yyyy'), '6', '18', '261', '09', '2066', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24369, to_date('19-09-2066', 'dd-mm-yyyy'), '7', '19', '262', '09', '2066', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24370, to_date('20-09-2066', 'dd-mm-yyyy'), '1', '20', '263', '09', '2066', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24371, to_date('21-09-2066', 'dd-mm-yyyy'), '2', '21', '264', '09', '2066', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24372, to_date('22-09-2066', 'dd-mm-yyyy'), '3', '22', '265', '09', '2066', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24373, to_date('23-09-2066', 'dd-mm-yyyy'), '4', '23', '266', '09', '2066', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24374, to_date('24-09-2066', 'dd-mm-yyyy'), '5', '24', '267', '09', '2066', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24375, to_date('25-09-2066', 'dd-mm-yyyy'), '6', '25', '268', '09', '2066', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24376, to_date('26-09-2066', 'dd-mm-yyyy'), '7', '26', '269', '09', '2066', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24377, to_date('27-09-2066', 'dd-mm-yyyy'), '1', '27', '270', '09', '2066', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24378, to_date('28-09-2066', 'dd-mm-yyyy'), '2', '28', '271', '09', '2066', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24379, to_date('29-09-2066', 'dd-mm-yyyy'), '3', '29', '272', '09', '2066', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24380, to_date('30-09-2066', 'dd-mm-yyyy'), '4', '30', '273', '09', '2066', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24381, to_date('01-10-2066', 'dd-mm-yyyy'), '5', '01', '274', '10', '2066', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24382, to_date('02-10-2066', 'dd-mm-yyyy'), '6', '02', '275', '10', '2066', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24383, to_date('03-10-2066', 'dd-mm-yyyy'), '7', '03', '276', '10', '2066', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24384, to_date('04-10-2066', 'dd-mm-yyyy'), '1', '04', '277', '10', '2066', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24385, to_date('05-10-2066', 'dd-mm-yyyy'), '2', '05', '278', '10', '2066', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24386, to_date('06-10-2066', 'dd-mm-yyyy'), '3', '06', '279', '10', '2066', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24387, to_date('07-10-2066', 'dd-mm-yyyy'), '4', '07', '280', '10', '2066', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24388, to_date('08-10-2066', 'dd-mm-yyyy'), '5', '08', '281', '10', '2066', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24389, to_date('09-10-2066', 'dd-mm-yyyy'), '6', '09', '282', '10', '2066', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24390, to_date('10-10-2066', 'dd-mm-yyyy'), '7', '10', '283', '10', '2066', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24391, to_date('11-10-2066', 'dd-mm-yyyy'), '1', '11', '284', '10', '2066', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24392, to_date('12-10-2066', 'dd-mm-yyyy'), '2', '12', '285', '10', '2066', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24393, to_date('13-10-2066', 'dd-mm-yyyy'), '3', '13', '286', '10', '2066', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24394, to_date('14-10-2066', 'dd-mm-yyyy'), '4', '14', '287', '10', '2066', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24395, to_date('15-10-2066', 'dd-mm-yyyy'), '5', '15', '288', '10', '2066', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24396, to_date('16-10-2066', 'dd-mm-yyyy'), '6', '16', '289', '10', '2066', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24397, to_date('17-10-2066', 'dd-mm-yyyy'), '7', '17', '290', '10', '2066', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24398, to_date('18-10-2066', 'dd-mm-yyyy'), '1', '18', '291', '10', '2066', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24399, to_date('19-10-2066', 'dd-mm-yyyy'), '2', '19', '292', '10', '2066', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24400, to_date('20-10-2066', 'dd-mm-yyyy'), '3', '20', '293', '10', '2066', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24401, to_date('21-10-2066', 'dd-mm-yyyy'), '4', '21', '294', '10', '2066', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24402, to_date('22-10-2066', 'dd-mm-yyyy'), '5', '22', '295', '10', '2066', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24403, to_date('23-10-2066', 'dd-mm-yyyy'), '6', '23', '296', '10', '2066', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24404, to_date('24-10-2066', 'dd-mm-yyyy'), '7', '24', '297', '10', '2066', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24405, to_date('25-10-2066', 'dd-mm-yyyy'), '1', '25', '298', '10', '2066', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24406, to_date('26-10-2066', 'dd-mm-yyyy'), '2', '26', '299', '10', '2066', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24407, to_date('27-10-2066', 'dd-mm-yyyy'), '3', '27', '300', '10', '2066', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24408, to_date('28-10-2066', 'dd-mm-yyyy'), '4', '28', '301', '10', '2066', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24409, to_date('29-10-2066', 'dd-mm-yyyy'), '5', '29', '302', '10', '2066', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24410, to_date('30-10-2066', 'dd-mm-yyyy'), '6', '30', '303', '10', '2066', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24411, to_date('31-10-2066', 'dd-mm-yyyy'), '7', '31', '304', '10', '2066', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24412, to_date('01-11-2066', 'dd-mm-yyyy'), '1', '01', '305', '11', '2066', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24413, to_date('02-11-2066', 'dd-mm-yyyy'), '2', '02', '306', '11', '2066', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24414, to_date('03-11-2066', 'dd-mm-yyyy'), '3', '03', '307', '11', '2066', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24415, to_date('04-11-2066', 'dd-mm-yyyy'), '4', '04', '308', '11', '2066', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24416, to_date('05-11-2066', 'dd-mm-yyyy'), '5', '05', '309', '11', '2066', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24417, to_date('06-11-2066', 'dd-mm-yyyy'), '6', '06', '310', '11', '2066', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24418, to_date('07-11-2066', 'dd-mm-yyyy'), '7', '07', '311', '11', '2066', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24419, to_date('08-11-2066', 'dd-mm-yyyy'), '1', '08', '312', '11', '2066', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24420, to_date('09-11-2066', 'dd-mm-yyyy'), '2', '09', '313', '11', '2066', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24421, to_date('10-11-2066', 'dd-mm-yyyy'), '3', '10', '314', '11', '2066', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24422, to_date('11-11-2066', 'dd-mm-yyyy'), '4', '11', '315', '11', '2066', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24423, to_date('12-11-2066', 'dd-mm-yyyy'), '5', '12', '316', '11', '2066', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24424, to_date('13-11-2066', 'dd-mm-yyyy'), '6', '13', '317', '11', '2066', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24425, to_date('14-11-2066', 'dd-mm-yyyy'), '7', '14', '318', '11', '2066', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24426, to_date('15-11-2066', 'dd-mm-yyyy'), '1', '15', '319', '11', '2066', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24427, to_date('16-11-2066', 'dd-mm-yyyy'), '2', '16', '320', '11', '2066', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24428, to_date('17-11-2066', 'dd-mm-yyyy'), '3', '17', '321', '11', '2066', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24429, to_date('18-11-2066', 'dd-mm-yyyy'), '4', '18', '322', '11', '2066', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24430, to_date('19-11-2066', 'dd-mm-yyyy'), '5', '19', '323', '11', '2066', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24431, to_date('20-11-2066', 'dd-mm-yyyy'), '6', '20', '324', '11', '2066', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24432, to_date('21-11-2066', 'dd-mm-yyyy'), '7', '21', '325', '11', '2066', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24433, to_date('22-11-2066', 'dd-mm-yyyy'), '1', '22', '326', '11', '2066', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24434, to_date('23-11-2066', 'dd-mm-yyyy'), '2', '23', '327', '11', '2066', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24435, to_date('24-11-2066', 'dd-mm-yyyy'), '3', '24', '328', '11', '2066', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24436, to_date('25-11-2066', 'dd-mm-yyyy'), '4', '25', '329', '11', '2066', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24437, to_date('26-11-2066', 'dd-mm-yyyy'), '5', '26', '330', '11', '2066', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24438, to_date('27-11-2066', 'dd-mm-yyyy'), '6', '27', '331', '11', '2066', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24439, to_date('28-11-2066', 'dd-mm-yyyy'), '7', '28', '332', '11', '2066', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24440, to_date('29-11-2066', 'dd-mm-yyyy'), '1', '29', '333', '11', '2066', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24441, to_date('30-11-2066', 'dd-mm-yyyy'), '2', '30', '334', '11', '2066', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24442, to_date('01-12-2066', 'dd-mm-yyyy'), '3', '01', '335', '12', '2066', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24443, to_date('02-12-2066', 'dd-mm-yyyy'), '4', '02', '336', '12', '2066', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24444, to_date('03-12-2066', 'dd-mm-yyyy'), '5', '03', '337', '12', '2066', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24445, to_date('04-12-2066', 'dd-mm-yyyy'), '6', '04', '338', '12', '2066', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24446, to_date('05-12-2066', 'dd-mm-yyyy'), '7', '05', '339', '12', '2066', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24447, to_date('06-12-2066', 'dd-mm-yyyy'), '1', '06', '340', '12', '2066', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24448, to_date('07-12-2066', 'dd-mm-yyyy'), '2', '07', '341', '12', '2066', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24449, to_date('08-12-2066', 'dd-mm-yyyy'), '3', '08', '342', '12', '2066', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24450, to_date('09-12-2066', 'dd-mm-yyyy'), '4', '09', '343', '12', '2066', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24451, to_date('10-12-2066', 'dd-mm-yyyy'), '5', '10', '344', '12', '2066', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24452, to_date('11-12-2066', 'dd-mm-yyyy'), '6', '11', '345', '12', '2066', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24453, to_date('12-12-2066', 'dd-mm-yyyy'), '7', '12', '346', '12', '2066', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24454, to_date('13-12-2066', 'dd-mm-yyyy'), '1', '13', '347', '12', '2066', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24455, to_date('14-12-2066', 'dd-mm-yyyy'), '2', '14', '348', '12', '2066', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24456, to_date('15-12-2066', 'dd-mm-yyyy'), '3', '15', '349', '12', '2066', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24457, to_date('16-12-2066', 'dd-mm-yyyy'), '4', '16', '350', '12', '2066', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24458, to_date('17-12-2066', 'dd-mm-yyyy'), '5', '17', '351', '12', '2066', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24459, to_date('18-12-2066', 'dd-mm-yyyy'), '6', '18', '352', '12', '2066', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24460, to_date('19-12-2066', 'dd-mm-yyyy'), '7', '19', '353', '12', '2066', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19691, to_date('28-11-2053', 'dd-mm-yyyy'), '5', '28', '332', '11', '2053', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19692, to_date('29-11-2053', 'dd-mm-yyyy'), '6', '29', '333', '11', '2053', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19693, to_date('30-11-2053', 'dd-mm-yyyy'), '7', '30', '334', '11', '2053', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19694, to_date('01-12-2053', 'dd-mm-yyyy'), '1', '01', '335', '12', '2053', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19695, to_date('02-12-2053', 'dd-mm-yyyy'), '2', '02', '336', '12', '2053', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19696, to_date('03-12-2053', 'dd-mm-yyyy'), '3', '03', '337', '12', '2053', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19697, to_date('04-12-2053', 'dd-mm-yyyy'), '4', '04', '338', '12', '2053', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19698, to_date('05-12-2053', 'dd-mm-yyyy'), '5', '05', '339', '12', '2053', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19699, to_date('06-12-2053', 'dd-mm-yyyy'), '6', '06', '340', '12', '2053', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19700, to_date('07-12-2053', 'dd-mm-yyyy'), '7', '07', '341', '12', '2053', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19701, to_date('08-12-2053', 'dd-mm-yyyy'), '1', '08', '342', '12', '2053', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19702, to_date('09-12-2053', 'dd-mm-yyyy'), '2', '09', '343', '12', '2053', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19703, to_date('10-12-2053', 'dd-mm-yyyy'), '3', '10', '344', '12', '2053', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19704, to_date('11-12-2053', 'dd-mm-yyyy'), '4', '11', '345', '12', '2053', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19705, to_date('12-12-2053', 'dd-mm-yyyy'), '5', '12', '346', '12', '2053', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19706, to_date('13-12-2053', 'dd-mm-yyyy'), '6', '13', '347', '12', '2053', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19707, to_date('14-12-2053', 'dd-mm-yyyy'), '7', '14', '348', '12', '2053', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19708, to_date('15-12-2053', 'dd-mm-yyyy'), '1', '15', '349', '12', '2053', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19709, to_date('16-12-2053', 'dd-mm-yyyy'), '2', '16', '350', '12', '2053', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19710, to_date('17-12-2053', 'dd-mm-yyyy'), '3', '17', '351', '12', '2053', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19711, to_date('18-12-2053', 'dd-mm-yyyy'), '4', '18', '352', '12', '2053', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19712, to_date('19-12-2053', 'dd-mm-yyyy'), '5', '19', '353', '12', '2053', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19713, to_date('20-12-2053', 'dd-mm-yyyy'), '6', '20', '354', '12', '2053', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19714, to_date('21-12-2053', 'dd-mm-yyyy'), '7', '21', '355', '12', '2053', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19715, to_date('22-12-2053', 'dd-mm-yyyy'), '1', '22', '356', '12', '2053', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19716, to_date('23-12-2053', 'dd-mm-yyyy'), '2', '23', '357', '12', '2053', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19717, to_date('24-12-2053', 'dd-mm-yyyy'), '3', '24', '358', '12', '2053', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19718, to_date('25-12-2053', 'dd-mm-yyyy'), '4', '25', '359', '12', '2053', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19719, to_date('26-12-2053', 'dd-mm-yyyy'), '5', '26', '360', '12', '2053', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19720, to_date('27-12-2053', 'dd-mm-yyyy'), '6', '27', '361', '12', '2053', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19721, to_date('28-12-2053', 'dd-mm-yyyy'), '7', '28', '362', '12', '2053', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19722, to_date('29-12-2053', 'dd-mm-yyyy'), '1', '29', '363', '12', '2053', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19723, to_date('30-12-2053', 'dd-mm-yyyy'), '2', '30', '364', '12', '2053', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19724, to_date('31-12-2053', 'dd-mm-yyyy'), '3', '31', '365', '12', '2053', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19725, to_date('01-01-2054', 'dd-mm-yyyy'), '4', '01', '001', '01', '2054', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19726, to_date('02-01-2054', 'dd-mm-yyyy'), '5', '02', '002', '01', '2054', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19727, to_date('03-01-2054', 'dd-mm-yyyy'), '6', '03', '003', '01', '2054', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19728, to_date('04-01-2054', 'dd-mm-yyyy'), '7', '04', '004', '01', '2054', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19729, to_date('05-01-2054', 'dd-mm-yyyy'), '1', '05', '005', '01', '2054', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19730, to_date('06-01-2054', 'dd-mm-yyyy'), '2', '06', '006', '01', '2054', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19731, to_date('07-01-2054', 'dd-mm-yyyy'), '3', '07', '007', '01', '2054', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19732, to_date('08-01-2054', 'dd-mm-yyyy'), '4', '08', '008', '01', '2054', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19733, to_date('09-01-2054', 'dd-mm-yyyy'), '5', '09', '009', '01', '2054', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19734, to_date('10-01-2054', 'dd-mm-yyyy'), '6', '10', '010', '01', '2054', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19735, to_date('11-01-2054', 'dd-mm-yyyy'), '7', '11', '011', '01', '2054', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19736, to_date('12-01-2054', 'dd-mm-yyyy'), '1', '12', '012', '01', '2054', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19737, to_date('13-01-2054', 'dd-mm-yyyy'), '2', '13', '013', '01', '2054', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19738, to_date('14-01-2054', 'dd-mm-yyyy'), '3', '14', '014', '01', '2054', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19739, to_date('15-01-2054', 'dd-mm-yyyy'), '4', '15', '015', '01', '2054', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19740, to_date('16-01-2054', 'dd-mm-yyyy'), '5', '16', '016', '01', '2054', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19741, to_date('17-01-2054', 'dd-mm-yyyy'), '6', '17', '017', '01', '2054', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19742, to_date('18-01-2054', 'dd-mm-yyyy'), '7', '18', '018', '01', '2054', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19743, to_date('19-01-2054', 'dd-mm-yyyy'), '1', '19', '019', '01', '2054', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19744, to_date('20-01-2054', 'dd-mm-yyyy'), '2', '20', '020', '01', '2054', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19745, to_date('21-01-2054', 'dd-mm-yyyy'), '3', '21', '021', '01', '2054', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19746, to_date('22-01-2054', 'dd-mm-yyyy'), '4', '22', '022', '01', '2054', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19747, to_date('23-01-2054', 'dd-mm-yyyy'), '5', '23', '023', '01', '2054', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19748, to_date('24-01-2054', 'dd-mm-yyyy'), '6', '24', '024', '01', '2054', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19749, to_date('25-01-2054', 'dd-mm-yyyy'), '7', '25', '025', '01', '2054', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19750, to_date('26-01-2054', 'dd-mm-yyyy'), '1', '26', '026', '01', '2054', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19751, to_date('27-01-2054', 'dd-mm-yyyy'), '2', '27', '027', '01', '2054', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19752, to_date('28-01-2054', 'dd-mm-yyyy'), '3', '28', '028', '01', '2054', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19753, to_date('29-01-2054', 'dd-mm-yyyy'), '4', '29', '029', '01', '2054', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19754, to_date('30-01-2054', 'dd-mm-yyyy'), '5', '30', '030', '01', '2054', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19755, to_date('31-01-2054', 'dd-mm-yyyy'), '6', '31', '031', '01', '2054', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19756, to_date('01-02-2054', 'dd-mm-yyyy'), '7', '01', '032', '02', '2054', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19757, to_date('02-02-2054', 'dd-mm-yyyy'), '1', '02', '033', '02', '2054', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19758, to_date('03-02-2054', 'dd-mm-yyyy'), '2', '03', '034', '02', '2054', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19759, to_date('04-02-2054', 'dd-mm-yyyy'), '3', '04', '035', '02', '2054', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19760, to_date('05-02-2054', 'dd-mm-yyyy'), '4', '05', '036', '02', '2054', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19761, to_date('06-02-2054', 'dd-mm-yyyy'), '5', '06', '037', '02', '2054', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19762, to_date('07-02-2054', 'dd-mm-yyyy'), '6', '07', '038', '02', '2054', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19763, to_date('08-02-2054', 'dd-mm-yyyy'), '7', '08', '039', '02', '2054', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19764, to_date('09-02-2054', 'dd-mm-yyyy'), '1', '09', '040', '02', '2054', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19765, to_date('10-02-2054', 'dd-mm-yyyy'), '2', '10', '041', '02', '2054', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19766, to_date('11-02-2054', 'dd-mm-yyyy'), '3', '11', '042', '02', '2054', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19767, to_date('12-02-2054', 'dd-mm-yyyy'), '4', '12', '043', '02', '2054', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19768, to_date('13-02-2054', 'dd-mm-yyyy'), '5', '13', '044', '02', '2054', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19769, to_date('14-02-2054', 'dd-mm-yyyy'), '6', '14', '045', '02', '2054', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19770, to_date('15-02-2054', 'dd-mm-yyyy'), '7', '15', '046', '02', '2054', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19771, to_date('16-02-2054', 'dd-mm-yyyy'), '1', '16', '047', '02', '2054', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19772, to_date('17-02-2054', 'dd-mm-yyyy'), '2', '17', '048', '02', '2054', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19773, to_date('18-02-2054', 'dd-mm-yyyy'), '3', '18', '049', '02', '2054', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19774, to_date('19-02-2054', 'dd-mm-yyyy'), '4', '19', '050', '02', '2054', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19775, to_date('20-02-2054', 'dd-mm-yyyy'), '5', '20', '051', '02', '2054', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19776, to_date('21-02-2054', 'dd-mm-yyyy'), '6', '21', '052', '02', '2054', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19777, to_date('22-02-2054', 'dd-mm-yyyy'), '7', '22', '053', '02', '2054', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19778, to_date('23-02-2054', 'dd-mm-yyyy'), '1', '23', '054', '02', '2054', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19779, to_date('24-02-2054', 'dd-mm-yyyy'), '2', '24', '055', '02', '2054', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19780, to_date('25-02-2054', 'dd-mm-yyyy'), '3', '25', '056', '02', '2054', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19781, to_date('26-02-2054', 'dd-mm-yyyy'), '4', '26', '057', '02', '2054', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19782, to_date('27-02-2054', 'dd-mm-yyyy'), '5', '27', '058', '02', '2054', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19783, to_date('28-02-2054', 'dd-mm-yyyy'), '6', '28', '059', '02', '2054', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19784, to_date('01-03-2054', 'dd-mm-yyyy'), '7', '01', '060', '03', '2054', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19785, to_date('02-03-2054', 'dd-mm-yyyy'), '1', '02', '061', '03', '2054', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19786, to_date('03-03-2054', 'dd-mm-yyyy'), '2', '03', '062', '03', '2054', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19787, to_date('04-03-2054', 'dd-mm-yyyy'), '3', '04', '063', '03', '2054', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19788, to_date('05-03-2054', 'dd-mm-yyyy'), '4', '05', '064', '03', '2054', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19789, to_date('06-03-2054', 'dd-mm-yyyy'), '5', '06', '065', '03', '2054', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19790, to_date('07-03-2054', 'dd-mm-yyyy'), '6', '07', '066', '03', '2054', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19791, to_date('08-03-2054', 'dd-mm-yyyy'), '7', '08', '067', '03', '2054', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19792, to_date('09-03-2054', 'dd-mm-yyyy'), '1', '09', '068', '03', '2054', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19793, to_date('10-03-2054', 'dd-mm-yyyy'), '2', '10', '069', '03', '2054', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19794, to_date('11-03-2054', 'dd-mm-yyyy'), '3', '11', '070', '03', '2054', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19795, to_date('12-03-2054', 'dd-mm-yyyy'), '4', '12', '071', '03', '2054', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19796, to_date('13-03-2054', 'dd-mm-yyyy'), '5', '13', '072', '03', '2054', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21281, to_date('06-04-2058', 'dd-mm-yyyy'), '6', '06', '096', '04', '2058', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21282, to_date('07-04-2058', 'dd-mm-yyyy'), '7', '07', '097', '04', '2058', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21283, to_date('08-04-2058', 'dd-mm-yyyy'), '1', '08', '098', '04', '2058', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21284, to_date('09-04-2058', 'dd-mm-yyyy'), '2', '09', '099', '04', '2058', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21285, to_date('10-04-2058', 'dd-mm-yyyy'), '3', '10', '100', '04', '2058', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21286, to_date('11-04-2058', 'dd-mm-yyyy'), '4', '11', '101', '04', '2058', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21287, to_date('12-04-2058', 'dd-mm-yyyy'), '5', '12', '102', '04', '2058', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21288, to_date('13-04-2058', 'dd-mm-yyyy'), '6', '13', '103', '04', '2058', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21289, to_date('14-04-2058', 'dd-mm-yyyy'), '7', '14', '104', '04', '2058', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21290, to_date('15-04-2058', 'dd-mm-yyyy'), '1', '15', '105', '04', '2058', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21291, to_date('16-04-2058', 'dd-mm-yyyy'), '2', '16', '106', '04', '2058', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21292, to_date('17-04-2058', 'dd-mm-yyyy'), '3', '17', '107', '04', '2058', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21293, to_date('18-04-2058', 'dd-mm-yyyy'), '4', '18', '108', '04', '2058', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21294, to_date('19-04-2058', 'dd-mm-yyyy'), '5', '19', '109', '04', '2058', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21295, to_date('20-04-2058', 'dd-mm-yyyy'), '6', '20', '110', '04', '2058', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21296, to_date('21-04-2058', 'dd-mm-yyyy'), '7', '21', '111', '04', '2058', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21297, to_date('22-04-2058', 'dd-mm-yyyy'), '1', '22', '112', '04', '2058', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21298, to_date('23-04-2058', 'dd-mm-yyyy'), '2', '23', '113', '04', '2058', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21299, to_date('24-04-2058', 'dd-mm-yyyy'), '3', '24', '114', '04', '2058', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21300, to_date('25-04-2058', 'dd-mm-yyyy'), '4', '25', '115', '04', '2058', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21301, to_date('26-04-2058', 'dd-mm-yyyy'), '5', '26', '116', '04', '2058', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21302, to_date('27-04-2058', 'dd-mm-yyyy'), '6', '27', '117', '04', '2058', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21303, to_date('28-04-2058', 'dd-mm-yyyy'), '7', '28', '118', '04', '2058', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21304, to_date('29-04-2058', 'dd-mm-yyyy'), '1', '29', '119', '04', '2058', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21305, to_date('30-04-2058', 'dd-mm-yyyy'), '2', '30', '120', '04', '2058', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21306, to_date('01-05-2058', 'dd-mm-yyyy'), '3', '01', '121', '05', '2058', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21307, to_date('02-05-2058', 'dd-mm-yyyy'), '4', '02', '122', '05', '2058', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21308, to_date('03-05-2058', 'dd-mm-yyyy'), '5', '03', '123', '05', '2058', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21309, to_date('04-05-2058', 'dd-mm-yyyy'), '6', '04', '124', '05', '2058', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21310, to_date('05-05-2058', 'dd-mm-yyyy'), '7', '05', '125', '05', '2058', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21311, to_date('06-05-2058', 'dd-mm-yyyy'), '1', '06', '126', '05', '2058', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21312, to_date('07-05-2058', 'dd-mm-yyyy'), '2', '07', '127', '05', '2058', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21313, to_date('08-05-2058', 'dd-mm-yyyy'), '3', '08', '128', '05', '2058', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21314, to_date('09-05-2058', 'dd-mm-yyyy'), '4', '09', '129', '05', '2058', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21315, to_date('10-05-2058', 'dd-mm-yyyy'), '5', '10', '130', '05', '2058', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21316, to_date('11-05-2058', 'dd-mm-yyyy'), '6', '11', '131', '05', '2058', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21317, to_date('12-05-2058', 'dd-mm-yyyy'), '7', '12', '132', '05', '2058', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21318, to_date('13-05-2058', 'dd-mm-yyyy'), '1', '13', '133', '05', '2058', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21319, to_date('14-05-2058', 'dd-mm-yyyy'), '2', '14', '134', '05', '2058', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21320, to_date('15-05-2058', 'dd-mm-yyyy'), '3', '15', '135', '05', '2058', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21321, to_date('16-05-2058', 'dd-mm-yyyy'), '4', '16', '136', '05', '2058', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21322, to_date('17-05-2058', 'dd-mm-yyyy'), '5', '17', '137', '05', '2058', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21323, to_date('18-05-2058', 'dd-mm-yyyy'), '6', '18', '138', '05', '2058', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21324, to_date('19-05-2058', 'dd-mm-yyyy'), '7', '19', '139', '05', '2058', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21325, to_date('20-05-2058', 'dd-mm-yyyy'), '1', '20', '140', '05', '2058', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21326, to_date('21-05-2058', 'dd-mm-yyyy'), '2', '21', '141', '05', '2058', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21327, to_date('22-05-2058', 'dd-mm-yyyy'), '3', '22', '142', '05', '2058', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21328, to_date('23-05-2058', 'dd-mm-yyyy'), '4', '23', '143', '05', '2058', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21329, to_date('24-05-2058', 'dd-mm-yyyy'), '5', '24', '144', '05', '2058', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21330, to_date('25-05-2058', 'dd-mm-yyyy'), '6', '25', '145', '05', '2058', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21331, to_date('26-05-2058', 'dd-mm-yyyy'), '7', '26', '146', '05', '2058', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21332, to_date('27-05-2058', 'dd-mm-yyyy'), '1', '27', '147', '05', '2058', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21333, to_date('28-05-2058', 'dd-mm-yyyy'), '2', '28', '148', '05', '2058', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21334, to_date('29-05-2058', 'dd-mm-yyyy'), '3', '29', '149', '05', '2058', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21335, to_date('30-05-2058', 'dd-mm-yyyy'), '4', '30', '150', '05', '2058', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21336, to_date('31-05-2058', 'dd-mm-yyyy'), '5', '31', '151', '05', '2058', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21337, to_date('01-06-2058', 'dd-mm-yyyy'), '6', '01', '152', '06', '2058', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21338, to_date('02-06-2058', 'dd-mm-yyyy'), '7', '02', '153', '06', '2058', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21339, to_date('03-06-2058', 'dd-mm-yyyy'), '1', '03', '154', '06', '2058', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21340, to_date('04-06-2058', 'dd-mm-yyyy'), '2', '04', '155', '06', '2058', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21341, to_date('05-06-2058', 'dd-mm-yyyy'), '3', '05', '156', '06', '2058', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21342, to_date('06-06-2058', 'dd-mm-yyyy'), '4', '06', '157', '06', '2058', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21343, to_date('07-06-2058', 'dd-mm-yyyy'), '5', '07', '158', '06', '2058', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21344, to_date('08-06-2058', 'dd-mm-yyyy'), '6', '08', '159', '06', '2058', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21345, to_date('09-06-2058', 'dd-mm-yyyy'), '7', '09', '160', '06', '2058', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21346, to_date('10-06-2058', 'dd-mm-yyyy'), '1', '10', '161', '06', '2058', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21347, to_date('11-06-2058', 'dd-mm-yyyy'), '2', '11', '162', '06', '2058', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21348, to_date('12-06-2058', 'dd-mm-yyyy'), '3', '12', '163', '06', '2058', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21349, to_date('13-06-2058', 'dd-mm-yyyy'), '4', '13', '164', '06', '2058', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21350, to_date('14-06-2058', 'dd-mm-yyyy'), '5', '14', '165', '06', '2058', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21351, to_date('15-06-2058', 'dd-mm-yyyy'), '6', '15', '166', '06', '2058', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21352, to_date('16-06-2058', 'dd-mm-yyyy'), '7', '16', '167', '06', '2058', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21353, to_date('17-06-2058', 'dd-mm-yyyy'), '1', '17', '168', '06', '2058', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21354, to_date('18-06-2058', 'dd-mm-yyyy'), '2', '18', '169', '06', '2058', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21355, to_date('19-06-2058', 'dd-mm-yyyy'), '3', '19', '170', '06', '2058', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21356, to_date('20-06-2058', 'dd-mm-yyyy'), '4', '20', '171', '06', '2058', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21357, to_date('21-06-2058', 'dd-mm-yyyy'), '5', '21', '172', '06', '2058', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21358, to_date('22-06-2058', 'dd-mm-yyyy'), '6', '22', '173', '06', '2058', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21359, to_date('23-06-2058', 'dd-mm-yyyy'), '7', '23', '174', '06', '2058', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21360, to_date('24-06-2058', 'dd-mm-yyyy'), '1', '24', '175', '06', '2058', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21361, to_date('25-06-2058', 'dd-mm-yyyy'), '2', '25', '176', '06', '2058', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21362, to_date('26-06-2058', 'dd-mm-yyyy'), '3', '26', '177', '06', '2058', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21363, to_date('27-06-2058', 'dd-mm-yyyy'), '4', '27', '178', '06', '2058', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21364, to_date('28-06-2058', 'dd-mm-yyyy'), '5', '28', '179', '06', '2058', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21365, to_date('29-06-2058', 'dd-mm-yyyy'), '6', '29', '180', '06', '2058', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21366, to_date('30-06-2058', 'dd-mm-yyyy'), '7', '30', '181', '06', '2058', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21367, to_date('01-07-2058', 'dd-mm-yyyy'), '1', '01', '182', '07', '2058', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21368, to_date('02-07-2058', 'dd-mm-yyyy'), '2', '02', '183', '07', '2058', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21369, to_date('03-07-2058', 'dd-mm-yyyy'), '3', '03', '184', '07', '2058', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21370, to_date('04-07-2058', 'dd-mm-yyyy'), '4', '04', '185', '07', '2058', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21371, to_date('05-07-2058', 'dd-mm-yyyy'), '5', '05', '186', '07', '2058', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21372, to_date('06-07-2058', 'dd-mm-yyyy'), '6', '06', '187', '07', '2058', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21373, to_date('07-07-2058', 'dd-mm-yyyy'), '7', '07', '188', '07', '2058', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21374, to_date('08-07-2058', 'dd-mm-yyyy'), '1', '08', '189', '07', '2058', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21375, to_date('09-07-2058', 'dd-mm-yyyy'), '2', '09', '190', '07', '2058', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21376, to_date('10-07-2058', 'dd-mm-yyyy'), '3', '10', '191', '07', '2058', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21377, to_date('11-07-2058', 'dd-mm-yyyy'), '4', '11', '192', '07', '2058', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21378, to_date('12-07-2058', 'dd-mm-yyyy'), '5', '12', '193', '07', '2058', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21379, to_date('13-07-2058', 'dd-mm-yyyy'), '6', '13', '194', '07', '2058', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21380, to_date('14-07-2058', 'dd-mm-yyyy'), '7', '14', '195', '07', '2058', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21381, to_date('15-07-2058', 'dd-mm-yyyy'), '1', '15', '196', '07', '2058', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21382, to_date('16-07-2058', 'dd-mm-yyyy'), '2', '16', '197', '07', '2058', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21383, to_date('17-07-2058', 'dd-mm-yyyy'), '3', '17', '198', '07', '2058', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21384, to_date('18-07-2058', 'dd-mm-yyyy'), '4', '18', '199', '07', '2058', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21385, to_date('19-07-2058', 'dd-mm-yyyy'), '5', '19', '200', '07', '2058', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21386, to_date('20-07-2058', 'dd-mm-yyyy'), '6', '20', '201', '07', '2058', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22871, to_date('13-08-2062', 'dd-mm-yyyy'), '7', '13', '225', '08', '2062', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22872, to_date('14-08-2062', 'dd-mm-yyyy'), '1', '14', '226', '08', '2062', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22873, to_date('15-08-2062', 'dd-mm-yyyy'), '2', '15', '227', '08', '2062', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22874, to_date('16-08-2062', 'dd-mm-yyyy'), '3', '16', '228', '08', '2062', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22875, to_date('17-08-2062', 'dd-mm-yyyy'), '4', '17', '229', '08', '2062', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22876, to_date('18-08-2062', 'dd-mm-yyyy'), '5', '18', '230', '08', '2062', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22877, to_date('19-08-2062', 'dd-mm-yyyy'), '6', '19', '231', '08', '2062', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22878, to_date('20-08-2062', 'dd-mm-yyyy'), '7', '20', '232', '08', '2062', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22879, to_date('21-08-2062', 'dd-mm-yyyy'), '1', '21', '233', '08', '2062', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22880, to_date('22-08-2062', 'dd-mm-yyyy'), '2', '22', '234', '08', '2062', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22881, to_date('23-08-2062', 'dd-mm-yyyy'), '3', '23', '235', '08', '2062', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22882, to_date('24-08-2062', 'dd-mm-yyyy'), '4', '24', '236', '08', '2062', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22883, to_date('25-08-2062', 'dd-mm-yyyy'), '5', '25', '237', '08', '2062', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22884, to_date('26-08-2062', 'dd-mm-yyyy'), '6', '26', '238', '08', '2062', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22885, to_date('27-08-2062', 'dd-mm-yyyy'), '7', '27', '239', '08', '2062', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22886, to_date('28-08-2062', 'dd-mm-yyyy'), '1', '28', '240', '08', '2062', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22887, to_date('29-08-2062', 'dd-mm-yyyy'), '2', '29', '241', '08', '2062', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22888, to_date('30-08-2062', 'dd-mm-yyyy'), '3', '30', '242', '08', '2062', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22889, to_date('31-08-2062', 'dd-mm-yyyy'), '4', '31', '243', '08', '2062', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22890, to_date('01-09-2062', 'dd-mm-yyyy'), '5', '01', '244', '09', '2062', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22891, to_date('02-09-2062', 'dd-mm-yyyy'), '6', '02', '245', '09', '2062', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22892, to_date('03-09-2062', 'dd-mm-yyyy'), '7', '03', '246', '09', '2062', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22893, to_date('04-09-2062', 'dd-mm-yyyy'), '1', '04', '247', '09', '2062', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22894, to_date('05-09-2062', 'dd-mm-yyyy'), '2', '05', '248', '09', '2062', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22895, to_date('06-09-2062', 'dd-mm-yyyy'), '3', '06', '249', '09', '2062', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22896, to_date('07-09-2062', 'dd-mm-yyyy'), '4', '07', '250', '09', '2062', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22897, to_date('08-09-2062', 'dd-mm-yyyy'), '5', '08', '251', '09', '2062', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22898, to_date('09-09-2062', 'dd-mm-yyyy'), '6', '09', '252', '09', '2062', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22899, to_date('10-09-2062', 'dd-mm-yyyy'), '7', '10', '253', '09', '2062', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22900, to_date('11-09-2062', 'dd-mm-yyyy'), '1', '11', '254', '09', '2062', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22901, to_date('12-09-2062', 'dd-mm-yyyy'), '2', '12', '255', '09', '2062', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22902, to_date('13-09-2062', 'dd-mm-yyyy'), '3', '13', '256', '09', '2062', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22903, to_date('14-09-2062', 'dd-mm-yyyy'), '4', '14', '257', '09', '2062', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22904, to_date('15-09-2062', 'dd-mm-yyyy'), '5', '15', '258', '09', '2062', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22905, to_date('16-09-2062', 'dd-mm-yyyy'), '6', '16', '259', '09', '2062', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22906, to_date('17-09-2062', 'dd-mm-yyyy'), '7', '17', '260', '09', '2062', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22907, to_date('18-09-2062', 'dd-mm-yyyy'), '1', '18', '261', '09', '2062', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22908, to_date('19-09-2062', 'dd-mm-yyyy'), '2', '19', '262', '09', '2062', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22909, to_date('20-09-2062', 'dd-mm-yyyy'), '3', '20', '263', '09', '2062', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22910, to_date('21-09-2062', 'dd-mm-yyyy'), '4', '21', '264', '09', '2062', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22911, to_date('22-09-2062', 'dd-mm-yyyy'), '5', '22', '265', '09', '2062', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22912, to_date('23-09-2062', 'dd-mm-yyyy'), '6', '23', '266', '09', '2062', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22913, to_date('24-09-2062', 'dd-mm-yyyy'), '7', '24', '267', '09', '2062', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22914, to_date('25-09-2062', 'dd-mm-yyyy'), '1', '25', '268', '09', '2062', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22915, to_date('26-09-2062', 'dd-mm-yyyy'), '2', '26', '269', '09', '2062', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22916, to_date('27-09-2062', 'dd-mm-yyyy'), '3', '27', '270', '09', '2062', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22917, to_date('28-09-2062', 'dd-mm-yyyy'), '4', '28', '271', '09', '2062', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22918, to_date('29-09-2062', 'dd-mm-yyyy'), '5', '29', '272', '09', '2062', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22919, to_date('30-09-2062', 'dd-mm-yyyy'), '6', '30', '273', '09', '2062', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22920, to_date('01-10-2062', 'dd-mm-yyyy'), '7', '01', '274', '10', '2062', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22921, to_date('02-10-2062', 'dd-mm-yyyy'), '1', '02', '275', '10', '2062', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22922, to_date('03-10-2062', 'dd-mm-yyyy'), '2', '03', '276', '10', '2062', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22923, to_date('04-10-2062', 'dd-mm-yyyy'), '3', '04', '277', '10', '2062', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22924, to_date('05-10-2062', 'dd-mm-yyyy'), '4', '05', '278', '10', '2062', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22925, to_date('06-10-2062', 'dd-mm-yyyy'), '5', '06', '279', '10', '2062', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22926, to_date('07-10-2062', 'dd-mm-yyyy'), '6', '07', '280', '10', '2062', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22927, to_date('08-10-2062', 'dd-mm-yyyy'), '7', '08', '281', '10', '2062', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22928, to_date('09-10-2062', 'dd-mm-yyyy'), '1', '09', '282', '10', '2062', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22929, to_date('10-10-2062', 'dd-mm-yyyy'), '2', '10', '283', '10', '2062', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22930, to_date('11-10-2062', 'dd-mm-yyyy'), '3', '11', '284', '10', '2062', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22931, to_date('12-10-2062', 'dd-mm-yyyy'), '4', '12', '285', '10', '2062', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22932, to_date('13-10-2062', 'dd-mm-yyyy'), '5', '13', '286', '10', '2062', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22933, to_date('14-10-2062', 'dd-mm-yyyy'), '6', '14', '287', '10', '2062', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22934, to_date('15-10-2062', 'dd-mm-yyyy'), '7', '15', '288', '10', '2062', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22935, to_date('16-10-2062', 'dd-mm-yyyy'), '1', '16', '289', '10', '2062', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22936, to_date('17-10-2062', 'dd-mm-yyyy'), '2', '17', '290', '10', '2062', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22937, to_date('18-10-2062', 'dd-mm-yyyy'), '3', '18', '291', '10', '2062', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22938, to_date('19-10-2062', 'dd-mm-yyyy'), '4', '19', '292', '10', '2062', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22939, to_date('20-10-2062', 'dd-mm-yyyy'), '5', '20', '293', '10', '2062', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22940, to_date('21-10-2062', 'dd-mm-yyyy'), '6', '21', '294', '10', '2062', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22941, to_date('22-10-2062', 'dd-mm-yyyy'), '7', '22', '295', '10', '2062', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22942, to_date('23-10-2062', 'dd-mm-yyyy'), '1', '23', '296', '10', '2062', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22943, to_date('24-10-2062', 'dd-mm-yyyy'), '2', '24', '297', '10', '2062', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22944, to_date('25-10-2062', 'dd-mm-yyyy'), '3', '25', '298', '10', '2062', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22945, to_date('26-10-2062', 'dd-mm-yyyy'), '4', '26', '299', '10', '2062', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22946, to_date('27-10-2062', 'dd-mm-yyyy'), '5', '27', '300', '10', '2062', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22947, to_date('28-10-2062', 'dd-mm-yyyy'), '6', '28', '301', '10', '2062', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22948, to_date('29-10-2062', 'dd-mm-yyyy'), '7', '29', '302', '10', '2062', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22949, to_date('30-10-2062', 'dd-mm-yyyy'), '1', '30', '303', '10', '2062', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22950, to_date('31-10-2062', 'dd-mm-yyyy'), '2', '31', '304', '10', '2062', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22951, to_date('01-11-2062', 'dd-mm-yyyy'), '3', '01', '305', '11', '2062', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22952, to_date('02-11-2062', 'dd-mm-yyyy'), '4', '02', '306', '11', '2062', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22953, to_date('03-11-2062', 'dd-mm-yyyy'), '5', '03', '307', '11', '2062', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22954, to_date('04-11-2062', 'dd-mm-yyyy'), '6', '04', '308', '11', '2062', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22955, to_date('05-11-2062', 'dd-mm-yyyy'), '7', '05', '309', '11', '2062', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22956, to_date('06-11-2062', 'dd-mm-yyyy'), '1', '06', '310', '11', '2062', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22957, to_date('07-11-2062', 'dd-mm-yyyy'), '2', '07', '311', '11', '2062', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22958, to_date('08-11-2062', 'dd-mm-yyyy'), '3', '08', '312', '11', '2062', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22959, to_date('09-11-2062', 'dd-mm-yyyy'), '4', '09', '313', '11', '2062', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22960, to_date('10-11-2062', 'dd-mm-yyyy'), '5', '10', '314', '11', '2062', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22961, to_date('11-11-2062', 'dd-mm-yyyy'), '6', '11', '315', '11', '2062', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22962, to_date('12-11-2062', 'dd-mm-yyyy'), '7', '12', '316', '11', '2062', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22963, to_date('13-11-2062', 'dd-mm-yyyy'), '1', '13', '317', '11', '2062', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22964, to_date('14-11-2062', 'dd-mm-yyyy'), '2', '14', '318', '11', '2062', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22965, to_date('15-11-2062', 'dd-mm-yyyy'), '3', '15', '319', '11', '2062', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22966, to_date('16-11-2062', 'dd-mm-yyyy'), '4', '16', '320', '11', '2062', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22967, to_date('17-11-2062', 'dd-mm-yyyy'), '5', '17', '321', '11', '2062', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22968, to_date('18-11-2062', 'dd-mm-yyyy'), '6', '18', '322', '11', '2062', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22969, to_date('19-11-2062', 'dd-mm-yyyy'), '7', '19', '323', '11', '2062', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22970, to_date('20-11-2062', 'dd-mm-yyyy'), '1', '20', '324', '11', '2062', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22971, to_date('21-11-2062', 'dd-mm-yyyy'), '2', '21', '325', '11', '2062', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22972, to_date('22-11-2062', 'dd-mm-yyyy'), '3', '22', '326', '11', '2062', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22973, to_date('23-11-2062', 'dd-mm-yyyy'), '4', '23', '327', '11', '2062', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22974, to_date('24-11-2062', 'dd-mm-yyyy'), '5', '24', '328', '11', '2062', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22975, to_date('25-11-2062', 'dd-mm-yyyy'), '6', '25', '329', '11', '2062', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22976, to_date('26-11-2062', 'dd-mm-yyyy'), '7', '26', '330', '11', '2062', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24461, to_date('20-12-2066', 'dd-mm-yyyy'), '1', '20', '354', '12', '2066', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24462, to_date('21-12-2066', 'dd-mm-yyyy'), '2', '21', '355', '12', '2066', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24463, to_date('22-12-2066', 'dd-mm-yyyy'), '3', '22', '356', '12', '2066', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24464, to_date('23-12-2066', 'dd-mm-yyyy'), '4', '23', '357', '12', '2066', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24465, to_date('24-12-2066', 'dd-mm-yyyy'), '5', '24', '358', '12', '2066', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24466, to_date('25-12-2066', 'dd-mm-yyyy'), '6', '25', '359', '12', '2066', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24467, to_date('26-12-2066', 'dd-mm-yyyy'), '7', '26', '360', '12', '2066', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24468, to_date('27-12-2066', 'dd-mm-yyyy'), '1', '27', '361', '12', '2066', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24469, to_date('28-12-2066', 'dd-mm-yyyy'), '2', '28', '362', '12', '2066', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24470, to_date('29-12-2066', 'dd-mm-yyyy'), '3', '29', '363', '12', '2066', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24471, to_date('30-12-2066', 'dd-mm-yyyy'), '4', '30', '364', '12', '2066', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24472, to_date('31-12-2066', 'dd-mm-yyyy'), '5', '31', '365', '12', '2066', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24473, to_date('01-01-2067', 'dd-mm-yyyy'), '6', '01', '001', '01', '2067', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24474, to_date('02-01-2067', 'dd-mm-yyyy'), '7', '02', '002', '01', '2067', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24475, to_date('03-01-2067', 'dd-mm-yyyy'), '1', '03', '003', '01', '2067', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24476, to_date('04-01-2067', 'dd-mm-yyyy'), '2', '04', '004', '01', '2067', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24477, to_date('05-01-2067', 'dd-mm-yyyy'), '3', '05', '005', '01', '2067', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24478, to_date('06-01-2067', 'dd-mm-yyyy'), '4', '06', '006', '01', '2067', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24479, to_date('07-01-2067', 'dd-mm-yyyy'), '5', '07', '007', '01', '2067', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24480, to_date('08-01-2067', 'dd-mm-yyyy'), '6', '08', '008', '01', '2067', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24481, to_date('09-01-2067', 'dd-mm-yyyy'), '7', '09', '009', '01', '2067', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24482, to_date('10-01-2067', 'dd-mm-yyyy'), '1', '10', '010', '01', '2067', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24483, to_date('11-01-2067', 'dd-mm-yyyy'), '2', '11', '011', '01', '2067', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24484, to_date('12-01-2067', 'dd-mm-yyyy'), '3', '12', '012', '01', '2067', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24485, to_date('13-01-2067', 'dd-mm-yyyy'), '4', '13', '013', '01', '2067', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24486, to_date('14-01-2067', 'dd-mm-yyyy'), '5', '14', '014', '01', '2067', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24487, to_date('15-01-2067', 'dd-mm-yyyy'), '6', '15', '015', '01', '2067', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24488, to_date('16-01-2067', 'dd-mm-yyyy'), '7', '16', '016', '01', '2067', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24489, to_date('17-01-2067', 'dd-mm-yyyy'), '1', '17', '017', '01', '2067', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24490, to_date('18-01-2067', 'dd-mm-yyyy'), '2', '18', '018', '01', '2067', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24491, to_date('19-01-2067', 'dd-mm-yyyy'), '3', '19', '019', '01', '2067', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24492, to_date('20-01-2067', 'dd-mm-yyyy'), '4', '20', '020', '01', '2067', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24493, to_date('21-01-2067', 'dd-mm-yyyy'), '5', '21', '021', '01', '2067', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24494, to_date('22-01-2067', 'dd-mm-yyyy'), '6', '22', '022', '01', '2067', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24495, to_date('23-01-2067', 'dd-mm-yyyy'), '7', '23', '023', '01', '2067', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24496, to_date('24-01-2067', 'dd-mm-yyyy'), '1', '24', '024', '01', '2067', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24497, to_date('25-01-2067', 'dd-mm-yyyy'), '2', '25', '025', '01', '2067', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24498, to_date('26-01-2067', 'dd-mm-yyyy'), '3', '26', '026', '01', '2067', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24499, to_date('27-01-2067', 'dd-mm-yyyy'), '4', '27', '027', '01', '2067', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24500, to_date('28-01-2067', 'dd-mm-yyyy'), '5', '28', '028', '01', '2067', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24501, to_date('29-01-2067', 'dd-mm-yyyy'), '6', '29', '029', '01', '2067', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24502, to_date('30-01-2067', 'dd-mm-yyyy'), '7', '30', '030', '01', '2067', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24503, to_date('31-01-2067', 'dd-mm-yyyy'), '1', '31', '031', '01', '2067', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24504, to_date('01-02-2067', 'dd-mm-yyyy'), '2', '01', '032', '02', '2067', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24505, to_date('02-02-2067', 'dd-mm-yyyy'), '3', '02', '033', '02', '2067', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24506, to_date('03-02-2067', 'dd-mm-yyyy'), '4', '03', '034', '02', '2067', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24507, to_date('04-02-2067', 'dd-mm-yyyy'), '5', '04', '035', '02', '2067', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24508, to_date('05-02-2067', 'dd-mm-yyyy'), '6', '05', '036', '02', '2067', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24509, to_date('06-02-2067', 'dd-mm-yyyy'), '7', '06', '037', '02', '2067', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24510, to_date('07-02-2067', 'dd-mm-yyyy'), '1', '07', '038', '02', '2067', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24511, to_date('08-02-2067', 'dd-mm-yyyy'), '2', '08', '039', '02', '2067', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24512, to_date('09-02-2067', 'dd-mm-yyyy'), '3', '09', '040', '02', '2067', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24513, to_date('10-02-2067', 'dd-mm-yyyy'), '4', '10', '041', '02', '2067', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24514, to_date('11-02-2067', 'dd-mm-yyyy'), '5', '11', '042', '02', '2067', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24515, to_date('12-02-2067', 'dd-mm-yyyy'), '6', '12', '043', '02', '2067', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24516, to_date('13-02-2067', 'dd-mm-yyyy'), '7', '13', '044', '02', '2067', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24517, to_date('14-02-2067', 'dd-mm-yyyy'), '1', '14', '045', '02', '2067', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24518, to_date('15-02-2067', 'dd-mm-yyyy'), '2', '15', '046', '02', '2067', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24519, to_date('16-02-2067', 'dd-mm-yyyy'), '3', '16', '047', '02', '2067', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24520, to_date('17-02-2067', 'dd-mm-yyyy'), '4', '17', '048', '02', '2067', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24521, to_date('18-02-2067', 'dd-mm-yyyy'), '5', '18', '049', '02', '2067', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24522, to_date('19-02-2067', 'dd-mm-yyyy'), '6', '19', '050', '02', '2067', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24523, to_date('20-02-2067', 'dd-mm-yyyy'), '7', '20', '051', '02', '2067', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24524, to_date('21-02-2067', 'dd-mm-yyyy'), '1', '21', '052', '02', '2067', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24525, to_date('22-02-2067', 'dd-mm-yyyy'), '2', '22', '053', '02', '2067', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24526, to_date('23-02-2067', 'dd-mm-yyyy'), '3', '23', '054', '02', '2067', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24527, to_date('24-02-2067', 'dd-mm-yyyy'), '4', '24', '055', '02', '2067', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24528, to_date('25-02-2067', 'dd-mm-yyyy'), '5', '25', '056', '02', '2067', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24529, to_date('26-02-2067', 'dd-mm-yyyy'), '6', '26', '057', '02', '2067', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24530, to_date('27-02-2067', 'dd-mm-yyyy'), '7', '27', '058', '02', '2067', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24531, to_date('28-02-2067', 'dd-mm-yyyy'), '1', '28', '059', '02', '2067', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24532, to_date('01-03-2067', 'dd-mm-yyyy'), '2', '01', '060', '03', '2067', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24533, to_date('02-03-2067', 'dd-mm-yyyy'), '3', '02', '061', '03', '2067', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24534, to_date('03-03-2067', 'dd-mm-yyyy'), '4', '03', '062', '03', '2067', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24535, to_date('04-03-2067', 'dd-mm-yyyy'), '5', '04', '063', '03', '2067', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24536, to_date('05-03-2067', 'dd-mm-yyyy'), '6', '05', '064', '03', '2067', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24537, to_date('06-03-2067', 'dd-mm-yyyy'), '7', '06', '065', '03', '2067', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24538, to_date('07-03-2067', 'dd-mm-yyyy'), '1', '07', '066', '03', '2067', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24539, to_date('08-03-2067', 'dd-mm-yyyy'), '2', '08', '067', '03', '2067', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24540, to_date('09-03-2067', 'dd-mm-yyyy'), '3', '09', '068', '03', '2067', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24541, to_date('10-03-2067', 'dd-mm-yyyy'), '4', '10', '069', '03', '2067', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24542, to_date('11-03-2067', 'dd-mm-yyyy'), '5', '11', '070', '03', '2067', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24543, to_date('12-03-2067', 'dd-mm-yyyy'), '6', '12', '071', '03', '2067', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24544, to_date('13-03-2067', 'dd-mm-yyyy'), '7', '13', '072', '03', '2067', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24545, to_date('14-03-2067', 'dd-mm-yyyy'), '1', '14', '073', '03', '2067', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24546, to_date('15-03-2067', 'dd-mm-yyyy'), '2', '15', '074', '03', '2067', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24547, to_date('16-03-2067', 'dd-mm-yyyy'), '3', '16', '075', '03', '2067', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24548, to_date('17-03-2067', 'dd-mm-yyyy'), '4', '17', '076', '03', '2067', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24549, to_date('18-03-2067', 'dd-mm-yyyy'), '5', '18', '077', '03', '2067', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24550, to_date('19-03-2067', 'dd-mm-yyyy'), '6', '19', '078', '03', '2067', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24551, to_date('20-03-2067', 'dd-mm-yyyy'), '7', '20', '079', '03', '2067', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24552, to_date('21-03-2067', 'dd-mm-yyyy'), '1', '21', '080', '03', '2067', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24553, to_date('22-03-2067', 'dd-mm-yyyy'), '2', '22', '081', '03', '2067', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24554, to_date('23-03-2067', 'dd-mm-yyyy'), '3', '23', '082', '03', '2067', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24555, to_date('24-03-2067', 'dd-mm-yyyy'), '4', '24', '083', '03', '2067', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24556, to_date('25-03-2067', 'dd-mm-yyyy'), '5', '25', '084', '03', '2067', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24557, to_date('26-03-2067', 'dd-mm-yyyy'), '6', '26', '085', '03', '2067', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24558, to_date('27-03-2067', 'dd-mm-yyyy'), '7', '27', '086', '03', '2067', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24559, to_date('28-03-2067', 'dd-mm-yyyy'), '1', '28', '087', '03', '2067', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24560, to_date('29-03-2067', 'dd-mm-yyyy'), '2', '29', '088', '03', '2067', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24561, to_date('30-03-2067', 'dd-mm-yyyy'), '3', '30', '089', '03', '2067', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24562, to_date('31-03-2067', 'dd-mm-yyyy'), '4', '31', '090', '03', '2067', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24563, to_date('01-04-2067', 'dd-mm-yyyy'), '5', '01', '091', '04', '2067', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24564, to_date('02-04-2067', 'dd-mm-yyyy'), '6', '02', '092', '04', '2067', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24565, to_date('03-04-2067', 'dd-mm-yyyy'), '7', '03', '093', '04', '2067', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24566, to_date('04-04-2067', 'dd-mm-yyyy'), '1', '04', '094', '04', '2067', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19797, to_date('14-03-2054', 'dd-mm-yyyy'), '6', '14', '073', '03', '2054', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19798, to_date('15-03-2054', 'dd-mm-yyyy'), '7', '15', '074', '03', '2054', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19799, to_date('16-03-2054', 'dd-mm-yyyy'), '1', '16', '075', '03', '2054', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19800, to_date('17-03-2054', 'dd-mm-yyyy'), '2', '17', '076', '03', '2054', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19801, to_date('18-03-2054', 'dd-mm-yyyy'), '3', '18', '077', '03', '2054', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19802, to_date('19-03-2054', 'dd-mm-yyyy'), '4', '19', '078', '03', '2054', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19803, to_date('20-03-2054', 'dd-mm-yyyy'), '5', '20', '079', '03', '2054', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19804, to_date('21-03-2054', 'dd-mm-yyyy'), '6', '21', '080', '03', '2054', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19805, to_date('22-03-2054', 'dd-mm-yyyy'), '7', '22', '081', '03', '2054', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19806, to_date('23-03-2054', 'dd-mm-yyyy'), '1', '23', '082', '03', '2054', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19807, to_date('24-03-2054', 'dd-mm-yyyy'), '2', '24', '083', '03', '2054', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19808, to_date('25-03-2054', 'dd-mm-yyyy'), '3', '25', '084', '03', '2054', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19809, to_date('26-03-2054', 'dd-mm-yyyy'), '4', '26', '085', '03', '2054', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19810, to_date('27-03-2054', 'dd-mm-yyyy'), '5', '27', '086', '03', '2054', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19811, to_date('28-03-2054', 'dd-mm-yyyy'), '6', '28', '087', '03', '2054', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19812, to_date('29-03-2054', 'dd-mm-yyyy'), '7', '29', '088', '03', '2054', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19813, to_date('30-03-2054', 'dd-mm-yyyy'), '1', '30', '089', '03', '2054', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19814, to_date('31-03-2054', 'dd-mm-yyyy'), '2', '31', '090', '03', '2054', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19815, to_date('01-04-2054', 'dd-mm-yyyy'), '3', '01', '091', '04', '2054', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19816, to_date('02-04-2054', 'dd-mm-yyyy'), '4', '02', '092', '04', '2054', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19817, to_date('03-04-2054', 'dd-mm-yyyy'), '5', '03', '093', '04', '2054', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19818, to_date('04-04-2054', 'dd-mm-yyyy'), '6', '04', '094', '04', '2054', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19819, to_date('05-04-2054', 'dd-mm-yyyy'), '7', '05', '095', '04', '2054', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19820, to_date('06-04-2054', 'dd-mm-yyyy'), '1', '06', '096', '04', '2054', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19821, to_date('07-04-2054', 'dd-mm-yyyy'), '2', '07', '097', '04', '2054', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19822, to_date('08-04-2054', 'dd-mm-yyyy'), '3', '08', '098', '04', '2054', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19823, to_date('09-04-2054', 'dd-mm-yyyy'), '4', '09', '099', '04', '2054', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19824, to_date('10-04-2054', 'dd-mm-yyyy'), '5', '10', '100', '04', '2054', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19825, to_date('11-04-2054', 'dd-mm-yyyy'), '6', '11', '101', '04', '2054', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19826, to_date('12-04-2054', 'dd-mm-yyyy'), '7', '12', '102', '04', '2054', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19827, to_date('13-04-2054', 'dd-mm-yyyy'), '1', '13', '103', '04', '2054', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19828, to_date('14-04-2054', 'dd-mm-yyyy'), '2', '14', '104', '04', '2054', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19829, to_date('15-04-2054', 'dd-mm-yyyy'), '3', '15', '105', '04', '2054', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19830, to_date('16-04-2054', 'dd-mm-yyyy'), '4', '16', '106', '04', '2054', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19831, to_date('17-04-2054', 'dd-mm-yyyy'), '5', '17', '107', '04', '2054', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19832, to_date('18-04-2054', 'dd-mm-yyyy'), '6', '18', '108', '04', '2054', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19833, to_date('19-04-2054', 'dd-mm-yyyy'), '7', '19', '109', '04', '2054', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19834, to_date('20-04-2054', 'dd-mm-yyyy'), '1', '20', '110', '04', '2054', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19835, to_date('21-04-2054', 'dd-mm-yyyy'), '2', '21', '111', '04', '2054', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19836, to_date('22-04-2054', 'dd-mm-yyyy'), '3', '22', '112', '04', '2054', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19837, to_date('23-04-2054', 'dd-mm-yyyy'), '4', '23', '113', '04', '2054', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19838, to_date('24-04-2054', 'dd-mm-yyyy'), '5', '24', '114', '04', '2054', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19839, to_date('25-04-2054', 'dd-mm-yyyy'), '6', '25', '115', '04', '2054', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19840, to_date('26-04-2054', 'dd-mm-yyyy'), '7', '26', '116', '04', '2054', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19841, to_date('27-04-2054', 'dd-mm-yyyy'), '1', '27', '117', '04', '2054', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19842, to_date('28-04-2054', 'dd-mm-yyyy'), '2', '28', '118', '04', '2054', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19843, to_date('29-04-2054', 'dd-mm-yyyy'), '3', '29', '119', '04', '2054', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19844, to_date('30-04-2054', 'dd-mm-yyyy'), '4', '30', '120', '04', '2054', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19845, to_date('01-05-2054', 'dd-mm-yyyy'), '5', '01', '121', '05', '2054', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19846, to_date('02-05-2054', 'dd-mm-yyyy'), '6', '02', '122', '05', '2054', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19847, to_date('03-05-2054', 'dd-mm-yyyy'), '7', '03', '123', '05', '2054', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19848, to_date('04-05-2054', 'dd-mm-yyyy'), '1', '04', '124', '05', '2054', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19849, to_date('05-05-2054', 'dd-mm-yyyy'), '2', '05', '125', '05', '2054', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19850, to_date('06-05-2054', 'dd-mm-yyyy'), '3', '06', '126', '05', '2054', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19851, to_date('07-05-2054', 'dd-mm-yyyy'), '4', '07', '127', '05', '2054', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19852, to_date('08-05-2054', 'dd-mm-yyyy'), '5', '08', '128', '05', '2054', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19853, to_date('09-05-2054', 'dd-mm-yyyy'), '6', '09', '129', '05', '2054', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19854, to_date('10-05-2054', 'dd-mm-yyyy'), '7', '10', '130', '05', '2054', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19855, to_date('11-05-2054', 'dd-mm-yyyy'), '1', '11', '131', '05', '2054', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19856, to_date('12-05-2054', 'dd-mm-yyyy'), '2', '12', '132', '05', '2054', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19857, to_date('13-05-2054', 'dd-mm-yyyy'), '3', '13', '133', '05', '2054', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19858, to_date('14-05-2054', 'dd-mm-yyyy'), '4', '14', '134', '05', '2054', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19859, to_date('15-05-2054', 'dd-mm-yyyy'), '5', '15', '135', '05', '2054', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19860, to_date('16-05-2054', 'dd-mm-yyyy'), '6', '16', '136', '05', '2054', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19861, to_date('17-05-2054', 'dd-mm-yyyy'), '7', '17', '137', '05', '2054', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19862, to_date('18-05-2054', 'dd-mm-yyyy'), '1', '18', '138', '05', '2054', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19863, to_date('19-05-2054', 'dd-mm-yyyy'), '2', '19', '139', '05', '2054', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19864, to_date('20-05-2054', 'dd-mm-yyyy'), '3', '20', '140', '05', '2054', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19865, to_date('21-05-2054', 'dd-mm-yyyy'), '4', '21', '141', '05', '2054', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19866, to_date('22-05-2054', 'dd-mm-yyyy'), '5', '22', '142', '05', '2054', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19867, to_date('23-05-2054', 'dd-mm-yyyy'), '6', '23', '143', '05', '2054', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19868, to_date('24-05-2054', 'dd-mm-yyyy'), '7', '24', '144', '05', '2054', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19869, to_date('25-05-2054', 'dd-mm-yyyy'), '1', '25', '145', '05', '2054', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19870, to_date('26-05-2054', 'dd-mm-yyyy'), '2', '26', '146', '05', '2054', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19871, to_date('27-05-2054', 'dd-mm-yyyy'), '3', '27', '147', '05', '2054', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19872, to_date('28-05-2054', 'dd-mm-yyyy'), '4', '28', '148', '05', '2054', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19873, to_date('29-05-2054', 'dd-mm-yyyy'), '5', '29', '149', '05', '2054', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19874, to_date('30-05-2054', 'dd-mm-yyyy'), '6', '30', '150', '05', '2054', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19875, to_date('31-05-2054', 'dd-mm-yyyy'), '7', '31', '151', '05', '2054', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19876, to_date('01-06-2054', 'dd-mm-yyyy'), '1', '01', '152', '06', '2054', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19877, to_date('02-06-2054', 'dd-mm-yyyy'), '2', '02', '153', '06', '2054', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19878, to_date('03-06-2054', 'dd-mm-yyyy'), '3', '03', '154', '06', '2054', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19879, to_date('04-06-2054', 'dd-mm-yyyy'), '4', '04', '155', '06', '2054', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19880, to_date('05-06-2054', 'dd-mm-yyyy'), '5', '05', '156', '06', '2054', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19881, to_date('06-06-2054', 'dd-mm-yyyy'), '6', '06', '157', '06', '2054', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19882, to_date('07-06-2054', 'dd-mm-yyyy'), '7', '07', '158', '06', '2054', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19883, to_date('08-06-2054', 'dd-mm-yyyy'), '1', '08', '159', '06', '2054', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19884, to_date('09-06-2054', 'dd-mm-yyyy'), '2', '09', '160', '06', '2054', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19885, to_date('10-06-2054', 'dd-mm-yyyy'), '3', '10', '161', '06', '2054', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19886, to_date('11-06-2054', 'dd-mm-yyyy'), '4', '11', '162', '06', '2054', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19887, to_date('12-06-2054', 'dd-mm-yyyy'), '5', '12', '163', '06', '2054', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19888, to_date('13-06-2054', 'dd-mm-yyyy'), '6', '13', '164', '06', '2054', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19889, to_date('14-06-2054', 'dd-mm-yyyy'), '7', '14', '165', '06', '2054', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19890, to_date('15-06-2054', 'dd-mm-yyyy'), '1', '15', '166', '06', '2054', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19891, to_date('16-06-2054', 'dd-mm-yyyy'), '2', '16', '167', '06', '2054', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19892, to_date('17-06-2054', 'dd-mm-yyyy'), '3', '17', '168', '06', '2054', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19893, to_date('18-06-2054', 'dd-mm-yyyy'), '4', '18', '169', '06', '2054', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19894, to_date('19-06-2054', 'dd-mm-yyyy'), '5', '19', '170', '06', '2054', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19895, to_date('20-06-2054', 'dd-mm-yyyy'), '6', '20', '171', '06', '2054', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19896, to_date('21-06-2054', 'dd-mm-yyyy'), '7', '21', '172', '06', '2054', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19897, to_date('22-06-2054', 'dd-mm-yyyy'), '1', '22', '173', '06', '2054', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19898, to_date('23-06-2054', 'dd-mm-yyyy'), '2', '23', '174', '06', '2054', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19899, to_date('24-06-2054', 'dd-mm-yyyy'), '3', '24', '175', '06', '2054', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19900, to_date('25-06-2054', 'dd-mm-yyyy'), '4', '25', '176', '06', '2054', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19901, to_date('26-06-2054', 'dd-mm-yyyy'), '5', '26', '177', '06', '2054', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19902, to_date('27-06-2054', 'dd-mm-yyyy'), '6', '27', '178', '06', '2054', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21387, to_date('21-07-2058', 'dd-mm-yyyy'), '7', '21', '202', '07', '2058', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21388, to_date('22-07-2058', 'dd-mm-yyyy'), '1', '22', '203', '07', '2058', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21389, to_date('23-07-2058', 'dd-mm-yyyy'), '2', '23', '204', '07', '2058', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21390, to_date('24-07-2058', 'dd-mm-yyyy'), '3', '24', '205', '07', '2058', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21391, to_date('25-07-2058', 'dd-mm-yyyy'), '4', '25', '206', '07', '2058', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21392, to_date('26-07-2058', 'dd-mm-yyyy'), '5', '26', '207', '07', '2058', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21393, to_date('27-07-2058', 'dd-mm-yyyy'), '6', '27', '208', '07', '2058', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21394, to_date('28-07-2058', 'dd-mm-yyyy'), '7', '28', '209', '07', '2058', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21395, to_date('29-07-2058', 'dd-mm-yyyy'), '1', '29', '210', '07', '2058', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21396, to_date('30-07-2058', 'dd-mm-yyyy'), '2', '30', '211', '07', '2058', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21397, to_date('31-07-2058', 'dd-mm-yyyy'), '3', '31', '212', '07', '2058', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21398, to_date('01-08-2058', 'dd-mm-yyyy'), '4', '01', '213', '08', '2058', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21399, to_date('02-08-2058', 'dd-mm-yyyy'), '5', '02', '214', '08', '2058', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21400, to_date('03-08-2058', 'dd-mm-yyyy'), '6', '03', '215', '08', '2058', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21401, to_date('04-08-2058', 'dd-mm-yyyy'), '7', '04', '216', '08', '2058', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21402, to_date('05-08-2058', 'dd-mm-yyyy'), '1', '05', '217', '08', '2058', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21403, to_date('06-08-2058', 'dd-mm-yyyy'), '2', '06', '218', '08', '2058', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21404, to_date('07-08-2058', 'dd-mm-yyyy'), '3', '07', '219', '08', '2058', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21405, to_date('08-08-2058', 'dd-mm-yyyy'), '4', '08', '220', '08', '2058', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21406, to_date('09-08-2058', 'dd-mm-yyyy'), '5', '09', '221', '08', '2058', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21407, to_date('10-08-2058', 'dd-mm-yyyy'), '6', '10', '222', '08', '2058', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21408, to_date('11-08-2058', 'dd-mm-yyyy'), '7', '11', '223', '08', '2058', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21409, to_date('12-08-2058', 'dd-mm-yyyy'), '1', '12', '224', '08', '2058', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21410, to_date('13-08-2058', 'dd-mm-yyyy'), '2', '13', '225', '08', '2058', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21411, to_date('14-08-2058', 'dd-mm-yyyy'), '3', '14', '226', '08', '2058', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21412, to_date('15-08-2058', 'dd-mm-yyyy'), '4', '15', '227', '08', '2058', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21413, to_date('16-08-2058', 'dd-mm-yyyy'), '5', '16', '228', '08', '2058', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21414, to_date('17-08-2058', 'dd-mm-yyyy'), '6', '17', '229', '08', '2058', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21415, to_date('18-08-2058', 'dd-mm-yyyy'), '7', '18', '230', '08', '2058', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21416, to_date('19-08-2058', 'dd-mm-yyyy'), '1', '19', '231', '08', '2058', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21417, to_date('20-08-2058', 'dd-mm-yyyy'), '2', '20', '232', '08', '2058', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21418, to_date('21-08-2058', 'dd-mm-yyyy'), '3', '21', '233', '08', '2058', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21419, to_date('22-08-2058', 'dd-mm-yyyy'), '4', '22', '234', '08', '2058', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21420, to_date('23-08-2058', 'dd-mm-yyyy'), '5', '23', '235', '08', '2058', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21421, to_date('24-08-2058', 'dd-mm-yyyy'), '6', '24', '236', '08', '2058', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21422, to_date('25-08-2058', 'dd-mm-yyyy'), '7', '25', '237', '08', '2058', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21423, to_date('26-08-2058', 'dd-mm-yyyy'), '1', '26', '238', '08', '2058', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21424, to_date('27-08-2058', 'dd-mm-yyyy'), '2', '27', '239', '08', '2058', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21425, to_date('28-08-2058', 'dd-mm-yyyy'), '3', '28', '240', '08', '2058', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21426, to_date('29-08-2058', 'dd-mm-yyyy'), '4', '29', '241', '08', '2058', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21427, to_date('30-08-2058', 'dd-mm-yyyy'), '5', '30', '242', '08', '2058', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21428, to_date('31-08-2058', 'dd-mm-yyyy'), '6', '31', '243', '08', '2058', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21429, to_date('01-09-2058', 'dd-mm-yyyy'), '7', '01', '244', '09', '2058', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21430, to_date('02-09-2058', 'dd-mm-yyyy'), '1', '02', '245', '09', '2058', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21431, to_date('03-09-2058', 'dd-mm-yyyy'), '2', '03', '246', '09', '2058', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21432, to_date('04-09-2058', 'dd-mm-yyyy'), '3', '04', '247', '09', '2058', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21433, to_date('05-09-2058', 'dd-mm-yyyy'), '4', '05', '248', '09', '2058', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21434, to_date('06-09-2058', 'dd-mm-yyyy'), '5', '06', '249', '09', '2058', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21435, to_date('07-09-2058', 'dd-mm-yyyy'), '6', '07', '250', '09', '2058', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21436, to_date('08-09-2058', 'dd-mm-yyyy'), '7', '08', '251', '09', '2058', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21437, to_date('09-09-2058', 'dd-mm-yyyy'), '1', '09', '252', '09', '2058', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21438, to_date('10-09-2058', 'dd-mm-yyyy'), '2', '10', '253', '09', '2058', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21439, to_date('11-09-2058', 'dd-mm-yyyy'), '3', '11', '254', '09', '2058', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21440, to_date('12-09-2058', 'dd-mm-yyyy'), '4', '12', '255', '09', '2058', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21441, to_date('13-09-2058', 'dd-mm-yyyy'), '5', '13', '256', '09', '2058', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21442, to_date('14-09-2058', 'dd-mm-yyyy'), '6', '14', '257', '09', '2058', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21443, to_date('15-09-2058', 'dd-mm-yyyy'), '7', '15', '258', '09', '2058', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21444, to_date('16-09-2058', 'dd-mm-yyyy'), '1', '16', '259', '09', '2058', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21445, to_date('17-09-2058', 'dd-mm-yyyy'), '2', '17', '260', '09', '2058', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21446, to_date('18-09-2058', 'dd-mm-yyyy'), '3', '18', '261', '09', '2058', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21447, to_date('19-09-2058', 'dd-mm-yyyy'), '4', '19', '262', '09', '2058', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21448, to_date('20-09-2058', 'dd-mm-yyyy'), '5', '20', '263', '09', '2058', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21449, to_date('21-09-2058', 'dd-mm-yyyy'), '6', '21', '264', '09', '2058', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21450, to_date('22-09-2058', 'dd-mm-yyyy'), '7', '22', '265', '09', '2058', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21451, to_date('23-09-2058', 'dd-mm-yyyy'), '1', '23', '266', '09', '2058', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21452, to_date('24-09-2058', 'dd-mm-yyyy'), '2', '24', '267', '09', '2058', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21453, to_date('25-09-2058', 'dd-mm-yyyy'), '3', '25', '268', '09', '2058', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21454, to_date('26-09-2058', 'dd-mm-yyyy'), '4', '26', '269', '09', '2058', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21455, to_date('27-09-2058', 'dd-mm-yyyy'), '5', '27', '270', '09', '2058', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21456, to_date('28-09-2058', 'dd-mm-yyyy'), '6', '28', '271', '09', '2058', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21457, to_date('29-09-2058', 'dd-mm-yyyy'), '7', '29', '272', '09', '2058', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21458, to_date('30-09-2058', 'dd-mm-yyyy'), '1', '30', '273', '09', '2058', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21459, to_date('01-10-2058', 'dd-mm-yyyy'), '2', '01', '274', '10', '2058', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21460, to_date('02-10-2058', 'dd-mm-yyyy'), '3', '02', '275', '10', '2058', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21461, to_date('03-10-2058', 'dd-mm-yyyy'), '4', '03', '276', '10', '2058', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21462, to_date('04-10-2058', 'dd-mm-yyyy'), '5', '04', '277', '10', '2058', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21463, to_date('05-10-2058', 'dd-mm-yyyy'), '6', '05', '278', '10', '2058', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21464, to_date('06-10-2058', 'dd-mm-yyyy'), '7', '06', '279', '10', '2058', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21465, to_date('07-10-2058', 'dd-mm-yyyy'), '1', '07', '280', '10', '2058', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21466, to_date('08-10-2058', 'dd-mm-yyyy'), '2', '08', '281', '10', '2058', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21467, to_date('09-10-2058', 'dd-mm-yyyy'), '3', '09', '282', '10', '2058', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21468, to_date('10-10-2058', 'dd-mm-yyyy'), '4', '10', '283', '10', '2058', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21469, to_date('11-10-2058', 'dd-mm-yyyy'), '5', '11', '284', '10', '2058', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21470, to_date('12-10-2058', 'dd-mm-yyyy'), '6', '12', '285', '10', '2058', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21471, to_date('13-10-2058', 'dd-mm-yyyy'), '7', '13', '286', '10', '2058', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21472, to_date('14-10-2058', 'dd-mm-yyyy'), '1', '14', '287', '10', '2058', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21473, to_date('15-10-2058', 'dd-mm-yyyy'), '2', '15', '288', '10', '2058', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21474, to_date('16-10-2058', 'dd-mm-yyyy'), '3', '16', '289', '10', '2058', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21475, to_date('17-10-2058', 'dd-mm-yyyy'), '4', '17', '290', '10', '2058', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21476, to_date('18-10-2058', 'dd-mm-yyyy'), '5', '18', '291', '10', '2058', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21477, to_date('19-10-2058', 'dd-mm-yyyy'), '6', '19', '292', '10', '2058', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21478, to_date('20-10-2058', 'dd-mm-yyyy'), '7', '20', '293', '10', '2058', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21479, to_date('21-10-2058', 'dd-mm-yyyy'), '1', '21', '294', '10', '2058', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21480, to_date('22-10-2058', 'dd-mm-yyyy'), '2', '22', '295', '10', '2058', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21481, to_date('23-10-2058', 'dd-mm-yyyy'), '3', '23', '296', '10', '2058', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21482, to_date('24-10-2058', 'dd-mm-yyyy'), '4', '24', '297', '10', '2058', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21483, to_date('25-10-2058', 'dd-mm-yyyy'), '5', '25', '298', '10', '2058', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21484, to_date('26-10-2058', 'dd-mm-yyyy'), '6', '26', '299', '10', '2058', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21485, to_date('27-10-2058', 'dd-mm-yyyy'), '7', '27', '300', '10', '2058', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21486, to_date('28-10-2058', 'dd-mm-yyyy'), '1', '28', '301', '10', '2058', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21487, to_date('29-10-2058', 'dd-mm-yyyy'), '2', '29', '302', '10', '2058', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21488, to_date('30-10-2058', 'dd-mm-yyyy'), '3', '30', '303', '10', '2058', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21489, to_date('31-10-2058', 'dd-mm-yyyy'), '4', '31', '304', '10', '2058', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21490, to_date('01-11-2058', 'dd-mm-yyyy'), '5', '01', '305', '11', '2058', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21491, to_date('02-11-2058', 'dd-mm-yyyy'), '6', '02', '306', '11', '2058', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21492, to_date('03-11-2058', 'dd-mm-yyyy'), '7', '03', '307', '11', '2058', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22977, to_date('27-11-2062', 'dd-mm-yyyy'), '1', '27', '331', '11', '2062', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22978, to_date('28-11-2062', 'dd-mm-yyyy'), '2', '28', '332', '11', '2062', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22979, to_date('29-11-2062', 'dd-mm-yyyy'), '3', '29', '333', '11', '2062', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22980, to_date('30-11-2062', 'dd-mm-yyyy'), '4', '30', '334', '11', '2062', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22981, to_date('01-12-2062', 'dd-mm-yyyy'), '5', '01', '335', '12', '2062', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22982, to_date('02-12-2062', 'dd-mm-yyyy'), '6', '02', '336', '12', '2062', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22983, to_date('03-12-2062', 'dd-mm-yyyy'), '7', '03', '337', '12', '2062', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22984, to_date('04-12-2062', 'dd-mm-yyyy'), '1', '04', '338', '12', '2062', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22985, to_date('05-12-2062', 'dd-mm-yyyy'), '2', '05', '339', '12', '2062', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22986, to_date('06-12-2062', 'dd-mm-yyyy'), '3', '06', '340', '12', '2062', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22987, to_date('07-12-2062', 'dd-mm-yyyy'), '4', '07', '341', '12', '2062', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22988, to_date('08-12-2062', 'dd-mm-yyyy'), '5', '08', '342', '12', '2062', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22989, to_date('09-12-2062', 'dd-mm-yyyy'), '6', '09', '343', '12', '2062', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22990, to_date('10-12-2062', 'dd-mm-yyyy'), '7', '10', '344', '12', '2062', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22991, to_date('11-12-2062', 'dd-mm-yyyy'), '1', '11', '345', '12', '2062', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22992, to_date('12-12-2062', 'dd-mm-yyyy'), '2', '12', '346', '12', '2062', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22993, to_date('13-12-2062', 'dd-mm-yyyy'), '3', '13', '347', '12', '2062', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22994, to_date('14-12-2062', 'dd-mm-yyyy'), '4', '14', '348', '12', '2062', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22995, to_date('15-12-2062', 'dd-mm-yyyy'), '5', '15', '349', '12', '2062', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22996, to_date('16-12-2062', 'dd-mm-yyyy'), '6', '16', '350', '12', '2062', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22997, to_date('17-12-2062', 'dd-mm-yyyy'), '7', '17', '351', '12', '2062', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22998, to_date('18-12-2062', 'dd-mm-yyyy'), '1', '18', '352', '12', '2062', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22999, to_date('19-12-2062', 'dd-mm-yyyy'), '2', '19', '353', '12', '2062', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23000, to_date('20-12-2062', 'dd-mm-yyyy'), '3', '20', '354', '12', '2062', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23001, to_date('21-12-2062', 'dd-mm-yyyy'), '4', '21', '355', '12', '2062', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23002, to_date('22-12-2062', 'dd-mm-yyyy'), '5', '22', '356', '12', '2062', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23003, to_date('23-12-2062', 'dd-mm-yyyy'), '6', '23', '357', '12', '2062', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23004, to_date('24-12-2062', 'dd-mm-yyyy'), '7', '24', '358', '12', '2062', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23005, to_date('25-12-2062', 'dd-mm-yyyy'), '1', '25', '359', '12', '2062', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23006, to_date('26-12-2062', 'dd-mm-yyyy'), '2', '26', '360', '12', '2062', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23007, to_date('27-12-2062', 'dd-mm-yyyy'), '3', '27', '361', '12', '2062', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23008, to_date('28-12-2062', 'dd-mm-yyyy'), '4', '28', '362', '12', '2062', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23009, to_date('29-12-2062', 'dd-mm-yyyy'), '5', '29', '363', '12', '2062', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23010, to_date('30-12-2062', 'dd-mm-yyyy'), '6', '30', '364', '12', '2062', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23011, to_date('31-12-2062', 'dd-mm-yyyy'), '7', '31', '365', '12', '2062', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23012, to_date('01-01-2063', 'dd-mm-yyyy'), '1', '01', '001', '01', '2063', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23013, to_date('02-01-2063', 'dd-mm-yyyy'), '2', '02', '002', '01', '2063', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23014, to_date('03-01-2063', 'dd-mm-yyyy'), '3', '03', '003', '01', '2063', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23015, to_date('04-01-2063', 'dd-mm-yyyy'), '4', '04', '004', '01', '2063', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23016, to_date('05-01-2063', 'dd-mm-yyyy'), '5', '05', '005', '01', '2063', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23017, to_date('06-01-2063', 'dd-mm-yyyy'), '6', '06', '006', '01', '2063', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23018, to_date('07-01-2063', 'dd-mm-yyyy'), '7', '07', '007', '01', '2063', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23019, to_date('08-01-2063', 'dd-mm-yyyy'), '1', '08', '008', '01', '2063', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23020, to_date('09-01-2063', 'dd-mm-yyyy'), '2', '09', '009', '01', '2063', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23021, to_date('10-01-2063', 'dd-mm-yyyy'), '3', '10', '010', '01', '2063', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23022, to_date('11-01-2063', 'dd-mm-yyyy'), '4', '11', '011', '01', '2063', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23023, to_date('12-01-2063', 'dd-mm-yyyy'), '5', '12', '012', '01', '2063', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23024, to_date('13-01-2063', 'dd-mm-yyyy'), '6', '13', '013', '01', '2063', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23025, to_date('14-01-2063', 'dd-mm-yyyy'), '7', '14', '014', '01', '2063', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23026, to_date('15-01-2063', 'dd-mm-yyyy'), '1', '15', '015', '01', '2063', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23027, to_date('16-01-2063', 'dd-mm-yyyy'), '2', '16', '016', '01', '2063', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23028, to_date('17-01-2063', 'dd-mm-yyyy'), '3', '17', '017', '01', '2063', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23029, to_date('18-01-2063', 'dd-mm-yyyy'), '4', '18', '018', '01', '2063', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23030, to_date('19-01-2063', 'dd-mm-yyyy'), '5', '19', '019', '01', '2063', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23031, to_date('20-01-2063', 'dd-mm-yyyy'), '6', '20', '020', '01', '2063', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23032, to_date('21-01-2063', 'dd-mm-yyyy'), '7', '21', '021', '01', '2063', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23033, to_date('22-01-2063', 'dd-mm-yyyy'), '1', '22', '022', '01', '2063', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23034, to_date('23-01-2063', 'dd-mm-yyyy'), '2', '23', '023', '01', '2063', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23035, to_date('24-01-2063', 'dd-mm-yyyy'), '3', '24', '024', '01', '2063', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23036, to_date('25-01-2063', 'dd-mm-yyyy'), '4', '25', '025', '01', '2063', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23037, to_date('26-01-2063', 'dd-mm-yyyy'), '5', '26', '026', '01', '2063', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23038, to_date('27-01-2063', 'dd-mm-yyyy'), '6', '27', '027', '01', '2063', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23039, to_date('28-01-2063', 'dd-mm-yyyy'), '7', '28', '028', '01', '2063', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23040, to_date('29-01-2063', 'dd-mm-yyyy'), '1', '29', '029', '01', '2063', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23041, to_date('30-01-2063', 'dd-mm-yyyy'), '2', '30', '030', '01', '2063', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23042, to_date('31-01-2063', 'dd-mm-yyyy'), '3', '31', '031', '01', '2063', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23043, to_date('01-02-2063', 'dd-mm-yyyy'), '4', '01', '032', '02', '2063', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23044, to_date('02-02-2063', 'dd-mm-yyyy'), '5', '02', '033', '02', '2063', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23045, to_date('03-02-2063', 'dd-mm-yyyy'), '6', '03', '034', '02', '2063', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23046, to_date('04-02-2063', 'dd-mm-yyyy'), '7', '04', '035', '02', '2063', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23047, to_date('05-02-2063', 'dd-mm-yyyy'), '1', '05', '036', '02', '2063', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23048, to_date('06-02-2063', 'dd-mm-yyyy'), '2', '06', '037', '02', '2063', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23049, to_date('07-02-2063', 'dd-mm-yyyy'), '3', '07', '038', '02', '2063', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23050, to_date('08-02-2063', 'dd-mm-yyyy'), '4', '08', '039', '02', '2063', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23051, to_date('09-02-2063', 'dd-mm-yyyy'), '5', '09', '040', '02', '2063', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23052, to_date('10-02-2063', 'dd-mm-yyyy'), '6', '10', '041', '02', '2063', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23053, to_date('11-02-2063', 'dd-mm-yyyy'), '7', '11', '042', '02', '2063', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23054, to_date('12-02-2063', 'dd-mm-yyyy'), '1', '12', '043', '02', '2063', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23055, to_date('13-02-2063', 'dd-mm-yyyy'), '2', '13', '044', '02', '2063', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23056, to_date('14-02-2063', 'dd-mm-yyyy'), '3', '14', '045', '02', '2063', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
commit;
prompt 15000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23057, to_date('15-02-2063', 'dd-mm-yyyy'), '4', '15', '046', '02', '2063', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23058, to_date('16-02-2063', 'dd-mm-yyyy'), '5', '16', '047', '02', '2063', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23059, to_date('17-02-2063', 'dd-mm-yyyy'), '6', '17', '048', '02', '2063', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23060, to_date('18-02-2063', 'dd-mm-yyyy'), '7', '18', '049', '02', '2063', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23061, to_date('19-02-2063', 'dd-mm-yyyy'), '1', '19', '050', '02', '2063', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23062, to_date('20-02-2063', 'dd-mm-yyyy'), '2', '20', '051', '02', '2063', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23063, to_date('21-02-2063', 'dd-mm-yyyy'), '3', '21', '052', '02', '2063', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23064, to_date('22-02-2063', 'dd-mm-yyyy'), '4', '22', '053', '02', '2063', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23065, to_date('23-02-2063', 'dd-mm-yyyy'), '5', '23', '054', '02', '2063', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23066, to_date('24-02-2063', 'dd-mm-yyyy'), '6', '24', '055', '02', '2063', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23067, to_date('25-02-2063', 'dd-mm-yyyy'), '7', '25', '056', '02', '2063', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23068, to_date('26-02-2063', 'dd-mm-yyyy'), '1', '26', '057', '02', '2063', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23069, to_date('27-02-2063', 'dd-mm-yyyy'), '2', '27', '058', '02', '2063', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23070, to_date('28-02-2063', 'dd-mm-yyyy'), '3', '28', '059', '02', '2063', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23071, to_date('01-03-2063', 'dd-mm-yyyy'), '4', '01', '060', '03', '2063', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23072, to_date('02-03-2063', 'dd-mm-yyyy'), '5', '02', '061', '03', '2063', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23073, to_date('03-03-2063', 'dd-mm-yyyy'), '6', '03', '062', '03', '2063', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23074, to_date('04-03-2063', 'dd-mm-yyyy'), '7', '04', '063', '03', '2063', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23075, to_date('05-03-2063', 'dd-mm-yyyy'), '1', '05', '064', '03', '2063', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23076, to_date('06-03-2063', 'dd-mm-yyyy'), '2', '06', '065', '03', '2063', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23077, to_date('07-03-2063', 'dd-mm-yyyy'), '3', '07', '066', '03', '2063', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23078, to_date('08-03-2063', 'dd-mm-yyyy'), '4', '08', '067', '03', '2063', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23079, to_date('09-03-2063', 'dd-mm-yyyy'), '5', '09', '068', '03', '2063', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23080, to_date('10-03-2063', 'dd-mm-yyyy'), '6', '10', '069', '03', '2063', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23081, to_date('11-03-2063', 'dd-mm-yyyy'), '7', '11', '070', '03', '2063', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23082, to_date('12-03-2063', 'dd-mm-yyyy'), '1', '12', '071', '03', '2063', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24567, to_date('05-04-2067', 'dd-mm-yyyy'), '2', '05', '095', '04', '2067', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24568, to_date('06-04-2067', 'dd-mm-yyyy'), '3', '06', '096', '04', '2067', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24569, to_date('07-04-2067', 'dd-mm-yyyy'), '4', '07', '097', '04', '2067', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24570, to_date('08-04-2067', 'dd-mm-yyyy'), '5', '08', '098', '04', '2067', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24571, to_date('09-04-2067', 'dd-mm-yyyy'), '6', '09', '099', '04', '2067', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24572, to_date('10-04-2067', 'dd-mm-yyyy'), '7', '10', '100', '04', '2067', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24573, to_date('11-04-2067', 'dd-mm-yyyy'), '1', '11', '101', '04', '2067', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24574, to_date('12-04-2067', 'dd-mm-yyyy'), '2', '12', '102', '04', '2067', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24575, to_date('13-04-2067', 'dd-mm-yyyy'), '3', '13', '103', '04', '2067', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24576, to_date('14-04-2067', 'dd-mm-yyyy'), '4', '14', '104', '04', '2067', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24577, to_date('15-04-2067', 'dd-mm-yyyy'), '5', '15', '105', '04', '2067', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24578, to_date('16-04-2067', 'dd-mm-yyyy'), '6', '16', '106', '04', '2067', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24579, to_date('17-04-2067', 'dd-mm-yyyy'), '7', '17', '107', '04', '2067', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24580, to_date('18-04-2067', 'dd-mm-yyyy'), '1', '18', '108', '04', '2067', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24581, to_date('19-04-2067', 'dd-mm-yyyy'), '2', '19', '109', '04', '2067', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24582, to_date('20-04-2067', 'dd-mm-yyyy'), '3', '20', '110', '04', '2067', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24583, to_date('21-04-2067', 'dd-mm-yyyy'), '4', '21', '111', '04', '2067', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24584, to_date('22-04-2067', 'dd-mm-yyyy'), '5', '22', '112', '04', '2067', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24585, to_date('23-04-2067', 'dd-mm-yyyy'), '6', '23', '113', '04', '2067', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24586, to_date('24-04-2067', 'dd-mm-yyyy'), '7', '24', '114', '04', '2067', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24587, to_date('25-04-2067', 'dd-mm-yyyy'), '1', '25', '115', '04', '2067', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24588, to_date('26-04-2067', 'dd-mm-yyyy'), '2', '26', '116', '04', '2067', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24589, to_date('27-04-2067', 'dd-mm-yyyy'), '3', '27', '117', '04', '2067', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24590, to_date('28-04-2067', 'dd-mm-yyyy'), '4', '28', '118', '04', '2067', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24591, to_date('29-04-2067', 'dd-mm-yyyy'), '5', '29', '119', '04', '2067', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24592, to_date('30-04-2067', 'dd-mm-yyyy'), '6', '30', '120', '04', '2067', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24593, to_date('01-05-2067', 'dd-mm-yyyy'), '7', '01', '121', '05', '2067', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24594, to_date('02-05-2067', 'dd-mm-yyyy'), '1', '02', '122', '05', '2067', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24595, to_date('03-05-2067', 'dd-mm-yyyy'), '2', '03', '123', '05', '2067', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24596, to_date('04-05-2067', 'dd-mm-yyyy'), '3', '04', '124', '05', '2067', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24597, to_date('05-05-2067', 'dd-mm-yyyy'), '4', '05', '125', '05', '2067', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24598, to_date('06-05-2067', 'dd-mm-yyyy'), '5', '06', '126', '05', '2067', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24599, to_date('07-05-2067', 'dd-mm-yyyy'), '6', '07', '127', '05', '2067', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24600, to_date('08-05-2067', 'dd-mm-yyyy'), '7', '08', '128', '05', '2067', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24601, to_date('09-05-2067', 'dd-mm-yyyy'), '1', '09', '129', '05', '2067', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24602, to_date('10-05-2067', 'dd-mm-yyyy'), '2', '10', '130', '05', '2067', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24603, to_date('11-05-2067', 'dd-mm-yyyy'), '3', '11', '131', '05', '2067', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24604, to_date('12-05-2067', 'dd-mm-yyyy'), '4', '12', '132', '05', '2067', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24605, to_date('13-05-2067', 'dd-mm-yyyy'), '5', '13', '133', '05', '2067', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24606, to_date('14-05-2067', 'dd-mm-yyyy'), '6', '14', '134', '05', '2067', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24607, to_date('15-05-2067', 'dd-mm-yyyy'), '7', '15', '135', '05', '2067', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24608, to_date('16-05-2067', 'dd-mm-yyyy'), '1', '16', '136', '05', '2067', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24609, to_date('17-05-2067', 'dd-mm-yyyy'), '2', '17', '137', '05', '2067', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24610, to_date('18-05-2067', 'dd-mm-yyyy'), '3', '18', '138', '05', '2067', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24611, to_date('19-05-2067', 'dd-mm-yyyy'), '4', '19', '139', '05', '2067', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24612, to_date('20-05-2067', 'dd-mm-yyyy'), '5', '20', '140', '05', '2067', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24613, to_date('21-05-2067', 'dd-mm-yyyy'), '6', '21', '141', '05', '2067', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24614, to_date('22-05-2067', 'dd-mm-yyyy'), '7', '22', '142', '05', '2067', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24615, to_date('23-05-2067', 'dd-mm-yyyy'), '1', '23', '143', '05', '2067', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24616, to_date('24-05-2067', 'dd-mm-yyyy'), '2', '24', '144', '05', '2067', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24617, to_date('25-05-2067', 'dd-mm-yyyy'), '3', '25', '145', '05', '2067', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24618, to_date('26-05-2067', 'dd-mm-yyyy'), '4', '26', '146', '05', '2067', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24619, to_date('27-05-2067', 'dd-mm-yyyy'), '5', '27', '147', '05', '2067', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24620, to_date('28-05-2067', 'dd-mm-yyyy'), '6', '28', '148', '05', '2067', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24621, to_date('29-05-2067', 'dd-mm-yyyy'), '7', '29', '149', '05', '2067', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24622, to_date('30-05-2067', 'dd-mm-yyyy'), '1', '30', '150', '05', '2067', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24623, to_date('31-05-2067', 'dd-mm-yyyy'), '2', '31', '151', '05', '2067', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24624, to_date('01-06-2067', 'dd-mm-yyyy'), '3', '01', '152', '06', '2067', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24625, to_date('02-06-2067', 'dd-mm-yyyy'), '4', '02', '153', '06', '2067', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24626, to_date('03-06-2067', 'dd-mm-yyyy'), '5', '03', '154', '06', '2067', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24627, to_date('04-06-2067', 'dd-mm-yyyy'), '6', '04', '155', '06', '2067', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24628, to_date('05-06-2067', 'dd-mm-yyyy'), '7', '05', '156', '06', '2067', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24629, to_date('06-06-2067', 'dd-mm-yyyy'), '1', '06', '157', '06', '2067', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24630, to_date('07-06-2067', 'dd-mm-yyyy'), '2', '07', '158', '06', '2067', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24631, to_date('08-06-2067', 'dd-mm-yyyy'), '3', '08', '159', '06', '2067', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24632, to_date('09-06-2067', 'dd-mm-yyyy'), '4', '09', '160', '06', '2067', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24633, to_date('10-06-2067', 'dd-mm-yyyy'), '5', '10', '161', '06', '2067', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24634, to_date('11-06-2067', 'dd-mm-yyyy'), '6', '11', '162', '06', '2067', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24635, to_date('12-06-2067', 'dd-mm-yyyy'), '7', '12', '163', '06', '2067', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24636, to_date('13-06-2067', 'dd-mm-yyyy'), '1', '13', '164', '06', '2067', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24637, to_date('14-06-2067', 'dd-mm-yyyy'), '2', '14', '165', '06', '2067', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24638, to_date('15-06-2067', 'dd-mm-yyyy'), '3', '15', '166', '06', '2067', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24639, to_date('16-06-2067', 'dd-mm-yyyy'), '4', '16', '167', '06', '2067', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24640, to_date('17-06-2067', 'dd-mm-yyyy'), '5', '17', '168', '06', '2067', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24641, to_date('18-06-2067', 'dd-mm-yyyy'), '6', '18', '169', '06', '2067', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24642, to_date('19-06-2067', 'dd-mm-yyyy'), '7', '19', '170', '06', '2067', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24643, to_date('20-06-2067', 'dd-mm-yyyy'), '1', '20', '171', '06', '2067', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24644, to_date('21-06-2067', 'dd-mm-yyyy'), '2', '21', '172', '06', '2067', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24645, to_date('22-06-2067', 'dd-mm-yyyy'), '3', '22', '173', '06', '2067', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24646, to_date('23-06-2067', 'dd-mm-yyyy'), '4', '23', '174', '06', '2067', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24647, to_date('24-06-2067', 'dd-mm-yyyy'), '5', '24', '175', '06', '2067', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24648, to_date('25-06-2067', 'dd-mm-yyyy'), '6', '25', '176', '06', '2067', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24649, to_date('26-06-2067', 'dd-mm-yyyy'), '7', '26', '177', '06', '2067', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24650, to_date('27-06-2067', 'dd-mm-yyyy'), '1', '27', '178', '06', '2067', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24651, to_date('28-06-2067', 'dd-mm-yyyy'), '2', '28', '179', '06', '2067', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24652, to_date('29-06-2067', 'dd-mm-yyyy'), '3', '29', '180', '06', '2067', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24653, to_date('30-06-2067', 'dd-mm-yyyy'), '4', '30', '181', '06', '2067', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24654, to_date('01-07-2067', 'dd-mm-yyyy'), '5', '01', '182', '07', '2067', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24655, to_date('02-07-2067', 'dd-mm-yyyy'), '6', '02', '183', '07', '2067', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24656, to_date('03-07-2067', 'dd-mm-yyyy'), '7', '03', '184', '07', '2067', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24657, to_date('04-07-2067', 'dd-mm-yyyy'), '1', '04', '185', '07', '2067', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24658, to_date('05-07-2067', 'dd-mm-yyyy'), '2', '05', '186', '07', '2067', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24659, to_date('06-07-2067', 'dd-mm-yyyy'), '3', '06', '187', '07', '2067', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24660, to_date('07-07-2067', 'dd-mm-yyyy'), '4', '07', '188', '07', '2067', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24661, to_date('08-07-2067', 'dd-mm-yyyy'), '5', '08', '189', '07', '2067', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24662, to_date('09-07-2067', 'dd-mm-yyyy'), '6', '09', '190', '07', '2067', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24663, to_date('10-07-2067', 'dd-mm-yyyy'), '7', '10', '191', '07', '2067', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24664, to_date('11-07-2067', 'dd-mm-yyyy'), '1', '11', '192', '07', '2067', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24665, to_date('12-07-2067', 'dd-mm-yyyy'), '2', '12', '193', '07', '2067', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24666, to_date('13-07-2067', 'dd-mm-yyyy'), '3', '13', '194', '07', '2067', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24667, to_date('14-07-2067', 'dd-mm-yyyy'), '4', '14', '195', '07', '2067', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24668, to_date('15-07-2067', 'dd-mm-yyyy'), '5', '15', '196', '07', '2067', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24669, to_date('16-07-2067', 'dd-mm-yyyy'), '6', '16', '197', '07', '2067', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24670, to_date('17-07-2067', 'dd-mm-yyyy'), '7', '17', '198', '07', '2067', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24671, to_date('18-07-2067', 'dd-mm-yyyy'), '1', '18', '199', '07', '2067', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24672, to_date('19-07-2067', 'dd-mm-yyyy'), '2', '19', '200', '07', '2067', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19903, to_date('28-06-2054', 'dd-mm-yyyy'), '7', '28', '179', '06', '2054', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19904, to_date('29-06-2054', 'dd-mm-yyyy'), '1', '29', '180', '06', '2054', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19905, to_date('30-06-2054', 'dd-mm-yyyy'), '2', '30', '181', '06', '2054', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19906, to_date('01-07-2054', 'dd-mm-yyyy'), '3', '01', '182', '07', '2054', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19907, to_date('02-07-2054', 'dd-mm-yyyy'), '4', '02', '183', '07', '2054', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19908, to_date('03-07-2054', 'dd-mm-yyyy'), '5', '03', '184', '07', '2054', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19909, to_date('04-07-2054', 'dd-mm-yyyy'), '6', '04', '185', '07', '2054', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19910, to_date('05-07-2054', 'dd-mm-yyyy'), '7', '05', '186', '07', '2054', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19911, to_date('06-07-2054', 'dd-mm-yyyy'), '1', '06', '187', '07', '2054', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19912, to_date('07-07-2054', 'dd-mm-yyyy'), '2', '07', '188', '07', '2054', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19913, to_date('08-07-2054', 'dd-mm-yyyy'), '3', '08', '189', '07', '2054', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19914, to_date('09-07-2054', 'dd-mm-yyyy'), '4', '09', '190', '07', '2054', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19915, to_date('10-07-2054', 'dd-mm-yyyy'), '5', '10', '191', '07', '2054', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19916, to_date('11-07-2054', 'dd-mm-yyyy'), '6', '11', '192', '07', '2054', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19917, to_date('12-07-2054', 'dd-mm-yyyy'), '7', '12', '193', '07', '2054', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19918, to_date('13-07-2054', 'dd-mm-yyyy'), '1', '13', '194', '07', '2054', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19919, to_date('14-07-2054', 'dd-mm-yyyy'), '2', '14', '195', '07', '2054', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19920, to_date('15-07-2054', 'dd-mm-yyyy'), '3', '15', '196', '07', '2054', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19921, to_date('16-07-2054', 'dd-mm-yyyy'), '4', '16', '197', '07', '2054', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19922, to_date('17-07-2054', 'dd-mm-yyyy'), '5', '17', '198', '07', '2054', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19923, to_date('18-07-2054', 'dd-mm-yyyy'), '6', '18', '199', '07', '2054', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19924, to_date('19-07-2054', 'dd-mm-yyyy'), '7', '19', '200', '07', '2054', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19925, to_date('20-07-2054', 'dd-mm-yyyy'), '1', '20', '201', '07', '2054', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19926, to_date('21-07-2054', 'dd-mm-yyyy'), '2', '21', '202', '07', '2054', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19927, to_date('22-07-2054', 'dd-mm-yyyy'), '3', '22', '203', '07', '2054', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19928, to_date('23-07-2054', 'dd-mm-yyyy'), '4', '23', '204', '07', '2054', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19929, to_date('24-07-2054', 'dd-mm-yyyy'), '5', '24', '205', '07', '2054', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19930, to_date('25-07-2054', 'dd-mm-yyyy'), '6', '25', '206', '07', '2054', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19931, to_date('26-07-2054', 'dd-mm-yyyy'), '7', '26', '207', '07', '2054', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19932, to_date('27-07-2054', 'dd-mm-yyyy'), '1', '27', '208', '07', '2054', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19933, to_date('28-07-2054', 'dd-mm-yyyy'), '2', '28', '209', '07', '2054', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19934, to_date('29-07-2054', 'dd-mm-yyyy'), '3', '29', '210', '07', '2054', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19935, to_date('30-07-2054', 'dd-mm-yyyy'), '4', '30', '211', '07', '2054', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19936, to_date('31-07-2054', 'dd-mm-yyyy'), '5', '31', '212', '07', '2054', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19937, to_date('01-08-2054', 'dd-mm-yyyy'), '6', '01', '213', '08', '2054', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19938, to_date('02-08-2054', 'dd-mm-yyyy'), '7', '02', '214', '08', '2054', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19939, to_date('03-08-2054', 'dd-mm-yyyy'), '1', '03', '215', '08', '2054', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19940, to_date('04-08-2054', 'dd-mm-yyyy'), '2', '04', '216', '08', '2054', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19941, to_date('05-08-2054', 'dd-mm-yyyy'), '3', '05', '217', '08', '2054', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19942, to_date('06-08-2054', 'dd-mm-yyyy'), '4', '06', '218', '08', '2054', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19943, to_date('07-08-2054', 'dd-mm-yyyy'), '5', '07', '219', '08', '2054', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19944, to_date('08-08-2054', 'dd-mm-yyyy'), '6', '08', '220', '08', '2054', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19945, to_date('09-08-2054', 'dd-mm-yyyy'), '7', '09', '221', '08', '2054', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19946, to_date('10-08-2054', 'dd-mm-yyyy'), '1', '10', '222', '08', '2054', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19947, to_date('11-08-2054', 'dd-mm-yyyy'), '2', '11', '223', '08', '2054', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19948, to_date('12-08-2054', 'dd-mm-yyyy'), '3', '12', '224', '08', '2054', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19949, to_date('13-08-2054', 'dd-mm-yyyy'), '4', '13', '225', '08', '2054', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19950, to_date('14-08-2054', 'dd-mm-yyyy'), '5', '14', '226', '08', '2054', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19951, to_date('15-08-2054', 'dd-mm-yyyy'), '6', '15', '227', '08', '2054', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19952, to_date('16-08-2054', 'dd-mm-yyyy'), '7', '16', '228', '08', '2054', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19953, to_date('17-08-2054', 'dd-mm-yyyy'), '1', '17', '229', '08', '2054', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19954, to_date('18-08-2054', 'dd-mm-yyyy'), '2', '18', '230', '08', '2054', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19955, to_date('19-08-2054', 'dd-mm-yyyy'), '3', '19', '231', '08', '2054', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19956, to_date('20-08-2054', 'dd-mm-yyyy'), '4', '20', '232', '08', '2054', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19957, to_date('21-08-2054', 'dd-mm-yyyy'), '5', '21', '233', '08', '2054', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19958, to_date('22-08-2054', 'dd-mm-yyyy'), '6', '22', '234', '08', '2054', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19959, to_date('23-08-2054', 'dd-mm-yyyy'), '7', '23', '235', '08', '2054', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19960, to_date('24-08-2054', 'dd-mm-yyyy'), '1', '24', '236', '08', '2054', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19961, to_date('25-08-2054', 'dd-mm-yyyy'), '2', '25', '237', '08', '2054', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19962, to_date('26-08-2054', 'dd-mm-yyyy'), '3', '26', '238', '08', '2054', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19963, to_date('27-08-2054', 'dd-mm-yyyy'), '4', '27', '239', '08', '2054', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19964, to_date('28-08-2054', 'dd-mm-yyyy'), '5', '28', '240', '08', '2054', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19965, to_date('29-08-2054', 'dd-mm-yyyy'), '6', '29', '241', '08', '2054', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19966, to_date('30-08-2054', 'dd-mm-yyyy'), '7', '30', '242', '08', '2054', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19967, to_date('31-08-2054', 'dd-mm-yyyy'), '1', '31', '243', '08', '2054', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19968, to_date('01-09-2054', 'dd-mm-yyyy'), '2', '01', '244', '09', '2054', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19969, to_date('02-09-2054', 'dd-mm-yyyy'), '3', '02', '245', '09', '2054', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19970, to_date('03-09-2054', 'dd-mm-yyyy'), '4', '03', '246', '09', '2054', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19971, to_date('04-09-2054', 'dd-mm-yyyy'), '5', '04', '247', '09', '2054', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19972, to_date('05-09-2054', 'dd-mm-yyyy'), '6', '05', '248', '09', '2054', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19973, to_date('06-09-2054', 'dd-mm-yyyy'), '7', '06', '249', '09', '2054', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19974, to_date('07-09-2054', 'dd-mm-yyyy'), '1', '07', '250', '09', '2054', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19975, to_date('08-09-2054', 'dd-mm-yyyy'), '2', '08', '251', '09', '2054', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19976, to_date('09-09-2054', 'dd-mm-yyyy'), '3', '09', '252', '09', '2054', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19977, to_date('10-09-2054', 'dd-mm-yyyy'), '4', '10', '253', '09', '2054', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19978, to_date('11-09-2054', 'dd-mm-yyyy'), '5', '11', '254', '09', '2054', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19979, to_date('12-09-2054', 'dd-mm-yyyy'), '6', '12', '255', '09', '2054', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19980, to_date('13-09-2054', 'dd-mm-yyyy'), '7', '13', '256', '09', '2054', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19981, to_date('14-09-2054', 'dd-mm-yyyy'), '1', '14', '257', '09', '2054', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19982, to_date('15-09-2054', 'dd-mm-yyyy'), '2', '15', '258', '09', '2054', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19983, to_date('16-09-2054', 'dd-mm-yyyy'), '3', '16', '259', '09', '2054', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19984, to_date('17-09-2054', 'dd-mm-yyyy'), '4', '17', '260', '09', '2054', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19985, to_date('18-09-2054', 'dd-mm-yyyy'), '5', '18', '261', '09', '2054', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19986, to_date('19-09-2054', 'dd-mm-yyyy'), '6', '19', '262', '09', '2054', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19987, to_date('20-09-2054', 'dd-mm-yyyy'), '7', '20', '263', '09', '2054', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19988, to_date('21-09-2054', 'dd-mm-yyyy'), '1', '21', '264', '09', '2054', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19989, to_date('22-09-2054', 'dd-mm-yyyy'), '2', '22', '265', '09', '2054', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19990, to_date('23-09-2054', 'dd-mm-yyyy'), '3', '23', '266', '09', '2054', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19991, to_date('24-09-2054', 'dd-mm-yyyy'), '4', '24', '267', '09', '2054', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19992, to_date('25-09-2054', 'dd-mm-yyyy'), '5', '25', '268', '09', '2054', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19993, to_date('26-09-2054', 'dd-mm-yyyy'), '6', '26', '269', '09', '2054', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19994, to_date('27-09-2054', 'dd-mm-yyyy'), '7', '27', '270', '09', '2054', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19995, to_date('28-09-2054', 'dd-mm-yyyy'), '1', '28', '271', '09', '2054', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19996, to_date('29-09-2054', 'dd-mm-yyyy'), '2', '29', '272', '09', '2054', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19997, to_date('30-09-2054', 'dd-mm-yyyy'), '3', '30', '273', '09', '2054', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19998, to_date('01-10-2054', 'dd-mm-yyyy'), '4', '01', '274', '10', '2054', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19999, to_date('02-10-2054', 'dd-mm-yyyy'), '5', '02', '275', '10', '2054', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20000, to_date('03-10-2054', 'dd-mm-yyyy'), '6', '03', '276', '10', '2054', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20001, to_date('04-10-2054', 'dd-mm-yyyy'), '7', '04', '277', '10', '2054', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20002, to_date('05-10-2054', 'dd-mm-yyyy'), '1', '05', '278', '10', '2054', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20003, to_date('06-10-2054', 'dd-mm-yyyy'), '2', '06', '279', '10', '2054', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20004, to_date('07-10-2054', 'dd-mm-yyyy'), '3', '07', '280', '10', '2054', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20005, to_date('08-10-2054', 'dd-mm-yyyy'), '4', '08', '281', '10', '2054', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20006, to_date('09-10-2054', 'dd-mm-yyyy'), '5', '09', '282', '10', '2054', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20007, to_date('10-10-2054', 'dd-mm-yyyy'), '6', '10', '283', '10', '2054', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20008, to_date('11-10-2054', 'dd-mm-yyyy'), '7', '11', '284', '10', '2054', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21493, to_date('04-11-2058', 'dd-mm-yyyy'), '1', '04', '308', '11', '2058', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21494, to_date('05-11-2058', 'dd-mm-yyyy'), '2', '05', '309', '11', '2058', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21495, to_date('06-11-2058', 'dd-mm-yyyy'), '3', '06', '310', '11', '2058', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21496, to_date('07-11-2058', 'dd-mm-yyyy'), '4', '07', '311', '11', '2058', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21497, to_date('08-11-2058', 'dd-mm-yyyy'), '5', '08', '312', '11', '2058', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21498, to_date('09-11-2058', 'dd-mm-yyyy'), '6', '09', '313', '11', '2058', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21499, to_date('10-11-2058', 'dd-mm-yyyy'), '7', '10', '314', '11', '2058', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21500, to_date('11-11-2058', 'dd-mm-yyyy'), '1', '11', '315', '11', '2058', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21501, to_date('12-11-2058', 'dd-mm-yyyy'), '2', '12', '316', '11', '2058', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21502, to_date('13-11-2058', 'dd-mm-yyyy'), '3', '13', '317', '11', '2058', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21503, to_date('14-11-2058', 'dd-mm-yyyy'), '4', '14', '318', '11', '2058', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21504, to_date('15-11-2058', 'dd-mm-yyyy'), '5', '15', '319', '11', '2058', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21505, to_date('16-11-2058', 'dd-mm-yyyy'), '6', '16', '320', '11', '2058', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21506, to_date('17-11-2058', 'dd-mm-yyyy'), '7', '17', '321', '11', '2058', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21507, to_date('18-11-2058', 'dd-mm-yyyy'), '1', '18', '322', '11', '2058', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21508, to_date('19-11-2058', 'dd-mm-yyyy'), '2', '19', '323', '11', '2058', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21509, to_date('20-11-2058', 'dd-mm-yyyy'), '3', '20', '324', '11', '2058', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21510, to_date('21-11-2058', 'dd-mm-yyyy'), '4', '21', '325', '11', '2058', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21511, to_date('22-11-2058', 'dd-mm-yyyy'), '5', '22', '326', '11', '2058', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21512, to_date('23-11-2058', 'dd-mm-yyyy'), '6', '23', '327', '11', '2058', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21513, to_date('24-11-2058', 'dd-mm-yyyy'), '7', '24', '328', '11', '2058', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21514, to_date('25-11-2058', 'dd-mm-yyyy'), '1', '25', '329', '11', '2058', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21515, to_date('26-11-2058', 'dd-mm-yyyy'), '2', '26', '330', '11', '2058', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21516, to_date('27-11-2058', 'dd-mm-yyyy'), '3', '27', '331', '11', '2058', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21517, to_date('28-11-2058', 'dd-mm-yyyy'), '4', '28', '332', '11', '2058', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21518, to_date('29-11-2058', 'dd-mm-yyyy'), '5', '29', '333', '11', '2058', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21519, to_date('30-11-2058', 'dd-mm-yyyy'), '6', '30', '334', '11', '2058', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21520, to_date('01-12-2058', 'dd-mm-yyyy'), '7', '01', '335', '12', '2058', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21521, to_date('02-12-2058', 'dd-mm-yyyy'), '1', '02', '336', '12', '2058', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21522, to_date('03-12-2058', 'dd-mm-yyyy'), '2', '03', '337', '12', '2058', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21523, to_date('04-12-2058', 'dd-mm-yyyy'), '3', '04', '338', '12', '2058', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21524, to_date('05-12-2058', 'dd-mm-yyyy'), '4', '05', '339', '12', '2058', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21525, to_date('06-12-2058', 'dd-mm-yyyy'), '5', '06', '340', '12', '2058', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21526, to_date('07-12-2058', 'dd-mm-yyyy'), '6', '07', '341', '12', '2058', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21527, to_date('08-12-2058', 'dd-mm-yyyy'), '7', '08', '342', '12', '2058', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21528, to_date('09-12-2058', 'dd-mm-yyyy'), '1', '09', '343', '12', '2058', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21529, to_date('10-12-2058', 'dd-mm-yyyy'), '2', '10', '344', '12', '2058', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21530, to_date('11-12-2058', 'dd-mm-yyyy'), '3', '11', '345', '12', '2058', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21531, to_date('12-12-2058', 'dd-mm-yyyy'), '4', '12', '346', '12', '2058', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21532, to_date('13-12-2058', 'dd-mm-yyyy'), '5', '13', '347', '12', '2058', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21533, to_date('14-12-2058', 'dd-mm-yyyy'), '6', '14', '348', '12', '2058', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21534, to_date('15-12-2058', 'dd-mm-yyyy'), '7', '15', '349', '12', '2058', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21535, to_date('16-12-2058', 'dd-mm-yyyy'), '1', '16', '350', '12', '2058', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21536, to_date('17-12-2058', 'dd-mm-yyyy'), '2', '17', '351', '12', '2058', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21537, to_date('18-12-2058', 'dd-mm-yyyy'), '3', '18', '352', '12', '2058', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21538, to_date('19-12-2058', 'dd-mm-yyyy'), '4', '19', '353', '12', '2058', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21539, to_date('20-12-2058', 'dd-mm-yyyy'), '5', '20', '354', '12', '2058', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21540, to_date('21-12-2058', 'dd-mm-yyyy'), '6', '21', '355', '12', '2058', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21541, to_date('22-12-2058', 'dd-mm-yyyy'), '7', '22', '356', '12', '2058', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21542, to_date('23-12-2058', 'dd-mm-yyyy'), '1', '23', '357', '12', '2058', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21543, to_date('24-12-2058', 'dd-mm-yyyy'), '2', '24', '358', '12', '2058', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21544, to_date('25-12-2058', 'dd-mm-yyyy'), '3', '25', '359', '12', '2058', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21545, to_date('26-12-2058', 'dd-mm-yyyy'), '4', '26', '360', '12', '2058', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21546, to_date('27-12-2058', 'dd-mm-yyyy'), '5', '27', '361', '12', '2058', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21547, to_date('28-12-2058', 'dd-mm-yyyy'), '6', '28', '362', '12', '2058', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21548, to_date('29-12-2058', 'dd-mm-yyyy'), '7', '29', '363', '12', '2058', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21549, to_date('30-12-2058', 'dd-mm-yyyy'), '1', '30', '364', '12', '2058', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21550, to_date('31-12-2058', 'dd-mm-yyyy'), '2', '31', '365', '12', '2058', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21551, to_date('01-01-2059', 'dd-mm-yyyy'), '3', '01', '001', '01', '2059', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21552, to_date('02-01-2059', 'dd-mm-yyyy'), '4', '02', '002', '01', '2059', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21553, to_date('03-01-2059', 'dd-mm-yyyy'), '5', '03', '003', '01', '2059', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21554, to_date('04-01-2059', 'dd-mm-yyyy'), '6', '04', '004', '01', '2059', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21555, to_date('05-01-2059', 'dd-mm-yyyy'), '7', '05', '005', '01', '2059', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21556, to_date('06-01-2059', 'dd-mm-yyyy'), '1', '06', '006', '01', '2059', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21557, to_date('07-01-2059', 'dd-mm-yyyy'), '2', '07', '007', '01', '2059', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21558, to_date('08-01-2059', 'dd-mm-yyyy'), '3', '08', '008', '01', '2059', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21559, to_date('09-01-2059', 'dd-mm-yyyy'), '4', '09', '009', '01', '2059', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21560, to_date('10-01-2059', 'dd-mm-yyyy'), '5', '10', '010', '01', '2059', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21561, to_date('11-01-2059', 'dd-mm-yyyy'), '6', '11', '011', '01', '2059', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21562, to_date('12-01-2059', 'dd-mm-yyyy'), '7', '12', '012', '01', '2059', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21563, to_date('13-01-2059', 'dd-mm-yyyy'), '1', '13', '013', '01', '2059', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21564, to_date('14-01-2059', 'dd-mm-yyyy'), '2', '14', '014', '01', '2059', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21565, to_date('15-01-2059', 'dd-mm-yyyy'), '3', '15', '015', '01', '2059', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21566, to_date('16-01-2059', 'dd-mm-yyyy'), '4', '16', '016', '01', '2059', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21567, to_date('17-01-2059', 'dd-mm-yyyy'), '5', '17', '017', '01', '2059', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21568, to_date('18-01-2059', 'dd-mm-yyyy'), '6', '18', '018', '01', '2059', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21569, to_date('19-01-2059', 'dd-mm-yyyy'), '7', '19', '019', '01', '2059', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21570, to_date('20-01-2059', 'dd-mm-yyyy'), '1', '20', '020', '01', '2059', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21571, to_date('21-01-2059', 'dd-mm-yyyy'), '2', '21', '021', '01', '2059', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21572, to_date('22-01-2059', 'dd-mm-yyyy'), '3', '22', '022', '01', '2059', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21573, to_date('23-01-2059', 'dd-mm-yyyy'), '4', '23', '023', '01', '2059', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21574, to_date('24-01-2059', 'dd-mm-yyyy'), '5', '24', '024', '01', '2059', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21575, to_date('25-01-2059', 'dd-mm-yyyy'), '6', '25', '025', '01', '2059', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21576, to_date('26-01-2059', 'dd-mm-yyyy'), '7', '26', '026', '01', '2059', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21577, to_date('27-01-2059', 'dd-mm-yyyy'), '1', '27', '027', '01', '2059', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21578, to_date('28-01-2059', 'dd-mm-yyyy'), '2', '28', '028', '01', '2059', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21579, to_date('29-01-2059', 'dd-mm-yyyy'), '3', '29', '029', '01', '2059', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21580, to_date('30-01-2059', 'dd-mm-yyyy'), '4', '30', '030', '01', '2059', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21581, to_date('31-01-2059', 'dd-mm-yyyy'), '5', '31', '031', '01', '2059', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21582, to_date('01-02-2059', 'dd-mm-yyyy'), '6', '01', '032', '02', '2059', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21583, to_date('02-02-2059', 'dd-mm-yyyy'), '7', '02', '033', '02', '2059', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21584, to_date('03-02-2059', 'dd-mm-yyyy'), '1', '03', '034', '02', '2059', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21585, to_date('04-02-2059', 'dd-mm-yyyy'), '2', '04', '035', '02', '2059', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21586, to_date('05-02-2059', 'dd-mm-yyyy'), '3', '05', '036', '02', '2059', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21587, to_date('06-02-2059', 'dd-mm-yyyy'), '4', '06', '037', '02', '2059', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21588, to_date('07-02-2059', 'dd-mm-yyyy'), '5', '07', '038', '02', '2059', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21589, to_date('08-02-2059', 'dd-mm-yyyy'), '6', '08', '039', '02', '2059', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21590, to_date('09-02-2059', 'dd-mm-yyyy'), '7', '09', '040', '02', '2059', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21591, to_date('10-02-2059', 'dd-mm-yyyy'), '1', '10', '041', '02', '2059', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21592, to_date('11-02-2059', 'dd-mm-yyyy'), '2', '11', '042', '02', '2059', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21593, to_date('12-02-2059', 'dd-mm-yyyy'), '3', '12', '043', '02', '2059', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21594, to_date('13-02-2059', 'dd-mm-yyyy'), '4', '13', '044', '02', '2059', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21595, to_date('14-02-2059', 'dd-mm-yyyy'), '5', '14', '045', '02', '2059', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21596, to_date('15-02-2059', 'dd-mm-yyyy'), '6', '15', '046', '02', '2059', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21597, to_date('16-02-2059', 'dd-mm-yyyy'), '7', '16', '047', '02', '2059', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21598, to_date('17-02-2059', 'dd-mm-yyyy'), '1', '17', '048', '02', '2059', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23083, to_date('13-03-2063', 'dd-mm-yyyy'), '2', '13', '072', '03', '2063', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23084, to_date('14-03-2063', 'dd-mm-yyyy'), '3', '14', '073', '03', '2063', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23085, to_date('15-03-2063', 'dd-mm-yyyy'), '4', '15', '074', '03', '2063', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23086, to_date('16-03-2063', 'dd-mm-yyyy'), '5', '16', '075', '03', '2063', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23087, to_date('17-03-2063', 'dd-mm-yyyy'), '6', '17', '076', '03', '2063', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23088, to_date('18-03-2063', 'dd-mm-yyyy'), '7', '18', '077', '03', '2063', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23089, to_date('19-03-2063', 'dd-mm-yyyy'), '1', '19', '078', '03', '2063', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23090, to_date('20-03-2063', 'dd-mm-yyyy'), '2', '20', '079', '03', '2063', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23091, to_date('21-03-2063', 'dd-mm-yyyy'), '3', '21', '080', '03', '2063', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23092, to_date('22-03-2063', 'dd-mm-yyyy'), '4', '22', '081', '03', '2063', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23093, to_date('23-03-2063', 'dd-mm-yyyy'), '5', '23', '082', '03', '2063', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23094, to_date('24-03-2063', 'dd-mm-yyyy'), '6', '24', '083', '03', '2063', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23095, to_date('25-03-2063', 'dd-mm-yyyy'), '7', '25', '084', '03', '2063', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23096, to_date('26-03-2063', 'dd-mm-yyyy'), '1', '26', '085', '03', '2063', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23097, to_date('27-03-2063', 'dd-mm-yyyy'), '2', '27', '086', '03', '2063', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23098, to_date('28-03-2063', 'dd-mm-yyyy'), '3', '28', '087', '03', '2063', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23099, to_date('29-03-2063', 'dd-mm-yyyy'), '4', '29', '088', '03', '2063', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23100, to_date('30-03-2063', 'dd-mm-yyyy'), '5', '30', '089', '03', '2063', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23101, to_date('31-03-2063', 'dd-mm-yyyy'), '6', '31', '090', '03', '2063', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23102, to_date('01-04-2063', 'dd-mm-yyyy'), '7', '01', '091', '04', '2063', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23103, to_date('02-04-2063', 'dd-mm-yyyy'), '1', '02', '092', '04', '2063', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23104, to_date('03-04-2063', 'dd-mm-yyyy'), '2', '03', '093', '04', '2063', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23105, to_date('04-04-2063', 'dd-mm-yyyy'), '3', '04', '094', '04', '2063', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23106, to_date('05-04-2063', 'dd-mm-yyyy'), '4', '05', '095', '04', '2063', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23107, to_date('06-04-2063', 'dd-mm-yyyy'), '5', '06', '096', '04', '2063', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23108, to_date('07-04-2063', 'dd-mm-yyyy'), '6', '07', '097', '04', '2063', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23109, to_date('08-04-2063', 'dd-mm-yyyy'), '7', '08', '098', '04', '2063', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23110, to_date('09-04-2063', 'dd-mm-yyyy'), '1', '09', '099', '04', '2063', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23111, to_date('10-04-2063', 'dd-mm-yyyy'), '2', '10', '100', '04', '2063', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23112, to_date('11-04-2063', 'dd-mm-yyyy'), '3', '11', '101', '04', '2063', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23113, to_date('12-04-2063', 'dd-mm-yyyy'), '4', '12', '102', '04', '2063', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23114, to_date('13-04-2063', 'dd-mm-yyyy'), '5', '13', '103', '04', '2063', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23115, to_date('14-04-2063', 'dd-mm-yyyy'), '6', '14', '104', '04', '2063', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23116, to_date('15-04-2063', 'dd-mm-yyyy'), '7', '15', '105', '04', '2063', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23117, to_date('16-04-2063', 'dd-mm-yyyy'), '1', '16', '106', '04', '2063', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23118, to_date('17-04-2063', 'dd-mm-yyyy'), '2', '17', '107', '04', '2063', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23119, to_date('18-04-2063', 'dd-mm-yyyy'), '3', '18', '108', '04', '2063', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23120, to_date('19-04-2063', 'dd-mm-yyyy'), '4', '19', '109', '04', '2063', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23121, to_date('20-04-2063', 'dd-mm-yyyy'), '5', '20', '110', '04', '2063', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23122, to_date('21-04-2063', 'dd-mm-yyyy'), '6', '21', '111', '04', '2063', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23123, to_date('22-04-2063', 'dd-mm-yyyy'), '7', '22', '112', '04', '2063', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23124, to_date('23-04-2063', 'dd-mm-yyyy'), '1', '23', '113', '04', '2063', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23125, to_date('24-04-2063', 'dd-mm-yyyy'), '2', '24', '114', '04', '2063', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23126, to_date('25-04-2063', 'dd-mm-yyyy'), '3', '25', '115', '04', '2063', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23127, to_date('26-04-2063', 'dd-mm-yyyy'), '4', '26', '116', '04', '2063', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23128, to_date('27-04-2063', 'dd-mm-yyyy'), '5', '27', '117', '04', '2063', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23129, to_date('28-04-2063', 'dd-mm-yyyy'), '6', '28', '118', '04', '2063', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23130, to_date('29-04-2063', 'dd-mm-yyyy'), '7', '29', '119', '04', '2063', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23131, to_date('30-04-2063', 'dd-mm-yyyy'), '1', '30', '120', '04', '2063', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23132, to_date('01-05-2063', 'dd-mm-yyyy'), '2', '01', '121', '05', '2063', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23133, to_date('02-05-2063', 'dd-mm-yyyy'), '3', '02', '122', '05', '2063', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23134, to_date('03-05-2063', 'dd-mm-yyyy'), '4', '03', '123', '05', '2063', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23135, to_date('04-05-2063', 'dd-mm-yyyy'), '5', '04', '124', '05', '2063', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23136, to_date('05-05-2063', 'dd-mm-yyyy'), '6', '05', '125', '05', '2063', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23137, to_date('06-05-2063', 'dd-mm-yyyy'), '7', '06', '126', '05', '2063', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23138, to_date('07-05-2063', 'dd-mm-yyyy'), '1', '07', '127', '05', '2063', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23139, to_date('08-05-2063', 'dd-mm-yyyy'), '2', '08', '128', '05', '2063', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23140, to_date('09-05-2063', 'dd-mm-yyyy'), '3', '09', '129', '05', '2063', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23141, to_date('10-05-2063', 'dd-mm-yyyy'), '4', '10', '130', '05', '2063', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23142, to_date('11-05-2063', 'dd-mm-yyyy'), '5', '11', '131', '05', '2063', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23143, to_date('12-05-2063', 'dd-mm-yyyy'), '6', '12', '132', '05', '2063', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23144, to_date('13-05-2063', 'dd-mm-yyyy'), '7', '13', '133', '05', '2063', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23145, to_date('14-05-2063', 'dd-mm-yyyy'), '1', '14', '134', '05', '2063', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23146, to_date('15-05-2063', 'dd-mm-yyyy'), '2', '15', '135', '05', '2063', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23147, to_date('16-05-2063', 'dd-mm-yyyy'), '3', '16', '136', '05', '2063', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23148, to_date('17-05-2063', 'dd-mm-yyyy'), '4', '17', '137', '05', '2063', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23149, to_date('18-05-2063', 'dd-mm-yyyy'), '5', '18', '138', '05', '2063', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23150, to_date('19-05-2063', 'dd-mm-yyyy'), '6', '19', '139', '05', '2063', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23151, to_date('20-05-2063', 'dd-mm-yyyy'), '7', '20', '140', '05', '2063', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23152, to_date('21-05-2063', 'dd-mm-yyyy'), '1', '21', '141', '05', '2063', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23153, to_date('22-05-2063', 'dd-mm-yyyy'), '2', '22', '142', '05', '2063', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23154, to_date('23-05-2063', 'dd-mm-yyyy'), '3', '23', '143', '05', '2063', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23155, to_date('24-05-2063', 'dd-mm-yyyy'), '4', '24', '144', '05', '2063', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23156, to_date('25-05-2063', 'dd-mm-yyyy'), '5', '25', '145', '05', '2063', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23157, to_date('26-05-2063', 'dd-mm-yyyy'), '6', '26', '146', '05', '2063', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23158, to_date('27-05-2063', 'dd-mm-yyyy'), '7', '27', '147', '05', '2063', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23159, to_date('28-05-2063', 'dd-mm-yyyy'), '1', '28', '148', '05', '2063', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23160, to_date('29-05-2063', 'dd-mm-yyyy'), '2', '29', '149', '05', '2063', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23161, to_date('30-05-2063', 'dd-mm-yyyy'), '3', '30', '150', '05', '2063', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23162, to_date('31-05-2063', 'dd-mm-yyyy'), '4', '31', '151', '05', '2063', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23163, to_date('01-06-2063', 'dd-mm-yyyy'), '5', '01', '152', '06', '2063', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23164, to_date('02-06-2063', 'dd-mm-yyyy'), '6', '02', '153', '06', '2063', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23165, to_date('03-06-2063', 'dd-mm-yyyy'), '7', '03', '154', '06', '2063', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23166, to_date('04-06-2063', 'dd-mm-yyyy'), '1', '04', '155', '06', '2063', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23167, to_date('05-06-2063', 'dd-mm-yyyy'), '2', '05', '156', '06', '2063', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23168, to_date('06-06-2063', 'dd-mm-yyyy'), '3', '06', '157', '06', '2063', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23169, to_date('07-06-2063', 'dd-mm-yyyy'), '4', '07', '158', '06', '2063', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23170, to_date('08-06-2063', 'dd-mm-yyyy'), '5', '08', '159', '06', '2063', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23171, to_date('09-06-2063', 'dd-mm-yyyy'), '6', '09', '160', '06', '2063', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23172, to_date('10-06-2063', 'dd-mm-yyyy'), '7', '10', '161', '06', '2063', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23173, to_date('11-06-2063', 'dd-mm-yyyy'), '1', '11', '162', '06', '2063', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23174, to_date('12-06-2063', 'dd-mm-yyyy'), '2', '12', '163', '06', '2063', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23175, to_date('13-06-2063', 'dd-mm-yyyy'), '3', '13', '164', '06', '2063', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23176, to_date('14-06-2063', 'dd-mm-yyyy'), '4', '14', '165', '06', '2063', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23177, to_date('15-06-2063', 'dd-mm-yyyy'), '5', '15', '166', '06', '2063', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23178, to_date('16-06-2063', 'dd-mm-yyyy'), '6', '16', '167', '06', '2063', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23179, to_date('17-06-2063', 'dd-mm-yyyy'), '7', '17', '168', '06', '2063', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23180, to_date('18-06-2063', 'dd-mm-yyyy'), '1', '18', '169', '06', '2063', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23181, to_date('19-06-2063', 'dd-mm-yyyy'), '2', '19', '170', '06', '2063', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23182, to_date('20-06-2063', 'dd-mm-yyyy'), '3', '20', '171', '06', '2063', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23183, to_date('21-06-2063', 'dd-mm-yyyy'), '4', '21', '172', '06', '2063', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23184, to_date('22-06-2063', 'dd-mm-yyyy'), '5', '22', '173', '06', '2063', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23185, to_date('23-06-2063', 'dd-mm-yyyy'), '6', '23', '174', '06', '2063', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23186, to_date('24-06-2063', 'dd-mm-yyyy'), '7', '24', '175', '06', '2063', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23187, to_date('25-06-2063', 'dd-mm-yyyy'), '1', '25', '176', '06', '2063', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23188, to_date('26-06-2063', 'dd-mm-yyyy'), '2', '26', '177', '06', '2063', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24673, to_date('20-07-2067', 'dd-mm-yyyy'), '3', '20', '201', '07', '2067', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24674, to_date('21-07-2067', 'dd-mm-yyyy'), '4', '21', '202', '07', '2067', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24675, to_date('22-07-2067', 'dd-mm-yyyy'), '5', '22', '203', '07', '2067', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24676, to_date('23-07-2067', 'dd-mm-yyyy'), '6', '23', '204', '07', '2067', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24677, to_date('24-07-2067', 'dd-mm-yyyy'), '7', '24', '205', '07', '2067', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24678, to_date('25-07-2067', 'dd-mm-yyyy'), '1', '25', '206', '07', '2067', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24679, to_date('26-07-2067', 'dd-mm-yyyy'), '2', '26', '207', '07', '2067', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24680, to_date('27-07-2067', 'dd-mm-yyyy'), '3', '27', '208', '07', '2067', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24681, to_date('28-07-2067', 'dd-mm-yyyy'), '4', '28', '209', '07', '2067', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24682, to_date('29-07-2067', 'dd-mm-yyyy'), '5', '29', '210', '07', '2067', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24683, to_date('30-07-2067', 'dd-mm-yyyy'), '6', '30', '211', '07', '2067', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24684, to_date('31-07-2067', 'dd-mm-yyyy'), '7', '31', '212', '07', '2067', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24685, to_date('01-08-2067', 'dd-mm-yyyy'), '1', '01', '213', '08', '2067', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24686, to_date('02-08-2067', 'dd-mm-yyyy'), '2', '02', '214', '08', '2067', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24687, to_date('03-08-2067', 'dd-mm-yyyy'), '3', '03', '215', '08', '2067', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24688, to_date('04-08-2067', 'dd-mm-yyyy'), '4', '04', '216', '08', '2067', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24689, to_date('05-08-2067', 'dd-mm-yyyy'), '5', '05', '217', '08', '2067', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24690, to_date('06-08-2067', 'dd-mm-yyyy'), '6', '06', '218', '08', '2067', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24691, to_date('07-08-2067', 'dd-mm-yyyy'), '7', '07', '219', '08', '2067', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24692, to_date('08-08-2067', 'dd-mm-yyyy'), '1', '08', '220', '08', '2067', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24693, to_date('09-08-2067', 'dd-mm-yyyy'), '2', '09', '221', '08', '2067', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24694, to_date('10-08-2067', 'dd-mm-yyyy'), '3', '10', '222', '08', '2067', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24695, to_date('11-08-2067', 'dd-mm-yyyy'), '4', '11', '223', '08', '2067', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24696, to_date('12-08-2067', 'dd-mm-yyyy'), '5', '12', '224', '08', '2067', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24697, to_date('13-08-2067', 'dd-mm-yyyy'), '6', '13', '225', '08', '2067', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24698, to_date('14-08-2067', 'dd-mm-yyyy'), '7', '14', '226', '08', '2067', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24699, to_date('15-08-2067', 'dd-mm-yyyy'), '1', '15', '227', '08', '2067', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24700, to_date('16-08-2067', 'dd-mm-yyyy'), '2', '16', '228', '08', '2067', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24701, to_date('17-08-2067', 'dd-mm-yyyy'), '3', '17', '229', '08', '2067', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24702, to_date('18-08-2067', 'dd-mm-yyyy'), '4', '18', '230', '08', '2067', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24703, to_date('19-08-2067', 'dd-mm-yyyy'), '5', '19', '231', '08', '2067', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24704, to_date('20-08-2067', 'dd-mm-yyyy'), '6', '20', '232', '08', '2067', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24705, to_date('21-08-2067', 'dd-mm-yyyy'), '7', '21', '233', '08', '2067', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24706, to_date('22-08-2067', 'dd-mm-yyyy'), '1', '22', '234', '08', '2067', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24707, to_date('23-08-2067', 'dd-mm-yyyy'), '2', '23', '235', '08', '2067', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24708, to_date('24-08-2067', 'dd-mm-yyyy'), '3', '24', '236', '08', '2067', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24709, to_date('25-08-2067', 'dd-mm-yyyy'), '4', '25', '237', '08', '2067', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24710, to_date('26-08-2067', 'dd-mm-yyyy'), '5', '26', '238', '08', '2067', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24711, to_date('27-08-2067', 'dd-mm-yyyy'), '6', '27', '239', '08', '2067', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24712, to_date('28-08-2067', 'dd-mm-yyyy'), '7', '28', '240', '08', '2067', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24713, to_date('29-08-2067', 'dd-mm-yyyy'), '1', '29', '241', '08', '2067', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24714, to_date('30-08-2067', 'dd-mm-yyyy'), '2', '30', '242', '08', '2067', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24715, to_date('31-08-2067', 'dd-mm-yyyy'), '3', '31', '243', '08', '2067', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24716, to_date('01-09-2067', 'dd-mm-yyyy'), '4', '01', '244', '09', '2067', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24717, to_date('02-09-2067', 'dd-mm-yyyy'), '5', '02', '245', '09', '2067', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24718, to_date('03-09-2067', 'dd-mm-yyyy'), '6', '03', '246', '09', '2067', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24719, to_date('04-09-2067', 'dd-mm-yyyy'), '7', '04', '247', '09', '2067', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24720, to_date('05-09-2067', 'dd-mm-yyyy'), '1', '05', '248', '09', '2067', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24721, to_date('06-09-2067', 'dd-mm-yyyy'), '2', '06', '249', '09', '2067', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24722, to_date('07-09-2067', 'dd-mm-yyyy'), '3', '07', '250', '09', '2067', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24723, to_date('08-09-2067', 'dd-mm-yyyy'), '4', '08', '251', '09', '2067', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24724, to_date('09-09-2067', 'dd-mm-yyyy'), '5', '09', '252', '09', '2067', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24725, to_date('10-09-2067', 'dd-mm-yyyy'), '6', '10', '253', '09', '2067', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24726, to_date('11-09-2067', 'dd-mm-yyyy'), '7', '11', '254', '09', '2067', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24727, to_date('12-09-2067', 'dd-mm-yyyy'), '1', '12', '255', '09', '2067', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24728, to_date('13-09-2067', 'dd-mm-yyyy'), '2', '13', '256', '09', '2067', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24729, to_date('14-09-2067', 'dd-mm-yyyy'), '3', '14', '257', '09', '2067', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24730, to_date('15-09-2067', 'dd-mm-yyyy'), '4', '15', '258', '09', '2067', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24731, to_date('16-09-2067', 'dd-mm-yyyy'), '5', '16', '259', '09', '2067', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24732, to_date('17-09-2067', 'dd-mm-yyyy'), '6', '17', '260', '09', '2067', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24733, to_date('18-09-2067', 'dd-mm-yyyy'), '7', '18', '261', '09', '2067', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24734, to_date('19-09-2067', 'dd-mm-yyyy'), '1', '19', '262', '09', '2067', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24735, to_date('20-09-2067', 'dd-mm-yyyy'), '2', '20', '263', '09', '2067', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24736, to_date('21-09-2067', 'dd-mm-yyyy'), '3', '21', '264', '09', '2067', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24737, to_date('22-09-2067', 'dd-mm-yyyy'), '4', '22', '265', '09', '2067', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24738, to_date('23-09-2067', 'dd-mm-yyyy'), '5', '23', '266', '09', '2067', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24739, to_date('24-09-2067', 'dd-mm-yyyy'), '6', '24', '267', '09', '2067', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24740, to_date('25-09-2067', 'dd-mm-yyyy'), '7', '25', '268', '09', '2067', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24741, to_date('26-09-2067', 'dd-mm-yyyy'), '1', '26', '269', '09', '2067', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24742, to_date('27-09-2067', 'dd-mm-yyyy'), '2', '27', '270', '09', '2067', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24743, to_date('28-09-2067', 'dd-mm-yyyy'), '3', '28', '271', '09', '2067', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24744, to_date('29-09-2067', 'dd-mm-yyyy'), '4', '29', '272', '09', '2067', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24745, to_date('30-09-2067', 'dd-mm-yyyy'), '5', '30', '273', '09', '2067', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24746, to_date('01-10-2067', 'dd-mm-yyyy'), '6', '01', '274', '10', '2067', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24747, to_date('02-10-2067', 'dd-mm-yyyy'), '7', '02', '275', '10', '2067', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24748, to_date('03-10-2067', 'dd-mm-yyyy'), '1', '03', '276', '10', '2067', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24749, to_date('04-10-2067', 'dd-mm-yyyy'), '2', '04', '277', '10', '2067', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24750, to_date('05-10-2067', 'dd-mm-yyyy'), '3', '05', '278', '10', '2067', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24751, to_date('06-10-2067', 'dd-mm-yyyy'), '4', '06', '279', '10', '2067', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24752, to_date('07-10-2067', 'dd-mm-yyyy'), '5', '07', '280', '10', '2067', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24753, to_date('08-10-2067', 'dd-mm-yyyy'), '6', '08', '281', '10', '2067', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24754, to_date('09-10-2067', 'dd-mm-yyyy'), '7', '09', '282', '10', '2067', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24755, to_date('10-10-2067', 'dd-mm-yyyy'), '1', '10', '283', '10', '2067', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24756, to_date('11-10-2067', 'dd-mm-yyyy'), '2', '11', '284', '10', '2067', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24757, to_date('12-10-2067', 'dd-mm-yyyy'), '3', '12', '285', '10', '2067', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24758, to_date('13-10-2067', 'dd-mm-yyyy'), '4', '13', '286', '10', '2067', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24759, to_date('14-10-2067', 'dd-mm-yyyy'), '5', '14', '287', '10', '2067', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24760, to_date('15-10-2067', 'dd-mm-yyyy'), '6', '15', '288', '10', '2067', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24761, to_date('16-10-2067', 'dd-mm-yyyy'), '7', '16', '289', '10', '2067', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24762, to_date('17-10-2067', 'dd-mm-yyyy'), '1', '17', '290', '10', '2067', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24763, to_date('18-10-2067', 'dd-mm-yyyy'), '2', '18', '291', '10', '2067', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24764, to_date('19-10-2067', 'dd-mm-yyyy'), '3', '19', '292', '10', '2067', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24765, to_date('20-10-2067', 'dd-mm-yyyy'), '4', '20', '293', '10', '2067', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24766, to_date('21-10-2067', 'dd-mm-yyyy'), '5', '21', '294', '10', '2067', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24767, to_date('22-10-2067', 'dd-mm-yyyy'), '6', '22', '295', '10', '2067', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24768, to_date('23-10-2067', 'dd-mm-yyyy'), '7', '23', '296', '10', '2067', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24769, to_date('24-10-2067', 'dd-mm-yyyy'), '1', '24', '297', '10', '2067', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24770, to_date('25-10-2067', 'dd-mm-yyyy'), '2', '25', '298', '10', '2067', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24771, to_date('26-10-2067', 'dd-mm-yyyy'), '3', '26', '299', '10', '2067', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24772, to_date('27-10-2067', 'dd-mm-yyyy'), '4', '27', '300', '10', '2067', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24773, to_date('28-10-2067', 'dd-mm-yyyy'), '5', '28', '301', '10', '2067', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24774, to_date('29-10-2067', 'dd-mm-yyyy'), '6', '29', '302', '10', '2067', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24775, to_date('30-10-2067', 'dd-mm-yyyy'), '7', '30', '303', '10', '2067', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24776, to_date('31-10-2067', 'dd-mm-yyyy'), '1', '31', '304', '10', '2067', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24777, to_date('01-11-2067', 'dd-mm-yyyy'), '2', '01', '305', '11', '2067', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24778, to_date('02-11-2067', 'dd-mm-yyyy'), '3', '02', '306', '11', '2067', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20009, to_date('12-10-2054', 'dd-mm-yyyy'), '1', '12', '285', '10', '2054', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20010, to_date('13-10-2054', 'dd-mm-yyyy'), '2', '13', '286', '10', '2054', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20011, to_date('14-10-2054', 'dd-mm-yyyy'), '3', '14', '287', '10', '2054', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20012, to_date('15-10-2054', 'dd-mm-yyyy'), '4', '15', '288', '10', '2054', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20013, to_date('16-10-2054', 'dd-mm-yyyy'), '5', '16', '289', '10', '2054', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20014, to_date('17-10-2054', 'dd-mm-yyyy'), '6', '17', '290', '10', '2054', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20015, to_date('18-10-2054', 'dd-mm-yyyy'), '7', '18', '291', '10', '2054', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20016, to_date('19-10-2054', 'dd-mm-yyyy'), '1', '19', '292', '10', '2054', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20017, to_date('20-10-2054', 'dd-mm-yyyy'), '2', '20', '293', '10', '2054', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20018, to_date('21-10-2054', 'dd-mm-yyyy'), '3', '21', '294', '10', '2054', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20019, to_date('22-10-2054', 'dd-mm-yyyy'), '4', '22', '295', '10', '2054', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20020, to_date('23-10-2054', 'dd-mm-yyyy'), '5', '23', '296', '10', '2054', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20021, to_date('24-10-2054', 'dd-mm-yyyy'), '6', '24', '297', '10', '2054', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20022, to_date('25-10-2054', 'dd-mm-yyyy'), '7', '25', '298', '10', '2054', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20023, to_date('26-10-2054', 'dd-mm-yyyy'), '1', '26', '299', '10', '2054', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20024, to_date('27-10-2054', 'dd-mm-yyyy'), '2', '27', '300', '10', '2054', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20025, to_date('28-10-2054', 'dd-mm-yyyy'), '3', '28', '301', '10', '2054', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20026, to_date('29-10-2054', 'dd-mm-yyyy'), '4', '29', '302', '10', '2054', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20027, to_date('30-10-2054', 'dd-mm-yyyy'), '5', '30', '303', '10', '2054', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20028, to_date('31-10-2054', 'dd-mm-yyyy'), '6', '31', '304', '10', '2054', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20029, to_date('01-11-2054', 'dd-mm-yyyy'), '7', '01', '305', '11', '2054', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20030, to_date('02-11-2054', 'dd-mm-yyyy'), '1', '02', '306', '11', '2054', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20031, to_date('03-11-2054', 'dd-mm-yyyy'), '2', '03', '307', '11', '2054', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20032, to_date('04-11-2054', 'dd-mm-yyyy'), '3', '04', '308', '11', '2054', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20033, to_date('05-11-2054', 'dd-mm-yyyy'), '4', '05', '309', '11', '2054', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20034, to_date('06-11-2054', 'dd-mm-yyyy'), '5', '06', '310', '11', '2054', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20035, to_date('07-11-2054', 'dd-mm-yyyy'), '6', '07', '311', '11', '2054', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20036, to_date('08-11-2054', 'dd-mm-yyyy'), '7', '08', '312', '11', '2054', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20037, to_date('09-11-2054', 'dd-mm-yyyy'), '1', '09', '313', '11', '2054', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20038, to_date('10-11-2054', 'dd-mm-yyyy'), '2', '10', '314', '11', '2054', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20039, to_date('11-11-2054', 'dd-mm-yyyy'), '3', '11', '315', '11', '2054', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20040, to_date('12-11-2054', 'dd-mm-yyyy'), '4', '12', '316', '11', '2054', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20041, to_date('13-11-2054', 'dd-mm-yyyy'), '5', '13', '317', '11', '2054', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20042, to_date('14-11-2054', 'dd-mm-yyyy'), '6', '14', '318', '11', '2054', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20043, to_date('15-11-2054', 'dd-mm-yyyy'), '7', '15', '319', '11', '2054', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20044, to_date('16-11-2054', 'dd-mm-yyyy'), '1', '16', '320', '11', '2054', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20045, to_date('17-11-2054', 'dd-mm-yyyy'), '2', '17', '321', '11', '2054', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20046, to_date('18-11-2054', 'dd-mm-yyyy'), '3', '18', '322', '11', '2054', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20047, to_date('19-11-2054', 'dd-mm-yyyy'), '4', '19', '323', '11', '2054', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20048, to_date('20-11-2054', 'dd-mm-yyyy'), '5', '20', '324', '11', '2054', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20049, to_date('21-11-2054', 'dd-mm-yyyy'), '6', '21', '325', '11', '2054', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20050, to_date('22-11-2054', 'dd-mm-yyyy'), '7', '22', '326', '11', '2054', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20051, to_date('23-11-2054', 'dd-mm-yyyy'), '1', '23', '327', '11', '2054', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20052, to_date('24-11-2054', 'dd-mm-yyyy'), '2', '24', '328', '11', '2054', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20053, to_date('25-11-2054', 'dd-mm-yyyy'), '3', '25', '329', '11', '2054', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20054, to_date('26-11-2054', 'dd-mm-yyyy'), '4', '26', '330', '11', '2054', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20055, to_date('27-11-2054', 'dd-mm-yyyy'), '5', '27', '331', '11', '2054', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20056, to_date('28-11-2054', 'dd-mm-yyyy'), '6', '28', '332', '11', '2054', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20057, to_date('29-11-2054', 'dd-mm-yyyy'), '7', '29', '333', '11', '2054', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20058, to_date('30-11-2054', 'dd-mm-yyyy'), '1', '30', '334', '11', '2054', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20059, to_date('01-12-2054', 'dd-mm-yyyy'), '2', '01', '335', '12', '2054', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20060, to_date('02-12-2054', 'dd-mm-yyyy'), '3', '02', '336', '12', '2054', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20061, to_date('03-12-2054', 'dd-mm-yyyy'), '4', '03', '337', '12', '2054', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20062, to_date('04-12-2054', 'dd-mm-yyyy'), '5', '04', '338', '12', '2054', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20063, to_date('05-12-2054', 'dd-mm-yyyy'), '6', '05', '339', '12', '2054', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20064, to_date('06-12-2054', 'dd-mm-yyyy'), '7', '06', '340', '12', '2054', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20065, to_date('07-12-2054', 'dd-mm-yyyy'), '1', '07', '341', '12', '2054', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20066, to_date('08-12-2054', 'dd-mm-yyyy'), '2', '08', '342', '12', '2054', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20067, to_date('09-12-2054', 'dd-mm-yyyy'), '3', '09', '343', '12', '2054', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20068, to_date('10-12-2054', 'dd-mm-yyyy'), '4', '10', '344', '12', '2054', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20069, to_date('11-12-2054', 'dd-mm-yyyy'), '5', '11', '345', '12', '2054', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20070, to_date('12-12-2054', 'dd-mm-yyyy'), '6', '12', '346', '12', '2054', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20071, to_date('13-12-2054', 'dd-mm-yyyy'), '7', '13', '347', '12', '2054', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20072, to_date('14-12-2054', 'dd-mm-yyyy'), '1', '14', '348', '12', '2054', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20073, to_date('15-12-2054', 'dd-mm-yyyy'), '2', '15', '349', '12', '2054', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20074, to_date('16-12-2054', 'dd-mm-yyyy'), '3', '16', '350', '12', '2054', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20075, to_date('17-12-2054', 'dd-mm-yyyy'), '4', '17', '351', '12', '2054', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20076, to_date('18-12-2054', 'dd-mm-yyyy'), '5', '18', '352', '12', '2054', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20077, to_date('19-12-2054', 'dd-mm-yyyy'), '6', '19', '353', '12', '2054', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20078, to_date('20-12-2054', 'dd-mm-yyyy'), '7', '20', '354', '12', '2054', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20079, to_date('21-12-2054', 'dd-mm-yyyy'), '1', '21', '355', '12', '2054', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20080, to_date('22-12-2054', 'dd-mm-yyyy'), '2', '22', '356', '12', '2054', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20081, to_date('23-12-2054', 'dd-mm-yyyy'), '3', '23', '357', '12', '2054', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20082, to_date('24-12-2054', 'dd-mm-yyyy'), '4', '24', '358', '12', '2054', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20083, to_date('25-12-2054', 'dd-mm-yyyy'), '5', '25', '359', '12', '2054', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20084, to_date('26-12-2054', 'dd-mm-yyyy'), '6', '26', '360', '12', '2054', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20085, to_date('27-12-2054', 'dd-mm-yyyy'), '7', '27', '361', '12', '2054', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20086, to_date('28-12-2054', 'dd-mm-yyyy'), '1', '28', '362', '12', '2054', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20087, to_date('29-12-2054', 'dd-mm-yyyy'), '2', '29', '363', '12', '2054', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20088, to_date('30-12-2054', 'dd-mm-yyyy'), '3', '30', '364', '12', '2054', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20089, to_date('31-12-2054', 'dd-mm-yyyy'), '4', '31', '365', '12', '2054', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20090, to_date('01-01-2055', 'dd-mm-yyyy'), '5', '01', '001', '01', '2055', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20091, to_date('02-01-2055', 'dd-mm-yyyy'), '6', '02', '002', '01', '2055', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20092, to_date('03-01-2055', 'dd-mm-yyyy'), '7', '03', '003', '01', '2055', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20093, to_date('04-01-2055', 'dd-mm-yyyy'), '1', '04', '004', '01', '2055', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20094, to_date('05-01-2055', 'dd-mm-yyyy'), '2', '05', '005', '01', '2055', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20095, to_date('06-01-2055', 'dd-mm-yyyy'), '3', '06', '006', '01', '2055', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20096, to_date('07-01-2055', 'dd-mm-yyyy'), '4', '07', '007', '01', '2055', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20097, to_date('08-01-2055', 'dd-mm-yyyy'), '5', '08', '008', '01', '2055', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20098, to_date('09-01-2055', 'dd-mm-yyyy'), '6', '09', '009', '01', '2055', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20099, to_date('10-01-2055', 'dd-mm-yyyy'), '7', '10', '010', '01', '2055', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20100, to_date('11-01-2055', 'dd-mm-yyyy'), '1', '11', '011', '01', '2055', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20101, to_date('12-01-2055', 'dd-mm-yyyy'), '2', '12', '012', '01', '2055', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20102, to_date('13-01-2055', 'dd-mm-yyyy'), '3', '13', '013', '01', '2055', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20103, to_date('14-01-2055', 'dd-mm-yyyy'), '4', '14', '014', '01', '2055', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20104, to_date('15-01-2055', 'dd-mm-yyyy'), '5', '15', '015', '01', '2055', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20105, to_date('16-01-2055', 'dd-mm-yyyy'), '6', '16', '016', '01', '2055', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20106, to_date('17-01-2055', 'dd-mm-yyyy'), '7', '17', '017', '01', '2055', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20107, to_date('18-01-2055', 'dd-mm-yyyy'), '1', '18', '018', '01', '2055', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20108, to_date('19-01-2055', 'dd-mm-yyyy'), '2', '19', '019', '01', '2055', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20109, to_date('20-01-2055', 'dd-mm-yyyy'), '3', '20', '020', '01', '2055', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20110, to_date('21-01-2055', 'dd-mm-yyyy'), '4', '21', '021', '01', '2055', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20111, to_date('22-01-2055', 'dd-mm-yyyy'), '5', '22', '022', '01', '2055', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20112, to_date('23-01-2055', 'dd-mm-yyyy'), '6', '23', '023', '01', '2055', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20113, to_date('24-01-2055', 'dd-mm-yyyy'), '7', '24', '024', '01', '2055', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20114, to_date('25-01-2055', 'dd-mm-yyyy'), '1', '25', '025', '01', '2055', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21599, to_date('18-02-2059', 'dd-mm-yyyy'), '2', '18', '049', '02', '2059', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21600, to_date('19-02-2059', 'dd-mm-yyyy'), '3', '19', '050', '02', '2059', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21601, to_date('20-02-2059', 'dd-mm-yyyy'), '4', '20', '051', '02', '2059', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21602, to_date('21-02-2059', 'dd-mm-yyyy'), '5', '21', '052', '02', '2059', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21603, to_date('22-02-2059', 'dd-mm-yyyy'), '6', '22', '053', '02', '2059', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21604, to_date('23-02-2059', 'dd-mm-yyyy'), '7', '23', '054', '02', '2059', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21605, to_date('24-02-2059', 'dd-mm-yyyy'), '1', '24', '055', '02', '2059', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21606, to_date('25-02-2059', 'dd-mm-yyyy'), '2', '25', '056', '02', '2059', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21607, to_date('26-02-2059', 'dd-mm-yyyy'), '3', '26', '057', '02', '2059', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21608, to_date('27-02-2059', 'dd-mm-yyyy'), '4', '27', '058', '02', '2059', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21609, to_date('28-02-2059', 'dd-mm-yyyy'), '5', '28', '059', '02', '2059', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21610, to_date('01-03-2059', 'dd-mm-yyyy'), '6', '01', '060', '03', '2059', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21611, to_date('02-03-2059', 'dd-mm-yyyy'), '7', '02', '061', '03', '2059', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21612, to_date('03-03-2059', 'dd-mm-yyyy'), '1', '03', '062', '03', '2059', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21613, to_date('04-03-2059', 'dd-mm-yyyy'), '2', '04', '063', '03', '2059', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21614, to_date('05-03-2059', 'dd-mm-yyyy'), '3', '05', '064', '03', '2059', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21615, to_date('06-03-2059', 'dd-mm-yyyy'), '4', '06', '065', '03', '2059', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21616, to_date('07-03-2059', 'dd-mm-yyyy'), '5', '07', '066', '03', '2059', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21617, to_date('08-03-2059', 'dd-mm-yyyy'), '6', '08', '067', '03', '2059', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21618, to_date('09-03-2059', 'dd-mm-yyyy'), '7', '09', '068', '03', '2059', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21619, to_date('10-03-2059', 'dd-mm-yyyy'), '1', '10', '069', '03', '2059', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21620, to_date('11-03-2059', 'dd-mm-yyyy'), '2', '11', '070', '03', '2059', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21621, to_date('12-03-2059', 'dd-mm-yyyy'), '3', '12', '071', '03', '2059', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21622, to_date('13-03-2059', 'dd-mm-yyyy'), '4', '13', '072', '03', '2059', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21623, to_date('14-03-2059', 'dd-mm-yyyy'), '5', '14', '073', '03', '2059', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21624, to_date('15-03-2059', 'dd-mm-yyyy'), '6', '15', '074', '03', '2059', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21625, to_date('16-03-2059', 'dd-mm-yyyy'), '7', '16', '075', '03', '2059', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21626, to_date('17-03-2059', 'dd-mm-yyyy'), '1', '17', '076', '03', '2059', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21627, to_date('18-03-2059', 'dd-mm-yyyy'), '2', '18', '077', '03', '2059', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21628, to_date('19-03-2059', 'dd-mm-yyyy'), '3', '19', '078', '03', '2059', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21629, to_date('20-03-2059', 'dd-mm-yyyy'), '4', '20', '079', '03', '2059', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21630, to_date('21-03-2059', 'dd-mm-yyyy'), '5', '21', '080', '03', '2059', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21631, to_date('22-03-2059', 'dd-mm-yyyy'), '6', '22', '081', '03', '2059', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21632, to_date('23-03-2059', 'dd-mm-yyyy'), '7', '23', '082', '03', '2059', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21633, to_date('24-03-2059', 'dd-mm-yyyy'), '1', '24', '083', '03', '2059', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21634, to_date('25-03-2059', 'dd-mm-yyyy'), '2', '25', '084', '03', '2059', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21635, to_date('26-03-2059', 'dd-mm-yyyy'), '3', '26', '085', '03', '2059', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21636, to_date('27-03-2059', 'dd-mm-yyyy'), '4', '27', '086', '03', '2059', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21637, to_date('28-03-2059', 'dd-mm-yyyy'), '5', '28', '087', '03', '2059', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21638, to_date('29-03-2059', 'dd-mm-yyyy'), '6', '29', '088', '03', '2059', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21639, to_date('30-03-2059', 'dd-mm-yyyy'), '7', '30', '089', '03', '2059', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21640, to_date('31-03-2059', 'dd-mm-yyyy'), '1', '31', '090', '03', '2059', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21641, to_date('01-04-2059', 'dd-mm-yyyy'), '2', '01', '091', '04', '2059', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21642, to_date('02-04-2059', 'dd-mm-yyyy'), '3', '02', '092', '04', '2059', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21643, to_date('03-04-2059', 'dd-mm-yyyy'), '4', '03', '093', '04', '2059', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21644, to_date('04-04-2059', 'dd-mm-yyyy'), '5', '04', '094', '04', '2059', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21645, to_date('05-04-2059', 'dd-mm-yyyy'), '6', '05', '095', '04', '2059', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21646, to_date('06-04-2059', 'dd-mm-yyyy'), '7', '06', '096', '04', '2059', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21647, to_date('07-04-2059', 'dd-mm-yyyy'), '1', '07', '097', '04', '2059', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21648, to_date('08-04-2059', 'dd-mm-yyyy'), '2', '08', '098', '04', '2059', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21649, to_date('09-04-2059', 'dd-mm-yyyy'), '3', '09', '099', '04', '2059', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21650, to_date('10-04-2059', 'dd-mm-yyyy'), '4', '10', '100', '04', '2059', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21651, to_date('11-04-2059', 'dd-mm-yyyy'), '5', '11', '101', '04', '2059', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21652, to_date('12-04-2059', 'dd-mm-yyyy'), '6', '12', '102', '04', '2059', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21653, to_date('13-04-2059', 'dd-mm-yyyy'), '7', '13', '103', '04', '2059', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21654, to_date('14-04-2059', 'dd-mm-yyyy'), '1', '14', '104', '04', '2059', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21655, to_date('15-04-2059', 'dd-mm-yyyy'), '2', '15', '105', '04', '2059', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21656, to_date('16-04-2059', 'dd-mm-yyyy'), '3', '16', '106', '04', '2059', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21657, to_date('17-04-2059', 'dd-mm-yyyy'), '4', '17', '107', '04', '2059', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21658, to_date('18-04-2059', 'dd-mm-yyyy'), '5', '18', '108', '04', '2059', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21659, to_date('19-04-2059', 'dd-mm-yyyy'), '6', '19', '109', '04', '2059', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21660, to_date('20-04-2059', 'dd-mm-yyyy'), '7', '20', '110', '04', '2059', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21661, to_date('21-04-2059', 'dd-mm-yyyy'), '1', '21', '111', '04', '2059', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21662, to_date('22-04-2059', 'dd-mm-yyyy'), '2', '22', '112', '04', '2059', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21663, to_date('23-04-2059', 'dd-mm-yyyy'), '3', '23', '113', '04', '2059', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21664, to_date('24-04-2059', 'dd-mm-yyyy'), '4', '24', '114', '04', '2059', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21665, to_date('25-04-2059', 'dd-mm-yyyy'), '5', '25', '115', '04', '2059', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21666, to_date('26-04-2059', 'dd-mm-yyyy'), '6', '26', '116', '04', '2059', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21667, to_date('27-04-2059', 'dd-mm-yyyy'), '7', '27', '117', '04', '2059', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21668, to_date('28-04-2059', 'dd-mm-yyyy'), '1', '28', '118', '04', '2059', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21669, to_date('29-04-2059', 'dd-mm-yyyy'), '2', '29', '119', '04', '2059', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21670, to_date('30-04-2059', 'dd-mm-yyyy'), '3', '30', '120', '04', '2059', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21671, to_date('01-05-2059', 'dd-mm-yyyy'), '4', '01', '121', '05', '2059', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21672, to_date('02-05-2059', 'dd-mm-yyyy'), '5', '02', '122', '05', '2059', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21673, to_date('03-05-2059', 'dd-mm-yyyy'), '6', '03', '123', '05', '2059', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21674, to_date('04-05-2059', 'dd-mm-yyyy'), '7', '04', '124', '05', '2059', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21675, to_date('05-05-2059', 'dd-mm-yyyy'), '1', '05', '125', '05', '2059', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21676, to_date('06-05-2059', 'dd-mm-yyyy'), '2', '06', '126', '05', '2059', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21677, to_date('07-05-2059', 'dd-mm-yyyy'), '3', '07', '127', '05', '2059', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21678, to_date('08-05-2059', 'dd-mm-yyyy'), '4', '08', '128', '05', '2059', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21679, to_date('09-05-2059', 'dd-mm-yyyy'), '5', '09', '129', '05', '2059', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21680, to_date('10-05-2059', 'dd-mm-yyyy'), '6', '10', '130', '05', '2059', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21681, to_date('11-05-2059', 'dd-mm-yyyy'), '7', '11', '131', '05', '2059', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21682, to_date('12-05-2059', 'dd-mm-yyyy'), '1', '12', '132', '05', '2059', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21683, to_date('13-05-2059', 'dd-mm-yyyy'), '2', '13', '133', '05', '2059', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21684, to_date('14-05-2059', 'dd-mm-yyyy'), '3', '14', '134', '05', '2059', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21685, to_date('15-05-2059', 'dd-mm-yyyy'), '4', '15', '135', '05', '2059', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21686, to_date('16-05-2059', 'dd-mm-yyyy'), '5', '16', '136', '05', '2059', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21687, to_date('17-05-2059', 'dd-mm-yyyy'), '6', '17', '137', '05', '2059', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21688, to_date('18-05-2059', 'dd-mm-yyyy'), '7', '18', '138', '05', '2059', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21689, to_date('19-05-2059', 'dd-mm-yyyy'), '1', '19', '139', '05', '2059', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21690, to_date('20-05-2059', 'dd-mm-yyyy'), '2', '20', '140', '05', '2059', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21691, to_date('21-05-2059', 'dd-mm-yyyy'), '3', '21', '141', '05', '2059', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21692, to_date('22-05-2059', 'dd-mm-yyyy'), '4', '22', '142', '05', '2059', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21693, to_date('23-05-2059', 'dd-mm-yyyy'), '5', '23', '143', '05', '2059', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21694, to_date('24-05-2059', 'dd-mm-yyyy'), '6', '24', '144', '05', '2059', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21695, to_date('25-05-2059', 'dd-mm-yyyy'), '7', '25', '145', '05', '2059', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21696, to_date('26-05-2059', 'dd-mm-yyyy'), '1', '26', '146', '05', '2059', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21697, to_date('27-05-2059', 'dd-mm-yyyy'), '2', '27', '147', '05', '2059', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21698, to_date('28-05-2059', 'dd-mm-yyyy'), '3', '28', '148', '05', '2059', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21699, to_date('29-05-2059', 'dd-mm-yyyy'), '4', '29', '149', '05', '2059', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21700, to_date('30-05-2059', 'dd-mm-yyyy'), '5', '30', '150', '05', '2059', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21701, to_date('31-05-2059', 'dd-mm-yyyy'), '6', '31', '151', '05', '2059', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21702, to_date('01-06-2059', 'dd-mm-yyyy'), '7', '01', '152', '06', '2059', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21703, to_date('02-06-2059', 'dd-mm-yyyy'), '1', '02', '153', '06', '2059', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21704, to_date('03-06-2059', 'dd-mm-yyyy'), '2', '03', '154', '06', '2059', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23189, to_date('27-06-2063', 'dd-mm-yyyy'), '3', '27', '178', '06', '2063', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23190, to_date('28-06-2063', 'dd-mm-yyyy'), '4', '28', '179', '06', '2063', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23191, to_date('29-06-2063', 'dd-mm-yyyy'), '5', '29', '180', '06', '2063', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23192, to_date('30-06-2063', 'dd-mm-yyyy'), '6', '30', '181', '06', '2063', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23193, to_date('01-07-2063', 'dd-mm-yyyy'), '7', '01', '182', '07', '2063', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23194, to_date('02-07-2063', 'dd-mm-yyyy'), '1', '02', '183', '07', '2063', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23195, to_date('03-07-2063', 'dd-mm-yyyy'), '2', '03', '184', '07', '2063', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23196, to_date('04-07-2063', 'dd-mm-yyyy'), '3', '04', '185', '07', '2063', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23197, to_date('05-07-2063', 'dd-mm-yyyy'), '4', '05', '186', '07', '2063', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23198, to_date('06-07-2063', 'dd-mm-yyyy'), '5', '06', '187', '07', '2063', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23199, to_date('07-07-2063', 'dd-mm-yyyy'), '6', '07', '188', '07', '2063', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23200, to_date('08-07-2063', 'dd-mm-yyyy'), '7', '08', '189', '07', '2063', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23201, to_date('09-07-2063', 'dd-mm-yyyy'), '1', '09', '190', '07', '2063', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23202, to_date('10-07-2063', 'dd-mm-yyyy'), '2', '10', '191', '07', '2063', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23203, to_date('11-07-2063', 'dd-mm-yyyy'), '3', '11', '192', '07', '2063', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23204, to_date('12-07-2063', 'dd-mm-yyyy'), '4', '12', '193', '07', '2063', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23205, to_date('13-07-2063', 'dd-mm-yyyy'), '5', '13', '194', '07', '2063', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23206, to_date('14-07-2063', 'dd-mm-yyyy'), '6', '14', '195', '07', '2063', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23207, to_date('15-07-2063', 'dd-mm-yyyy'), '7', '15', '196', '07', '2063', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23208, to_date('16-07-2063', 'dd-mm-yyyy'), '1', '16', '197', '07', '2063', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23209, to_date('17-07-2063', 'dd-mm-yyyy'), '2', '17', '198', '07', '2063', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23210, to_date('18-07-2063', 'dd-mm-yyyy'), '3', '18', '199', '07', '2063', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23211, to_date('19-07-2063', 'dd-mm-yyyy'), '4', '19', '200', '07', '2063', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23212, to_date('20-07-2063', 'dd-mm-yyyy'), '5', '20', '201', '07', '2063', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23213, to_date('21-07-2063', 'dd-mm-yyyy'), '6', '21', '202', '07', '2063', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23214, to_date('22-07-2063', 'dd-mm-yyyy'), '7', '22', '203', '07', '2063', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23215, to_date('23-07-2063', 'dd-mm-yyyy'), '1', '23', '204', '07', '2063', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23216, to_date('24-07-2063', 'dd-mm-yyyy'), '2', '24', '205', '07', '2063', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23217, to_date('25-07-2063', 'dd-mm-yyyy'), '3', '25', '206', '07', '2063', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23218, to_date('26-07-2063', 'dd-mm-yyyy'), '4', '26', '207', '07', '2063', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23219, to_date('27-07-2063', 'dd-mm-yyyy'), '5', '27', '208', '07', '2063', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23220, to_date('28-07-2063', 'dd-mm-yyyy'), '6', '28', '209', '07', '2063', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23221, to_date('29-07-2063', 'dd-mm-yyyy'), '7', '29', '210', '07', '2063', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23222, to_date('30-07-2063', 'dd-mm-yyyy'), '1', '30', '211', '07', '2063', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23223, to_date('31-07-2063', 'dd-mm-yyyy'), '2', '31', '212', '07', '2063', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23224, to_date('01-08-2063', 'dd-mm-yyyy'), '3', '01', '213', '08', '2063', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23225, to_date('02-08-2063', 'dd-mm-yyyy'), '4', '02', '214', '08', '2063', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23226, to_date('03-08-2063', 'dd-mm-yyyy'), '5', '03', '215', '08', '2063', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23227, to_date('04-08-2063', 'dd-mm-yyyy'), '6', '04', '216', '08', '2063', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23228, to_date('05-08-2063', 'dd-mm-yyyy'), '7', '05', '217', '08', '2063', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23229, to_date('06-08-2063', 'dd-mm-yyyy'), '1', '06', '218', '08', '2063', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23230, to_date('07-08-2063', 'dd-mm-yyyy'), '2', '07', '219', '08', '2063', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23231, to_date('08-08-2063', 'dd-mm-yyyy'), '3', '08', '220', '08', '2063', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23232, to_date('09-08-2063', 'dd-mm-yyyy'), '4', '09', '221', '08', '2063', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23233, to_date('10-08-2063', 'dd-mm-yyyy'), '5', '10', '222', '08', '2063', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23234, to_date('11-08-2063', 'dd-mm-yyyy'), '6', '11', '223', '08', '2063', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23235, to_date('12-08-2063', 'dd-mm-yyyy'), '7', '12', '224', '08', '2063', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23236, to_date('13-08-2063', 'dd-mm-yyyy'), '1', '13', '225', '08', '2063', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23237, to_date('14-08-2063', 'dd-mm-yyyy'), '2', '14', '226', '08', '2063', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23238, to_date('15-08-2063', 'dd-mm-yyyy'), '3', '15', '227', '08', '2063', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23239, to_date('16-08-2063', 'dd-mm-yyyy'), '4', '16', '228', '08', '2063', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23240, to_date('17-08-2063', 'dd-mm-yyyy'), '5', '17', '229', '08', '2063', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23241, to_date('18-08-2063', 'dd-mm-yyyy'), '6', '18', '230', '08', '2063', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23242, to_date('19-08-2063', 'dd-mm-yyyy'), '7', '19', '231', '08', '2063', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23243, to_date('20-08-2063', 'dd-mm-yyyy'), '1', '20', '232', '08', '2063', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23244, to_date('21-08-2063', 'dd-mm-yyyy'), '2', '21', '233', '08', '2063', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23245, to_date('22-08-2063', 'dd-mm-yyyy'), '3', '22', '234', '08', '2063', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23246, to_date('23-08-2063', 'dd-mm-yyyy'), '4', '23', '235', '08', '2063', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23247, to_date('24-08-2063', 'dd-mm-yyyy'), '5', '24', '236', '08', '2063', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23248, to_date('25-08-2063', 'dd-mm-yyyy'), '6', '25', '237', '08', '2063', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23249, to_date('26-08-2063', 'dd-mm-yyyy'), '7', '26', '238', '08', '2063', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23250, to_date('27-08-2063', 'dd-mm-yyyy'), '1', '27', '239', '08', '2063', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23251, to_date('28-08-2063', 'dd-mm-yyyy'), '2', '28', '240', '08', '2063', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23252, to_date('29-08-2063', 'dd-mm-yyyy'), '3', '29', '241', '08', '2063', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23253, to_date('30-08-2063', 'dd-mm-yyyy'), '4', '30', '242', '08', '2063', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23254, to_date('31-08-2063', 'dd-mm-yyyy'), '5', '31', '243', '08', '2063', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23255, to_date('01-09-2063', 'dd-mm-yyyy'), '6', '01', '244', '09', '2063', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23256, to_date('02-09-2063', 'dd-mm-yyyy'), '7', '02', '245', '09', '2063', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23257, to_date('03-09-2063', 'dd-mm-yyyy'), '1', '03', '246', '09', '2063', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23258, to_date('04-09-2063', 'dd-mm-yyyy'), '2', '04', '247', '09', '2063', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23259, to_date('05-09-2063', 'dd-mm-yyyy'), '3', '05', '248', '09', '2063', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23260, to_date('06-09-2063', 'dd-mm-yyyy'), '4', '06', '249', '09', '2063', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23261, to_date('07-09-2063', 'dd-mm-yyyy'), '5', '07', '250', '09', '2063', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23262, to_date('08-09-2063', 'dd-mm-yyyy'), '6', '08', '251', '09', '2063', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23263, to_date('09-09-2063', 'dd-mm-yyyy'), '7', '09', '252', '09', '2063', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23264, to_date('10-09-2063', 'dd-mm-yyyy'), '1', '10', '253', '09', '2063', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23265, to_date('11-09-2063', 'dd-mm-yyyy'), '2', '11', '254', '09', '2063', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23266, to_date('12-09-2063', 'dd-mm-yyyy'), '3', '12', '255', '09', '2063', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23267, to_date('13-09-2063', 'dd-mm-yyyy'), '4', '13', '256', '09', '2063', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23268, to_date('14-09-2063', 'dd-mm-yyyy'), '5', '14', '257', '09', '2063', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23269, to_date('15-09-2063', 'dd-mm-yyyy'), '6', '15', '258', '09', '2063', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23270, to_date('16-09-2063', 'dd-mm-yyyy'), '7', '16', '259', '09', '2063', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23271, to_date('17-09-2063', 'dd-mm-yyyy'), '1', '17', '260', '09', '2063', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23272, to_date('18-09-2063', 'dd-mm-yyyy'), '2', '18', '261', '09', '2063', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23273, to_date('19-09-2063', 'dd-mm-yyyy'), '3', '19', '262', '09', '2063', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23274, to_date('20-09-2063', 'dd-mm-yyyy'), '4', '20', '263', '09', '2063', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23275, to_date('21-09-2063', 'dd-mm-yyyy'), '5', '21', '264', '09', '2063', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23276, to_date('22-09-2063', 'dd-mm-yyyy'), '6', '22', '265', '09', '2063', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23277, to_date('23-09-2063', 'dd-mm-yyyy'), '7', '23', '266', '09', '2063', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23278, to_date('24-09-2063', 'dd-mm-yyyy'), '1', '24', '267', '09', '2063', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23279, to_date('25-09-2063', 'dd-mm-yyyy'), '2', '25', '268', '09', '2063', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23280, to_date('26-09-2063', 'dd-mm-yyyy'), '3', '26', '269', '09', '2063', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23281, to_date('27-09-2063', 'dd-mm-yyyy'), '4', '27', '270', '09', '2063', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23282, to_date('28-09-2063', 'dd-mm-yyyy'), '5', '28', '271', '09', '2063', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23283, to_date('29-09-2063', 'dd-mm-yyyy'), '6', '29', '272', '09', '2063', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23284, to_date('30-09-2063', 'dd-mm-yyyy'), '7', '30', '273', '09', '2063', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23285, to_date('01-10-2063', 'dd-mm-yyyy'), '1', '01', '274', '10', '2063', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23286, to_date('02-10-2063', 'dd-mm-yyyy'), '2', '02', '275', '10', '2063', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23287, to_date('03-10-2063', 'dd-mm-yyyy'), '3', '03', '276', '10', '2063', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23288, to_date('04-10-2063', 'dd-mm-yyyy'), '4', '04', '277', '10', '2063', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23289, to_date('05-10-2063', 'dd-mm-yyyy'), '5', '05', '278', '10', '2063', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23290, to_date('06-10-2063', 'dd-mm-yyyy'), '6', '06', '279', '10', '2063', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23291, to_date('07-10-2063', 'dd-mm-yyyy'), '7', '07', '280', '10', '2063', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23292, to_date('08-10-2063', 'dd-mm-yyyy'), '1', '08', '281', '10', '2063', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23293, to_date('09-10-2063', 'dd-mm-yyyy'), '2', '09', '282', '10', '2063', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23294, to_date('10-10-2063', 'dd-mm-yyyy'), '3', '10', '283', '10', '2063', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24779, to_date('03-11-2067', 'dd-mm-yyyy'), '4', '03', '307', '11', '2067', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24780, to_date('04-11-2067', 'dd-mm-yyyy'), '5', '04', '308', '11', '2067', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24781, to_date('05-11-2067', 'dd-mm-yyyy'), '6', '05', '309', '11', '2067', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24782, to_date('06-11-2067', 'dd-mm-yyyy'), '7', '06', '310', '11', '2067', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24783, to_date('07-11-2067', 'dd-mm-yyyy'), '1', '07', '311', '11', '2067', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24784, to_date('08-11-2067', 'dd-mm-yyyy'), '2', '08', '312', '11', '2067', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24785, to_date('09-11-2067', 'dd-mm-yyyy'), '3', '09', '313', '11', '2067', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24786, to_date('10-11-2067', 'dd-mm-yyyy'), '4', '10', '314', '11', '2067', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24787, to_date('11-11-2067', 'dd-mm-yyyy'), '5', '11', '315', '11', '2067', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24788, to_date('12-11-2067', 'dd-mm-yyyy'), '6', '12', '316', '11', '2067', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24789, to_date('13-11-2067', 'dd-mm-yyyy'), '7', '13', '317', '11', '2067', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24790, to_date('14-11-2067', 'dd-mm-yyyy'), '1', '14', '318', '11', '2067', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24791, to_date('15-11-2067', 'dd-mm-yyyy'), '2', '15', '319', '11', '2067', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24792, to_date('16-11-2067', 'dd-mm-yyyy'), '3', '16', '320', '11', '2067', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24793, to_date('17-11-2067', 'dd-mm-yyyy'), '4', '17', '321', '11', '2067', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24794, to_date('18-11-2067', 'dd-mm-yyyy'), '5', '18', '322', '11', '2067', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24795, to_date('19-11-2067', 'dd-mm-yyyy'), '6', '19', '323', '11', '2067', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24796, to_date('20-11-2067', 'dd-mm-yyyy'), '7', '20', '324', '11', '2067', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24797, to_date('21-11-2067', 'dd-mm-yyyy'), '1', '21', '325', '11', '2067', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24798, to_date('22-11-2067', 'dd-mm-yyyy'), '2', '22', '326', '11', '2067', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24799, to_date('23-11-2067', 'dd-mm-yyyy'), '3', '23', '327', '11', '2067', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24800, to_date('24-11-2067', 'dd-mm-yyyy'), '4', '24', '328', '11', '2067', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24801, to_date('25-11-2067', 'dd-mm-yyyy'), '5', '25', '329', '11', '2067', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24802, to_date('26-11-2067', 'dd-mm-yyyy'), '6', '26', '330', '11', '2067', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24803, to_date('27-11-2067', 'dd-mm-yyyy'), '7', '27', '331', '11', '2067', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24804, to_date('28-11-2067', 'dd-mm-yyyy'), '1', '28', '332', '11', '2067', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24805, to_date('29-11-2067', 'dd-mm-yyyy'), '2', '29', '333', '11', '2067', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24806, to_date('30-11-2067', 'dd-mm-yyyy'), '3', '30', '334', '11', '2067', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24807, to_date('01-12-2067', 'dd-mm-yyyy'), '4', '01', '335', '12', '2067', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24808, to_date('02-12-2067', 'dd-mm-yyyy'), '5', '02', '336', '12', '2067', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24809, to_date('03-12-2067', 'dd-mm-yyyy'), '6', '03', '337', '12', '2067', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24810, to_date('04-12-2067', 'dd-mm-yyyy'), '7', '04', '338', '12', '2067', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24811, to_date('05-12-2067', 'dd-mm-yyyy'), '1', '05', '339', '12', '2067', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24812, to_date('06-12-2067', 'dd-mm-yyyy'), '2', '06', '340', '12', '2067', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24813, to_date('07-12-2067', 'dd-mm-yyyy'), '3', '07', '341', '12', '2067', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24814, to_date('08-12-2067', 'dd-mm-yyyy'), '4', '08', '342', '12', '2067', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24815, to_date('09-12-2067', 'dd-mm-yyyy'), '5', '09', '343', '12', '2067', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24816, to_date('10-12-2067', 'dd-mm-yyyy'), '6', '10', '344', '12', '2067', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24817, to_date('11-12-2067', 'dd-mm-yyyy'), '7', '11', '345', '12', '2067', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24818, to_date('12-12-2067', 'dd-mm-yyyy'), '1', '12', '346', '12', '2067', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24819, to_date('13-12-2067', 'dd-mm-yyyy'), '2', '13', '347', '12', '2067', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24820, to_date('14-12-2067', 'dd-mm-yyyy'), '3', '14', '348', '12', '2067', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24821, to_date('15-12-2067', 'dd-mm-yyyy'), '4', '15', '349', '12', '2067', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24822, to_date('16-12-2067', 'dd-mm-yyyy'), '5', '16', '350', '12', '2067', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24823, to_date('17-12-2067', 'dd-mm-yyyy'), '6', '17', '351', '12', '2067', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24824, to_date('18-12-2067', 'dd-mm-yyyy'), '7', '18', '352', '12', '2067', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24825, to_date('19-12-2067', 'dd-mm-yyyy'), '1', '19', '353', '12', '2067', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24826, to_date('20-12-2067', 'dd-mm-yyyy'), '2', '20', '354', '12', '2067', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24827, to_date('21-12-2067', 'dd-mm-yyyy'), '3', '21', '355', '12', '2067', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24828, to_date('22-12-2067', 'dd-mm-yyyy'), '4', '22', '356', '12', '2067', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24829, to_date('23-12-2067', 'dd-mm-yyyy'), '5', '23', '357', '12', '2067', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24830, to_date('24-12-2067', 'dd-mm-yyyy'), '6', '24', '358', '12', '2067', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24831, to_date('25-12-2067', 'dd-mm-yyyy'), '7', '25', '359', '12', '2067', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24832, to_date('26-12-2067', 'dd-mm-yyyy'), '1', '26', '360', '12', '2067', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24833, to_date('27-12-2067', 'dd-mm-yyyy'), '2', '27', '361', '12', '2067', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24834, to_date('28-12-2067', 'dd-mm-yyyy'), '3', '28', '362', '12', '2067', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24835, to_date('29-12-2067', 'dd-mm-yyyy'), '4', '29', '363', '12', '2067', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24836, to_date('30-12-2067', 'dd-mm-yyyy'), '5', '30', '364', '12', '2067', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24837, to_date('31-12-2067', 'dd-mm-yyyy'), '6', '31', '365', '12', '2067', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24838, to_date('01-01-2068', 'dd-mm-yyyy'), '7', '01', '001', '01', '2068', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24839, to_date('02-01-2068', 'dd-mm-yyyy'), '1', '02', '002', '01', '2068', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24840, to_date('03-01-2068', 'dd-mm-yyyy'), '2', '03', '003', '01', '2068', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24841, to_date('04-01-2068', 'dd-mm-yyyy'), '3', '04', '004', '01', '2068', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24842, to_date('05-01-2068', 'dd-mm-yyyy'), '4', '05', '005', '01', '2068', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24843, to_date('06-01-2068', 'dd-mm-yyyy'), '5', '06', '006', '01', '2068', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24844, to_date('07-01-2068', 'dd-mm-yyyy'), '6', '07', '007', '01', '2068', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24845, to_date('08-01-2068', 'dd-mm-yyyy'), '7', '08', '008', '01', '2068', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24846, to_date('09-01-2068', 'dd-mm-yyyy'), '1', '09', '009', '01', '2068', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24847, to_date('10-01-2068', 'dd-mm-yyyy'), '2', '10', '010', '01', '2068', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24848, to_date('11-01-2068', 'dd-mm-yyyy'), '3', '11', '011', '01', '2068', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24849, to_date('12-01-2068', 'dd-mm-yyyy'), '4', '12', '012', '01', '2068', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24850, to_date('13-01-2068', 'dd-mm-yyyy'), '5', '13', '013', '01', '2068', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24851, to_date('14-01-2068', 'dd-mm-yyyy'), '6', '14', '014', '01', '2068', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24852, to_date('15-01-2068', 'dd-mm-yyyy'), '7', '15', '015', '01', '2068', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24853, to_date('16-01-2068', 'dd-mm-yyyy'), '1', '16', '016', '01', '2068', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24854, to_date('17-01-2068', 'dd-mm-yyyy'), '2', '17', '017', '01', '2068', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24855, to_date('18-01-2068', 'dd-mm-yyyy'), '3', '18', '018', '01', '2068', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24856, to_date('19-01-2068', 'dd-mm-yyyy'), '4', '19', '019', '01', '2068', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24857, to_date('20-01-2068', 'dd-mm-yyyy'), '5', '20', '020', '01', '2068', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24858, to_date('21-01-2068', 'dd-mm-yyyy'), '6', '21', '021', '01', '2068', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24859, to_date('22-01-2068', 'dd-mm-yyyy'), '7', '22', '022', '01', '2068', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24860, to_date('23-01-2068', 'dd-mm-yyyy'), '1', '23', '023', '01', '2068', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24861, to_date('24-01-2068', 'dd-mm-yyyy'), '2', '24', '024', '01', '2068', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24862, to_date('25-01-2068', 'dd-mm-yyyy'), '3', '25', '025', '01', '2068', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24863, to_date('26-01-2068', 'dd-mm-yyyy'), '4', '26', '026', '01', '2068', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24864, to_date('27-01-2068', 'dd-mm-yyyy'), '5', '27', '027', '01', '2068', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24865, to_date('28-01-2068', 'dd-mm-yyyy'), '6', '28', '028', '01', '2068', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24866, to_date('29-01-2068', 'dd-mm-yyyy'), '7', '29', '029', '01', '2068', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24867, to_date('30-01-2068', 'dd-mm-yyyy'), '1', '30', '030', '01', '2068', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24868, to_date('31-01-2068', 'dd-mm-yyyy'), '2', '31', '031', '01', '2068', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24869, to_date('01-02-2068', 'dd-mm-yyyy'), '3', '01', '032', '02', '2068', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24870, to_date('02-02-2068', 'dd-mm-yyyy'), '4', '02', '033', '02', '2068', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24871, to_date('03-02-2068', 'dd-mm-yyyy'), '5', '03', '034', '02', '2068', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24872, to_date('04-02-2068', 'dd-mm-yyyy'), '6', '04', '035', '02', '2068', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24873, to_date('05-02-2068', 'dd-mm-yyyy'), '7', '05', '036', '02', '2068', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24874, to_date('06-02-2068', 'dd-mm-yyyy'), '1', '06', '037', '02', '2068', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24875, to_date('07-02-2068', 'dd-mm-yyyy'), '2', '07', '038', '02', '2068', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24876, to_date('08-02-2068', 'dd-mm-yyyy'), '3', '08', '039', '02', '2068', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24877, to_date('09-02-2068', 'dd-mm-yyyy'), '4', '09', '040', '02', '2068', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24878, to_date('10-02-2068', 'dd-mm-yyyy'), '5', '10', '041', '02', '2068', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24879, to_date('11-02-2068', 'dd-mm-yyyy'), '6', '11', '042', '02', '2068', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24880, to_date('12-02-2068', 'dd-mm-yyyy'), '7', '12', '043', '02', '2068', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24881, to_date('13-02-2068', 'dd-mm-yyyy'), '1', '13', '044', '02', '2068', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24882, to_date('14-02-2068', 'dd-mm-yyyy'), '2', '14', '045', '02', '2068', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24883, to_date('15-02-2068', 'dd-mm-yyyy'), '3', '15', '046', '02', '2068', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24884, to_date('16-02-2068', 'dd-mm-yyyy'), '4', '16', '047', '02', '2068', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20115, to_date('26-01-2055', 'dd-mm-yyyy'), '2', '26', '026', '01', '2055', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20116, to_date('27-01-2055', 'dd-mm-yyyy'), '3', '27', '027', '01', '2055', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20117, to_date('28-01-2055', 'dd-mm-yyyy'), '4', '28', '028', '01', '2055', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20118, to_date('29-01-2055', 'dd-mm-yyyy'), '5', '29', '029', '01', '2055', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20119, to_date('30-01-2055', 'dd-mm-yyyy'), '6', '30', '030', '01', '2055', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20120, to_date('31-01-2055', 'dd-mm-yyyy'), '7', '31', '031', '01', '2055', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20121, to_date('01-02-2055', 'dd-mm-yyyy'), '1', '01', '032', '02', '2055', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20122, to_date('02-02-2055', 'dd-mm-yyyy'), '2', '02', '033', '02', '2055', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20123, to_date('03-02-2055', 'dd-mm-yyyy'), '3', '03', '034', '02', '2055', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20124, to_date('04-02-2055', 'dd-mm-yyyy'), '4', '04', '035', '02', '2055', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20125, to_date('05-02-2055', 'dd-mm-yyyy'), '5', '05', '036', '02', '2055', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20126, to_date('06-02-2055', 'dd-mm-yyyy'), '6', '06', '037', '02', '2055', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20127, to_date('07-02-2055', 'dd-mm-yyyy'), '7', '07', '038', '02', '2055', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20128, to_date('08-02-2055', 'dd-mm-yyyy'), '1', '08', '039', '02', '2055', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20129, to_date('09-02-2055', 'dd-mm-yyyy'), '2', '09', '040', '02', '2055', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20130, to_date('10-02-2055', 'dd-mm-yyyy'), '3', '10', '041', '02', '2055', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20131, to_date('11-02-2055', 'dd-mm-yyyy'), '4', '11', '042', '02', '2055', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20132, to_date('12-02-2055', 'dd-mm-yyyy'), '5', '12', '043', '02', '2055', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20133, to_date('13-02-2055', 'dd-mm-yyyy'), '6', '13', '044', '02', '2055', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20134, to_date('14-02-2055', 'dd-mm-yyyy'), '7', '14', '045', '02', '2055', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
commit;
prompt 16000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20135, to_date('15-02-2055', 'dd-mm-yyyy'), '1', '15', '046', '02', '2055', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20136, to_date('16-02-2055', 'dd-mm-yyyy'), '2', '16', '047', '02', '2055', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20137, to_date('17-02-2055', 'dd-mm-yyyy'), '3', '17', '048', '02', '2055', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20138, to_date('18-02-2055', 'dd-mm-yyyy'), '4', '18', '049', '02', '2055', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20139, to_date('19-02-2055', 'dd-mm-yyyy'), '5', '19', '050', '02', '2055', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20140, to_date('20-02-2055', 'dd-mm-yyyy'), '6', '20', '051', '02', '2055', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20141, to_date('21-02-2055', 'dd-mm-yyyy'), '7', '21', '052', '02', '2055', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20142, to_date('22-02-2055', 'dd-mm-yyyy'), '1', '22', '053', '02', '2055', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20143, to_date('23-02-2055', 'dd-mm-yyyy'), '2', '23', '054', '02', '2055', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20144, to_date('24-02-2055', 'dd-mm-yyyy'), '3', '24', '055', '02', '2055', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20145, to_date('25-02-2055', 'dd-mm-yyyy'), '4', '25', '056', '02', '2055', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20146, to_date('26-02-2055', 'dd-mm-yyyy'), '5', '26', '057', '02', '2055', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20147, to_date('27-02-2055', 'dd-mm-yyyy'), '6', '27', '058', '02', '2055', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20148, to_date('28-02-2055', 'dd-mm-yyyy'), '7', '28', '059', '02', '2055', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20149, to_date('01-03-2055', 'dd-mm-yyyy'), '1', '01', '060', '03', '2055', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20150, to_date('02-03-2055', 'dd-mm-yyyy'), '2', '02', '061', '03', '2055', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20151, to_date('03-03-2055', 'dd-mm-yyyy'), '3', '03', '062', '03', '2055', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20152, to_date('04-03-2055', 'dd-mm-yyyy'), '4', '04', '063', '03', '2055', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20153, to_date('05-03-2055', 'dd-mm-yyyy'), '5', '05', '064', '03', '2055', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20154, to_date('06-03-2055', 'dd-mm-yyyy'), '6', '06', '065', '03', '2055', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20155, to_date('07-03-2055', 'dd-mm-yyyy'), '7', '07', '066', '03', '2055', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20156, to_date('08-03-2055', 'dd-mm-yyyy'), '1', '08', '067', '03', '2055', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20157, to_date('09-03-2055', 'dd-mm-yyyy'), '2', '09', '068', '03', '2055', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20158, to_date('10-03-2055', 'dd-mm-yyyy'), '3', '10', '069', '03', '2055', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20159, to_date('11-03-2055', 'dd-mm-yyyy'), '4', '11', '070', '03', '2055', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20160, to_date('12-03-2055', 'dd-mm-yyyy'), '5', '12', '071', '03', '2055', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20161, to_date('13-03-2055', 'dd-mm-yyyy'), '6', '13', '072', '03', '2055', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20162, to_date('14-03-2055', 'dd-mm-yyyy'), '7', '14', '073', '03', '2055', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20163, to_date('15-03-2055', 'dd-mm-yyyy'), '1', '15', '074', '03', '2055', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20164, to_date('16-03-2055', 'dd-mm-yyyy'), '2', '16', '075', '03', '2055', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20165, to_date('17-03-2055', 'dd-mm-yyyy'), '3', '17', '076', '03', '2055', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20166, to_date('18-03-2055', 'dd-mm-yyyy'), '4', '18', '077', '03', '2055', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20167, to_date('19-03-2055', 'dd-mm-yyyy'), '5', '19', '078', '03', '2055', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20168, to_date('20-03-2055', 'dd-mm-yyyy'), '6', '20', '079', '03', '2055', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20169, to_date('21-03-2055', 'dd-mm-yyyy'), '7', '21', '080', '03', '2055', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20170, to_date('22-03-2055', 'dd-mm-yyyy'), '1', '22', '081', '03', '2055', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20171, to_date('23-03-2055', 'dd-mm-yyyy'), '2', '23', '082', '03', '2055', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20172, to_date('24-03-2055', 'dd-mm-yyyy'), '3', '24', '083', '03', '2055', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20173, to_date('25-03-2055', 'dd-mm-yyyy'), '4', '25', '084', '03', '2055', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20174, to_date('26-03-2055', 'dd-mm-yyyy'), '5', '26', '085', '03', '2055', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20175, to_date('27-03-2055', 'dd-mm-yyyy'), '6', '27', '086', '03', '2055', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20176, to_date('28-03-2055', 'dd-mm-yyyy'), '7', '28', '087', '03', '2055', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20177, to_date('29-03-2055', 'dd-mm-yyyy'), '1', '29', '088', '03', '2055', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20178, to_date('30-03-2055', 'dd-mm-yyyy'), '2', '30', '089', '03', '2055', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20179, to_date('31-03-2055', 'dd-mm-yyyy'), '3', '31', '090', '03', '2055', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20180, to_date('01-04-2055', 'dd-mm-yyyy'), '4', '01', '091', '04', '2055', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20181, to_date('02-04-2055', 'dd-mm-yyyy'), '5', '02', '092', '04', '2055', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20182, to_date('03-04-2055', 'dd-mm-yyyy'), '6', '03', '093', '04', '2055', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20183, to_date('04-04-2055', 'dd-mm-yyyy'), '7', '04', '094', '04', '2055', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20184, to_date('05-04-2055', 'dd-mm-yyyy'), '1', '05', '095', '04', '2055', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20185, to_date('06-04-2055', 'dd-mm-yyyy'), '2', '06', '096', '04', '2055', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20186, to_date('07-04-2055', 'dd-mm-yyyy'), '3', '07', '097', '04', '2055', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20187, to_date('08-04-2055', 'dd-mm-yyyy'), '4', '08', '098', '04', '2055', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20188, to_date('09-04-2055', 'dd-mm-yyyy'), '5', '09', '099', '04', '2055', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20189, to_date('10-04-2055', 'dd-mm-yyyy'), '6', '10', '100', '04', '2055', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20190, to_date('11-04-2055', 'dd-mm-yyyy'), '7', '11', '101', '04', '2055', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20191, to_date('12-04-2055', 'dd-mm-yyyy'), '1', '12', '102', '04', '2055', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20192, to_date('13-04-2055', 'dd-mm-yyyy'), '2', '13', '103', '04', '2055', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20193, to_date('14-04-2055', 'dd-mm-yyyy'), '3', '14', '104', '04', '2055', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20194, to_date('15-04-2055', 'dd-mm-yyyy'), '4', '15', '105', '04', '2055', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20195, to_date('16-04-2055', 'dd-mm-yyyy'), '5', '16', '106', '04', '2055', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20196, to_date('17-04-2055', 'dd-mm-yyyy'), '6', '17', '107', '04', '2055', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20197, to_date('18-04-2055', 'dd-mm-yyyy'), '7', '18', '108', '04', '2055', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20198, to_date('19-04-2055', 'dd-mm-yyyy'), '1', '19', '109', '04', '2055', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20199, to_date('20-04-2055', 'dd-mm-yyyy'), '2', '20', '110', '04', '2055', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20200, to_date('21-04-2055', 'dd-mm-yyyy'), '3', '21', '111', '04', '2055', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20201, to_date('22-04-2055', 'dd-mm-yyyy'), '4', '22', '112', '04', '2055', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20202, to_date('23-04-2055', 'dd-mm-yyyy'), '5', '23', '113', '04', '2055', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20203, to_date('24-04-2055', 'dd-mm-yyyy'), '6', '24', '114', '04', '2055', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20204, to_date('25-04-2055', 'dd-mm-yyyy'), '7', '25', '115', '04', '2055', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20205, to_date('26-04-2055', 'dd-mm-yyyy'), '1', '26', '116', '04', '2055', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20206, to_date('27-04-2055', 'dd-mm-yyyy'), '2', '27', '117', '04', '2055', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20207, to_date('28-04-2055', 'dd-mm-yyyy'), '3', '28', '118', '04', '2055', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20208, to_date('29-04-2055', 'dd-mm-yyyy'), '4', '29', '119', '04', '2055', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20209, to_date('30-04-2055', 'dd-mm-yyyy'), '5', '30', '120', '04', '2055', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20210, to_date('01-05-2055', 'dd-mm-yyyy'), '6', '01', '121', '05', '2055', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20211, to_date('02-05-2055', 'dd-mm-yyyy'), '7', '02', '122', '05', '2055', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20212, to_date('03-05-2055', 'dd-mm-yyyy'), '1', '03', '123', '05', '2055', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20213, to_date('04-05-2055', 'dd-mm-yyyy'), '2', '04', '124', '05', '2055', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20214, to_date('05-05-2055', 'dd-mm-yyyy'), '3', '05', '125', '05', '2055', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20215, to_date('06-05-2055', 'dd-mm-yyyy'), '4', '06', '126', '05', '2055', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20216, to_date('07-05-2055', 'dd-mm-yyyy'), '5', '07', '127', '05', '2055', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20217, to_date('08-05-2055', 'dd-mm-yyyy'), '6', '08', '128', '05', '2055', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20218, to_date('09-05-2055', 'dd-mm-yyyy'), '7', '09', '129', '05', '2055', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20219, to_date('10-05-2055', 'dd-mm-yyyy'), '1', '10', '130', '05', '2055', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20220, to_date('11-05-2055', 'dd-mm-yyyy'), '2', '11', '131', '05', '2055', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21705, to_date('04-06-2059', 'dd-mm-yyyy'), '3', '04', '155', '06', '2059', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21706, to_date('05-06-2059', 'dd-mm-yyyy'), '4', '05', '156', '06', '2059', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21707, to_date('06-06-2059', 'dd-mm-yyyy'), '5', '06', '157', '06', '2059', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21708, to_date('07-06-2059', 'dd-mm-yyyy'), '6', '07', '158', '06', '2059', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21709, to_date('08-06-2059', 'dd-mm-yyyy'), '7', '08', '159', '06', '2059', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21710, to_date('09-06-2059', 'dd-mm-yyyy'), '1', '09', '160', '06', '2059', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21711, to_date('10-06-2059', 'dd-mm-yyyy'), '2', '10', '161', '06', '2059', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21712, to_date('11-06-2059', 'dd-mm-yyyy'), '3', '11', '162', '06', '2059', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21713, to_date('12-06-2059', 'dd-mm-yyyy'), '4', '12', '163', '06', '2059', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21714, to_date('13-06-2059', 'dd-mm-yyyy'), '5', '13', '164', '06', '2059', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21715, to_date('14-06-2059', 'dd-mm-yyyy'), '6', '14', '165', '06', '2059', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21716, to_date('15-06-2059', 'dd-mm-yyyy'), '7', '15', '166', '06', '2059', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21717, to_date('16-06-2059', 'dd-mm-yyyy'), '1', '16', '167', '06', '2059', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21718, to_date('17-06-2059', 'dd-mm-yyyy'), '2', '17', '168', '06', '2059', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21719, to_date('18-06-2059', 'dd-mm-yyyy'), '3', '18', '169', '06', '2059', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21720, to_date('19-06-2059', 'dd-mm-yyyy'), '4', '19', '170', '06', '2059', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21721, to_date('20-06-2059', 'dd-mm-yyyy'), '5', '20', '171', '06', '2059', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21722, to_date('21-06-2059', 'dd-mm-yyyy'), '6', '21', '172', '06', '2059', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21723, to_date('22-06-2059', 'dd-mm-yyyy'), '7', '22', '173', '06', '2059', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21724, to_date('23-06-2059', 'dd-mm-yyyy'), '1', '23', '174', '06', '2059', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21725, to_date('24-06-2059', 'dd-mm-yyyy'), '2', '24', '175', '06', '2059', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21726, to_date('25-06-2059', 'dd-mm-yyyy'), '3', '25', '176', '06', '2059', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21727, to_date('26-06-2059', 'dd-mm-yyyy'), '4', '26', '177', '06', '2059', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21728, to_date('27-06-2059', 'dd-mm-yyyy'), '5', '27', '178', '06', '2059', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21729, to_date('28-06-2059', 'dd-mm-yyyy'), '6', '28', '179', '06', '2059', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21730, to_date('29-06-2059', 'dd-mm-yyyy'), '7', '29', '180', '06', '2059', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21731, to_date('30-06-2059', 'dd-mm-yyyy'), '1', '30', '181', '06', '2059', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21732, to_date('01-07-2059', 'dd-mm-yyyy'), '2', '01', '182', '07', '2059', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21733, to_date('02-07-2059', 'dd-mm-yyyy'), '3', '02', '183', '07', '2059', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21734, to_date('03-07-2059', 'dd-mm-yyyy'), '4', '03', '184', '07', '2059', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21735, to_date('04-07-2059', 'dd-mm-yyyy'), '5', '04', '185', '07', '2059', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21736, to_date('05-07-2059', 'dd-mm-yyyy'), '6', '05', '186', '07', '2059', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21737, to_date('06-07-2059', 'dd-mm-yyyy'), '7', '06', '187', '07', '2059', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21738, to_date('07-07-2059', 'dd-mm-yyyy'), '1', '07', '188', '07', '2059', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21739, to_date('08-07-2059', 'dd-mm-yyyy'), '2', '08', '189', '07', '2059', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21740, to_date('09-07-2059', 'dd-mm-yyyy'), '3', '09', '190', '07', '2059', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21741, to_date('10-07-2059', 'dd-mm-yyyy'), '4', '10', '191', '07', '2059', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21742, to_date('11-07-2059', 'dd-mm-yyyy'), '5', '11', '192', '07', '2059', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21743, to_date('12-07-2059', 'dd-mm-yyyy'), '6', '12', '193', '07', '2059', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21744, to_date('13-07-2059', 'dd-mm-yyyy'), '7', '13', '194', '07', '2059', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21745, to_date('14-07-2059', 'dd-mm-yyyy'), '1', '14', '195', '07', '2059', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21746, to_date('15-07-2059', 'dd-mm-yyyy'), '2', '15', '196', '07', '2059', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21747, to_date('16-07-2059', 'dd-mm-yyyy'), '3', '16', '197', '07', '2059', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21748, to_date('17-07-2059', 'dd-mm-yyyy'), '4', '17', '198', '07', '2059', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21749, to_date('18-07-2059', 'dd-mm-yyyy'), '5', '18', '199', '07', '2059', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21750, to_date('19-07-2059', 'dd-mm-yyyy'), '6', '19', '200', '07', '2059', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21751, to_date('20-07-2059', 'dd-mm-yyyy'), '7', '20', '201', '07', '2059', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21752, to_date('21-07-2059', 'dd-mm-yyyy'), '1', '21', '202', '07', '2059', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21753, to_date('22-07-2059', 'dd-mm-yyyy'), '2', '22', '203', '07', '2059', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21754, to_date('23-07-2059', 'dd-mm-yyyy'), '3', '23', '204', '07', '2059', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21755, to_date('24-07-2059', 'dd-mm-yyyy'), '4', '24', '205', '07', '2059', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21756, to_date('25-07-2059', 'dd-mm-yyyy'), '5', '25', '206', '07', '2059', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21757, to_date('26-07-2059', 'dd-mm-yyyy'), '6', '26', '207', '07', '2059', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21758, to_date('27-07-2059', 'dd-mm-yyyy'), '7', '27', '208', '07', '2059', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21759, to_date('28-07-2059', 'dd-mm-yyyy'), '1', '28', '209', '07', '2059', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21760, to_date('29-07-2059', 'dd-mm-yyyy'), '2', '29', '210', '07', '2059', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21761, to_date('30-07-2059', 'dd-mm-yyyy'), '3', '30', '211', '07', '2059', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21762, to_date('31-07-2059', 'dd-mm-yyyy'), '4', '31', '212', '07', '2059', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21763, to_date('01-08-2059', 'dd-mm-yyyy'), '5', '01', '213', '08', '2059', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21764, to_date('02-08-2059', 'dd-mm-yyyy'), '6', '02', '214', '08', '2059', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21765, to_date('03-08-2059', 'dd-mm-yyyy'), '7', '03', '215', '08', '2059', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21766, to_date('04-08-2059', 'dd-mm-yyyy'), '1', '04', '216', '08', '2059', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21767, to_date('05-08-2059', 'dd-mm-yyyy'), '2', '05', '217', '08', '2059', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21768, to_date('06-08-2059', 'dd-mm-yyyy'), '3', '06', '218', '08', '2059', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21769, to_date('07-08-2059', 'dd-mm-yyyy'), '4', '07', '219', '08', '2059', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21770, to_date('08-08-2059', 'dd-mm-yyyy'), '5', '08', '220', '08', '2059', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21771, to_date('09-08-2059', 'dd-mm-yyyy'), '6', '09', '221', '08', '2059', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21772, to_date('10-08-2059', 'dd-mm-yyyy'), '7', '10', '222', '08', '2059', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21773, to_date('11-08-2059', 'dd-mm-yyyy'), '1', '11', '223', '08', '2059', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21774, to_date('12-08-2059', 'dd-mm-yyyy'), '2', '12', '224', '08', '2059', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21775, to_date('13-08-2059', 'dd-mm-yyyy'), '3', '13', '225', '08', '2059', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21776, to_date('14-08-2059', 'dd-mm-yyyy'), '4', '14', '226', '08', '2059', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21777, to_date('15-08-2059', 'dd-mm-yyyy'), '5', '15', '227', '08', '2059', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21778, to_date('16-08-2059', 'dd-mm-yyyy'), '6', '16', '228', '08', '2059', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21779, to_date('17-08-2059', 'dd-mm-yyyy'), '7', '17', '229', '08', '2059', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21780, to_date('18-08-2059', 'dd-mm-yyyy'), '1', '18', '230', '08', '2059', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21781, to_date('19-08-2059', 'dd-mm-yyyy'), '2', '19', '231', '08', '2059', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21782, to_date('20-08-2059', 'dd-mm-yyyy'), '3', '20', '232', '08', '2059', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21783, to_date('21-08-2059', 'dd-mm-yyyy'), '4', '21', '233', '08', '2059', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21784, to_date('22-08-2059', 'dd-mm-yyyy'), '5', '22', '234', '08', '2059', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21785, to_date('23-08-2059', 'dd-mm-yyyy'), '6', '23', '235', '08', '2059', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21786, to_date('24-08-2059', 'dd-mm-yyyy'), '7', '24', '236', '08', '2059', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21787, to_date('25-08-2059', 'dd-mm-yyyy'), '1', '25', '237', '08', '2059', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21788, to_date('26-08-2059', 'dd-mm-yyyy'), '2', '26', '238', '08', '2059', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21789, to_date('27-08-2059', 'dd-mm-yyyy'), '3', '27', '239', '08', '2059', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21790, to_date('28-08-2059', 'dd-mm-yyyy'), '4', '28', '240', '08', '2059', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21791, to_date('29-08-2059', 'dd-mm-yyyy'), '5', '29', '241', '08', '2059', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21792, to_date('30-08-2059', 'dd-mm-yyyy'), '6', '30', '242', '08', '2059', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21793, to_date('31-08-2059', 'dd-mm-yyyy'), '7', '31', '243', '08', '2059', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21794, to_date('01-09-2059', 'dd-mm-yyyy'), '1', '01', '244', '09', '2059', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21795, to_date('02-09-2059', 'dd-mm-yyyy'), '2', '02', '245', '09', '2059', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21796, to_date('03-09-2059', 'dd-mm-yyyy'), '3', '03', '246', '09', '2059', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21797, to_date('04-09-2059', 'dd-mm-yyyy'), '4', '04', '247', '09', '2059', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21798, to_date('05-09-2059', 'dd-mm-yyyy'), '5', '05', '248', '09', '2059', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21799, to_date('06-09-2059', 'dd-mm-yyyy'), '6', '06', '249', '09', '2059', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21800, to_date('07-09-2059', 'dd-mm-yyyy'), '7', '07', '250', '09', '2059', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21801, to_date('08-09-2059', 'dd-mm-yyyy'), '1', '08', '251', '09', '2059', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21802, to_date('09-09-2059', 'dd-mm-yyyy'), '2', '09', '252', '09', '2059', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21803, to_date('10-09-2059', 'dd-mm-yyyy'), '3', '10', '253', '09', '2059', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21804, to_date('11-09-2059', 'dd-mm-yyyy'), '4', '11', '254', '09', '2059', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21805, to_date('12-09-2059', 'dd-mm-yyyy'), '5', '12', '255', '09', '2059', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21806, to_date('13-09-2059', 'dd-mm-yyyy'), '6', '13', '256', '09', '2059', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21807, to_date('14-09-2059', 'dd-mm-yyyy'), '7', '14', '257', '09', '2059', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21808, to_date('15-09-2059', 'dd-mm-yyyy'), '1', '15', '258', '09', '2059', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21809, to_date('16-09-2059', 'dd-mm-yyyy'), '2', '16', '259', '09', '2059', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21810, to_date('17-09-2059', 'dd-mm-yyyy'), '3', '17', '260', '09', '2059', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23295, to_date('11-10-2063', 'dd-mm-yyyy'), '4', '11', '284', '10', '2063', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23296, to_date('12-10-2063', 'dd-mm-yyyy'), '5', '12', '285', '10', '2063', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23297, to_date('13-10-2063', 'dd-mm-yyyy'), '6', '13', '286', '10', '2063', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23298, to_date('14-10-2063', 'dd-mm-yyyy'), '7', '14', '287', '10', '2063', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23299, to_date('15-10-2063', 'dd-mm-yyyy'), '1', '15', '288', '10', '2063', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23300, to_date('16-10-2063', 'dd-mm-yyyy'), '2', '16', '289', '10', '2063', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23301, to_date('17-10-2063', 'dd-mm-yyyy'), '3', '17', '290', '10', '2063', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23302, to_date('18-10-2063', 'dd-mm-yyyy'), '4', '18', '291', '10', '2063', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23303, to_date('19-10-2063', 'dd-mm-yyyy'), '5', '19', '292', '10', '2063', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23304, to_date('20-10-2063', 'dd-mm-yyyy'), '6', '20', '293', '10', '2063', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23305, to_date('21-10-2063', 'dd-mm-yyyy'), '7', '21', '294', '10', '2063', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23306, to_date('22-10-2063', 'dd-mm-yyyy'), '1', '22', '295', '10', '2063', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23307, to_date('23-10-2063', 'dd-mm-yyyy'), '2', '23', '296', '10', '2063', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23308, to_date('24-10-2063', 'dd-mm-yyyy'), '3', '24', '297', '10', '2063', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23309, to_date('25-10-2063', 'dd-mm-yyyy'), '4', '25', '298', '10', '2063', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23310, to_date('26-10-2063', 'dd-mm-yyyy'), '5', '26', '299', '10', '2063', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23311, to_date('27-10-2063', 'dd-mm-yyyy'), '6', '27', '300', '10', '2063', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23312, to_date('28-10-2063', 'dd-mm-yyyy'), '7', '28', '301', '10', '2063', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23313, to_date('29-10-2063', 'dd-mm-yyyy'), '1', '29', '302', '10', '2063', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23314, to_date('30-10-2063', 'dd-mm-yyyy'), '2', '30', '303', '10', '2063', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23315, to_date('31-10-2063', 'dd-mm-yyyy'), '3', '31', '304', '10', '2063', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23316, to_date('01-11-2063', 'dd-mm-yyyy'), '4', '01', '305', '11', '2063', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23317, to_date('02-11-2063', 'dd-mm-yyyy'), '5', '02', '306', '11', '2063', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23318, to_date('03-11-2063', 'dd-mm-yyyy'), '6', '03', '307', '11', '2063', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23319, to_date('04-11-2063', 'dd-mm-yyyy'), '7', '04', '308', '11', '2063', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23320, to_date('05-11-2063', 'dd-mm-yyyy'), '1', '05', '309', '11', '2063', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23321, to_date('06-11-2063', 'dd-mm-yyyy'), '2', '06', '310', '11', '2063', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23322, to_date('07-11-2063', 'dd-mm-yyyy'), '3', '07', '311', '11', '2063', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23323, to_date('08-11-2063', 'dd-mm-yyyy'), '4', '08', '312', '11', '2063', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23324, to_date('09-11-2063', 'dd-mm-yyyy'), '5', '09', '313', '11', '2063', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23325, to_date('10-11-2063', 'dd-mm-yyyy'), '6', '10', '314', '11', '2063', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23326, to_date('11-11-2063', 'dd-mm-yyyy'), '7', '11', '315', '11', '2063', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23327, to_date('12-11-2063', 'dd-mm-yyyy'), '1', '12', '316', '11', '2063', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23328, to_date('13-11-2063', 'dd-mm-yyyy'), '2', '13', '317', '11', '2063', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23329, to_date('14-11-2063', 'dd-mm-yyyy'), '3', '14', '318', '11', '2063', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23330, to_date('15-11-2063', 'dd-mm-yyyy'), '4', '15', '319', '11', '2063', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23331, to_date('16-11-2063', 'dd-mm-yyyy'), '5', '16', '320', '11', '2063', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23332, to_date('17-11-2063', 'dd-mm-yyyy'), '6', '17', '321', '11', '2063', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23333, to_date('18-11-2063', 'dd-mm-yyyy'), '7', '18', '322', '11', '2063', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23334, to_date('19-11-2063', 'dd-mm-yyyy'), '1', '19', '323', '11', '2063', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23335, to_date('20-11-2063', 'dd-mm-yyyy'), '2', '20', '324', '11', '2063', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23336, to_date('21-11-2063', 'dd-mm-yyyy'), '3', '21', '325', '11', '2063', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23337, to_date('22-11-2063', 'dd-mm-yyyy'), '4', '22', '326', '11', '2063', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23338, to_date('23-11-2063', 'dd-mm-yyyy'), '5', '23', '327', '11', '2063', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23339, to_date('24-11-2063', 'dd-mm-yyyy'), '6', '24', '328', '11', '2063', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23340, to_date('25-11-2063', 'dd-mm-yyyy'), '7', '25', '329', '11', '2063', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23341, to_date('26-11-2063', 'dd-mm-yyyy'), '1', '26', '330', '11', '2063', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23342, to_date('27-11-2063', 'dd-mm-yyyy'), '2', '27', '331', '11', '2063', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23343, to_date('28-11-2063', 'dd-mm-yyyy'), '3', '28', '332', '11', '2063', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23344, to_date('29-11-2063', 'dd-mm-yyyy'), '4', '29', '333', '11', '2063', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23345, to_date('30-11-2063', 'dd-mm-yyyy'), '5', '30', '334', '11', '2063', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23346, to_date('01-12-2063', 'dd-mm-yyyy'), '6', '01', '335', '12', '2063', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23347, to_date('02-12-2063', 'dd-mm-yyyy'), '7', '02', '336', '12', '2063', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23348, to_date('03-12-2063', 'dd-mm-yyyy'), '1', '03', '337', '12', '2063', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23349, to_date('04-12-2063', 'dd-mm-yyyy'), '2', '04', '338', '12', '2063', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23350, to_date('05-12-2063', 'dd-mm-yyyy'), '3', '05', '339', '12', '2063', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23351, to_date('06-12-2063', 'dd-mm-yyyy'), '4', '06', '340', '12', '2063', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23352, to_date('07-12-2063', 'dd-mm-yyyy'), '5', '07', '341', '12', '2063', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23353, to_date('08-12-2063', 'dd-mm-yyyy'), '6', '08', '342', '12', '2063', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23354, to_date('09-12-2063', 'dd-mm-yyyy'), '7', '09', '343', '12', '2063', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23355, to_date('10-12-2063', 'dd-mm-yyyy'), '1', '10', '344', '12', '2063', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23356, to_date('11-12-2063', 'dd-mm-yyyy'), '2', '11', '345', '12', '2063', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23357, to_date('12-12-2063', 'dd-mm-yyyy'), '3', '12', '346', '12', '2063', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23358, to_date('13-12-2063', 'dd-mm-yyyy'), '4', '13', '347', '12', '2063', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23359, to_date('14-12-2063', 'dd-mm-yyyy'), '5', '14', '348', '12', '2063', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23360, to_date('15-12-2063', 'dd-mm-yyyy'), '6', '15', '349', '12', '2063', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23361, to_date('16-12-2063', 'dd-mm-yyyy'), '7', '16', '350', '12', '2063', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23362, to_date('17-12-2063', 'dd-mm-yyyy'), '1', '17', '351', '12', '2063', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23363, to_date('18-12-2063', 'dd-mm-yyyy'), '2', '18', '352', '12', '2063', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23364, to_date('19-12-2063', 'dd-mm-yyyy'), '3', '19', '353', '12', '2063', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23365, to_date('20-12-2063', 'dd-mm-yyyy'), '4', '20', '354', '12', '2063', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23366, to_date('21-12-2063', 'dd-mm-yyyy'), '5', '21', '355', '12', '2063', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23367, to_date('22-12-2063', 'dd-mm-yyyy'), '6', '22', '356', '12', '2063', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23368, to_date('23-12-2063', 'dd-mm-yyyy'), '7', '23', '357', '12', '2063', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23369, to_date('24-12-2063', 'dd-mm-yyyy'), '1', '24', '358', '12', '2063', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23370, to_date('25-12-2063', 'dd-mm-yyyy'), '2', '25', '359', '12', '2063', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23371, to_date('26-12-2063', 'dd-mm-yyyy'), '3', '26', '360', '12', '2063', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23372, to_date('27-12-2063', 'dd-mm-yyyy'), '4', '27', '361', '12', '2063', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23373, to_date('28-12-2063', 'dd-mm-yyyy'), '5', '28', '362', '12', '2063', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23374, to_date('29-12-2063', 'dd-mm-yyyy'), '6', '29', '363', '12', '2063', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23375, to_date('30-12-2063', 'dd-mm-yyyy'), '7', '30', '364', '12', '2063', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23376, to_date('31-12-2063', 'dd-mm-yyyy'), '1', '31', '365', '12', '2063', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23377, to_date('01-01-2064', 'dd-mm-yyyy'), '2', '01', '001', '01', '2064', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23378, to_date('02-01-2064', 'dd-mm-yyyy'), '3', '02', '002', '01', '2064', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23379, to_date('03-01-2064', 'dd-mm-yyyy'), '4', '03', '003', '01', '2064', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23380, to_date('04-01-2064', 'dd-mm-yyyy'), '5', '04', '004', '01', '2064', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23381, to_date('05-01-2064', 'dd-mm-yyyy'), '6', '05', '005', '01', '2064', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23382, to_date('06-01-2064', 'dd-mm-yyyy'), '7', '06', '006', '01', '2064', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23383, to_date('07-01-2064', 'dd-mm-yyyy'), '1', '07', '007', '01', '2064', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23384, to_date('08-01-2064', 'dd-mm-yyyy'), '2', '08', '008', '01', '2064', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23385, to_date('09-01-2064', 'dd-mm-yyyy'), '3', '09', '009', '01', '2064', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23386, to_date('10-01-2064', 'dd-mm-yyyy'), '4', '10', '010', '01', '2064', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23387, to_date('11-01-2064', 'dd-mm-yyyy'), '5', '11', '011', '01', '2064', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23388, to_date('12-01-2064', 'dd-mm-yyyy'), '6', '12', '012', '01', '2064', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23389, to_date('13-01-2064', 'dd-mm-yyyy'), '7', '13', '013', '01', '2064', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23390, to_date('14-01-2064', 'dd-mm-yyyy'), '1', '14', '014', '01', '2064', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23391, to_date('15-01-2064', 'dd-mm-yyyy'), '2', '15', '015', '01', '2064', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23392, to_date('16-01-2064', 'dd-mm-yyyy'), '3', '16', '016', '01', '2064', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23393, to_date('17-01-2064', 'dd-mm-yyyy'), '4', '17', '017', '01', '2064', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23394, to_date('18-01-2064', 'dd-mm-yyyy'), '5', '18', '018', '01', '2064', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23395, to_date('19-01-2064', 'dd-mm-yyyy'), '6', '19', '019', '01', '2064', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23396, to_date('20-01-2064', 'dd-mm-yyyy'), '7', '20', '020', '01', '2064', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23397, to_date('21-01-2064', 'dd-mm-yyyy'), '1', '21', '021', '01', '2064', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23398, to_date('22-01-2064', 'dd-mm-yyyy'), '2', '22', '022', '01', '2064', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23399, to_date('23-01-2064', 'dd-mm-yyyy'), '3', '23', '023', '01', '2064', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23400, to_date('24-01-2064', 'dd-mm-yyyy'), '4', '24', '024', '01', '2064', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24885, to_date('17-02-2068', 'dd-mm-yyyy'), '5', '17', '048', '02', '2068', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24886, to_date('18-02-2068', 'dd-mm-yyyy'), '6', '18', '049', '02', '2068', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24887, to_date('19-02-2068', 'dd-mm-yyyy'), '7', '19', '050', '02', '2068', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24888, to_date('20-02-2068', 'dd-mm-yyyy'), '1', '20', '051', '02', '2068', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24889, to_date('21-02-2068', 'dd-mm-yyyy'), '2', '21', '052', '02', '2068', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24890, to_date('22-02-2068', 'dd-mm-yyyy'), '3', '22', '053', '02', '2068', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24891, to_date('23-02-2068', 'dd-mm-yyyy'), '4', '23', '054', '02', '2068', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24892, to_date('24-02-2068', 'dd-mm-yyyy'), '5', '24', '055', '02', '2068', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24893, to_date('25-02-2068', 'dd-mm-yyyy'), '6', '25', '056', '02', '2068', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24894, to_date('26-02-2068', 'dd-mm-yyyy'), '7', '26', '057', '02', '2068', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24895, to_date('27-02-2068', 'dd-mm-yyyy'), '1', '27', '058', '02', '2068', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24896, to_date('28-02-2068', 'dd-mm-yyyy'), '2', '28', '059', '02', '2068', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24897, to_date('29-02-2068', 'dd-mm-yyyy'), '3', '29', '060', '02', '2068', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24898, to_date('01-03-2068', 'dd-mm-yyyy'), '4', '01', '061', '03', '2068', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24899, to_date('02-03-2068', 'dd-mm-yyyy'), '5', '02', '062', '03', '2068', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24900, to_date('03-03-2068', 'dd-mm-yyyy'), '6', '03', '063', '03', '2068', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24901, to_date('04-03-2068', 'dd-mm-yyyy'), '7', '04', '064', '03', '2068', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24902, to_date('05-03-2068', 'dd-mm-yyyy'), '1', '05', '065', '03', '2068', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24903, to_date('06-03-2068', 'dd-mm-yyyy'), '2', '06', '066', '03', '2068', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24904, to_date('07-03-2068', 'dd-mm-yyyy'), '3', '07', '067', '03', '2068', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24905, to_date('08-03-2068', 'dd-mm-yyyy'), '4', '08', '068', '03', '2068', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24906, to_date('09-03-2068', 'dd-mm-yyyy'), '5', '09', '069', '03', '2068', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24907, to_date('10-03-2068', 'dd-mm-yyyy'), '6', '10', '070', '03', '2068', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24908, to_date('11-03-2068', 'dd-mm-yyyy'), '7', '11', '071', '03', '2068', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24909, to_date('12-03-2068', 'dd-mm-yyyy'), '1', '12', '072', '03', '2068', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24910, to_date('13-03-2068', 'dd-mm-yyyy'), '2', '13', '073', '03', '2068', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24911, to_date('14-03-2068', 'dd-mm-yyyy'), '3', '14', '074', '03', '2068', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24912, to_date('15-03-2068', 'dd-mm-yyyy'), '4', '15', '075', '03', '2068', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24913, to_date('16-03-2068', 'dd-mm-yyyy'), '5', '16', '076', '03', '2068', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24914, to_date('17-03-2068', 'dd-mm-yyyy'), '6', '17', '077', '03', '2068', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24915, to_date('18-03-2068', 'dd-mm-yyyy'), '7', '18', '078', '03', '2068', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24916, to_date('19-03-2068', 'dd-mm-yyyy'), '1', '19', '079', '03', '2068', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24917, to_date('20-03-2068', 'dd-mm-yyyy'), '2', '20', '080', '03', '2068', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24918, to_date('21-03-2068', 'dd-mm-yyyy'), '3', '21', '081', '03', '2068', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24919, to_date('22-03-2068', 'dd-mm-yyyy'), '4', '22', '082', '03', '2068', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24920, to_date('23-03-2068', 'dd-mm-yyyy'), '5', '23', '083', '03', '2068', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24921, to_date('24-03-2068', 'dd-mm-yyyy'), '6', '24', '084', '03', '2068', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24922, to_date('25-03-2068', 'dd-mm-yyyy'), '7', '25', '085', '03', '2068', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24923, to_date('26-03-2068', 'dd-mm-yyyy'), '1', '26', '086', '03', '2068', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24924, to_date('27-03-2068', 'dd-mm-yyyy'), '2', '27', '087', '03', '2068', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24925, to_date('28-03-2068', 'dd-mm-yyyy'), '3', '28', '088', '03', '2068', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24926, to_date('29-03-2068', 'dd-mm-yyyy'), '4', '29', '089', '03', '2068', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24927, to_date('30-03-2068', 'dd-mm-yyyy'), '5', '30', '090', '03', '2068', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24928, to_date('31-03-2068', 'dd-mm-yyyy'), '6', '31', '091', '03', '2068', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24929, to_date('01-04-2068', 'dd-mm-yyyy'), '7', '01', '092', '04', '2068', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24930, to_date('02-04-2068', 'dd-mm-yyyy'), '1', '02', '093', '04', '2068', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24931, to_date('03-04-2068', 'dd-mm-yyyy'), '2', '03', '094', '04', '2068', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24932, to_date('04-04-2068', 'dd-mm-yyyy'), '3', '04', '095', '04', '2068', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24933, to_date('05-04-2068', 'dd-mm-yyyy'), '4', '05', '096', '04', '2068', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24934, to_date('06-04-2068', 'dd-mm-yyyy'), '5', '06', '097', '04', '2068', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24935, to_date('07-04-2068', 'dd-mm-yyyy'), '6', '07', '098', '04', '2068', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24936, to_date('08-04-2068', 'dd-mm-yyyy'), '7', '08', '099', '04', '2068', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24937, to_date('09-04-2068', 'dd-mm-yyyy'), '1', '09', '100', '04', '2068', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24938, to_date('10-04-2068', 'dd-mm-yyyy'), '2', '10', '101', '04', '2068', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24939, to_date('11-04-2068', 'dd-mm-yyyy'), '3', '11', '102', '04', '2068', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24940, to_date('12-04-2068', 'dd-mm-yyyy'), '4', '12', '103', '04', '2068', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24941, to_date('13-04-2068', 'dd-mm-yyyy'), '5', '13', '104', '04', '2068', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24942, to_date('14-04-2068', 'dd-mm-yyyy'), '6', '14', '105', '04', '2068', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24943, to_date('15-04-2068', 'dd-mm-yyyy'), '7', '15', '106', '04', '2068', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24944, to_date('16-04-2068', 'dd-mm-yyyy'), '1', '16', '107', '04', '2068', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24945, to_date('17-04-2068', 'dd-mm-yyyy'), '2', '17', '108', '04', '2068', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24946, to_date('18-04-2068', 'dd-mm-yyyy'), '3', '18', '109', '04', '2068', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24947, to_date('19-04-2068', 'dd-mm-yyyy'), '4', '19', '110', '04', '2068', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24948, to_date('20-04-2068', 'dd-mm-yyyy'), '5', '20', '111', '04', '2068', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24949, to_date('21-04-2068', 'dd-mm-yyyy'), '6', '21', '112', '04', '2068', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24950, to_date('22-04-2068', 'dd-mm-yyyy'), '7', '22', '113', '04', '2068', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24951, to_date('23-04-2068', 'dd-mm-yyyy'), '1', '23', '114', '04', '2068', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24952, to_date('24-04-2068', 'dd-mm-yyyy'), '2', '24', '115', '04', '2068', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24953, to_date('25-04-2068', 'dd-mm-yyyy'), '3', '25', '116', '04', '2068', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24954, to_date('26-04-2068', 'dd-mm-yyyy'), '4', '26', '117', '04', '2068', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24955, to_date('27-04-2068', 'dd-mm-yyyy'), '5', '27', '118', '04', '2068', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24956, to_date('28-04-2068', 'dd-mm-yyyy'), '6', '28', '119', '04', '2068', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24957, to_date('29-04-2068', 'dd-mm-yyyy'), '7', '29', '120', '04', '2068', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24958, to_date('30-04-2068', 'dd-mm-yyyy'), '1', '30', '121', '04', '2068', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24959, to_date('01-05-2068', 'dd-mm-yyyy'), '2', '01', '122', '05', '2068', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24960, to_date('02-05-2068', 'dd-mm-yyyy'), '3', '02', '123', '05', '2068', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24961, to_date('03-05-2068', 'dd-mm-yyyy'), '4', '03', '124', '05', '2068', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24962, to_date('04-05-2068', 'dd-mm-yyyy'), '5', '04', '125', '05', '2068', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24963, to_date('05-05-2068', 'dd-mm-yyyy'), '6', '05', '126', '05', '2068', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24964, to_date('06-05-2068', 'dd-mm-yyyy'), '7', '06', '127', '05', '2068', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24965, to_date('07-05-2068', 'dd-mm-yyyy'), '1', '07', '128', '05', '2068', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24966, to_date('08-05-2068', 'dd-mm-yyyy'), '2', '08', '129', '05', '2068', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24967, to_date('09-05-2068', 'dd-mm-yyyy'), '3', '09', '130', '05', '2068', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24968, to_date('10-05-2068', 'dd-mm-yyyy'), '4', '10', '131', '05', '2068', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24969, to_date('11-05-2068', 'dd-mm-yyyy'), '5', '11', '132', '05', '2068', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24970, to_date('12-05-2068', 'dd-mm-yyyy'), '6', '12', '133', '05', '2068', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24971, to_date('13-05-2068', 'dd-mm-yyyy'), '7', '13', '134', '05', '2068', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24972, to_date('14-05-2068', 'dd-mm-yyyy'), '1', '14', '135', '05', '2068', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24973, to_date('15-05-2068', 'dd-mm-yyyy'), '2', '15', '136', '05', '2068', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24974, to_date('16-05-2068', 'dd-mm-yyyy'), '3', '16', '137', '05', '2068', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24975, to_date('17-05-2068', 'dd-mm-yyyy'), '4', '17', '138', '05', '2068', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24976, to_date('18-05-2068', 'dd-mm-yyyy'), '5', '18', '139', '05', '2068', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24977, to_date('19-05-2068', 'dd-mm-yyyy'), '6', '19', '140', '05', '2068', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24978, to_date('20-05-2068', 'dd-mm-yyyy'), '7', '20', '141', '05', '2068', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24979, to_date('21-05-2068', 'dd-mm-yyyy'), '1', '21', '142', '05', '2068', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24980, to_date('22-05-2068', 'dd-mm-yyyy'), '2', '22', '143', '05', '2068', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24981, to_date('23-05-2068', 'dd-mm-yyyy'), '3', '23', '144', '05', '2068', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24982, to_date('24-05-2068', 'dd-mm-yyyy'), '4', '24', '145', '05', '2068', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24983, to_date('25-05-2068', 'dd-mm-yyyy'), '5', '25', '146', '05', '2068', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24984, to_date('26-05-2068', 'dd-mm-yyyy'), '6', '26', '147', '05', '2068', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24985, to_date('27-05-2068', 'dd-mm-yyyy'), '7', '27', '148', '05', '2068', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24986, to_date('28-05-2068', 'dd-mm-yyyy'), '1', '28', '149', '05', '2068', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24987, to_date('29-05-2068', 'dd-mm-yyyy'), '2', '29', '150', '05', '2068', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24988, to_date('30-05-2068', 'dd-mm-yyyy'), '3', '30', '151', '05', '2068', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24989, to_date('31-05-2068', 'dd-mm-yyyy'), '4', '31', '152', '05', '2068', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24990, to_date('01-06-2068', 'dd-mm-yyyy'), '5', '01', '153', '06', '2068', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20221, to_date('12-05-2055', 'dd-mm-yyyy'), '3', '12', '132', '05', '2055', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20222, to_date('13-05-2055', 'dd-mm-yyyy'), '4', '13', '133', '05', '2055', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20223, to_date('14-05-2055', 'dd-mm-yyyy'), '5', '14', '134', '05', '2055', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20224, to_date('15-05-2055', 'dd-mm-yyyy'), '6', '15', '135', '05', '2055', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20225, to_date('16-05-2055', 'dd-mm-yyyy'), '7', '16', '136', '05', '2055', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20226, to_date('17-05-2055', 'dd-mm-yyyy'), '1', '17', '137', '05', '2055', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20227, to_date('18-05-2055', 'dd-mm-yyyy'), '2', '18', '138', '05', '2055', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20228, to_date('19-05-2055', 'dd-mm-yyyy'), '3', '19', '139', '05', '2055', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20229, to_date('20-05-2055', 'dd-mm-yyyy'), '4', '20', '140', '05', '2055', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20230, to_date('21-05-2055', 'dd-mm-yyyy'), '5', '21', '141', '05', '2055', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20231, to_date('22-05-2055', 'dd-mm-yyyy'), '6', '22', '142', '05', '2055', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20232, to_date('23-05-2055', 'dd-mm-yyyy'), '7', '23', '143', '05', '2055', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20233, to_date('24-05-2055', 'dd-mm-yyyy'), '1', '24', '144', '05', '2055', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20234, to_date('25-05-2055', 'dd-mm-yyyy'), '2', '25', '145', '05', '2055', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20235, to_date('26-05-2055', 'dd-mm-yyyy'), '3', '26', '146', '05', '2055', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20236, to_date('27-05-2055', 'dd-mm-yyyy'), '4', '27', '147', '05', '2055', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20237, to_date('28-05-2055', 'dd-mm-yyyy'), '5', '28', '148', '05', '2055', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20238, to_date('29-05-2055', 'dd-mm-yyyy'), '6', '29', '149', '05', '2055', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20239, to_date('30-05-2055', 'dd-mm-yyyy'), '7', '30', '150', '05', '2055', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20240, to_date('31-05-2055', 'dd-mm-yyyy'), '1', '31', '151', '05', '2055', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20241, to_date('01-06-2055', 'dd-mm-yyyy'), '2', '01', '152', '06', '2055', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20242, to_date('02-06-2055', 'dd-mm-yyyy'), '3', '02', '153', '06', '2055', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20243, to_date('03-06-2055', 'dd-mm-yyyy'), '4', '03', '154', '06', '2055', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20244, to_date('04-06-2055', 'dd-mm-yyyy'), '5', '04', '155', '06', '2055', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20245, to_date('05-06-2055', 'dd-mm-yyyy'), '6', '05', '156', '06', '2055', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20246, to_date('06-06-2055', 'dd-mm-yyyy'), '7', '06', '157', '06', '2055', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20247, to_date('07-06-2055', 'dd-mm-yyyy'), '1', '07', '158', '06', '2055', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20248, to_date('08-06-2055', 'dd-mm-yyyy'), '2', '08', '159', '06', '2055', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20249, to_date('09-06-2055', 'dd-mm-yyyy'), '3', '09', '160', '06', '2055', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20250, to_date('10-06-2055', 'dd-mm-yyyy'), '4', '10', '161', '06', '2055', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20251, to_date('11-06-2055', 'dd-mm-yyyy'), '5', '11', '162', '06', '2055', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20252, to_date('12-06-2055', 'dd-mm-yyyy'), '6', '12', '163', '06', '2055', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20253, to_date('13-06-2055', 'dd-mm-yyyy'), '7', '13', '164', '06', '2055', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20254, to_date('14-06-2055', 'dd-mm-yyyy'), '1', '14', '165', '06', '2055', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20255, to_date('15-06-2055', 'dd-mm-yyyy'), '2', '15', '166', '06', '2055', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20256, to_date('16-06-2055', 'dd-mm-yyyy'), '3', '16', '167', '06', '2055', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20257, to_date('17-06-2055', 'dd-mm-yyyy'), '4', '17', '168', '06', '2055', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20258, to_date('18-06-2055', 'dd-mm-yyyy'), '5', '18', '169', '06', '2055', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20259, to_date('19-06-2055', 'dd-mm-yyyy'), '6', '19', '170', '06', '2055', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20260, to_date('20-06-2055', 'dd-mm-yyyy'), '7', '20', '171', '06', '2055', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20261, to_date('21-06-2055', 'dd-mm-yyyy'), '1', '21', '172', '06', '2055', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20262, to_date('22-06-2055', 'dd-mm-yyyy'), '2', '22', '173', '06', '2055', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20263, to_date('23-06-2055', 'dd-mm-yyyy'), '3', '23', '174', '06', '2055', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20264, to_date('24-06-2055', 'dd-mm-yyyy'), '4', '24', '175', '06', '2055', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20265, to_date('25-06-2055', 'dd-mm-yyyy'), '5', '25', '176', '06', '2055', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20266, to_date('26-06-2055', 'dd-mm-yyyy'), '6', '26', '177', '06', '2055', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20267, to_date('27-06-2055', 'dd-mm-yyyy'), '7', '27', '178', '06', '2055', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20268, to_date('28-06-2055', 'dd-mm-yyyy'), '1', '28', '179', '06', '2055', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20269, to_date('29-06-2055', 'dd-mm-yyyy'), '2', '29', '180', '06', '2055', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20270, to_date('30-06-2055', 'dd-mm-yyyy'), '3', '30', '181', '06', '2055', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20271, to_date('01-07-2055', 'dd-mm-yyyy'), '4', '01', '182', '07', '2055', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20272, to_date('02-07-2055', 'dd-mm-yyyy'), '5', '02', '183', '07', '2055', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20273, to_date('03-07-2055', 'dd-mm-yyyy'), '6', '03', '184', '07', '2055', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20274, to_date('04-07-2055', 'dd-mm-yyyy'), '7', '04', '185', '07', '2055', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20275, to_date('05-07-2055', 'dd-mm-yyyy'), '1', '05', '186', '07', '2055', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20276, to_date('06-07-2055', 'dd-mm-yyyy'), '2', '06', '187', '07', '2055', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20277, to_date('07-07-2055', 'dd-mm-yyyy'), '3', '07', '188', '07', '2055', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20278, to_date('08-07-2055', 'dd-mm-yyyy'), '4', '08', '189', '07', '2055', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20279, to_date('09-07-2055', 'dd-mm-yyyy'), '5', '09', '190', '07', '2055', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20280, to_date('10-07-2055', 'dd-mm-yyyy'), '6', '10', '191', '07', '2055', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20281, to_date('11-07-2055', 'dd-mm-yyyy'), '7', '11', '192', '07', '2055', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20282, to_date('12-07-2055', 'dd-mm-yyyy'), '1', '12', '193', '07', '2055', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20283, to_date('13-07-2055', 'dd-mm-yyyy'), '2', '13', '194', '07', '2055', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20284, to_date('14-07-2055', 'dd-mm-yyyy'), '3', '14', '195', '07', '2055', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20285, to_date('15-07-2055', 'dd-mm-yyyy'), '4', '15', '196', '07', '2055', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20286, to_date('16-07-2055', 'dd-mm-yyyy'), '5', '16', '197', '07', '2055', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20287, to_date('17-07-2055', 'dd-mm-yyyy'), '6', '17', '198', '07', '2055', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20288, to_date('18-07-2055', 'dd-mm-yyyy'), '7', '18', '199', '07', '2055', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20289, to_date('19-07-2055', 'dd-mm-yyyy'), '1', '19', '200', '07', '2055', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20290, to_date('20-07-2055', 'dd-mm-yyyy'), '2', '20', '201', '07', '2055', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20291, to_date('21-07-2055', 'dd-mm-yyyy'), '3', '21', '202', '07', '2055', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20292, to_date('22-07-2055', 'dd-mm-yyyy'), '4', '22', '203', '07', '2055', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20293, to_date('23-07-2055', 'dd-mm-yyyy'), '5', '23', '204', '07', '2055', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20294, to_date('24-07-2055', 'dd-mm-yyyy'), '6', '24', '205', '07', '2055', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20295, to_date('25-07-2055', 'dd-mm-yyyy'), '7', '25', '206', '07', '2055', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20296, to_date('26-07-2055', 'dd-mm-yyyy'), '1', '26', '207', '07', '2055', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20297, to_date('27-07-2055', 'dd-mm-yyyy'), '2', '27', '208', '07', '2055', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20298, to_date('28-07-2055', 'dd-mm-yyyy'), '3', '28', '209', '07', '2055', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20299, to_date('29-07-2055', 'dd-mm-yyyy'), '4', '29', '210', '07', '2055', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20300, to_date('30-07-2055', 'dd-mm-yyyy'), '5', '30', '211', '07', '2055', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20301, to_date('31-07-2055', 'dd-mm-yyyy'), '6', '31', '212', '07', '2055', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20302, to_date('01-08-2055', 'dd-mm-yyyy'), '7', '01', '213', '08', '2055', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20303, to_date('02-08-2055', 'dd-mm-yyyy'), '1', '02', '214', '08', '2055', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20304, to_date('03-08-2055', 'dd-mm-yyyy'), '2', '03', '215', '08', '2055', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20305, to_date('04-08-2055', 'dd-mm-yyyy'), '3', '04', '216', '08', '2055', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20306, to_date('05-08-2055', 'dd-mm-yyyy'), '4', '05', '217', '08', '2055', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20307, to_date('06-08-2055', 'dd-mm-yyyy'), '5', '06', '218', '08', '2055', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20308, to_date('07-08-2055', 'dd-mm-yyyy'), '6', '07', '219', '08', '2055', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20309, to_date('08-08-2055', 'dd-mm-yyyy'), '7', '08', '220', '08', '2055', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20310, to_date('09-08-2055', 'dd-mm-yyyy'), '1', '09', '221', '08', '2055', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20311, to_date('10-08-2055', 'dd-mm-yyyy'), '2', '10', '222', '08', '2055', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20312, to_date('11-08-2055', 'dd-mm-yyyy'), '3', '11', '223', '08', '2055', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20313, to_date('12-08-2055', 'dd-mm-yyyy'), '4', '12', '224', '08', '2055', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20314, to_date('13-08-2055', 'dd-mm-yyyy'), '5', '13', '225', '08', '2055', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20315, to_date('14-08-2055', 'dd-mm-yyyy'), '6', '14', '226', '08', '2055', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20316, to_date('15-08-2055', 'dd-mm-yyyy'), '7', '15', '227', '08', '2055', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20317, to_date('16-08-2055', 'dd-mm-yyyy'), '1', '16', '228', '08', '2055', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20318, to_date('17-08-2055', 'dd-mm-yyyy'), '2', '17', '229', '08', '2055', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20319, to_date('18-08-2055', 'dd-mm-yyyy'), '3', '18', '230', '08', '2055', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20320, to_date('19-08-2055', 'dd-mm-yyyy'), '4', '19', '231', '08', '2055', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20321, to_date('20-08-2055', 'dd-mm-yyyy'), '5', '20', '232', '08', '2055', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20322, to_date('21-08-2055', 'dd-mm-yyyy'), '6', '21', '233', '08', '2055', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20323, to_date('22-08-2055', 'dd-mm-yyyy'), '7', '22', '234', '08', '2055', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20324, to_date('23-08-2055', 'dd-mm-yyyy'), '1', '23', '235', '08', '2055', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20325, to_date('24-08-2055', 'dd-mm-yyyy'), '2', '24', '236', '08', '2055', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20326, to_date('25-08-2055', 'dd-mm-yyyy'), '3', '25', '237', '08', '2055', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21811, to_date('18-09-2059', 'dd-mm-yyyy'), '4', '18', '261', '09', '2059', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21812, to_date('19-09-2059', 'dd-mm-yyyy'), '5', '19', '262', '09', '2059', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21813, to_date('20-09-2059', 'dd-mm-yyyy'), '6', '20', '263', '09', '2059', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21814, to_date('21-09-2059', 'dd-mm-yyyy'), '7', '21', '264', '09', '2059', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21815, to_date('22-09-2059', 'dd-mm-yyyy'), '1', '22', '265', '09', '2059', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21816, to_date('23-09-2059', 'dd-mm-yyyy'), '2', '23', '266', '09', '2059', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21817, to_date('24-09-2059', 'dd-mm-yyyy'), '3', '24', '267', '09', '2059', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21818, to_date('25-09-2059', 'dd-mm-yyyy'), '4', '25', '268', '09', '2059', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21819, to_date('26-09-2059', 'dd-mm-yyyy'), '5', '26', '269', '09', '2059', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21820, to_date('27-09-2059', 'dd-mm-yyyy'), '6', '27', '270', '09', '2059', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21821, to_date('28-09-2059', 'dd-mm-yyyy'), '7', '28', '271', '09', '2059', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21822, to_date('29-09-2059', 'dd-mm-yyyy'), '1', '29', '272', '09', '2059', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21823, to_date('30-09-2059', 'dd-mm-yyyy'), '2', '30', '273', '09', '2059', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21824, to_date('01-10-2059', 'dd-mm-yyyy'), '3', '01', '274', '10', '2059', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21825, to_date('02-10-2059', 'dd-mm-yyyy'), '4', '02', '275', '10', '2059', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21826, to_date('03-10-2059', 'dd-mm-yyyy'), '5', '03', '276', '10', '2059', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21827, to_date('04-10-2059', 'dd-mm-yyyy'), '6', '04', '277', '10', '2059', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21828, to_date('05-10-2059', 'dd-mm-yyyy'), '7', '05', '278', '10', '2059', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21829, to_date('06-10-2059', 'dd-mm-yyyy'), '1', '06', '279', '10', '2059', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21830, to_date('07-10-2059', 'dd-mm-yyyy'), '2', '07', '280', '10', '2059', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21831, to_date('08-10-2059', 'dd-mm-yyyy'), '3', '08', '281', '10', '2059', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21832, to_date('09-10-2059', 'dd-mm-yyyy'), '4', '09', '282', '10', '2059', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21833, to_date('10-10-2059', 'dd-mm-yyyy'), '5', '10', '283', '10', '2059', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21834, to_date('11-10-2059', 'dd-mm-yyyy'), '6', '11', '284', '10', '2059', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21835, to_date('12-10-2059', 'dd-mm-yyyy'), '7', '12', '285', '10', '2059', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21836, to_date('13-10-2059', 'dd-mm-yyyy'), '1', '13', '286', '10', '2059', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21837, to_date('14-10-2059', 'dd-mm-yyyy'), '2', '14', '287', '10', '2059', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21838, to_date('15-10-2059', 'dd-mm-yyyy'), '3', '15', '288', '10', '2059', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21839, to_date('16-10-2059', 'dd-mm-yyyy'), '4', '16', '289', '10', '2059', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21840, to_date('17-10-2059', 'dd-mm-yyyy'), '5', '17', '290', '10', '2059', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21841, to_date('18-10-2059', 'dd-mm-yyyy'), '6', '18', '291', '10', '2059', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21842, to_date('19-10-2059', 'dd-mm-yyyy'), '7', '19', '292', '10', '2059', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21843, to_date('20-10-2059', 'dd-mm-yyyy'), '1', '20', '293', '10', '2059', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21844, to_date('21-10-2059', 'dd-mm-yyyy'), '2', '21', '294', '10', '2059', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21845, to_date('22-10-2059', 'dd-mm-yyyy'), '3', '22', '295', '10', '2059', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21846, to_date('23-10-2059', 'dd-mm-yyyy'), '4', '23', '296', '10', '2059', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21847, to_date('24-10-2059', 'dd-mm-yyyy'), '5', '24', '297', '10', '2059', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21848, to_date('25-10-2059', 'dd-mm-yyyy'), '6', '25', '298', '10', '2059', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21849, to_date('26-10-2059', 'dd-mm-yyyy'), '7', '26', '299', '10', '2059', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21850, to_date('27-10-2059', 'dd-mm-yyyy'), '1', '27', '300', '10', '2059', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21851, to_date('28-10-2059', 'dd-mm-yyyy'), '2', '28', '301', '10', '2059', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21852, to_date('29-10-2059', 'dd-mm-yyyy'), '3', '29', '302', '10', '2059', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21853, to_date('30-10-2059', 'dd-mm-yyyy'), '4', '30', '303', '10', '2059', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21854, to_date('31-10-2059', 'dd-mm-yyyy'), '5', '31', '304', '10', '2059', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21855, to_date('01-11-2059', 'dd-mm-yyyy'), '6', '01', '305', '11', '2059', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21856, to_date('02-11-2059', 'dd-mm-yyyy'), '7', '02', '306', '11', '2059', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21857, to_date('03-11-2059', 'dd-mm-yyyy'), '1', '03', '307', '11', '2059', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21858, to_date('04-11-2059', 'dd-mm-yyyy'), '2', '04', '308', '11', '2059', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21859, to_date('05-11-2059', 'dd-mm-yyyy'), '3', '05', '309', '11', '2059', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21860, to_date('06-11-2059', 'dd-mm-yyyy'), '4', '06', '310', '11', '2059', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21861, to_date('07-11-2059', 'dd-mm-yyyy'), '5', '07', '311', '11', '2059', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21862, to_date('08-11-2059', 'dd-mm-yyyy'), '6', '08', '312', '11', '2059', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21863, to_date('09-11-2059', 'dd-mm-yyyy'), '7', '09', '313', '11', '2059', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21864, to_date('10-11-2059', 'dd-mm-yyyy'), '1', '10', '314', '11', '2059', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21865, to_date('11-11-2059', 'dd-mm-yyyy'), '2', '11', '315', '11', '2059', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21866, to_date('12-11-2059', 'dd-mm-yyyy'), '3', '12', '316', '11', '2059', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21867, to_date('13-11-2059', 'dd-mm-yyyy'), '4', '13', '317', '11', '2059', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21868, to_date('14-11-2059', 'dd-mm-yyyy'), '5', '14', '318', '11', '2059', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21869, to_date('15-11-2059', 'dd-mm-yyyy'), '6', '15', '319', '11', '2059', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21870, to_date('16-11-2059', 'dd-mm-yyyy'), '7', '16', '320', '11', '2059', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21871, to_date('17-11-2059', 'dd-mm-yyyy'), '1', '17', '321', '11', '2059', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21872, to_date('18-11-2059', 'dd-mm-yyyy'), '2', '18', '322', '11', '2059', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21873, to_date('19-11-2059', 'dd-mm-yyyy'), '3', '19', '323', '11', '2059', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21874, to_date('20-11-2059', 'dd-mm-yyyy'), '4', '20', '324', '11', '2059', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21875, to_date('21-11-2059', 'dd-mm-yyyy'), '5', '21', '325', '11', '2059', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21876, to_date('22-11-2059', 'dd-mm-yyyy'), '6', '22', '326', '11', '2059', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21877, to_date('23-11-2059', 'dd-mm-yyyy'), '7', '23', '327', '11', '2059', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21878, to_date('24-11-2059', 'dd-mm-yyyy'), '1', '24', '328', '11', '2059', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21879, to_date('25-11-2059', 'dd-mm-yyyy'), '2', '25', '329', '11', '2059', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21880, to_date('26-11-2059', 'dd-mm-yyyy'), '3', '26', '330', '11', '2059', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21881, to_date('27-11-2059', 'dd-mm-yyyy'), '4', '27', '331', '11', '2059', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21882, to_date('28-11-2059', 'dd-mm-yyyy'), '5', '28', '332', '11', '2059', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21883, to_date('29-11-2059', 'dd-mm-yyyy'), '6', '29', '333', '11', '2059', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21884, to_date('30-11-2059', 'dd-mm-yyyy'), '7', '30', '334', '11', '2059', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21885, to_date('01-12-2059', 'dd-mm-yyyy'), '1', '01', '335', '12', '2059', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21886, to_date('02-12-2059', 'dd-mm-yyyy'), '2', '02', '336', '12', '2059', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21887, to_date('03-12-2059', 'dd-mm-yyyy'), '3', '03', '337', '12', '2059', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21888, to_date('04-12-2059', 'dd-mm-yyyy'), '4', '04', '338', '12', '2059', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21889, to_date('05-12-2059', 'dd-mm-yyyy'), '5', '05', '339', '12', '2059', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21890, to_date('06-12-2059', 'dd-mm-yyyy'), '6', '06', '340', '12', '2059', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21891, to_date('07-12-2059', 'dd-mm-yyyy'), '7', '07', '341', '12', '2059', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21892, to_date('08-12-2059', 'dd-mm-yyyy'), '1', '08', '342', '12', '2059', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21893, to_date('09-12-2059', 'dd-mm-yyyy'), '2', '09', '343', '12', '2059', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21894, to_date('10-12-2059', 'dd-mm-yyyy'), '3', '10', '344', '12', '2059', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21895, to_date('11-12-2059', 'dd-mm-yyyy'), '4', '11', '345', '12', '2059', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21896, to_date('12-12-2059', 'dd-mm-yyyy'), '5', '12', '346', '12', '2059', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21897, to_date('13-12-2059', 'dd-mm-yyyy'), '6', '13', '347', '12', '2059', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21898, to_date('14-12-2059', 'dd-mm-yyyy'), '7', '14', '348', '12', '2059', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21899, to_date('15-12-2059', 'dd-mm-yyyy'), '1', '15', '349', '12', '2059', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21900, to_date('16-12-2059', 'dd-mm-yyyy'), '2', '16', '350', '12', '2059', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21901, to_date('17-12-2059', 'dd-mm-yyyy'), '3', '17', '351', '12', '2059', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21902, to_date('18-12-2059', 'dd-mm-yyyy'), '4', '18', '352', '12', '2059', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21903, to_date('19-12-2059', 'dd-mm-yyyy'), '5', '19', '353', '12', '2059', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21904, to_date('20-12-2059', 'dd-mm-yyyy'), '6', '20', '354', '12', '2059', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21905, to_date('21-12-2059', 'dd-mm-yyyy'), '7', '21', '355', '12', '2059', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21906, to_date('22-12-2059', 'dd-mm-yyyy'), '1', '22', '356', '12', '2059', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21907, to_date('23-12-2059', 'dd-mm-yyyy'), '2', '23', '357', '12', '2059', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21908, to_date('24-12-2059', 'dd-mm-yyyy'), '3', '24', '358', '12', '2059', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21909, to_date('25-12-2059', 'dd-mm-yyyy'), '4', '25', '359', '12', '2059', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21910, to_date('26-12-2059', 'dd-mm-yyyy'), '5', '26', '360', '12', '2059', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21911, to_date('27-12-2059', 'dd-mm-yyyy'), '6', '27', '361', '12', '2059', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21912, to_date('28-12-2059', 'dd-mm-yyyy'), '7', '28', '362', '12', '2059', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21913, to_date('29-12-2059', 'dd-mm-yyyy'), '1', '29', '363', '12', '2059', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21914, to_date('30-12-2059', 'dd-mm-yyyy'), '2', '30', '364', '12', '2059', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21915, to_date('31-12-2059', 'dd-mm-yyyy'), '3', '31', '365', '12', '2059', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21916, to_date('01-01-2060', 'dd-mm-yyyy'), '4', '01', '001', '01', '2060', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23401, to_date('25-01-2064', 'dd-mm-yyyy'), '5', '25', '025', '01', '2064', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23402, to_date('26-01-2064', 'dd-mm-yyyy'), '6', '26', '026', '01', '2064', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23403, to_date('27-01-2064', 'dd-mm-yyyy'), '7', '27', '027', '01', '2064', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23404, to_date('28-01-2064', 'dd-mm-yyyy'), '1', '28', '028', '01', '2064', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23405, to_date('29-01-2064', 'dd-mm-yyyy'), '2', '29', '029', '01', '2064', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23406, to_date('30-01-2064', 'dd-mm-yyyy'), '3', '30', '030', '01', '2064', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23407, to_date('31-01-2064', 'dd-mm-yyyy'), '4', '31', '031', '01', '2064', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23408, to_date('01-02-2064', 'dd-mm-yyyy'), '5', '01', '032', '02', '2064', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23409, to_date('02-02-2064', 'dd-mm-yyyy'), '6', '02', '033', '02', '2064', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23410, to_date('03-02-2064', 'dd-mm-yyyy'), '7', '03', '034', '02', '2064', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23411, to_date('04-02-2064', 'dd-mm-yyyy'), '1', '04', '035', '02', '2064', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23412, to_date('05-02-2064', 'dd-mm-yyyy'), '2', '05', '036', '02', '2064', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23413, to_date('06-02-2064', 'dd-mm-yyyy'), '3', '06', '037', '02', '2064', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23414, to_date('07-02-2064', 'dd-mm-yyyy'), '4', '07', '038', '02', '2064', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23415, to_date('08-02-2064', 'dd-mm-yyyy'), '5', '08', '039', '02', '2064', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23416, to_date('09-02-2064', 'dd-mm-yyyy'), '6', '09', '040', '02', '2064', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23417, to_date('10-02-2064', 'dd-mm-yyyy'), '7', '10', '041', '02', '2064', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23418, to_date('11-02-2064', 'dd-mm-yyyy'), '1', '11', '042', '02', '2064', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23419, to_date('12-02-2064', 'dd-mm-yyyy'), '2', '12', '043', '02', '2064', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23420, to_date('13-02-2064', 'dd-mm-yyyy'), '3', '13', '044', '02', '2064', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23421, to_date('14-02-2064', 'dd-mm-yyyy'), '4', '14', '045', '02', '2064', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23422, to_date('15-02-2064', 'dd-mm-yyyy'), '5', '15', '046', '02', '2064', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23423, to_date('16-02-2064', 'dd-mm-yyyy'), '6', '16', '047', '02', '2064', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23424, to_date('17-02-2064', 'dd-mm-yyyy'), '7', '17', '048', '02', '2064', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23425, to_date('18-02-2064', 'dd-mm-yyyy'), '1', '18', '049', '02', '2064', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23426, to_date('19-02-2064', 'dd-mm-yyyy'), '2', '19', '050', '02', '2064', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23427, to_date('20-02-2064', 'dd-mm-yyyy'), '3', '20', '051', '02', '2064', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23428, to_date('21-02-2064', 'dd-mm-yyyy'), '4', '21', '052', '02', '2064', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23429, to_date('22-02-2064', 'dd-mm-yyyy'), '5', '22', '053', '02', '2064', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23430, to_date('23-02-2064', 'dd-mm-yyyy'), '6', '23', '054', '02', '2064', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23431, to_date('24-02-2064', 'dd-mm-yyyy'), '7', '24', '055', '02', '2064', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23432, to_date('25-02-2064', 'dd-mm-yyyy'), '1', '25', '056', '02', '2064', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23433, to_date('26-02-2064', 'dd-mm-yyyy'), '2', '26', '057', '02', '2064', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23434, to_date('27-02-2064', 'dd-mm-yyyy'), '3', '27', '058', '02', '2064', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23435, to_date('28-02-2064', 'dd-mm-yyyy'), '4', '28', '059', '02', '2064', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23436, to_date('29-02-2064', 'dd-mm-yyyy'), '5', '29', '060', '02', '2064', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23437, to_date('01-03-2064', 'dd-mm-yyyy'), '6', '01', '061', '03', '2064', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23438, to_date('02-03-2064', 'dd-mm-yyyy'), '7', '02', '062', '03', '2064', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23439, to_date('03-03-2064', 'dd-mm-yyyy'), '1', '03', '063', '03', '2064', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23440, to_date('04-03-2064', 'dd-mm-yyyy'), '2', '04', '064', '03', '2064', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23441, to_date('05-03-2064', 'dd-mm-yyyy'), '3', '05', '065', '03', '2064', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23442, to_date('06-03-2064', 'dd-mm-yyyy'), '4', '06', '066', '03', '2064', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23443, to_date('07-03-2064', 'dd-mm-yyyy'), '5', '07', '067', '03', '2064', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23444, to_date('08-03-2064', 'dd-mm-yyyy'), '6', '08', '068', '03', '2064', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23445, to_date('09-03-2064', 'dd-mm-yyyy'), '7', '09', '069', '03', '2064', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23446, to_date('10-03-2064', 'dd-mm-yyyy'), '1', '10', '070', '03', '2064', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23447, to_date('11-03-2064', 'dd-mm-yyyy'), '2', '11', '071', '03', '2064', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23448, to_date('12-03-2064', 'dd-mm-yyyy'), '3', '12', '072', '03', '2064', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23449, to_date('13-03-2064', 'dd-mm-yyyy'), '4', '13', '073', '03', '2064', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23450, to_date('14-03-2064', 'dd-mm-yyyy'), '5', '14', '074', '03', '2064', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23451, to_date('15-03-2064', 'dd-mm-yyyy'), '6', '15', '075', '03', '2064', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23452, to_date('16-03-2064', 'dd-mm-yyyy'), '7', '16', '076', '03', '2064', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23453, to_date('17-03-2064', 'dd-mm-yyyy'), '1', '17', '077', '03', '2064', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23454, to_date('18-03-2064', 'dd-mm-yyyy'), '2', '18', '078', '03', '2064', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23455, to_date('19-03-2064', 'dd-mm-yyyy'), '3', '19', '079', '03', '2064', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23456, to_date('20-03-2064', 'dd-mm-yyyy'), '4', '20', '080', '03', '2064', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23457, to_date('21-03-2064', 'dd-mm-yyyy'), '5', '21', '081', '03', '2064', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23458, to_date('22-03-2064', 'dd-mm-yyyy'), '6', '22', '082', '03', '2064', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23459, to_date('23-03-2064', 'dd-mm-yyyy'), '7', '23', '083', '03', '2064', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23460, to_date('24-03-2064', 'dd-mm-yyyy'), '1', '24', '084', '03', '2064', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23461, to_date('25-03-2064', 'dd-mm-yyyy'), '2', '25', '085', '03', '2064', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23462, to_date('26-03-2064', 'dd-mm-yyyy'), '3', '26', '086', '03', '2064', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23463, to_date('27-03-2064', 'dd-mm-yyyy'), '4', '27', '087', '03', '2064', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23464, to_date('28-03-2064', 'dd-mm-yyyy'), '5', '28', '088', '03', '2064', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23465, to_date('29-03-2064', 'dd-mm-yyyy'), '6', '29', '089', '03', '2064', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23466, to_date('30-03-2064', 'dd-mm-yyyy'), '7', '30', '090', '03', '2064', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23467, to_date('31-03-2064', 'dd-mm-yyyy'), '1', '31', '091', '03', '2064', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23468, to_date('01-04-2064', 'dd-mm-yyyy'), '2', '01', '092', '04', '2064', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23469, to_date('02-04-2064', 'dd-mm-yyyy'), '3', '02', '093', '04', '2064', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23470, to_date('03-04-2064', 'dd-mm-yyyy'), '4', '03', '094', '04', '2064', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23471, to_date('04-04-2064', 'dd-mm-yyyy'), '5', '04', '095', '04', '2064', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23472, to_date('05-04-2064', 'dd-mm-yyyy'), '6', '05', '096', '04', '2064', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23473, to_date('06-04-2064', 'dd-mm-yyyy'), '7', '06', '097', '04', '2064', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23474, to_date('07-04-2064', 'dd-mm-yyyy'), '1', '07', '098', '04', '2064', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23475, to_date('08-04-2064', 'dd-mm-yyyy'), '2', '08', '099', '04', '2064', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23476, to_date('09-04-2064', 'dd-mm-yyyy'), '3', '09', '100', '04', '2064', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23477, to_date('10-04-2064', 'dd-mm-yyyy'), '4', '10', '101', '04', '2064', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23478, to_date('11-04-2064', 'dd-mm-yyyy'), '5', '11', '102', '04', '2064', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23479, to_date('12-04-2064', 'dd-mm-yyyy'), '6', '12', '103', '04', '2064', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23480, to_date('13-04-2064', 'dd-mm-yyyy'), '7', '13', '104', '04', '2064', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23481, to_date('14-04-2064', 'dd-mm-yyyy'), '1', '14', '105', '04', '2064', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23482, to_date('15-04-2064', 'dd-mm-yyyy'), '2', '15', '106', '04', '2064', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23483, to_date('16-04-2064', 'dd-mm-yyyy'), '3', '16', '107', '04', '2064', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23484, to_date('17-04-2064', 'dd-mm-yyyy'), '4', '17', '108', '04', '2064', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23485, to_date('18-04-2064', 'dd-mm-yyyy'), '5', '18', '109', '04', '2064', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23486, to_date('19-04-2064', 'dd-mm-yyyy'), '6', '19', '110', '04', '2064', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23487, to_date('20-04-2064', 'dd-mm-yyyy'), '7', '20', '111', '04', '2064', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23488, to_date('21-04-2064', 'dd-mm-yyyy'), '1', '21', '112', '04', '2064', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23489, to_date('22-04-2064', 'dd-mm-yyyy'), '2', '22', '113', '04', '2064', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23490, to_date('23-04-2064', 'dd-mm-yyyy'), '3', '23', '114', '04', '2064', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23491, to_date('24-04-2064', 'dd-mm-yyyy'), '4', '24', '115', '04', '2064', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23492, to_date('25-04-2064', 'dd-mm-yyyy'), '5', '25', '116', '04', '2064', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23493, to_date('26-04-2064', 'dd-mm-yyyy'), '6', '26', '117', '04', '2064', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23494, to_date('27-04-2064', 'dd-mm-yyyy'), '7', '27', '118', '04', '2064', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23495, to_date('28-04-2064', 'dd-mm-yyyy'), '1', '28', '119', '04', '2064', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23496, to_date('29-04-2064', 'dd-mm-yyyy'), '2', '29', '120', '04', '2064', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23497, to_date('30-04-2064', 'dd-mm-yyyy'), '3', '30', '121', '04', '2064', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23498, to_date('01-05-2064', 'dd-mm-yyyy'), '4', '01', '122', '05', '2064', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23499, to_date('02-05-2064', 'dd-mm-yyyy'), '5', '02', '123', '05', '2064', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23500, to_date('03-05-2064', 'dd-mm-yyyy'), '6', '03', '124', '05', '2064', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23501, to_date('04-05-2064', 'dd-mm-yyyy'), '7', '04', '125', '05', '2064', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23502, to_date('05-05-2064', 'dd-mm-yyyy'), '1', '05', '126', '05', '2064', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23503, to_date('06-05-2064', 'dd-mm-yyyy'), '2', '06', '127', '05', '2064', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23504, to_date('07-05-2064', 'dd-mm-yyyy'), '3', '07', '128', '05', '2064', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23505, to_date('08-05-2064', 'dd-mm-yyyy'), '4', '08', '129', '05', '2064', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23506, to_date('09-05-2064', 'dd-mm-yyyy'), '5', '09', '130', '05', '2064', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24991, to_date('02-06-2068', 'dd-mm-yyyy'), '6', '02', '154', '06', '2068', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24992, to_date('03-06-2068', 'dd-mm-yyyy'), '7', '03', '155', '06', '2068', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24993, to_date('04-06-2068', 'dd-mm-yyyy'), '1', '04', '156', '06', '2068', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24994, to_date('05-06-2068', 'dd-mm-yyyy'), '2', '05', '157', '06', '2068', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24995, to_date('06-06-2068', 'dd-mm-yyyy'), '3', '06', '158', '06', '2068', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24996, to_date('07-06-2068', 'dd-mm-yyyy'), '4', '07', '159', '06', '2068', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24997, to_date('08-06-2068', 'dd-mm-yyyy'), '5', '08', '160', '06', '2068', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24998, to_date('09-06-2068', 'dd-mm-yyyy'), '6', '09', '161', '06', '2068', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24999, to_date('10-06-2068', 'dd-mm-yyyy'), '7', '10', '162', '06', '2068', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25000, to_date('11-06-2068', 'dd-mm-yyyy'), '1', '11', '163', '06', '2068', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25001, to_date('12-06-2068', 'dd-mm-yyyy'), '2', '12', '164', '06', '2068', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25002, to_date('13-06-2068', 'dd-mm-yyyy'), '3', '13', '165', '06', '2068', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25003, to_date('14-06-2068', 'dd-mm-yyyy'), '4', '14', '166', '06', '2068', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25004, to_date('15-06-2068', 'dd-mm-yyyy'), '5', '15', '167', '06', '2068', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25005, to_date('16-06-2068', 'dd-mm-yyyy'), '6', '16', '168', '06', '2068', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25006, to_date('17-06-2068', 'dd-mm-yyyy'), '7', '17', '169', '06', '2068', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25007, to_date('18-06-2068', 'dd-mm-yyyy'), '1', '18', '170', '06', '2068', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25008, to_date('19-06-2068', 'dd-mm-yyyy'), '2', '19', '171', '06', '2068', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25009, to_date('20-06-2068', 'dd-mm-yyyy'), '3', '20', '172', '06', '2068', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25010, to_date('21-06-2068', 'dd-mm-yyyy'), '4', '21', '173', '06', '2068', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25011, to_date('22-06-2068', 'dd-mm-yyyy'), '5', '22', '174', '06', '2068', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25012, to_date('23-06-2068', 'dd-mm-yyyy'), '6', '23', '175', '06', '2068', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25013, to_date('24-06-2068', 'dd-mm-yyyy'), '7', '24', '176', '06', '2068', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25014, to_date('25-06-2068', 'dd-mm-yyyy'), '1', '25', '177', '06', '2068', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25015, to_date('26-06-2068', 'dd-mm-yyyy'), '2', '26', '178', '06', '2068', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25016, to_date('27-06-2068', 'dd-mm-yyyy'), '3', '27', '179', '06', '2068', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25017, to_date('28-06-2068', 'dd-mm-yyyy'), '4', '28', '180', '06', '2068', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25018, to_date('29-06-2068', 'dd-mm-yyyy'), '5', '29', '181', '06', '2068', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25019, to_date('30-06-2068', 'dd-mm-yyyy'), '6', '30', '182', '06', '2068', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25020, to_date('01-07-2068', 'dd-mm-yyyy'), '7', '01', '183', '07', '2068', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25021, to_date('02-07-2068', 'dd-mm-yyyy'), '1', '02', '184', '07', '2068', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25022, to_date('03-07-2068', 'dd-mm-yyyy'), '2', '03', '185', '07', '2068', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25023, to_date('04-07-2068', 'dd-mm-yyyy'), '3', '04', '186', '07', '2068', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25024, to_date('05-07-2068', 'dd-mm-yyyy'), '4', '05', '187', '07', '2068', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25025, to_date('06-07-2068', 'dd-mm-yyyy'), '5', '06', '188', '07', '2068', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25026, to_date('07-07-2068', 'dd-mm-yyyy'), '6', '07', '189', '07', '2068', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25027, to_date('08-07-2068', 'dd-mm-yyyy'), '7', '08', '190', '07', '2068', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25028, to_date('09-07-2068', 'dd-mm-yyyy'), '1', '09', '191', '07', '2068', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25029, to_date('10-07-2068', 'dd-mm-yyyy'), '2', '10', '192', '07', '2068', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25030, to_date('11-07-2068', 'dd-mm-yyyy'), '3', '11', '193', '07', '2068', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25031, to_date('12-07-2068', 'dd-mm-yyyy'), '4', '12', '194', '07', '2068', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25032, to_date('13-07-2068', 'dd-mm-yyyy'), '5', '13', '195', '07', '2068', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25033, to_date('14-07-2068', 'dd-mm-yyyy'), '6', '14', '196', '07', '2068', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25034, to_date('15-07-2068', 'dd-mm-yyyy'), '7', '15', '197', '07', '2068', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25035, to_date('16-07-2068', 'dd-mm-yyyy'), '1', '16', '198', '07', '2068', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25036, to_date('17-07-2068', 'dd-mm-yyyy'), '2', '17', '199', '07', '2068', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25037, to_date('18-07-2068', 'dd-mm-yyyy'), '3', '18', '200', '07', '2068', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25038, to_date('19-07-2068', 'dd-mm-yyyy'), '4', '19', '201', '07', '2068', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25039, to_date('20-07-2068', 'dd-mm-yyyy'), '5', '20', '202', '07', '2068', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25040, to_date('21-07-2068', 'dd-mm-yyyy'), '6', '21', '203', '07', '2068', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25041, to_date('22-07-2068', 'dd-mm-yyyy'), '7', '22', '204', '07', '2068', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25042, to_date('23-07-2068', 'dd-mm-yyyy'), '1', '23', '205', '07', '2068', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25043, to_date('24-07-2068', 'dd-mm-yyyy'), '2', '24', '206', '07', '2068', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25044, to_date('25-07-2068', 'dd-mm-yyyy'), '3', '25', '207', '07', '2068', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25045, to_date('26-07-2068', 'dd-mm-yyyy'), '4', '26', '208', '07', '2068', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25046, to_date('27-07-2068', 'dd-mm-yyyy'), '5', '27', '209', '07', '2068', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25047, to_date('28-07-2068', 'dd-mm-yyyy'), '6', '28', '210', '07', '2068', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25048, to_date('29-07-2068', 'dd-mm-yyyy'), '7', '29', '211', '07', '2068', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25049, to_date('30-07-2068', 'dd-mm-yyyy'), '1', '30', '212', '07', '2068', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25050, to_date('31-07-2068', 'dd-mm-yyyy'), '2', '31', '213', '07', '2068', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25051, to_date('01-08-2068', 'dd-mm-yyyy'), '3', '01', '214', '08', '2068', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25052, to_date('02-08-2068', 'dd-mm-yyyy'), '4', '02', '215', '08', '2068', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25053, to_date('03-08-2068', 'dd-mm-yyyy'), '5', '03', '216', '08', '2068', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25054, to_date('04-08-2068', 'dd-mm-yyyy'), '6', '04', '217', '08', '2068', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25055, to_date('05-08-2068', 'dd-mm-yyyy'), '7', '05', '218', '08', '2068', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25056, to_date('06-08-2068', 'dd-mm-yyyy'), '1', '06', '219', '08', '2068', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25057, to_date('07-08-2068', 'dd-mm-yyyy'), '2', '07', '220', '08', '2068', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25058, to_date('08-08-2068', 'dd-mm-yyyy'), '3', '08', '221', '08', '2068', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25059, to_date('09-08-2068', 'dd-mm-yyyy'), '4', '09', '222', '08', '2068', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25060, to_date('10-08-2068', 'dd-mm-yyyy'), '5', '10', '223', '08', '2068', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25061, to_date('11-08-2068', 'dd-mm-yyyy'), '6', '11', '224', '08', '2068', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25062, to_date('12-08-2068', 'dd-mm-yyyy'), '7', '12', '225', '08', '2068', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25063, to_date('13-08-2068', 'dd-mm-yyyy'), '1', '13', '226', '08', '2068', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25064, to_date('14-08-2068', 'dd-mm-yyyy'), '2', '14', '227', '08', '2068', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25065, to_date('15-08-2068', 'dd-mm-yyyy'), '3', '15', '228', '08', '2068', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25066, to_date('16-08-2068', 'dd-mm-yyyy'), '4', '16', '229', '08', '2068', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25067, to_date('17-08-2068', 'dd-mm-yyyy'), '5', '17', '230', '08', '2068', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25068, to_date('18-08-2068', 'dd-mm-yyyy'), '6', '18', '231', '08', '2068', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25069, to_date('19-08-2068', 'dd-mm-yyyy'), '7', '19', '232', '08', '2068', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25070, to_date('20-08-2068', 'dd-mm-yyyy'), '1', '20', '233', '08', '2068', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25071, to_date('21-08-2068', 'dd-mm-yyyy'), '2', '21', '234', '08', '2068', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25072, to_date('22-08-2068', 'dd-mm-yyyy'), '3', '22', '235', '08', '2068', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25073, to_date('23-08-2068', 'dd-mm-yyyy'), '4', '23', '236', '08', '2068', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25074, to_date('24-08-2068', 'dd-mm-yyyy'), '5', '24', '237', '08', '2068', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25075, to_date('25-08-2068', 'dd-mm-yyyy'), '6', '25', '238', '08', '2068', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25076, to_date('26-08-2068', 'dd-mm-yyyy'), '7', '26', '239', '08', '2068', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25077, to_date('27-08-2068', 'dd-mm-yyyy'), '1', '27', '240', '08', '2068', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25078, to_date('28-08-2068', 'dd-mm-yyyy'), '2', '28', '241', '08', '2068', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25079, to_date('29-08-2068', 'dd-mm-yyyy'), '3', '29', '242', '08', '2068', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25080, to_date('30-08-2068', 'dd-mm-yyyy'), '4', '30', '243', '08', '2068', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25081, to_date('31-08-2068', 'dd-mm-yyyy'), '5', '31', '244', '08', '2068', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25082, to_date('01-09-2068', 'dd-mm-yyyy'), '6', '01', '245', '09', '2068', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25083, to_date('02-09-2068', 'dd-mm-yyyy'), '7', '02', '246', '09', '2068', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25084, to_date('03-09-2068', 'dd-mm-yyyy'), '1', '03', '247', '09', '2068', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25085, to_date('04-09-2068', 'dd-mm-yyyy'), '2', '04', '248', '09', '2068', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25086, to_date('05-09-2068', 'dd-mm-yyyy'), '3', '05', '249', '09', '2068', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25087, to_date('06-09-2068', 'dd-mm-yyyy'), '4', '06', '250', '09', '2068', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25088, to_date('07-09-2068', 'dd-mm-yyyy'), '5', '07', '251', '09', '2068', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25089, to_date('08-09-2068', 'dd-mm-yyyy'), '6', '08', '252', '09', '2068', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25090, to_date('09-09-2068', 'dd-mm-yyyy'), '7', '09', '253', '09', '2068', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25091, to_date('10-09-2068', 'dd-mm-yyyy'), '1', '10', '254', '09', '2068', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25092, to_date('11-09-2068', 'dd-mm-yyyy'), '2', '11', '255', '09', '2068', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25093, to_date('12-09-2068', 'dd-mm-yyyy'), '3', '12', '256', '09', '2068', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25094, to_date('13-09-2068', 'dd-mm-yyyy'), '4', '13', '257', '09', '2068', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25095, to_date('14-09-2068', 'dd-mm-yyyy'), '5', '14', '258', '09', '2068', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25096, to_date('15-09-2068', 'dd-mm-yyyy'), '6', '15', '259', '09', '2068', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20327, to_date('26-08-2055', 'dd-mm-yyyy'), '4', '26', '238', '08', '2055', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20328, to_date('27-08-2055', 'dd-mm-yyyy'), '5', '27', '239', '08', '2055', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20329, to_date('28-08-2055', 'dd-mm-yyyy'), '6', '28', '240', '08', '2055', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20330, to_date('29-08-2055', 'dd-mm-yyyy'), '7', '29', '241', '08', '2055', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20331, to_date('30-08-2055', 'dd-mm-yyyy'), '1', '30', '242', '08', '2055', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20332, to_date('31-08-2055', 'dd-mm-yyyy'), '2', '31', '243', '08', '2055', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20333, to_date('01-09-2055', 'dd-mm-yyyy'), '3', '01', '244', '09', '2055', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20334, to_date('02-09-2055', 'dd-mm-yyyy'), '4', '02', '245', '09', '2055', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20335, to_date('03-09-2055', 'dd-mm-yyyy'), '5', '03', '246', '09', '2055', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20336, to_date('04-09-2055', 'dd-mm-yyyy'), '6', '04', '247', '09', '2055', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20337, to_date('05-09-2055', 'dd-mm-yyyy'), '7', '05', '248', '09', '2055', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20338, to_date('06-09-2055', 'dd-mm-yyyy'), '1', '06', '249', '09', '2055', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20339, to_date('07-09-2055', 'dd-mm-yyyy'), '2', '07', '250', '09', '2055', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20340, to_date('08-09-2055', 'dd-mm-yyyy'), '3', '08', '251', '09', '2055', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20341, to_date('09-09-2055', 'dd-mm-yyyy'), '4', '09', '252', '09', '2055', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20342, to_date('10-09-2055', 'dd-mm-yyyy'), '5', '10', '253', '09', '2055', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20343, to_date('11-09-2055', 'dd-mm-yyyy'), '6', '11', '254', '09', '2055', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20344, to_date('12-09-2055', 'dd-mm-yyyy'), '7', '12', '255', '09', '2055', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20345, to_date('13-09-2055', 'dd-mm-yyyy'), '1', '13', '256', '09', '2055', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20346, to_date('14-09-2055', 'dd-mm-yyyy'), '2', '14', '257', '09', '2055', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20347, to_date('15-09-2055', 'dd-mm-yyyy'), '3', '15', '258', '09', '2055', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20348, to_date('16-09-2055', 'dd-mm-yyyy'), '4', '16', '259', '09', '2055', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20349, to_date('17-09-2055', 'dd-mm-yyyy'), '5', '17', '260', '09', '2055', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20350, to_date('18-09-2055', 'dd-mm-yyyy'), '6', '18', '261', '09', '2055', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20351, to_date('19-09-2055', 'dd-mm-yyyy'), '7', '19', '262', '09', '2055', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20352, to_date('20-09-2055', 'dd-mm-yyyy'), '1', '20', '263', '09', '2055', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20353, to_date('21-09-2055', 'dd-mm-yyyy'), '2', '21', '264', '09', '2055', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20354, to_date('22-09-2055', 'dd-mm-yyyy'), '3', '22', '265', '09', '2055', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20355, to_date('23-09-2055', 'dd-mm-yyyy'), '4', '23', '266', '09', '2055', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20356, to_date('24-09-2055', 'dd-mm-yyyy'), '5', '24', '267', '09', '2055', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20357, to_date('25-09-2055', 'dd-mm-yyyy'), '6', '25', '268', '09', '2055', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20358, to_date('26-09-2055', 'dd-mm-yyyy'), '7', '26', '269', '09', '2055', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20359, to_date('27-09-2055', 'dd-mm-yyyy'), '1', '27', '270', '09', '2055', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20360, to_date('28-09-2055', 'dd-mm-yyyy'), '2', '28', '271', '09', '2055', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20361, to_date('29-09-2055', 'dd-mm-yyyy'), '3', '29', '272', '09', '2055', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20362, to_date('30-09-2055', 'dd-mm-yyyy'), '4', '30', '273', '09', '2055', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20363, to_date('01-10-2055', 'dd-mm-yyyy'), '5', '01', '274', '10', '2055', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20364, to_date('02-10-2055', 'dd-mm-yyyy'), '6', '02', '275', '10', '2055', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20365, to_date('03-10-2055', 'dd-mm-yyyy'), '7', '03', '276', '10', '2055', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20366, to_date('04-10-2055', 'dd-mm-yyyy'), '1', '04', '277', '10', '2055', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20367, to_date('05-10-2055', 'dd-mm-yyyy'), '2', '05', '278', '10', '2055', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20368, to_date('06-10-2055', 'dd-mm-yyyy'), '3', '06', '279', '10', '2055', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20369, to_date('07-10-2055', 'dd-mm-yyyy'), '4', '07', '280', '10', '2055', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20370, to_date('08-10-2055', 'dd-mm-yyyy'), '5', '08', '281', '10', '2055', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20371, to_date('09-10-2055', 'dd-mm-yyyy'), '6', '09', '282', '10', '2055', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20372, to_date('10-10-2055', 'dd-mm-yyyy'), '7', '10', '283', '10', '2055', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20373, to_date('11-10-2055', 'dd-mm-yyyy'), '1', '11', '284', '10', '2055', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20374, to_date('12-10-2055', 'dd-mm-yyyy'), '2', '12', '285', '10', '2055', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20375, to_date('13-10-2055', 'dd-mm-yyyy'), '3', '13', '286', '10', '2055', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20376, to_date('14-10-2055', 'dd-mm-yyyy'), '4', '14', '287', '10', '2055', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20377, to_date('15-10-2055', 'dd-mm-yyyy'), '5', '15', '288', '10', '2055', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20378, to_date('16-10-2055', 'dd-mm-yyyy'), '6', '16', '289', '10', '2055', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20379, to_date('17-10-2055', 'dd-mm-yyyy'), '7', '17', '290', '10', '2055', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20380, to_date('18-10-2055', 'dd-mm-yyyy'), '1', '18', '291', '10', '2055', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20381, to_date('19-10-2055', 'dd-mm-yyyy'), '2', '19', '292', '10', '2055', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20382, to_date('20-10-2055', 'dd-mm-yyyy'), '3', '20', '293', '10', '2055', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20383, to_date('21-10-2055', 'dd-mm-yyyy'), '4', '21', '294', '10', '2055', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20384, to_date('22-10-2055', 'dd-mm-yyyy'), '5', '22', '295', '10', '2055', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20385, to_date('23-10-2055', 'dd-mm-yyyy'), '6', '23', '296', '10', '2055', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20386, to_date('24-10-2055', 'dd-mm-yyyy'), '7', '24', '297', '10', '2055', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20387, to_date('25-10-2055', 'dd-mm-yyyy'), '1', '25', '298', '10', '2055', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20388, to_date('26-10-2055', 'dd-mm-yyyy'), '2', '26', '299', '10', '2055', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20389, to_date('27-10-2055', 'dd-mm-yyyy'), '3', '27', '300', '10', '2055', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20390, to_date('28-10-2055', 'dd-mm-yyyy'), '4', '28', '301', '10', '2055', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20391, to_date('29-10-2055', 'dd-mm-yyyy'), '5', '29', '302', '10', '2055', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20392, to_date('30-10-2055', 'dd-mm-yyyy'), '6', '30', '303', '10', '2055', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20393, to_date('31-10-2055', 'dd-mm-yyyy'), '7', '31', '304', '10', '2055', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20394, to_date('01-11-2055', 'dd-mm-yyyy'), '1', '01', '305', '11', '2055', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20395, to_date('02-11-2055', 'dd-mm-yyyy'), '2', '02', '306', '11', '2055', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20396, to_date('03-11-2055', 'dd-mm-yyyy'), '3', '03', '307', '11', '2055', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20397, to_date('04-11-2055', 'dd-mm-yyyy'), '4', '04', '308', '11', '2055', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20398, to_date('05-11-2055', 'dd-mm-yyyy'), '5', '05', '309', '11', '2055', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20399, to_date('06-11-2055', 'dd-mm-yyyy'), '6', '06', '310', '11', '2055', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20400, to_date('07-11-2055', 'dd-mm-yyyy'), '7', '07', '311', '11', '2055', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20401, to_date('08-11-2055', 'dd-mm-yyyy'), '1', '08', '312', '11', '2055', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20402, to_date('09-11-2055', 'dd-mm-yyyy'), '2', '09', '313', '11', '2055', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20403, to_date('10-11-2055', 'dd-mm-yyyy'), '3', '10', '314', '11', '2055', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20404, to_date('11-11-2055', 'dd-mm-yyyy'), '4', '11', '315', '11', '2055', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20405, to_date('12-11-2055', 'dd-mm-yyyy'), '5', '12', '316', '11', '2055', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20406, to_date('13-11-2055', 'dd-mm-yyyy'), '6', '13', '317', '11', '2055', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20407, to_date('14-11-2055', 'dd-mm-yyyy'), '7', '14', '318', '11', '2055', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20408, to_date('15-11-2055', 'dd-mm-yyyy'), '1', '15', '319', '11', '2055', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20409, to_date('16-11-2055', 'dd-mm-yyyy'), '2', '16', '320', '11', '2055', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20410, to_date('17-11-2055', 'dd-mm-yyyy'), '3', '17', '321', '11', '2055', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20411, to_date('18-11-2055', 'dd-mm-yyyy'), '4', '18', '322', '11', '2055', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20412, to_date('19-11-2055', 'dd-mm-yyyy'), '5', '19', '323', '11', '2055', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20413, to_date('20-11-2055', 'dd-mm-yyyy'), '6', '20', '324', '11', '2055', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20414, to_date('21-11-2055', 'dd-mm-yyyy'), '7', '21', '325', '11', '2055', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20415, to_date('22-11-2055', 'dd-mm-yyyy'), '1', '22', '326', '11', '2055', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20416, to_date('23-11-2055', 'dd-mm-yyyy'), '2', '23', '327', '11', '2055', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20417, to_date('24-11-2055', 'dd-mm-yyyy'), '3', '24', '328', '11', '2055', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20418, to_date('25-11-2055', 'dd-mm-yyyy'), '4', '25', '329', '11', '2055', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20419, to_date('26-11-2055', 'dd-mm-yyyy'), '5', '26', '330', '11', '2055', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20420, to_date('27-11-2055', 'dd-mm-yyyy'), '6', '27', '331', '11', '2055', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20421, to_date('28-11-2055', 'dd-mm-yyyy'), '7', '28', '332', '11', '2055', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20422, to_date('29-11-2055', 'dd-mm-yyyy'), '1', '29', '333', '11', '2055', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20423, to_date('30-11-2055', 'dd-mm-yyyy'), '2', '30', '334', '11', '2055', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20424, to_date('01-12-2055', 'dd-mm-yyyy'), '3', '01', '335', '12', '2055', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20425, to_date('02-12-2055', 'dd-mm-yyyy'), '4', '02', '336', '12', '2055', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20426, to_date('03-12-2055', 'dd-mm-yyyy'), '5', '03', '337', '12', '2055', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20427, to_date('04-12-2055', 'dd-mm-yyyy'), '6', '04', '338', '12', '2055', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20428, to_date('05-12-2055', 'dd-mm-yyyy'), '7', '05', '339', '12', '2055', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20429, to_date('06-12-2055', 'dd-mm-yyyy'), '1', '06', '340', '12', '2055', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20430, to_date('07-12-2055', 'dd-mm-yyyy'), '2', '07', '341', '12', '2055', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20431, to_date('08-12-2055', 'dd-mm-yyyy'), '3', '08', '342', '12', '2055', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20432, to_date('09-12-2055', 'dd-mm-yyyy'), '4', '09', '343', '12', '2055', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21917, to_date('02-01-2060', 'dd-mm-yyyy'), '5', '02', '002', '01', '2060', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21918, to_date('03-01-2060', 'dd-mm-yyyy'), '6', '03', '003', '01', '2060', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21919, to_date('04-01-2060', 'dd-mm-yyyy'), '7', '04', '004', '01', '2060', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21920, to_date('05-01-2060', 'dd-mm-yyyy'), '1', '05', '005', '01', '2060', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21921, to_date('06-01-2060', 'dd-mm-yyyy'), '2', '06', '006', '01', '2060', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21922, to_date('07-01-2060', 'dd-mm-yyyy'), '3', '07', '007', '01', '2060', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21923, to_date('08-01-2060', 'dd-mm-yyyy'), '4', '08', '008', '01', '2060', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21924, to_date('09-01-2060', 'dd-mm-yyyy'), '5', '09', '009', '01', '2060', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21925, to_date('10-01-2060', 'dd-mm-yyyy'), '6', '10', '010', '01', '2060', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21926, to_date('11-01-2060', 'dd-mm-yyyy'), '7', '11', '011', '01', '2060', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21927, to_date('12-01-2060', 'dd-mm-yyyy'), '1', '12', '012', '01', '2060', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21928, to_date('13-01-2060', 'dd-mm-yyyy'), '2', '13', '013', '01', '2060', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21929, to_date('14-01-2060', 'dd-mm-yyyy'), '3', '14', '014', '01', '2060', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21930, to_date('15-01-2060', 'dd-mm-yyyy'), '4', '15', '015', '01', '2060', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21931, to_date('16-01-2060', 'dd-mm-yyyy'), '5', '16', '016', '01', '2060', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21932, to_date('17-01-2060', 'dd-mm-yyyy'), '6', '17', '017', '01', '2060', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21933, to_date('18-01-2060', 'dd-mm-yyyy'), '7', '18', '018', '01', '2060', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21934, to_date('19-01-2060', 'dd-mm-yyyy'), '1', '19', '019', '01', '2060', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21935, to_date('20-01-2060', 'dd-mm-yyyy'), '2', '20', '020', '01', '2060', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21936, to_date('21-01-2060', 'dd-mm-yyyy'), '3', '21', '021', '01', '2060', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21937, to_date('22-01-2060', 'dd-mm-yyyy'), '4', '22', '022', '01', '2060', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21938, to_date('23-01-2060', 'dd-mm-yyyy'), '5', '23', '023', '01', '2060', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21939, to_date('24-01-2060', 'dd-mm-yyyy'), '6', '24', '024', '01', '2060', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21940, to_date('25-01-2060', 'dd-mm-yyyy'), '7', '25', '025', '01', '2060', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21941, to_date('26-01-2060', 'dd-mm-yyyy'), '1', '26', '026', '01', '2060', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21942, to_date('27-01-2060', 'dd-mm-yyyy'), '2', '27', '027', '01', '2060', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21943, to_date('28-01-2060', 'dd-mm-yyyy'), '3', '28', '028', '01', '2060', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21944, to_date('29-01-2060', 'dd-mm-yyyy'), '4', '29', '029', '01', '2060', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21945, to_date('30-01-2060', 'dd-mm-yyyy'), '5', '30', '030', '01', '2060', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21946, to_date('31-01-2060', 'dd-mm-yyyy'), '6', '31', '031', '01', '2060', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21947, to_date('01-02-2060', 'dd-mm-yyyy'), '7', '01', '032', '02', '2060', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21948, to_date('02-02-2060', 'dd-mm-yyyy'), '1', '02', '033', '02', '2060', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21949, to_date('03-02-2060', 'dd-mm-yyyy'), '2', '03', '034', '02', '2060', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21950, to_date('04-02-2060', 'dd-mm-yyyy'), '3', '04', '035', '02', '2060', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21951, to_date('05-02-2060', 'dd-mm-yyyy'), '4', '05', '036', '02', '2060', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21952, to_date('06-02-2060', 'dd-mm-yyyy'), '5', '06', '037', '02', '2060', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21953, to_date('07-02-2060', 'dd-mm-yyyy'), '6', '07', '038', '02', '2060', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21954, to_date('08-02-2060', 'dd-mm-yyyy'), '7', '08', '039', '02', '2060', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21955, to_date('09-02-2060', 'dd-mm-yyyy'), '1', '09', '040', '02', '2060', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21956, to_date('10-02-2060', 'dd-mm-yyyy'), '2', '10', '041', '02', '2060', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21957, to_date('11-02-2060', 'dd-mm-yyyy'), '3', '11', '042', '02', '2060', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21958, to_date('12-02-2060', 'dd-mm-yyyy'), '4', '12', '043', '02', '2060', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21959, to_date('13-02-2060', 'dd-mm-yyyy'), '5', '13', '044', '02', '2060', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21960, to_date('14-02-2060', 'dd-mm-yyyy'), '6', '14', '045', '02', '2060', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21961, to_date('15-02-2060', 'dd-mm-yyyy'), '7', '15', '046', '02', '2060', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21962, to_date('16-02-2060', 'dd-mm-yyyy'), '1', '16', '047', '02', '2060', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21963, to_date('17-02-2060', 'dd-mm-yyyy'), '2', '17', '048', '02', '2060', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21964, to_date('18-02-2060', 'dd-mm-yyyy'), '3', '18', '049', '02', '2060', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21965, to_date('19-02-2060', 'dd-mm-yyyy'), '4', '19', '050', '02', '2060', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21966, to_date('20-02-2060', 'dd-mm-yyyy'), '5', '20', '051', '02', '2060', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21967, to_date('21-02-2060', 'dd-mm-yyyy'), '6', '21', '052', '02', '2060', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21968, to_date('22-02-2060', 'dd-mm-yyyy'), '7', '22', '053', '02', '2060', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21969, to_date('23-02-2060', 'dd-mm-yyyy'), '1', '23', '054', '02', '2060', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21970, to_date('24-02-2060', 'dd-mm-yyyy'), '2', '24', '055', '02', '2060', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21971, to_date('25-02-2060', 'dd-mm-yyyy'), '3', '25', '056', '02', '2060', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21972, to_date('26-02-2060', 'dd-mm-yyyy'), '4', '26', '057', '02', '2060', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21973, to_date('27-02-2060', 'dd-mm-yyyy'), '5', '27', '058', '02', '2060', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21974, to_date('28-02-2060', 'dd-mm-yyyy'), '6', '28', '059', '02', '2060', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21975, to_date('29-02-2060', 'dd-mm-yyyy'), '7', '29', '060', '02', '2060', '09', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21976, to_date('01-03-2060', 'dd-mm-yyyy'), '1', '01', '061', '03', '2060', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21977, to_date('02-03-2060', 'dd-mm-yyyy'), '2', '02', '062', '03', '2060', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21978, to_date('03-03-2060', 'dd-mm-yyyy'), '3', '03', '063', '03', '2060', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21979, to_date('04-03-2060', 'dd-mm-yyyy'), '4', '04', '064', '03', '2060', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21980, to_date('05-03-2060', 'dd-mm-yyyy'), '5', '05', '065', '03', '2060', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21981, to_date('06-03-2060', 'dd-mm-yyyy'), '6', '06', '066', '03', '2060', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21982, to_date('07-03-2060', 'dd-mm-yyyy'), '7', '07', '067', '03', '2060', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
commit;
prompt 17000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21983, to_date('08-03-2060', 'dd-mm-yyyy'), '1', '08', '068', '03', '2060', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21984, to_date('09-03-2060', 'dd-mm-yyyy'), '2', '09', '069', '03', '2060', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21985, to_date('10-03-2060', 'dd-mm-yyyy'), '3', '10', '070', '03', '2060', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21986, to_date('11-03-2060', 'dd-mm-yyyy'), '4', '11', '071', '03', '2060', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21987, to_date('12-03-2060', 'dd-mm-yyyy'), '5', '12', '072', '03', '2060', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21988, to_date('13-03-2060', 'dd-mm-yyyy'), '6', '13', '073', '03', '2060', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21989, to_date('14-03-2060', 'dd-mm-yyyy'), '7', '14', '074', '03', '2060', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21990, to_date('15-03-2060', 'dd-mm-yyyy'), '1', '15', '075', '03', '2060', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21991, to_date('16-03-2060', 'dd-mm-yyyy'), '2', '16', '076', '03', '2060', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21992, to_date('17-03-2060', 'dd-mm-yyyy'), '3', '17', '077', '03', '2060', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21993, to_date('18-03-2060', 'dd-mm-yyyy'), '4', '18', '078', '03', '2060', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21994, to_date('19-03-2060', 'dd-mm-yyyy'), '5', '19', '079', '03', '2060', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21995, to_date('20-03-2060', 'dd-mm-yyyy'), '6', '20', '080', '03', '2060', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21996, to_date('21-03-2060', 'dd-mm-yyyy'), '7', '21', '081', '03', '2060', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21997, to_date('22-03-2060', 'dd-mm-yyyy'), '1', '22', '082', '03', '2060', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21998, to_date('23-03-2060', 'dd-mm-yyyy'), '2', '23', '083', '03', '2060', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (21999, to_date('24-03-2060', 'dd-mm-yyyy'), '3', '24', '084', '03', '2060', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22000, to_date('25-03-2060', 'dd-mm-yyyy'), '4', '25', '085', '03', '2060', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22001, to_date('26-03-2060', 'dd-mm-yyyy'), '5', '26', '086', '03', '2060', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22002, to_date('27-03-2060', 'dd-mm-yyyy'), '6', '27', '087', '03', '2060', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22003, to_date('28-03-2060', 'dd-mm-yyyy'), '7', '28', '088', '03', '2060', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22004, to_date('29-03-2060', 'dd-mm-yyyy'), '1', '29', '089', '03', '2060', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22005, to_date('30-03-2060', 'dd-mm-yyyy'), '2', '30', '090', '03', '2060', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22006, to_date('31-03-2060', 'dd-mm-yyyy'), '3', '31', '091', '03', '2060', '14', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22007, to_date('01-04-2060', 'dd-mm-yyyy'), '4', '01', '092', '04', '2060', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22008, to_date('02-04-2060', 'dd-mm-yyyy'), '5', '02', '093', '04', '2060', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22009, to_date('03-04-2060', 'dd-mm-yyyy'), '6', '03', '094', '04', '2060', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22010, to_date('04-04-2060', 'dd-mm-yyyy'), '7', '04', '095', '04', '2060', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22011, to_date('05-04-2060', 'dd-mm-yyyy'), '1', '05', '096', '04', '2060', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22012, to_date('06-04-2060', 'dd-mm-yyyy'), '2', '06', '097', '04', '2060', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22013, to_date('07-04-2060', 'dd-mm-yyyy'), '3', '07', '098', '04', '2060', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22014, to_date('08-04-2060', 'dd-mm-yyyy'), '4', '08', '099', '04', '2060', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22015, to_date('09-04-2060', 'dd-mm-yyyy'), '5', '09', '100', '04', '2060', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22016, to_date('10-04-2060', 'dd-mm-yyyy'), '6', '10', '101', '04', '2060', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22017, to_date('11-04-2060', 'dd-mm-yyyy'), '7', '11', '102', '04', '2060', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22018, to_date('12-04-2060', 'dd-mm-yyyy'), '1', '12', '103', '04', '2060', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22019, to_date('13-04-2060', 'dd-mm-yyyy'), '2', '13', '104', '04', '2060', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22020, to_date('14-04-2060', 'dd-mm-yyyy'), '3', '14', '105', '04', '2060', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22021, to_date('15-04-2060', 'dd-mm-yyyy'), '4', '15', '106', '04', '2060', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22022, to_date('16-04-2060', 'dd-mm-yyyy'), '5', '16', '107', '04', '2060', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23507, to_date('10-05-2064', 'dd-mm-yyyy'), '6', '10', '131', '05', '2064', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23508, to_date('11-05-2064', 'dd-mm-yyyy'), '7', '11', '132', '05', '2064', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23509, to_date('12-05-2064', 'dd-mm-yyyy'), '1', '12', '133', '05', '2064', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23510, to_date('13-05-2064', 'dd-mm-yyyy'), '2', '13', '134', '05', '2064', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23511, to_date('14-05-2064', 'dd-mm-yyyy'), '3', '14', '135', '05', '2064', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23512, to_date('15-05-2064', 'dd-mm-yyyy'), '4', '15', '136', '05', '2064', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23513, to_date('16-05-2064', 'dd-mm-yyyy'), '5', '16', '137', '05', '2064', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23514, to_date('17-05-2064', 'dd-mm-yyyy'), '6', '17', '138', '05', '2064', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23515, to_date('18-05-2064', 'dd-mm-yyyy'), '7', '18', '139', '05', '2064', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23516, to_date('19-05-2064', 'dd-mm-yyyy'), '1', '19', '140', '05', '2064', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23517, to_date('20-05-2064', 'dd-mm-yyyy'), '2', '20', '141', '05', '2064', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23518, to_date('21-05-2064', 'dd-mm-yyyy'), '3', '21', '142', '05', '2064', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23519, to_date('22-05-2064', 'dd-mm-yyyy'), '4', '22', '143', '05', '2064', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23520, to_date('23-05-2064', 'dd-mm-yyyy'), '5', '23', '144', '05', '2064', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23521, to_date('24-05-2064', 'dd-mm-yyyy'), '6', '24', '145', '05', '2064', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23522, to_date('25-05-2064', 'dd-mm-yyyy'), '7', '25', '146', '05', '2064', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23523, to_date('26-05-2064', 'dd-mm-yyyy'), '1', '26', '147', '05', '2064', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23524, to_date('27-05-2064', 'dd-mm-yyyy'), '2', '27', '148', '05', '2064', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23525, to_date('28-05-2064', 'dd-mm-yyyy'), '3', '28', '149', '05', '2064', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23526, to_date('29-05-2064', 'dd-mm-yyyy'), '4', '29', '150', '05', '2064', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23527, to_date('30-05-2064', 'dd-mm-yyyy'), '5', '30', '151', '05', '2064', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23528, to_date('31-05-2064', 'dd-mm-yyyy'), '6', '31', '152', '05', '2064', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23529, to_date('01-06-2064', 'dd-mm-yyyy'), '7', '01', '153', '06', '2064', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23530, to_date('02-06-2064', 'dd-mm-yyyy'), '1', '02', '154', '06', '2064', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23531, to_date('03-06-2064', 'dd-mm-yyyy'), '2', '03', '155', '06', '2064', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23532, to_date('04-06-2064', 'dd-mm-yyyy'), '3', '04', '156', '06', '2064', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23533, to_date('05-06-2064', 'dd-mm-yyyy'), '4', '05', '157', '06', '2064', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23534, to_date('06-06-2064', 'dd-mm-yyyy'), '5', '06', '158', '06', '2064', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23535, to_date('07-06-2064', 'dd-mm-yyyy'), '6', '07', '159', '06', '2064', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23536, to_date('08-06-2064', 'dd-mm-yyyy'), '7', '08', '160', '06', '2064', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23537, to_date('09-06-2064', 'dd-mm-yyyy'), '1', '09', '161', '06', '2064', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23538, to_date('10-06-2064', 'dd-mm-yyyy'), '2', '10', '162', '06', '2064', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23539, to_date('11-06-2064', 'dd-mm-yyyy'), '3', '11', '163', '06', '2064', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23540, to_date('12-06-2064', 'dd-mm-yyyy'), '4', '12', '164', '06', '2064', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23541, to_date('13-06-2064', 'dd-mm-yyyy'), '5', '13', '165', '06', '2064', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23542, to_date('14-06-2064', 'dd-mm-yyyy'), '6', '14', '166', '06', '2064', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23543, to_date('15-06-2064', 'dd-mm-yyyy'), '7', '15', '167', '06', '2064', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23544, to_date('16-06-2064', 'dd-mm-yyyy'), '1', '16', '168', '06', '2064', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23545, to_date('17-06-2064', 'dd-mm-yyyy'), '2', '17', '169', '06', '2064', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23546, to_date('18-06-2064', 'dd-mm-yyyy'), '3', '18', '170', '06', '2064', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23547, to_date('19-06-2064', 'dd-mm-yyyy'), '4', '19', '171', '06', '2064', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23548, to_date('20-06-2064', 'dd-mm-yyyy'), '5', '20', '172', '06', '2064', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23549, to_date('21-06-2064', 'dd-mm-yyyy'), '6', '21', '173', '06', '2064', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23550, to_date('22-06-2064', 'dd-mm-yyyy'), '7', '22', '174', '06', '2064', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23551, to_date('23-06-2064', 'dd-mm-yyyy'), '1', '23', '175', '06', '2064', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23552, to_date('24-06-2064', 'dd-mm-yyyy'), '2', '24', '176', '06', '2064', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23553, to_date('25-06-2064', 'dd-mm-yyyy'), '3', '25', '177', '06', '2064', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23554, to_date('26-06-2064', 'dd-mm-yyyy'), '4', '26', '178', '06', '2064', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23555, to_date('27-06-2064', 'dd-mm-yyyy'), '5', '27', '179', '06', '2064', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23556, to_date('28-06-2064', 'dd-mm-yyyy'), '6', '28', '180', '06', '2064', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23557, to_date('29-06-2064', 'dd-mm-yyyy'), '7', '29', '181', '06', '2064', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23558, to_date('30-06-2064', 'dd-mm-yyyy'), '1', '30', '182', '06', '2064', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23559, to_date('01-07-2064', 'dd-mm-yyyy'), '2', '01', '183', '07', '2064', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23560, to_date('02-07-2064', 'dd-mm-yyyy'), '3', '02', '184', '07', '2064', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23561, to_date('03-07-2064', 'dd-mm-yyyy'), '4', '03', '185', '07', '2064', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23562, to_date('04-07-2064', 'dd-mm-yyyy'), '5', '04', '186', '07', '2064', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23563, to_date('05-07-2064', 'dd-mm-yyyy'), '6', '05', '187', '07', '2064', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23564, to_date('06-07-2064', 'dd-mm-yyyy'), '7', '06', '188', '07', '2064', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23565, to_date('07-07-2064', 'dd-mm-yyyy'), '1', '07', '189', '07', '2064', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23566, to_date('08-07-2064', 'dd-mm-yyyy'), '2', '08', '190', '07', '2064', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23567, to_date('09-07-2064', 'dd-mm-yyyy'), '3', '09', '191', '07', '2064', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23568, to_date('10-07-2064', 'dd-mm-yyyy'), '4', '10', '192', '07', '2064', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23569, to_date('11-07-2064', 'dd-mm-yyyy'), '5', '11', '193', '07', '2064', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23570, to_date('12-07-2064', 'dd-mm-yyyy'), '6', '12', '194', '07', '2064', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23571, to_date('13-07-2064', 'dd-mm-yyyy'), '7', '13', '195', '07', '2064', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23572, to_date('14-07-2064', 'dd-mm-yyyy'), '1', '14', '196', '07', '2064', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23573, to_date('15-07-2064', 'dd-mm-yyyy'), '2', '15', '197', '07', '2064', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23574, to_date('16-07-2064', 'dd-mm-yyyy'), '3', '16', '198', '07', '2064', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23575, to_date('17-07-2064', 'dd-mm-yyyy'), '4', '17', '199', '07', '2064', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23576, to_date('18-07-2064', 'dd-mm-yyyy'), '5', '18', '200', '07', '2064', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23577, to_date('19-07-2064', 'dd-mm-yyyy'), '6', '19', '201', '07', '2064', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23578, to_date('20-07-2064', 'dd-mm-yyyy'), '7', '20', '202', '07', '2064', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23579, to_date('21-07-2064', 'dd-mm-yyyy'), '1', '21', '203', '07', '2064', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23580, to_date('22-07-2064', 'dd-mm-yyyy'), '2', '22', '204', '07', '2064', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23581, to_date('23-07-2064', 'dd-mm-yyyy'), '3', '23', '205', '07', '2064', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23582, to_date('24-07-2064', 'dd-mm-yyyy'), '4', '24', '206', '07', '2064', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23583, to_date('25-07-2064', 'dd-mm-yyyy'), '5', '25', '207', '07', '2064', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23584, to_date('26-07-2064', 'dd-mm-yyyy'), '6', '26', '208', '07', '2064', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23585, to_date('27-07-2064', 'dd-mm-yyyy'), '7', '27', '209', '07', '2064', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23586, to_date('28-07-2064', 'dd-mm-yyyy'), '1', '28', '210', '07', '2064', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23587, to_date('29-07-2064', 'dd-mm-yyyy'), '2', '29', '211', '07', '2064', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23588, to_date('30-07-2064', 'dd-mm-yyyy'), '3', '30', '212', '07', '2064', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23589, to_date('31-07-2064', 'dd-mm-yyyy'), '4', '31', '213', '07', '2064', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23590, to_date('01-08-2064', 'dd-mm-yyyy'), '5', '01', '214', '08', '2064', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23591, to_date('02-08-2064', 'dd-mm-yyyy'), '6', '02', '215', '08', '2064', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23592, to_date('03-08-2064', 'dd-mm-yyyy'), '7', '03', '216', '08', '2064', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23593, to_date('04-08-2064', 'dd-mm-yyyy'), '1', '04', '217', '08', '2064', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23594, to_date('05-08-2064', 'dd-mm-yyyy'), '2', '05', '218', '08', '2064', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23595, to_date('06-08-2064', 'dd-mm-yyyy'), '3', '06', '219', '08', '2064', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23596, to_date('07-08-2064', 'dd-mm-yyyy'), '4', '07', '220', '08', '2064', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23597, to_date('08-08-2064', 'dd-mm-yyyy'), '5', '08', '221', '08', '2064', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23598, to_date('09-08-2064', 'dd-mm-yyyy'), '6', '09', '222', '08', '2064', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23599, to_date('10-08-2064', 'dd-mm-yyyy'), '7', '10', '223', '08', '2064', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23600, to_date('11-08-2064', 'dd-mm-yyyy'), '1', '11', '224', '08', '2064', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23601, to_date('12-08-2064', 'dd-mm-yyyy'), '2', '12', '225', '08', '2064', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23602, to_date('13-08-2064', 'dd-mm-yyyy'), '3', '13', '226', '08', '2064', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23603, to_date('14-08-2064', 'dd-mm-yyyy'), '4', '14', '227', '08', '2064', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23604, to_date('15-08-2064', 'dd-mm-yyyy'), '5', '15', '228', '08', '2064', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23605, to_date('16-08-2064', 'dd-mm-yyyy'), '6', '16', '229', '08', '2064', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23606, to_date('17-08-2064', 'dd-mm-yyyy'), '7', '17', '230', '08', '2064', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23607, to_date('18-08-2064', 'dd-mm-yyyy'), '1', '18', '231', '08', '2064', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23608, to_date('19-08-2064', 'dd-mm-yyyy'), '2', '19', '232', '08', '2064', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23609, to_date('20-08-2064', 'dd-mm-yyyy'), '3', '20', '233', '08', '2064', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23610, to_date('21-08-2064', 'dd-mm-yyyy'), '4', '21', '234', '08', '2064', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23611, to_date('22-08-2064', 'dd-mm-yyyy'), '5', '22', '235', '08', '2064', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23612, to_date('23-08-2064', 'dd-mm-yyyy'), '6', '23', '236', '08', '2064', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25097, to_date('16-09-2068', 'dd-mm-yyyy'), '7', '16', '260', '09', '2068', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25098, to_date('17-09-2068', 'dd-mm-yyyy'), '1', '17', '261', '09', '2068', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25099, to_date('18-09-2068', 'dd-mm-yyyy'), '2', '18', '262', '09', '2068', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25100, to_date('19-09-2068', 'dd-mm-yyyy'), '3', '19', '263', '09', '2068', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25101, to_date('20-09-2068', 'dd-mm-yyyy'), '4', '20', '264', '09', '2068', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25102, to_date('21-09-2068', 'dd-mm-yyyy'), '5', '21', '265', '09', '2068', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25103, to_date('22-09-2068', 'dd-mm-yyyy'), '6', '22', '266', '09', '2068', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25104, to_date('23-09-2068', 'dd-mm-yyyy'), '7', '23', '267', '09', '2068', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25105, to_date('24-09-2068', 'dd-mm-yyyy'), '1', '24', '268', '09', '2068', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25106, to_date('25-09-2068', 'dd-mm-yyyy'), '2', '25', '269', '09', '2068', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25107, to_date('26-09-2068', 'dd-mm-yyyy'), '3', '26', '270', '09', '2068', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25108, to_date('27-09-2068', 'dd-mm-yyyy'), '4', '27', '271', '09', '2068', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25109, to_date('28-09-2068', 'dd-mm-yyyy'), '5', '28', '272', '09', '2068', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25110, to_date('29-09-2068', 'dd-mm-yyyy'), '6', '29', '273', '09', '2068', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25111, to_date('30-09-2068', 'dd-mm-yyyy'), '7', '30', '274', '09', '2068', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25112, to_date('01-10-2068', 'dd-mm-yyyy'), '1', '01', '275', '10', '2068', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25113, to_date('02-10-2068', 'dd-mm-yyyy'), '2', '02', '276', '10', '2068', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25114, to_date('03-10-2068', 'dd-mm-yyyy'), '3', '03', '277', '10', '2068', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25115, to_date('04-10-2068', 'dd-mm-yyyy'), '4', '04', '278', '10', '2068', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25116, to_date('05-10-2068', 'dd-mm-yyyy'), '5', '05', '279', '10', '2068', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25117, to_date('06-10-2068', 'dd-mm-yyyy'), '6', '06', '280', '10', '2068', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25118, to_date('07-10-2068', 'dd-mm-yyyy'), '7', '07', '281', '10', '2068', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25119, to_date('08-10-2068', 'dd-mm-yyyy'), '1', '08', '282', '10', '2068', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25120, to_date('09-10-2068', 'dd-mm-yyyy'), '2', '09', '283', '10', '2068', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25121, to_date('10-10-2068', 'dd-mm-yyyy'), '3', '10', '284', '10', '2068', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25122, to_date('11-10-2068', 'dd-mm-yyyy'), '4', '11', '285', '10', '2068', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25123, to_date('12-10-2068', 'dd-mm-yyyy'), '5', '12', '286', '10', '2068', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25124, to_date('13-10-2068', 'dd-mm-yyyy'), '6', '13', '287', '10', '2068', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25125, to_date('14-10-2068', 'dd-mm-yyyy'), '7', '14', '288', '10', '2068', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25126, to_date('15-10-2068', 'dd-mm-yyyy'), '1', '15', '289', '10', '2068', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25127, to_date('16-10-2068', 'dd-mm-yyyy'), '2', '16', '290', '10', '2068', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25128, to_date('17-10-2068', 'dd-mm-yyyy'), '3', '17', '291', '10', '2068', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25129, to_date('18-10-2068', 'dd-mm-yyyy'), '4', '18', '292', '10', '2068', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25130, to_date('19-10-2068', 'dd-mm-yyyy'), '5', '19', '293', '10', '2068', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25131, to_date('20-10-2068', 'dd-mm-yyyy'), '6', '20', '294', '10', '2068', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25132, to_date('21-10-2068', 'dd-mm-yyyy'), '7', '21', '295', '10', '2068', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25133, to_date('22-10-2068', 'dd-mm-yyyy'), '1', '22', '296', '10', '2068', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25134, to_date('23-10-2068', 'dd-mm-yyyy'), '2', '23', '297', '10', '2068', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25135, to_date('24-10-2068', 'dd-mm-yyyy'), '3', '24', '298', '10', '2068', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25136, to_date('25-10-2068', 'dd-mm-yyyy'), '4', '25', '299', '10', '2068', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25137, to_date('26-10-2068', 'dd-mm-yyyy'), '5', '26', '300', '10', '2068', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25138, to_date('27-10-2068', 'dd-mm-yyyy'), '6', '27', '301', '10', '2068', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25139, to_date('28-10-2068', 'dd-mm-yyyy'), '7', '28', '302', '10', '2068', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25140, to_date('29-10-2068', 'dd-mm-yyyy'), '1', '29', '303', '10', '2068', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25141, to_date('30-10-2068', 'dd-mm-yyyy'), '2', '30', '304', '10', '2068', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25142, to_date('31-10-2068', 'dd-mm-yyyy'), '3', '31', '305', '10', '2068', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25143, to_date('01-11-2068', 'dd-mm-yyyy'), '4', '01', '306', '11', '2068', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25144, to_date('02-11-2068', 'dd-mm-yyyy'), '5', '02', '307', '11', '2068', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25145, to_date('03-11-2068', 'dd-mm-yyyy'), '6', '03', '308', '11', '2068', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25146, to_date('04-11-2068', 'dd-mm-yyyy'), '7', '04', '309', '11', '2068', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25147, to_date('05-11-2068', 'dd-mm-yyyy'), '1', '05', '310', '11', '2068', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25148, to_date('06-11-2068', 'dd-mm-yyyy'), '2', '06', '311', '11', '2068', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25149, to_date('07-11-2068', 'dd-mm-yyyy'), '3', '07', '312', '11', '2068', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25150, to_date('08-11-2068', 'dd-mm-yyyy'), '4', '08', '313', '11', '2068', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25151, to_date('09-11-2068', 'dd-mm-yyyy'), '5', '09', '314', '11', '2068', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25152, to_date('10-11-2068', 'dd-mm-yyyy'), '6', '10', '315', '11', '2068', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25153, to_date('11-11-2068', 'dd-mm-yyyy'), '7', '11', '316', '11', '2068', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25154, to_date('12-11-2068', 'dd-mm-yyyy'), '1', '12', '317', '11', '2068', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25155, to_date('13-11-2068', 'dd-mm-yyyy'), '2', '13', '318', '11', '2068', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25156, to_date('14-11-2068', 'dd-mm-yyyy'), '3', '14', '319', '11', '2068', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25157, to_date('15-11-2068', 'dd-mm-yyyy'), '4', '15', '320', '11', '2068', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25158, to_date('16-11-2068', 'dd-mm-yyyy'), '5', '16', '321', '11', '2068', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25159, to_date('17-11-2068', 'dd-mm-yyyy'), '6', '17', '322', '11', '2068', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25160, to_date('18-11-2068', 'dd-mm-yyyy'), '7', '18', '323', '11', '2068', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25161, to_date('19-11-2068', 'dd-mm-yyyy'), '1', '19', '324', '11', '2068', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25162, to_date('20-11-2068', 'dd-mm-yyyy'), '2', '20', '325', '11', '2068', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25163, to_date('21-11-2068', 'dd-mm-yyyy'), '3', '21', '326', '11', '2068', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25164, to_date('22-11-2068', 'dd-mm-yyyy'), '4', '22', '327', '11', '2068', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25165, to_date('23-11-2068', 'dd-mm-yyyy'), '5', '23', '328', '11', '2068', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25166, to_date('24-11-2068', 'dd-mm-yyyy'), '6', '24', '329', '11', '2068', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25167, to_date('25-11-2068', 'dd-mm-yyyy'), '7', '25', '330', '11', '2068', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25168, to_date('26-11-2068', 'dd-mm-yyyy'), '1', '26', '331', '11', '2068', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25169, to_date('27-11-2068', 'dd-mm-yyyy'), '2', '27', '332', '11', '2068', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25170, to_date('28-11-2068', 'dd-mm-yyyy'), '3', '28', '333', '11', '2068', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25171, to_date('29-11-2068', 'dd-mm-yyyy'), '4', '29', '334', '11', '2068', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25172, to_date('30-11-2068', 'dd-mm-yyyy'), '5', '30', '335', '11', '2068', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25173, to_date('01-12-2068', 'dd-mm-yyyy'), '6', '01', '336', '12', '2068', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25174, to_date('02-12-2068', 'dd-mm-yyyy'), '7', '02', '337', '12', '2068', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25175, to_date('03-12-2068', 'dd-mm-yyyy'), '1', '03', '338', '12', '2068', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25176, to_date('04-12-2068', 'dd-mm-yyyy'), '2', '04', '339', '12', '2068', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25177, to_date('05-12-2068', 'dd-mm-yyyy'), '3', '05', '340', '12', '2068', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25178, to_date('06-12-2068', 'dd-mm-yyyy'), '4', '06', '341', '12', '2068', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25179, to_date('07-12-2068', 'dd-mm-yyyy'), '5', '07', '342', '12', '2068', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25180, to_date('08-12-2068', 'dd-mm-yyyy'), '6', '08', '343', '12', '2068', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25181, to_date('09-12-2068', 'dd-mm-yyyy'), '7', '09', '344', '12', '2068', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25182, to_date('10-12-2068', 'dd-mm-yyyy'), '1', '10', '345', '12', '2068', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25183, to_date('11-12-2068', 'dd-mm-yyyy'), '2', '11', '346', '12', '2068', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25184, to_date('12-12-2068', 'dd-mm-yyyy'), '3', '12', '347', '12', '2068', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25185, to_date('13-12-2068', 'dd-mm-yyyy'), '4', '13', '348', '12', '2068', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25186, to_date('14-12-2068', 'dd-mm-yyyy'), '5', '14', '349', '12', '2068', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25187, to_date('15-12-2068', 'dd-mm-yyyy'), '6', '15', '350', '12', '2068', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25188, to_date('16-12-2068', 'dd-mm-yyyy'), '7', '16', '351', '12', '2068', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25189, to_date('17-12-2068', 'dd-mm-yyyy'), '1', '17', '352', '12', '2068', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25190, to_date('18-12-2068', 'dd-mm-yyyy'), '2', '18', '353', '12', '2068', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25191, to_date('19-12-2068', 'dd-mm-yyyy'), '3', '19', '354', '12', '2068', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25192, to_date('20-12-2068', 'dd-mm-yyyy'), '4', '20', '355', '12', '2068', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25193, to_date('21-12-2068', 'dd-mm-yyyy'), '5', '21', '356', '12', '2068', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25194, to_date('22-12-2068', 'dd-mm-yyyy'), '6', '22', '357', '12', '2068', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25195, to_date('23-12-2068', 'dd-mm-yyyy'), '7', '23', '358', '12', '2068', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25196, to_date('24-12-2068', 'dd-mm-yyyy'), '1', '24', '359', '12', '2068', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25197, to_date('25-12-2068', 'dd-mm-yyyy'), '2', '25', '360', '12', '2068', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25198, to_date('26-12-2068', 'dd-mm-yyyy'), '3', '26', '361', '12', '2068', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25199, to_date('27-12-2068', 'dd-mm-yyyy'), '4', '27', '362', '12', '2068', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25200, to_date('28-12-2068', 'dd-mm-yyyy'), '5', '28', '363', '12', '2068', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25201, to_date('29-12-2068', 'dd-mm-yyyy'), '6', '29', '364', '12', '2068', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25202, to_date('30-12-2068', 'dd-mm-yyyy'), '7', '30', '365', '12', '2068', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20433, to_date('10-12-2055', 'dd-mm-yyyy'), '5', '10', '344', '12', '2055', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20434, to_date('11-12-2055', 'dd-mm-yyyy'), '6', '11', '345', '12', '2055', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20435, to_date('12-12-2055', 'dd-mm-yyyy'), '7', '12', '346', '12', '2055', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20436, to_date('13-12-2055', 'dd-mm-yyyy'), '1', '13', '347', '12', '2055', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20437, to_date('14-12-2055', 'dd-mm-yyyy'), '2', '14', '348', '12', '2055', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20438, to_date('15-12-2055', 'dd-mm-yyyy'), '3', '15', '349', '12', '2055', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20439, to_date('16-12-2055', 'dd-mm-yyyy'), '4', '16', '350', '12', '2055', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20440, to_date('17-12-2055', 'dd-mm-yyyy'), '5', '17', '351', '12', '2055', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20441, to_date('18-12-2055', 'dd-mm-yyyy'), '6', '18', '352', '12', '2055', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20442, to_date('19-12-2055', 'dd-mm-yyyy'), '7', '19', '353', '12', '2055', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20443, to_date('20-12-2055', 'dd-mm-yyyy'), '1', '20', '354', '12', '2055', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20444, to_date('21-12-2055', 'dd-mm-yyyy'), '2', '21', '355', '12', '2055', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20445, to_date('22-12-2055', 'dd-mm-yyyy'), '3', '22', '356', '12', '2055', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20446, to_date('23-12-2055', 'dd-mm-yyyy'), '4', '23', '357', '12', '2055', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20447, to_date('24-12-2055', 'dd-mm-yyyy'), '5', '24', '358', '12', '2055', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20448, to_date('25-12-2055', 'dd-mm-yyyy'), '6', '25', '359', '12', '2055', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20449, to_date('26-12-2055', 'dd-mm-yyyy'), '7', '26', '360', '12', '2055', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20450, to_date('27-12-2055', 'dd-mm-yyyy'), '1', '27', '361', '12', '2055', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20451, to_date('28-12-2055', 'dd-mm-yyyy'), '2', '28', '362', '12', '2055', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20452, to_date('29-12-2055', 'dd-mm-yyyy'), '3', '29', '363', '12', '2055', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20453, to_date('30-12-2055', 'dd-mm-yyyy'), '4', '30', '364', '12', '2055', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20454, to_date('31-12-2055', 'dd-mm-yyyy'), '5', '31', '365', '12', '2055', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20455, to_date('01-01-2056', 'dd-mm-yyyy'), '6', '01', '001', '01', '2056', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20456, to_date('02-01-2056', 'dd-mm-yyyy'), '7', '02', '002', '01', '2056', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20457, to_date('03-01-2056', 'dd-mm-yyyy'), '1', '03', '003', '01', '2056', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20458, to_date('04-01-2056', 'dd-mm-yyyy'), '2', '04', '004', '01', '2056', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20459, to_date('05-01-2056', 'dd-mm-yyyy'), '3', '05', '005', '01', '2056', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20460, to_date('06-01-2056', 'dd-mm-yyyy'), '4', '06', '006', '01', '2056', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20461, to_date('07-01-2056', 'dd-mm-yyyy'), '5', '07', '007', '01', '2056', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20462, to_date('08-01-2056', 'dd-mm-yyyy'), '6', '08', '008', '01', '2056', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20463, to_date('09-01-2056', 'dd-mm-yyyy'), '7', '09', '009', '01', '2056', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20464, to_date('10-01-2056', 'dd-mm-yyyy'), '1', '10', '010', '01', '2056', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20465, to_date('11-01-2056', 'dd-mm-yyyy'), '2', '11', '011', '01', '2056', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20466, to_date('12-01-2056', 'dd-mm-yyyy'), '3', '12', '012', '01', '2056', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20467, to_date('13-01-2056', 'dd-mm-yyyy'), '4', '13', '013', '01', '2056', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20468, to_date('14-01-2056', 'dd-mm-yyyy'), '5', '14', '014', '01', '2056', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20469, to_date('15-01-2056', 'dd-mm-yyyy'), '6', '15', '015', '01', '2056', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20470, to_date('16-01-2056', 'dd-mm-yyyy'), '7', '16', '016', '01', '2056', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20471, to_date('17-01-2056', 'dd-mm-yyyy'), '1', '17', '017', '01', '2056', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20472, to_date('18-01-2056', 'dd-mm-yyyy'), '2', '18', '018', '01', '2056', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20473, to_date('19-01-2056', 'dd-mm-yyyy'), '3', '19', '019', '01', '2056', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20474, to_date('20-01-2056', 'dd-mm-yyyy'), '4', '20', '020', '01', '2056', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20475, to_date('21-01-2056', 'dd-mm-yyyy'), '5', '21', '021', '01', '2056', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20476, to_date('22-01-2056', 'dd-mm-yyyy'), '6', '22', '022', '01', '2056', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20477, to_date('23-01-2056', 'dd-mm-yyyy'), '7', '23', '023', '01', '2056', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20478, to_date('24-01-2056', 'dd-mm-yyyy'), '1', '24', '024', '01', '2056', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20479, to_date('25-01-2056', 'dd-mm-yyyy'), '2', '25', '025', '01', '2056', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20480, to_date('26-01-2056', 'dd-mm-yyyy'), '3', '26', '026', '01', '2056', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20481, to_date('27-01-2056', 'dd-mm-yyyy'), '4', '27', '027', '01', '2056', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20482, to_date('28-01-2056', 'dd-mm-yyyy'), '5', '28', '028', '01', '2056', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20483, to_date('29-01-2056', 'dd-mm-yyyy'), '6', '29', '029', '01', '2056', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20484, to_date('30-01-2056', 'dd-mm-yyyy'), '7', '30', '030', '01', '2056', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20485, to_date('31-01-2056', 'dd-mm-yyyy'), '1', '31', '031', '01', '2056', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20486, to_date('01-02-2056', 'dd-mm-yyyy'), '2', '01', '032', '02', '2056', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20487, to_date('02-02-2056', 'dd-mm-yyyy'), '3', '02', '033', '02', '2056', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20488, to_date('03-02-2056', 'dd-mm-yyyy'), '4', '03', '034', '02', '2056', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20489, to_date('04-02-2056', 'dd-mm-yyyy'), '5', '04', '035', '02', '2056', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20490, to_date('05-02-2056', 'dd-mm-yyyy'), '6', '05', '036', '02', '2056', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20491, to_date('06-02-2056', 'dd-mm-yyyy'), '7', '06', '037', '02', '2056', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20492, to_date('07-02-2056', 'dd-mm-yyyy'), '1', '07', '038', '02', '2056', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20493, to_date('08-02-2056', 'dd-mm-yyyy'), '2', '08', '039', '02', '2056', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20494, to_date('09-02-2056', 'dd-mm-yyyy'), '3', '09', '040', '02', '2056', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20495, to_date('10-02-2056', 'dd-mm-yyyy'), '4', '10', '041', '02', '2056', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20496, to_date('11-02-2056', 'dd-mm-yyyy'), '5', '11', '042', '02', '2056', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20497, to_date('12-02-2056', 'dd-mm-yyyy'), '6', '12', '043', '02', '2056', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20498, to_date('13-02-2056', 'dd-mm-yyyy'), '7', '13', '044', '02', '2056', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20499, to_date('14-02-2056', 'dd-mm-yyyy'), '1', '14', '045', '02', '2056', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20500, to_date('15-02-2056', 'dd-mm-yyyy'), '2', '15', '046', '02', '2056', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20501, to_date('16-02-2056', 'dd-mm-yyyy'), '3', '16', '047', '02', '2056', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20502, to_date('17-02-2056', 'dd-mm-yyyy'), '4', '17', '048', '02', '2056', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20503, to_date('18-02-2056', 'dd-mm-yyyy'), '5', '18', '049', '02', '2056', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20504, to_date('19-02-2056', 'dd-mm-yyyy'), '6', '19', '050', '02', '2056', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20505, to_date('20-02-2056', 'dd-mm-yyyy'), '7', '20', '051', '02', '2056', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20506, to_date('21-02-2056', 'dd-mm-yyyy'), '1', '21', '052', '02', '2056', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20507, to_date('22-02-2056', 'dd-mm-yyyy'), '2', '22', '053', '02', '2056', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20508, to_date('23-02-2056', 'dd-mm-yyyy'), '3', '23', '054', '02', '2056', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20509, to_date('24-02-2056', 'dd-mm-yyyy'), '4', '24', '055', '02', '2056', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20510, to_date('25-02-2056', 'dd-mm-yyyy'), '5', '25', '056', '02', '2056', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20511, to_date('26-02-2056', 'dd-mm-yyyy'), '6', '26', '057', '02', '2056', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20512, to_date('27-02-2056', 'dd-mm-yyyy'), '7', '27', '058', '02', '2056', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20513, to_date('28-02-2056', 'dd-mm-yyyy'), '1', '28', '059', '02', '2056', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20514, to_date('29-02-2056', 'dd-mm-yyyy'), '2', '29', '060', '02', '2056', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20515, to_date('01-03-2056', 'dd-mm-yyyy'), '3', '01', '061', '03', '2056', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20516, to_date('02-03-2056', 'dd-mm-yyyy'), '4', '02', '062', '03', '2056', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20517, to_date('03-03-2056', 'dd-mm-yyyy'), '5', '03', '063', '03', '2056', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20518, to_date('04-03-2056', 'dd-mm-yyyy'), '6', '04', '064', '03', '2056', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20519, to_date('05-03-2056', 'dd-mm-yyyy'), '7', '05', '065', '03', '2056', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20520, to_date('06-03-2056', 'dd-mm-yyyy'), '1', '06', '066', '03', '2056', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20521, to_date('07-03-2056', 'dd-mm-yyyy'), '2', '07', '067', '03', '2056', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20522, to_date('08-03-2056', 'dd-mm-yyyy'), '3', '08', '068', '03', '2056', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20523, to_date('09-03-2056', 'dd-mm-yyyy'), '4', '09', '069', '03', '2056', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20524, to_date('10-03-2056', 'dd-mm-yyyy'), '5', '10', '070', '03', '2056', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20525, to_date('11-03-2056', 'dd-mm-yyyy'), '6', '11', '071', '03', '2056', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20526, to_date('12-03-2056', 'dd-mm-yyyy'), '7', '12', '072', '03', '2056', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20527, to_date('13-03-2056', 'dd-mm-yyyy'), '1', '13', '073', '03', '2056', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20528, to_date('14-03-2056', 'dd-mm-yyyy'), '2', '14', '074', '03', '2056', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20529, to_date('15-03-2056', 'dd-mm-yyyy'), '3', '15', '075', '03', '2056', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20530, to_date('16-03-2056', 'dd-mm-yyyy'), '4', '16', '076', '03', '2056', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20531, to_date('17-03-2056', 'dd-mm-yyyy'), '5', '17', '077', '03', '2056', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20532, to_date('18-03-2056', 'dd-mm-yyyy'), '6', '18', '078', '03', '2056', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20533, to_date('19-03-2056', 'dd-mm-yyyy'), '7', '19', '079', '03', '2056', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20534, to_date('20-03-2056', 'dd-mm-yyyy'), '1', '20', '080', '03', '2056', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20535, to_date('21-03-2056', 'dd-mm-yyyy'), '2', '21', '081', '03', '2056', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20536, to_date('22-03-2056', 'dd-mm-yyyy'), '3', '22', '082', '03', '2056', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20537, to_date('23-03-2056', 'dd-mm-yyyy'), '4', '23', '083', '03', '2056', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20538, to_date('24-03-2056', 'dd-mm-yyyy'), '5', '24', '084', '03', '2056', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22023, to_date('17-04-2060', 'dd-mm-yyyy'), '6', '17', '108', '04', '2060', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22024, to_date('18-04-2060', 'dd-mm-yyyy'), '7', '18', '109', '04', '2060', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22025, to_date('19-04-2060', 'dd-mm-yyyy'), '1', '19', '110', '04', '2060', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22026, to_date('20-04-2060', 'dd-mm-yyyy'), '2', '20', '111', '04', '2060', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22027, to_date('21-04-2060', 'dd-mm-yyyy'), '3', '21', '112', '04', '2060', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22028, to_date('22-04-2060', 'dd-mm-yyyy'), '4', '22', '113', '04', '2060', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22029, to_date('23-04-2060', 'dd-mm-yyyy'), '5', '23', '114', '04', '2060', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22030, to_date('24-04-2060', 'dd-mm-yyyy'), '6', '24', '115', '04', '2060', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22031, to_date('25-04-2060', 'dd-mm-yyyy'), '7', '25', '116', '04', '2060', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22032, to_date('26-04-2060', 'dd-mm-yyyy'), '1', '26', '117', '04', '2060', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22033, to_date('27-04-2060', 'dd-mm-yyyy'), '2', '27', '118', '04', '2060', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22034, to_date('28-04-2060', 'dd-mm-yyyy'), '3', '28', '119', '04', '2060', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22035, to_date('29-04-2060', 'dd-mm-yyyy'), '4', '29', '120', '04', '2060', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22036, to_date('30-04-2060', 'dd-mm-yyyy'), '5', '30', '121', '04', '2060', '18', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22037, to_date('01-05-2060', 'dd-mm-yyyy'), '6', '01', '122', '05', '2060', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22038, to_date('02-05-2060', 'dd-mm-yyyy'), '7', '02', '123', '05', '2060', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22039, to_date('03-05-2060', 'dd-mm-yyyy'), '1', '03', '124', '05', '2060', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22040, to_date('04-05-2060', 'dd-mm-yyyy'), '2', '04', '125', '05', '2060', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22041, to_date('05-05-2060', 'dd-mm-yyyy'), '3', '05', '126', '05', '2060', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22042, to_date('06-05-2060', 'dd-mm-yyyy'), '4', '06', '127', '05', '2060', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22043, to_date('07-05-2060', 'dd-mm-yyyy'), '5', '07', '128', '05', '2060', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22044, to_date('08-05-2060', 'dd-mm-yyyy'), '6', '08', '129', '05', '2060', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22045, to_date('09-05-2060', 'dd-mm-yyyy'), '7', '09', '130', '05', '2060', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22046, to_date('10-05-2060', 'dd-mm-yyyy'), '1', '10', '131', '05', '2060', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22047, to_date('11-05-2060', 'dd-mm-yyyy'), '2', '11', '132', '05', '2060', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22048, to_date('12-05-2060', 'dd-mm-yyyy'), '3', '12', '133', '05', '2060', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22049, to_date('13-05-2060', 'dd-mm-yyyy'), '4', '13', '134', '05', '2060', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22050, to_date('14-05-2060', 'dd-mm-yyyy'), '5', '14', '135', '05', '2060', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22051, to_date('15-05-2060', 'dd-mm-yyyy'), '6', '15', '136', '05', '2060', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22052, to_date('16-05-2060', 'dd-mm-yyyy'), '7', '16', '137', '05', '2060', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22053, to_date('17-05-2060', 'dd-mm-yyyy'), '1', '17', '138', '05', '2060', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22054, to_date('18-05-2060', 'dd-mm-yyyy'), '2', '18', '139', '05', '2060', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22055, to_date('19-05-2060', 'dd-mm-yyyy'), '3', '19', '140', '05', '2060', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22056, to_date('20-05-2060', 'dd-mm-yyyy'), '4', '20', '141', '05', '2060', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22057, to_date('21-05-2060', 'dd-mm-yyyy'), '5', '21', '142', '05', '2060', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22058, to_date('22-05-2060', 'dd-mm-yyyy'), '6', '22', '143', '05', '2060', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22059, to_date('23-05-2060', 'dd-mm-yyyy'), '7', '23', '144', '05', '2060', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22060, to_date('24-05-2060', 'dd-mm-yyyy'), '1', '24', '145', '05', '2060', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22061, to_date('25-05-2060', 'dd-mm-yyyy'), '2', '25', '146', '05', '2060', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22062, to_date('26-05-2060', 'dd-mm-yyyy'), '3', '26', '147', '05', '2060', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22063, to_date('27-05-2060', 'dd-mm-yyyy'), '4', '27', '148', '05', '2060', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22064, to_date('28-05-2060', 'dd-mm-yyyy'), '5', '28', '149', '05', '2060', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22065, to_date('29-05-2060', 'dd-mm-yyyy'), '6', '29', '150', '05', '2060', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22066, to_date('30-05-2060', 'dd-mm-yyyy'), '7', '30', '151', '05', '2060', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22067, to_date('31-05-2060', 'dd-mm-yyyy'), '1', '31', '152', '05', '2060', '23', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22068, to_date('01-06-2060', 'dd-mm-yyyy'), '2', '01', '153', '06', '2060', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22069, to_date('02-06-2060', 'dd-mm-yyyy'), '3', '02', '154', '06', '2060', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22070, to_date('03-06-2060', 'dd-mm-yyyy'), '4', '03', '155', '06', '2060', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22071, to_date('04-06-2060', 'dd-mm-yyyy'), '5', '04', '156', '06', '2060', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22072, to_date('05-06-2060', 'dd-mm-yyyy'), '6', '05', '157', '06', '2060', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22073, to_date('06-06-2060', 'dd-mm-yyyy'), '7', '06', '158', '06', '2060', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22074, to_date('07-06-2060', 'dd-mm-yyyy'), '1', '07', '159', '06', '2060', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22075, to_date('08-06-2060', 'dd-mm-yyyy'), '2', '08', '160', '06', '2060', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22076, to_date('09-06-2060', 'dd-mm-yyyy'), '3', '09', '161', '06', '2060', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22077, to_date('10-06-2060', 'dd-mm-yyyy'), '4', '10', '162', '06', '2060', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22078, to_date('11-06-2060', 'dd-mm-yyyy'), '5', '11', '163', '06', '2060', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22079, to_date('12-06-2060', 'dd-mm-yyyy'), '6', '12', '164', '06', '2060', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22080, to_date('13-06-2060', 'dd-mm-yyyy'), '7', '13', '165', '06', '2060', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22081, to_date('14-06-2060', 'dd-mm-yyyy'), '1', '14', '166', '06', '2060', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22082, to_date('15-06-2060', 'dd-mm-yyyy'), '2', '15', '167', '06', '2060', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22083, to_date('16-06-2060', 'dd-mm-yyyy'), '3', '16', '168', '06', '2060', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22084, to_date('17-06-2060', 'dd-mm-yyyy'), '4', '17', '169', '06', '2060', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22085, to_date('18-06-2060', 'dd-mm-yyyy'), '5', '18', '170', '06', '2060', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22086, to_date('19-06-2060', 'dd-mm-yyyy'), '6', '19', '171', '06', '2060', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22087, to_date('20-06-2060', 'dd-mm-yyyy'), '7', '20', '172', '06', '2060', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22088, to_date('21-06-2060', 'dd-mm-yyyy'), '1', '21', '173', '06', '2060', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22089, to_date('22-06-2060', 'dd-mm-yyyy'), '2', '22', '174', '06', '2060', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22090, to_date('23-06-2060', 'dd-mm-yyyy'), '3', '23', '175', '06', '2060', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22091, to_date('24-06-2060', 'dd-mm-yyyy'), '4', '24', '176', '06', '2060', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22092, to_date('25-06-2060', 'dd-mm-yyyy'), '5', '25', '177', '06', '2060', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22093, to_date('26-06-2060', 'dd-mm-yyyy'), '6', '26', '178', '06', '2060', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22094, to_date('27-06-2060', 'dd-mm-yyyy'), '7', '27', '179', '06', '2060', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22095, to_date('28-06-2060', 'dd-mm-yyyy'), '1', '28', '180', '06', '2060', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22096, to_date('29-06-2060', 'dd-mm-yyyy'), '2', '29', '181', '06', '2060', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22097, to_date('30-06-2060', 'dd-mm-yyyy'), '3', '30', '182', '06', '2060', '27', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22098, to_date('01-07-2060', 'dd-mm-yyyy'), '4', '01', '183', '07', '2060', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22099, to_date('02-07-2060', 'dd-mm-yyyy'), '5', '02', '184', '07', '2060', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22100, to_date('03-07-2060', 'dd-mm-yyyy'), '6', '03', '185', '07', '2060', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22101, to_date('04-07-2060', 'dd-mm-yyyy'), '7', '04', '186', '07', '2060', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22102, to_date('05-07-2060', 'dd-mm-yyyy'), '1', '05', '187', '07', '2060', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22103, to_date('06-07-2060', 'dd-mm-yyyy'), '2', '06', '188', '07', '2060', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22104, to_date('07-07-2060', 'dd-mm-yyyy'), '3', '07', '189', '07', '2060', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22105, to_date('08-07-2060', 'dd-mm-yyyy'), '4', '08', '190', '07', '2060', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22106, to_date('09-07-2060', 'dd-mm-yyyy'), '5', '09', '191', '07', '2060', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22107, to_date('10-07-2060', 'dd-mm-yyyy'), '6', '10', '192', '07', '2060', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22108, to_date('11-07-2060', 'dd-mm-yyyy'), '7', '11', '193', '07', '2060', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22109, to_date('12-07-2060', 'dd-mm-yyyy'), '1', '12', '194', '07', '2060', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22110, to_date('13-07-2060', 'dd-mm-yyyy'), '2', '13', '195', '07', '2060', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22111, to_date('14-07-2060', 'dd-mm-yyyy'), '3', '14', '196', '07', '2060', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22112, to_date('15-07-2060', 'dd-mm-yyyy'), '4', '15', '197', '07', '2060', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22113, to_date('16-07-2060', 'dd-mm-yyyy'), '5', '16', '198', '07', '2060', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22114, to_date('17-07-2060', 'dd-mm-yyyy'), '6', '17', '199', '07', '2060', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22115, to_date('18-07-2060', 'dd-mm-yyyy'), '7', '18', '200', '07', '2060', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22116, to_date('19-07-2060', 'dd-mm-yyyy'), '1', '19', '201', '07', '2060', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22117, to_date('20-07-2060', 'dd-mm-yyyy'), '2', '20', '202', '07', '2060', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22118, to_date('21-07-2060', 'dd-mm-yyyy'), '3', '21', '203', '07', '2060', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22119, to_date('22-07-2060', 'dd-mm-yyyy'), '4', '22', '204', '07', '2060', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22120, to_date('23-07-2060', 'dd-mm-yyyy'), '5', '23', '205', '07', '2060', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22121, to_date('24-07-2060', 'dd-mm-yyyy'), '6', '24', '206', '07', '2060', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22122, to_date('25-07-2060', 'dd-mm-yyyy'), '7', '25', '207', '07', '2060', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22123, to_date('26-07-2060', 'dd-mm-yyyy'), '1', '26', '208', '07', '2060', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22124, to_date('27-07-2060', 'dd-mm-yyyy'), '2', '27', '209', '07', '2060', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22125, to_date('28-07-2060', 'dd-mm-yyyy'), '3', '28', '210', '07', '2060', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22126, to_date('29-07-2060', 'dd-mm-yyyy'), '4', '29', '211', '07', '2060', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22127, to_date('30-07-2060', 'dd-mm-yyyy'), '5', '30', '212', '07', '2060', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22128, to_date('31-07-2060', 'dd-mm-yyyy'), '6', '31', '213', '07', '2060', '31', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23613, to_date('24-08-2064', 'dd-mm-yyyy'), '7', '24', '237', '08', '2064', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23614, to_date('25-08-2064', 'dd-mm-yyyy'), '1', '25', '238', '08', '2064', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23615, to_date('26-08-2064', 'dd-mm-yyyy'), '2', '26', '239', '08', '2064', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23616, to_date('27-08-2064', 'dd-mm-yyyy'), '3', '27', '240', '08', '2064', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23617, to_date('28-08-2064', 'dd-mm-yyyy'), '4', '28', '241', '08', '2064', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23618, to_date('29-08-2064', 'dd-mm-yyyy'), '5', '29', '242', '08', '2064', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23619, to_date('30-08-2064', 'dd-mm-yyyy'), '6', '30', '243', '08', '2064', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23620, to_date('31-08-2064', 'dd-mm-yyyy'), '7', '31', '244', '08', '2064', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23621, to_date('01-09-2064', 'dd-mm-yyyy'), '1', '01', '245', '09', '2064', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23622, to_date('02-09-2064', 'dd-mm-yyyy'), '2', '02', '246', '09', '2064', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23623, to_date('03-09-2064', 'dd-mm-yyyy'), '3', '03', '247', '09', '2064', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23624, to_date('04-09-2064', 'dd-mm-yyyy'), '4', '04', '248', '09', '2064', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23625, to_date('05-09-2064', 'dd-mm-yyyy'), '5', '05', '249', '09', '2064', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23626, to_date('06-09-2064', 'dd-mm-yyyy'), '6', '06', '250', '09', '2064', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23627, to_date('07-09-2064', 'dd-mm-yyyy'), '7', '07', '251', '09', '2064', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23628, to_date('08-09-2064', 'dd-mm-yyyy'), '1', '08', '252', '09', '2064', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23629, to_date('09-09-2064', 'dd-mm-yyyy'), '2', '09', '253', '09', '2064', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23630, to_date('10-09-2064', 'dd-mm-yyyy'), '3', '10', '254', '09', '2064', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23631, to_date('11-09-2064', 'dd-mm-yyyy'), '4', '11', '255', '09', '2064', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23632, to_date('12-09-2064', 'dd-mm-yyyy'), '5', '12', '256', '09', '2064', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23633, to_date('13-09-2064', 'dd-mm-yyyy'), '6', '13', '257', '09', '2064', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23634, to_date('14-09-2064', 'dd-mm-yyyy'), '7', '14', '258', '09', '2064', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23635, to_date('15-09-2064', 'dd-mm-yyyy'), '1', '15', '259', '09', '2064', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23636, to_date('16-09-2064', 'dd-mm-yyyy'), '2', '16', '260', '09', '2064', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23637, to_date('17-09-2064', 'dd-mm-yyyy'), '3', '17', '261', '09', '2064', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23638, to_date('18-09-2064', 'dd-mm-yyyy'), '4', '18', '262', '09', '2064', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23639, to_date('19-09-2064', 'dd-mm-yyyy'), '5', '19', '263', '09', '2064', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23640, to_date('20-09-2064', 'dd-mm-yyyy'), '6', '20', '264', '09', '2064', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23641, to_date('21-09-2064', 'dd-mm-yyyy'), '7', '21', '265', '09', '2064', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23642, to_date('22-09-2064', 'dd-mm-yyyy'), '1', '22', '266', '09', '2064', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23643, to_date('23-09-2064', 'dd-mm-yyyy'), '2', '23', '267', '09', '2064', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23644, to_date('24-09-2064', 'dd-mm-yyyy'), '3', '24', '268', '09', '2064', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23645, to_date('25-09-2064', 'dd-mm-yyyy'), '4', '25', '269', '09', '2064', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23646, to_date('26-09-2064', 'dd-mm-yyyy'), '5', '26', '270', '09', '2064', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23647, to_date('27-09-2064', 'dd-mm-yyyy'), '6', '27', '271', '09', '2064', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23648, to_date('28-09-2064', 'dd-mm-yyyy'), '7', '28', '272', '09', '2064', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23649, to_date('29-09-2064', 'dd-mm-yyyy'), '1', '29', '273', '09', '2064', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23650, to_date('30-09-2064', 'dd-mm-yyyy'), '2', '30', '274', '09', '2064', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23651, to_date('01-10-2064', 'dd-mm-yyyy'), '3', '01', '275', '10', '2064', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23652, to_date('02-10-2064', 'dd-mm-yyyy'), '4', '02', '276', '10', '2064', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23653, to_date('03-10-2064', 'dd-mm-yyyy'), '5', '03', '277', '10', '2064', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23654, to_date('04-10-2064', 'dd-mm-yyyy'), '6', '04', '278', '10', '2064', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23655, to_date('05-10-2064', 'dd-mm-yyyy'), '7', '05', '279', '10', '2064', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23656, to_date('06-10-2064', 'dd-mm-yyyy'), '1', '06', '280', '10', '2064', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23657, to_date('07-10-2064', 'dd-mm-yyyy'), '2', '07', '281', '10', '2064', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23658, to_date('08-10-2064', 'dd-mm-yyyy'), '3', '08', '282', '10', '2064', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23659, to_date('09-10-2064', 'dd-mm-yyyy'), '4', '09', '283', '10', '2064', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23660, to_date('10-10-2064', 'dd-mm-yyyy'), '5', '10', '284', '10', '2064', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23661, to_date('11-10-2064', 'dd-mm-yyyy'), '6', '11', '285', '10', '2064', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23662, to_date('12-10-2064', 'dd-mm-yyyy'), '7', '12', '286', '10', '2064', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23663, to_date('13-10-2064', 'dd-mm-yyyy'), '1', '13', '287', '10', '2064', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23664, to_date('14-10-2064', 'dd-mm-yyyy'), '2', '14', '288', '10', '2064', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23665, to_date('15-10-2064', 'dd-mm-yyyy'), '3', '15', '289', '10', '2064', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23666, to_date('16-10-2064', 'dd-mm-yyyy'), '4', '16', '290', '10', '2064', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23667, to_date('17-10-2064', 'dd-mm-yyyy'), '5', '17', '291', '10', '2064', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23668, to_date('18-10-2064', 'dd-mm-yyyy'), '6', '18', '292', '10', '2064', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23669, to_date('19-10-2064', 'dd-mm-yyyy'), '7', '19', '293', '10', '2064', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23670, to_date('20-10-2064', 'dd-mm-yyyy'), '1', '20', '294', '10', '2064', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23671, to_date('21-10-2064', 'dd-mm-yyyy'), '2', '21', '295', '10', '2064', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23672, to_date('22-10-2064', 'dd-mm-yyyy'), '3', '22', '296', '10', '2064', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23673, to_date('23-10-2064', 'dd-mm-yyyy'), '4', '23', '297', '10', '2064', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23674, to_date('24-10-2064', 'dd-mm-yyyy'), '5', '24', '298', '10', '2064', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23675, to_date('25-10-2064', 'dd-mm-yyyy'), '6', '25', '299', '10', '2064', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23676, to_date('26-10-2064', 'dd-mm-yyyy'), '7', '26', '300', '10', '2064', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23677, to_date('27-10-2064', 'dd-mm-yyyy'), '1', '27', '301', '10', '2064', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23678, to_date('28-10-2064', 'dd-mm-yyyy'), '2', '28', '302', '10', '2064', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23679, to_date('29-10-2064', 'dd-mm-yyyy'), '3', '29', '303', '10', '2064', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23680, to_date('30-10-2064', 'dd-mm-yyyy'), '4', '30', '304', '10', '2064', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23681, to_date('31-10-2064', 'dd-mm-yyyy'), '5', '31', '305', '10', '2064', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23682, to_date('01-11-2064', 'dd-mm-yyyy'), '6', '01', '306', '11', '2064', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23683, to_date('02-11-2064', 'dd-mm-yyyy'), '7', '02', '307', '11', '2064', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23684, to_date('03-11-2064', 'dd-mm-yyyy'), '1', '03', '308', '11', '2064', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23685, to_date('04-11-2064', 'dd-mm-yyyy'), '2', '04', '309', '11', '2064', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23686, to_date('05-11-2064', 'dd-mm-yyyy'), '3', '05', '310', '11', '2064', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23687, to_date('06-11-2064', 'dd-mm-yyyy'), '4', '06', '311', '11', '2064', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23688, to_date('07-11-2064', 'dd-mm-yyyy'), '5', '07', '312', '11', '2064', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23689, to_date('08-11-2064', 'dd-mm-yyyy'), '6', '08', '313', '11', '2064', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23690, to_date('09-11-2064', 'dd-mm-yyyy'), '7', '09', '314', '11', '2064', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23691, to_date('10-11-2064', 'dd-mm-yyyy'), '1', '10', '315', '11', '2064', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23692, to_date('11-11-2064', 'dd-mm-yyyy'), '2', '11', '316', '11', '2064', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23693, to_date('12-11-2064', 'dd-mm-yyyy'), '3', '12', '317', '11', '2064', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23694, to_date('13-11-2064', 'dd-mm-yyyy'), '4', '13', '318', '11', '2064', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23695, to_date('14-11-2064', 'dd-mm-yyyy'), '5', '14', '319', '11', '2064', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23696, to_date('15-11-2064', 'dd-mm-yyyy'), '6', '15', '320', '11', '2064', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23697, to_date('16-11-2064', 'dd-mm-yyyy'), '7', '16', '321', '11', '2064', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23698, to_date('17-11-2064', 'dd-mm-yyyy'), '1', '17', '322', '11', '2064', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23699, to_date('18-11-2064', 'dd-mm-yyyy'), '2', '18', '323', '11', '2064', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23700, to_date('19-11-2064', 'dd-mm-yyyy'), '3', '19', '324', '11', '2064', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23701, to_date('20-11-2064', 'dd-mm-yyyy'), '4', '20', '325', '11', '2064', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23702, to_date('21-11-2064', 'dd-mm-yyyy'), '5', '21', '326', '11', '2064', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23703, to_date('22-11-2064', 'dd-mm-yyyy'), '6', '22', '327', '11', '2064', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23704, to_date('23-11-2064', 'dd-mm-yyyy'), '7', '23', '328', '11', '2064', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23705, to_date('24-11-2064', 'dd-mm-yyyy'), '1', '24', '329', '11', '2064', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23706, to_date('25-11-2064', 'dd-mm-yyyy'), '2', '25', '330', '11', '2064', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23707, to_date('26-11-2064', 'dd-mm-yyyy'), '3', '26', '331', '11', '2064', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23708, to_date('27-11-2064', 'dd-mm-yyyy'), '4', '27', '332', '11', '2064', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23709, to_date('28-11-2064', 'dd-mm-yyyy'), '5', '28', '333', '11', '2064', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23710, to_date('29-11-2064', 'dd-mm-yyyy'), '6', '29', '334', '11', '2064', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23711, to_date('30-11-2064', 'dd-mm-yyyy'), '7', '30', '335', '11', '2064', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23712, to_date('01-12-2064', 'dd-mm-yyyy'), '1', '01', '336', '12', '2064', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23713, to_date('02-12-2064', 'dd-mm-yyyy'), '2', '02', '337', '12', '2064', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23714, to_date('03-12-2064', 'dd-mm-yyyy'), '3', '03', '338', '12', '2064', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23715, to_date('04-12-2064', 'dd-mm-yyyy'), '4', '04', '339', '12', '2064', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23716, to_date('05-12-2064', 'dd-mm-yyyy'), '5', '05', '340', '12', '2064', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23717, to_date('06-12-2064', 'dd-mm-yyyy'), '6', '06', '341', '12', '2064', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23718, to_date('07-12-2064', 'dd-mm-yyyy'), '7', '07', '342', '12', '2064', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25203, to_date('31-12-2068', 'dd-mm-yyyy'), '1', '31', '366', '12', '2068', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25204, to_date('01-01-2069', 'dd-mm-yyyy'), '2', '01', '001', '01', '2069', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25205, to_date('02-01-2069', 'dd-mm-yyyy'), '3', '02', '002', '01', '2069', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25206, to_date('03-01-2069', 'dd-mm-yyyy'), '4', '03', '003', '01', '2069', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25207, to_date('04-01-2069', 'dd-mm-yyyy'), '5', '04', '004', '01', '2069', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25208, to_date('05-01-2069', 'dd-mm-yyyy'), '6', '05', '005', '01', '2069', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25209, to_date('06-01-2069', 'dd-mm-yyyy'), '7', '06', '006', '01', '2069', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25210, to_date('07-01-2069', 'dd-mm-yyyy'), '1', '07', '007', '01', '2069', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25211, to_date('08-01-2069', 'dd-mm-yyyy'), '2', '08', '008', '01', '2069', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25212, to_date('09-01-2069', 'dd-mm-yyyy'), '3', '09', '009', '01', '2069', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25213, to_date('10-01-2069', 'dd-mm-yyyy'), '4', '10', '010', '01', '2069', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25214, to_date('11-01-2069', 'dd-mm-yyyy'), '5', '11', '011', '01', '2069', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25215, to_date('12-01-2069', 'dd-mm-yyyy'), '6', '12', '012', '01', '2069', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25216, to_date('13-01-2069', 'dd-mm-yyyy'), '7', '13', '013', '01', '2069', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25217, to_date('14-01-2069', 'dd-mm-yyyy'), '1', '14', '014', '01', '2069', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25218, to_date('15-01-2069', 'dd-mm-yyyy'), '2', '15', '015', '01', '2069', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25219, to_date('16-01-2069', 'dd-mm-yyyy'), '3', '16', '016', '01', '2069', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25220, to_date('17-01-2069', 'dd-mm-yyyy'), '4', '17', '017', '01', '2069', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25221, to_date('18-01-2069', 'dd-mm-yyyy'), '5', '18', '018', '01', '2069', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25222, to_date('19-01-2069', 'dd-mm-yyyy'), '6', '19', '019', '01', '2069', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25223, to_date('20-01-2069', 'dd-mm-yyyy'), '7', '20', '020', '01', '2069', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25224, to_date('21-01-2069', 'dd-mm-yyyy'), '1', '21', '021', '01', '2069', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25225, to_date('22-01-2069', 'dd-mm-yyyy'), '2', '22', '022', '01', '2069', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25226, to_date('23-01-2069', 'dd-mm-yyyy'), '3', '23', '023', '01', '2069', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25227, to_date('24-01-2069', 'dd-mm-yyyy'), '4', '24', '024', '01', '2069', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25228, to_date('25-01-2069', 'dd-mm-yyyy'), '5', '25', '025', '01', '2069', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25229, to_date('26-01-2069', 'dd-mm-yyyy'), '6', '26', '026', '01', '2069', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25230, to_date('27-01-2069', 'dd-mm-yyyy'), '7', '27', '027', '01', '2069', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25231, to_date('28-01-2069', 'dd-mm-yyyy'), '1', '28', '028', '01', '2069', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25232, to_date('29-01-2069', 'dd-mm-yyyy'), '2', '29', '029', '01', '2069', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25233, to_date('30-01-2069', 'dd-mm-yyyy'), '3', '30', '030', '01', '2069', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25234, to_date('31-01-2069', 'dd-mm-yyyy'), '4', '31', '031', '01', '2069', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25235, to_date('01-02-2069', 'dd-mm-yyyy'), '5', '01', '032', '02', '2069', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25236, to_date('02-02-2069', 'dd-mm-yyyy'), '6', '02', '033', '02', '2069', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25237, to_date('03-02-2069', 'dd-mm-yyyy'), '7', '03', '034', '02', '2069', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25238, to_date('04-02-2069', 'dd-mm-yyyy'), '1', '04', '035', '02', '2069', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25239, to_date('05-02-2069', 'dd-mm-yyyy'), '2', '05', '036', '02', '2069', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25240, to_date('06-02-2069', 'dd-mm-yyyy'), '3', '06', '037', '02', '2069', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25241, to_date('07-02-2069', 'dd-mm-yyyy'), '4', '07', '038', '02', '2069', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25242, to_date('08-02-2069', 'dd-mm-yyyy'), '5', '08', '039', '02', '2069', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25243, to_date('09-02-2069', 'dd-mm-yyyy'), '6', '09', '040', '02', '2069', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25244, to_date('10-02-2069', 'dd-mm-yyyy'), '7', '10', '041', '02', '2069', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25245, to_date('11-02-2069', 'dd-mm-yyyy'), '1', '11', '042', '02', '2069', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25246, to_date('12-02-2069', 'dd-mm-yyyy'), '2', '12', '043', '02', '2069', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25247, to_date('13-02-2069', 'dd-mm-yyyy'), '3', '13', '044', '02', '2069', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25248, to_date('14-02-2069', 'dd-mm-yyyy'), '4', '14', '045', '02', '2069', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25249, to_date('15-02-2069', 'dd-mm-yyyy'), '5', '15', '046', '02', '2069', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25250, to_date('16-02-2069', 'dd-mm-yyyy'), '6', '16', '047', '02', '2069', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25251, to_date('17-02-2069', 'dd-mm-yyyy'), '7', '17', '048', '02', '2069', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25252, to_date('18-02-2069', 'dd-mm-yyyy'), '1', '18', '049', '02', '2069', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25253, to_date('19-02-2069', 'dd-mm-yyyy'), '2', '19', '050', '02', '2069', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25254, to_date('20-02-2069', 'dd-mm-yyyy'), '3', '20', '051', '02', '2069', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25255, to_date('21-02-2069', 'dd-mm-yyyy'), '4', '21', '052', '02', '2069', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25256, to_date('22-02-2069', 'dd-mm-yyyy'), '5', '22', '053', '02', '2069', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25257, to_date('23-02-2069', 'dd-mm-yyyy'), '6', '23', '054', '02', '2069', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25258, to_date('24-02-2069', 'dd-mm-yyyy'), '7', '24', '055', '02', '2069', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25259, to_date('25-02-2069', 'dd-mm-yyyy'), '1', '25', '056', '02', '2069', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25260, to_date('26-02-2069', 'dd-mm-yyyy'), '2', '26', '057', '02', '2069', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25261, to_date('27-02-2069', 'dd-mm-yyyy'), '3', '27', '058', '02', '2069', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25262, to_date('28-02-2069', 'dd-mm-yyyy'), '4', '28', '059', '02', '2069', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25263, to_date('01-03-2069', 'dd-mm-yyyy'), '5', '01', '060', '03', '2069', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25264, to_date('02-03-2069', 'dd-mm-yyyy'), '6', '02', '061', '03', '2069', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25265, to_date('03-03-2069', 'dd-mm-yyyy'), '7', '03', '062', '03', '2069', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25266, to_date('04-03-2069', 'dd-mm-yyyy'), '1', '04', '063', '03', '2069', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25267, to_date('05-03-2069', 'dd-mm-yyyy'), '2', '05', '064', '03', '2069', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25268, to_date('06-03-2069', 'dd-mm-yyyy'), '3', '06', '065', '03', '2069', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25269, to_date('07-03-2069', 'dd-mm-yyyy'), '4', '07', '066', '03', '2069', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25270, to_date('08-03-2069', 'dd-mm-yyyy'), '5', '08', '067', '03', '2069', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25271, to_date('09-03-2069', 'dd-mm-yyyy'), '6', '09', '068', '03', '2069', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25272, to_date('10-03-2069', 'dd-mm-yyyy'), '7', '10', '069', '03', '2069', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25273, to_date('11-03-2069', 'dd-mm-yyyy'), '1', '11', '070', '03', '2069', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25274, to_date('12-03-2069', 'dd-mm-yyyy'), '2', '12', '071', '03', '2069', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25275, to_date('13-03-2069', 'dd-mm-yyyy'), '3', '13', '072', '03', '2069', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25276, to_date('14-03-2069', 'dd-mm-yyyy'), '4', '14', '073', '03', '2069', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25277, to_date('15-03-2069', 'dd-mm-yyyy'), '5', '15', '074', '03', '2069', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25278, to_date('16-03-2069', 'dd-mm-yyyy'), '6', '16', '075', '03', '2069', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25279, to_date('17-03-2069', 'dd-mm-yyyy'), '7', '17', '076', '03', '2069', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25280, to_date('18-03-2069', 'dd-mm-yyyy'), '1', '18', '077', '03', '2069', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25281, to_date('19-03-2069', 'dd-mm-yyyy'), '2', '19', '078', '03', '2069', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25282, to_date('20-03-2069', 'dd-mm-yyyy'), '3', '20', '079', '03', '2069', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25283, to_date('21-03-2069', 'dd-mm-yyyy'), '4', '21', '080', '03', '2069', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25284, to_date('22-03-2069', 'dd-mm-yyyy'), '5', '22', '081', '03', '2069', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25285, to_date('23-03-2069', 'dd-mm-yyyy'), '6', '23', '082', '03', '2069', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25286, to_date('24-03-2069', 'dd-mm-yyyy'), '7', '24', '083', '03', '2069', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25287, to_date('25-03-2069', 'dd-mm-yyyy'), '1', '25', '084', '03', '2069', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25288, to_date('26-03-2069', 'dd-mm-yyyy'), '2', '26', '085', '03', '2069', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25289, to_date('27-03-2069', 'dd-mm-yyyy'), '3', '27', '086', '03', '2069', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25290, to_date('28-03-2069', 'dd-mm-yyyy'), '4', '28', '087', '03', '2069', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25291, to_date('29-03-2069', 'dd-mm-yyyy'), '5', '29', '088', '03', '2069', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25292, to_date('30-03-2069', 'dd-mm-yyyy'), '6', '30', '089', '03', '2069', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25293, to_date('31-03-2069', 'dd-mm-yyyy'), '7', '31', '090', '03', '2069', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25294, to_date('01-04-2069', 'dd-mm-yyyy'), '1', '01', '091', '04', '2069', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25295, to_date('02-04-2069', 'dd-mm-yyyy'), '2', '02', '092', '04', '2069', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25296, to_date('03-04-2069', 'dd-mm-yyyy'), '3', '03', '093', '04', '2069', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25297, to_date('04-04-2069', 'dd-mm-yyyy'), '4', '04', '094', '04', '2069', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25298, to_date('05-04-2069', 'dd-mm-yyyy'), '5', '05', '095', '04', '2069', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25299, to_date('06-04-2069', 'dd-mm-yyyy'), '6', '06', '096', '04', '2069', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25300, to_date('07-04-2069', 'dd-mm-yyyy'), '7', '07', '097', '04', '2069', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25301, to_date('08-04-2069', 'dd-mm-yyyy'), '1', '08', '098', '04', '2069', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25302, to_date('09-04-2069', 'dd-mm-yyyy'), '2', '09', '099', '04', '2069', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25303, to_date('10-04-2069', 'dd-mm-yyyy'), '3', '10', '100', '04', '2069', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25304, to_date('11-04-2069', 'dd-mm-yyyy'), '4', '11', '101', '04', '2069', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25305, to_date('12-04-2069', 'dd-mm-yyyy'), '5', '12', '102', '04', '2069', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25306, to_date('13-04-2069', 'dd-mm-yyyy'), '6', '13', '103', '04', '2069', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25307, to_date('14-04-2069', 'dd-mm-yyyy'), '7', '14', '104', '04', '2069', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25308, to_date('15-04-2069', 'dd-mm-yyyy'), '1', '15', '105', '04', '2069', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20539, to_date('25-03-2056', 'dd-mm-yyyy'), '6', '25', '085', '03', '2056', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20540, to_date('26-03-2056', 'dd-mm-yyyy'), '7', '26', '086', '03', '2056', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20541, to_date('27-03-2056', 'dd-mm-yyyy'), '1', '27', '087', '03', '2056', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20542, to_date('28-03-2056', 'dd-mm-yyyy'), '2', '28', '088', '03', '2056', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20543, to_date('29-03-2056', 'dd-mm-yyyy'), '3', '29', '089', '03', '2056', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20544, to_date('30-03-2056', 'dd-mm-yyyy'), '4', '30', '090', '03', '2056', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20545, to_date('31-03-2056', 'dd-mm-yyyy'), '5', '31', '091', '03', '2056', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20546, to_date('01-04-2056', 'dd-mm-yyyy'), '6', '01', '092', '04', '2056', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20547, to_date('02-04-2056', 'dd-mm-yyyy'), '7', '02', '093', '04', '2056', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20548, to_date('03-04-2056', 'dd-mm-yyyy'), '1', '03', '094', '04', '2056', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20549, to_date('04-04-2056', 'dd-mm-yyyy'), '2', '04', '095', '04', '2056', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20550, to_date('05-04-2056', 'dd-mm-yyyy'), '3', '05', '096', '04', '2056', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20551, to_date('06-04-2056', 'dd-mm-yyyy'), '4', '06', '097', '04', '2056', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20552, to_date('07-04-2056', 'dd-mm-yyyy'), '5', '07', '098', '04', '2056', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20553, to_date('08-04-2056', 'dd-mm-yyyy'), '6', '08', '099', '04', '2056', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20554, to_date('09-04-2056', 'dd-mm-yyyy'), '7', '09', '100', '04', '2056', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20555, to_date('10-04-2056', 'dd-mm-yyyy'), '1', '10', '101', '04', '2056', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20556, to_date('11-04-2056', 'dd-mm-yyyy'), '2', '11', '102', '04', '2056', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20557, to_date('12-04-2056', 'dd-mm-yyyy'), '3', '12', '103', '04', '2056', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20558, to_date('13-04-2056', 'dd-mm-yyyy'), '4', '13', '104', '04', '2056', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20559, to_date('14-04-2056', 'dd-mm-yyyy'), '5', '14', '105', '04', '2056', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20560, to_date('15-04-2056', 'dd-mm-yyyy'), '6', '15', '106', '04', '2056', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20561, to_date('16-04-2056', 'dd-mm-yyyy'), '7', '16', '107', '04', '2056', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20562, to_date('17-04-2056', 'dd-mm-yyyy'), '1', '17', '108', '04', '2056', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20563, to_date('18-04-2056', 'dd-mm-yyyy'), '2', '18', '109', '04', '2056', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20564, to_date('19-04-2056', 'dd-mm-yyyy'), '3', '19', '110', '04', '2056', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20565, to_date('20-04-2056', 'dd-mm-yyyy'), '4', '20', '111', '04', '2056', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20566, to_date('21-04-2056', 'dd-mm-yyyy'), '5', '21', '112', '04', '2056', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20567, to_date('22-04-2056', 'dd-mm-yyyy'), '6', '22', '113', '04', '2056', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20568, to_date('23-04-2056', 'dd-mm-yyyy'), '7', '23', '114', '04', '2056', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20569, to_date('24-04-2056', 'dd-mm-yyyy'), '1', '24', '115', '04', '2056', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20570, to_date('25-04-2056', 'dd-mm-yyyy'), '2', '25', '116', '04', '2056', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20571, to_date('26-04-2056', 'dd-mm-yyyy'), '3', '26', '117', '04', '2056', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20572, to_date('27-04-2056', 'dd-mm-yyyy'), '4', '27', '118', '04', '2056', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20573, to_date('28-04-2056', 'dd-mm-yyyy'), '5', '28', '119', '04', '2056', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20574, to_date('29-04-2056', 'dd-mm-yyyy'), '6', '29', '120', '04', '2056', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20575, to_date('30-04-2056', 'dd-mm-yyyy'), '7', '30', '121', '04', '2056', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20576, to_date('01-05-2056', 'dd-mm-yyyy'), '1', '01', '122', '05', '2056', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20577, to_date('02-05-2056', 'dd-mm-yyyy'), '2', '02', '123', '05', '2056', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20578, to_date('03-05-2056', 'dd-mm-yyyy'), '3', '03', '124', '05', '2056', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20579, to_date('04-05-2056', 'dd-mm-yyyy'), '4', '04', '125', '05', '2056', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20580, to_date('05-05-2056', 'dd-mm-yyyy'), '5', '05', '126', '05', '2056', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20581, to_date('06-05-2056', 'dd-mm-yyyy'), '6', '06', '127', '05', '2056', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20582, to_date('07-05-2056', 'dd-mm-yyyy'), '7', '07', '128', '05', '2056', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20583, to_date('08-05-2056', 'dd-mm-yyyy'), '1', '08', '129', '05', '2056', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20584, to_date('09-05-2056', 'dd-mm-yyyy'), '2', '09', '130', '05', '2056', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20585, to_date('10-05-2056', 'dd-mm-yyyy'), '3', '10', '131', '05', '2056', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20586, to_date('11-05-2056', 'dd-mm-yyyy'), '4', '11', '132', '05', '2056', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20587, to_date('12-05-2056', 'dd-mm-yyyy'), '5', '12', '133', '05', '2056', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20588, to_date('13-05-2056', 'dd-mm-yyyy'), '6', '13', '134', '05', '2056', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20589, to_date('14-05-2056', 'dd-mm-yyyy'), '7', '14', '135', '05', '2056', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20590, to_date('15-05-2056', 'dd-mm-yyyy'), '1', '15', '136', '05', '2056', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20591, to_date('16-05-2056', 'dd-mm-yyyy'), '2', '16', '137', '05', '2056', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20592, to_date('17-05-2056', 'dd-mm-yyyy'), '3', '17', '138', '05', '2056', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20593, to_date('18-05-2056', 'dd-mm-yyyy'), '4', '18', '139', '05', '2056', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20594, to_date('19-05-2056', 'dd-mm-yyyy'), '5', '19', '140', '05', '2056', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20595, to_date('20-05-2056', 'dd-mm-yyyy'), '6', '20', '141', '05', '2056', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20596, to_date('21-05-2056', 'dd-mm-yyyy'), '7', '21', '142', '05', '2056', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20597, to_date('22-05-2056', 'dd-mm-yyyy'), '1', '22', '143', '05', '2056', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20598, to_date('23-05-2056', 'dd-mm-yyyy'), '2', '23', '144', '05', '2056', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20599, to_date('24-05-2056', 'dd-mm-yyyy'), '3', '24', '145', '05', '2056', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20600, to_date('25-05-2056', 'dd-mm-yyyy'), '4', '25', '146', '05', '2056', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20601, to_date('26-05-2056', 'dd-mm-yyyy'), '5', '26', '147', '05', '2056', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20602, to_date('27-05-2056', 'dd-mm-yyyy'), '6', '27', '148', '05', '2056', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20603, to_date('28-05-2056', 'dd-mm-yyyy'), '7', '28', '149', '05', '2056', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20604, to_date('29-05-2056', 'dd-mm-yyyy'), '1', '29', '150', '05', '2056', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20605, to_date('30-05-2056', 'dd-mm-yyyy'), '2', '30', '151', '05', '2056', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20606, to_date('31-05-2056', 'dd-mm-yyyy'), '3', '31', '152', '05', '2056', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20607, to_date('01-06-2056', 'dd-mm-yyyy'), '4', '01', '153', '06', '2056', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20608, to_date('02-06-2056', 'dd-mm-yyyy'), '5', '02', '154', '06', '2056', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20609, to_date('03-06-2056', 'dd-mm-yyyy'), '6', '03', '155', '06', '2056', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20610, to_date('04-06-2056', 'dd-mm-yyyy'), '7', '04', '156', '06', '2056', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20611, to_date('05-06-2056', 'dd-mm-yyyy'), '1', '05', '157', '06', '2056', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20612, to_date('06-06-2056', 'dd-mm-yyyy'), '2', '06', '158', '06', '2056', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20613, to_date('07-06-2056', 'dd-mm-yyyy'), '3', '07', '159', '06', '2056', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20614, to_date('08-06-2056', 'dd-mm-yyyy'), '4', '08', '160', '06', '2056', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20615, to_date('09-06-2056', 'dd-mm-yyyy'), '5', '09', '161', '06', '2056', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20616, to_date('10-06-2056', 'dd-mm-yyyy'), '6', '10', '162', '06', '2056', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20617, to_date('11-06-2056', 'dd-mm-yyyy'), '7', '11', '163', '06', '2056', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20618, to_date('12-06-2056', 'dd-mm-yyyy'), '1', '12', '164', '06', '2056', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20619, to_date('13-06-2056', 'dd-mm-yyyy'), '2', '13', '165', '06', '2056', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20620, to_date('14-06-2056', 'dd-mm-yyyy'), '3', '14', '166', '06', '2056', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20621, to_date('15-06-2056', 'dd-mm-yyyy'), '4', '15', '167', '06', '2056', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20622, to_date('16-06-2056', 'dd-mm-yyyy'), '5', '16', '168', '06', '2056', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20623, to_date('17-06-2056', 'dd-mm-yyyy'), '6', '17', '169', '06', '2056', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20624, to_date('18-06-2056', 'dd-mm-yyyy'), '7', '18', '170', '06', '2056', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20625, to_date('19-06-2056', 'dd-mm-yyyy'), '1', '19', '171', '06', '2056', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20626, to_date('20-06-2056', 'dd-mm-yyyy'), '2', '20', '172', '06', '2056', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20627, to_date('21-06-2056', 'dd-mm-yyyy'), '3', '21', '173', '06', '2056', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20628, to_date('22-06-2056', 'dd-mm-yyyy'), '4', '22', '174', '06', '2056', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20629, to_date('23-06-2056', 'dd-mm-yyyy'), '5', '23', '175', '06', '2056', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20630, to_date('24-06-2056', 'dd-mm-yyyy'), '6', '24', '176', '06', '2056', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20631, to_date('25-06-2056', 'dd-mm-yyyy'), '7', '25', '177', '06', '2056', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20632, to_date('26-06-2056', 'dd-mm-yyyy'), '1', '26', '178', '06', '2056', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20633, to_date('27-06-2056', 'dd-mm-yyyy'), '2', '27', '179', '06', '2056', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20634, to_date('28-06-2056', 'dd-mm-yyyy'), '3', '28', '180', '06', '2056', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20635, to_date('29-06-2056', 'dd-mm-yyyy'), '4', '29', '181', '06', '2056', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20636, to_date('30-06-2056', 'dd-mm-yyyy'), '5', '30', '182', '06', '2056', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20637, to_date('01-07-2056', 'dd-mm-yyyy'), '6', '01', '183', '07', '2056', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20638, to_date('02-07-2056', 'dd-mm-yyyy'), '7', '02', '184', '07', '2056', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20639, to_date('03-07-2056', 'dd-mm-yyyy'), '1', '03', '185', '07', '2056', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20640, to_date('04-07-2056', 'dd-mm-yyyy'), '2', '04', '186', '07', '2056', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20641, to_date('05-07-2056', 'dd-mm-yyyy'), '3', '05', '187', '07', '2056', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20642, to_date('06-07-2056', 'dd-mm-yyyy'), '4', '06', '188', '07', '2056', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20643, to_date('07-07-2056', 'dd-mm-yyyy'), '5', '07', '189', '07', '2056', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20644, to_date('08-07-2056', 'dd-mm-yyyy'), '6', '08', '190', '07', '2056', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22129, to_date('01-08-2060', 'dd-mm-yyyy'), '7', '01', '214', '08', '2060', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22130, to_date('02-08-2060', 'dd-mm-yyyy'), '1', '02', '215', '08', '2060', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22131, to_date('03-08-2060', 'dd-mm-yyyy'), '2', '03', '216', '08', '2060', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22132, to_date('04-08-2060', 'dd-mm-yyyy'), '3', '04', '217', '08', '2060', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22133, to_date('05-08-2060', 'dd-mm-yyyy'), '4', '05', '218', '08', '2060', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22134, to_date('06-08-2060', 'dd-mm-yyyy'), '5', '06', '219', '08', '2060', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22135, to_date('07-08-2060', 'dd-mm-yyyy'), '6', '07', '220', '08', '2060', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22136, to_date('08-08-2060', 'dd-mm-yyyy'), '7', '08', '221', '08', '2060', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22137, to_date('09-08-2060', 'dd-mm-yyyy'), '1', '09', '222', '08', '2060', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22138, to_date('10-08-2060', 'dd-mm-yyyy'), '2', '10', '223', '08', '2060', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22139, to_date('11-08-2060', 'dd-mm-yyyy'), '3', '11', '224', '08', '2060', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22140, to_date('12-08-2060', 'dd-mm-yyyy'), '4', '12', '225', '08', '2060', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22141, to_date('13-08-2060', 'dd-mm-yyyy'), '5', '13', '226', '08', '2060', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22142, to_date('14-08-2060', 'dd-mm-yyyy'), '6', '14', '227', '08', '2060', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22143, to_date('15-08-2060', 'dd-mm-yyyy'), '7', '15', '228', '08', '2060', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22144, to_date('16-08-2060', 'dd-mm-yyyy'), '1', '16', '229', '08', '2060', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22145, to_date('17-08-2060', 'dd-mm-yyyy'), '2', '17', '230', '08', '2060', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22146, to_date('18-08-2060', 'dd-mm-yyyy'), '3', '18', '231', '08', '2060', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22147, to_date('19-08-2060', 'dd-mm-yyyy'), '4', '19', '232', '08', '2060', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22148, to_date('20-08-2060', 'dd-mm-yyyy'), '5', '20', '233', '08', '2060', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22149, to_date('21-08-2060', 'dd-mm-yyyy'), '6', '21', '234', '08', '2060', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22150, to_date('22-08-2060', 'dd-mm-yyyy'), '7', '22', '235', '08', '2060', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22151, to_date('23-08-2060', 'dd-mm-yyyy'), '1', '23', '236', '08', '2060', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22152, to_date('24-08-2060', 'dd-mm-yyyy'), '2', '24', '237', '08', '2060', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22153, to_date('25-08-2060', 'dd-mm-yyyy'), '3', '25', '238', '08', '2060', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22154, to_date('26-08-2060', 'dd-mm-yyyy'), '4', '26', '239', '08', '2060', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22155, to_date('27-08-2060', 'dd-mm-yyyy'), '5', '27', '240', '08', '2060', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22156, to_date('28-08-2060', 'dd-mm-yyyy'), '6', '28', '241', '08', '2060', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22157, to_date('29-08-2060', 'dd-mm-yyyy'), '7', '29', '242', '08', '2060', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22158, to_date('30-08-2060', 'dd-mm-yyyy'), '1', '30', '243', '08', '2060', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22159, to_date('31-08-2060', 'dd-mm-yyyy'), '2', '31', '244', '08', '2060', '36', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22160, to_date('01-09-2060', 'dd-mm-yyyy'), '3', '01', '245', '09', '2060', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22161, to_date('02-09-2060', 'dd-mm-yyyy'), '4', '02', '246', '09', '2060', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22162, to_date('03-09-2060', 'dd-mm-yyyy'), '5', '03', '247', '09', '2060', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22163, to_date('04-09-2060', 'dd-mm-yyyy'), '6', '04', '248', '09', '2060', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22164, to_date('05-09-2060', 'dd-mm-yyyy'), '7', '05', '249', '09', '2060', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22165, to_date('06-09-2060', 'dd-mm-yyyy'), '1', '06', '250', '09', '2060', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22166, to_date('07-09-2060', 'dd-mm-yyyy'), '2', '07', '251', '09', '2060', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22167, to_date('08-09-2060', 'dd-mm-yyyy'), '3', '08', '252', '09', '2060', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22168, to_date('09-09-2060', 'dd-mm-yyyy'), '4', '09', '253', '09', '2060', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22169, to_date('10-09-2060', 'dd-mm-yyyy'), '5', '10', '254', '09', '2060', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22170, to_date('11-09-2060', 'dd-mm-yyyy'), '6', '11', '255', '09', '2060', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22171, to_date('12-09-2060', 'dd-mm-yyyy'), '7', '12', '256', '09', '2060', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22172, to_date('13-09-2060', 'dd-mm-yyyy'), '1', '13', '257', '09', '2060', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22173, to_date('14-09-2060', 'dd-mm-yyyy'), '2', '14', '258', '09', '2060', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22174, to_date('15-09-2060', 'dd-mm-yyyy'), '3', '15', '259', '09', '2060', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22175, to_date('16-09-2060', 'dd-mm-yyyy'), '4', '16', '260', '09', '2060', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22176, to_date('17-09-2060', 'dd-mm-yyyy'), '5', '17', '261', '09', '2060', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22177, to_date('18-09-2060', 'dd-mm-yyyy'), '6', '18', '262', '09', '2060', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22178, to_date('19-09-2060', 'dd-mm-yyyy'), '7', '19', '263', '09', '2060', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22179, to_date('20-09-2060', 'dd-mm-yyyy'), '1', '20', '264', '09', '2060', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22180, to_date('21-09-2060', 'dd-mm-yyyy'), '2', '21', '265', '09', '2060', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22181, to_date('22-09-2060', 'dd-mm-yyyy'), '3', '22', '266', '09', '2060', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22182, to_date('23-09-2060', 'dd-mm-yyyy'), '4', '23', '267', '09', '2060', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22183, to_date('24-09-2060', 'dd-mm-yyyy'), '5', '24', '268', '09', '2060', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22184, to_date('25-09-2060', 'dd-mm-yyyy'), '6', '25', '269', '09', '2060', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22185, to_date('26-09-2060', 'dd-mm-yyyy'), '7', '26', '270', '09', '2060', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22186, to_date('27-09-2060', 'dd-mm-yyyy'), '1', '27', '271', '09', '2060', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22187, to_date('28-09-2060', 'dd-mm-yyyy'), '2', '28', '272', '09', '2060', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22188, to_date('29-09-2060', 'dd-mm-yyyy'), '3', '29', '273', '09', '2060', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22189, to_date('30-09-2060', 'dd-mm-yyyy'), '4', '30', '274', '09', '2060', '40', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22190, to_date('01-10-2060', 'dd-mm-yyyy'), '5', '01', '275', '10', '2060', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22191, to_date('02-10-2060', 'dd-mm-yyyy'), '6', '02', '276', '10', '2060', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22192, to_date('03-10-2060', 'dd-mm-yyyy'), '7', '03', '277', '10', '2060', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22193, to_date('04-10-2060', 'dd-mm-yyyy'), '1', '04', '278', '10', '2060', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22194, to_date('05-10-2060', 'dd-mm-yyyy'), '2', '05', '279', '10', '2060', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22195, to_date('06-10-2060', 'dd-mm-yyyy'), '3', '06', '280', '10', '2060', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22196, to_date('07-10-2060', 'dd-mm-yyyy'), '4', '07', '281', '10', '2060', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22197, to_date('08-10-2060', 'dd-mm-yyyy'), '5', '08', '282', '10', '2060', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22198, to_date('09-10-2060', 'dd-mm-yyyy'), '6', '09', '283', '10', '2060', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22199, to_date('10-10-2060', 'dd-mm-yyyy'), '7', '10', '284', '10', '2060', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22200, to_date('11-10-2060', 'dd-mm-yyyy'), '1', '11', '285', '10', '2060', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22201, to_date('12-10-2060', 'dd-mm-yyyy'), '2', '12', '286', '10', '2060', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22202, to_date('13-10-2060', 'dd-mm-yyyy'), '3', '13', '287', '10', '2060', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22203, to_date('14-10-2060', 'dd-mm-yyyy'), '4', '14', '288', '10', '2060', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22204, to_date('15-10-2060', 'dd-mm-yyyy'), '5', '15', '289', '10', '2060', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22205, to_date('16-10-2060', 'dd-mm-yyyy'), '6', '16', '290', '10', '2060', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22206, to_date('17-10-2060', 'dd-mm-yyyy'), '7', '17', '291', '10', '2060', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22207, to_date('18-10-2060', 'dd-mm-yyyy'), '1', '18', '292', '10', '2060', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22208, to_date('19-10-2060', 'dd-mm-yyyy'), '2', '19', '293', '10', '2060', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22209, to_date('20-10-2060', 'dd-mm-yyyy'), '3', '20', '294', '10', '2060', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22210, to_date('21-10-2060', 'dd-mm-yyyy'), '4', '21', '295', '10', '2060', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22211, to_date('22-10-2060', 'dd-mm-yyyy'), '5', '22', '296', '10', '2060', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22212, to_date('23-10-2060', 'dd-mm-yyyy'), '6', '23', '297', '10', '2060', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22213, to_date('24-10-2060', 'dd-mm-yyyy'), '7', '24', '298', '10', '2060', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22214, to_date('25-10-2060', 'dd-mm-yyyy'), '1', '25', '299', '10', '2060', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22215, to_date('26-10-2060', 'dd-mm-yyyy'), '2', '26', '300', '10', '2060', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22216, to_date('27-10-2060', 'dd-mm-yyyy'), '3', '27', '301', '10', '2060', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22217, to_date('28-10-2060', 'dd-mm-yyyy'), '4', '28', '302', '10', '2060', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22218, to_date('29-10-2060', 'dd-mm-yyyy'), '5', '29', '303', '10', '2060', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22219, to_date('30-10-2060', 'dd-mm-yyyy'), '6', '30', '304', '10', '2060', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22220, to_date('31-10-2060', 'dd-mm-yyyy'), '7', '31', '305', '10', '2060', '44', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22221, to_date('01-11-2060', 'dd-mm-yyyy'), '1', '01', '306', '11', '2060', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22222, to_date('02-11-2060', 'dd-mm-yyyy'), '2', '02', '307', '11', '2060', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22223, to_date('03-11-2060', 'dd-mm-yyyy'), '3', '03', '308', '11', '2060', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22224, to_date('04-11-2060', 'dd-mm-yyyy'), '4', '04', '309', '11', '2060', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22225, to_date('05-11-2060', 'dd-mm-yyyy'), '5', '05', '310', '11', '2060', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22226, to_date('06-11-2060', 'dd-mm-yyyy'), '6', '06', '311', '11', '2060', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22227, to_date('07-11-2060', 'dd-mm-yyyy'), '7', '07', '312', '11', '2060', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22228, to_date('08-11-2060', 'dd-mm-yyyy'), '1', '08', '313', '11', '2060', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22229, to_date('09-11-2060', 'dd-mm-yyyy'), '2', '09', '314', '11', '2060', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22230, to_date('10-11-2060', 'dd-mm-yyyy'), '3', '10', '315', '11', '2060', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22231, to_date('11-11-2060', 'dd-mm-yyyy'), '4', '11', '316', '11', '2060', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22232, to_date('12-11-2060', 'dd-mm-yyyy'), '5', '12', '317', '11', '2060', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22233, to_date('13-11-2060', 'dd-mm-yyyy'), '6', '13', '318', '11', '2060', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22234, to_date('14-11-2060', 'dd-mm-yyyy'), '7', '14', '319', '11', '2060', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23719, to_date('08-12-2064', 'dd-mm-yyyy'), '1', '08', '343', '12', '2064', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23720, to_date('09-12-2064', 'dd-mm-yyyy'), '2', '09', '344', '12', '2064', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23721, to_date('10-12-2064', 'dd-mm-yyyy'), '3', '10', '345', '12', '2064', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23722, to_date('11-12-2064', 'dd-mm-yyyy'), '4', '11', '346', '12', '2064', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23723, to_date('12-12-2064', 'dd-mm-yyyy'), '5', '12', '347', '12', '2064', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23724, to_date('13-12-2064', 'dd-mm-yyyy'), '6', '13', '348', '12', '2064', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23725, to_date('14-12-2064', 'dd-mm-yyyy'), '7', '14', '349', '12', '2064', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23726, to_date('15-12-2064', 'dd-mm-yyyy'), '1', '15', '350', '12', '2064', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23727, to_date('16-12-2064', 'dd-mm-yyyy'), '2', '16', '351', '12', '2064', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23728, to_date('17-12-2064', 'dd-mm-yyyy'), '3', '17', '352', '12', '2064', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23729, to_date('18-12-2064', 'dd-mm-yyyy'), '4', '18', '353', '12', '2064', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23730, to_date('19-12-2064', 'dd-mm-yyyy'), '5', '19', '354', '12', '2064', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23731, to_date('20-12-2064', 'dd-mm-yyyy'), '6', '20', '355', '12', '2064', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23732, to_date('21-12-2064', 'dd-mm-yyyy'), '7', '21', '356', '12', '2064', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23733, to_date('22-12-2064', 'dd-mm-yyyy'), '1', '22', '357', '12', '2064', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23734, to_date('23-12-2064', 'dd-mm-yyyy'), '2', '23', '358', '12', '2064', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23735, to_date('24-12-2064', 'dd-mm-yyyy'), '3', '24', '359', '12', '2064', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23736, to_date('25-12-2064', 'dd-mm-yyyy'), '4', '25', '360', '12', '2064', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23737, to_date('26-12-2064', 'dd-mm-yyyy'), '5', '26', '361', '12', '2064', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23738, to_date('27-12-2064', 'dd-mm-yyyy'), '6', '27', '362', '12', '2064', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23739, to_date('28-12-2064', 'dd-mm-yyyy'), '7', '28', '363', '12', '2064', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23740, to_date('29-12-2064', 'dd-mm-yyyy'), '1', '29', '364', '12', '2064', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23741, to_date('30-12-2064', 'dd-mm-yyyy'), '2', '30', '365', '12', '2064', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23742, to_date('31-12-2064', 'dd-mm-yyyy'), '3', '31', '366', '12', '2064', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23743, to_date('01-01-2065', 'dd-mm-yyyy'), '4', '01', '001', '01', '2065', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23744, to_date('02-01-2065', 'dd-mm-yyyy'), '5', '02', '002', '01', '2065', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23745, to_date('03-01-2065', 'dd-mm-yyyy'), '6', '03', '003', '01', '2065', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23746, to_date('04-01-2065', 'dd-mm-yyyy'), '7', '04', '004', '01', '2065', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23747, to_date('05-01-2065', 'dd-mm-yyyy'), '1', '05', '005', '01', '2065', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23748, to_date('06-01-2065', 'dd-mm-yyyy'), '2', '06', '006', '01', '2065', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23749, to_date('07-01-2065', 'dd-mm-yyyy'), '3', '07', '007', '01', '2065', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23750, to_date('08-01-2065', 'dd-mm-yyyy'), '4', '08', '008', '01', '2065', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23751, to_date('09-01-2065', 'dd-mm-yyyy'), '5', '09', '009', '01', '2065', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23752, to_date('10-01-2065', 'dd-mm-yyyy'), '6', '10', '010', '01', '2065', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23753, to_date('11-01-2065', 'dd-mm-yyyy'), '7', '11', '011', '01', '2065', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23754, to_date('12-01-2065', 'dd-mm-yyyy'), '1', '12', '012', '01', '2065', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23755, to_date('13-01-2065', 'dd-mm-yyyy'), '2', '13', '013', '01', '2065', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23756, to_date('14-01-2065', 'dd-mm-yyyy'), '3', '14', '014', '01', '2065', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23757, to_date('15-01-2065', 'dd-mm-yyyy'), '4', '15', '015', '01', '2065', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23758, to_date('16-01-2065', 'dd-mm-yyyy'), '5', '16', '016', '01', '2065', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23759, to_date('17-01-2065', 'dd-mm-yyyy'), '6', '17', '017', '01', '2065', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23760, to_date('18-01-2065', 'dd-mm-yyyy'), '7', '18', '018', '01', '2065', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23761, to_date('19-01-2065', 'dd-mm-yyyy'), '1', '19', '019', '01', '2065', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23762, to_date('20-01-2065', 'dd-mm-yyyy'), '2', '20', '020', '01', '2065', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23763, to_date('21-01-2065', 'dd-mm-yyyy'), '3', '21', '021', '01', '2065', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23764, to_date('22-01-2065', 'dd-mm-yyyy'), '4', '22', '022', '01', '2065', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23765, to_date('23-01-2065', 'dd-mm-yyyy'), '5', '23', '023', '01', '2065', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23766, to_date('24-01-2065', 'dd-mm-yyyy'), '6', '24', '024', '01', '2065', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23767, to_date('25-01-2065', 'dd-mm-yyyy'), '7', '25', '025', '01', '2065', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23768, to_date('26-01-2065', 'dd-mm-yyyy'), '1', '26', '026', '01', '2065', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23769, to_date('27-01-2065', 'dd-mm-yyyy'), '2', '27', '027', '01', '2065', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23770, to_date('28-01-2065', 'dd-mm-yyyy'), '3', '28', '028', '01', '2065', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23771, to_date('29-01-2065', 'dd-mm-yyyy'), '4', '29', '029', '01', '2065', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23772, to_date('30-01-2065', 'dd-mm-yyyy'), '5', '30', '030', '01', '2065', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23773, to_date('31-01-2065', 'dd-mm-yyyy'), '6', '31', '031', '01', '2065', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23774, to_date('01-02-2065', 'dd-mm-yyyy'), '7', '01', '032', '02', '2065', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23775, to_date('02-02-2065', 'dd-mm-yyyy'), '1', '02', '033', '02', '2065', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23776, to_date('03-02-2065', 'dd-mm-yyyy'), '2', '03', '034', '02', '2065', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23777, to_date('04-02-2065', 'dd-mm-yyyy'), '3', '04', '035', '02', '2065', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23778, to_date('05-02-2065', 'dd-mm-yyyy'), '4', '05', '036', '02', '2065', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23779, to_date('06-02-2065', 'dd-mm-yyyy'), '5', '06', '037', '02', '2065', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23780, to_date('07-02-2065', 'dd-mm-yyyy'), '6', '07', '038', '02', '2065', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23781, to_date('08-02-2065', 'dd-mm-yyyy'), '7', '08', '039', '02', '2065', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23782, to_date('09-02-2065', 'dd-mm-yyyy'), '1', '09', '040', '02', '2065', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23783, to_date('10-02-2065', 'dd-mm-yyyy'), '2', '10', '041', '02', '2065', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23784, to_date('11-02-2065', 'dd-mm-yyyy'), '3', '11', '042', '02', '2065', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23785, to_date('12-02-2065', 'dd-mm-yyyy'), '4', '12', '043', '02', '2065', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23786, to_date('13-02-2065', 'dd-mm-yyyy'), '5', '13', '044', '02', '2065', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23787, to_date('14-02-2065', 'dd-mm-yyyy'), '6', '14', '045', '02', '2065', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23788, to_date('15-02-2065', 'dd-mm-yyyy'), '7', '15', '046', '02', '2065', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23789, to_date('16-02-2065', 'dd-mm-yyyy'), '1', '16', '047', '02', '2065', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23790, to_date('17-02-2065', 'dd-mm-yyyy'), '2', '17', '048', '02', '2065', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23791, to_date('18-02-2065', 'dd-mm-yyyy'), '3', '18', '049', '02', '2065', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23792, to_date('19-02-2065', 'dd-mm-yyyy'), '4', '19', '050', '02', '2065', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23793, to_date('20-02-2065', 'dd-mm-yyyy'), '5', '20', '051', '02', '2065', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23794, to_date('21-02-2065', 'dd-mm-yyyy'), '6', '21', '052', '02', '2065', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23795, to_date('22-02-2065', 'dd-mm-yyyy'), '7', '22', '053', '02', '2065', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23796, to_date('23-02-2065', 'dd-mm-yyyy'), '1', '23', '054', '02', '2065', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23797, to_date('24-02-2065', 'dd-mm-yyyy'), '2', '24', '055', '02', '2065', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23798, to_date('25-02-2065', 'dd-mm-yyyy'), '3', '25', '056', '02', '2065', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23799, to_date('26-02-2065', 'dd-mm-yyyy'), '4', '26', '057', '02', '2065', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23800, to_date('27-02-2065', 'dd-mm-yyyy'), '5', '27', '058', '02', '2065', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23801, to_date('28-02-2065', 'dd-mm-yyyy'), '6', '28', '059', '02', '2065', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23802, to_date('01-03-2065', 'dd-mm-yyyy'), '7', '01', '060', '03', '2065', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23803, to_date('02-03-2065', 'dd-mm-yyyy'), '1', '02', '061', '03', '2065', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23804, to_date('03-03-2065', 'dd-mm-yyyy'), '2', '03', '062', '03', '2065', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23805, to_date('04-03-2065', 'dd-mm-yyyy'), '3', '04', '063', '03', '2065', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23806, to_date('05-03-2065', 'dd-mm-yyyy'), '4', '05', '064', '03', '2065', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23807, to_date('06-03-2065', 'dd-mm-yyyy'), '5', '06', '065', '03', '2065', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23808, to_date('07-03-2065', 'dd-mm-yyyy'), '6', '07', '066', '03', '2065', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23809, to_date('08-03-2065', 'dd-mm-yyyy'), '7', '08', '067', '03', '2065', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23810, to_date('09-03-2065', 'dd-mm-yyyy'), '1', '09', '068', '03', '2065', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23811, to_date('10-03-2065', 'dd-mm-yyyy'), '2', '10', '069', '03', '2065', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23812, to_date('11-03-2065', 'dd-mm-yyyy'), '3', '11', '070', '03', '2065', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23813, to_date('12-03-2065', 'dd-mm-yyyy'), '4', '12', '071', '03', '2065', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23814, to_date('13-03-2065', 'dd-mm-yyyy'), '5', '13', '072', '03', '2065', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23815, to_date('14-03-2065', 'dd-mm-yyyy'), '6', '14', '073', '03', '2065', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23816, to_date('15-03-2065', 'dd-mm-yyyy'), '7', '15', '074', '03', '2065', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23817, to_date('16-03-2065', 'dd-mm-yyyy'), '1', '16', '075', '03', '2065', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23818, to_date('17-03-2065', 'dd-mm-yyyy'), '2', '17', '076', '03', '2065', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23819, to_date('18-03-2065', 'dd-mm-yyyy'), '3', '18', '077', '03', '2065', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23820, to_date('19-03-2065', 'dd-mm-yyyy'), '4', '19', '078', '03', '2065', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23821, to_date('20-03-2065', 'dd-mm-yyyy'), '5', '20', '079', '03', '2065', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23822, to_date('21-03-2065', 'dd-mm-yyyy'), '6', '21', '080', '03', '2065', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23823, to_date('22-03-2065', 'dd-mm-yyyy'), '7', '22', '081', '03', '2065', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23824, to_date('23-03-2065', 'dd-mm-yyyy'), '1', '23', '082', '03', '2065', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25309, to_date('16-04-2069', 'dd-mm-yyyy'), '2', '16', '106', '04', '2069', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25310, to_date('17-04-2069', 'dd-mm-yyyy'), '3', '17', '107', '04', '2069', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25311, to_date('18-04-2069', 'dd-mm-yyyy'), '4', '18', '108', '04', '2069', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25312, to_date('19-04-2069', 'dd-mm-yyyy'), '5', '19', '109', '04', '2069', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25313, to_date('20-04-2069', 'dd-mm-yyyy'), '6', '20', '110', '04', '2069', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25314, to_date('21-04-2069', 'dd-mm-yyyy'), '7', '21', '111', '04', '2069', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
commit;
prompt 18000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25315, to_date('22-04-2069', 'dd-mm-yyyy'), '1', '22', '112', '04', '2069', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25316, to_date('23-04-2069', 'dd-mm-yyyy'), '2', '23', '113', '04', '2069', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25317, to_date('24-04-2069', 'dd-mm-yyyy'), '3', '24', '114', '04', '2069', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25318, to_date('25-04-2069', 'dd-mm-yyyy'), '4', '25', '115', '04', '2069', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25319, to_date('26-04-2069', 'dd-mm-yyyy'), '5', '26', '116', '04', '2069', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25320, to_date('27-04-2069', 'dd-mm-yyyy'), '6', '27', '117', '04', '2069', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25321, to_date('28-04-2069', 'dd-mm-yyyy'), '7', '28', '118', '04', '2069', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25322, to_date('29-04-2069', 'dd-mm-yyyy'), '1', '29', '119', '04', '2069', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25323, to_date('30-04-2069', 'dd-mm-yyyy'), '2', '30', '120', '04', '2069', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25324, to_date('01-05-2069', 'dd-mm-yyyy'), '3', '01', '121', '05', '2069', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25325, to_date('02-05-2069', 'dd-mm-yyyy'), '4', '02', '122', '05', '2069', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25326, to_date('03-05-2069', 'dd-mm-yyyy'), '5', '03', '123', '05', '2069', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25327, to_date('04-05-2069', 'dd-mm-yyyy'), '6', '04', '124', '05', '2069', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25328, to_date('05-05-2069', 'dd-mm-yyyy'), '7', '05', '125', '05', '2069', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25329, to_date('06-05-2069', 'dd-mm-yyyy'), '1', '06', '126', '05', '2069', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25330, to_date('07-05-2069', 'dd-mm-yyyy'), '2', '07', '127', '05', '2069', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25331, to_date('08-05-2069', 'dd-mm-yyyy'), '3', '08', '128', '05', '2069', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25332, to_date('09-05-2069', 'dd-mm-yyyy'), '4', '09', '129', '05', '2069', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25333, to_date('10-05-2069', 'dd-mm-yyyy'), '5', '10', '130', '05', '2069', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25334, to_date('11-05-2069', 'dd-mm-yyyy'), '6', '11', '131', '05', '2069', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25335, to_date('12-05-2069', 'dd-mm-yyyy'), '7', '12', '132', '05', '2069', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25336, to_date('13-05-2069', 'dd-mm-yyyy'), '1', '13', '133', '05', '2069', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25337, to_date('14-05-2069', 'dd-mm-yyyy'), '2', '14', '134', '05', '2069', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25338, to_date('15-05-2069', 'dd-mm-yyyy'), '3', '15', '135', '05', '2069', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25339, to_date('16-05-2069', 'dd-mm-yyyy'), '4', '16', '136', '05', '2069', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25340, to_date('17-05-2069', 'dd-mm-yyyy'), '5', '17', '137', '05', '2069', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25341, to_date('18-05-2069', 'dd-mm-yyyy'), '6', '18', '138', '05', '2069', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25342, to_date('19-05-2069', 'dd-mm-yyyy'), '7', '19', '139', '05', '2069', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25343, to_date('20-05-2069', 'dd-mm-yyyy'), '1', '20', '140', '05', '2069', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25344, to_date('21-05-2069', 'dd-mm-yyyy'), '2', '21', '141', '05', '2069', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25345, to_date('22-05-2069', 'dd-mm-yyyy'), '3', '22', '142', '05', '2069', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25346, to_date('23-05-2069', 'dd-mm-yyyy'), '4', '23', '143', '05', '2069', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25347, to_date('24-05-2069', 'dd-mm-yyyy'), '5', '24', '144', '05', '2069', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25348, to_date('25-05-2069', 'dd-mm-yyyy'), '6', '25', '145', '05', '2069', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25349, to_date('26-05-2069', 'dd-mm-yyyy'), '7', '26', '146', '05', '2069', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25350, to_date('27-05-2069', 'dd-mm-yyyy'), '1', '27', '147', '05', '2069', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25351, to_date('28-05-2069', 'dd-mm-yyyy'), '2', '28', '148', '05', '2069', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25352, to_date('29-05-2069', 'dd-mm-yyyy'), '3', '29', '149', '05', '2069', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25353, to_date('30-05-2069', 'dd-mm-yyyy'), '4', '30', '150', '05', '2069', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25354, to_date('31-05-2069', 'dd-mm-yyyy'), '5', '31', '151', '05', '2069', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25355, to_date('01-06-2069', 'dd-mm-yyyy'), '6', '01', '152', '06', '2069', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25356, to_date('02-06-2069', 'dd-mm-yyyy'), '7', '02', '153', '06', '2069', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25357, to_date('03-06-2069', 'dd-mm-yyyy'), '1', '03', '154', '06', '2069', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25358, to_date('04-06-2069', 'dd-mm-yyyy'), '2', '04', '155', '06', '2069', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25359, to_date('05-06-2069', 'dd-mm-yyyy'), '3', '05', '156', '06', '2069', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25360, to_date('06-06-2069', 'dd-mm-yyyy'), '4', '06', '157', '06', '2069', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25361, to_date('07-06-2069', 'dd-mm-yyyy'), '5', '07', '158', '06', '2069', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25362, to_date('08-06-2069', 'dd-mm-yyyy'), '6', '08', '159', '06', '2069', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25363, to_date('09-06-2069', 'dd-mm-yyyy'), '7', '09', '160', '06', '2069', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25364, to_date('10-06-2069', 'dd-mm-yyyy'), '1', '10', '161', '06', '2069', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25365, to_date('11-06-2069', 'dd-mm-yyyy'), '2', '11', '162', '06', '2069', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25366, to_date('12-06-2069', 'dd-mm-yyyy'), '3', '12', '163', '06', '2069', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25367, to_date('13-06-2069', 'dd-mm-yyyy'), '4', '13', '164', '06', '2069', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25368, to_date('14-06-2069', 'dd-mm-yyyy'), '5', '14', '165', '06', '2069', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25369, to_date('15-06-2069', 'dd-mm-yyyy'), '6', '15', '166', '06', '2069', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25370, to_date('16-06-2069', 'dd-mm-yyyy'), '7', '16', '167', '06', '2069', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25371, to_date('17-06-2069', 'dd-mm-yyyy'), '1', '17', '168', '06', '2069', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25372, to_date('18-06-2069', 'dd-mm-yyyy'), '2', '18', '169', '06', '2069', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25373, to_date('19-06-2069', 'dd-mm-yyyy'), '3', '19', '170', '06', '2069', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25374, to_date('20-06-2069', 'dd-mm-yyyy'), '4', '20', '171', '06', '2069', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25375, to_date('21-06-2069', 'dd-mm-yyyy'), '5', '21', '172', '06', '2069', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25376, to_date('22-06-2069', 'dd-mm-yyyy'), '6', '22', '173', '06', '2069', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25377, to_date('23-06-2069', 'dd-mm-yyyy'), '7', '23', '174', '06', '2069', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25378, to_date('24-06-2069', 'dd-mm-yyyy'), '1', '24', '175', '06', '2069', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25379, to_date('25-06-2069', 'dd-mm-yyyy'), '2', '25', '176', '06', '2069', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25380, to_date('26-06-2069', 'dd-mm-yyyy'), '3', '26', '177', '06', '2069', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25381, to_date('27-06-2069', 'dd-mm-yyyy'), '4', '27', '178', '06', '2069', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25382, to_date('28-06-2069', 'dd-mm-yyyy'), '5', '28', '179', '06', '2069', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25383, to_date('29-06-2069', 'dd-mm-yyyy'), '6', '29', '180', '06', '2069', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25384, to_date('30-06-2069', 'dd-mm-yyyy'), '7', '30', '181', '06', '2069', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25385, to_date('01-07-2069', 'dd-mm-yyyy'), '1', '01', '182', '07', '2069', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25386, to_date('02-07-2069', 'dd-mm-yyyy'), '2', '02', '183', '07', '2069', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25387, to_date('03-07-2069', 'dd-mm-yyyy'), '3', '03', '184', '07', '2069', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25388, to_date('04-07-2069', 'dd-mm-yyyy'), '4', '04', '185', '07', '2069', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25389, to_date('05-07-2069', 'dd-mm-yyyy'), '5', '05', '186', '07', '2069', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25390, to_date('06-07-2069', 'dd-mm-yyyy'), '6', '06', '187', '07', '2069', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25391, to_date('07-07-2069', 'dd-mm-yyyy'), '7', '07', '188', '07', '2069', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25392, to_date('08-07-2069', 'dd-mm-yyyy'), '1', '08', '189', '07', '2069', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25393, to_date('09-07-2069', 'dd-mm-yyyy'), '2', '09', '190', '07', '2069', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25394, to_date('10-07-2069', 'dd-mm-yyyy'), '3', '10', '191', '07', '2069', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25395, to_date('11-07-2069', 'dd-mm-yyyy'), '4', '11', '192', '07', '2069', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25396, to_date('12-07-2069', 'dd-mm-yyyy'), '5', '12', '193', '07', '2069', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25397, to_date('13-07-2069', 'dd-mm-yyyy'), '6', '13', '194', '07', '2069', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25398, to_date('14-07-2069', 'dd-mm-yyyy'), '7', '14', '195', '07', '2069', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25399, to_date('15-07-2069', 'dd-mm-yyyy'), '1', '15', '196', '07', '2069', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25400, to_date('16-07-2069', 'dd-mm-yyyy'), '2', '16', '197', '07', '2069', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25401, to_date('17-07-2069', 'dd-mm-yyyy'), '3', '17', '198', '07', '2069', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25402, to_date('18-07-2069', 'dd-mm-yyyy'), '4', '18', '199', '07', '2069', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25403, to_date('19-07-2069', 'dd-mm-yyyy'), '5', '19', '200', '07', '2069', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25404, to_date('20-07-2069', 'dd-mm-yyyy'), '6', '20', '201', '07', '2069', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25405, to_date('21-07-2069', 'dd-mm-yyyy'), '7', '21', '202', '07', '2069', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25406, to_date('22-07-2069', 'dd-mm-yyyy'), '1', '22', '203', '07', '2069', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25407, to_date('23-07-2069', 'dd-mm-yyyy'), '2', '23', '204', '07', '2069', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25408, to_date('24-07-2069', 'dd-mm-yyyy'), '3', '24', '205', '07', '2069', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25409, to_date('25-07-2069', 'dd-mm-yyyy'), '4', '25', '206', '07', '2069', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25410, to_date('26-07-2069', 'dd-mm-yyyy'), '5', '26', '207', '07', '2069', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25411, to_date('27-07-2069', 'dd-mm-yyyy'), '6', '27', '208', '07', '2069', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25412, to_date('28-07-2069', 'dd-mm-yyyy'), '7', '28', '209', '07', '2069', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25413, to_date('29-07-2069', 'dd-mm-yyyy'), '1', '29', '210', '07', '2069', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25414, to_date('30-07-2069', 'dd-mm-yyyy'), '2', '30', '211', '07', '2069', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20645, to_date('09-07-2056', 'dd-mm-yyyy'), '7', '09', '191', '07', '2056', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20646, to_date('10-07-2056', 'dd-mm-yyyy'), '1', '10', '192', '07', '2056', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20647, to_date('11-07-2056', 'dd-mm-yyyy'), '2', '11', '193', '07', '2056', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20648, to_date('12-07-2056', 'dd-mm-yyyy'), '3', '12', '194', '07', '2056', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20649, to_date('13-07-2056', 'dd-mm-yyyy'), '4', '13', '195', '07', '2056', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20650, to_date('14-07-2056', 'dd-mm-yyyy'), '5', '14', '196', '07', '2056', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20651, to_date('15-07-2056', 'dd-mm-yyyy'), '6', '15', '197', '07', '2056', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20652, to_date('16-07-2056', 'dd-mm-yyyy'), '7', '16', '198', '07', '2056', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20653, to_date('17-07-2056', 'dd-mm-yyyy'), '1', '17', '199', '07', '2056', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20654, to_date('18-07-2056', 'dd-mm-yyyy'), '2', '18', '200', '07', '2056', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20655, to_date('19-07-2056', 'dd-mm-yyyy'), '3', '19', '201', '07', '2056', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20656, to_date('20-07-2056', 'dd-mm-yyyy'), '4', '20', '202', '07', '2056', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20657, to_date('21-07-2056', 'dd-mm-yyyy'), '5', '21', '203', '07', '2056', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20658, to_date('22-07-2056', 'dd-mm-yyyy'), '6', '22', '204', '07', '2056', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20659, to_date('23-07-2056', 'dd-mm-yyyy'), '7', '23', '205', '07', '2056', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20660, to_date('24-07-2056', 'dd-mm-yyyy'), '1', '24', '206', '07', '2056', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20661, to_date('25-07-2056', 'dd-mm-yyyy'), '2', '25', '207', '07', '2056', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20662, to_date('26-07-2056', 'dd-mm-yyyy'), '3', '26', '208', '07', '2056', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20663, to_date('27-07-2056', 'dd-mm-yyyy'), '4', '27', '209', '07', '2056', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20664, to_date('28-07-2056', 'dd-mm-yyyy'), '5', '28', '210', '07', '2056', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20665, to_date('29-07-2056', 'dd-mm-yyyy'), '6', '29', '211', '07', '2056', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20666, to_date('30-07-2056', 'dd-mm-yyyy'), '7', '30', '212', '07', '2056', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20667, to_date('31-07-2056', 'dd-mm-yyyy'), '1', '31', '213', '07', '2056', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20668, to_date('01-08-2056', 'dd-mm-yyyy'), '2', '01', '214', '08', '2056', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20669, to_date('02-08-2056', 'dd-mm-yyyy'), '3', '02', '215', '08', '2056', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20670, to_date('03-08-2056', 'dd-mm-yyyy'), '4', '03', '216', '08', '2056', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20671, to_date('04-08-2056', 'dd-mm-yyyy'), '5', '04', '217', '08', '2056', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20672, to_date('05-08-2056', 'dd-mm-yyyy'), '6', '05', '218', '08', '2056', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20673, to_date('06-08-2056', 'dd-mm-yyyy'), '7', '06', '219', '08', '2056', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20674, to_date('07-08-2056', 'dd-mm-yyyy'), '1', '07', '220', '08', '2056', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20675, to_date('08-08-2056', 'dd-mm-yyyy'), '2', '08', '221', '08', '2056', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20676, to_date('09-08-2056', 'dd-mm-yyyy'), '3', '09', '222', '08', '2056', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20677, to_date('10-08-2056', 'dd-mm-yyyy'), '4', '10', '223', '08', '2056', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20678, to_date('11-08-2056', 'dd-mm-yyyy'), '5', '11', '224', '08', '2056', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20679, to_date('12-08-2056', 'dd-mm-yyyy'), '6', '12', '225', '08', '2056', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20680, to_date('13-08-2056', 'dd-mm-yyyy'), '7', '13', '226', '08', '2056', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20681, to_date('14-08-2056', 'dd-mm-yyyy'), '1', '14', '227', '08', '2056', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20682, to_date('15-08-2056', 'dd-mm-yyyy'), '2', '15', '228', '08', '2056', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20683, to_date('16-08-2056', 'dd-mm-yyyy'), '3', '16', '229', '08', '2056', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20684, to_date('17-08-2056', 'dd-mm-yyyy'), '4', '17', '230', '08', '2056', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20685, to_date('18-08-2056', 'dd-mm-yyyy'), '5', '18', '231', '08', '2056', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20686, to_date('19-08-2056', 'dd-mm-yyyy'), '6', '19', '232', '08', '2056', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20687, to_date('20-08-2056', 'dd-mm-yyyy'), '7', '20', '233', '08', '2056', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20688, to_date('21-08-2056', 'dd-mm-yyyy'), '1', '21', '234', '08', '2056', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20689, to_date('22-08-2056', 'dd-mm-yyyy'), '2', '22', '235', '08', '2056', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20690, to_date('23-08-2056', 'dd-mm-yyyy'), '3', '23', '236', '08', '2056', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20691, to_date('24-08-2056', 'dd-mm-yyyy'), '4', '24', '237', '08', '2056', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20692, to_date('25-08-2056', 'dd-mm-yyyy'), '5', '25', '238', '08', '2056', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20693, to_date('26-08-2056', 'dd-mm-yyyy'), '6', '26', '239', '08', '2056', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20694, to_date('27-08-2056', 'dd-mm-yyyy'), '7', '27', '240', '08', '2056', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20695, to_date('28-08-2056', 'dd-mm-yyyy'), '1', '28', '241', '08', '2056', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20696, to_date('29-08-2056', 'dd-mm-yyyy'), '2', '29', '242', '08', '2056', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20697, to_date('30-08-2056', 'dd-mm-yyyy'), '3', '30', '243', '08', '2056', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20698, to_date('31-08-2056', 'dd-mm-yyyy'), '4', '31', '244', '08', '2056', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20699, to_date('01-09-2056', 'dd-mm-yyyy'), '5', '01', '245', '09', '2056', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20700, to_date('02-09-2056', 'dd-mm-yyyy'), '6', '02', '246', '09', '2056', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20701, to_date('03-09-2056', 'dd-mm-yyyy'), '7', '03', '247', '09', '2056', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20702, to_date('04-09-2056', 'dd-mm-yyyy'), '1', '04', '248', '09', '2056', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20703, to_date('05-09-2056', 'dd-mm-yyyy'), '2', '05', '249', '09', '2056', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20704, to_date('06-09-2056', 'dd-mm-yyyy'), '3', '06', '250', '09', '2056', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20705, to_date('07-09-2056', 'dd-mm-yyyy'), '4', '07', '251', '09', '2056', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20706, to_date('08-09-2056', 'dd-mm-yyyy'), '5', '08', '252', '09', '2056', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20707, to_date('09-09-2056', 'dd-mm-yyyy'), '6', '09', '253', '09', '2056', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20708, to_date('10-09-2056', 'dd-mm-yyyy'), '7', '10', '254', '09', '2056', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20709, to_date('11-09-2056', 'dd-mm-yyyy'), '1', '11', '255', '09', '2056', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20710, to_date('12-09-2056', 'dd-mm-yyyy'), '2', '12', '256', '09', '2056', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20711, to_date('13-09-2056', 'dd-mm-yyyy'), '3', '13', '257', '09', '2056', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20712, to_date('14-09-2056', 'dd-mm-yyyy'), '4', '14', '258', '09', '2056', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20713, to_date('15-09-2056', 'dd-mm-yyyy'), '5', '15', '259', '09', '2056', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20714, to_date('16-09-2056', 'dd-mm-yyyy'), '6', '16', '260', '09', '2056', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20715, to_date('17-09-2056', 'dd-mm-yyyy'), '7', '17', '261', '09', '2056', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20716, to_date('18-09-2056', 'dd-mm-yyyy'), '1', '18', '262', '09', '2056', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20717, to_date('19-09-2056', 'dd-mm-yyyy'), '2', '19', '263', '09', '2056', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20718, to_date('20-09-2056', 'dd-mm-yyyy'), '3', '20', '264', '09', '2056', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20719, to_date('21-09-2056', 'dd-mm-yyyy'), '4', '21', '265', '09', '2056', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20720, to_date('22-09-2056', 'dd-mm-yyyy'), '5', '22', '266', '09', '2056', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20721, to_date('23-09-2056', 'dd-mm-yyyy'), '6', '23', '267', '09', '2056', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20722, to_date('24-09-2056', 'dd-mm-yyyy'), '7', '24', '268', '09', '2056', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20723, to_date('25-09-2056', 'dd-mm-yyyy'), '1', '25', '269', '09', '2056', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20724, to_date('26-09-2056', 'dd-mm-yyyy'), '2', '26', '270', '09', '2056', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20725, to_date('27-09-2056', 'dd-mm-yyyy'), '3', '27', '271', '09', '2056', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20726, to_date('28-09-2056', 'dd-mm-yyyy'), '4', '28', '272', '09', '2056', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20727, to_date('29-09-2056', 'dd-mm-yyyy'), '5', '29', '273', '09', '2056', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20728, to_date('30-09-2056', 'dd-mm-yyyy'), '6', '30', '274', '09', '2056', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20729, to_date('01-10-2056', 'dd-mm-yyyy'), '7', '01', '275', '10', '2056', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20730, to_date('02-10-2056', 'dd-mm-yyyy'), '1', '02', '276', '10', '2056', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20731, to_date('03-10-2056', 'dd-mm-yyyy'), '2', '03', '277', '10', '2056', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20732, to_date('04-10-2056', 'dd-mm-yyyy'), '3', '04', '278', '10', '2056', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20733, to_date('05-10-2056', 'dd-mm-yyyy'), '4', '05', '279', '10', '2056', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20734, to_date('06-10-2056', 'dd-mm-yyyy'), '5', '06', '280', '10', '2056', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20735, to_date('07-10-2056', 'dd-mm-yyyy'), '6', '07', '281', '10', '2056', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20736, to_date('08-10-2056', 'dd-mm-yyyy'), '7', '08', '282', '10', '2056', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20737, to_date('09-10-2056', 'dd-mm-yyyy'), '1', '09', '283', '10', '2056', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20738, to_date('10-10-2056', 'dd-mm-yyyy'), '2', '10', '284', '10', '2056', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20739, to_date('11-10-2056', 'dd-mm-yyyy'), '3', '11', '285', '10', '2056', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20740, to_date('12-10-2056', 'dd-mm-yyyy'), '4', '12', '286', '10', '2056', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20741, to_date('13-10-2056', 'dd-mm-yyyy'), '5', '13', '287', '10', '2056', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20742, to_date('14-10-2056', 'dd-mm-yyyy'), '6', '14', '288', '10', '2056', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20743, to_date('15-10-2056', 'dd-mm-yyyy'), '7', '15', '289', '10', '2056', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20744, to_date('16-10-2056', 'dd-mm-yyyy'), '1', '16', '290', '10', '2056', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20745, to_date('17-10-2056', 'dd-mm-yyyy'), '2', '17', '291', '10', '2056', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20746, to_date('18-10-2056', 'dd-mm-yyyy'), '3', '18', '292', '10', '2056', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20747, to_date('19-10-2056', 'dd-mm-yyyy'), '4', '19', '293', '10', '2056', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20748, to_date('20-10-2056', 'dd-mm-yyyy'), '5', '20', '294', '10', '2056', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20749, to_date('21-10-2056', 'dd-mm-yyyy'), '6', '21', '295', '10', '2056', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20750, to_date('22-10-2056', 'dd-mm-yyyy'), '7', '22', '296', '10', '2056', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22235, to_date('15-11-2060', 'dd-mm-yyyy'), '1', '15', '320', '11', '2060', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22236, to_date('16-11-2060', 'dd-mm-yyyy'), '2', '16', '321', '11', '2060', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22237, to_date('17-11-2060', 'dd-mm-yyyy'), '3', '17', '322', '11', '2060', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22238, to_date('18-11-2060', 'dd-mm-yyyy'), '4', '18', '323', '11', '2060', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22239, to_date('19-11-2060', 'dd-mm-yyyy'), '5', '19', '324', '11', '2060', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22240, to_date('20-11-2060', 'dd-mm-yyyy'), '6', '20', '325', '11', '2060', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22241, to_date('21-11-2060', 'dd-mm-yyyy'), '7', '21', '326', '11', '2060', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22242, to_date('22-11-2060', 'dd-mm-yyyy'), '1', '22', '327', '11', '2060', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22243, to_date('23-11-2060', 'dd-mm-yyyy'), '2', '23', '328', '11', '2060', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22244, to_date('24-11-2060', 'dd-mm-yyyy'), '3', '24', '329', '11', '2060', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22245, to_date('25-11-2060', 'dd-mm-yyyy'), '4', '25', '330', '11', '2060', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22246, to_date('26-11-2060', 'dd-mm-yyyy'), '5', '26', '331', '11', '2060', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22247, to_date('27-11-2060', 'dd-mm-yyyy'), '6', '27', '332', '11', '2060', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22248, to_date('28-11-2060', 'dd-mm-yyyy'), '7', '28', '333', '11', '2060', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22249, to_date('29-11-2060', 'dd-mm-yyyy'), '1', '29', '334', '11', '2060', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22250, to_date('30-11-2060', 'dd-mm-yyyy'), '2', '30', '335', '11', '2060', '49', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22251, to_date('01-12-2060', 'dd-mm-yyyy'), '3', '01', '336', '12', '2060', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22252, to_date('02-12-2060', 'dd-mm-yyyy'), '4', '02', '337', '12', '2060', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22253, to_date('03-12-2060', 'dd-mm-yyyy'), '5', '03', '338', '12', '2060', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22254, to_date('04-12-2060', 'dd-mm-yyyy'), '6', '04', '339', '12', '2060', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22255, to_date('05-12-2060', 'dd-mm-yyyy'), '7', '05', '340', '12', '2060', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22256, to_date('06-12-2060', 'dd-mm-yyyy'), '1', '06', '341', '12', '2060', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22257, to_date('07-12-2060', 'dd-mm-yyyy'), '2', '07', '342', '12', '2060', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22258, to_date('08-12-2060', 'dd-mm-yyyy'), '3', '08', '343', '12', '2060', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22259, to_date('09-12-2060', 'dd-mm-yyyy'), '4', '09', '344', '12', '2060', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22260, to_date('10-12-2060', 'dd-mm-yyyy'), '5', '10', '345', '12', '2060', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22261, to_date('11-12-2060', 'dd-mm-yyyy'), '6', '11', '346', '12', '2060', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22262, to_date('12-12-2060', 'dd-mm-yyyy'), '7', '12', '347', '12', '2060', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22263, to_date('13-12-2060', 'dd-mm-yyyy'), '1', '13', '348', '12', '2060', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22264, to_date('14-12-2060', 'dd-mm-yyyy'), '2', '14', '349', '12', '2060', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22265, to_date('15-12-2060', 'dd-mm-yyyy'), '3', '15', '350', '12', '2060', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22266, to_date('16-12-2060', 'dd-mm-yyyy'), '4', '16', '351', '12', '2060', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22267, to_date('17-12-2060', 'dd-mm-yyyy'), '5', '17', '352', '12', '2060', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22268, to_date('18-12-2060', 'dd-mm-yyyy'), '6', '18', '353', '12', '2060', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22269, to_date('19-12-2060', 'dd-mm-yyyy'), '7', '19', '354', '12', '2060', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22270, to_date('20-12-2060', 'dd-mm-yyyy'), '1', '20', '355', '12', '2060', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22271, to_date('21-12-2060', 'dd-mm-yyyy'), '2', '21', '356', '12', '2060', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22272, to_date('22-12-2060', 'dd-mm-yyyy'), '3', '22', '357', '12', '2060', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22273, to_date('23-12-2060', 'dd-mm-yyyy'), '4', '23', '358', '12', '2060', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22274, to_date('24-12-2060', 'dd-mm-yyyy'), '5', '24', '359', '12', '2060', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22275, to_date('25-12-2060', 'dd-mm-yyyy'), '6', '25', '360', '12', '2060', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22276, to_date('26-12-2060', 'dd-mm-yyyy'), '7', '26', '361', '12', '2060', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22277, to_date('27-12-2060', 'dd-mm-yyyy'), '1', '27', '362', '12', '2060', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22278, to_date('28-12-2060', 'dd-mm-yyyy'), '2', '28', '363', '12', '2060', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22279, to_date('29-12-2060', 'dd-mm-yyyy'), '3', '29', '364', '12', '2060', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22280, to_date('30-12-2060', 'dd-mm-yyyy'), '4', '30', '365', '12', '2060', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22281, to_date('31-12-2060', 'dd-mm-yyyy'), '5', '31', '366', '12', '2060', '53', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22282, to_date('01-01-2061', 'dd-mm-yyyy'), '6', '01', '001', '01', '2061', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22283, to_date('02-01-2061', 'dd-mm-yyyy'), '7', '02', '002', '01', '2061', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22284, to_date('03-01-2061', 'dd-mm-yyyy'), '1', '03', '003', '01', '2061', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22285, to_date('04-01-2061', 'dd-mm-yyyy'), '2', '04', '004', '01', '2061', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22286, to_date('05-01-2061', 'dd-mm-yyyy'), '3', '05', '005', '01', '2061', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22287, to_date('06-01-2061', 'dd-mm-yyyy'), '4', '06', '006', '01', '2061', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22288, to_date('07-01-2061', 'dd-mm-yyyy'), '5', '07', '007', '01', '2061', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22289, to_date('08-01-2061', 'dd-mm-yyyy'), '6', '08', '008', '01', '2061', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22290, to_date('09-01-2061', 'dd-mm-yyyy'), '7', '09', '009', '01', '2061', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22291, to_date('10-01-2061', 'dd-mm-yyyy'), '1', '10', '010', '01', '2061', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22292, to_date('11-01-2061', 'dd-mm-yyyy'), '2', '11', '011', '01', '2061', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22293, to_date('12-01-2061', 'dd-mm-yyyy'), '3', '12', '012', '01', '2061', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22294, to_date('13-01-2061', 'dd-mm-yyyy'), '4', '13', '013', '01', '2061', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22295, to_date('14-01-2061', 'dd-mm-yyyy'), '5', '14', '014', '01', '2061', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22296, to_date('15-01-2061', 'dd-mm-yyyy'), '6', '15', '015', '01', '2061', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22297, to_date('16-01-2061', 'dd-mm-yyyy'), '7', '16', '016', '01', '2061', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22298, to_date('17-01-2061', 'dd-mm-yyyy'), '1', '17', '017', '01', '2061', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22299, to_date('18-01-2061', 'dd-mm-yyyy'), '2', '18', '018', '01', '2061', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22300, to_date('19-01-2061', 'dd-mm-yyyy'), '3', '19', '019', '01', '2061', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22301, to_date('20-01-2061', 'dd-mm-yyyy'), '4', '20', '020', '01', '2061', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22302, to_date('21-01-2061', 'dd-mm-yyyy'), '5', '21', '021', '01', '2061', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22303, to_date('22-01-2061', 'dd-mm-yyyy'), '6', '22', '022', '01', '2061', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22304, to_date('23-01-2061', 'dd-mm-yyyy'), '7', '23', '023', '01', '2061', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22305, to_date('24-01-2061', 'dd-mm-yyyy'), '1', '24', '024', '01', '2061', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22306, to_date('25-01-2061', 'dd-mm-yyyy'), '2', '25', '025', '01', '2061', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22307, to_date('26-01-2061', 'dd-mm-yyyy'), '3', '26', '026', '01', '2061', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22308, to_date('27-01-2061', 'dd-mm-yyyy'), '4', '27', '027', '01', '2061', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22309, to_date('28-01-2061', 'dd-mm-yyyy'), '5', '28', '028', '01', '2061', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22310, to_date('29-01-2061', 'dd-mm-yyyy'), '6', '29', '029', '01', '2061', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22311, to_date('30-01-2061', 'dd-mm-yyyy'), '7', '30', '030', '01', '2061', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22312, to_date('31-01-2061', 'dd-mm-yyyy'), '1', '31', '031', '01', '2061', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22313, to_date('01-02-2061', 'dd-mm-yyyy'), '2', '01', '032', '02', '2061', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22314, to_date('02-02-2061', 'dd-mm-yyyy'), '3', '02', '033', '02', '2061', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22315, to_date('03-02-2061', 'dd-mm-yyyy'), '4', '03', '034', '02', '2061', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22316, to_date('04-02-2061', 'dd-mm-yyyy'), '5', '04', '035', '02', '2061', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22317, to_date('05-02-2061', 'dd-mm-yyyy'), '6', '05', '036', '02', '2061', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22318, to_date('06-02-2061', 'dd-mm-yyyy'), '7', '06', '037', '02', '2061', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22319, to_date('07-02-2061', 'dd-mm-yyyy'), '1', '07', '038', '02', '2061', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22320, to_date('08-02-2061', 'dd-mm-yyyy'), '2', '08', '039', '02', '2061', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22321, to_date('09-02-2061', 'dd-mm-yyyy'), '3', '09', '040', '02', '2061', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22322, to_date('10-02-2061', 'dd-mm-yyyy'), '4', '10', '041', '02', '2061', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22323, to_date('11-02-2061', 'dd-mm-yyyy'), '5', '11', '042', '02', '2061', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22324, to_date('12-02-2061', 'dd-mm-yyyy'), '6', '12', '043', '02', '2061', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22325, to_date('13-02-2061', 'dd-mm-yyyy'), '7', '13', '044', '02', '2061', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22326, to_date('14-02-2061', 'dd-mm-yyyy'), '1', '14', '045', '02', '2061', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22327, to_date('15-02-2061', 'dd-mm-yyyy'), '2', '15', '046', '02', '2061', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22328, to_date('16-02-2061', 'dd-mm-yyyy'), '3', '16', '047', '02', '2061', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22329, to_date('17-02-2061', 'dd-mm-yyyy'), '4', '17', '048', '02', '2061', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22330, to_date('18-02-2061', 'dd-mm-yyyy'), '5', '18', '049', '02', '2061', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22331, to_date('19-02-2061', 'dd-mm-yyyy'), '6', '19', '050', '02', '2061', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22332, to_date('20-02-2061', 'dd-mm-yyyy'), '7', '20', '051', '02', '2061', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22333, to_date('21-02-2061', 'dd-mm-yyyy'), '1', '21', '052', '02', '2061', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22334, to_date('22-02-2061', 'dd-mm-yyyy'), '2', '22', '053', '02', '2061', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22335, to_date('23-02-2061', 'dd-mm-yyyy'), '3', '23', '054', '02', '2061', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22336, to_date('24-02-2061', 'dd-mm-yyyy'), '4', '24', '055', '02', '2061', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22337, to_date('25-02-2061', 'dd-mm-yyyy'), '5', '25', '056', '02', '2061', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22338, to_date('26-02-2061', 'dd-mm-yyyy'), '6', '26', '057', '02', '2061', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22339, to_date('27-02-2061', 'dd-mm-yyyy'), '7', '27', '058', '02', '2061', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22340, to_date('28-02-2061', 'dd-mm-yyyy'), '1', '28', '059', '02', '2061', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23825, to_date('24-03-2065', 'dd-mm-yyyy'), '2', '24', '083', '03', '2065', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23826, to_date('25-03-2065', 'dd-mm-yyyy'), '3', '25', '084', '03', '2065', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23827, to_date('26-03-2065', 'dd-mm-yyyy'), '4', '26', '085', '03', '2065', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23828, to_date('27-03-2065', 'dd-mm-yyyy'), '5', '27', '086', '03', '2065', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23829, to_date('28-03-2065', 'dd-mm-yyyy'), '6', '28', '087', '03', '2065', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23830, to_date('29-03-2065', 'dd-mm-yyyy'), '7', '29', '088', '03', '2065', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23831, to_date('30-03-2065', 'dd-mm-yyyy'), '1', '30', '089', '03', '2065', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23832, to_date('31-03-2065', 'dd-mm-yyyy'), '2', '31', '090', '03', '2065', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23833, to_date('01-04-2065', 'dd-mm-yyyy'), '3', '01', '091', '04', '2065', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23834, to_date('02-04-2065', 'dd-mm-yyyy'), '4', '02', '092', '04', '2065', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23835, to_date('03-04-2065', 'dd-mm-yyyy'), '5', '03', '093', '04', '2065', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23836, to_date('04-04-2065', 'dd-mm-yyyy'), '6', '04', '094', '04', '2065', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23837, to_date('05-04-2065', 'dd-mm-yyyy'), '7', '05', '095', '04', '2065', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23838, to_date('06-04-2065', 'dd-mm-yyyy'), '1', '06', '096', '04', '2065', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23839, to_date('07-04-2065', 'dd-mm-yyyy'), '2', '07', '097', '04', '2065', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23840, to_date('08-04-2065', 'dd-mm-yyyy'), '3', '08', '098', '04', '2065', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23841, to_date('09-04-2065', 'dd-mm-yyyy'), '4', '09', '099', '04', '2065', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23842, to_date('10-04-2065', 'dd-mm-yyyy'), '5', '10', '100', '04', '2065', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23843, to_date('11-04-2065', 'dd-mm-yyyy'), '6', '11', '101', '04', '2065', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23844, to_date('12-04-2065', 'dd-mm-yyyy'), '7', '12', '102', '04', '2065', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23845, to_date('13-04-2065', 'dd-mm-yyyy'), '1', '13', '103', '04', '2065', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23846, to_date('14-04-2065', 'dd-mm-yyyy'), '2', '14', '104', '04', '2065', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23847, to_date('15-04-2065', 'dd-mm-yyyy'), '3', '15', '105', '04', '2065', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23848, to_date('16-04-2065', 'dd-mm-yyyy'), '4', '16', '106', '04', '2065', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23849, to_date('17-04-2065', 'dd-mm-yyyy'), '5', '17', '107', '04', '2065', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23850, to_date('18-04-2065', 'dd-mm-yyyy'), '6', '18', '108', '04', '2065', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23851, to_date('19-04-2065', 'dd-mm-yyyy'), '7', '19', '109', '04', '2065', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23852, to_date('20-04-2065', 'dd-mm-yyyy'), '1', '20', '110', '04', '2065', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23853, to_date('21-04-2065', 'dd-mm-yyyy'), '2', '21', '111', '04', '2065', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23854, to_date('22-04-2065', 'dd-mm-yyyy'), '3', '22', '112', '04', '2065', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23855, to_date('23-04-2065', 'dd-mm-yyyy'), '4', '23', '113', '04', '2065', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23856, to_date('24-04-2065', 'dd-mm-yyyy'), '5', '24', '114', '04', '2065', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23857, to_date('25-04-2065', 'dd-mm-yyyy'), '6', '25', '115', '04', '2065', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23858, to_date('26-04-2065', 'dd-mm-yyyy'), '7', '26', '116', '04', '2065', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23859, to_date('27-04-2065', 'dd-mm-yyyy'), '1', '27', '117', '04', '2065', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23860, to_date('28-04-2065', 'dd-mm-yyyy'), '2', '28', '118', '04', '2065', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23861, to_date('29-04-2065', 'dd-mm-yyyy'), '3', '29', '119', '04', '2065', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23862, to_date('30-04-2065', 'dd-mm-yyyy'), '4', '30', '120', '04', '2065', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23863, to_date('01-05-2065', 'dd-mm-yyyy'), '5', '01', '121', '05', '2065', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23864, to_date('02-05-2065', 'dd-mm-yyyy'), '6', '02', '122', '05', '2065', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23865, to_date('03-05-2065', 'dd-mm-yyyy'), '7', '03', '123', '05', '2065', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23866, to_date('04-05-2065', 'dd-mm-yyyy'), '1', '04', '124', '05', '2065', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23867, to_date('05-05-2065', 'dd-mm-yyyy'), '2', '05', '125', '05', '2065', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23868, to_date('06-05-2065', 'dd-mm-yyyy'), '3', '06', '126', '05', '2065', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23869, to_date('07-05-2065', 'dd-mm-yyyy'), '4', '07', '127', '05', '2065', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23870, to_date('08-05-2065', 'dd-mm-yyyy'), '5', '08', '128', '05', '2065', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23871, to_date('09-05-2065', 'dd-mm-yyyy'), '6', '09', '129', '05', '2065', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23872, to_date('10-05-2065', 'dd-mm-yyyy'), '7', '10', '130', '05', '2065', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23873, to_date('11-05-2065', 'dd-mm-yyyy'), '1', '11', '131', '05', '2065', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23874, to_date('12-05-2065', 'dd-mm-yyyy'), '2', '12', '132', '05', '2065', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23875, to_date('13-05-2065', 'dd-mm-yyyy'), '3', '13', '133', '05', '2065', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23876, to_date('14-05-2065', 'dd-mm-yyyy'), '4', '14', '134', '05', '2065', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23877, to_date('15-05-2065', 'dd-mm-yyyy'), '5', '15', '135', '05', '2065', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23878, to_date('16-05-2065', 'dd-mm-yyyy'), '6', '16', '136', '05', '2065', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23879, to_date('17-05-2065', 'dd-mm-yyyy'), '7', '17', '137', '05', '2065', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23880, to_date('18-05-2065', 'dd-mm-yyyy'), '1', '18', '138', '05', '2065', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23881, to_date('19-05-2065', 'dd-mm-yyyy'), '2', '19', '139', '05', '2065', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23882, to_date('20-05-2065', 'dd-mm-yyyy'), '3', '20', '140', '05', '2065', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23883, to_date('21-05-2065', 'dd-mm-yyyy'), '4', '21', '141', '05', '2065', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23884, to_date('22-05-2065', 'dd-mm-yyyy'), '5', '22', '142', '05', '2065', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23885, to_date('23-05-2065', 'dd-mm-yyyy'), '6', '23', '143', '05', '2065', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23886, to_date('24-05-2065', 'dd-mm-yyyy'), '7', '24', '144', '05', '2065', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23887, to_date('25-05-2065', 'dd-mm-yyyy'), '1', '25', '145', '05', '2065', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23888, to_date('26-05-2065', 'dd-mm-yyyy'), '2', '26', '146', '05', '2065', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23889, to_date('27-05-2065', 'dd-mm-yyyy'), '3', '27', '147', '05', '2065', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23890, to_date('28-05-2065', 'dd-mm-yyyy'), '4', '28', '148', '05', '2065', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23891, to_date('29-05-2065', 'dd-mm-yyyy'), '5', '29', '149', '05', '2065', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23892, to_date('30-05-2065', 'dd-mm-yyyy'), '6', '30', '150', '05', '2065', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23893, to_date('31-05-2065', 'dd-mm-yyyy'), '7', '31', '151', '05', '2065', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23894, to_date('01-06-2065', 'dd-mm-yyyy'), '1', '01', '152', '06', '2065', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23895, to_date('02-06-2065', 'dd-mm-yyyy'), '2', '02', '153', '06', '2065', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23896, to_date('03-06-2065', 'dd-mm-yyyy'), '3', '03', '154', '06', '2065', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23897, to_date('04-06-2065', 'dd-mm-yyyy'), '4', '04', '155', '06', '2065', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23898, to_date('05-06-2065', 'dd-mm-yyyy'), '5', '05', '156', '06', '2065', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23899, to_date('06-06-2065', 'dd-mm-yyyy'), '6', '06', '157', '06', '2065', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23900, to_date('07-06-2065', 'dd-mm-yyyy'), '7', '07', '158', '06', '2065', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23901, to_date('08-06-2065', 'dd-mm-yyyy'), '1', '08', '159', '06', '2065', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23902, to_date('09-06-2065', 'dd-mm-yyyy'), '2', '09', '160', '06', '2065', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23903, to_date('10-06-2065', 'dd-mm-yyyy'), '3', '10', '161', '06', '2065', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23904, to_date('11-06-2065', 'dd-mm-yyyy'), '4', '11', '162', '06', '2065', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23905, to_date('12-06-2065', 'dd-mm-yyyy'), '5', '12', '163', '06', '2065', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23906, to_date('13-06-2065', 'dd-mm-yyyy'), '6', '13', '164', '06', '2065', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23907, to_date('14-06-2065', 'dd-mm-yyyy'), '7', '14', '165', '06', '2065', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23908, to_date('15-06-2065', 'dd-mm-yyyy'), '1', '15', '166', '06', '2065', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23909, to_date('16-06-2065', 'dd-mm-yyyy'), '2', '16', '167', '06', '2065', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23910, to_date('17-06-2065', 'dd-mm-yyyy'), '3', '17', '168', '06', '2065', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23911, to_date('18-06-2065', 'dd-mm-yyyy'), '4', '18', '169', '06', '2065', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23912, to_date('19-06-2065', 'dd-mm-yyyy'), '5', '19', '170', '06', '2065', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23913, to_date('20-06-2065', 'dd-mm-yyyy'), '6', '20', '171', '06', '2065', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23914, to_date('21-06-2065', 'dd-mm-yyyy'), '7', '21', '172', '06', '2065', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23915, to_date('22-06-2065', 'dd-mm-yyyy'), '1', '22', '173', '06', '2065', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23916, to_date('23-06-2065', 'dd-mm-yyyy'), '2', '23', '174', '06', '2065', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23917, to_date('24-06-2065', 'dd-mm-yyyy'), '3', '24', '175', '06', '2065', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23918, to_date('25-06-2065', 'dd-mm-yyyy'), '4', '25', '176', '06', '2065', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23919, to_date('26-06-2065', 'dd-mm-yyyy'), '5', '26', '177', '06', '2065', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23920, to_date('27-06-2065', 'dd-mm-yyyy'), '6', '27', '178', '06', '2065', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23921, to_date('28-06-2065', 'dd-mm-yyyy'), '7', '28', '179', '06', '2065', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23922, to_date('29-06-2065', 'dd-mm-yyyy'), '1', '29', '180', '06', '2065', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23923, to_date('30-06-2065', 'dd-mm-yyyy'), '2', '30', '181', '06', '2065', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23924, to_date('01-07-2065', 'dd-mm-yyyy'), '3', '01', '182', '07', '2065', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23925, to_date('02-07-2065', 'dd-mm-yyyy'), '4', '02', '183', '07', '2065', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23926, to_date('03-07-2065', 'dd-mm-yyyy'), '5', '03', '184', '07', '2065', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23927, to_date('04-07-2065', 'dd-mm-yyyy'), '6', '04', '185', '07', '2065', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23928, to_date('05-07-2065', 'dd-mm-yyyy'), '7', '05', '186', '07', '2065', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23929, to_date('06-07-2065', 'dd-mm-yyyy'), '1', '06', '187', '07', '2065', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23930, to_date('07-07-2065', 'dd-mm-yyyy'), '2', '07', '188', '07', '2065', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25415, to_date('31-07-2069', 'dd-mm-yyyy'), '3', '31', '212', '07', '2069', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25416, to_date('01-08-2069', 'dd-mm-yyyy'), '4', '01', '213', '08', '2069', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25417, to_date('02-08-2069', 'dd-mm-yyyy'), '5', '02', '214', '08', '2069', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25418, to_date('03-08-2069', 'dd-mm-yyyy'), '6', '03', '215', '08', '2069', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25419, to_date('04-08-2069', 'dd-mm-yyyy'), '7', '04', '216', '08', '2069', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25420, to_date('05-08-2069', 'dd-mm-yyyy'), '1', '05', '217', '08', '2069', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25421, to_date('06-08-2069', 'dd-mm-yyyy'), '2', '06', '218', '08', '2069', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25422, to_date('07-08-2069', 'dd-mm-yyyy'), '3', '07', '219', '08', '2069', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25423, to_date('08-08-2069', 'dd-mm-yyyy'), '4', '08', '220', '08', '2069', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25424, to_date('09-08-2069', 'dd-mm-yyyy'), '5', '09', '221', '08', '2069', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25425, to_date('10-08-2069', 'dd-mm-yyyy'), '6', '10', '222', '08', '2069', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25426, to_date('11-08-2069', 'dd-mm-yyyy'), '7', '11', '223', '08', '2069', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25427, to_date('12-08-2069', 'dd-mm-yyyy'), '1', '12', '224', '08', '2069', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25428, to_date('13-08-2069', 'dd-mm-yyyy'), '2', '13', '225', '08', '2069', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25429, to_date('14-08-2069', 'dd-mm-yyyy'), '3', '14', '226', '08', '2069', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25430, to_date('15-08-2069', 'dd-mm-yyyy'), '4', '15', '227', '08', '2069', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25431, to_date('16-08-2069', 'dd-mm-yyyy'), '5', '16', '228', '08', '2069', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25432, to_date('17-08-2069', 'dd-mm-yyyy'), '6', '17', '229', '08', '2069', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25433, to_date('18-08-2069', 'dd-mm-yyyy'), '7', '18', '230', '08', '2069', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25434, to_date('19-08-2069', 'dd-mm-yyyy'), '1', '19', '231', '08', '2069', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25435, to_date('20-08-2069', 'dd-mm-yyyy'), '2', '20', '232', '08', '2069', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25436, to_date('21-08-2069', 'dd-mm-yyyy'), '3', '21', '233', '08', '2069', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25437, to_date('22-08-2069', 'dd-mm-yyyy'), '4', '22', '234', '08', '2069', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25438, to_date('23-08-2069', 'dd-mm-yyyy'), '5', '23', '235', '08', '2069', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25439, to_date('24-08-2069', 'dd-mm-yyyy'), '6', '24', '236', '08', '2069', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25440, to_date('25-08-2069', 'dd-mm-yyyy'), '7', '25', '237', '08', '2069', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25441, to_date('26-08-2069', 'dd-mm-yyyy'), '1', '26', '238', '08', '2069', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25442, to_date('27-08-2069', 'dd-mm-yyyy'), '2', '27', '239', '08', '2069', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25443, to_date('28-08-2069', 'dd-mm-yyyy'), '3', '28', '240', '08', '2069', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25444, to_date('29-08-2069', 'dd-mm-yyyy'), '4', '29', '241', '08', '2069', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25445, to_date('30-08-2069', 'dd-mm-yyyy'), '5', '30', '242', '08', '2069', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25446, to_date('31-08-2069', 'dd-mm-yyyy'), '6', '31', '243', '08', '2069', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25447, to_date('01-09-2069', 'dd-mm-yyyy'), '7', '01', '244', '09', '2069', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25448, to_date('02-09-2069', 'dd-mm-yyyy'), '1', '02', '245', '09', '2069', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25449, to_date('03-09-2069', 'dd-mm-yyyy'), '2', '03', '246', '09', '2069', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25450, to_date('04-09-2069', 'dd-mm-yyyy'), '3', '04', '247', '09', '2069', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25451, to_date('05-09-2069', 'dd-mm-yyyy'), '4', '05', '248', '09', '2069', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25452, to_date('06-09-2069', 'dd-mm-yyyy'), '5', '06', '249', '09', '2069', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25453, to_date('07-09-2069', 'dd-mm-yyyy'), '6', '07', '250', '09', '2069', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25454, to_date('08-09-2069', 'dd-mm-yyyy'), '7', '08', '251', '09', '2069', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25455, to_date('09-09-2069', 'dd-mm-yyyy'), '1', '09', '252', '09', '2069', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25456, to_date('10-09-2069', 'dd-mm-yyyy'), '2', '10', '253', '09', '2069', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25457, to_date('11-09-2069', 'dd-mm-yyyy'), '3', '11', '254', '09', '2069', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25458, to_date('12-09-2069', 'dd-mm-yyyy'), '4', '12', '255', '09', '2069', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25459, to_date('13-09-2069', 'dd-mm-yyyy'), '5', '13', '256', '09', '2069', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25460, to_date('14-09-2069', 'dd-mm-yyyy'), '6', '14', '257', '09', '2069', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25461, to_date('15-09-2069', 'dd-mm-yyyy'), '7', '15', '258', '09', '2069', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25462, to_date('16-09-2069', 'dd-mm-yyyy'), '1', '16', '259', '09', '2069', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25463, to_date('17-09-2069', 'dd-mm-yyyy'), '2', '17', '260', '09', '2069', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25464, to_date('18-09-2069', 'dd-mm-yyyy'), '3', '18', '261', '09', '2069', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25465, to_date('19-09-2069', 'dd-mm-yyyy'), '4', '19', '262', '09', '2069', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25466, to_date('20-09-2069', 'dd-mm-yyyy'), '5', '20', '263', '09', '2069', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25467, to_date('21-09-2069', 'dd-mm-yyyy'), '6', '21', '264', '09', '2069', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25468, to_date('22-09-2069', 'dd-mm-yyyy'), '7', '22', '265', '09', '2069', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25469, to_date('23-09-2069', 'dd-mm-yyyy'), '1', '23', '266', '09', '2069', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25470, to_date('24-09-2069', 'dd-mm-yyyy'), '2', '24', '267', '09', '2069', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25471, to_date('25-09-2069', 'dd-mm-yyyy'), '3', '25', '268', '09', '2069', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25472, to_date('26-09-2069', 'dd-mm-yyyy'), '4', '26', '269', '09', '2069', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25473, to_date('27-09-2069', 'dd-mm-yyyy'), '5', '27', '270', '09', '2069', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25474, to_date('28-09-2069', 'dd-mm-yyyy'), '6', '28', '271', '09', '2069', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25475, to_date('29-09-2069', 'dd-mm-yyyy'), '7', '29', '272', '09', '2069', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25476, to_date('30-09-2069', 'dd-mm-yyyy'), '1', '30', '273', '09', '2069', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25477, to_date('01-10-2069', 'dd-mm-yyyy'), '2', '01', '274', '10', '2069', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25478, to_date('02-10-2069', 'dd-mm-yyyy'), '3', '02', '275', '10', '2069', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25479, to_date('03-10-2069', 'dd-mm-yyyy'), '4', '03', '276', '10', '2069', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25480, to_date('04-10-2069', 'dd-mm-yyyy'), '5', '04', '277', '10', '2069', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25481, to_date('05-10-2069', 'dd-mm-yyyy'), '6', '05', '278', '10', '2069', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25482, to_date('06-10-2069', 'dd-mm-yyyy'), '7', '06', '279', '10', '2069', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25483, to_date('07-10-2069', 'dd-mm-yyyy'), '1', '07', '280', '10', '2069', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25484, to_date('08-10-2069', 'dd-mm-yyyy'), '2', '08', '281', '10', '2069', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25485, to_date('09-10-2069', 'dd-mm-yyyy'), '3', '09', '282', '10', '2069', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25486, to_date('10-10-2069', 'dd-mm-yyyy'), '4', '10', '283', '10', '2069', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25487, to_date('11-10-2069', 'dd-mm-yyyy'), '5', '11', '284', '10', '2069', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25488, to_date('12-10-2069', 'dd-mm-yyyy'), '6', '12', '285', '10', '2069', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25489, to_date('13-10-2069', 'dd-mm-yyyy'), '7', '13', '286', '10', '2069', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25490, to_date('14-10-2069', 'dd-mm-yyyy'), '1', '14', '287', '10', '2069', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25491, to_date('15-10-2069', 'dd-mm-yyyy'), '2', '15', '288', '10', '2069', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25492, to_date('16-10-2069', 'dd-mm-yyyy'), '3', '16', '289', '10', '2069', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25493, to_date('17-10-2069', 'dd-mm-yyyy'), '4', '17', '290', '10', '2069', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25494, to_date('18-10-2069', 'dd-mm-yyyy'), '5', '18', '291', '10', '2069', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25495, to_date('19-10-2069', 'dd-mm-yyyy'), '6', '19', '292', '10', '2069', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25496, to_date('20-10-2069', 'dd-mm-yyyy'), '7', '20', '293', '10', '2069', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25497, to_date('21-10-2069', 'dd-mm-yyyy'), '1', '21', '294', '10', '2069', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25498, to_date('22-10-2069', 'dd-mm-yyyy'), '2', '22', '295', '10', '2069', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25499, to_date('23-10-2069', 'dd-mm-yyyy'), '3', '23', '296', '10', '2069', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25500, to_date('24-10-2069', 'dd-mm-yyyy'), '4', '24', '297', '10', '2069', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25501, to_date('25-10-2069', 'dd-mm-yyyy'), '5', '25', '298', '10', '2069', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25502, to_date('26-10-2069', 'dd-mm-yyyy'), '6', '26', '299', '10', '2069', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25503, to_date('27-10-2069', 'dd-mm-yyyy'), '7', '27', '300', '10', '2069', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25504, to_date('28-10-2069', 'dd-mm-yyyy'), '1', '28', '301', '10', '2069', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25505, to_date('29-10-2069', 'dd-mm-yyyy'), '2', '29', '302', '10', '2069', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25506, to_date('30-10-2069', 'dd-mm-yyyy'), '3', '30', '303', '10', '2069', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25507, to_date('31-10-2069', 'dd-mm-yyyy'), '4', '31', '304', '10', '2069', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25508, to_date('01-11-2069', 'dd-mm-yyyy'), '5', '01', '305', '11', '2069', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25509, to_date('02-11-2069', 'dd-mm-yyyy'), '6', '02', '306', '11', '2069', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25510, to_date('03-11-2069', 'dd-mm-yyyy'), '7', '03', '307', '11', '2069', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25511, to_date('04-11-2069', 'dd-mm-yyyy'), '1', '04', '308', '11', '2069', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25512, to_date('05-11-2069', 'dd-mm-yyyy'), '2', '05', '309', '11', '2069', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25513, to_date('06-11-2069', 'dd-mm-yyyy'), '3', '06', '310', '11', '2069', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25514, to_date('07-11-2069', 'dd-mm-yyyy'), '4', '07', '311', '11', '2069', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25515, to_date('08-11-2069', 'dd-mm-yyyy'), '5', '08', '312', '11', '2069', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25516, to_date('09-11-2069', 'dd-mm-yyyy'), '6', '09', '313', '11', '2069', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25517, to_date('10-11-2069', 'dd-mm-yyyy'), '7', '10', '314', '11', '2069', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25518, to_date('11-11-2069', 'dd-mm-yyyy'), '1', '11', '315', '11', '2069', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25519, to_date('12-11-2069', 'dd-mm-yyyy'), '2', '12', '316', '11', '2069', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25520, to_date('13-11-2069', 'dd-mm-yyyy'), '3', '13', '317', '11', '2069', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20751, to_date('23-10-2056', 'dd-mm-yyyy'), '1', '23', '297', '10', '2056', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20752, to_date('24-10-2056', 'dd-mm-yyyy'), '2', '24', '298', '10', '2056', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20753, to_date('25-10-2056', 'dd-mm-yyyy'), '3', '25', '299', '10', '2056', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20754, to_date('26-10-2056', 'dd-mm-yyyy'), '4', '26', '300', '10', '2056', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20755, to_date('27-10-2056', 'dd-mm-yyyy'), '5', '27', '301', '10', '2056', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20756, to_date('28-10-2056', 'dd-mm-yyyy'), '6', '28', '302', '10', '2056', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20757, to_date('29-10-2056', 'dd-mm-yyyy'), '7', '29', '303', '10', '2056', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20758, to_date('30-10-2056', 'dd-mm-yyyy'), '1', '30', '304', '10', '2056', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20759, to_date('31-10-2056', 'dd-mm-yyyy'), '2', '31', '305', '10', '2056', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20760, to_date('01-11-2056', 'dd-mm-yyyy'), '3', '01', '306', '11', '2056', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20761, to_date('02-11-2056', 'dd-mm-yyyy'), '4', '02', '307', '11', '2056', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20762, to_date('03-11-2056', 'dd-mm-yyyy'), '5', '03', '308', '11', '2056', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20763, to_date('04-11-2056', 'dd-mm-yyyy'), '6', '04', '309', '11', '2056', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20764, to_date('05-11-2056', 'dd-mm-yyyy'), '7', '05', '310', '11', '2056', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20765, to_date('06-11-2056', 'dd-mm-yyyy'), '1', '06', '311', '11', '2056', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20766, to_date('07-11-2056', 'dd-mm-yyyy'), '2', '07', '312', '11', '2056', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20767, to_date('08-11-2056', 'dd-mm-yyyy'), '3', '08', '313', '11', '2056', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20768, to_date('09-11-2056', 'dd-mm-yyyy'), '4', '09', '314', '11', '2056', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20769, to_date('10-11-2056', 'dd-mm-yyyy'), '5', '10', '315', '11', '2056', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20770, to_date('11-11-2056', 'dd-mm-yyyy'), '6', '11', '316', '11', '2056', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20771, to_date('12-11-2056', 'dd-mm-yyyy'), '7', '12', '317', '11', '2056', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20772, to_date('13-11-2056', 'dd-mm-yyyy'), '1', '13', '318', '11', '2056', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20773, to_date('14-11-2056', 'dd-mm-yyyy'), '2', '14', '319', '11', '2056', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20774, to_date('15-11-2056', 'dd-mm-yyyy'), '3', '15', '320', '11', '2056', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20775, to_date('16-11-2056', 'dd-mm-yyyy'), '4', '16', '321', '11', '2056', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20776, to_date('17-11-2056', 'dd-mm-yyyy'), '5', '17', '322', '11', '2056', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20777, to_date('18-11-2056', 'dd-mm-yyyy'), '6', '18', '323', '11', '2056', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20778, to_date('19-11-2056', 'dd-mm-yyyy'), '7', '19', '324', '11', '2056', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20779, to_date('20-11-2056', 'dd-mm-yyyy'), '1', '20', '325', '11', '2056', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20780, to_date('21-11-2056', 'dd-mm-yyyy'), '2', '21', '326', '11', '2056', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20781, to_date('22-11-2056', 'dd-mm-yyyy'), '3', '22', '327', '11', '2056', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20782, to_date('23-11-2056', 'dd-mm-yyyy'), '4', '23', '328', '11', '2056', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20783, to_date('24-11-2056', 'dd-mm-yyyy'), '5', '24', '329', '11', '2056', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20784, to_date('25-11-2056', 'dd-mm-yyyy'), '6', '25', '330', '11', '2056', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20785, to_date('26-11-2056', 'dd-mm-yyyy'), '7', '26', '331', '11', '2056', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20786, to_date('27-11-2056', 'dd-mm-yyyy'), '1', '27', '332', '11', '2056', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20787, to_date('28-11-2056', 'dd-mm-yyyy'), '2', '28', '333', '11', '2056', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20788, to_date('29-11-2056', 'dd-mm-yyyy'), '3', '29', '334', '11', '2056', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20789, to_date('30-11-2056', 'dd-mm-yyyy'), '4', '30', '335', '11', '2056', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20790, to_date('01-12-2056', 'dd-mm-yyyy'), '5', '01', '336', '12', '2056', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20791, to_date('02-12-2056', 'dd-mm-yyyy'), '6', '02', '337', '12', '2056', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20792, to_date('03-12-2056', 'dd-mm-yyyy'), '7', '03', '338', '12', '2056', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20793, to_date('04-12-2056', 'dd-mm-yyyy'), '1', '04', '339', '12', '2056', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20794, to_date('05-12-2056', 'dd-mm-yyyy'), '2', '05', '340', '12', '2056', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20795, to_date('06-12-2056', 'dd-mm-yyyy'), '3', '06', '341', '12', '2056', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20796, to_date('07-12-2056', 'dd-mm-yyyy'), '4', '07', '342', '12', '2056', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20797, to_date('08-12-2056', 'dd-mm-yyyy'), '5', '08', '343', '12', '2056', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20798, to_date('09-12-2056', 'dd-mm-yyyy'), '6', '09', '344', '12', '2056', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20799, to_date('10-12-2056', 'dd-mm-yyyy'), '7', '10', '345', '12', '2056', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20800, to_date('11-12-2056', 'dd-mm-yyyy'), '1', '11', '346', '12', '2056', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20801, to_date('12-12-2056', 'dd-mm-yyyy'), '2', '12', '347', '12', '2056', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20802, to_date('13-12-2056', 'dd-mm-yyyy'), '3', '13', '348', '12', '2056', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20803, to_date('14-12-2056', 'dd-mm-yyyy'), '4', '14', '349', '12', '2056', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20804, to_date('15-12-2056', 'dd-mm-yyyy'), '5', '15', '350', '12', '2056', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20805, to_date('16-12-2056', 'dd-mm-yyyy'), '6', '16', '351', '12', '2056', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20806, to_date('17-12-2056', 'dd-mm-yyyy'), '7', '17', '352', '12', '2056', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20807, to_date('18-12-2056', 'dd-mm-yyyy'), '1', '18', '353', '12', '2056', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20808, to_date('19-12-2056', 'dd-mm-yyyy'), '2', '19', '354', '12', '2056', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20809, to_date('20-12-2056', 'dd-mm-yyyy'), '3', '20', '355', '12', '2056', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20810, to_date('21-12-2056', 'dd-mm-yyyy'), '4', '21', '356', '12', '2056', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20811, to_date('22-12-2056', 'dd-mm-yyyy'), '5', '22', '357', '12', '2056', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20812, to_date('23-12-2056', 'dd-mm-yyyy'), '6', '23', '358', '12', '2056', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20813, to_date('24-12-2056', 'dd-mm-yyyy'), '7', '24', '359', '12', '2056', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20814, to_date('25-12-2056', 'dd-mm-yyyy'), '1', '25', '360', '12', '2056', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20815, to_date('26-12-2056', 'dd-mm-yyyy'), '2', '26', '361', '12', '2056', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20816, to_date('27-12-2056', 'dd-mm-yyyy'), '3', '27', '362', '12', '2056', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20817, to_date('28-12-2056', 'dd-mm-yyyy'), '4', '28', '363', '12', '2056', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20818, to_date('29-12-2056', 'dd-mm-yyyy'), '5', '29', '364', '12', '2056', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20819, to_date('30-12-2056', 'dd-mm-yyyy'), '6', '30', '365', '12', '2056', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20820, to_date('31-12-2056', 'dd-mm-yyyy'), '7', '31', '366', '12', '2056', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20821, to_date('01-01-2057', 'dd-mm-yyyy'), '1', '01', '001', '01', '2057', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20822, to_date('02-01-2057', 'dd-mm-yyyy'), '2', '02', '002', '01', '2057', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20823, to_date('03-01-2057', 'dd-mm-yyyy'), '3', '03', '003', '01', '2057', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20824, to_date('04-01-2057', 'dd-mm-yyyy'), '4', '04', '004', '01', '2057', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20825, to_date('05-01-2057', 'dd-mm-yyyy'), '5', '05', '005', '01', '2057', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20826, to_date('06-01-2057', 'dd-mm-yyyy'), '6', '06', '006', '01', '2057', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20827, to_date('07-01-2057', 'dd-mm-yyyy'), '7', '07', '007', '01', '2057', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20828, to_date('08-01-2057', 'dd-mm-yyyy'), '1', '08', '008', '01', '2057', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20829, to_date('09-01-2057', 'dd-mm-yyyy'), '2', '09', '009', '01', '2057', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20830, to_date('10-01-2057', 'dd-mm-yyyy'), '3', '10', '010', '01', '2057', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20831, to_date('11-01-2057', 'dd-mm-yyyy'), '4', '11', '011', '01', '2057', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20832, to_date('12-01-2057', 'dd-mm-yyyy'), '5', '12', '012', '01', '2057', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20833, to_date('13-01-2057', 'dd-mm-yyyy'), '6', '13', '013', '01', '2057', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20834, to_date('14-01-2057', 'dd-mm-yyyy'), '7', '14', '014', '01', '2057', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20835, to_date('15-01-2057', 'dd-mm-yyyy'), '1', '15', '015', '01', '2057', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20836, to_date('16-01-2057', 'dd-mm-yyyy'), '2', '16', '016', '01', '2057', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20837, to_date('17-01-2057', 'dd-mm-yyyy'), '3', '17', '017', '01', '2057', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20838, to_date('18-01-2057', 'dd-mm-yyyy'), '4', '18', '018', '01', '2057', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20839, to_date('19-01-2057', 'dd-mm-yyyy'), '5', '19', '019', '01', '2057', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20840, to_date('20-01-2057', 'dd-mm-yyyy'), '6', '20', '020', '01', '2057', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20841, to_date('21-01-2057', 'dd-mm-yyyy'), '7', '21', '021', '01', '2057', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20842, to_date('22-01-2057', 'dd-mm-yyyy'), '1', '22', '022', '01', '2057', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20843, to_date('23-01-2057', 'dd-mm-yyyy'), '2', '23', '023', '01', '2057', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20844, to_date('24-01-2057', 'dd-mm-yyyy'), '3', '24', '024', '01', '2057', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20845, to_date('25-01-2057', 'dd-mm-yyyy'), '4', '25', '025', '01', '2057', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20846, to_date('26-01-2057', 'dd-mm-yyyy'), '5', '26', '026', '01', '2057', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20847, to_date('27-01-2057', 'dd-mm-yyyy'), '6', '27', '027', '01', '2057', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20848, to_date('28-01-2057', 'dd-mm-yyyy'), '7', '28', '028', '01', '2057', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20849, to_date('29-01-2057', 'dd-mm-yyyy'), '1', '29', '029', '01', '2057', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20850, to_date('30-01-2057', 'dd-mm-yyyy'), '2', '30', '030', '01', '2057', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20851, to_date('31-01-2057', 'dd-mm-yyyy'), '3', '31', '031', '01', '2057', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20852, to_date('01-02-2057', 'dd-mm-yyyy'), '4', '01', '032', '02', '2057', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20853, to_date('02-02-2057', 'dd-mm-yyyy'), '5', '02', '033', '02', '2057', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20854, to_date('03-02-2057', 'dd-mm-yyyy'), '6', '03', '034', '02', '2057', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20855, to_date('04-02-2057', 'dd-mm-yyyy'), '7', '04', '035', '02', '2057', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20856, to_date('05-02-2057', 'dd-mm-yyyy'), '1', '05', '036', '02', '2057', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22341, to_date('01-03-2061', 'dd-mm-yyyy'), '2', '01', '060', '03', '2061', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22342, to_date('02-03-2061', 'dd-mm-yyyy'), '3', '02', '061', '03', '2061', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22343, to_date('03-03-2061', 'dd-mm-yyyy'), '4', '03', '062', '03', '2061', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22344, to_date('04-03-2061', 'dd-mm-yyyy'), '5', '04', '063', '03', '2061', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22345, to_date('05-03-2061', 'dd-mm-yyyy'), '6', '05', '064', '03', '2061', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22346, to_date('06-03-2061', 'dd-mm-yyyy'), '7', '06', '065', '03', '2061', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22347, to_date('07-03-2061', 'dd-mm-yyyy'), '1', '07', '066', '03', '2061', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22348, to_date('08-03-2061', 'dd-mm-yyyy'), '2', '08', '067', '03', '2061', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22349, to_date('09-03-2061', 'dd-mm-yyyy'), '3', '09', '068', '03', '2061', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22350, to_date('10-03-2061', 'dd-mm-yyyy'), '4', '10', '069', '03', '2061', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22351, to_date('11-03-2061', 'dd-mm-yyyy'), '5', '11', '070', '03', '2061', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22352, to_date('12-03-2061', 'dd-mm-yyyy'), '6', '12', '071', '03', '2061', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22353, to_date('13-03-2061', 'dd-mm-yyyy'), '7', '13', '072', '03', '2061', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22354, to_date('14-03-2061', 'dd-mm-yyyy'), '1', '14', '073', '03', '2061', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22355, to_date('15-03-2061', 'dd-mm-yyyy'), '2', '15', '074', '03', '2061', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22356, to_date('16-03-2061', 'dd-mm-yyyy'), '3', '16', '075', '03', '2061', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22357, to_date('17-03-2061', 'dd-mm-yyyy'), '4', '17', '076', '03', '2061', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22358, to_date('18-03-2061', 'dd-mm-yyyy'), '5', '18', '077', '03', '2061', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22359, to_date('19-03-2061', 'dd-mm-yyyy'), '6', '19', '078', '03', '2061', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22360, to_date('20-03-2061', 'dd-mm-yyyy'), '7', '20', '079', '03', '2061', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22361, to_date('21-03-2061', 'dd-mm-yyyy'), '1', '21', '080', '03', '2061', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22362, to_date('22-03-2061', 'dd-mm-yyyy'), '2', '22', '081', '03', '2061', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22363, to_date('23-03-2061', 'dd-mm-yyyy'), '3', '23', '082', '03', '2061', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22364, to_date('24-03-2061', 'dd-mm-yyyy'), '4', '24', '083', '03', '2061', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22365, to_date('25-03-2061', 'dd-mm-yyyy'), '5', '25', '084', '03', '2061', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22366, to_date('26-03-2061', 'dd-mm-yyyy'), '6', '26', '085', '03', '2061', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22367, to_date('27-03-2061', 'dd-mm-yyyy'), '7', '27', '086', '03', '2061', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22368, to_date('28-03-2061', 'dd-mm-yyyy'), '1', '28', '087', '03', '2061', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22369, to_date('29-03-2061', 'dd-mm-yyyy'), '2', '29', '088', '03', '2061', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22370, to_date('30-03-2061', 'dd-mm-yyyy'), '3', '30', '089', '03', '2061', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22371, to_date('31-03-2061', 'dd-mm-yyyy'), '4', '31', '090', '03', '2061', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22372, to_date('01-04-2061', 'dd-mm-yyyy'), '5', '01', '091', '04', '2061', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22373, to_date('02-04-2061', 'dd-mm-yyyy'), '6', '02', '092', '04', '2061', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22374, to_date('03-04-2061', 'dd-mm-yyyy'), '7', '03', '093', '04', '2061', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22375, to_date('04-04-2061', 'dd-mm-yyyy'), '1', '04', '094', '04', '2061', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22376, to_date('05-04-2061', 'dd-mm-yyyy'), '2', '05', '095', '04', '2061', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22377, to_date('06-04-2061', 'dd-mm-yyyy'), '3', '06', '096', '04', '2061', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22378, to_date('07-04-2061', 'dd-mm-yyyy'), '4', '07', '097', '04', '2061', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22379, to_date('08-04-2061', 'dd-mm-yyyy'), '5', '08', '098', '04', '2061', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22380, to_date('09-04-2061', 'dd-mm-yyyy'), '6', '09', '099', '04', '2061', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22381, to_date('10-04-2061', 'dd-mm-yyyy'), '7', '10', '100', '04', '2061', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22382, to_date('11-04-2061', 'dd-mm-yyyy'), '1', '11', '101', '04', '2061', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22383, to_date('12-04-2061', 'dd-mm-yyyy'), '2', '12', '102', '04', '2061', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22384, to_date('13-04-2061', 'dd-mm-yyyy'), '3', '13', '103', '04', '2061', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22385, to_date('14-04-2061', 'dd-mm-yyyy'), '4', '14', '104', '04', '2061', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22386, to_date('15-04-2061', 'dd-mm-yyyy'), '5', '15', '105', '04', '2061', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22387, to_date('16-04-2061', 'dd-mm-yyyy'), '6', '16', '106', '04', '2061', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22388, to_date('17-04-2061', 'dd-mm-yyyy'), '7', '17', '107', '04', '2061', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22389, to_date('18-04-2061', 'dd-mm-yyyy'), '1', '18', '108', '04', '2061', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22390, to_date('19-04-2061', 'dd-mm-yyyy'), '2', '19', '109', '04', '2061', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22391, to_date('20-04-2061', 'dd-mm-yyyy'), '3', '20', '110', '04', '2061', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22392, to_date('21-04-2061', 'dd-mm-yyyy'), '4', '21', '111', '04', '2061', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22393, to_date('22-04-2061', 'dd-mm-yyyy'), '5', '22', '112', '04', '2061', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22394, to_date('23-04-2061', 'dd-mm-yyyy'), '6', '23', '113', '04', '2061', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22395, to_date('24-04-2061', 'dd-mm-yyyy'), '7', '24', '114', '04', '2061', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22396, to_date('25-04-2061', 'dd-mm-yyyy'), '1', '25', '115', '04', '2061', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22397, to_date('26-04-2061', 'dd-mm-yyyy'), '2', '26', '116', '04', '2061', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22398, to_date('27-04-2061', 'dd-mm-yyyy'), '3', '27', '117', '04', '2061', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22399, to_date('28-04-2061', 'dd-mm-yyyy'), '4', '28', '118', '04', '2061', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22400, to_date('29-04-2061', 'dd-mm-yyyy'), '5', '29', '119', '04', '2061', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22401, to_date('30-04-2061', 'dd-mm-yyyy'), '6', '30', '120', '04', '2061', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22402, to_date('01-05-2061', 'dd-mm-yyyy'), '7', '01', '121', '05', '2061', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22403, to_date('02-05-2061', 'dd-mm-yyyy'), '1', '02', '122', '05', '2061', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22404, to_date('03-05-2061', 'dd-mm-yyyy'), '2', '03', '123', '05', '2061', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22405, to_date('04-05-2061', 'dd-mm-yyyy'), '3', '04', '124', '05', '2061', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22406, to_date('05-05-2061', 'dd-mm-yyyy'), '4', '05', '125', '05', '2061', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22407, to_date('06-05-2061', 'dd-mm-yyyy'), '5', '06', '126', '05', '2061', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22408, to_date('07-05-2061', 'dd-mm-yyyy'), '6', '07', '127', '05', '2061', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22409, to_date('08-05-2061', 'dd-mm-yyyy'), '7', '08', '128', '05', '2061', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22410, to_date('09-05-2061', 'dd-mm-yyyy'), '1', '09', '129', '05', '2061', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22411, to_date('10-05-2061', 'dd-mm-yyyy'), '2', '10', '130', '05', '2061', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22412, to_date('11-05-2061', 'dd-mm-yyyy'), '3', '11', '131', '05', '2061', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22413, to_date('12-05-2061', 'dd-mm-yyyy'), '4', '12', '132', '05', '2061', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22414, to_date('13-05-2061', 'dd-mm-yyyy'), '5', '13', '133', '05', '2061', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22415, to_date('14-05-2061', 'dd-mm-yyyy'), '6', '14', '134', '05', '2061', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22416, to_date('15-05-2061', 'dd-mm-yyyy'), '7', '15', '135', '05', '2061', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22417, to_date('16-05-2061', 'dd-mm-yyyy'), '1', '16', '136', '05', '2061', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22418, to_date('17-05-2061', 'dd-mm-yyyy'), '2', '17', '137', '05', '2061', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22419, to_date('18-05-2061', 'dd-mm-yyyy'), '3', '18', '138', '05', '2061', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22420, to_date('19-05-2061', 'dd-mm-yyyy'), '4', '19', '139', '05', '2061', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22421, to_date('20-05-2061', 'dd-mm-yyyy'), '5', '20', '140', '05', '2061', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22422, to_date('21-05-2061', 'dd-mm-yyyy'), '6', '21', '141', '05', '2061', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22423, to_date('22-05-2061', 'dd-mm-yyyy'), '7', '22', '142', '05', '2061', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22424, to_date('23-05-2061', 'dd-mm-yyyy'), '1', '23', '143', '05', '2061', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22425, to_date('24-05-2061', 'dd-mm-yyyy'), '2', '24', '144', '05', '2061', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22426, to_date('25-05-2061', 'dd-mm-yyyy'), '3', '25', '145', '05', '2061', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22427, to_date('26-05-2061', 'dd-mm-yyyy'), '4', '26', '146', '05', '2061', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22428, to_date('27-05-2061', 'dd-mm-yyyy'), '5', '27', '147', '05', '2061', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22429, to_date('28-05-2061', 'dd-mm-yyyy'), '6', '28', '148', '05', '2061', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22430, to_date('29-05-2061', 'dd-mm-yyyy'), '7', '29', '149', '05', '2061', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22431, to_date('30-05-2061', 'dd-mm-yyyy'), '1', '30', '150', '05', '2061', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22432, to_date('31-05-2061', 'dd-mm-yyyy'), '2', '31', '151', '05', '2061', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22433, to_date('01-06-2061', 'dd-mm-yyyy'), '3', '01', '152', '06', '2061', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22434, to_date('02-06-2061', 'dd-mm-yyyy'), '4', '02', '153', '06', '2061', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22435, to_date('03-06-2061', 'dd-mm-yyyy'), '5', '03', '154', '06', '2061', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22436, to_date('04-06-2061', 'dd-mm-yyyy'), '6', '04', '155', '06', '2061', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22437, to_date('05-06-2061', 'dd-mm-yyyy'), '7', '05', '156', '06', '2061', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22438, to_date('06-06-2061', 'dd-mm-yyyy'), '1', '06', '157', '06', '2061', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22439, to_date('07-06-2061', 'dd-mm-yyyy'), '2', '07', '158', '06', '2061', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22440, to_date('08-06-2061', 'dd-mm-yyyy'), '3', '08', '159', '06', '2061', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22441, to_date('09-06-2061', 'dd-mm-yyyy'), '4', '09', '160', '06', '2061', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22442, to_date('10-06-2061', 'dd-mm-yyyy'), '5', '10', '161', '06', '2061', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22443, to_date('11-06-2061', 'dd-mm-yyyy'), '6', '11', '162', '06', '2061', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22444, to_date('12-06-2061', 'dd-mm-yyyy'), '7', '12', '163', '06', '2061', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22445, to_date('13-06-2061', 'dd-mm-yyyy'), '1', '13', '164', '06', '2061', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22446, to_date('14-06-2061', 'dd-mm-yyyy'), '2', '14', '165', '06', '2061', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23931, to_date('08-07-2065', 'dd-mm-yyyy'), '3', '08', '189', '07', '2065', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23932, to_date('09-07-2065', 'dd-mm-yyyy'), '4', '09', '190', '07', '2065', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23933, to_date('10-07-2065', 'dd-mm-yyyy'), '5', '10', '191', '07', '2065', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23934, to_date('11-07-2065', 'dd-mm-yyyy'), '6', '11', '192', '07', '2065', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23935, to_date('12-07-2065', 'dd-mm-yyyy'), '7', '12', '193', '07', '2065', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23936, to_date('13-07-2065', 'dd-mm-yyyy'), '1', '13', '194', '07', '2065', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23937, to_date('14-07-2065', 'dd-mm-yyyy'), '2', '14', '195', '07', '2065', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23938, to_date('15-07-2065', 'dd-mm-yyyy'), '3', '15', '196', '07', '2065', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23939, to_date('16-07-2065', 'dd-mm-yyyy'), '4', '16', '197', '07', '2065', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23940, to_date('17-07-2065', 'dd-mm-yyyy'), '5', '17', '198', '07', '2065', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23941, to_date('18-07-2065', 'dd-mm-yyyy'), '6', '18', '199', '07', '2065', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23942, to_date('19-07-2065', 'dd-mm-yyyy'), '7', '19', '200', '07', '2065', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23943, to_date('20-07-2065', 'dd-mm-yyyy'), '1', '20', '201', '07', '2065', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23944, to_date('21-07-2065', 'dd-mm-yyyy'), '2', '21', '202', '07', '2065', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23945, to_date('22-07-2065', 'dd-mm-yyyy'), '3', '22', '203', '07', '2065', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23946, to_date('23-07-2065', 'dd-mm-yyyy'), '4', '23', '204', '07', '2065', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23947, to_date('24-07-2065', 'dd-mm-yyyy'), '5', '24', '205', '07', '2065', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23948, to_date('25-07-2065', 'dd-mm-yyyy'), '6', '25', '206', '07', '2065', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23949, to_date('26-07-2065', 'dd-mm-yyyy'), '7', '26', '207', '07', '2065', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23950, to_date('27-07-2065', 'dd-mm-yyyy'), '1', '27', '208', '07', '2065', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23951, to_date('28-07-2065', 'dd-mm-yyyy'), '2', '28', '209', '07', '2065', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23952, to_date('29-07-2065', 'dd-mm-yyyy'), '3', '29', '210', '07', '2065', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23953, to_date('30-07-2065', 'dd-mm-yyyy'), '4', '30', '211', '07', '2065', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23954, to_date('31-07-2065', 'dd-mm-yyyy'), '5', '31', '212', '07', '2065', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23955, to_date('01-08-2065', 'dd-mm-yyyy'), '6', '01', '213', '08', '2065', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23956, to_date('02-08-2065', 'dd-mm-yyyy'), '7', '02', '214', '08', '2065', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23957, to_date('03-08-2065', 'dd-mm-yyyy'), '1', '03', '215', '08', '2065', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23958, to_date('04-08-2065', 'dd-mm-yyyy'), '2', '04', '216', '08', '2065', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23959, to_date('05-08-2065', 'dd-mm-yyyy'), '3', '05', '217', '08', '2065', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23960, to_date('06-08-2065', 'dd-mm-yyyy'), '4', '06', '218', '08', '2065', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23961, to_date('07-08-2065', 'dd-mm-yyyy'), '5', '07', '219', '08', '2065', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23962, to_date('08-08-2065', 'dd-mm-yyyy'), '6', '08', '220', '08', '2065', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23963, to_date('09-08-2065', 'dd-mm-yyyy'), '7', '09', '221', '08', '2065', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23964, to_date('10-08-2065', 'dd-mm-yyyy'), '1', '10', '222', '08', '2065', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23965, to_date('11-08-2065', 'dd-mm-yyyy'), '2', '11', '223', '08', '2065', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23966, to_date('12-08-2065', 'dd-mm-yyyy'), '3', '12', '224', '08', '2065', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23967, to_date('13-08-2065', 'dd-mm-yyyy'), '4', '13', '225', '08', '2065', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23968, to_date('14-08-2065', 'dd-mm-yyyy'), '5', '14', '226', '08', '2065', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23969, to_date('15-08-2065', 'dd-mm-yyyy'), '6', '15', '227', '08', '2065', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23970, to_date('16-08-2065', 'dd-mm-yyyy'), '7', '16', '228', '08', '2065', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23971, to_date('17-08-2065', 'dd-mm-yyyy'), '1', '17', '229', '08', '2065', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23972, to_date('18-08-2065', 'dd-mm-yyyy'), '2', '18', '230', '08', '2065', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23973, to_date('19-08-2065', 'dd-mm-yyyy'), '3', '19', '231', '08', '2065', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23974, to_date('20-08-2065', 'dd-mm-yyyy'), '4', '20', '232', '08', '2065', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23975, to_date('21-08-2065', 'dd-mm-yyyy'), '5', '21', '233', '08', '2065', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23976, to_date('22-08-2065', 'dd-mm-yyyy'), '6', '22', '234', '08', '2065', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23977, to_date('23-08-2065', 'dd-mm-yyyy'), '7', '23', '235', '08', '2065', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23978, to_date('24-08-2065', 'dd-mm-yyyy'), '1', '24', '236', '08', '2065', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23979, to_date('25-08-2065', 'dd-mm-yyyy'), '2', '25', '237', '08', '2065', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23980, to_date('26-08-2065', 'dd-mm-yyyy'), '3', '26', '238', '08', '2065', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23981, to_date('27-08-2065', 'dd-mm-yyyy'), '4', '27', '239', '08', '2065', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23982, to_date('28-08-2065', 'dd-mm-yyyy'), '5', '28', '240', '08', '2065', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23983, to_date('29-08-2065', 'dd-mm-yyyy'), '6', '29', '241', '08', '2065', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23984, to_date('30-08-2065', 'dd-mm-yyyy'), '7', '30', '242', '08', '2065', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23985, to_date('31-08-2065', 'dd-mm-yyyy'), '1', '31', '243', '08', '2065', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23986, to_date('01-09-2065', 'dd-mm-yyyy'), '2', '01', '244', '09', '2065', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23987, to_date('02-09-2065', 'dd-mm-yyyy'), '3', '02', '245', '09', '2065', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23988, to_date('03-09-2065', 'dd-mm-yyyy'), '4', '03', '246', '09', '2065', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23989, to_date('04-09-2065', 'dd-mm-yyyy'), '5', '04', '247', '09', '2065', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23990, to_date('05-09-2065', 'dd-mm-yyyy'), '6', '05', '248', '09', '2065', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23991, to_date('06-09-2065', 'dd-mm-yyyy'), '7', '06', '249', '09', '2065', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23992, to_date('07-09-2065', 'dd-mm-yyyy'), '1', '07', '250', '09', '2065', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23993, to_date('08-09-2065', 'dd-mm-yyyy'), '2', '08', '251', '09', '2065', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23994, to_date('09-09-2065', 'dd-mm-yyyy'), '3', '09', '252', '09', '2065', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23995, to_date('10-09-2065', 'dd-mm-yyyy'), '4', '10', '253', '09', '2065', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23996, to_date('11-09-2065', 'dd-mm-yyyy'), '5', '11', '254', '09', '2065', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23997, to_date('12-09-2065', 'dd-mm-yyyy'), '6', '12', '255', '09', '2065', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23998, to_date('13-09-2065', 'dd-mm-yyyy'), '7', '13', '256', '09', '2065', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (23999, to_date('14-09-2065', 'dd-mm-yyyy'), '1', '14', '257', '09', '2065', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24000, to_date('15-09-2065', 'dd-mm-yyyy'), '2', '15', '258', '09', '2065', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24001, to_date('16-09-2065', 'dd-mm-yyyy'), '3', '16', '259', '09', '2065', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24002, to_date('17-09-2065', 'dd-mm-yyyy'), '4', '17', '260', '09', '2065', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24003, to_date('18-09-2065', 'dd-mm-yyyy'), '5', '18', '261', '09', '2065', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24004, to_date('19-09-2065', 'dd-mm-yyyy'), '6', '19', '262', '09', '2065', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24005, to_date('20-09-2065', 'dd-mm-yyyy'), '7', '20', '263', '09', '2065', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24006, to_date('21-09-2065', 'dd-mm-yyyy'), '1', '21', '264', '09', '2065', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24007, to_date('22-09-2065', 'dd-mm-yyyy'), '2', '22', '265', '09', '2065', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24008, to_date('23-09-2065', 'dd-mm-yyyy'), '3', '23', '266', '09', '2065', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24009, to_date('24-09-2065', 'dd-mm-yyyy'), '4', '24', '267', '09', '2065', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24010, to_date('25-09-2065', 'dd-mm-yyyy'), '5', '25', '268', '09', '2065', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24011, to_date('26-09-2065', 'dd-mm-yyyy'), '6', '26', '269', '09', '2065', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24012, to_date('27-09-2065', 'dd-mm-yyyy'), '7', '27', '270', '09', '2065', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24013, to_date('28-09-2065', 'dd-mm-yyyy'), '1', '28', '271', '09', '2065', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24014, to_date('29-09-2065', 'dd-mm-yyyy'), '2', '29', '272', '09', '2065', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24015, to_date('30-09-2065', 'dd-mm-yyyy'), '3', '30', '273', '09', '2065', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24016, to_date('01-10-2065', 'dd-mm-yyyy'), '4', '01', '274', '10', '2065', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24017, to_date('02-10-2065', 'dd-mm-yyyy'), '5', '02', '275', '10', '2065', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24018, to_date('03-10-2065', 'dd-mm-yyyy'), '6', '03', '276', '10', '2065', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24019, to_date('04-10-2065', 'dd-mm-yyyy'), '7', '04', '277', '10', '2065', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24020, to_date('05-10-2065', 'dd-mm-yyyy'), '1', '05', '278', '10', '2065', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24021, to_date('06-10-2065', 'dd-mm-yyyy'), '2', '06', '279', '10', '2065', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24022, to_date('07-10-2065', 'dd-mm-yyyy'), '3', '07', '280', '10', '2065', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24023, to_date('08-10-2065', 'dd-mm-yyyy'), '4', '08', '281', '10', '2065', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24024, to_date('09-10-2065', 'dd-mm-yyyy'), '5', '09', '282', '10', '2065', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24025, to_date('10-10-2065', 'dd-mm-yyyy'), '6', '10', '283', '10', '2065', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24026, to_date('11-10-2065', 'dd-mm-yyyy'), '7', '11', '284', '10', '2065', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24027, to_date('12-10-2065', 'dd-mm-yyyy'), '1', '12', '285', '10', '2065', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24028, to_date('13-10-2065', 'dd-mm-yyyy'), '2', '13', '286', '10', '2065', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24029, to_date('14-10-2065', 'dd-mm-yyyy'), '3', '14', '287', '10', '2065', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24030, to_date('15-10-2065', 'dd-mm-yyyy'), '4', '15', '288', '10', '2065', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24031, to_date('16-10-2065', 'dd-mm-yyyy'), '5', '16', '289', '10', '2065', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24032, to_date('17-10-2065', 'dd-mm-yyyy'), '6', '17', '290', '10', '2065', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24033, to_date('18-10-2065', 'dd-mm-yyyy'), '7', '18', '291', '10', '2065', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24034, to_date('19-10-2065', 'dd-mm-yyyy'), '1', '19', '292', '10', '2065', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24035, to_date('20-10-2065', 'dd-mm-yyyy'), '2', '20', '293', '10', '2065', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24036, to_date('21-10-2065', 'dd-mm-yyyy'), '3', '21', '294', '10', '2065', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25521, to_date('14-11-2069', 'dd-mm-yyyy'), '4', '14', '318', '11', '2069', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25522, to_date('15-11-2069', 'dd-mm-yyyy'), '5', '15', '319', '11', '2069', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25523, to_date('16-11-2069', 'dd-mm-yyyy'), '6', '16', '320', '11', '2069', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25524, to_date('17-11-2069', 'dd-mm-yyyy'), '7', '17', '321', '11', '2069', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25525, to_date('18-11-2069', 'dd-mm-yyyy'), '1', '18', '322', '11', '2069', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25526, to_date('19-11-2069', 'dd-mm-yyyy'), '2', '19', '323', '11', '2069', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25527, to_date('20-11-2069', 'dd-mm-yyyy'), '3', '20', '324', '11', '2069', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25528, to_date('21-11-2069', 'dd-mm-yyyy'), '4', '21', '325', '11', '2069', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25529, to_date('22-11-2069', 'dd-mm-yyyy'), '5', '22', '326', '11', '2069', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25530, to_date('23-11-2069', 'dd-mm-yyyy'), '6', '23', '327', '11', '2069', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25531, to_date('24-11-2069', 'dd-mm-yyyy'), '7', '24', '328', '11', '2069', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25532, to_date('25-11-2069', 'dd-mm-yyyy'), '1', '25', '329', '11', '2069', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25533, to_date('26-11-2069', 'dd-mm-yyyy'), '2', '26', '330', '11', '2069', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25534, to_date('27-11-2069', 'dd-mm-yyyy'), '3', '27', '331', '11', '2069', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25535, to_date('28-11-2069', 'dd-mm-yyyy'), '4', '28', '332', '11', '2069', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25536, to_date('29-11-2069', 'dd-mm-yyyy'), '5', '29', '333', '11', '2069', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25537, to_date('30-11-2069', 'dd-mm-yyyy'), '6', '30', '334', '11', '2069', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25538, to_date('01-12-2069', 'dd-mm-yyyy'), '7', '01', '335', '12', '2069', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25539, to_date('02-12-2069', 'dd-mm-yyyy'), '1', '02', '336', '12', '2069', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25540, to_date('03-12-2069', 'dd-mm-yyyy'), '2', '03', '337', '12', '2069', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25541, to_date('04-12-2069', 'dd-mm-yyyy'), '3', '04', '338', '12', '2069', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25542, to_date('05-12-2069', 'dd-mm-yyyy'), '4', '05', '339', '12', '2069', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25543, to_date('06-12-2069', 'dd-mm-yyyy'), '5', '06', '340', '12', '2069', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25544, to_date('07-12-2069', 'dd-mm-yyyy'), '6', '07', '341', '12', '2069', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25545, to_date('08-12-2069', 'dd-mm-yyyy'), '7', '08', '342', '12', '2069', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25546, to_date('09-12-2069', 'dd-mm-yyyy'), '1', '09', '343', '12', '2069', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25547, to_date('10-12-2069', 'dd-mm-yyyy'), '2', '10', '344', '12', '2069', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25548, to_date('11-12-2069', 'dd-mm-yyyy'), '3', '11', '345', '12', '2069', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25549, to_date('12-12-2069', 'dd-mm-yyyy'), '4', '12', '346', '12', '2069', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25550, to_date('13-12-2069', 'dd-mm-yyyy'), '5', '13', '347', '12', '2069', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25551, to_date('14-12-2069', 'dd-mm-yyyy'), '6', '14', '348', '12', '2069', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25552, to_date('15-12-2069', 'dd-mm-yyyy'), '7', '15', '349', '12', '2069', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25553, to_date('16-12-2069', 'dd-mm-yyyy'), '1', '16', '350', '12', '2069', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25554, to_date('17-12-2069', 'dd-mm-yyyy'), '2', '17', '351', '12', '2069', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25555, to_date('18-12-2069', 'dd-mm-yyyy'), '3', '18', '352', '12', '2069', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25556, to_date('19-12-2069', 'dd-mm-yyyy'), '4', '19', '353', '12', '2069', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25557, to_date('20-12-2069', 'dd-mm-yyyy'), '5', '20', '354', '12', '2069', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25558, to_date('21-12-2069', 'dd-mm-yyyy'), '6', '21', '355', '12', '2069', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25559, to_date('22-12-2069', 'dd-mm-yyyy'), '7', '22', '356', '12', '2069', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25560, to_date('23-12-2069', 'dd-mm-yyyy'), '1', '23', '357', '12', '2069', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25561, to_date('24-12-2069', 'dd-mm-yyyy'), '2', '24', '358', '12', '2069', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25562, to_date('25-12-2069', 'dd-mm-yyyy'), '3', '25', '359', '12', '2069', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25563, to_date('26-12-2069', 'dd-mm-yyyy'), '4', '26', '360', '12', '2069', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25564, to_date('27-12-2069', 'dd-mm-yyyy'), '5', '27', '361', '12', '2069', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25565, to_date('28-12-2069', 'dd-mm-yyyy'), '6', '28', '362', '12', '2069', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25566, to_date('29-12-2069', 'dd-mm-yyyy'), '7', '29', '363', '12', '2069', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25567, to_date('30-12-2069', 'dd-mm-yyyy'), '1', '30', '364', '12', '2069', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25568, to_date('31-12-2069', 'dd-mm-yyyy'), '2', '31', '365', '12', '2069', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25569, to_date('01-01-2070', 'dd-mm-yyyy'), '3', '01', '001', '01', '2070', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25570, to_date('02-01-2070', 'dd-mm-yyyy'), '4', '02', '002', '01', '2070', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25571, to_date('03-01-2070', 'dd-mm-yyyy'), '5', '03', '003', '01', '2070', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25572, to_date('04-01-2070', 'dd-mm-yyyy'), '6', '04', '004', '01', '2070', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25573, to_date('05-01-2070', 'dd-mm-yyyy'), '7', '05', '005', '01', '2070', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25574, to_date('06-01-2070', 'dd-mm-yyyy'), '1', '06', '006', '01', '2070', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25575, to_date('07-01-2070', 'dd-mm-yyyy'), '2', '07', '007', '01', '2070', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25576, to_date('08-01-2070', 'dd-mm-yyyy'), '3', '08', '008', '01', '2070', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25577, to_date('09-01-2070', 'dd-mm-yyyy'), '4', '09', '009', '01', '2070', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25578, to_date('10-01-2070', 'dd-mm-yyyy'), '5', '10', '010', '01', '2070', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25579, to_date('11-01-2070', 'dd-mm-yyyy'), '6', '11', '011', '01', '2070', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25580, to_date('12-01-2070', 'dd-mm-yyyy'), '7', '12', '012', '01', '2070', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25581, to_date('13-01-2070', 'dd-mm-yyyy'), '1', '13', '013', '01', '2070', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25582, to_date('14-01-2070', 'dd-mm-yyyy'), '2', '14', '014', '01', '2070', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25583, to_date('15-01-2070', 'dd-mm-yyyy'), '3', '15', '015', '01', '2070', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25584, to_date('16-01-2070', 'dd-mm-yyyy'), '4', '16', '016', '01', '2070', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25585, to_date('17-01-2070', 'dd-mm-yyyy'), '5', '17', '017', '01', '2070', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25586, to_date('18-01-2070', 'dd-mm-yyyy'), '6', '18', '018', '01', '2070', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25587, to_date('19-01-2070', 'dd-mm-yyyy'), '7', '19', '019', '01', '2070', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25588, to_date('20-01-2070', 'dd-mm-yyyy'), '1', '20', '020', '01', '2070', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25589, to_date('21-01-2070', 'dd-mm-yyyy'), '2', '21', '021', '01', '2070', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25590, to_date('22-01-2070', 'dd-mm-yyyy'), '3', '22', '022', '01', '2070', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25591, to_date('23-01-2070', 'dd-mm-yyyy'), '4', '23', '023', '01', '2070', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25592, to_date('24-01-2070', 'dd-mm-yyyy'), '5', '24', '024', '01', '2070', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25593, to_date('25-01-2070', 'dd-mm-yyyy'), '6', '25', '025', '01', '2070', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25594, to_date('26-01-2070', 'dd-mm-yyyy'), '7', '26', '026', '01', '2070', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25595, to_date('27-01-2070', 'dd-mm-yyyy'), '1', '27', '027', '01', '2070', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25596, to_date('28-01-2070', 'dd-mm-yyyy'), '2', '28', '028', '01', '2070', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25597, to_date('29-01-2070', 'dd-mm-yyyy'), '3', '29', '029', '01', '2070', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25598, to_date('30-01-2070', 'dd-mm-yyyy'), '4', '30', '030', '01', '2070', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25599, to_date('31-01-2070', 'dd-mm-yyyy'), '5', '31', '031', '01', '2070', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25600, to_date('01-02-2070', 'dd-mm-yyyy'), '6', '01', '032', '02', '2070', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25601, to_date('02-02-2070', 'dd-mm-yyyy'), '7', '02', '033', '02', '2070', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25602, to_date('03-02-2070', 'dd-mm-yyyy'), '1', '03', '034', '02', '2070', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25603, to_date('04-02-2070', 'dd-mm-yyyy'), '2', '04', '035', '02', '2070', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25604, to_date('05-02-2070', 'dd-mm-yyyy'), '3', '05', '036', '02', '2070', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25605, to_date('06-02-2070', 'dd-mm-yyyy'), '4', '06', '037', '02', '2070', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25606, to_date('07-02-2070', 'dd-mm-yyyy'), '5', '07', '038', '02', '2070', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25607, to_date('08-02-2070', 'dd-mm-yyyy'), '6', '08', '039', '02', '2070', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25608, to_date('09-02-2070', 'dd-mm-yyyy'), '7', '09', '040', '02', '2070', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25609, to_date('10-02-2070', 'dd-mm-yyyy'), '1', '10', '041', '02', '2070', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25610, to_date('11-02-2070', 'dd-mm-yyyy'), '2', '11', '042', '02', '2070', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25611, to_date('12-02-2070', 'dd-mm-yyyy'), '3', '12', '043', '02', '2070', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25612, to_date('13-02-2070', 'dd-mm-yyyy'), '4', '13', '044', '02', '2070', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25613, to_date('14-02-2070', 'dd-mm-yyyy'), '5', '14', '045', '02', '2070', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25614, to_date('15-02-2070', 'dd-mm-yyyy'), '6', '15', '046', '02', '2070', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25615, to_date('16-02-2070', 'dd-mm-yyyy'), '7', '16', '047', '02', '2070', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25616, to_date('17-02-2070', 'dd-mm-yyyy'), '1', '17', '048', '02', '2070', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25617, to_date('18-02-2070', 'dd-mm-yyyy'), '2', '18', '049', '02', '2070', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25618, to_date('19-02-2070', 'dd-mm-yyyy'), '3', '19', '050', '02', '2070', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25619, to_date('20-02-2070', 'dd-mm-yyyy'), '4', '20', '051', '02', '2070', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25620, to_date('21-02-2070', 'dd-mm-yyyy'), '5', '21', '052', '02', '2070', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25621, to_date('22-02-2070', 'dd-mm-yyyy'), '6', '22', '053', '02', '2070', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25622, to_date('23-02-2070', 'dd-mm-yyyy'), '7', '23', '054', '02', '2070', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25623, to_date('24-02-2070', 'dd-mm-yyyy'), '1', '24', '055', '02', '2070', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25624, to_date('25-02-2070', 'dd-mm-yyyy'), '2', '25', '056', '02', '2070', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25625, to_date('26-02-2070', 'dd-mm-yyyy'), '3', '26', '057', '02', '2070', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (25626, to_date('27-02-2070', 'dd-mm-yyyy'), '4', '27', '058', '02', '2070', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20857, to_date('06-02-2057', 'dd-mm-yyyy'), '2', '06', '037', '02', '2057', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20858, to_date('07-02-2057', 'dd-mm-yyyy'), '3', '07', '038', '02', '2057', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20859, to_date('08-02-2057', 'dd-mm-yyyy'), '4', '08', '039', '02', '2057', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20860, to_date('09-02-2057', 'dd-mm-yyyy'), '5', '09', '040', '02', '2057', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20861, to_date('10-02-2057', 'dd-mm-yyyy'), '6', '10', '041', '02', '2057', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20862, to_date('11-02-2057', 'dd-mm-yyyy'), '7', '11', '042', '02', '2057', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20863, to_date('12-02-2057', 'dd-mm-yyyy'), '1', '12', '043', '02', '2057', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20864, to_date('13-02-2057', 'dd-mm-yyyy'), '2', '13', '044', '02', '2057', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20865, to_date('14-02-2057', 'dd-mm-yyyy'), '3', '14', '045', '02', '2057', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20866, to_date('15-02-2057', 'dd-mm-yyyy'), '4', '15', '046', '02', '2057', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20867, to_date('16-02-2057', 'dd-mm-yyyy'), '5', '16', '047', '02', '2057', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20868, to_date('17-02-2057', 'dd-mm-yyyy'), '6', '17', '048', '02', '2057', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20869, to_date('18-02-2057', 'dd-mm-yyyy'), '7', '18', '049', '02', '2057', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20870, to_date('19-02-2057', 'dd-mm-yyyy'), '1', '19', '050', '02', '2057', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20871, to_date('20-02-2057', 'dd-mm-yyyy'), '2', '20', '051', '02', '2057', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20872, to_date('21-02-2057', 'dd-mm-yyyy'), '3', '21', '052', '02', '2057', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20873, to_date('22-02-2057', 'dd-mm-yyyy'), '4', '22', '053', '02', '2057', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20874, to_date('23-02-2057', 'dd-mm-yyyy'), '5', '23', '054', '02', '2057', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20875, to_date('24-02-2057', 'dd-mm-yyyy'), '6', '24', '055', '02', '2057', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20876, to_date('25-02-2057', 'dd-mm-yyyy'), '7', '25', '056', '02', '2057', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20877, to_date('26-02-2057', 'dd-mm-yyyy'), '1', '26', '057', '02', '2057', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20878, to_date('27-02-2057', 'dd-mm-yyyy'), '2', '27', '058', '02', '2057', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20879, to_date('28-02-2057', 'dd-mm-yyyy'), '3', '28', '059', '02', '2057', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20880, to_date('01-03-2057', 'dd-mm-yyyy'), '4', '01', '060', '03', '2057', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20881, to_date('02-03-2057', 'dd-mm-yyyy'), '5', '02', '061', '03', '2057', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20882, to_date('03-03-2057', 'dd-mm-yyyy'), '6', '03', '062', '03', '2057', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20883, to_date('04-03-2057', 'dd-mm-yyyy'), '7', '04', '063', '03', '2057', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20884, to_date('05-03-2057', 'dd-mm-yyyy'), '1', '05', '064', '03', '2057', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20885, to_date('06-03-2057', 'dd-mm-yyyy'), '2', '06', '065', '03', '2057', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20886, to_date('07-03-2057', 'dd-mm-yyyy'), '3', '07', '066', '03', '2057', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20887, to_date('08-03-2057', 'dd-mm-yyyy'), '4', '08', '067', '03', '2057', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20888, to_date('09-03-2057', 'dd-mm-yyyy'), '5', '09', '068', '03', '2057', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20889, to_date('10-03-2057', 'dd-mm-yyyy'), '6', '10', '069', '03', '2057', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20890, to_date('11-03-2057', 'dd-mm-yyyy'), '7', '11', '070', '03', '2057', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20891, to_date('12-03-2057', 'dd-mm-yyyy'), '1', '12', '071', '03', '2057', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20892, to_date('13-03-2057', 'dd-mm-yyyy'), '2', '13', '072', '03', '2057', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20893, to_date('14-03-2057', 'dd-mm-yyyy'), '3', '14', '073', '03', '2057', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20894, to_date('15-03-2057', 'dd-mm-yyyy'), '4', '15', '074', '03', '2057', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20895, to_date('16-03-2057', 'dd-mm-yyyy'), '5', '16', '075', '03', '2057', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20896, to_date('17-03-2057', 'dd-mm-yyyy'), '6', '17', '076', '03', '2057', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20897, to_date('18-03-2057', 'dd-mm-yyyy'), '7', '18', '077', '03', '2057', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20898, to_date('19-03-2057', 'dd-mm-yyyy'), '1', '19', '078', '03', '2057', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20899, to_date('20-03-2057', 'dd-mm-yyyy'), '2', '20', '079', '03', '2057', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20900, to_date('21-03-2057', 'dd-mm-yyyy'), '3', '21', '080', '03', '2057', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20901, to_date('22-03-2057', 'dd-mm-yyyy'), '4', '22', '081', '03', '2057', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20902, to_date('23-03-2057', 'dd-mm-yyyy'), '5', '23', '082', '03', '2057', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20903, to_date('24-03-2057', 'dd-mm-yyyy'), '6', '24', '083', '03', '2057', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20904, to_date('25-03-2057', 'dd-mm-yyyy'), '7', '25', '084', '03', '2057', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20905, to_date('26-03-2057', 'dd-mm-yyyy'), '1', '26', '085', '03', '2057', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20906, to_date('27-03-2057', 'dd-mm-yyyy'), '2', '27', '086', '03', '2057', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20907, to_date('28-03-2057', 'dd-mm-yyyy'), '3', '28', '087', '03', '2057', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20908, to_date('29-03-2057', 'dd-mm-yyyy'), '4', '29', '088', '03', '2057', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
commit;
prompt 19000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20909, to_date('30-03-2057', 'dd-mm-yyyy'), '5', '30', '089', '03', '2057', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20910, to_date('31-03-2057', 'dd-mm-yyyy'), '6', '31', '090', '03', '2057', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20911, to_date('01-04-2057', 'dd-mm-yyyy'), '7', '01', '091', '04', '2057', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20912, to_date('02-04-2057', 'dd-mm-yyyy'), '1', '02', '092', '04', '2057', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20913, to_date('03-04-2057', 'dd-mm-yyyy'), '2', '03', '093', '04', '2057', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20914, to_date('04-04-2057', 'dd-mm-yyyy'), '3', '04', '094', '04', '2057', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20915, to_date('05-04-2057', 'dd-mm-yyyy'), '4', '05', '095', '04', '2057', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20916, to_date('06-04-2057', 'dd-mm-yyyy'), '5', '06', '096', '04', '2057', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20917, to_date('07-04-2057', 'dd-mm-yyyy'), '6', '07', '097', '04', '2057', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20918, to_date('08-04-2057', 'dd-mm-yyyy'), '7', '08', '098', '04', '2057', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20919, to_date('09-04-2057', 'dd-mm-yyyy'), '1', '09', '099', '04', '2057', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20920, to_date('10-04-2057', 'dd-mm-yyyy'), '2', '10', '100', '04', '2057', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20921, to_date('11-04-2057', 'dd-mm-yyyy'), '3', '11', '101', '04', '2057', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20922, to_date('12-04-2057', 'dd-mm-yyyy'), '4', '12', '102', '04', '2057', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20923, to_date('13-04-2057', 'dd-mm-yyyy'), '5', '13', '103', '04', '2057', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20924, to_date('14-04-2057', 'dd-mm-yyyy'), '6', '14', '104', '04', '2057', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20925, to_date('15-04-2057', 'dd-mm-yyyy'), '7', '15', '105', '04', '2057', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20926, to_date('16-04-2057', 'dd-mm-yyyy'), '1', '16', '106', '04', '2057', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20927, to_date('17-04-2057', 'dd-mm-yyyy'), '2', '17', '107', '04', '2057', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20928, to_date('18-04-2057', 'dd-mm-yyyy'), '3', '18', '108', '04', '2057', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20929, to_date('19-04-2057', 'dd-mm-yyyy'), '4', '19', '109', '04', '2057', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20930, to_date('20-04-2057', 'dd-mm-yyyy'), '5', '20', '110', '04', '2057', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20931, to_date('21-04-2057', 'dd-mm-yyyy'), '6', '21', '111', '04', '2057', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20932, to_date('22-04-2057', 'dd-mm-yyyy'), '7', '22', '112', '04', '2057', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20933, to_date('23-04-2057', 'dd-mm-yyyy'), '1', '23', '113', '04', '2057', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20934, to_date('24-04-2057', 'dd-mm-yyyy'), '2', '24', '114', '04', '2057', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20935, to_date('25-04-2057', 'dd-mm-yyyy'), '3', '25', '115', '04', '2057', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20936, to_date('26-04-2057', 'dd-mm-yyyy'), '4', '26', '116', '04', '2057', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20937, to_date('27-04-2057', 'dd-mm-yyyy'), '5', '27', '117', '04', '2057', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20938, to_date('28-04-2057', 'dd-mm-yyyy'), '6', '28', '118', '04', '2057', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20939, to_date('29-04-2057', 'dd-mm-yyyy'), '7', '29', '119', '04', '2057', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20940, to_date('30-04-2057', 'dd-mm-yyyy'), '1', '30', '120', '04', '2057', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20941, to_date('01-05-2057', 'dd-mm-yyyy'), '2', '01', '121', '05', '2057', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20942, to_date('02-05-2057', 'dd-mm-yyyy'), '3', '02', '122', '05', '2057', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20943, to_date('03-05-2057', 'dd-mm-yyyy'), '4', '03', '123', '05', '2057', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20944, to_date('04-05-2057', 'dd-mm-yyyy'), '5', '04', '124', '05', '2057', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20945, to_date('05-05-2057', 'dd-mm-yyyy'), '6', '05', '125', '05', '2057', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20946, to_date('06-05-2057', 'dd-mm-yyyy'), '7', '06', '126', '05', '2057', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20947, to_date('07-05-2057', 'dd-mm-yyyy'), '1', '07', '127', '05', '2057', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20948, to_date('08-05-2057', 'dd-mm-yyyy'), '2', '08', '128', '05', '2057', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20949, to_date('09-05-2057', 'dd-mm-yyyy'), '3', '09', '129', '05', '2057', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20950, to_date('10-05-2057', 'dd-mm-yyyy'), '4', '10', '130', '05', '2057', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20951, to_date('11-05-2057', 'dd-mm-yyyy'), '5', '11', '131', '05', '2057', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20952, to_date('12-05-2057', 'dd-mm-yyyy'), '6', '12', '132', '05', '2057', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20953, to_date('13-05-2057', 'dd-mm-yyyy'), '7', '13', '133', '05', '2057', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20954, to_date('14-05-2057', 'dd-mm-yyyy'), '1', '14', '134', '05', '2057', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20955, to_date('15-05-2057', 'dd-mm-yyyy'), '2', '15', '135', '05', '2057', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20956, to_date('16-05-2057', 'dd-mm-yyyy'), '3', '16', '136', '05', '2057', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20957, to_date('17-05-2057', 'dd-mm-yyyy'), '4', '17', '137', '05', '2057', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20958, to_date('18-05-2057', 'dd-mm-yyyy'), '5', '18', '138', '05', '2057', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20959, to_date('19-05-2057', 'dd-mm-yyyy'), '6', '19', '139', '05', '2057', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20960, to_date('20-05-2057', 'dd-mm-yyyy'), '7', '20', '140', '05', '2057', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20961, to_date('21-05-2057', 'dd-mm-yyyy'), '1', '21', '141', '05', '2057', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (20962, to_date('22-05-2057', 'dd-mm-yyyy'), '2', '22', '142', '05', '2057', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22447, to_date('15-06-2061', 'dd-mm-yyyy'), '3', '15', '166', '06', '2061', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22448, to_date('16-06-2061', 'dd-mm-yyyy'), '4', '16', '167', '06', '2061', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22449, to_date('17-06-2061', 'dd-mm-yyyy'), '5', '17', '168', '06', '2061', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22450, to_date('18-06-2061', 'dd-mm-yyyy'), '6', '18', '169', '06', '2061', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22451, to_date('19-06-2061', 'dd-mm-yyyy'), '7', '19', '170', '06', '2061', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22452, to_date('20-06-2061', 'dd-mm-yyyy'), '1', '20', '171', '06', '2061', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22453, to_date('21-06-2061', 'dd-mm-yyyy'), '2', '21', '172', '06', '2061', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22454, to_date('22-06-2061', 'dd-mm-yyyy'), '3', '22', '173', '06', '2061', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22455, to_date('23-06-2061', 'dd-mm-yyyy'), '4', '23', '174', '06', '2061', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22456, to_date('24-06-2061', 'dd-mm-yyyy'), '5', '24', '175', '06', '2061', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22457, to_date('25-06-2061', 'dd-mm-yyyy'), '6', '25', '176', '06', '2061', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22458, to_date('26-06-2061', 'dd-mm-yyyy'), '7', '26', '177', '06', '2061', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22459, to_date('27-06-2061', 'dd-mm-yyyy'), '1', '27', '178', '06', '2061', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22460, to_date('28-06-2061', 'dd-mm-yyyy'), '2', '28', '179', '06', '2061', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22461, to_date('29-06-2061', 'dd-mm-yyyy'), '3', '29', '180', '06', '2061', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22462, to_date('30-06-2061', 'dd-mm-yyyy'), '4', '30', '181', '06', '2061', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22463, to_date('01-07-2061', 'dd-mm-yyyy'), '5', '01', '182', '07', '2061', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22464, to_date('02-07-2061', 'dd-mm-yyyy'), '6', '02', '183', '07', '2061', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22465, to_date('03-07-2061', 'dd-mm-yyyy'), '7', '03', '184', '07', '2061', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22466, to_date('04-07-2061', 'dd-mm-yyyy'), '1', '04', '185', '07', '2061', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22467, to_date('05-07-2061', 'dd-mm-yyyy'), '2', '05', '186', '07', '2061', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22468, to_date('06-07-2061', 'dd-mm-yyyy'), '3', '06', '187', '07', '2061', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22469, to_date('07-07-2061', 'dd-mm-yyyy'), '4', '07', '188', '07', '2061', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22470, to_date('08-07-2061', 'dd-mm-yyyy'), '5', '08', '189', '07', '2061', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22471, to_date('09-07-2061', 'dd-mm-yyyy'), '6', '09', '190', '07', '2061', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22472, to_date('10-07-2061', 'dd-mm-yyyy'), '7', '10', '191', '07', '2061', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22473, to_date('11-07-2061', 'dd-mm-yyyy'), '1', '11', '192', '07', '2061', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22474, to_date('12-07-2061', 'dd-mm-yyyy'), '2', '12', '193', '07', '2061', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22475, to_date('13-07-2061', 'dd-mm-yyyy'), '3', '13', '194', '07', '2061', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22476, to_date('14-07-2061', 'dd-mm-yyyy'), '4', '14', '195', '07', '2061', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22477, to_date('15-07-2061', 'dd-mm-yyyy'), '5', '15', '196', '07', '2061', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22478, to_date('16-07-2061', 'dd-mm-yyyy'), '6', '16', '197', '07', '2061', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22479, to_date('17-07-2061', 'dd-mm-yyyy'), '7', '17', '198', '07', '2061', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22480, to_date('18-07-2061', 'dd-mm-yyyy'), '1', '18', '199', '07', '2061', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22481, to_date('19-07-2061', 'dd-mm-yyyy'), '2', '19', '200', '07', '2061', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22482, to_date('20-07-2061', 'dd-mm-yyyy'), '3', '20', '201', '07', '2061', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22483, to_date('21-07-2061', 'dd-mm-yyyy'), '4', '21', '202', '07', '2061', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22484, to_date('22-07-2061', 'dd-mm-yyyy'), '5', '22', '203', '07', '2061', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22485, to_date('23-07-2061', 'dd-mm-yyyy'), '6', '23', '204', '07', '2061', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22486, to_date('24-07-2061', 'dd-mm-yyyy'), '7', '24', '205', '07', '2061', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22487, to_date('25-07-2061', 'dd-mm-yyyy'), '1', '25', '206', '07', '2061', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22488, to_date('26-07-2061', 'dd-mm-yyyy'), '2', '26', '207', '07', '2061', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22489, to_date('27-07-2061', 'dd-mm-yyyy'), '3', '27', '208', '07', '2061', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22490, to_date('28-07-2061', 'dd-mm-yyyy'), '4', '28', '209', '07', '2061', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22491, to_date('29-07-2061', 'dd-mm-yyyy'), '5', '29', '210', '07', '2061', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22492, to_date('30-07-2061', 'dd-mm-yyyy'), '6', '30', '211', '07', '2061', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22493, to_date('31-07-2061', 'dd-mm-yyyy'), '7', '31', '212', '07', '2061', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22494, to_date('01-08-2061', 'dd-mm-yyyy'), '1', '01', '213', '08', '2061', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22495, to_date('02-08-2061', 'dd-mm-yyyy'), '2', '02', '214', '08', '2061', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22496, to_date('03-08-2061', 'dd-mm-yyyy'), '3', '03', '215', '08', '2061', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22497, to_date('04-08-2061', 'dd-mm-yyyy'), '4', '04', '216', '08', '2061', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22498, to_date('05-08-2061', 'dd-mm-yyyy'), '5', '05', '217', '08', '2061', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22499, to_date('06-08-2061', 'dd-mm-yyyy'), '6', '06', '218', '08', '2061', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22500, to_date('07-08-2061', 'dd-mm-yyyy'), '7', '07', '219', '08', '2061', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22501, to_date('08-08-2061', 'dd-mm-yyyy'), '1', '08', '220', '08', '2061', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22502, to_date('09-08-2061', 'dd-mm-yyyy'), '2', '09', '221', '08', '2061', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22503, to_date('10-08-2061', 'dd-mm-yyyy'), '3', '10', '222', '08', '2061', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22504, to_date('11-08-2061', 'dd-mm-yyyy'), '4', '11', '223', '08', '2061', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22505, to_date('12-08-2061', 'dd-mm-yyyy'), '5', '12', '224', '08', '2061', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22506, to_date('13-08-2061', 'dd-mm-yyyy'), '6', '13', '225', '08', '2061', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22507, to_date('14-08-2061', 'dd-mm-yyyy'), '7', '14', '226', '08', '2061', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22508, to_date('15-08-2061', 'dd-mm-yyyy'), '1', '15', '227', '08', '2061', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22509, to_date('16-08-2061', 'dd-mm-yyyy'), '2', '16', '228', '08', '2061', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22510, to_date('17-08-2061', 'dd-mm-yyyy'), '3', '17', '229', '08', '2061', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22511, to_date('18-08-2061', 'dd-mm-yyyy'), '4', '18', '230', '08', '2061', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22512, to_date('19-08-2061', 'dd-mm-yyyy'), '5', '19', '231', '08', '2061', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22513, to_date('20-08-2061', 'dd-mm-yyyy'), '6', '20', '232', '08', '2061', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22514, to_date('21-08-2061', 'dd-mm-yyyy'), '7', '21', '233', '08', '2061', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22515, to_date('22-08-2061', 'dd-mm-yyyy'), '1', '22', '234', '08', '2061', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22516, to_date('23-08-2061', 'dd-mm-yyyy'), '2', '23', '235', '08', '2061', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22517, to_date('24-08-2061', 'dd-mm-yyyy'), '3', '24', '236', '08', '2061', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22518, to_date('25-08-2061', 'dd-mm-yyyy'), '4', '25', '237', '08', '2061', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22519, to_date('26-08-2061', 'dd-mm-yyyy'), '5', '26', '238', '08', '2061', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22520, to_date('27-08-2061', 'dd-mm-yyyy'), '6', '27', '239', '08', '2061', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22521, to_date('28-08-2061', 'dd-mm-yyyy'), '7', '28', '240', '08', '2061', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22522, to_date('29-08-2061', 'dd-mm-yyyy'), '1', '29', '241', '08', '2061', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22523, to_date('30-08-2061', 'dd-mm-yyyy'), '2', '30', '242', '08', '2061', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22524, to_date('31-08-2061', 'dd-mm-yyyy'), '3', '31', '243', '08', '2061', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22525, to_date('01-09-2061', 'dd-mm-yyyy'), '4', '01', '244', '09', '2061', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22526, to_date('02-09-2061', 'dd-mm-yyyy'), '5', '02', '245', '09', '2061', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22527, to_date('03-09-2061', 'dd-mm-yyyy'), '6', '03', '246', '09', '2061', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22528, to_date('04-09-2061', 'dd-mm-yyyy'), '7', '04', '247', '09', '2061', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22529, to_date('05-09-2061', 'dd-mm-yyyy'), '1', '05', '248', '09', '2061', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22530, to_date('06-09-2061', 'dd-mm-yyyy'), '2', '06', '249', '09', '2061', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22531, to_date('07-09-2061', 'dd-mm-yyyy'), '3', '07', '250', '09', '2061', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22532, to_date('08-09-2061', 'dd-mm-yyyy'), '4', '08', '251', '09', '2061', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22533, to_date('09-09-2061', 'dd-mm-yyyy'), '5', '09', '252', '09', '2061', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22534, to_date('10-09-2061', 'dd-mm-yyyy'), '6', '10', '253', '09', '2061', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22535, to_date('11-09-2061', 'dd-mm-yyyy'), '7', '11', '254', '09', '2061', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22536, to_date('12-09-2061', 'dd-mm-yyyy'), '1', '12', '255', '09', '2061', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22537, to_date('13-09-2061', 'dd-mm-yyyy'), '2', '13', '256', '09', '2061', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22538, to_date('14-09-2061', 'dd-mm-yyyy'), '3', '14', '257', '09', '2061', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22539, to_date('15-09-2061', 'dd-mm-yyyy'), '4', '15', '258', '09', '2061', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22540, to_date('16-09-2061', 'dd-mm-yyyy'), '5', '16', '259', '09', '2061', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22541, to_date('17-09-2061', 'dd-mm-yyyy'), '6', '17', '260', '09', '2061', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22542, to_date('18-09-2061', 'dd-mm-yyyy'), '7', '18', '261', '09', '2061', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22543, to_date('19-09-2061', 'dd-mm-yyyy'), '1', '19', '262', '09', '2061', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22544, to_date('20-09-2061', 'dd-mm-yyyy'), '2', '20', '263', '09', '2061', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22545, to_date('21-09-2061', 'dd-mm-yyyy'), '3', '21', '264', '09', '2061', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22546, to_date('22-09-2061', 'dd-mm-yyyy'), '4', '22', '265', '09', '2061', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22547, to_date('23-09-2061', 'dd-mm-yyyy'), '5', '23', '266', '09', '2061', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22548, to_date('24-09-2061', 'dd-mm-yyyy'), '6', '24', '267', '09', '2061', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22549, to_date('25-09-2061', 'dd-mm-yyyy'), '7', '25', '268', '09', '2061', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22550, to_date('26-09-2061', 'dd-mm-yyyy'), '1', '26', '269', '09', '2061', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22551, to_date('27-09-2061', 'dd-mm-yyyy'), '2', '27', '270', '09', '2061', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (22552, to_date('28-09-2061', 'dd-mm-yyyy'), '3', '28', '271', '09', '2061', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24037, to_date('22-10-2065', 'dd-mm-yyyy'), '4', '22', '295', '10', '2065', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24038, to_date('23-10-2065', 'dd-mm-yyyy'), '5', '23', '296', '10', '2065', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24039, to_date('24-10-2065', 'dd-mm-yyyy'), '6', '24', '297', '10', '2065', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24040, to_date('25-10-2065', 'dd-mm-yyyy'), '7', '25', '298', '10', '2065', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24041, to_date('26-10-2065', 'dd-mm-yyyy'), '1', '26', '299', '10', '2065', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24042, to_date('27-10-2065', 'dd-mm-yyyy'), '2', '27', '300', '10', '2065', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24043, to_date('28-10-2065', 'dd-mm-yyyy'), '3', '28', '301', '10', '2065', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24044, to_date('29-10-2065', 'dd-mm-yyyy'), '4', '29', '302', '10', '2065', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24045, to_date('30-10-2065', 'dd-mm-yyyy'), '5', '30', '303', '10', '2065', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24046, to_date('31-10-2065', 'dd-mm-yyyy'), '6', '31', '304', '10', '2065', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24047, to_date('01-11-2065', 'dd-mm-yyyy'), '7', '01', '305', '11', '2065', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24048, to_date('02-11-2065', 'dd-mm-yyyy'), '1', '02', '306', '11', '2065', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24049, to_date('03-11-2065', 'dd-mm-yyyy'), '2', '03', '307', '11', '2065', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24050, to_date('04-11-2065', 'dd-mm-yyyy'), '3', '04', '308', '11', '2065', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24051, to_date('05-11-2065', 'dd-mm-yyyy'), '4', '05', '309', '11', '2065', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24052, to_date('06-11-2065', 'dd-mm-yyyy'), '5', '06', '310', '11', '2065', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24053, to_date('07-11-2065', 'dd-mm-yyyy'), '6', '07', '311', '11', '2065', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24054, to_date('08-11-2065', 'dd-mm-yyyy'), '7', '08', '312', '11', '2065', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24055, to_date('09-11-2065', 'dd-mm-yyyy'), '1', '09', '313', '11', '2065', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24056, to_date('10-11-2065', 'dd-mm-yyyy'), '2', '10', '314', '11', '2065', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24057, to_date('11-11-2065', 'dd-mm-yyyy'), '3', '11', '315', '11', '2065', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24058, to_date('12-11-2065', 'dd-mm-yyyy'), '4', '12', '316', '11', '2065', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24059, to_date('13-11-2065', 'dd-mm-yyyy'), '5', '13', '317', '11', '2065', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24060, to_date('14-11-2065', 'dd-mm-yyyy'), '6', '14', '318', '11', '2065', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24061, to_date('15-11-2065', 'dd-mm-yyyy'), '7', '15', '319', '11', '2065', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24062, to_date('16-11-2065', 'dd-mm-yyyy'), '1', '16', '320', '11', '2065', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24063, to_date('17-11-2065', 'dd-mm-yyyy'), '2', '17', '321', '11', '2065', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24064, to_date('18-11-2065', 'dd-mm-yyyy'), '3', '18', '322', '11', '2065', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24065, to_date('19-11-2065', 'dd-mm-yyyy'), '4', '19', '323', '11', '2065', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24066, to_date('20-11-2065', 'dd-mm-yyyy'), '5', '20', '324', '11', '2065', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24067, to_date('21-11-2065', 'dd-mm-yyyy'), '6', '21', '325', '11', '2065', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24068, to_date('22-11-2065', 'dd-mm-yyyy'), '7', '22', '326', '11', '2065', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24069, to_date('23-11-2065', 'dd-mm-yyyy'), '1', '23', '327', '11', '2065', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24070, to_date('24-11-2065', 'dd-mm-yyyy'), '2', '24', '328', '11', '2065', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24071, to_date('25-11-2065', 'dd-mm-yyyy'), '3', '25', '329', '11', '2065', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24072, to_date('26-11-2065', 'dd-mm-yyyy'), '4', '26', '330', '11', '2065', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24073, to_date('27-11-2065', 'dd-mm-yyyy'), '5', '27', '331', '11', '2065', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24074, to_date('28-11-2065', 'dd-mm-yyyy'), '6', '28', '332', '11', '2065', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24075, to_date('29-11-2065', 'dd-mm-yyyy'), '7', '29', '333', '11', '2065', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24076, to_date('30-11-2065', 'dd-mm-yyyy'), '1', '30', '334', '11', '2065', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24077, to_date('01-12-2065', 'dd-mm-yyyy'), '2', '01', '335', '12', '2065', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24078, to_date('02-12-2065', 'dd-mm-yyyy'), '3', '02', '336', '12', '2065', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24079, to_date('03-12-2065', 'dd-mm-yyyy'), '4', '03', '337', '12', '2065', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24080, to_date('04-12-2065', 'dd-mm-yyyy'), '5', '04', '338', '12', '2065', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24081, to_date('05-12-2065', 'dd-mm-yyyy'), '6', '05', '339', '12', '2065', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24082, to_date('06-12-2065', 'dd-mm-yyyy'), '7', '06', '340', '12', '2065', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24083, to_date('07-12-2065', 'dd-mm-yyyy'), '1', '07', '341', '12', '2065', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24084, to_date('08-12-2065', 'dd-mm-yyyy'), '2', '08', '342', '12', '2065', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24085, to_date('09-12-2065', 'dd-mm-yyyy'), '3', '09', '343', '12', '2065', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24086, to_date('10-12-2065', 'dd-mm-yyyy'), '4', '10', '344', '12', '2065', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24087, to_date('11-12-2065', 'dd-mm-yyyy'), '5', '11', '345', '12', '2065', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24088, to_date('12-12-2065', 'dd-mm-yyyy'), '6', '12', '346', '12', '2065', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24089, to_date('13-12-2065', 'dd-mm-yyyy'), '7', '13', '347', '12', '2065', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24090, to_date('14-12-2065', 'dd-mm-yyyy'), '1', '14', '348', '12', '2065', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24091, to_date('15-12-2065', 'dd-mm-yyyy'), '2', '15', '349', '12', '2065', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24092, to_date('16-12-2065', 'dd-mm-yyyy'), '3', '16', '350', '12', '2065', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24093, to_date('17-12-2065', 'dd-mm-yyyy'), '4', '17', '351', '12', '2065', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24094, to_date('18-12-2065', 'dd-mm-yyyy'), '5', '18', '352', '12', '2065', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24095, to_date('19-12-2065', 'dd-mm-yyyy'), '6', '19', '353', '12', '2065', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24096, to_date('20-12-2065', 'dd-mm-yyyy'), '7', '20', '354', '12', '2065', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24097, to_date('21-12-2065', 'dd-mm-yyyy'), '1', '21', '355', '12', '2065', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24098, to_date('22-12-2065', 'dd-mm-yyyy'), '2', '22', '356', '12', '2065', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24099, to_date('23-12-2065', 'dd-mm-yyyy'), '3', '23', '357', '12', '2065', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24100, to_date('24-12-2065', 'dd-mm-yyyy'), '4', '24', '358', '12', '2065', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24101, to_date('25-12-2065', 'dd-mm-yyyy'), '5', '25', '359', '12', '2065', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24102, to_date('26-12-2065', 'dd-mm-yyyy'), '6', '26', '360', '12', '2065', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24103, to_date('27-12-2065', 'dd-mm-yyyy'), '7', '27', '361', '12', '2065', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24104, to_date('28-12-2065', 'dd-mm-yyyy'), '1', '28', '362', '12', '2065', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24105, to_date('29-12-2065', 'dd-mm-yyyy'), '2', '29', '363', '12', '2065', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24106, to_date('30-12-2065', 'dd-mm-yyyy'), '3', '30', '364', '12', '2065', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24107, to_date('31-12-2065', 'dd-mm-yyyy'), '4', '31', '365', '12', '2065', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24108, to_date('01-01-2066', 'dd-mm-yyyy'), '5', '01', '001', '01', '2066', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24109, to_date('02-01-2066', 'dd-mm-yyyy'), '6', '02', '002', '01', '2066', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24110, to_date('03-01-2066', 'dd-mm-yyyy'), '7', '03', '003', '01', '2066', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24111, to_date('04-01-2066', 'dd-mm-yyyy'), '1', '04', '004', '01', '2066', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24112, to_date('05-01-2066', 'dd-mm-yyyy'), '2', '05', '005', '01', '2066', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24113, to_date('06-01-2066', 'dd-mm-yyyy'), '3', '06', '006', '01', '2066', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24114, to_date('07-01-2066', 'dd-mm-yyyy'), '4', '07', '007', '01', '2066', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24115, to_date('08-01-2066', 'dd-mm-yyyy'), '5', '08', '008', '01', '2066', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24116, to_date('09-01-2066', 'dd-mm-yyyy'), '6', '09', '009', '01', '2066', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24117, to_date('10-01-2066', 'dd-mm-yyyy'), '7', '10', '010', '01', '2066', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24118, to_date('11-01-2066', 'dd-mm-yyyy'), '1', '11', '011', '01', '2066', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24119, to_date('12-01-2066', 'dd-mm-yyyy'), '2', '12', '012', '01', '2066', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24120, to_date('13-01-2066', 'dd-mm-yyyy'), '3', '13', '013', '01', '2066', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24121, to_date('14-01-2066', 'dd-mm-yyyy'), '4', '14', '014', '01', '2066', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24122, to_date('15-01-2066', 'dd-mm-yyyy'), '5', '15', '015', '01', '2066', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24123, to_date('16-01-2066', 'dd-mm-yyyy'), '6', '16', '016', '01', '2066', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24124, to_date('17-01-2066', 'dd-mm-yyyy'), '7', '17', '017', '01', '2066', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24125, to_date('18-01-2066', 'dd-mm-yyyy'), '1', '18', '018', '01', '2066', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24126, to_date('19-01-2066', 'dd-mm-yyyy'), '2', '19', '019', '01', '2066', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24127, to_date('20-01-2066', 'dd-mm-yyyy'), '3', '20', '020', '01', '2066', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24128, to_date('21-01-2066', 'dd-mm-yyyy'), '4', '21', '021', '01', '2066', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24129, to_date('22-01-2066', 'dd-mm-yyyy'), '5', '22', '022', '01', '2066', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24130, to_date('23-01-2066', 'dd-mm-yyyy'), '6', '23', '023', '01', '2066', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24131, to_date('24-01-2066', 'dd-mm-yyyy'), '7', '24', '024', '01', '2066', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24132, to_date('25-01-2066', 'dd-mm-yyyy'), '1', '25', '025', '01', '2066', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24133, to_date('26-01-2066', 'dd-mm-yyyy'), '2', '26', '026', '01', '2066', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24134, to_date('27-01-2066', 'dd-mm-yyyy'), '3', '27', '027', '01', '2066', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24135, to_date('28-01-2066', 'dd-mm-yyyy'), '4', '28', '028', '01', '2066', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24136, to_date('29-01-2066', 'dd-mm-yyyy'), '5', '29', '029', '01', '2066', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24137, to_date('30-01-2066', 'dd-mm-yyyy'), '6', '30', '030', '01', '2066', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24138, to_date('31-01-2066', 'dd-mm-yyyy'), '7', '31', '031', '01', '2066', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24139, to_date('01-02-2066', 'dd-mm-yyyy'), '1', '01', '032', '02', '2066', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24140, to_date('02-02-2066', 'dd-mm-yyyy'), '2', '02', '033', '02', '2066', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24141, to_date('03-02-2066', 'dd-mm-yyyy'), '3', '03', '034', '02', '2066', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (24142, to_date('04-02-2066', 'dd-mm-yyyy'), '4', '04', '035', '02', '2066', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14285, to_date('09-02-2039', 'dd-mm-yyyy'), '3', '09', '040', '02', '2039', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14286, to_date('10-02-2039', 'dd-mm-yyyy'), '4', '10', '041', '02', '2039', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14287, to_date('11-02-2039', 'dd-mm-yyyy'), '5', '11', '042', '02', '2039', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14288, to_date('12-02-2039', 'dd-mm-yyyy'), '6', '12', '043', '02', '2039', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14289, to_date('13-02-2039', 'dd-mm-yyyy'), '7', '13', '044', '02', '2039', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14290, to_date('14-02-2039', 'dd-mm-yyyy'), '1', '14', '045', '02', '2039', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14291, to_date('15-02-2039', 'dd-mm-yyyy'), '2', '15', '046', '02', '2039', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14292, to_date('16-02-2039', 'dd-mm-yyyy'), '3', '16', '047', '02', '2039', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14293, to_date('17-02-2039', 'dd-mm-yyyy'), '4', '17', '048', '02', '2039', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14294, to_date('18-02-2039', 'dd-mm-yyyy'), '5', '18', '049', '02', '2039', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14295, to_date('19-02-2039', 'dd-mm-yyyy'), '6', '19', '050', '02', '2039', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14296, to_date('20-02-2039', 'dd-mm-yyyy'), '7', '20', '051', '02', '2039', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14297, to_date('21-02-2039', 'dd-mm-yyyy'), '1', '21', '052', '02', '2039', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14298, to_date('22-02-2039', 'dd-mm-yyyy'), '2', '22', '053', '02', '2039', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14299, to_date('23-02-2039', 'dd-mm-yyyy'), '3', '23', '054', '02', '2039', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14300, to_date('24-02-2039', 'dd-mm-yyyy'), '4', '24', '055', '02', '2039', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14301, to_date('25-02-2039', 'dd-mm-yyyy'), '5', '25', '056', '02', '2039', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14302, to_date('26-02-2039', 'dd-mm-yyyy'), '6', '26', '057', '02', '2039', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14303, to_date('27-02-2039', 'dd-mm-yyyy'), '7', '27', '058', '02', '2039', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14304, to_date('28-02-2039', 'dd-mm-yyyy'), '1', '28', '059', '02', '2039', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14305, to_date('01-03-2039', 'dd-mm-yyyy'), '2', '01', '060', '03', '2039', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14306, to_date('02-03-2039', 'dd-mm-yyyy'), '3', '02', '061', '03', '2039', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14307, to_date('03-03-2039', 'dd-mm-yyyy'), '4', '03', '062', '03', '2039', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14308, to_date('04-03-2039', 'dd-mm-yyyy'), '5', '04', '063', '03', '2039', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14309, to_date('05-03-2039', 'dd-mm-yyyy'), '6', '05', '064', '03', '2039', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14310, to_date('06-03-2039', 'dd-mm-yyyy'), '7', '06', '065', '03', '2039', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14311, to_date('07-03-2039', 'dd-mm-yyyy'), '1', '07', '066', '03', '2039', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14312, to_date('08-03-2039', 'dd-mm-yyyy'), '2', '08', '067', '03', '2039', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14313, to_date('09-03-2039', 'dd-mm-yyyy'), '3', '09', '068', '03', '2039', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14314, to_date('10-03-2039', 'dd-mm-yyyy'), '4', '10', '069', '03', '2039', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14315, to_date('11-03-2039', 'dd-mm-yyyy'), '5', '11', '070', '03', '2039', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14316, to_date('12-03-2039', 'dd-mm-yyyy'), '6', '12', '071', '03', '2039', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14317, to_date('13-03-2039', 'dd-mm-yyyy'), '7', '13', '072', '03', '2039', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14318, to_date('14-03-2039', 'dd-mm-yyyy'), '1', '14', '073', '03', '2039', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14319, to_date('15-03-2039', 'dd-mm-yyyy'), '2', '15', '074', '03', '2039', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14320, to_date('16-03-2039', 'dd-mm-yyyy'), '3', '16', '075', '03', '2039', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14321, to_date('17-03-2039', 'dd-mm-yyyy'), '4', '17', '076', '03', '2039', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14322, to_date('18-03-2039', 'dd-mm-yyyy'), '5', '18', '077', '03', '2039', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14323, to_date('19-03-2039', 'dd-mm-yyyy'), '6', '19', '078', '03', '2039', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14324, to_date('20-03-2039', 'dd-mm-yyyy'), '7', '20', '079', '03', '2039', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14325, to_date('21-03-2039', 'dd-mm-yyyy'), '1', '21', '080', '03', '2039', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14326, to_date('22-03-2039', 'dd-mm-yyyy'), '2', '22', '081', '03', '2039', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14327, to_date('23-03-2039', 'dd-mm-yyyy'), '3', '23', '082', '03', '2039', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14328, to_date('24-03-2039', 'dd-mm-yyyy'), '4', '24', '083', '03', '2039', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14329, to_date('25-03-2039', 'dd-mm-yyyy'), '5', '25', '084', '03', '2039', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14330, to_date('26-03-2039', 'dd-mm-yyyy'), '6', '26', '085', '03', '2039', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14331, to_date('27-03-2039', 'dd-mm-yyyy'), '7', '27', '086', '03', '2039', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14332, to_date('28-03-2039', 'dd-mm-yyyy'), '1', '28', '087', '03', '2039', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14333, to_date('29-03-2039', 'dd-mm-yyyy'), '2', '29', '088', '03', '2039', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14334, to_date('30-03-2039', 'dd-mm-yyyy'), '3', '30', '089', '03', '2039', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14335, to_date('31-03-2039', 'dd-mm-yyyy'), '4', '31', '090', '03', '2039', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14336, to_date('01-04-2039', 'dd-mm-yyyy'), '5', '01', '091', '04', '2039', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14337, to_date('02-04-2039', 'dd-mm-yyyy'), '6', '02', '092', '04', '2039', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14338, to_date('03-04-2039', 'dd-mm-yyyy'), '7', '03', '093', '04', '2039', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14339, to_date('04-04-2039', 'dd-mm-yyyy'), '1', '04', '094', '04', '2039', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14340, to_date('05-04-2039', 'dd-mm-yyyy'), '2', '05', '095', '04', '2039', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14341, to_date('06-04-2039', 'dd-mm-yyyy'), '3', '06', '096', '04', '2039', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14342, to_date('07-04-2039', 'dd-mm-yyyy'), '4', '07', '097', '04', '2039', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14343, to_date('08-04-2039', 'dd-mm-yyyy'), '5', '08', '098', '04', '2039', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14344, to_date('09-04-2039', 'dd-mm-yyyy'), '6', '09', '099', '04', '2039', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14345, to_date('10-04-2039', 'dd-mm-yyyy'), '7', '10', '100', '04', '2039', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14346, to_date('11-04-2039', 'dd-mm-yyyy'), '1', '11', '101', '04', '2039', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14347, to_date('12-04-2039', 'dd-mm-yyyy'), '2', '12', '102', '04', '2039', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14348, to_date('13-04-2039', 'dd-mm-yyyy'), '3', '13', '103', '04', '2039', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14349, to_date('14-04-2039', 'dd-mm-yyyy'), '4', '14', '104', '04', '2039', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14350, to_date('15-04-2039', 'dd-mm-yyyy'), '5', '15', '105', '04', '2039', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14351, to_date('16-04-2039', 'dd-mm-yyyy'), '6', '16', '106', '04', '2039', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14352, to_date('17-04-2039', 'dd-mm-yyyy'), '7', '17', '107', '04', '2039', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14353, to_date('18-04-2039', 'dd-mm-yyyy'), '1', '18', '108', '04', '2039', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14354, to_date('19-04-2039', 'dd-mm-yyyy'), '2', '19', '109', '04', '2039', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14355, to_date('20-04-2039', 'dd-mm-yyyy'), '3', '20', '110', '04', '2039', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14356, to_date('21-04-2039', 'dd-mm-yyyy'), '4', '21', '111', '04', '2039', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14357, to_date('22-04-2039', 'dd-mm-yyyy'), '5', '22', '112', '04', '2039', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14358, to_date('23-04-2039', 'dd-mm-yyyy'), '6', '23', '113', '04', '2039', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14359, to_date('24-04-2039', 'dd-mm-yyyy'), '7', '24', '114', '04', '2039', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14360, to_date('25-04-2039', 'dd-mm-yyyy'), '1', '25', '115', '04', '2039', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14361, to_date('26-04-2039', 'dd-mm-yyyy'), '2', '26', '116', '04', '2039', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14362, to_date('27-04-2039', 'dd-mm-yyyy'), '3', '27', '117', '04', '2039', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14363, to_date('28-04-2039', 'dd-mm-yyyy'), '4', '28', '118', '04', '2039', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14364, to_date('29-04-2039', 'dd-mm-yyyy'), '5', '29', '119', '04', '2039', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14365, to_date('30-04-2039', 'dd-mm-yyyy'), '6', '30', '120', '04', '2039', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14366, to_date('01-05-2039', 'dd-mm-yyyy'), '7', '01', '121', '05', '2039', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14367, to_date('02-05-2039', 'dd-mm-yyyy'), '1', '02', '122', '05', '2039', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14368, to_date('03-05-2039', 'dd-mm-yyyy'), '2', '03', '123', '05', '2039', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14369, to_date('04-05-2039', 'dd-mm-yyyy'), '3', '04', '124', '05', '2039', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14370, to_date('05-05-2039', 'dd-mm-yyyy'), '4', '05', '125', '05', '2039', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14371, to_date('06-05-2039', 'dd-mm-yyyy'), '5', '06', '126', '05', '2039', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14372, to_date('07-05-2039', 'dd-mm-yyyy'), '6', '07', '127', '05', '2039', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14373, to_date('08-05-2039', 'dd-mm-yyyy'), '7', '08', '128', '05', '2039', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14374, to_date('09-05-2039', 'dd-mm-yyyy'), '1', '09', '129', '05', '2039', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14375, to_date('10-05-2039', 'dd-mm-yyyy'), '2', '10', '130', '05', '2039', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14376, to_date('11-05-2039', 'dd-mm-yyyy'), '3', '11', '131', '05', '2039', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14377, to_date('12-05-2039', 'dd-mm-yyyy'), '4', '12', '132', '05', '2039', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14378, to_date('13-05-2039', 'dd-mm-yyyy'), '5', '13', '133', '05', '2039', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14379, to_date('14-05-2039', 'dd-mm-yyyy'), '6', '14', '134', '05', '2039', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14380, to_date('15-05-2039', 'dd-mm-yyyy'), '7', '15', '135', '05', '2039', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14381, to_date('16-05-2039', 'dd-mm-yyyy'), '1', '16', '136', '05', '2039', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14382, to_date('17-05-2039', 'dd-mm-yyyy'), '2', '17', '137', '05', '2039', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14383, to_date('18-05-2039', 'dd-mm-yyyy'), '3', '18', '138', '05', '2039', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14384, to_date('19-05-2039', 'dd-mm-yyyy'), '4', '19', '139', '05', '2039', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14385, to_date('20-05-2039', 'dd-mm-yyyy'), '5', '20', '140', '05', '2039', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14386, to_date('21-05-2039', 'dd-mm-yyyy'), '6', '21', '141', '05', '2039', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14387, to_date('22-05-2039', 'dd-mm-yyyy'), '7', '22', '142', '05', '2039', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14388, to_date('23-05-2039', 'dd-mm-yyyy'), '1', '23', '143', '05', '2039', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14389, to_date('24-05-2039', 'dd-mm-yyyy'), '2', '24', '144', '05', '2039', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14390, to_date('25-05-2039', 'dd-mm-yyyy'), '3', '25', '145', '05', '2039', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15875, to_date('18-06-2043', 'dd-mm-yyyy'), '4', '18', '169', '06', '2043', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15876, to_date('19-06-2043', 'dd-mm-yyyy'), '5', '19', '170', '06', '2043', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15877, to_date('20-06-2043', 'dd-mm-yyyy'), '6', '20', '171', '06', '2043', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15878, to_date('21-06-2043', 'dd-mm-yyyy'), '7', '21', '172', '06', '2043', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15879, to_date('22-06-2043', 'dd-mm-yyyy'), '1', '22', '173', '06', '2043', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15880, to_date('23-06-2043', 'dd-mm-yyyy'), '2', '23', '174', '06', '2043', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15881, to_date('24-06-2043', 'dd-mm-yyyy'), '3', '24', '175', '06', '2043', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15882, to_date('25-06-2043', 'dd-mm-yyyy'), '4', '25', '176', '06', '2043', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15883, to_date('26-06-2043', 'dd-mm-yyyy'), '5', '26', '177', '06', '2043', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15884, to_date('27-06-2043', 'dd-mm-yyyy'), '6', '27', '178', '06', '2043', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15885, to_date('28-06-2043', 'dd-mm-yyyy'), '7', '28', '179', '06', '2043', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15886, to_date('29-06-2043', 'dd-mm-yyyy'), '1', '29', '180', '06', '2043', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15887, to_date('30-06-2043', 'dd-mm-yyyy'), '2', '30', '181', '06', '2043', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15888, to_date('01-07-2043', 'dd-mm-yyyy'), '3', '01', '182', '07', '2043', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15889, to_date('02-07-2043', 'dd-mm-yyyy'), '4', '02', '183', '07', '2043', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15890, to_date('03-07-2043', 'dd-mm-yyyy'), '5', '03', '184', '07', '2043', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15891, to_date('04-07-2043', 'dd-mm-yyyy'), '6', '04', '185', '07', '2043', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15892, to_date('05-07-2043', 'dd-mm-yyyy'), '7', '05', '186', '07', '2043', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15893, to_date('06-07-2043', 'dd-mm-yyyy'), '1', '06', '187', '07', '2043', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15894, to_date('07-07-2043', 'dd-mm-yyyy'), '2', '07', '188', '07', '2043', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15895, to_date('08-07-2043', 'dd-mm-yyyy'), '3', '08', '189', '07', '2043', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15896, to_date('09-07-2043', 'dd-mm-yyyy'), '4', '09', '190', '07', '2043', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15897, to_date('10-07-2043', 'dd-mm-yyyy'), '5', '10', '191', '07', '2043', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15898, to_date('11-07-2043', 'dd-mm-yyyy'), '6', '11', '192', '07', '2043', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15899, to_date('12-07-2043', 'dd-mm-yyyy'), '7', '12', '193', '07', '2043', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15900, to_date('13-07-2043', 'dd-mm-yyyy'), '1', '13', '194', '07', '2043', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15901, to_date('14-07-2043', 'dd-mm-yyyy'), '2', '14', '195', '07', '2043', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15902, to_date('15-07-2043', 'dd-mm-yyyy'), '3', '15', '196', '07', '2043', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15903, to_date('16-07-2043', 'dd-mm-yyyy'), '4', '16', '197', '07', '2043', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15904, to_date('17-07-2043', 'dd-mm-yyyy'), '5', '17', '198', '07', '2043', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15905, to_date('18-07-2043', 'dd-mm-yyyy'), '6', '18', '199', '07', '2043', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15906, to_date('19-07-2043', 'dd-mm-yyyy'), '7', '19', '200', '07', '2043', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15907, to_date('20-07-2043', 'dd-mm-yyyy'), '1', '20', '201', '07', '2043', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15908, to_date('21-07-2043', 'dd-mm-yyyy'), '2', '21', '202', '07', '2043', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15909, to_date('22-07-2043', 'dd-mm-yyyy'), '3', '22', '203', '07', '2043', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15910, to_date('23-07-2043', 'dd-mm-yyyy'), '4', '23', '204', '07', '2043', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15911, to_date('24-07-2043', 'dd-mm-yyyy'), '5', '24', '205', '07', '2043', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15912, to_date('25-07-2043', 'dd-mm-yyyy'), '6', '25', '206', '07', '2043', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15913, to_date('26-07-2043', 'dd-mm-yyyy'), '7', '26', '207', '07', '2043', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15914, to_date('27-07-2043', 'dd-mm-yyyy'), '1', '27', '208', '07', '2043', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15915, to_date('28-07-2043', 'dd-mm-yyyy'), '2', '28', '209', '07', '2043', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15916, to_date('29-07-2043', 'dd-mm-yyyy'), '3', '29', '210', '07', '2043', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15917, to_date('30-07-2043', 'dd-mm-yyyy'), '4', '30', '211', '07', '2043', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15918, to_date('31-07-2043', 'dd-mm-yyyy'), '5', '31', '212', '07', '2043', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15919, to_date('01-08-2043', 'dd-mm-yyyy'), '6', '01', '213', '08', '2043', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15920, to_date('02-08-2043', 'dd-mm-yyyy'), '7', '02', '214', '08', '2043', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15921, to_date('03-08-2043', 'dd-mm-yyyy'), '1', '03', '215', '08', '2043', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15922, to_date('04-08-2043', 'dd-mm-yyyy'), '2', '04', '216', '08', '2043', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15923, to_date('05-08-2043', 'dd-mm-yyyy'), '3', '05', '217', '08', '2043', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15924, to_date('06-08-2043', 'dd-mm-yyyy'), '4', '06', '218', '08', '2043', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15925, to_date('07-08-2043', 'dd-mm-yyyy'), '5', '07', '219', '08', '2043', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15926, to_date('08-08-2043', 'dd-mm-yyyy'), '6', '08', '220', '08', '2043', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15927, to_date('09-08-2043', 'dd-mm-yyyy'), '7', '09', '221', '08', '2043', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15928, to_date('10-08-2043', 'dd-mm-yyyy'), '1', '10', '222', '08', '2043', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15929, to_date('11-08-2043', 'dd-mm-yyyy'), '2', '11', '223', '08', '2043', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15930, to_date('12-08-2043', 'dd-mm-yyyy'), '3', '12', '224', '08', '2043', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15931, to_date('13-08-2043', 'dd-mm-yyyy'), '4', '13', '225', '08', '2043', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15932, to_date('14-08-2043', 'dd-mm-yyyy'), '5', '14', '226', '08', '2043', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15933, to_date('15-08-2043', 'dd-mm-yyyy'), '6', '15', '227', '08', '2043', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15934, to_date('16-08-2043', 'dd-mm-yyyy'), '7', '16', '228', '08', '2043', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15935, to_date('17-08-2043', 'dd-mm-yyyy'), '1', '17', '229', '08', '2043', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15936, to_date('18-08-2043', 'dd-mm-yyyy'), '2', '18', '230', '08', '2043', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15937, to_date('19-08-2043', 'dd-mm-yyyy'), '3', '19', '231', '08', '2043', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15938, to_date('20-08-2043', 'dd-mm-yyyy'), '4', '20', '232', '08', '2043', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15939, to_date('21-08-2043', 'dd-mm-yyyy'), '5', '21', '233', '08', '2043', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15940, to_date('22-08-2043', 'dd-mm-yyyy'), '6', '22', '234', '08', '2043', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15941, to_date('23-08-2043', 'dd-mm-yyyy'), '7', '23', '235', '08', '2043', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15942, to_date('24-08-2043', 'dd-mm-yyyy'), '1', '24', '236', '08', '2043', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15943, to_date('25-08-2043', 'dd-mm-yyyy'), '2', '25', '237', '08', '2043', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15944, to_date('26-08-2043', 'dd-mm-yyyy'), '3', '26', '238', '08', '2043', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15945, to_date('27-08-2043', 'dd-mm-yyyy'), '4', '27', '239', '08', '2043', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15946, to_date('28-08-2043', 'dd-mm-yyyy'), '5', '28', '240', '08', '2043', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15947, to_date('29-08-2043', 'dd-mm-yyyy'), '6', '29', '241', '08', '2043', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15948, to_date('30-08-2043', 'dd-mm-yyyy'), '7', '30', '242', '08', '2043', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15949, to_date('31-08-2043', 'dd-mm-yyyy'), '1', '31', '243', '08', '2043', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15950, to_date('01-09-2043', 'dd-mm-yyyy'), '2', '01', '244', '09', '2043', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15951, to_date('02-09-2043', 'dd-mm-yyyy'), '3', '02', '245', '09', '2043', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15952, to_date('03-09-2043', 'dd-mm-yyyy'), '4', '03', '246', '09', '2043', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15953, to_date('04-09-2043', 'dd-mm-yyyy'), '5', '04', '247', '09', '2043', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15954, to_date('05-09-2043', 'dd-mm-yyyy'), '6', '05', '248', '09', '2043', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15955, to_date('06-09-2043', 'dd-mm-yyyy'), '7', '06', '249', '09', '2043', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15956, to_date('07-09-2043', 'dd-mm-yyyy'), '1', '07', '250', '09', '2043', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15957, to_date('08-09-2043', 'dd-mm-yyyy'), '2', '08', '251', '09', '2043', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15958, to_date('09-09-2043', 'dd-mm-yyyy'), '3', '09', '252', '09', '2043', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15959, to_date('10-09-2043', 'dd-mm-yyyy'), '4', '10', '253', '09', '2043', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15960, to_date('11-09-2043', 'dd-mm-yyyy'), '5', '11', '254', '09', '2043', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15961, to_date('12-09-2043', 'dd-mm-yyyy'), '6', '12', '255', '09', '2043', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15962, to_date('13-09-2043', 'dd-mm-yyyy'), '7', '13', '256', '09', '2043', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15963, to_date('14-09-2043', 'dd-mm-yyyy'), '1', '14', '257', '09', '2043', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15964, to_date('15-09-2043', 'dd-mm-yyyy'), '2', '15', '258', '09', '2043', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15965, to_date('16-09-2043', 'dd-mm-yyyy'), '3', '16', '259', '09', '2043', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15966, to_date('17-09-2043', 'dd-mm-yyyy'), '4', '17', '260', '09', '2043', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15967, to_date('18-09-2043', 'dd-mm-yyyy'), '5', '18', '261', '09', '2043', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15968, to_date('19-09-2043', 'dd-mm-yyyy'), '6', '19', '262', '09', '2043', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15969, to_date('20-09-2043', 'dd-mm-yyyy'), '7', '20', '263', '09', '2043', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15970, to_date('21-09-2043', 'dd-mm-yyyy'), '1', '21', '264', '09', '2043', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15971, to_date('22-09-2043', 'dd-mm-yyyy'), '2', '22', '265', '09', '2043', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15972, to_date('23-09-2043', 'dd-mm-yyyy'), '3', '23', '266', '09', '2043', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15973, to_date('24-09-2043', 'dd-mm-yyyy'), '4', '24', '267', '09', '2043', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15974, to_date('25-09-2043', 'dd-mm-yyyy'), '5', '25', '268', '09', '2043', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15975, to_date('26-09-2043', 'dd-mm-yyyy'), '6', '26', '269', '09', '2043', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15976, to_date('27-09-2043', 'dd-mm-yyyy'), '7', '27', '270', '09', '2043', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15977, to_date('28-09-2043', 'dd-mm-yyyy'), '1', '28', '271', '09', '2043', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15978, to_date('29-09-2043', 'dd-mm-yyyy'), '2', '29', '272', '09', '2043', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15979, to_date('30-09-2043', 'dd-mm-yyyy'), '3', '30', '273', '09', '2043', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15980, to_date('01-10-2043', 'dd-mm-yyyy'), '4', '01', '274', '10', '2043', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17465, to_date('25-10-2047', 'dd-mm-yyyy'), '5', '25', '298', '10', '2047', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17466, to_date('26-10-2047', 'dd-mm-yyyy'), '6', '26', '299', '10', '2047', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17467, to_date('27-10-2047', 'dd-mm-yyyy'), '7', '27', '300', '10', '2047', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17468, to_date('28-10-2047', 'dd-mm-yyyy'), '1', '28', '301', '10', '2047', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17469, to_date('29-10-2047', 'dd-mm-yyyy'), '2', '29', '302', '10', '2047', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17470, to_date('30-10-2047', 'dd-mm-yyyy'), '3', '30', '303', '10', '2047', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17471, to_date('31-10-2047', 'dd-mm-yyyy'), '4', '31', '304', '10', '2047', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17472, to_date('01-11-2047', 'dd-mm-yyyy'), '5', '01', '305', '11', '2047', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17473, to_date('02-11-2047', 'dd-mm-yyyy'), '6', '02', '306', '11', '2047', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17474, to_date('03-11-2047', 'dd-mm-yyyy'), '7', '03', '307', '11', '2047', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17475, to_date('04-11-2047', 'dd-mm-yyyy'), '1', '04', '308', '11', '2047', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17476, to_date('05-11-2047', 'dd-mm-yyyy'), '2', '05', '309', '11', '2047', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17477, to_date('06-11-2047', 'dd-mm-yyyy'), '3', '06', '310', '11', '2047', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17478, to_date('07-11-2047', 'dd-mm-yyyy'), '4', '07', '311', '11', '2047', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17479, to_date('08-11-2047', 'dd-mm-yyyy'), '5', '08', '312', '11', '2047', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17480, to_date('09-11-2047', 'dd-mm-yyyy'), '6', '09', '313', '11', '2047', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17481, to_date('10-11-2047', 'dd-mm-yyyy'), '7', '10', '314', '11', '2047', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17482, to_date('11-11-2047', 'dd-mm-yyyy'), '1', '11', '315', '11', '2047', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17483, to_date('12-11-2047', 'dd-mm-yyyy'), '2', '12', '316', '11', '2047', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17484, to_date('13-11-2047', 'dd-mm-yyyy'), '3', '13', '317', '11', '2047', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17485, to_date('14-11-2047', 'dd-mm-yyyy'), '4', '14', '318', '11', '2047', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17486, to_date('15-11-2047', 'dd-mm-yyyy'), '5', '15', '319', '11', '2047', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17487, to_date('16-11-2047', 'dd-mm-yyyy'), '6', '16', '320', '11', '2047', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17488, to_date('17-11-2047', 'dd-mm-yyyy'), '7', '17', '321', '11', '2047', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17489, to_date('18-11-2047', 'dd-mm-yyyy'), '1', '18', '322', '11', '2047', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17490, to_date('19-11-2047', 'dd-mm-yyyy'), '2', '19', '323', '11', '2047', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17491, to_date('20-11-2047', 'dd-mm-yyyy'), '3', '20', '324', '11', '2047', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17492, to_date('21-11-2047', 'dd-mm-yyyy'), '4', '21', '325', '11', '2047', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17493, to_date('22-11-2047', 'dd-mm-yyyy'), '5', '22', '326', '11', '2047', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17494, to_date('23-11-2047', 'dd-mm-yyyy'), '6', '23', '327', '11', '2047', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17495, to_date('24-11-2047', 'dd-mm-yyyy'), '7', '24', '328', '11', '2047', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17496, to_date('25-11-2047', 'dd-mm-yyyy'), '1', '25', '329', '11', '2047', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17497, to_date('26-11-2047', 'dd-mm-yyyy'), '2', '26', '330', '11', '2047', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17498, to_date('27-11-2047', 'dd-mm-yyyy'), '3', '27', '331', '11', '2047', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17499, to_date('28-11-2047', 'dd-mm-yyyy'), '4', '28', '332', '11', '2047', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17500, to_date('29-11-2047', 'dd-mm-yyyy'), '5', '29', '333', '11', '2047', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17501, to_date('30-11-2047', 'dd-mm-yyyy'), '6', '30', '334', '11', '2047', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17502, to_date('01-12-2047', 'dd-mm-yyyy'), '7', '01', '335', '12', '2047', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17503, to_date('02-12-2047', 'dd-mm-yyyy'), '1', '02', '336', '12', '2047', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17504, to_date('03-12-2047', 'dd-mm-yyyy'), '2', '03', '337', '12', '2047', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17505, to_date('04-12-2047', 'dd-mm-yyyy'), '3', '04', '338', '12', '2047', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17506, to_date('05-12-2047', 'dd-mm-yyyy'), '4', '05', '339', '12', '2047', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17507, to_date('06-12-2047', 'dd-mm-yyyy'), '5', '06', '340', '12', '2047', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17508, to_date('07-12-2047', 'dd-mm-yyyy'), '6', '07', '341', '12', '2047', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17509, to_date('08-12-2047', 'dd-mm-yyyy'), '7', '08', '342', '12', '2047', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17510, to_date('09-12-2047', 'dd-mm-yyyy'), '1', '09', '343', '12', '2047', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17511, to_date('10-12-2047', 'dd-mm-yyyy'), '2', '10', '344', '12', '2047', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17512, to_date('11-12-2047', 'dd-mm-yyyy'), '3', '11', '345', '12', '2047', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17513, to_date('12-12-2047', 'dd-mm-yyyy'), '4', '12', '346', '12', '2047', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17514, to_date('13-12-2047', 'dd-mm-yyyy'), '5', '13', '347', '12', '2047', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17515, to_date('14-12-2047', 'dd-mm-yyyy'), '6', '14', '348', '12', '2047', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17516, to_date('15-12-2047', 'dd-mm-yyyy'), '7', '15', '349', '12', '2047', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17517, to_date('16-12-2047', 'dd-mm-yyyy'), '1', '16', '350', '12', '2047', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17518, to_date('17-12-2047', 'dd-mm-yyyy'), '2', '17', '351', '12', '2047', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17519, to_date('18-12-2047', 'dd-mm-yyyy'), '3', '18', '352', '12', '2047', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17520, to_date('19-12-2047', 'dd-mm-yyyy'), '4', '19', '353', '12', '2047', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17521, to_date('20-12-2047', 'dd-mm-yyyy'), '5', '20', '354', '12', '2047', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17522, to_date('21-12-2047', 'dd-mm-yyyy'), '6', '21', '355', '12', '2047', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17523, to_date('22-12-2047', 'dd-mm-yyyy'), '7', '22', '356', '12', '2047', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17524, to_date('23-12-2047', 'dd-mm-yyyy'), '1', '23', '357', '12', '2047', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17525, to_date('24-12-2047', 'dd-mm-yyyy'), '2', '24', '358', '12', '2047', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17526, to_date('25-12-2047', 'dd-mm-yyyy'), '3', '25', '359', '12', '2047', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17527, to_date('26-12-2047', 'dd-mm-yyyy'), '4', '26', '360', '12', '2047', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17528, to_date('27-12-2047', 'dd-mm-yyyy'), '5', '27', '361', '12', '2047', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17529, to_date('28-12-2047', 'dd-mm-yyyy'), '6', '28', '362', '12', '2047', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17530, to_date('29-12-2047', 'dd-mm-yyyy'), '7', '29', '363', '12', '2047', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17531, to_date('30-12-2047', 'dd-mm-yyyy'), '1', '30', '364', '12', '2047', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17532, to_date('31-12-2047', 'dd-mm-yyyy'), '2', '31', '365', '12', '2047', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17533, to_date('01-01-2048', 'dd-mm-yyyy'), '3', '01', '001', '01', '2048', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17534, to_date('02-01-2048', 'dd-mm-yyyy'), '4', '02', '002', '01', '2048', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17535, to_date('03-01-2048', 'dd-mm-yyyy'), '5', '03', '003', '01', '2048', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17536, to_date('04-01-2048', 'dd-mm-yyyy'), '6', '04', '004', '01', '2048', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17537, to_date('05-01-2048', 'dd-mm-yyyy'), '7', '05', '005', '01', '2048', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17538, to_date('06-01-2048', 'dd-mm-yyyy'), '1', '06', '006', '01', '2048', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17539, to_date('07-01-2048', 'dd-mm-yyyy'), '2', '07', '007', '01', '2048', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17540, to_date('08-01-2048', 'dd-mm-yyyy'), '3', '08', '008', '01', '2048', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17541, to_date('09-01-2048', 'dd-mm-yyyy'), '4', '09', '009', '01', '2048', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17542, to_date('10-01-2048', 'dd-mm-yyyy'), '5', '10', '010', '01', '2048', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17543, to_date('11-01-2048', 'dd-mm-yyyy'), '6', '11', '011', '01', '2048', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17544, to_date('12-01-2048', 'dd-mm-yyyy'), '7', '12', '012', '01', '2048', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17545, to_date('13-01-2048', 'dd-mm-yyyy'), '1', '13', '013', '01', '2048', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17546, to_date('14-01-2048', 'dd-mm-yyyy'), '2', '14', '014', '01', '2048', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17547, to_date('15-01-2048', 'dd-mm-yyyy'), '3', '15', '015', '01', '2048', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17548, to_date('16-01-2048', 'dd-mm-yyyy'), '4', '16', '016', '01', '2048', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17549, to_date('17-01-2048', 'dd-mm-yyyy'), '5', '17', '017', '01', '2048', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17550, to_date('18-01-2048', 'dd-mm-yyyy'), '6', '18', '018', '01', '2048', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17551, to_date('19-01-2048', 'dd-mm-yyyy'), '7', '19', '019', '01', '2048', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17552, to_date('20-01-2048', 'dd-mm-yyyy'), '1', '20', '020', '01', '2048', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17553, to_date('21-01-2048', 'dd-mm-yyyy'), '2', '21', '021', '01', '2048', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17554, to_date('22-01-2048', 'dd-mm-yyyy'), '3', '22', '022', '01', '2048', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17555, to_date('23-01-2048', 'dd-mm-yyyy'), '4', '23', '023', '01', '2048', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17556, to_date('24-01-2048', 'dd-mm-yyyy'), '5', '24', '024', '01', '2048', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17557, to_date('25-01-2048', 'dd-mm-yyyy'), '6', '25', '025', '01', '2048', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17558, to_date('26-01-2048', 'dd-mm-yyyy'), '7', '26', '026', '01', '2048', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17559, to_date('27-01-2048', 'dd-mm-yyyy'), '1', '27', '027', '01', '2048', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17560, to_date('28-01-2048', 'dd-mm-yyyy'), '2', '28', '028', '01', '2048', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17561, to_date('29-01-2048', 'dd-mm-yyyy'), '3', '29', '029', '01', '2048', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17562, to_date('30-01-2048', 'dd-mm-yyyy'), '4', '30', '030', '01', '2048', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17563, to_date('31-01-2048', 'dd-mm-yyyy'), '5', '31', '031', '01', '2048', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17564, to_date('01-02-2048', 'dd-mm-yyyy'), '6', '01', '032', '02', '2048', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17565, to_date('02-02-2048', 'dd-mm-yyyy'), '7', '02', '033', '02', '2048', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17566, to_date('03-02-2048', 'dd-mm-yyyy'), '1', '03', '034', '02', '2048', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17567, to_date('04-02-2048', 'dd-mm-yyyy'), '2', '04', '035', '02', '2048', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17568, to_date('05-02-2048', 'dd-mm-yyyy'), '3', '05', '036', '02', '2048', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17569, to_date('06-02-2048', 'dd-mm-yyyy'), '4', '06', '037', '02', '2048', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17570, to_date('07-02-2048', 'dd-mm-yyyy'), '5', '07', '038', '02', '2048', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19055, to_date('02-03-2052', 'dd-mm-yyyy'), '6', '02', '062', '03', '2052', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19056, to_date('03-03-2052', 'dd-mm-yyyy'), '7', '03', '063', '03', '2052', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19057, to_date('04-03-2052', 'dd-mm-yyyy'), '1', '04', '064', '03', '2052', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19058, to_date('05-03-2052', 'dd-mm-yyyy'), '2', '05', '065', '03', '2052', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19059, to_date('06-03-2052', 'dd-mm-yyyy'), '3', '06', '066', '03', '2052', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19060, to_date('07-03-2052', 'dd-mm-yyyy'), '4', '07', '067', '03', '2052', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19061, to_date('08-03-2052', 'dd-mm-yyyy'), '5', '08', '068', '03', '2052', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19062, to_date('09-03-2052', 'dd-mm-yyyy'), '6', '09', '069', '03', '2052', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19063, to_date('10-03-2052', 'dd-mm-yyyy'), '7', '10', '070', '03', '2052', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19064, to_date('11-03-2052', 'dd-mm-yyyy'), '1', '11', '071', '03', '2052', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19065, to_date('12-03-2052', 'dd-mm-yyyy'), '2', '12', '072', '03', '2052', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19066, to_date('13-03-2052', 'dd-mm-yyyy'), '3', '13', '073', '03', '2052', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19067, to_date('14-03-2052', 'dd-mm-yyyy'), '4', '14', '074', '03', '2052', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19068, to_date('15-03-2052', 'dd-mm-yyyy'), '5', '15', '075', '03', '2052', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19069, to_date('16-03-2052', 'dd-mm-yyyy'), '6', '16', '076', '03', '2052', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19070, to_date('17-03-2052', 'dd-mm-yyyy'), '7', '17', '077', '03', '2052', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19071, to_date('18-03-2052', 'dd-mm-yyyy'), '1', '18', '078', '03', '2052', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19072, to_date('19-03-2052', 'dd-mm-yyyy'), '2', '19', '079', '03', '2052', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19073, to_date('20-03-2052', 'dd-mm-yyyy'), '3', '20', '080', '03', '2052', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19074, to_date('21-03-2052', 'dd-mm-yyyy'), '4', '21', '081', '03', '2052', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19075, to_date('22-03-2052', 'dd-mm-yyyy'), '5', '22', '082', '03', '2052', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19076, to_date('23-03-2052', 'dd-mm-yyyy'), '6', '23', '083', '03', '2052', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19077, to_date('24-03-2052', 'dd-mm-yyyy'), '7', '24', '084', '03', '2052', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19078, to_date('25-03-2052', 'dd-mm-yyyy'), '1', '25', '085', '03', '2052', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19079, to_date('26-03-2052', 'dd-mm-yyyy'), '2', '26', '086', '03', '2052', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19080, to_date('27-03-2052', 'dd-mm-yyyy'), '3', '27', '087', '03', '2052', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19081, to_date('28-03-2052', 'dd-mm-yyyy'), '4', '28', '088', '03', '2052', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19082, to_date('29-03-2052', 'dd-mm-yyyy'), '5', '29', '089', '03', '2052', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19083, to_date('30-03-2052', 'dd-mm-yyyy'), '6', '30', '090', '03', '2052', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19084, to_date('31-03-2052', 'dd-mm-yyyy'), '7', '31', '091', '03', '2052', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19085, to_date('01-04-2052', 'dd-mm-yyyy'), '1', '01', '092', '04', '2052', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19086, to_date('02-04-2052', 'dd-mm-yyyy'), '2', '02', '093', '04', '2052', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19087, to_date('03-04-2052', 'dd-mm-yyyy'), '3', '03', '094', '04', '2052', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19088, to_date('04-04-2052', 'dd-mm-yyyy'), '4', '04', '095', '04', '2052', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19089, to_date('05-04-2052', 'dd-mm-yyyy'), '5', '05', '096', '04', '2052', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19090, to_date('06-04-2052', 'dd-mm-yyyy'), '6', '06', '097', '04', '2052', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19091, to_date('07-04-2052', 'dd-mm-yyyy'), '7', '07', '098', '04', '2052', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19092, to_date('08-04-2052', 'dd-mm-yyyy'), '1', '08', '099', '04', '2052', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19093, to_date('09-04-2052', 'dd-mm-yyyy'), '2', '09', '100', '04', '2052', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19094, to_date('10-04-2052', 'dd-mm-yyyy'), '3', '10', '101', '04', '2052', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19095, to_date('11-04-2052', 'dd-mm-yyyy'), '4', '11', '102', '04', '2052', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19096, to_date('12-04-2052', 'dd-mm-yyyy'), '5', '12', '103', '04', '2052', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19097, to_date('13-04-2052', 'dd-mm-yyyy'), '6', '13', '104', '04', '2052', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19098, to_date('14-04-2052', 'dd-mm-yyyy'), '7', '14', '105', '04', '2052', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19099, to_date('15-04-2052', 'dd-mm-yyyy'), '1', '15', '106', '04', '2052', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19100, to_date('16-04-2052', 'dd-mm-yyyy'), '2', '16', '107', '04', '2052', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19101, to_date('17-04-2052', 'dd-mm-yyyy'), '3', '17', '108', '04', '2052', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19102, to_date('18-04-2052', 'dd-mm-yyyy'), '4', '18', '109', '04', '2052', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19103, to_date('19-04-2052', 'dd-mm-yyyy'), '5', '19', '110', '04', '2052', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19104, to_date('20-04-2052', 'dd-mm-yyyy'), '6', '20', '111', '04', '2052', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19105, to_date('21-04-2052', 'dd-mm-yyyy'), '7', '21', '112', '04', '2052', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19106, to_date('22-04-2052', 'dd-mm-yyyy'), '1', '22', '113', '04', '2052', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19107, to_date('23-04-2052', 'dd-mm-yyyy'), '2', '23', '114', '04', '2052', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19108, to_date('24-04-2052', 'dd-mm-yyyy'), '3', '24', '115', '04', '2052', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19109, to_date('25-04-2052', 'dd-mm-yyyy'), '4', '25', '116', '04', '2052', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19110, to_date('26-04-2052', 'dd-mm-yyyy'), '5', '26', '117', '04', '2052', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19111, to_date('27-04-2052', 'dd-mm-yyyy'), '6', '27', '118', '04', '2052', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19112, to_date('28-04-2052', 'dd-mm-yyyy'), '7', '28', '119', '04', '2052', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19113, to_date('29-04-2052', 'dd-mm-yyyy'), '1', '29', '120', '04', '2052', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19114, to_date('30-04-2052', 'dd-mm-yyyy'), '2', '30', '121', '04', '2052', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19115, to_date('01-05-2052', 'dd-mm-yyyy'), '3', '01', '122', '05', '2052', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19116, to_date('02-05-2052', 'dd-mm-yyyy'), '4', '02', '123', '05', '2052', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19117, to_date('03-05-2052', 'dd-mm-yyyy'), '5', '03', '124', '05', '2052', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19118, to_date('04-05-2052', 'dd-mm-yyyy'), '6', '04', '125', '05', '2052', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19119, to_date('05-05-2052', 'dd-mm-yyyy'), '7', '05', '126', '05', '2052', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19120, to_date('06-05-2052', 'dd-mm-yyyy'), '1', '06', '127', '05', '2052', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19121, to_date('07-05-2052', 'dd-mm-yyyy'), '2', '07', '128', '05', '2052', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19122, to_date('08-05-2052', 'dd-mm-yyyy'), '3', '08', '129', '05', '2052', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19123, to_date('09-05-2052', 'dd-mm-yyyy'), '4', '09', '130', '05', '2052', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19124, to_date('10-05-2052', 'dd-mm-yyyy'), '5', '10', '131', '05', '2052', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19125, to_date('11-05-2052', 'dd-mm-yyyy'), '6', '11', '132', '05', '2052', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19126, to_date('12-05-2052', 'dd-mm-yyyy'), '7', '12', '133', '05', '2052', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19127, to_date('13-05-2052', 'dd-mm-yyyy'), '1', '13', '134', '05', '2052', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19128, to_date('14-05-2052', 'dd-mm-yyyy'), '2', '14', '135', '05', '2052', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19129, to_date('15-05-2052', 'dd-mm-yyyy'), '3', '15', '136', '05', '2052', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19130, to_date('16-05-2052', 'dd-mm-yyyy'), '4', '16', '137', '05', '2052', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19131, to_date('17-05-2052', 'dd-mm-yyyy'), '5', '17', '138', '05', '2052', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19132, to_date('18-05-2052', 'dd-mm-yyyy'), '6', '18', '139', '05', '2052', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19133, to_date('19-05-2052', 'dd-mm-yyyy'), '7', '19', '140', '05', '2052', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19134, to_date('20-05-2052', 'dd-mm-yyyy'), '1', '20', '141', '05', '2052', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19135, to_date('21-05-2052', 'dd-mm-yyyy'), '2', '21', '142', '05', '2052', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19136, to_date('22-05-2052', 'dd-mm-yyyy'), '3', '22', '143', '05', '2052', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19137, to_date('23-05-2052', 'dd-mm-yyyy'), '4', '23', '144', '05', '2052', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19138, to_date('24-05-2052', 'dd-mm-yyyy'), '5', '24', '145', '05', '2052', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19139, to_date('25-05-2052', 'dd-mm-yyyy'), '6', '25', '146', '05', '2052', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19140, to_date('26-05-2052', 'dd-mm-yyyy'), '7', '26', '147', '05', '2052', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19141, to_date('27-05-2052', 'dd-mm-yyyy'), '1', '27', '148', '05', '2052', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19142, to_date('28-05-2052', 'dd-mm-yyyy'), '2', '28', '149', '05', '2052', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19143, to_date('29-05-2052', 'dd-mm-yyyy'), '3', '29', '150', '05', '2052', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19144, to_date('30-05-2052', 'dd-mm-yyyy'), '4', '30', '151', '05', '2052', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19145, to_date('31-05-2052', 'dd-mm-yyyy'), '5', '31', '152', '05', '2052', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19146, to_date('01-06-2052', 'dd-mm-yyyy'), '6', '01', '153', '06', '2052', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19147, to_date('02-06-2052', 'dd-mm-yyyy'), '7', '02', '154', '06', '2052', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19148, to_date('03-06-2052', 'dd-mm-yyyy'), '1', '03', '155', '06', '2052', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19149, to_date('04-06-2052', 'dd-mm-yyyy'), '2', '04', '156', '06', '2052', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19150, to_date('05-06-2052', 'dd-mm-yyyy'), '3', '05', '157', '06', '2052', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19151, to_date('06-06-2052', 'dd-mm-yyyy'), '4', '06', '158', '06', '2052', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19152, to_date('07-06-2052', 'dd-mm-yyyy'), '5', '07', '159', '06', '2052', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19153, to_date('08-06-2052', 'dd-mm-yyyy'), '6', '08', '160', '06', '2052', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19154, to_date('09-06-2052', 'dd-mm-yyyy'), '7', '09', '161', '06', '2052', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19155, to_date('10-06-2052', 'dd-mm-yyyy'), '1', '10', '162', '06', '2052', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19156, to_date('11-06-2052', 'dd-mm-yyyy'), '2', '11', '163', '06', '2052', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19157, to_date('12-06-2052', 'dd-mm-yyyy'), '3', '12', '164', '06', '2052', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19158, to_date('13-06-2052', 'dd-mm-yyyy'), '4', '13', '165', '06', '2052', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19159, to_date('14-06-2052', 'dd-mm-yyyy'), '5', '14', '166', '06', '2052', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19160, to_date('15-06-2052', 'dd-mm-yyyy'), '6', '15', '167', '06', '2052', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19161, to_date('16-06-2052', 'dd-mm-yyyy'), '7', '16', '168', '06', '2052', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19162, to_date('17-06-2052', 'dd-mm-yyyy'), '1', '17', '169', '06', '2052', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19163, to_date('18-06-2052', 'dd-mm-yyyy'), '2', '18', '170', '06', '2052', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19164, to_date('19-06-2052', 'dd-mm-yyyy'), '3', '19', '171', '06', '2052', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19165, to_date('20-06-2052', 'dd-mm-yyyy'), '4', '20', '172', '06', '2052', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19166, to_date('21-06-2052', 'dd-mm-yyyy'), '5', '21', '173', '06', '2052', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19167, to_date('22-06-2052', 'dd-mm-yyyy'), '6', '22', '174', '06', '2052', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19168, to_date('23-06-2052', 'dd-mm-yyyy'), '7', '23', '175', '06', '2052', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19169, to_date('24-06-2052', 'dd-mm-yyyy'), '1', '24', '176', '06', '2052', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19170, to_date('25-06-2052', 'dd-mm-yyyy'), '2', '25', '177', '06', '2052', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19171, to_date('26-06-2052', 'dd-mm-yyyy'), '3', '26', '178', '06', '2052', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19172, to_date('27-06-2052', 'dd-mm-yyyy'), '4', '27', '179', '06', '2052', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19173, to_date('28-06-2052', 'dd-mm-yyyy'), '5', '28', '180', '06', '2052', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19174, to_date('29-06-2052', 'dd-mm-yyyy'), '6', '29', '181', '06', '2052', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19175, to_date('30-06-2052', 'dd-mm-yyyy'), '7', '30', '182', '06', '2052', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19176, to_date('01-07-2052', 'dd-mm-yyyy'), '1', '01', '183', '07', '2052', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19177, to_date('02-07-2052', 'dd-mm-yyyy'), '2', '02', '184', '07', '2052', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19178, to_date('03-07-2052', 'dd-mm-yyyy'), '3', '03', '185', '07', '2052', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19179, to_date('04-07-2052', 'dd-mm-yyyy'), '4', '04', '186', '07', '2052', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19180, to_date('05-07-2052', 'dd-mm-yyyy'), '5', '05', '187', '07', '2052', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19181, to_date('06-07-2052', 'dd-mm-yyyy'), '6', '06', '188', '07', '2052', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19182, to_date('07-07-2052', 'dd-mm-yyyy'), '7', '07', '189', '07', '2052', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19183, to_date('08-07-2052', 'dd-mm-yyyy'), '1', '08', '190', '07', '2052', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19184, to_date('09-07-2052', 'dd-mm-yyyy'), '2', '09', '191', '07', '2052', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19185, to_date('10-07-2052', 'dd-mm-yyyy'), '3', '10', '192', '07', '2052', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19186, to_date('11-07-2052', 'dd-mm-yyyy'), '4', '11', '193', '07', '2052', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19187, to_date('12-07-2052', 'dd-mm-yyyy'), '5', '12', '194', '07', '2052', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19188, to_date('13-07-2052', 'dd-mm-yyyy'), '6', '13', '195', '07', '2052', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19189, to_date('14-07-2052', 'dd-mm-yyyy'), '7', '14', '196', '07', '2052', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19190, to_date('15-07-2052', 'dd-mm-yyyy'), '1', '15', '197', '07', '2052', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19191, to_date('16-07-2052', 'dd-mm-yyyy'), '2', '16', '198', '07', '2052', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19192, to_date('17-07-2052', 'dd-mm-yyyy'), '3', '17', '199', '07', '2052', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19193, to_date('18-07-2052', 'dd-mm-yyyy'), '4', '18', '200', '07', '2052', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19194, to_date('19-07-2052', 'dd-mm-yyyy'), '5', '19', '201', '07', '2052', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19195, to_date('20-07-2052', 'dd-mm-yyyy'), '6', '20', '202', '07', '2052', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19196, to_date('21-07-2052', 'dd-mm-yyyy'), '7', '21', '203', '07', '2052', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19197, to_date('22-07-2052', 'dd-mm-yyyy'), '1', '22', '204', '07', '2052', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19198, to_date('23-07-2052', 'dd-mm-yyyy'), '2', '23', '205', '07', '2052', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19199, to_date('24-07-2052', 'dd-mm-yyyy'), '3', '24', '206', '07', '2052', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19200, to_date('25-07-2052', 'dd-mm-yyyy'), '4', '25', '207', '07', '2052', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19201, to_date('26-07-2052', 'dd-mm-yyyy'), '5', '26', '208', '07', '2052', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19202, to_date('27-07-2052', 'dd-mm-yyyy'), '6', '27', '209', '07', '2052', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19203, to_date('28-07-2052', 'dd-mm-yyyy'), '7', '28', '210', '07', '2052', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19204, to_date('29-07-2052', 'dd-mm-yyyy'), '1', '29', '211', '07', '2052', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19205, to_date('30-07-2052', 'dd-mm-yyyy'), '2', '30', '212', '07', '2052', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19206, to_date('31-07-2052', 'dd-mm-yyyy'), '3', '31', '213', '07', '2052', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19207, to_date('01-08-2052', 'dd-mm-yyyy'), '4', '01', '214', '08', '2052', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19208, to_date('02-08-2052', 'dd-mm-yyyy'), '5', '02', '215', '08', '2052', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19209, to_date('03-08-2052', 'dd-mm-yyyy'), '6', '03', '216', '08', '2052', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19210, to_date('04-08-2052', 'dd-mm-yyyy'), '7', '04', '217', '08', '2052', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19211, to_date('05-08-2052', 'dd-mm-yyyy'), '1', '05', '218', '08', '2052', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19212, to_date('06-08-2052', 'dd-mm-yyyy'), '2', '06', '219', '08', '2052', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19213, to_date('07-08-2052', 'dd-mm-yyyy'), '3', '07', '220', '08', '2052', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19214, to_date('08-08-2052', 'dd-mm-yyyy'), '4', '08', '221', '08', '2052', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19215, to_date('09-08-2052', 'dd-mm-yyyy'), '5', '09', '222', '08', '2052', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19216, to_date('10-08-2052', 'dd-mm-yyyy'), '6', '10', '223', '08', '2052', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19217, to_date('11-08-2052', 'dd-mm-yyyy'), '7', '11', '224', '08', '2052', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19218, to_date('12-08-2052', 'dd-mm-yyyy'), '1', '12', '225', '08', '2052', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19219, to_date('13-08-2052', 'dd-mm-yyyy'), '2', '13', '226', '08', '2052', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19220, to_date('14-08-2052', 'dd-mm-yyyy'), '3', '14', '227', '08', '2052', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19221, to_date('15-08-2052', 'dd-mm-yyyy'), '4', '15', '228', '08', '2052', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19222, to_date('16-08-2052', 'dd-mm-yyyy'), '5', '16', '229', '08', '2052', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19223, to_date('17-08-2052', 'dd-mm-yyyy'), '6', '17', '230', '08', '2052', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19224, to_date('18-08-2052', 'dd-mm-yyyy'), '7', '18', '231', '08', '2052', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19225, to_date('19-08-2052', 'dd-mm-yyyy'), '1', '19', '232', '08', '2052', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19226, to_date('20-08-2052', 'dd-mm-yyyy'), '2', '20', '233', '08', '2052', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19227, to_date('21-08-2052', 'dd-mm-yyyy'), '3', '21', '234', '08', '2052', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19228, to_date('22-08-2052', 'dd-mm-yyyy'), '4', '22', '235', '08', '2052', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19229, to_date('23-08-2052', 'dd-mm-yyyy'), '5', '23', '236', '08', '2052', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19230, to_date('24-08-2052', 'dd-mm-yyyy'), '6', '24', '237', '08', '2052', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19231, to_date('25-08-2052', 'dd-mm-yyyy'), '7', '25', '238', '08', '2052', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19232, to_date('26-08-2052', 'dd-mm-yyyy'), '1', '26', '239', '08', '2052', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19233, to_date('27-08-2052', 'dd-mm-yyyy'), '2', '27', '240', '08', '2052', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19234, to_date('28-08-2052', 'dd-mm-yyyy'), '3', '28', '241', '08', '2052', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19235, to_date('29-08-2052', 'dd-mm-yyyy'), '4', '29', '242', '08', '2052', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19236, to_date('30-08-2052', 'dd-mm-yyyy'), '5', '30', '243', '08', '2052', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19237, to_date('31-08-2052', 'dd-mm-yyyy'), '6', '31', '244', '08', '2052', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19238, to_date('01-09-2052', 'dd-mm-yyyy'), '7', '01', '245', '09', '2052', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19239, to_date('02-09-2052', 'dd-mm-yyyy'), '1', '02', '246', '09', '2052', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19240, to_date('03-09-2052', 'dd-mm-yyyy'), '2', '03', '247', '09', '2052', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19241, to_date('04-09-2052', 'dd-mm-yyyy'), '3', '04', '248', '09', '2052', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19242, to_date('05-09-2052', 'dd-mm-yyyy'), '4', '05', '249', '09', '2052', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19243, to_date('06-09-2052', 'dd-mm-yyyy'), '5', '06', '250', '09', '2052', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19244, to_date('07-09-2052', 'dd-mm-yyyy'), '6', '07', '251', '09', '2052', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19245, to_date('08-09-2052', 'dd-mm-yyyy'), '7', '08', '252', '09', '2052', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19246, to_date('09-09-2052', 'dd-mm-yyyy'), '1', '09', '253', '09', '2052', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19247, to_date('10-09-2052', 'dd-mm-yyyy'), '2', '10', '254', '09', '2052', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19248, to_date('11-09-2052', 'dd-mm-yyyy'), '3', '11', '255', '09', '2052', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19249, to_date('12-09-2052', 'dd-mm-yyyy'), '4', '12', '256', '09', '2052', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19250, to_date('13-09-2052', 'dd-mm-yyyy'), '5', '13', '257', '09', '2052', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19251, to_date('14-09-2052', 'dd-mm-yyyy'), '6', '14', '258', '09', '2052', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19252, to_date('15-09-2052', 'dd-mm-yyyy'), '7', '15', '259', '09', '2052', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19253, to_date('16-09-2052', 'dd-mm-yyyy'), '1', '16', '260', '09', '2052', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19254, to_date('17-09-2052', 'dd-mm-yyyy'), '2', '17', '261', '09', '2052', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19255, to_date('18-09-2052', 'dd-mm-yyyy'), '3', '18', '262', '09', '2052', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19256, to_date('19-09-2052', 'dd-mm-yyyy'), '4', '19', '263', '09', '2052', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19257, to_date('20-09-2052', 'dd-mm-yyyy'), '5', '20', '264', '09', '2052', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19258, to_date('21-09-2052', 'dd-mm-yyyy'), '6', '21', '265', '09', '2052', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19259, to_date('22-09-2052', 'dd-mm-yyyy'), '7', '22', '266', '09', '2052', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19260, to_date('23-09-2052', 'dd-mm-yyyy'), '1', '23', '267', '09', '2052', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19261, to_date('24-09-2052', 'dd-mm-yyyy'), '2', '24', '268', '09', '2052', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19262, to_date('25-09-2052', 'dd-mm-yyyy'), '3', '25', '269', '09', '2052', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19263, to_date('26-09-2052', 'dd-mm-yyyy'), '4', '26', '270', '09', '2052', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19264, to_date('27-09-2052', 'dd-mm-yyyy'), '5', '27', '271', '09', '2052', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19265, to_date('28-09-2052', 'dd-mm-yyyy'), '6', '28', '272', '09', '2052', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19266, to_date('29-09-2052', 'dd-mm-yyyy'), '7', '29', '273', '09', '2052', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19267, to_date('30-09-2052', 'dd-mm-yyyy'), '1', '30', '274', '09', '2052', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19268, to_date('01-10-2052', 'dd-mm-yyyy'), '2', '01', '275', '10', '2052', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19269, to_date('02-10-2052', 'dd-mm-yyyy'), '3', '02', '276', '10', '2052', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19270, to_date('03-10-2052', 'dd-mm-yyyy'), '4', '03', '277', '10', '2052', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19271, to_date('04-10-2052', 'dd-mm-yyyy'), '5', '04', '278', '10', '2052', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19272, to_date('05-10-2052', 'dd-mm-yyyy'), '6', '05', '279', '10', '2052', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19273, to_date('06-10-2052', 'dd-mm-yyyy'), '7', '06', '280', '10', '2052', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19274, to_date('07-10-2052', 'dd-mm-yyyy'), '1', '07', '281', '10', '2052', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19275, to_date('08-10-2052', 'dd-mm-yyyy'), '2', '08', '282', '10', '2052', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19276, to_date('09-10-2052', 'dd-mm-yyyy'), '3', '09', '283', '10', '2052', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19277, to_date('10-10-2052', 'dd-mm-yyyy'), '4', '10', '284', '10', '2052', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19278, to_date('11-10-2052', 'dd-mm-yyyy'), '5', '11', '285', '10', '2052', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19279, to_date('12-10-2052', 'dd-mm-yyyy'), '6', '12', '286', '10', '2052', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19280, to_date('13-10-2052', 'dd-mm-yyyy'), '7', '13', '287', '10', '2052', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19281, to_date('14-10-2052', 'dd-mm-yyyy'), '1', '14', '288', '10', '2052', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19282, to_date('15-10-2052', 'dd-mm-yyyy'), '2', '15', '289', '10', '2052', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19283, to_date('16-10-2052', 'dd-mm-yyyy'), '3', '16', '290', '10', '2052', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19284, to_date('17-10-2052', 'dd-mm-yyyy'), '4', '17', '291', '10', '2052', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19285, to_date('18-10-2052', 'dd-mm-yyyy'), '5', '18', '292', '10', '2052', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19286, to_date('19-10-2052', 'dd-mm-yyyy'), '6', '19', '293', '10', '2052', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19287, to_date('20-10-2052', 'dd-mm-yyyy'), '7', '20', '294', '10', '2052', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19288, to_date('21-10-2052', 'dd-mm-yyyy'), '1', '21', '295', '10', '2052', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19289, to_date('22-10-2052', 'dd-mm-yyyy'), '2', '22', '296', '10', '2052', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19290, to_date('23-10-2052', 'dd-mm-yyyy'), '3', '23', '297', '10', '2052', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19291, to_date('24-10-2052', 'dd-mm-yyyy'), '4', '24', '298', '10', '2052', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19292, to_date('25-10-2052', 'dd-mm-yyyy'), '5', '25', '299', '10', '2052', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19293, to_date('26-10-2052', 'dd-mm-yyyy'), '6', '26', '300', '10', '2052', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19294, to_date('27-10-2052', 'dd-mm-yyyy'), '7', '27', '301', '10', '2052', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19295, to_date('28-10-2052', 'dd-mm-yyyy'), '1', '28', '302', '10', '2052', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19296, to_date('29-10-2052', 'dd-mm-yyyy'), '2', '29', '303', '10', '2052', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19297, to_date('30-10-2052', 'dd-mm-yyyy'), '3', '30', '304', '10', '2052', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19298, to_date('31-10-2052', 'dd-mm-yyyy'), '4', '31', '305', '10', '2052', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19299, to_date('01-11-2052', 'dd-mm-yyyy'), '5', '01', '306', '11', '2052', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19300, to_date('02-11-2052', 'dd-mm-yyyy'), '6', '02', '307', '11', '2052', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19301, to_date('03-11-2052', 'dd-mm-yyyy'), '7', '03', '308', '11', '2052', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19302, to_date('04-11-2052', 'dd-mm-yyyy'), '1', '04', '309', '11', '2052', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19303, to_date('05-11-2052', 'dd-mm-yyyy'), '2', '05', '310', '11', '2052', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19304, to_date('06-11-2052', 'dd-mm-yyyy'), '3', '06', '311', '11', '2052', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19305, to_date('07-11-2052', 'dd-mm-yyyy'), '4', '07', '312', '11', '2052', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19306, to_date('08-11-2052', 'dd-mm-yyyy'), '5', '08', '313', '11', '2052', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19307, to_date('09-11-2052', 'dd-mm-yyyy'), '6', '09', '314', '11', '2052', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19308, to_date('10-11-2052', 'dd-mm-yyyy'), '7', '10', '315', '11', '2052', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19309, to_date('11-11-2052', 'dd-mm-yyyy'), '1', '11', '316', '11', '2052', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19310, to_date('12-11-2052', 'dd-mm-yyyy'), '2', '12', '317', '11', '2052', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19311, to_date('13-11-2052', 'dd-mm-yyyy'), '3', '13', '318', '11', '2052', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19312, to_date('14-11-2052', 'dd-mm-yyyy'), '4', '14', '319', '11', '2052', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19313, to_date('15-11-2052', 'dd-mm-yyyy'), '5', '15', '320', '11', '2052', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19314, to_date('16-11-2052', 'dd-mm-yyyy'), '6', '16', '321', '11', '2052', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19315, to_date('17-11-2052', 'dd-mm-yyyy'), '7', '17', '322', '11', '2052', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19316, to_date('18-11-2052', 'dd-mm-yyyy'), '1', '18', '323', '11', '2052', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19317, to_date('19-11-2052', 'dd-mm-yyyy'), '2', '19', '324', '11', '2052', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19318, to_date('20-11-2052', 'dd-mm-yyyy'), '3', '20', '325', '11', '2052', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19319, to_date('21-11-2052', 'dd-mm-yyyy'), '4', '21', '326', '11', '2052', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19320, to_date('22-11-2052', 'dd-mm-yyyy'), '5', '22', '327', '11', '2052', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19321, to_date('23-11-2052', 'dd-mm-yyyy'), '6', '23', '328', '11', '2052', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19322, to_date('24-11-2052', 'dd-mm-yyyy'), '7', '24', '329', '11', '2052', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19323, to_date('25-11-2052', 'dd-mm-yyyy'), '1', '25', '330', '11', '2052', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19324, to_date('26-11-2052', 'dd-mm-yyyy'), '2', '26', '331', '11', '2052', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19325, to_date('27-11-2052', 'dd-mm-yyyy'), '3', '27', '332', '11', '2052', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19326, to_date('28-11-2052', 'dd-mm-yyyy'), '4', '28', '333', '11', '2052', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19327, to_date('29-11-2052', 'dd-mm-yyyy'), '5', '29', '334', '11', '2052', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19328, to_date('30-11-2052', 'dd-mm-yyyy'), '6', '30', '335', '11', '2052', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19329, to_date('01-12-2052', 'dd-mm-yyyy'), '7', '01', '336', '12', '2052', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19330, to_date('02-12-2052', 'dd-mm-yyyy'), '1', '02', '337', '12', '2052', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19331, to_date('03-12-2052', 'dd-mm-yyyy'), '2', '03', '338', '12', '2052', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19332, to_date('04-12-2052', 'dd-mm-yyyy'), '3', '04', '339', '12', '2052', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19333, to_date('05-12-2052', 'dd-mm-yyyy'), '4', '05', '340', '12', '2052', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19334, to_date('06-12-2052', 'dd-mm-yyyy'), '5', '06', '341', '12', '2052', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19335, to_date('07-12-2052', 'dd-mm-yyyy'), '6', '07', '342', '12', '2052', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19336, to_date('08-12-2052', 'dd-mm-yyyy'), '7', '08', '343', '12', '2052', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19337, to_date('09-12-2052', 'dd-mm-yyyy'), '1', '09', '344', '12', '2052', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19338, to_date('10-12-2052', 'dd-mm-yyyy'), '2', '10', '345', '12', '2052', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19339, to_date('11-12-2052', 'dd-mm-yyyy'), '3', '11', '346', '12', '2052', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19340, to_date('12-12-2052', 'dd-mm-yyyy'), '4', '12', '347', '12', '2052', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19341, to_date('13-12-2052', 'dd-mm-yyyy'), '5', '13', '348', '12', '2052', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19342, to_date('14-12-2052', 'dd-mm-yyyy'), '6', '14', '349', '12', '2052', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19343, to_date('15-12-2052', 'dd-mm-yyyy'), '7', '15', '350', '12', '2052', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19344, to_date('16-12-2052', 'dd-mm-yyyy'), '1', '16', '351', '12', '2052', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19345, to_date('17-12-2052', 'dd-mm-yyyy'), '2', '17', '352', '12', '2052', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19346, to_date('18-12-2052', 'dd-mm-yyyy'), '3', '18', '353', '12', '2052', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19347, to_date('19-12-2052', 'dd-mm-yyyy'), '4', '19', '354', '12', '2052', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19348, to_date('20-12-2052', 'dd-mm-yyyy'), '5', '20', '355', '12', '2052', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19349, to_date('21-12-2052', 'dd-mm-yyyy'), '6', '21', '356', '12', '2052', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19350, to_date('22-12-2052', 'dd-mm-yyyy'), '7', '22', '357', '12', '2052', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19351, to_date('23-12-2052', 'dd-mm-yyyy'), '1', '23', '358', '12', '2052', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19352, to_date('24-12-2052', 'dd-mm-yyyy'), '2', '24', '359', '12', '2052', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19353, to_date('25-12-2052', 'dd-mm-yyyy'), '3', '25', '360', '12', '2052', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19354, to_date('26-12-2052', 'dd-mm-yyyy'), '4', '26', '361', '12', '2052', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19355, to_date('27-12-2052', 'dd-mm-yyyy'), '5', '27', '362', '12', '2052', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19356, to_date('28-12-2052', 'dd-mm-yyyy'), '6', '28', '363', '12', '2052', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19357, to_date('29-12-2052', 'dd-mm-yyyy'), '7', '29', '364', '12', '2052', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19358, to_date('30-12-2052', 'dd-mm-yyyy'), '1', '30', '365', '12', '2052', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19359, to_date('31-12-2052', 'dd-mm-yyyy'), '2', '31', '366', '12', '2052', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19360, to_date('01-01-2053', 'dd-mm-yyyy'), '3', '01', '001', '01', '2053', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19361, to_date('02-01-2053', 'dd-mm-yyyy'), '4', '02', '002', '01', '2053', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19362, to_date('03-01-2053', 'dd-mm-yyyy'), '5', '03', '003', '01', '2053', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19363, to_date('04-01-2053', 'dd-mm-yyyy'), '6', '04', '004', '01', '2053', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19364, to_date('05-01-2053', 'dd-mm-yyyy'), '7', '05', '005', '01', '2053', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19365, to_date('06-01-2053', 'dd-mm-yyyy'), '1', '06', '006', '01', '2053', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19366, to_date('07-01-2053', 'dd-mm-yyyy'), '2', '07', '007', '01', '2053', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19367, to_date('08-01-2053', 'dd-mm-yyyy'), '3', '08', '008', '01', '2053', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19368, to_date('09-01-2053', 'dd-mm-yyyy'), '4', '09', '009', '01', '2053', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19369, to_date('10-01-2053', 'dd-mm-yyyy'), '5', '10', '010', '01', '2053', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19370, to_date('11-01-2053', 'dd-mm-yyyy'), '6', '11', '011', '01', '2053', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19371, to_date('12-01-2053', 'dd-mm-yyyy'), '7', '12', '012', '01', '2053', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19372, to_date('13-01-2053', 'dd-mm-yyyy'), '1', '13', '013', '01', '2053', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19373, to_date('14-01-2053', 'dd-mm-yyyy'), '2', '14', '014', '01', '2053', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19374, to_date('15-01-2053', 'dd-mm-yyyy'), '3', '15', '015', '01', '2053', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19375, to_date('16-01-2053', 'dd-mm-yyyy'), '4', '16', '016', '01', '2053', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19376, to_date('17-01-2053', 'dd-mm-yyyy'), '5', '17', '017', '01', '2053', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19377, to_date('18-01-2053', 'dd-mm-yyyy'), '6', '18', '018', '01', '2053', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19378, to_date('19-01-2053', 'dd-mm-yyyy'), '7', '19', '019', '01', '2053', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19379, to_date('20-01-2053', 'dd-mm-yyyy'), '1', '20', '020', '01', '2053', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19380, to_date('21-01-2053', 'dd-mm-yyyy'), '2', '21', '021', '01', '2053', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19381, to_date('22-01-2053', 'dd-mm-yyyy'), '3', '22', '022', '01', '2053', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19382, to_date('23-01-2053', 'dd-mm-yyyy'), '4', '23', '023', '01', '2053', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19383, to_date('24-01-2053', 'dd-mm-yyyy'), '5', '24', '024', '01', '2053', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19384, to_date('25-01-2053', 'dd-mm-yyyy'), '6', '25', '025', '01', '2053', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19385, to_date('26-01-2053', 'dd-mm-yyyy'), '7', '26', '026', '01', '2053', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19386, to_date('27-01-2053', 'dd-mm-yyyy'), '1', '27', '027', '01', '2053', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19387, to_date('28-01-2053', 'dd-mm-yyyy'), '2', '28', '028', '01', '2053', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19388, to_date('29-01-2053', 'dd-mm-yyyy'), '3', '29', '029', '01', '2053', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19389, to_date('30-01-2053', 'dd-mm-yyyy'), '4', '30', '030', '01', '2053', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19390, to_date('31-01-2053', 'dd-mm-yyyy'), '5', '31', '031', '01', '2053', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19391, to_date('01-02-2053', 'dd-mm-yyyy'), '6', '01', '032', '02', '2053', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19392, to_date('02-02-2053', 'dd-mm-yyyy'), '7', '02', '033', '02', '2053', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19393, to_date('03-02-2053', 'dd-mm-yyyy'), '1', '03', '034', '02', '2053', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19394, to_date('04-02-2053', 'dd-mm-yyyy'), '2', '04', '035', '02', '2053', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19395, to_date('05-02-2053', 'dd-mm-yyyy'), '3', '05', '036', '02', '2053', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19396, to_date('06-02-2053', 'dd-mm-yyyy'), '4', '06', '037', '02', '2053', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19397, to_date('07-02-2053', 'dd-mm-yyyy'), '5', '07', '038', '02', '2053', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19398, to_date('08-02-2053', 'dd-mm-yyyy'), '6', '08', '039', '02', '2053', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19399, to_date('09-02-2053', 'dd-mm-yyyy'), '7', '09', '040', '02', '2053', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19400, to_date('10-02-2053', 'dd-mm-yyyy'), '1', '10', '041', '02', '2053', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19401, to_date('11-02-2053', 'dd-mm-yyyy'), '2', '11', '042', '02', '2053', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19402, to_date('12-02-2053', 'dd-mm-yyyy'), '3', '12', '043', '02', '2053', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19403, to_date('13-02-2053', 'dd-mm-yyyy'), '4', '13', '044', '02', '2053', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19404, to_date('14-02-2053', 'dd-mm-yyyy'), '5', '14', '045', '02', '2053', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19405, to_date('15-02-2053', 'dd-mm-yyyy'), '6', '15', '046', '02', '2053', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19406, to_date('16-02-2053', 'dd-mm-yyyy'), '7', '16', '047', '02', '2053', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19407, to_date('17-02-2053', 'dd-mm-yyyy'), '1', '17', '048', '02', '2053', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19408, to_date('18-02-2053', 'dd-mm-yyyy'), '2', '18', '049', '02', '2053', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19409, to_date('19-02-2053', 'dd-mm-yyyy'), '3', '19', '050', '02', '2053', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19410, to_date('20-02-2053', 'dd-mm-yyyy'), '4', '20', '051', '02', '2053', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19411, to_date('21-02-2053', 'dd-mm-yyyy'), '5', '21', '052', '02', '2053', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19412, to_date('22-02-2053', 'dd-mm-yyyy'), '6', '22', '053', '02', '2053', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19413, to_date('23-02-2053', 'dd-mm-yyyy'), '7', '23', '054', '02', '2053', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19414, to_date('24-02-2053', 'dd-mm-yyyy'), '1', '24', '055', '02', '2053', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19415, to_date('25-02-2053', 'dd-mm-yyyy'), '2', '25', '056', '02', '2053', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19416, to_date('26-02-2053', 'dd-mm-yyyy'), '3', '26', '057', '02', '2053', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19417, to_date('27-02-2053', 'dd-mm-yyyy'), '4', '27', '058', '02', '2053', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19418, to_date('28-02-2053', 'dd-mm-yyyy'), '5', '28', '059', '02', '2053', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19419, to_date('01-03-2053', 'dd-mm-yyyy'), '6', '01', '060', '03', '2053', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19420, to_date('02-03-2053', 'dd-mm-yyyy'), '7', '02', '061', '03', '2053', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19421, to_date('03-03-2053', 'dd-mm-yyyy'), '1', '03', '062', '03', '2053', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19422, to_date('04-03-2053', 'dd-mm-yyyy'), '2', '04', '063', '03', '2053', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19423, to_date('05-03-2053', 'dd-mm-yyyy'), '3', '05', '064', '03', '2053', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19424, to_date('06-03-2053', 'dd-mm-yyyy'), '4', '06', '065', '03', '2053', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19425, to_date('07-03-2053', 'dd-mm-yyyy'), '5', '07', '066', '03', '2053', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19426, to_date('08-03-2053', 'dd-mm-yyyy'), '6', '08', '067', '03', '2053', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19427, to_date('09-03-2053', 'dd-mm-yyyy'), '7', '09', '068', '03', '2053', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19428, to_date('10-03-2053', 'dd-mm-yyyy'), '1', '10', '069', '03', '2053', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19429, to_date('11-03-2053', 'dd-mm-yyyy'), '2', '11', '070', '03', '2053', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19430, to_date('12-03-2053', 'dd-mm-yyyy'), '3', '12', '071', '03', '2053', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19431, to_date('13-03-2053', 'dd-mm-yyyy'), '4', '13', '072', '03', '2053', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19432, to_date('14-03-2053', 'dd-mm-yyyy'), '5', '14', '073', '03', '2053', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19433, to_date('15-03-2053', 'dd-mm-yyyy'), '6', '15', '074', '03', '2053', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19434, to_date('16-03-2053', 'dd-mm-yyyy'), '7', '16', '075', '03', '2053', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19435, to_date('17-03-2053', 'dd-mm-yyyy'), '1', '17', '076', '03', '2053', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19436, to_date('18-03-2053', 'dd-mm-yyyy'), '2', '18', '077', '03', '2053', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19437, to_date('19-03-2053', 'dd-mm-yyyy'), '3', '19', '078', '03', '2053', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19438, to_date('20-03-2053', 'dd-mm-yyyy'), '4', '20', '079', '03', '2053', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19439, to_date('21-03-2053', 'dd-mm-yyyy'), '5', '21', '080', '03', '2053', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19440, to_date('22-03-2053', 'dd-mm-yyyy'), '6', '22', '081', '03', '2053', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19441, to_date('23-03-2053', 'dd-mm-yyyy'), '7', '23', '082', '03', '2053', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19442, to_date('24-03-2053', 'dd-mm-yyyy'), '1', '24', '083', '03', '2053', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19443, to_date('25-03-2053', 'dd-mm-yyyy'), '2', '25', '084', '03', '2053', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19444, to_date('26-03-2053', 'dd-mm-yyyy'), '3', '26', '085', '03', '2053', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19445, to_date('27-03-2053', 'dd-mm-yyyy'), '4', '27', '086', '03', '2053', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19446, to_date('28-03-2053', 'dd-mm-yyyy'), '5', '28', '087', '03', '2053', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19447, to_date('29-03-2053', 'dd-mm-yyyy'), '6', '29', '088', '03', '2053', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19448, to_date('30-03-2053', 'dd-mm-yyyy'), '7', '30', '089', '03', '2053', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19449, to_date('31-03-2053', 'dd-mm-yyyy'), '1', '31', '090', '03', '2053', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19450, to_date('01-04-2053', 'dd-mm-yyyy'), '2', '01', '091', '04', '2053', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19451, to_date('02-04-2053', 'dd-mm-yyyy'), '3', '02', '092', '04', '2053', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19452, to_date('03-04-2053', 'dd-mm-yyyy'), '4', '03', '093', '04', '2053', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19453, to_date('04-04-2053', 'dd-mm-yyyy'), '5', '04', '094', '04', '2053', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19454, to_date('05-04-2053', 'dd-mm-yyyy'), '6', '05', '095', '04', '2053', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19455, to_date('06-04-2053', 'dd-mm-yyyy'), '7', '06', '096', '04', '2053', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19456, to_date('07-04-2053', 'dd-mm-yyyy'), '1', '07', '097', '04', '2053', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19457, to_date('08-04-2053', 'dd-mm-yyyy'), '2', '08', '098', '04', '2053', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19458, to_date('09-04-2053', 'dd-mm-yyyy'), '3', '09', '099', '04', '2053', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19459, to_date('10-04-2053', 'dd-mm-yyyy'), '4', '10', '100', '04', '2053', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19460, to_date('11-04-2053', 'dd-mm-yyyy'), '5', '11', '101', '04', '2053', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19461, to_date('12-04-2053', 'dd-mm-yyyy'), '6', '12', '102', '04', '2053', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19462, to_date('13-04-2053', 'dd-mm-yyyy'), '7', '13', '103', '04', '2053', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19463, to_date('14-04-2053', 'dd-mm-yyyy'), '1', '14', '104', '04', '2053', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19464, to_date('15-04-2053', 'dd-mm-yyyy'), '2', '15', '105', '04', '2053', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19465, to_date('16-04-2053', 'dd-mm-yyyy'), '3', '16', '106', '04', '2053', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19466, to_date('17-04-2053', 'dd-mm-yyyy'), '4', '17', '107', '04', '2053', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19467, to_date('18-04-2053', 'dd-mm-yyyy'), '5', '18', '108', '04', '2053', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19468, to_date('19-04-2053', 'dd-mm-yyyy'), '6', '19', '109', '04', '2053', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19469, to_date('20-04-2053', 'dd-mm-yyyy'), '7', '20', '110', '04', '2053', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19470, to_date('21-04-2053', 'dd-mm-yyyy'), '1', '21', '111', '04', '2053', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
commit;
prompt 20000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19471, to_date('22-04-2053', 'dd-mm-yyyy'), '2', '22', '112', '04', '2053', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19472, to_date('23-04-2053', 'dd-mm-yyyy'), '3', '23', '113', '04', '2053', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19473, to_date('24-04-2053', 'dd-mm-yyyy'), '4', '24', '114', '04', '2053', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19474, to_date('25-04-2053', 'dd-mm-yyyy'), '5', '25', '115', '04', '2053', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19475, to_date('26-04-2053', 'dd-mm-yyyy'), '6', '26', '116', '04', '2053', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19476, to_date('27-04-2053', 'dd-mm-yyyy'), '7', '27', '117', '04', '2053', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19477, to_date('28-04-2053', 'dd-mm-yyyy'), '1', '28', '118', '04', '2053', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19478, to_date('29-04-2053', 'dd-mm-yyyy'), '2', '29', '119', '04', '2053', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12695, to_date('03-10-2034', 'dd-mm-yyyy'), '2', '03', '276', '10', '2034', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12696, to_date('04-10-2034', 'dd-mm-yyyy'), '3', '04', '277', '10', '2034', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12697, to_date('05-10-2034', 'dd-mm-yyyy'), '4', '05', '278', '10', '2034', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12698, to_date('06-10-2034', 'dd-mm-yyyy'), '5', '06', '279', '10', '2034', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12699, to_date('07-10-2034', 'dd-mm-yyyy'), '6', '07', '280', '10', '2034', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12700, to_date('08-10-2034', 'dd-mm-yyyy'), '7', '08', '281', '10', '2034', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12701, to_date('09-10-2034', 'dd-mm-yyyy'), '1', '09', '282', '10', '2034', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12702, to_date('10-10-2034', 'dd-mm-yyyy'), '2', '10', '283', '10', '2034', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12703, to_date('11-10-2034', 'dd-mm-yyyy'), '3', '11', '284', '10', '2034', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12704, to_date('12-10-2034', 'dd-mm-yyyy'), '4', '12', '285', '10', '2034', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12705, to_date('13-10-2034', 'dd-mm-yyyy'), '5', '13', '286', '10', '2034', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12706, to_date('14-10-2034', 'dd-mm-yyyy'), '6', '14', '287', '10', '2034', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12707, to_date('15-10-2034', 'dd-mm-yyyy'), '7', '15', '288', '10', '2034', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12708, to_date('16-10-2034', 'dd-mm-yyyy'), '1', '16', '289', '10', '2034', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12709, to_date('17-10-2034', 'dd-mm-yyyy'), '2', '17', '290', '10', '2034', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12710, to_date('18-10-2034', 'dd-mm-yyyy'), '3', '18', '291', '10', '2034', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12711, to_date('19-10-2034', 'dd-mm-yyyy'), '4', '19', '292', '10', '2034', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12712, to_date('20-10-2034', 'dd-mm-yyyy'), '5', '20', '293', '10', '2034', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12713, to_date('21-10-2034', 'dd-mm-yyyy'), '6', '21', '294', '10', '2034', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12714, to_date('22-10-2034', 'dd-mm-yyyy'), '7', '22', '295', '10', '2034', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12715, to_date('23-10-2034', 'dd-mm-yyyy'), '1', '23', '296', '10', '2034', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12716, to_date('24-10-2034', 'dd-mm-yyyy'), '2', '24', '297', '10', '2034', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12717, to_date('25-10-2034', 'dd-mm-yyyy'), '3', '25', '298', '10', '2034', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12718, to_date('26-10-2034', 'dd-mm-yyyy'), '4', '26', '299', '10', '2034', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12719, to_date('27-10-2034', 'dd-mm-yyyy'), '5', '27', '300', '10', '2034', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12720, to_date('28-10-2034', 'dd-mm-yyyy'), '6', '28', '301', '10', '2034', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12721, to_date('29-10-2034', 'dd-mm-yyyy'), '7', '29', '302', '10', '2034', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12722, to_date('30-10-2034', 'dd-mm-yyyy'), '1', '30', '303', '10', '2034', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12723, to_date('31-10-2034', 'dd-mm-yyyy'), '2', '31', '304', '10', '2034', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12724, to_date('01-11-2034', 'dd-mm-yyyy'), '3', '01', '305', '11', '2034', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12725, to_date('02-11-2034', 'dd-mm-yyyy'), '4', '02', '306', '11', '2034', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12726, to_date('03-11-2034', 'dd-mm-yyyy'), '5', '03', '307', '11', '2034', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12727, to_date('04-11-2034', 'dd-mm-yyyy'), '6', '04', '308', '11', '2034', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12728, to_date('05-11-2034', 'dd-mm-yyyy'), '7', '05', '309', '11', '2034', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12729, to_date('06-11-2034', 'dd-mm-yyyy'), '1', '06', '310', '11', '2034', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12730, to_date('07-11-2034', 'dd-mm-yyyy'), '2', '07', '311', '11', '2034', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12731, to_date('08-11-2034', 'dd-mm-yyyy'), '3', '08', '312', '11', '2034', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12732, to_date('09-11-2034', 'dd-mm-yyyy'), '4', '09', '313', '11', '2034', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12733, to_date('10-11-2034', 'dd-mm-yyyy'), '5', '10', '314', '11', '2034', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12734, to_date('11-11-2034', 'dd-mm-yyyy'), '6', '11', '315', '11', '2034', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12735, to_date('12-11-2034', 'dd-mm-yyyy'), '7', '12', '316', '11', '2034', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12736, to_date('13-11-2034', 'dd-mm-yyyy'), '1', '13', '317', '11', '2034', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12737, to_date('14-11-2034', 'dd-mm-yyyy'), '2', '14', '318', '11', '2034', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12738, to_date('15-11-2034', 'dd-mm-yyyy'), '3', '15', '319', '11', '2034', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12739, to_date('16-11-2034', 'dd-mm-yyyy'), '4', '16', '320', '11', '2034', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12740, to_date('17-11-2034', 'dd-mm-yyyy'), '5', '17', '321', '11', '2034', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12741, to_date('18-11-2034', 'dd-mm-yyyy'), '6', '18', '322', '11', '2034', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12742, to_date('19-11-2034', 'dd-mm-yyyy'), '7', '19', '323', '11', '2034', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12743, to_date('20-11-2034', 'dd-mm-yyyy'), '1', '20', '324', '11', '2034', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12744, to_date('21-11-2034', 'dd-mm-yyyy'), '2', '21', '325', '11', '2034', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12745, to_date('22-11-2034', 'dd-mm-yyyy'), '3', '22', '326', '11', '2034', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12746, to_date('23-11-2034', 'dd-mm-yyyy'), '4', '23', '327', '11', '2034', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12747, to_date('24-11-2034', 'dd-mm-yyyy'), '5', '24', '328', '11', '2034', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12748, to_date('25-11-2034', 'dd-mm-yyyy'), '6', '25', '329', '11', '2034', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12749, to_date('26-11-2034', 'dd-mm-yyyy'), '7', '26', '330', '11', '2034', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12750, to_date('27-11-2034', 'dd-mm-yyyy'), '1', '27', '331', '11', '2034', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12751, to_date('28-11-2034', 'dd-mm-yyyy'), '2', '28', '332', '11', '2034', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12752, to_date('29-11-2034', 'dd-mm-yyyy'), '3', '29', '333', '11', '2034', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12753, to_date('30-11-2034', 'dd-mm-yyyy'), '4', '30', '334', '11', '2034', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12754, to_date('01-12-2034', 'dd-mm-yyyy'), '5', '01', '335', '12', '2034', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12755, to_date('02-12-2034', 'dd-mm-yyyy'), '6', '02', '336', '12', '2034', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12756, to_date('03-12-2034', 'dd-mm-yyyy'), '7', '03', '337', '12', '2034', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12757, to_date('04-12-2034', 'dd-mm-yyyy'), '1', '04', '338', '12', '2034', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12758, to_date('05-12-2034', 'dd-mm-yyyy'), '2', '05', '339', '12', '2034', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12759, to_date('06-12-2034', 'dd-mm-yyyy'), '3', '06', '340', '12', '2034', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12760, to_date('07-12-2034', 'dd-mm-yyyy'), '4', '07', '341', '12', '2034', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12761, to_date('08-12-2034', 'dd-mm-yyyy'), '5', '08', '342', '12', '2034', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12762, to_date('09-12-2034', 'dd-mm-yyyy'), '6', '09', '343', '12', '2034', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12763, to_date('10-12-2034', 'dd-mm-yyyy'), '7', '10', '344', '12', '2034', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12764, to_date('11-12-2034', 'dd-mm-yyyy'), '1', '11', '345', '12', '2034', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12765, to_date('12-12-2034', 'dd-mm-yyyy'), '2', '12', '346', '12', '2034', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12766, to_date('13-12-2034', 'dd-mm-yyyy'), '3', '13', '347', '12', '2034', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12767, to_date('14-12-2034', 'dd-mm-yyyy'), '4', '14', '348', '12', '2034', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12768, to_date('15-12-2034', 'dd-mm-yyyy'), '5', '15', '349', '12', '2034', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12769, to_date('16-12-2034', 'dd-mm-yyyy'), '6', '16', '350', '12', '2034', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12770, to_date('17-12-2034', 'dd-mm-yyyy'), '7', '17', '351', '12', '2034', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12771, to_date('18-12-2034', 'dd-mm-yyyy'), '1', '18', '352', '12', '2034', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12772, to_date('19-12-2034', 'dd-mm-yyyy'), '2', '19', '353', '12', '2034', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12773, to_date('20-12-2034', 'dd-mm-yyyy'), '3', '20', '354', '12', '2034', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12774, to_date('21-12-2034', 'dd-mm-yyyy'), '4', '21', '355', '12', '2034', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12775, to_date('22-12-2034', 'dd-mm-yyyy'), '5', '22', '356', '12', '2034', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12776, to_date('23-12-2034', 'dd-mm-yyyy'), '6', '23', '357', '12', '2034', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12777, to_date('24-12-2034', 'dd-mm-yyyy'), '7', '24', '358', '12', '2034', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12778, to_date('25-12-2034', 'dd-mm-yyyy'), '1', '25', '359', '12', '2034', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12779, to_date('26-12-2034', 'dd-mm-yyyy'), '2', '26', '360', '12', '2034', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12780, to_date('27-12-2034', 'dd-mm-yyyy'), '3', '27', '361', '12', '2034', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12781, to_date('28-12-2034', 'dd-mm-yyyy'), '4', '28', '362', '12', '2034', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12782, to_date('29-12-2034', 'dd-mm-yyyy'), '5', '29', '363', '12', '2034', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12783, to_date('30-12-2034', 'dd-mm-yyyy'), '6', '30', '364', '12', '2034', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12784, to_date('31-12-2034', 'dd-mm-yyyy'), '7', '31', '365', '12', '2034', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12785, to_date('01-01-2035', 'dd-mm-yyyy'), '1', '01', '001', '01', '2035', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12786, to_date('02-01-2035', 'dd-mm-yyyy'), '2', '02', '002', '01', '2035', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12787, to_date('03-01-2035', 'dd-mm-yyyy'), '3', '03', '003', '01', '2035', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12788, to_date('04-01-2035', 'dd-mm-yyyy'), '4', '04', '004', '01', '2035', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12789, to_date('05-01-2035', 'dd-mm-yyyy'), '5', '05', '005', '01', '2035', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12790, to_date('06-01-2035', 'dd-mm-yyyy'), '6', '06', '006', '01', '2035', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12791, to_date('07-01-2035', 'dd-mm-yyyy'), '7', '07', '007', '01', '2035', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12792, to_date('08-01-2035', 'dd-mm-yyyy'), '1', '08', '008', '01', '2035', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12793, to_date('09-01-2035', 'dd-mm-yyyy'), '2', '09', '009', '01', '2035', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12794, to_date('10-01-2035', 'dd-mm-yyyy'), '3', '10', '010', '01', '2035', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12795, to_date('11-01-2035', 'dd-mm-yyyy'), '4', '11', '011', '01', '2035', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12796, to_date('12-01-2035', 'dd-mm-yyyy'), '5', '12', '012', '01', '2035', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12797, to_date('13-01-2035', 'dd-mm-yyyy'), '6', '13', '013', '01', '2035', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12798, to_date('14-01-2035', 'dd-mm-yyyy'), '7', '14', '014', '01', '2035', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12799, to_date('15-01-2035', 'dd-mm-yyyy'), '1', '15', '015', '01', '2035', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12800, to_date('16-01-2035', 'dd-mm-yyyy'), '2', '16', '016', '01', '2035', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14391, to_date('26-05-2039', 'dd-mm-yyyy'), '4', '26', '146', '05', '2039', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14392, to_date('27-05-2039', 'dd-mm-yyyy'), '5', '27', '147', '05', '2039', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14393, to_date('28-05-2039', 'dd-mm-yyyy'), '6', '28', '148', '05', '2039', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14394, to_date('29-05-2039', 'dd-mm-yyyy'), '7', '29', '149', '05', '2039', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14395, to_date('30-05-2039', 'dd-mm-yyyy'), '1', '30', '150', '05', '2039', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14396, to_date('31-05-2039', 'dd-mm-yyyy'), '2', '31', '151', '05', '2039', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14397, to_date('01-06-2039', 'dd-mm-yyyy'), '3', '01', '152', '06', '2039', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14398, to_date('02-06-2039', 'dd-mm-yyyy'), '4', '02', '153', '06', '2039', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14399, to_date('03-06-2039', 'dd-mm-yyyy'), '5', '03', '154', '06', '2039', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14400, to_date('04-06-2039', 'dd-mm-yyyy'), '6', '04', '155', '06', '2039', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14401, to_date('05-06-2039', 'dd-mm-yyyy'), '7', '05', '156', '06', '2039', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14402, to_date('06-06-2039', 'dd-mm-yyyy'), '1', '06', '157', '06', '2039', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14403, to_date('07-06-2039', 'dd-mm-yyyy'), '2', '07', '158', '06', '2039', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14404, to_date('08-06-2039', 'dd-mm-yyyy'), '3', '08', '159', '06', '2039', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14405, to_date('09-06-2039', 'dd-mm-yyyy'), '4', '09', '160', '06', '2039', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14406, to_date('10-06-2039', 'dd-mm-yyyy'), '5', '10', '161', '06', '2039', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14407, to_date('11-06-2039', 'dd-mm-yyyy'), '6', '11', '162', '06', '2039', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14408, to_date('12-06-2039', 'dd-mm-yyyy'), '7', '12', '163', '06', '2039', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14409, to_date('13-06-2039', 'dd-mm-yyyy'), '1', '13', '164', '06', '2039', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14410, to_date('14-06-2039', 'dd-mm-yyyy'), '2', '14', '165', '06', '2039', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14411, to_date('15-06-2039', 'dd-mm-yyyy'), '3', '15', '166', '06', '2039', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14412, to_date('16-06-2039', 'dd-mm-yyyy'), '4', '16', '167', '06', '2039', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14413, to_date('17-06-2039', 'dd-mm-yyyy'), '5', '17', '168', '06', '2039', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14414, to_date('18-06-2039', 'dd-mm-yyyy'), '6', '18', '169', '06', '2039', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14415, to_date('19-06-2039', 'dd-mm-yyyy'), '7', '19', '170', '06', '2039', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14416, to_date('20-06-2039', 'dd-mm-yyyy'), '1', '20', '171', '06', '2039', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14417, to_date('21-06-2039', 'dd-mm-yyyy'), '2', '21', '172', '06', '2039', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14418, to_date('22-06-2039', 'dd-mm-yyyy'), '3', '22', '173', '06', '2039', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14419, to_date('23-06-2039', 'dd-mm-yyyy'), '4', '23', '174', '06', '2039', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14420, to_date('24-06-2039', 'dd-mm-yyyy'), '5', '24', '175', '06', '2039', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14421, to_date('25-06-2039', 'dd-mm-yyyy'), '6', '25', '176', '06', '2039', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14422, to_date('26-06-2039', 'dd-mm-yyyy'), '7', '26', '177', '06', '2039', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14423, to_date('27-06-2039', 'dd-mm-yyyy'), '1', '27', '178', '06', '2039', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14424, to_date('28-06-2039', 'dd-mm-yyyy'), '2', '28', '179', '06', '2039', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14425, to_date('29-06-2039', 'dd-mm-yyyy'), '3', '29', '180', '06', '2039', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14426, to_date('30-06-2039', 'dd-mm-yyyy'), '4', '30', '181', '06', '2039', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14427, to_date('01-07-2039', 'dd-mm-yyyy'), '5', '01', '182', '07', '2039', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14428, to_date('02-07-2039', 'dd-mm-yyyy'), '6', '02', '183', '07', '2039', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14429, to_date('03-07-2039', 'dd-mm-yyyy'), '7', '03', '184', '07', '2039', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14430, to_date('04-07-2039', 'dd-mm-yyyy'), '1', '04', '185', '07', '2039', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14431, to_date('05-07-2039', 'dd-mm-yyyy'), '2', '05', '186', '07', '2039', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14432, to_date('06-07-2039', 'dd-mm-yyyy'), '3', '06', '187', '07', '2039', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14433, to_date('07-07-2039', 'dd-mm-yyyy'), '4', '07', '188', '07', '2039', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14434, to_date('08-07-2039', 'dd-mm-yyyy'), '5', '08', '189', '07', '2039', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14435, to_date('09-07-2039', 'dd-mm-yyyy'), '6', '09', '190', '07', '2039', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14436, to_date('10-07-2039', 'dd-mm-yyyy'), '7', '10', '191', '07', '2039', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14437, to_date('11-07-2039', 'dd-mm-yyyy'), '1', '11', '192', '07', '2039', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14438, to_date('12-07-2039', 'dd-mm-yyyy'), '2', '12', '193', '07', '2039', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14439, to_date('13-07-2039', 'dd-mm-yyyy'), '3', '13', '194', '07', '2039', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14440, to_date('14-07-2039', 'dd-mm-yyyy'), '4', '14', '195', '07', '2039', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14441, to_date('15-07-2039', 'dd-mm-yyyy'), '5', '15', '196', '07', '2039', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14442, to_date('16-07-2039', 'dd-mm-yyyy'), '6', '16', '197', '07', '2039', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14443, to_date('17-07-2039', 'dd-mm-yyyy'), '7', '17', '198', '07', '2039', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14444, to_date('18-07-2039', 'dd-mm-yyyy'), '1', '18', '199', '07', '2039', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14445, to_date('19-07-2039', 'dd-mm-yyyy'), '2', '19', '200', '07', '2039', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14446, to_date('20-07-2039', 'dd-mm-yyyy'), '3', '20', '201', '07', '2039', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14447, to_date('21-07-2039', 'dd-mm-yyyy'), '4', '21', '202', '07', '2039', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14448, to_date('22-07-2039', 'dd-mm-yyyy'), '5', '22', '203', '07', '2039', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14449, to_date('23-07-2039', 'dd-mm-yyyy'), '6', '23', '204', '07', '2039', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14450, to_date('24-07-2039', 'dd-mm-yyyy'), '7', '24', '205', '07', '2039', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14451, to_date('25-07-2039', 'dd-mm-yyyy'), '1', '25', '206', '07', '2039', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14452, to_date('26-07-2039', 'dd-mm-yyyy'), '2', '26', '207', '07', '2039', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14453, to_date('27-07-2039', 'dd-mm-yyyy'), '3', '27', '208', '07', '2039', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14454, to_date('28-07-2039', 'dd-mm-yyyy'), '4', '28', '209', '07', '2039', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14455, to_date('29-07-2039', 'dd-mm-yyyy'), '5', '29', '210', '07', '2039', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14456, to_date('30-07-2039', 'dd-mm-yyyy'), '6', '30', '211', '07', '2039', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14457, to_date('31-07-2039', 'dd-mm-yyyy'), '7', '31', '212', '07', '2039', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14458, to_date('01-08-2039', 'dd-mm-yyyy'), '1', '01', '213', '08', '2039', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14459, to_date('02-08-2039', 'dd-mm-yyyy'), '2', '02', '214', '08', '2039', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14460, to_date('03-08-2039', 'dd-mm-yyyy'), '3', '03', '215', '08', '2039', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14461, to_date('04-08-2039', 'dd-mm-yyyy'), '4', '04', '216', '08', '2039', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14462, to_date('05-08-2039', 'dd-mm-yyyy'), '5', '05', '217', '08', '2039', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14463, to_date('06-08-2039', 'dd-mm-yyyy'), '6', '06', '218', '08', '2039', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14464, to_date('07-08-2039', 'dd-mm-yyyy'), '7', '07', '219', '08', '2039', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14465, to_date('08-08-2039', 'dd-mm-yyyy'), '1', '08', '220', '08', '2039', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14466, to_date('09-08-2039', 'dd-mm-yyyy'), '2', '09', '221', '08', '2039', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14467, to_date('10-08-2039', 'dd-mm-yyyy'), '3', '10', '222', '08', '2039', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14468, to_date('11-08-2039', 'dd-mm-yyyy'), '4', '11', '223', '08', '2039', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14469, to_date('12-08-2039', 'dd-mm-yyyy'), '5', '12', '224', '08', '2039', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14470, to_date('13-08-2039', 'dd-mm-yyyy'), '6', '13', '225', '08', '2039', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14471, to_date('14-08-2039', 'dd-mm-yyyy'), '7', '14', '226', '08', '2039', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14472, to_date('15-08-2039', 'dd-mm-yyyy'), '1', '15', '227', '08', '2039', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14473, to_date('16-08-2039', 'dd-mm-yyyy'), '2', '16', '228', '08', '2039', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14474, to_date('17-08-2039', 'dd-mm-yyyy'), '3', '17', '229', '08', '2039', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14475, to_date('18-08-2039', 'dd-mm-yyyy'), '4', '18', '230', '08', '2039', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14476, to_date('19-08-2039', 'dd-mm-yyyy'), '5', '19', '231', '08', '2039', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14477, to_date('20-08-2039', 'dd-mm-yyyy'), '6', '20', '232', '08', '2039', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14478, to_date('21-08-2039', 'dd-mm-yyyy'), '7', '21', '233', '08', '2039', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14479, to_date('22-08-2039', 'dd-mm-yyyy'), '1', '22', '234', '08', '2039', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14480, to_date('23-08-2039', 'dd-mm-yyyy'), '2', '23', '235', '08', '2039', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14481, to_date('24-08-2039', 'dd-mm-yyyy'), '3', '24', '236', '08', '2039', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14482, to_date('25-08-2039', 'dd-mm-yyyy'), '4', '25', '237', '08', '2039', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14483, to_date('26-08-2039', 'dd-mm-yyyy'), '5', '26', '238', '08', '2039', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14484, to_date('27-08-2039', 'dd-mm-yyyy'), '6', '27', '239', '08', '2039', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14485, to_date('28-08-2039', 'dd-mm-yyyy'), '7', '28', '240', '08', '2039', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14486, to_date('29-08-2039', 'dd-mm-yyyy'), '1', '29', '241', '08', '2039', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14487, to_date('30-08-2039', 'dd-mm-yyyy'), '2', '30', '242', '08', '2039', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14488, to_date('31-08-2039', 'dd-mm-yyyy'), '3', '31', '243', '08', '2039', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14489, to_date('01-09-2039', 'dd-mm-yyyy'), '4', '01', '244', '09', '2039', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14490, to_date('02-09-2039', 'dd-mm-yyyy'), '5', '02', '245', '09', '2039', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14491, to_date('03-09-2039', 'dd-mm-yyyy'), '6', '03', '246', '09', '2039', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14492, to_date('04-09-2039', 'dd-mm-yyyy'), '7', '04', '247', '09', '2039', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14493, to_date('05-09-2039', 'dd-mm-yyyy'), '1', '05', '248', '09', '2039', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14494, to_date('06-09-2039', 'dd-mm-yyyy'), '2', '06', '249', '09', '2039', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14495, to_date('07-09-2039', 'dd-mm-yyyy'), '3', '07', '250', '09', '2039', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14496, to_date('08-09-2039', 'dd-mm-yyyy'), '4', '08', '251', '09', '2039', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15981, to_date('02-10-2043', 'dd-mm-yyyy'), '5', '02', '275', '10', '2043', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15982, to_date('03-10-2043', 'dd-mm-yyyy'), '6', '03', '276', '10', '2043', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15983, to_date('04-10-2043', 'dd-mm-yyyy'), '7', '04', '277', '10', '2043', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15984, to_date('05-10-2043', 'dd-mm-yyyy'), '1', '05', '278', '10', '2043', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15985, to_date('06-10-2043', 'dd-mm-yyyy'), '2', '06', '279', '10', '2043', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15986, to_date('07-10-2043', 'dd-mm-yyyy'), '3', '07', '280', '10', '2043', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15987, to_date('08-10-2043', 'dd-mm-yyyy'), '4', '08', '281', '10', '2043', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15988, to_date('09-10-2043', 'dd-mm-yyyy'), '5', '09', '282', '10', '2043', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15989, to_date('10-10-2043', 'dd-mm-yyyy'), '6', '10', '283', '10', '2043', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15990, to_date('11-10-2043', 'dd-mm-yyyy'), '7', '11', '284', '10', '2043', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15991, to_date('12-10-2043', 'dd-mm-yyyy'), '1', '12', '285', '10', '2043', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15992, to_date('13-10-2043', 'dd-mm-yyyy'), '2', '13', '286', '10', '2043', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15993, to_date('14-10-2043', 'dd-mm-yyyy'), '3', '14', '287', '10', '2043', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15994, to_date('15-10-2043', 'dd-mm-yyyy'), '4', '15', '288', '10', '2043', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15995, to_date('16-10-2043', 'dd-mm-yyyy'), '5', '16', '289', '10', '2043', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15996, to_date('17-10-2043', 'dd-mm-yyyy'), '6', '17', '290', '10', '2043', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15997, to_date('18-10-2043', 'dd-mm-yyyy'), '7', '18', '291', '10', '2043', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15998, to_date('19-10-2043', 'dd-mm-yyyy'), '1', '19', '292', '10', '2043', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15999, to_date('20-10-2043', 'dd-mm-yyyy'), '2', '20', '293', '10', '2043', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16000, to_date('21-10-2043', 'dd-mm-yyyy'), '3', '21', '294', '10', '2043', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16001, to_date('22-10-2043', 'dd-mm-yyyy'), '4', '22', '295', '10', '2043', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16002, to_date('23-10-2043', 'dd-mm-yyyy'), '5', '23', '296', '10', '2043', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16003, to_date('24-10-2043', 'dd-mm-yyyy'), '6', '24', '297', '10', '2043', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16004, to_date('25-10-2043', 'dd-mm-yyyy'), '7', '25', '298', '10', '2043', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16005, to_date('26-10-2043', 'dd-mm-yyyy'), '1', '26', '299', '10', '2043', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16006, to_date('27-10-2043', 'dd-mm-yyyy'), '2', '27', '300', '10', '2043', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16007, to_date('28-10-2043', 'dd-mm-yyyy'), '3', '28', '301', '10', '2043', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16008, to_date('29-10-2043', 'dd-mm-yyyy'), '4', '29', '302', '10', '2043', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16009, to_date('30-10-2043', 'dd-mm-yyyy'), '5', '30', '303', '10', '2043', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16010, to_date('31-10-2043', 'dd-mm-yyyy'), '6', '31', '304', '10', '2043', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16011, to_date('01-11-2043', 'dd-mm-yyyy'), '7', '01', '305', '11', '2043', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16012, to_date('02-11-2043', 'dd-mm-yyyy'), '1', '02', '306', '11', '2043', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16013, to_date('03-11-2043', 'dd-mm-yyyy'), '2', '03', '307', '11', '2043', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16014, to_date('04-11-2043', 'dd-mm-yyyy'), '3', '04', '308', '11', '2043', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16015, to_date('05-11-2043', 'dd-mm-yyyy'), '4', '05', '309', '11', '2043', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16016, to_date('06-11-2043', 'dd-mm-yyyy'), '5', '06', '310', '11', '2043', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16017, to_date('07-11-2043', 'dd-mm-yyyy'), '6', '07', '311', '11', '2043', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16018, to_date('08-11-2043', 'dd-mm-yyyy'), '7', '08', '312', '11', '2043', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16019, to_date('09-11-2043', 'dd-mm-yyyy'), '1', '09', '313', '11', '2043', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16020, to_date('10-11-2043', 'dd-mm-yyyy'), '2', '10', '314', '11', '2043', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16021, to_date('11-11-2043', 'dd-mm-yyyy'), '3', '11', '315', '11', '2043', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16022, to_date('12-11-2043', 'dd-mm-yyyy'), '4', '12', '316', '11', '2043', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16023, to_date('13-11-2043', 'dd-mm-yyyy'), '5', '13', '317', '11', '2043', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16024, to_date('14-11-2043', 'dd-mm-yyyy'), '6', '14', '318', '11', '2043', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16025, to_date('15-11-2043', 'dd-mm-yyyy'), '7', '15', '319', '11', '2043', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16026, to_date('16-11-2043', 'dd-mm-yyyy'), '1', '16', '320', '11', '2043', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16027, to_date('17-11-2043', 'dd-mm-yyyy'), '2', '17', '321', '11', '2043', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16028, to_date('18-11-2043', 'dd-mm-yyyy'), '3', '18', '322', '11', '2043', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16029, to_date('19-11-2043', 'dd-mm-yyyy'), '4', '19', '323', '11', '2043', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16030, to_date('20-11-2043', 'dd-mm-yyyy'), '5', '20', '324', '11', '2043', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16031, to_date('21-11-2043', 'dd-mm-yyyy'), '6', '21', '325', '11', '2043', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16032, to_date('22-11-2043', 'dd-mm-yyyy'), '7', '22', '326', '11', '2043', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16033, to_date('23-11-2043', 'dd-mm-yyyy'), '1', '23', '327', '11', '2043', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16034, to_date('24-11-2043', 'dd-mm-yyyy'), '2', '24', '328', '11', '2043', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16035, to_date('25-11-2043', 'dd-mm-yyyy'), '3', '25', '329', '11', '2043', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16036, to_date('26-11-2043', 'dd-mm-yyyy'), '4', '26', '330', '11', '2043', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16037, to_date('27-11-2043', 'dd-mm-yyyy'), '5', '27', '331', '11', '2043', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16038, to_date('28-11-2043', 'dd-mm-yyyy'), '6', '28', '332', '11', '2043', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16039, to_date('29-11-2043', 'dd-mm-yyyy'), '7', '29', '333', '11', '2043', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16040, to_date('30-11-2043', 'dd-mm-yyyy'), '1', '30', '334', '11', '2043', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16041, to_date('01-12-2043', 'dd-mm-yyyy'), '2', '01', '335', '12', '2043', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16042, to_date('02-12-2043', 'dd-mm-yyyy'), '3', '02', '336', '12', '2043', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16043, to_date('03-12-2043', 'dd-mm-yyyy'), '4', '03', '337', '12', '2043', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16044, to_date('04-12-2043', 'dd-mm-yyyy'), '5', '04', '338', '12', '2043', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16045, to_date('05-12-2043', 'dd-mm-yyyy'), '6', '05', '339', '12', '2043', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16046, to_date('06-12-2043', 'dd-mm-yyyy'), '7', '06', '340', '12', '2043', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16047, to_date('07-12-2043', 'dd-mm-yyyy'), '1', '07', '341', '12', '2043', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16048, to_date('08-12-2043', 'dd-mm-yyyy'), '2', '08', '342', '12', '2043', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16049, to_date('09-12-2043', 'dd-mm-yyyy'), '3', '09', '343', '12', '2043', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16050, to_date('10-12-2043', 'dd-mm-yyyy'), '4', '10', '344', '12', '2043', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16051, to_date('11-12-2043', 'dd-mm-yyyy'), '5', '11', '345', '12', '2043', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16052, to_date('12-12-2043', 'dd-mm-yyyy'), '6', '12', '346', '12', '2043', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16053, to_date('13-12-2043', 'dd-mm-yyyy'), '7', '13', '347', '12', '2043', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16054, to_date('14-12-2043', 'dd-mm-yyyy'), '1', '14', '348', '12', '2043', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16055, to_date('15-12-2043', 'dd-mm-yyyy'), '2', '15', '349', '12', '2043', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16056, to_date('16-12-2043', 'dd-mm-yyyy'), '3', '16', '350', '12', '2043', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16057, to_date('17-12-2043', 'dd-mm-yyyy'), '4', '17', '351', '12', '2043', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16058, to_date('18-12-2043', 'dd-mm-yyyy'), '5', '18', '352', '12', '2043', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16059, to_date('19-12-2043', 'dd-mm-yyyy'), '6', '19', '353', '12', '2043', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16060, to_date('20-12-2043', 'dd-mm-yyyy'), '7', '20', '354', '12', '2043', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16061, to_date('21-12-2043', 'dd-mm-yyyy'), '1', '21', '355', '12', '2043', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16062, to_date('22-12-2043', 'dd-mm-yyyy'), '2', '22', '356', '12', '2043', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16063, to_date('23-12-2043', 'dd-mm-yyyy'), '3', '23', '357', '12', '2043', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16064, to_date('24-12-2043', 'dd-mm-yyyy'), '4', '24', '358', '12', '2043', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16065, to_date('25-12-2043', 'dd-mm-yyyy'), '5', '25', '359', '12', '2043', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16066, to_date('26-12-2043', 'dd-mm-yyyy'), '6', '26', '360', '12', '2043', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16067, to_date('27-12-2043', 'dd-mm-yyyy'), '7', '27', '361', '12', '2043', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16068, to_date('28-12-2043', 'dd-mm-yyyy'), '1', '28', '362', '12', '2043', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16069, to_date('29-12-2043', 'dd-mm-yyyy'), '2', '29', '363', '12', '2043', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16070, to_date('30-12-2043', 'dd-mm-yyyy'), '3', '30', '364', '12', '2043', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16071, to_date('31-12-2043', 'dd-mm-yyyy'), '4', '31', '365', '12', '2043', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16072, to_date('01-01-2044', 'dd-mm-yyyy'), '5', '01', '001', '01', '2044', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16073, to_date('02-01-2044', 'dd-mm-yyyy'), '6', '02', '002', '01', '2044', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16074, to_date('03-01-2044', 'dd-mm-yyyy'), '7', '03', '003', '01', '2044', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16075, to_date('04-01-2044', 'dd-mm-yyyy'), '1', '04', '004', '01', '2044', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16076, to_date('05-01-2044', 'dd-mm-yyyy'), '2', '05', '005', '01', '2044', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16077, to_date('06-01-2044', 'dd-mm-yyyy'), '3', '06', '006', '01', '2044', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16078, to_date('07-01-2044', 'dd-mm-yyyy'), '4', '07', '007', '01', '2044', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16079, to_date('08-01-2044', 'dd-mm-yyyy'), '5', '08', '008', '01', '2044', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16080, to_date('09-01-2044', 'dd-mm-yyyy'), '6', '09', '009', '01', '2044', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16081, to_date('10-01-2044', 'dd-mm-yyyy'), '7', '10', '010', '01', '2044', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16082, to_date('11-01-2044', 'dd-mm-yyyy'), '1', '11', '011', '01', '2044', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16083, to_date('12-01-2044', 'dd-mm-yyyy'), '2', '12', '012', '01', '2044', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16084, to_date('13-01-2044', 'dd-mm-yyyy'), '3', '13', '013', '01', '2044', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16085, to_date('14-01-2044', 'dd-mm-yyyy'), '4', '14', '014', '01', '2044', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16086, to_date('15-01-2044', 'dd-mm-yyyy'), '5', '15', '015', '01', '2044', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17571, to_date('08-02-2048', 'dd-mm-yyyy'), '6', '08', '039', '02', '2048', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17572, to_date('09-02-2048', 'dd-mm-yyyy'), '7', '09', '040', '02', '2048', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17573, to_date('10-02-2048', 'dd-mm-yyyy'), '1', '10', '041', '02', '2048', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17574, to_date('11-02-2048', 'dd-mm-yyyy'), '2', '11', '042', '02', '2048', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17575, to_date('12-02-2048', 'dd-mm-yyyy'), '3', '12', '043', '02', '2048', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17576, to_date('13-02-2048', 'dd-mm-yyyy'), '4', '13', '044', '02', '2048', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17577, to_date('14-02-2048', 'dd-mm-yyyy'), '5', '14', '045', '02', '2048', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17578, to_date('15-02-2048', 'dd-mm-yyyy'), '6', '15', '046', '02', '2048', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17579, to_date('16-02-2048', 'dd-mm-yyyy'), '7', '16', '047', '02', '2048', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17580, to_date('17-02-2048', 'dd-mm-yyyy'), '1', '17', '048', '02', '2048', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17581, to_date('18-02-2048', 'dd-mm-yyyy'), '2', '18', '049', '02', '2048', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17582, to_date('19-02-2048', 'dd-mm-yyyy'), '3', '19', '050', '02', '2048', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17583, to_date('20-02-2048', 'dd-mm-yyyy'), '4', '20', '051', '02', '2048', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17584, to_date('21-02-2048', 'dd-mm-yyyy'), '5', '21', '052', '02', '2048', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17585, to_date('22-02-2048', 'dd-mm-yyyy'), '6', '22', '053', '02', '2048', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17586, to_date('23-02-2048', 'dd-mm-yyyy'), '7', '23', '054', '02', '2048', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17587, to_date('24-02-2048', 'dd-mm-yyyy'), '1', '24', '055', '02', '2048', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17588, to_date('25-02-2048', 'dd-mm-yyyy'), '2', '25', '056', '02', '2048', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17589, to_date('26-02-2048', 'dd-mm-yyyy'), '3', '26', '057', '02', '2048', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17590, to_date('27-02-2048', 'dd-mm-yyyy'), '4', '27', '058', '02', '2048', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17591, to_date('28-02-2048', 'dd-mm-yyyy'), '5', '28', '059', '02', '2048', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17592, to_date('29-02-2048', 'dd-mm-yyyy'), '6', '29', '060', '02', '2048', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17593, to_date('01-03-2048', 'dd-mm-yyyy'), '7', '01', '061', '03', '2048', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17594, to_date('02-03-2048', 'dd-mm-yyyy'), '1', '02', '062', '03', '2048', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17595, to_date('03-03-2048', 'dd-mm-yyyy'), '2', '03', '063', '03', '2048', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17596, to_date('04-03-2048', 'dd-mm-yyyy'), '3', '04', '064', '03', '2048', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17597, to_date('05-03-2048', 'dd-mm-yyyy'), '4', '05', '065', '03', '2048', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17598, to_date('06-03-2048', 'dd-mm-yyyy'), '5', '06', '066', '03', '2048', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17599, to_date('07-03-2048', 'dd-mm-yyyy'), '6', '07', '067', '03', '2048', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17600, to_date('08-03-2048', 'dd-mm-yyyy'), '7', '08', '068', '03', '2048', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17601, to_date('09-03-2048', 'dd-mm-yyyy'), '1', '09', '069', '03', '2048', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17602, to_date('10-03-2048', 'dd-mm-yyyy'), '2', '10', '070', '03', '2048', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17603, to_date('11-03-2048', 'dd-mm-yyyy'), '3', '11', '071', '03', '2048', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17604, to_date('12-03-2048', 'dd-mm-yyyy'), '4', '12', '072', '03', '2048', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17605, to_date('13-03-2048', 'dd-mm-yyyy'), '5', '13', '073', '03', '2048', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17606, to_date('14-03-2048', 'dd-mm-yyyy'), '6', '14', '074', '03', '2048', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17607, to_date('15-03-2048', 'dd-mm-yyyy'), '7', '15', '075', '03', '2048', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17608, to_date('16-03-2048', 'dd-mm-yyyy'), '1', '16', '076', '03', '2048', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17609, to_date('17-03-2048', 'dd-mm-yyyy'), '2', '17', '077', '03', '2048', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17610, to_date('18-03-2048', 'dd-mm-yyyy'), '3', '18', '078', '03', '2048', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17611, to_date('19-03-2048', 'dd-mm-yyyy'), '4', '19', '079', '03', '2048', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17612, to_date('20-03-2048', 'dd-mm-yyyy'), '5', '20', '080', '03', '2048', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17613, to_date('21-03-2048', 'dd-mm-yyyy'), '6', '21', '081', '03', '2048', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17614, to_date('22-03-2048', 'dd-mm-yyyy'), '7', '22', '082', '03', '2048', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17615, to_date('23-03-2048', 'dd-mm-yyyy'), '1', '23', '083', '03', '2048', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17616, to_date('24-03-2048', 'dd-mm-yyyy'), '2', '24', '084', '03', '2048', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17617, to_date('25-03-2048', 'dd-mm-yyyy'), '3', '25', '085', '03', '2048', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17618, to_date('26-03-2048', 'dd-mm-yyyy'), '4', '26', '086', '03', '2048', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17619, to_date('27-03-2048', 'dd-mm-yyyy'), '5', '27', '087', '03', '2048', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17620, to_date('28-03-2048', 'dd-mm-yyyy'), '6', '28', '088', '03', '2048', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17621, to_date('29-03-2048', 'dd-mm-yyyy'), '7', '29', '089', '03', '2048', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17622, to_date('30-03-2048', 'dd-mm-yyyy'), '1', '30', '090', '03', '2048', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17623, to_date('31-03-2048', 'dd-mm-yyyy'), '2', '31', '091', '03', '2048', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17624, to_date('01-04-2048', 'dd-mm-yyyy'), '3', '01', '092', '04', '2048', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17625, to_date('02-04-2048', 'dd-mm-yyyy'), '4', '02', '093', '04', '2048', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17626, to_date('03-04-2048', 'dd-mm-yyyy'), '5', '03', '094', '04', '2048', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17627, to_date('04-04-2048', 'dd-mm-yyyy'), '6', '04', '095', '04', '2048', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17628, to_date('05-04-2048', 'dd-mm-yyyy'), '7', '05', '096', '04', '2048', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17629, to_date('06-04-2048', 'dd-mm-yyyy'), '1', '06', '097', '04', '2048', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17630, to_date('07-04-2048', 'dd-mm-yyyy'), '2', '07', '098', '04', '2048', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17631, to_date('08-04-2048', 'dd-mm-yyyy'), '3', '08', '099', '04', '2048', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17632, to_date('09-04-2048', 'dd-mm-yyyy'), '4', '09', '100', '04', '2048', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17633, to_date('10-04-2048', 'dd-mm-yyyy'), '5', '10', '101', '04', '2048', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17634, to_date('11-04-2048', 'dd-mm-yyyy'), '6', '11', '102', '04', '2048', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17635, to_date('12-04-2048', 'dd-mm-yyyy'), '7', '12', '103', '04', '2048', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17636, to_date('13-04-2048', 'dd-mm-yyyy'), '1', '13', '104', '04', '2048', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17637, to_date('14-04-2048', 'dd-mm-yyyy'), '2', '14', '105', '04', '2048', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17638, to_date('15-04-2048', 'dd-mm-yyyy'), '3', '15', '106', '04', '2048', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17639, to_date('16-04-2048', 'dd-mm-yyyy'), '4', '16', '107', '04', '2048', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17640, to_date('17-04-2048', 'dd-mm-yyyy'), '5', '17', '108', '04', '2048', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17641, to_date('18-04-2048', 'dd-mm-yyyy'), '6', '18', '109', '04', '2048', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17642, to_date('19-04-2048', 'dd-mm-yyyy'), '7', '19', '110', '04', '2048', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17643, to_date('20-04-2048', 'dd-mm-yyyy'), '1', '20', '111', '04', '2048', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17644, to_date('21-04-2048', 'dd-mm-yyyy'), '2', '21', '112', '04', '2048', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17645, to_date('22-04-2048', 'dd-mm-yyyy'), '3', '22', '113', '04', '2048', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17646, to_date('23-04-2048', 'dd-mm-yyyy'), '4', '23', '114', '04', '2048', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17647, to_date('24-04-2048', 'dd-mm-yyyy'), '5', '24', '115', '04', '2048', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17648, to_date('25-04-2048', 'dd-mm-yyyy'), '6', '25', '116', '04', '2048', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17649, to_date('26-04-2048', 'dd-mm-yyyy'), '7', '26', '117', '04', '2048', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17650, to_date('27-04-2048', 'dd-mm-yyyy'), '1', '27', '118', '04', '2048', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17651, to_date('28-04-2048', 'dd-mm-yyyy'), '2', '28', '119', '04', '2048', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17652, to_date('29-04-2048', 'dd-mm-yyyy'), '3', '29', '120', '04', '2048', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17653, to_date('30-04-2048', 'dd-mm-yyyy'), '4', '30', '121', '04', '2048', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17654, to_date('01-05-2048', 'dd-mm-yyyy'), '5', '01', '122', '05', '2048', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17655, to_date('02-05-2048', 'dd-mm-yyyy'), '6', '02', '123', '05', '2048', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17656, to_date('03-05-2048', 'dd-mm-yyyy'), '7', '03', '124', '05', '2048', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17657, to_date('04-05-2048', 'dd-mm-yyyy'), '1', '04', '125', '05', '2048', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17658, to_date('05-05-2048', 'dd-mm-yyyy'), '2', '05', '126', '05', '2048', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17659, to_date('06-05-2048', 'dd-mm-yyyy'), '3', '06', '127', '05', '2048', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17660, to_date('07-05-2048', 'dd-mm-yyyy'), '4', '07', '128', '05', '2048', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17661, to_date('08-05-2048', 'dd-mm-yyyy'), '5', '08', '129', '05', '2048', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17662, to_date('09-05-2048', 'dd-mm-yyyy'), '6', '09', '130', '05', '2048', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17663, to_date('10-05-2048', 'dd-mm-yyyy'), '7', '10', '131', '05', '2048', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17664, to_date('11-05-2048', 'dd-mm-yyyy'), '1', '11', '132', '05', '2048', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17665, to_date('12-05-2048', 'dd-mm-yyyy'), '2', '12', '133', '05', '2048', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17666, to_date('13-05-2048', 'dd-mm-yyyy'), '3', '13', '134', '05', '2048', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17667, to_date('14-05-2048', 'dd-mm-yyyy'), '4', '14', '135', '05', '2048', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17668, to_date('15-05-2048', 'dd-mm-yyyy'), '5', '15', '136', '05', '2048', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17669, to_date('16-05-2048', 'dd-mm-yyyy'), '6', '16', '137', '05', '2048', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17670, to_date('17-05-2048', 'dd-mm-yyyy'), '7', '17', '138', '05', '2048', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17671, to_date('18-05-2048', 'dd-mm-yyyy'), '1', '18', '139', '05', '2048', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17672, to_date('19-05-2048', 'dd-mm-yyyy'), '2', '19', '140', '05', '2048', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17673, to_date('20-05-2048', 'dd-mm-yyyy'), '3', '20', '141', '05', '2048', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17674, to_date('21-05-2048', 'dd-mm-yyyy'), '4', '21', '142', '05', '2048', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17675, to_date('22-05-2048', 'dd-mm-yyyy'), '5', '22', '143', '05', '2048', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17676, to_date('23-05-2048', 'dd-mm-yyyy'), '6', '23', '144', '05', '2048', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12801, to_date('17-01-2035', 'dd-mm-yyyy'), '3', '17', '017', '01', '2035', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12802, to_date('18-01-2035', 'dd-mm-yyyy'), '4', '18', '018', '01', '2035', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12803, to_date('19-01-2035', 'dd-mm-yyyy'), '5', '19', '019', '01', '2035', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12804, to_date('20-01-2035', 'dd-mm-yyyy'), '6', '20', '020', '01', '2035', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12805, to_date('21-01-2035', 'dd-mm-yyyy'), '7', '21', '021', '01', '2035', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12806, to_date('22-01-2035', 'dd-mm-yyyy'), '1', '22', '022', '01', '2035', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12807, to_date('23-01-2035', 'dd-mm-yyyy'), '2', '23', '023', '01', '2035', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12808, to_date('24-01-2035', 'dd-mm-yyyy'), '3', '24', '024', '01', '2035', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12809, to_date('25-01-2035', 'dd-mm-yyyy'), '4', '25', '025', '01', '2035', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12810, to_date('26-01-2035', 'dd-mm-yyyy'), '5', '26', '026', '01', '2035', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12811, to_date('27-01-2035', 'dd-mm-yyyy'), '6', '27', '027', '01', '2035', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12812, to_date('28-01-2035', 'dd-mm-yyyy'), '7', '28', '028', '01', '2035', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12813, to_date('29-01-2035', 'dd-mm-yyyy'), '1', '29', '029', '01', '2035', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12814, to_date('30-01-2035', 'dd-mm-yyyy'), '2', '30', '030', '01', '2035', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12815, to_date('31-01-2035', 'dd-mm-yyyy'), '3', '31', '031', '01', '2035', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12816, to_date('01-02-2035', 'dd-mm-yyyy'), '4', '01', '032', '02', '2035', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12817, to_date('02-02-2035', 'dd-mm-yyyy'), '5', '02', '033', '02', '2035', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12818, to_date('03-02-2035', 'dd-mm-yyyy'), '6', '03', '034', '02', '2035', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12819, to_date('04-02-2035', 'dd-mm-yyyy'), '7', '04', '035', '02', '2035', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12820, to_date('05-02-2035', 'dd-mm-yyyy'), '1', '05', '036', '02', '2035', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12821, to_date('06-02-2035', 'dd-mm-yyyy'), '2', '06', '037', '02', '2035', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12822, to_date('07-02-2035', 'dd-mm-yyyy'), '3', '07', '038', '02', '2035', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12823, to_date('08-02-2035', 'dd-mm-yyyy'), '4', '08', '039', '02', '2035', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12824, to_date('09-02-2035', 'dd-mm-yyyy'), '5', '09', '040', '02', '2035', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12825, to_date('10-02-2035', 'dd-mm-yyyy'), '6', '10', '041', '02', '2035', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12826, to_date('11-02-2035', 'dd-mm-yyyy'), '7', '11', '042', '02', '2035', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12827, to_date('12-02-2035', 'dd-mm-yyyy'), '1', '12', '043', '02', '2035', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12828, to_date('13-02-2035', 'dd-mm-yyyy'), '2', '13', '044', '02', '2035', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12829, to_date('14-02-2035', 'dd-mm-yyyy'), '3', '14', '045', '02', '2035', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12830, to_date('15-02-2035', 'dd-mm-yyyy'), '4', '15', '046', '02', '2035', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12831, to_date('16-02-2035', 'dd-mm-yyyy'), '5', '16', '047', '02', '2035', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12832, to_date('17-02-2035', 'dd-mm-yyyy'), '6', '17', '048', '02', '2035', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12833, to_date('18-02-2035', 'dd-mm-yyyy'), '7', '18', '049', '02', '2035', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12834, to_date('19-02-2035', 'dd-mm-yyyy'), '1', '19', '050', '02', '2035', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12835, to_date('20-02-2035', 'dd-mm-yyyy'), '2', '20', '051', '02', '2035', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12836, to_date('21-02-2035', 'dd-mm-yyyy'), '3', '21', '052', '02', '2035', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12837, to_date('22-02-2035', 'dd-mm-yyyy'), '4', '22', '053', '02', '2035', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12838, to_date('23-02-2035', 'dd-mm-yyyy'), '5', '23', '054', '02', '2035', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12839, to_date('24-02-2035', 'dd-mm-yyyy'), '6', '24', '055', '02', '2035', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12840, to_date('25-02-2035', 'dd-mm-yyyy'), '7', '25', '056', '02', '2035', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12841, to_date('26-02-2035', 'dd-mm-yyyy'), '1', '26', '057', '02', '2035', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12842, to_date('27-02-2035', 'dd-mm-yyyy'), '2', '27', '058', '02', '2035', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12843, to_date('28-02-2035', 'dd-mm-yyyy'), '3', '28', '059', '02', '2035', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12844, to_date('01-03-2035', 'dd-mm-yyyy'), '4', '01', '060', '03', '2035', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12845, to_date('02-03-2035', 'dd-mm-yyyy'), '5', '02', '061', '03', '2035', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12846, to_date('03-03-2035', 'dd-mm-yyyy'), '6', '03', '062', '03', '2035', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12847, to_date('04-03-2035', 'dd-mm-yyyy'), '7', '04', '063', '03', '2035', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12848, to_date('05-03-2035', 'dd-mm-yyyy'), '1', '05', '064', '03', '2035', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12849, to_date('06-03-2035', 'dd-mm-yyyy'), '2', '06', '065', '03', '2035', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12850, to_date('07-03-2035', 'dd-mm-yyyy'), '3', '07', '066', '03', '2035', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12851, to_date('08-03-2035', 'dd-mm-yyyy'), '4', '08', '067', '03', '2035', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12852, to_date('09-03-2035', 'dd-mm-yyyy'), '5', '09', '068', '03', '2035', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12853, to_date('10-03-2035', 'dd-mm-yyyy'), '6', '10', '069', '03', '2035', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12854, to_date('11-03-2035', 'dd-mm-yyyy'), '7', '11', '070', '03', '2035', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12855, to_date('12-03-2035', 'dd-mm-yyyy'), '1', '12', '071', '03', '2035', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12856, to_date('13-03-2035', 'dd-mm-yyyy'), '2', '13', '072', '03', '2035', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12857, to_date('14-03-2035', 'dd-mm-yyyy'), '3', '14', '073', '03', '2035', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12858, to_date('15-03-2035', 'dd-mm-yyyy'), '4', '15', '074', '03', '2035', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12859, to_date('16-03-2035', 'dd-mm-yyyy'), '5', '16', '075', '03', '2035', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12860, to_date('17-03-2035', 'dd-mm-yyyy'), '6', '17', '076', '03', '2035', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12861, to_date('18-03-2035', 'dd-mm-yyyy'), '7', '18', '077', '03', '2035', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12862, to_date('19-03-2035', 'dd-mm-yyyy'), '1', '19', '078', '03', '2035', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12863, to_date('20-03-2035', 'dd-mm-yyyy'), '2', '20', '079', '03', '2035', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12864, to_date('21-03-2035', 'dd-mm-yyyy'), '3', '21', '080', '03', '2035', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12865, to_date('22-03-2035', 'dd-mm-yyyy'), '4', '22', '081', '03', '2035', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12866, to_date('23-03-2035', 'dd-mm-yyyy'), '5', '23', '082', '03', '2035', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12867, to_date('24-03-2035', 'dd-mm-yyyy'), '6', '24', '083', '03', '2035', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12868, to_date('25-03-2035', 'dd-mm-yyyy'), '7', '25', '084', '03', '2035', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12869, to_date('26-03-2035', 'dd-mm-yyyy'), '1', '26', '085', '03', '2035', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12870, to_date('27-03-2035', 'dd-mm-yyyy'), '2', '27', '086', '03', '2035', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12871, to_date('28-03-2035', 'dd-mm-yyyy'), '3', '28', '087', '03', '2035', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12872, to_date('29-03-2035', 'dd-mm-yyyy'), '4', '29', '088', '03', '2035', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12873, to_date('30-03-2035', 'dd-mm-yyyy'), '5', '30', '089', '03', '2035', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12874, to_date('31-03-2035', 'dd-mm-yyyy'), '6', '31', '090', '03', '2035', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12875, to_date('01-04-2035', 'dd-mm-yyyy'), '7', '01', '091', '04', '2035', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12876, to_date('02-04-2035', 'dd-mm-yyyy'), '1', '02', '092', '04', '2035', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12877, to_date('03-04-2035', 'dd-mm-yyyy'), '2', '03', '093', '04', '2035', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12878, to_date('04-04-2035', 'dd-mm-yyyy'), '3', '04', '094', '04', '2035', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12879, to_date('05-04-2035', 'dd-mm-yyyy'), '4', '05', '095', '04', '2035', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12880, to_date('06-04-2035', 'dd-mm-yyyy'), '5', '06', '096', '04', '2035', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12881, to_date('07-04-2035', 'dd-mm-yyyy'), '6', '07', '097', '04', '2035', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12882, to_date('08-04-2035', 'dd-mm-yyyy'), '7', '08', '098', '04', '2035', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12883, to_date('09-04-2035', 'dd-mm-yyyy'), '1', '09', '099', '04', '2035', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12884, to_date('10-04-2035', 'dd-mm-yyyy'), '2', '10', '100', '04', '2035', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12885, to_date('11-04-2035', 'dd-mm-yyyy'), '3', '11', '101', '04', '2035', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12886, to_date('12-04-2035', 'dd-mm-yyyy'), '4', '12', '102', '04', '2035', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12887, to_date('13-04-2035', 'dd-mm-yyyy'), '5', '13', '103', '04', '2035', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12888, to_date('14-04-2035', 'dd-mm-yyyy'), '6', '14', '104', '04', '2035', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12889, to_date('15-04-2035', 'dd-mm-yyyy'), '7', '15', '105', '04', '2035', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12890, to_date('16-04-2035', 'dd-mm-yyyy'), '1', '16', '106', '04', '2035', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12891, to_date('17-04-2035', 'dd-mm-yyyy'), '2', '17', '107', '04', '2035', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12892, to_date('18-04-2035', 'dd-mm-yyyy'), '3', '18', '108', '04', '2035', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12893, to_date('19-04-2035', 'dd-mm-yyyy'), '4', '19', '109', '04', '2035', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12894, to_date('20-04-2035', 'dd-mm-yyyy'), '5', '20', '110', '04', '2035', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12895, to_date('21-04-2035', 'dd-mm-yyyy'), '6', '21', '111', '04', '2035', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12896, to_date('22-04-2035', 'dd-mm-yyyy'), '7', '22', '112', '04', '2035', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12897, to_date('23-04-2035', 'dd-mm-yyyy'), '1', '23', '113', '04', '2035', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12898, to_date('24-04-2035', 'dd-mm-yyyy'), '2', '24', '114', '04', '2035', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12899, to_date('25-04-2035', 'dd-mm-yyyy'), '3', '25', '115', '04', '2035', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12900, to_date('26-04-2035', 'dd-mm-yyyy'), '4', '26', '116', '04', '2035', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12901, to_date('27-04-2035', 'dd-mm-yyyy'), '5', '27', '117', '04', '2035', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12902, to_date('28-04-2035', 'dd-mm-yyyy'), '6', '28', '118', '04', '2035', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12903, to_date('29-04-2035', 'dd-mm-yyyy'), '7', '29', '119', '04', '2035', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12904, to_date('30-04-2035', 'dd-mm-yyyy'), '1', '30', '120', '04', '2035', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12905, to_date('01-05-2035', 'dd-mm-yyyy'), '2', '01', '121', '05', '2035', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12906, to_date('02-05-2035', 'dd-mm-yyyy'), '3', '02', '122', '05', '2035', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14497, to_date('09-09-2039', 'dd-mm-yyyy'), '5', '09', '252', '09', '2039', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14498, to_date('10-09-2039', 'dd-mm-yyyy'), '6', '10', '253', '09', '2039', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14499, to_date('11-09-2039', 'dd-mm-yyyy'), '7', '11', '254', '09', '2039', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14500, to_date('12-09-2039', 'dd-mm-yyyy'), '1', '12', '255', '09', '2039', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14501, to_date('13-09-2039', 'dd-mm-yyyy'), '2', '13', '256', '09', '2039', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14502, to_date('14-09-2039', 'dd-mm-yyyy'), '3', '14', '257', '09', '2039', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14503, to_date('15-09-2039', 'dd-mm-yyyy'), '4', '15', '258', '09', '2039', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14504, to_date('16-09-2039', 'dd-mm-yyyy'), '5', '16', '259', '09', '2039', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14505, to_date('17-09-2039', 'dd-mm-yyyy'), '6', '17', '260', '09', '2039', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14506, to_date('18-09-2039', 'dd-mm-yyyy'), '7', '18', '261', '09', '2039', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14507, to_date('19-09-2039', 'dd-mm-yyyy'), '1', '19', '262', '09', '2039', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14508, to_date('20-09-2039', 'dd-mm-yyyy'), '2', '20', '263', '09', '2039', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14509, to_date('21-09-2039', 'dd-mm-yyyy'), '3', '21', '264', '09', '2039', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14510, to_date('22-09-2039', 'dd-mm-yyyy'), '4', '22', '265', '09', '2039', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14511, to_date('23-09-2039', 'dd-mm-yyyy'), '5', '23', '266', '09', '2039', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14512, to_date('24-09-2039', 'dd-mm-yyyy'), '6', '24', '267', '09', '2039', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14513, to_date('25-09-2039', 'dd-mm-yyyy'), '7', '25', '268', '09', '2039', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14514, to_date('26-09-2039', 'dd-mm-yyyy'), '1', '26', '269', '09', '2039', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14515, to_date('27-09-2039', 'dd-mm-yyyy'), '2', '27', '270', '09', '2039', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14516, to_date('28-09-2039', 'dd-mm-yyyy'), '3', '28', '271', '09', '2039', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14517, to_date('29-09-2039', 'dd-mm-yyyy'), '4', '29', '272', '09', '2039', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14518, to_date('30-09-2039', 'dd-mm-yyyy'), '5', '30', '273', '09', '2039', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14519, to_date('01-10-2039', 'dd-mm-yyyy'), '6', '01', '274', '10', '2039', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14520, to_date('02-10-2039', 'dd-mm-yyyy'), '7', '02', '275', '10', '2039', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14521, to_date('03-10-2039', 'dd-mm-yyyy'), '1', '03', '276', '10', '2039', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14522, to_date('04-10-2039', 'dd-mm-yyyy'), '2', '04', '277', '10', '2039', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14523, to_date('05-10-2039', 'dd-mm-yyyy'), '3', '05', '278', '10', '2039', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14524, to_date('06-10-2039', 'dd-mm-yyyy'), '4', '06', '279', '10', '2039', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14525, to_date('07-10-2039', 'dd-mm-yyyy'), '5', '07', '280', '10', '2039', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14526, to_date('08-10-2039', 'dd-mm-yyyy'), '6', '08', '281', '10', '2039', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14527, to_date('09-10-2039', 'dd-mm-yyyy'), '7', '09', '282', '10', '2039', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14528, to_date('10-10-2039', 'dd-mm-yyyy'), '1', '10', '283', '10', '2039', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14529, to_date('11-10-2039', 'dd-mm-yyyy'), '2', '11', '284', '10', '2039', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14530, to_date('12-10-2039', 'dd-mm-yyyy'), '3', '12', '285', '10', '2039', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14531, to_date('13-10-2039', 'dd-mm-yyyy'), '4', '13', '286', '10', '2039', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14532, to_date('14-10-2039', 'dd-mm-yyyy'), '5', '14', '287', '10', '2039', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14533, to_date('15-10-2039', 'dd-mm-yyyy'), '6', '15', '288', '10', '2039', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14534, to_date('16-10-2039', 'dd-mm-yyyy'), '7', '16', '289', '10', '2039', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14535, to_date('17-10-2039', 'dd-mm-yyyy'), '1', '17', '290', '10', '2039', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14536, to_date('18-10-2039', 'dd-mm-yyyy'), '2', '18', '291', '10', '2039', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14537, to_date('19-10-2039', 'dd-mm-yyyy'), '3', '19', '292', '10', '2039', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14538, to_date('20-10-2039', 'dd-mm-yyyy'), '4', '20', '293', '10', '2039', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14539, to_date('21-10-2039', 'dd-mm-yyyy'), '5', '21', '294', '10', '2039', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14540, to_date('22-10-2039', 'dd-mm-yyyy'), '6', '22', '295', '10', '2039', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14541, to_date('23-10-2039', 'dd-mm-yyyy'), '7', '23', '296', '10', '2039', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14542, to_date('24-10-2039', 'dd-mm-yyyy'), '1', '24', '297', '10', '2039', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14543, to_date('25-10-2039', 'dd-mm-yyyy'), '2', '25', '298', '10', '2039', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14544, to_date('26-10-2039', 'dd-mm-yyyy'), '3', '26', '299', '10', '2039', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14545, to_date('27-10-2039', 'dd-mm-yyyy'), '4', '27', '300', '10', '2039', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14546, to_date('28-10-2039', 'dd-mm-yyyy'), '5', '28', '301', '10', '2039', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14547, to_date('29-10-2039', 'dd-mm-yyyy'), '6', '29', '302', '10', '2039', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14548, to_date('30-10-2039', 'dd-mm-yyyy'), '7', '30', '303', '10', '2039', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14549, to_date('31-10-2039', 'dd-mm-yyyy'), '1', '31', '304', '10', '2039', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14550, to_date('01-11-2039', 'dd-mm-yyyy'), '2', '01', '305', '11', '2039', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14551, to_date('02-11-2039', 'dd-mm-yyyy'), '3', '02', '306', '11', '2039', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14552, to_date('03-11-2039', 'dd-mm-yyyy'), '4', '03', '307', '11', '2039', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14553, to_date('04-11-2039', 'dd-mm-yyyy'), '5', '04', '308', '11', '2039', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14554, to_date('05-11-2039', 'dd-mm-yyyy'), '6', '05', '309', '11', '2039', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14555, to_date('06-11-2039', 'dd-mm-yyyy'), '7', '06', '310', '11', '2039', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14556, to_date('07-11-2039', 'dd-mm-yyyy'), '1', '07', '311', '11', '2039', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14557, to_date('08-11-2039', 'dd-mm-yyyy'), '2', '08', '312', '11', '2039', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14558, to_date('09-11-2039', 'dd-mm-yyyy'), '3', '09', '313', '11', '2039', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14559, to_date('10-11-2039', 'dd-mm-yyyy'), '4', '10', '314', '11', '2039', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14560, to_date('11-11-2039', 'dd-mm-yyyy'), '5', '11', '315', '11', '2039', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14561, to_date('12-11-2039', 'dd-mm-yyyy'), '6', '12', '316', '11', '2039', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14562, to_date('13-11-2039', 'dd-mm-yyyy'), '7', '13', '317', '11', '2039', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14563, to_date('14-11-2039', 'dd-mm-yyyy'), '1', '14', '318', '11', '2039', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14564, to_date('15-11-2039', 'dd-mm-yyyy'), '2', '15', '319', '11', '2039', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14565, to_date('16-11-2039', 'dd-mm-yyyy'), '3', '16', '320', '11', '2039', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14566, to_date('17-11-2039', 'dd-mm-yyyy'), '4', '17', '321', '11', '2039', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14567, to_date('18-11-2039', 'dd-mm-yyyy'), '5', '18', '322', '11', '2039', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14568, to_date('19-11-2039', 'dd-mm-yyyy'), '6', '19', '323', '11', '2039', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14569, to_date('20-11-2039', 'dd-mm-yyyy'), '7', '20', '324', '11', '2039', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14570, to_date('21-11-2039', 'dd-mm-yyyy'), '1', '21', '325', '11', '2039', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14571, to_date('22-11-2039', 'dd-mm-yyyy'), '2', '22', '326', '11', '2039', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14572, to_date('23-11-2039', 'dd-mm-yyyy'), '3', '23', '327', '11', '2039', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14573, to_date('24-11-2039', 'dd-mm-yyyy'), '4', '24', '328', '11', '2039', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14574, to_date('25-11-2039', 'dd-mm-yyyy'), '5', '25', '329', '11', '2039', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14575, to_date('26-11-2039', 'dd-mm-yyyy'), '6', '26', '330', '11', '2039', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14576, to_date('27-11-2039', 'dd-mm-yyyy'), '7', '27', '331', '11', '2039', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14577, to_date('28-11-2039', 'dd-mm-yyyy'), '1', '28', '332', '11', '2039', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14578, to_date('29-11-2039', 'dd-mm-yyyy'), '2', '29', '333', '11', '2039', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14579, to_date('30-11-2039', 'dd-mm-yyyy'), '3', '30', '334', '11', '2039', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14580, to_date('01-12-2039', 'dd-mm-yyyy'), '4', '01', '335', '12', '2039', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14581, to_date('02-12-2039', 'dd-mm-yyyy'), '5', '02', '336', '12', '2039', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14582, to_date('03-12-2039', 'dd-mm-yyyy'), '6', '03', '337', '12', '2039', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14583, to_date('04-12-2039', 'dd-mm-yyyy'), '7', '04', '338', '12', '2039', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14584, to_date('05-12-2039', 'dd-mm-yyyy'), '1', '05', '339', '12', '2039', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14585, to_date('06-12-2039', 'dd-mm-yyyy'), '2', '06', '340', '12', '2039', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14586, to_date('07-12-2039', 'dd-mm-yyyy'), '3', '07', '341', '12', '2039', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14587, to_date('08-12-2039', 'dd-mm-yyyy'), '4', '08', '342', '12', '2039', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14588, to_date('09-12-2039', 'dd-mm-yyyy'), '5', '09', '343', '12', '2039', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14589, to_date('10-12-2039', 'dd-mm-yyyy'), '6', '10', '344', '12', '2039', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14590, to_date('11-12-2039', 'dd-mm-yyyy'), '7', '11', '345', '12', '2039', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14591, to_date('12-12-2039', 'dd-mm-yyyy'), '1', '12', '346', '12', '2039', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14592, to_date('13-12-2039', 'dd-mm-yyyy'), '2', '13', '347', '12', '2039', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14593, to_date('14-12-2039', 'dd-mm-yyyy'), '3', '14', '348', '12', '2039', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14594, to_date('15-12-2039', 'dd-mm-yyyy'), '4', '15', '349', '12', '2039', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14595, to_date('16-12-2039', 'dd-mm-yyyy'), '5', '16', '350', '12', '2039', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14596, to_date('17-12-2039', 'dd-mm-yyyy'), '6', '17', '351', '12', '2039', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14597, to_date('18-12-2039', 'dd-mm-yyyy'), '7', '18', '352', '12', '2039', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14598, to_date('19-12-2039', 'dd-mm-yyyy'), '1', '19', '353', '12', '2039', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14599, to_date('20-12-2039', 'dd-mm-yyyy'), '2', '20', '354', '12', '2039', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14600, to_date('21-12-2039', 'dd-mm-yyyy'), '3', '21', '355', '12', '2039', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14601, to_date('22-12-2039', 'dd-mm-yyyy'), '4', '22', '356', '12', '2039', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14602, to_date('23-12-2039', 'dd-mm-yyyy'), '5', '23', '357', '12', '2039', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16087, to_date('16-01-2044', 'dd-mm-yyyy'), '6', '16', '016', '01', '2044', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16088, to_date('17-01-2044', 'dd-mm-yyyy'), '7', '17', '017', '01', '2044', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16089, to_date('18-01-2044', 'dd-mm-yyyy'), '1', '18', '018', '01', '2044', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16090, to_date('19-01-2044', 'dd-mm-yyyy'), '2', '19', '019', '01', '2044', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16091, to_date('20-01-2044', 'dd-mm-yyyy'), '3', '20', '020', '01', '2044', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16092, to_date('21-01-2044', 'dd-mm-yyyy'), '4', '21', '021', '01', '2044', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16093, to_date('22-01-2044', 'dd-mm-yyyy'), '5', '22', '022', '01', '2044', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16094, to_date('23-01-2044', 'dd-mm-yyyy'), '6', '23', '023', '01', '2044', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16095, to_date('24-01-2044', 'dd-mm-yyyy'), '7', '24', '024', '01', '2044', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16096, to_date('25-01-2044', 'dd-mm-yyyy'), '1', '25', '025', '01', '2044', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16097, to_date('26-01-2044', 'dd-mm-yyyy'), '2', '26', '026', '01', '2044', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16098, to_date('27-01-2044', 'dd-mm-yyyy'), '3', '27', '027', '01', '2044', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16099, to_date('28-01-2044', 'dd-mm-yyyy'), '4', '28', '028', '01', '2044', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16100, to_date('29-01-2044', 'dd-mm-yyyy'), '5', '29', '029', '01', '2044', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16101, to_date('30-01-2044', 'dd-mm-yyyy'), '6', '30', '030', '01', '2044', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16102, to_date('31-01-2044', 'dd-mm-yyyy'), '7', '31', '031', '01', '2044', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16103, to_date('01-02-2044', 'dd-mm-yyyy'), '1', '01', '032', '02', '2044', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16104, to_date('02-02-2044', 'dd-mm-yyyy'), '2', '02', '033', '02', '2044', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16105, to_date('03-02-2044', 'dd-mm-yyyy'), '3', '03', '034', '02', '2044', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16106, to_date('04-02-2044', 'dd-mm-yyyy'), '4', '04', '035', '02', '2044', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16107, to_date('05-02-2044', 'dd-mm-yyyy'), '5', '05', '036', '02', '2044', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16108, to_date('06-02-2044', 'dd-mm-yyyy'), '6', '06', '037', '02', '2044', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16109, to_date('07-02-2044', 'dd-mm-yyyy'), '7', '07', '038', '02', '2044', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16110, to_date('08-02-2044', 'dd-mm-yyyy'), '1', '08', '039', '02', '2044', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16111, to_date('09-02-2044', 'dd-mm-yyyy'), '2', '09', '040', '02', '2044', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16112, to_date('10-02-2044', 'dd-mm-yyyy'), '3', '10', '041', '02', '2044', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16113, to_date('11-02-2044', 'dd-mm-yyyy'), '4', '11', '042', '02', '2044', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16114, to_date('12-02-2044', 'dd-mm-yyyy'), '5', '12', '043', '02', '2044', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16115, to_date('13-02-2044', 'dd-mm-yyyy'), '6', '13', '044', '02', '2044', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16116, to_date('14-02-2044', 'dd-mm-yyyy'), '7', '14', '045', '02', '2044', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16117, to_date('15-02-2044', 'dd-mm-yyyy'), '1', '15', '046', '02', '2044', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16118, to_date('16-02-2044', 'dd-mm-yyyy'), '2', '16', '047', '02', '2044', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16119, to_date('17-02-2044', 'dd-mm-yyyy'), '3', '17', '048', '02', '2044', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16120, to_date('18-02-2044', 'dd-mm-yyyy'), '4', '18', '049', '02', '2044', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16121, to_date('19-02-2044', 'dd-mm-yyyy'), '5', '19', '050', '02', '2044', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16122, to_date('20-02-2044', 'dd-mm-yyyy'), '6', '20', '051', '02', '2044', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16123, to_date('21-02-2044', 'dd-mm-yyyy'), '7', '21', '052', '02', '2044', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16124, to_date('22-02-2044', 'dd-mm-yyyy'), '1', '22', '053', '02', '2044', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16125, to_date('23-02-2044', 'dd-mm-yyyy'), '2', '23', '054', '02', '2044', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16126, to_date('24-02-2044', 'dd-mm-yyyy'), '3', '24', '055', '02', '2044', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16127, to_date('25-02-2044', 'dd-mm-yyyy'), '4', '25', '056', '02', '2044', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16128, to_date('26-02-2044', 'dd-mm-yyyy'), '5', '26', '057', '02', '2044', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16129, to_date('27-02-2044', 'dd-mm-yyyy'), '6', '27', '058', '02', '2044', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16130, to_date('28-02-2044', 'dd-mm-yyyy'), '7', '28', '059', '02', '2044', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16131, to_date('29-02-2044', 'dd-mm-yyyy'), '1', '29', '060', '02', '2044', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16132, to_date('01-03-2044', 'dd-mm-yyyy'), '2', '01', '061', '03', '2044', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16133, to_date('02-03-2044', 'dd-mm-yyyy'), '3', '02', '062', '03', '2044', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16134, to_date('03-03-2044', 'dd-mm-yyyy'), '4', '03', '063', '03', '2044', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16135, to_date('04-03-2044', 'dd-mm-yyyy'), '5', '04', '064', '03', '2044', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16136, to_date('05-03-2044', 'dd-mm-yyyy'), '6', '05', '065', '03', '2044', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16137, to_date('06-03-2044', 'dd-mm-yyyy'), '7', '06', '066', '03', '2044', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16138, to_date('07-03-2044', 'dd-mm-yyyy'), '1', '07', '067', '03', '2044', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16139, to_date('08-03-2044', 'dd-mm-yyyy'), '2', '08', '068', '03', '2044', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16140, to_date('09-03-2044', 'dd-mm-yyyy'), '3', '09', '069', '03', '2044', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16141, to_date('10-03-2044', 'dd-mm-yyyy'), '4', '10', '070', '03', '2044', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16142, to_date('11-03-2044', 'dd-mm-yyyy'), '5', '11', '071', '03', '2044', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16143, to_date('12-03-2044', 'dd-mm-yyyy'), '6', '12', '072', '03', '2044', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16144, to_date('13-03-2044', 'dd-mm-yyyy'), '7', '13', '073', '03', '2044', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16145, to_date('14-03-2044', 'dd-mm-yyyy'), '1', '14', '074', '03', '2044', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16146, to_date('15-03-2044', 'dd-mm-yyyy'), '2', '15', '075', '03', '2044', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16147, to_date('16-03-2044', 'dd-mm-yyyy'), '3', '16', '076', '03', '2044', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16148, to_date('17-03-2044', 'dd-mm-yyyy'), '4', '17', '077', '03', '2044', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16149, to_date('18-03-2044', 'dd-mm-yyyy'), '5', '18', '078', '03', '2044', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16150, to_date('19-03-2044', 'dd-mm-yyyy'), '6', '19', '079', '03', '2044', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16151, to_date('20-03-2044', 'dd-mm-yyyy'), '7', '20', '080', '03', '2044', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16152, to_date('21-03-2044', 'dd-mm-yyyy'), '1', '21', '081', '03', '2044', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16153, to_date('22-03-2044', 'dd-mm-yyyy'), '2', '22', '082', '03', '2044', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16154, to_date('23-03-2044', 'dd-mm-yyyy'), '3', '23', '083', '03', '2044', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16155, to_date('24-03-2044', 'dd-mm-yyyy'), '4', '24', '084', '03', '2044', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16156, to_date('25-03-2044', 'dd-mm-yyyy'), '5', '25', '085', '03', '2044', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16157, to_date('26-03-2044', 'dd-mm-yyyy'), '6', '26', '086', '03', '2044', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16158, to_date('27-03-2044', 'dd-mm-yyyy'), '7', '27', '087', '03', '2044', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16159, to_date('28-03-2044', 'dd-mm-yyyy'), '1', '28', '088', '03', '2044', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16160, to_date('29-03-2044', 'dd-mm-yyyy'), '2', '29', '089', '03', '2044', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16161, to_date('30-03-2044', 'dd-mm-yyyy'), '3', '30', '090', '03', '2044', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16162, to_date('31-03-2044', 'dd-mm-yyyy'), '4', '31', '091', '03', '2044', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16163, to_date('01-04-2044', 'dd-mm-yyyy'), '5', '01', '092', '04', '2044', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16164, to_date('02-04-2044', 'dd-mm-yyyy'), '6', '02', '093', '04', '2044', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16165, to_date('03-04-2044', 'dd-mm-yyyy'), '7', '03', '094', '04', '2044', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16166, to_date('04-04-2044', 'dd-mm-yyyy'), '1', '04', '095', '04', '2044', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16167, to_date('05-04-2044', 'dd-mm-yyyy'), '2', '05', '096', '04', '2044', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16168, to_date('06-04-2044', 'dd-mm-yyyy'), '3', '06', '097', '04', '2044', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16169, to_date('07-04-2044', 'dd-mm-yyyy'), '4', '07', '098', '04', '2044', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16170, to_date('08-04-2044', 'dd-mm-yyyy'), '5', '08', '099', '04', '2044', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16171, to_date('09-04-2044', 'dd-mm-yyyy'), '6', '09', '100', '04', '2044', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16172, to_date('10-04-2044', 'dd-mm-yyyy'), '7', '10', '101', '04', '2044', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16173, to_date('11-04-2044', 'dd-mm-yyyy'), '1', '11', '102', '04', '2044', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16174, to_date('12-04-2044', 'dd-mm-yyyy'), '2', '12', '103', '04', '2044', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16175, to_date('13-04-2044', 'dd-mm-yyyy'), '3', '13', '104', '04', '2044', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16176, to_date('14-04-2044', 'dd-mm-yyyy'), '4', '14', '105', '04', '2044', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16177, to_date('15-04-2044', 'dd-mm-yyyy'), '5', '15', '106', '04', '2044', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16178, to_date('16-04-2044', 'dd-mm-yyyy'), '6', '16', '107', '04', '2044', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16179, to_date('17-04-2044', 'dd-mm-yyyy'), '7', '17', '108', '04', '2044', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16180, to_date('18-04-2044', 'dd-mm-yyyy'), '1', '18', '109', '04', '2044', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16181, to_date('19-04-2044', 'dd-mm-yyyy'), '2', '19', '110', '04', '2044', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16182, to_date('20-04-2044', 'dd-mm-yyyy'), '3', '20', '111', '04', '2044', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16183, to_date('21-04-2044', 'dd-mm-yyyy'), '4', '21', '112', '04', '2044', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16184, to_date('22-04-2044', 'dd-mm-yyyy'), '5', '22', '113', '04', '2044', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16185, to_date('23-04-2044', 'dd-mm-yyyy'), '6', '23', '114', '04', '2044', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16186, to_date('24-04-2044', 'dd-mm-yyyy'), '7', '24', '115', '04', '2044', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16187, to_date('25-04-2044', 'dd-mm-yyyy'), '1', '25', '116', '04', '2044', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16188, to_date('26-04-2044', 'dd-mm-yyyy'), '2', '26', '117', '04', '2044', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16189, to_date('27-04-2044', 'dd-mm-yyyy'), '3', '27', '118', '04', '2044', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16190, to_date('28-04-2044', 'dd-mm-yyyy'), '4', '28', '119', '04', '2044', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16191, to_date('29-04-2044', 'dd-mm-yyyy'), '5', '29', '120', '04', '2044', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16192, to_date('30-04-2044', 'dd-mm-yyyy'), '6', '30', '121', '04', '2044', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17677, to_date('24-05-2048', 'dd-mm-yyyy'), '7', '24', '145', '05', '2048', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17678, to_date('25-05-2048', 'dd-mm-yyyy'), '1', '25', '146', '05', '2048', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17679, to_date('26-05-2048', 'dd-mm-yyyy'), '2', '26', '147', '05', '2048', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17680, to_date('27-05-2048', 'dd-mm-yyyy'), '3', '27', '148', '05', '2048', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17681, to_date('28-05-2048', 'dd-mm-yyyy'), '4', '28', '149', '05', '2048', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17682, to_date('29-05-2048', 'dd-mm-yyyy'), '5', '29', '150', '05', '2048', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17683, to_date('30-05-2048', 'dd-mm-yyyy'), '6', '30', '151', '05', '2048', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17684, to_date('31-05-2048', 'dd-mm-yyyy'), '7', '31', '152', '05', '2048', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17685, to_date('01-06-2048', 'dd-mm-yyyy'), '1', '01', '153', '06', '2048', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17686, to_date('02-06-2048', 'dd-mm-yyyy'), '2', '02', '154', '06', '2048', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17687, to_date('03-06-2048', 'dd-mm-yyyy'), '3', '03', '155', '06', '2048', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17688, to_date('04-06-2048', 'dd-mm-yyyy'), '4', '04', '156', '06', '2048', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17689, to_date('05-06-2048', 'dd-mm-yyyy'), '5', '05', '157', '06', '2048', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17690, to_date('06-06-2048', 'dd-mm-yyyy'), '6', '06', '158', '06', '2048', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17691, to_date('07-06-2048', 'dd-mm-yyyy'), '7', '07', '159', '06', '2048', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17692, to_date('08-06-2048', 'dd-mm-yyyy'), '1', '08', '160', '06', '2048', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17693, to_date('09-06-2048', 'dd-mm-yyyy'), '2', '09', '161', '06', '2048', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17694, to_date('10-06-2048', 'dd-mm-yyyy'), '3', '10', '162', '06', '2048', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17695, to_date('11-06-2048', 'dd-mm-yyyy'), '4', '11', '163', '06', '2048', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17696, to_date('12-06-2048', 'dd-mm-yyyy'), '5', '12', '164', '06', '2048', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17697, to_date('13-06-2048', 'dd-mm-yyyy'), '6', '13', '165', '06', '2048', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17698, to_date('14-06-2048', 'dd-mm-yyyy'), '7', '14', '166', '06', '2048', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17699, to_date('15-06-2048', 'dd-mm-yyyy'), '1', '15', '167', '06', '2048', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17700, to_date('16-06-2048', 'dd-mm-yyyy'), '2', '16', '168', '06', '2048', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17701, to_date('17-06-2048', 'dd-mm-yyyy'), '3', '17', '169', '06', '2048', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17702, to_date('18-06-2048', 'dd-mm-yyyy'), '4', '18', '170', '06', '2048', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17703, to_date('19-06-2048', 'dd-mm-yyyy'), '5', '19', '171', '06', '2048', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17704, to_date('20-06-2048', 'dd-mm-yyyy'), '6', '20', '172', '06', '2048', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17705, to_date('21-06-2048', 'dd-mm-yyyy'), '7', '21', '173', '06', '2048', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17706, to_date('22-06-2048', 'dd-mm-yyyy'), '1', '22', '174', '06', '2048', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17707, to_date('23-06-2048', 'dd-mm-yyyy'), '2', '23', '175', '06', '2048', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17708, to_date('24-06-2048', 'dd-mm-yyyy'), '3', '24', '176', '06', '2048', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17709, to_date('25-06-2048', 'dd-mm-yyyy'), '4', '25', '177', '06', '2048', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17710, to_date('26-06-2048', 'dd-mm-yyyy'), '5', '26', '178', '06', '2048', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17711, to_date('27-06-2048', 'dd-mm-yyyy'), '6', '27', '179', '06', '2048', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17712, to_date('28-06-2048', 'dd-mm-yyyy'), '7', '28', '180', '06', '2048', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17713, to_date('29-06-2048', 'dd-mm-yyyy'), '1', '29', '181', '06', '2048', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17714, to_date('30-06-2048', 'dd-mm-yyyy'), '2', '30', '182', '06', '2048', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17715, to_date('01-07-2048', 'dd-mm-yyyy'), '3', '01', '183', '07', '2048', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17716, to_date('02-07-2048', 'dd-mm-yyyy'), '4', '02', '184', '07', '2048', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17717, to_date('03-07-2048', 'dd-mm-yyyy'), '5', '03', '185', '07', '2048', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17718, to_date('04-07-2048', 'dd-mm-yyyy'), '6', '04', '186', '07', '2048', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17719, to_date('05-07-2048', 'dd-mm-yyyy'), '7', '05', '187', '07', '2048', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17720, to_date('06-07-2048', 'dd-mm-yyyy'), '1', '06', '188', '07', '2048', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17721, to_date('07-07-2048', 'dd-mm-yyyy'), '2', '07', '189', '07', '2048', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17722, to_date('08-07-2048', 'dd-mm-yyyy'), '3', '08', '190', '07', '2048', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17723, to_date('09-07-2048', 'dd-mm-yyyy'), '4', '09', '191', '07', '2048', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17724, to_date('10-07-2048', 'dd-mm-yyyy'), '5', '10', '192', '07', '2048', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17725, to_date('11-07-2048', 'dd-mm-yyyy'), '6', '11', '193', '07', '2048', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17726, to_date('12-07-2048', 'dd-mm-yyyy'), '7', '12', '194', '07', '2048', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17727, to_date('13-07-2048', 'dd-mm-yyyy'), '1', '13', '195', '07', '2048', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17728, to_date('14-07-2048', 'dd-mm-yyyy'), '2', '14', '196', '07', '2048', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17729, to_date('15-07-2048', 'dd-mm-yyyy'), '3', '15', '197', '07', '2048', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17730, to_date('16-07-2048', 'dd-mm-yyyy'), '4', '16', '198', '07', '2048', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17731, to_date('17-07-2048', 'dd-mm-yyyy'), '5', '17', '199', '07', '2048', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17732, to_date('18-07-2048', 'dd-mm-yyyy'), '6', '18', '200', '07', '2048', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17733, to_date('19-07-2048', 'dd-mm-yyyy'), '7', '19', '201', '07', '2048', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17734, to_date('20-07-2048', 'dd-mm-yyyy'), '1', '20', '202', '07', '2048', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17735, to_date('21-07-2048', 'dd-mm-yyyy'), '2', '21', '203', '07', '2048', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17736, to_date('22-07-2048', 'dd-mm-yyyy'), '3', '22', '204', '07', '2048', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17737, to_date('23-07-2048', 'dd-mm-yyyy'), '4', '23', '205', '07', '2048', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17738, to_date('24-07-2048', 'dd-mm-yyyy'), '5', '24', '206', '07', '2048', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17739, to_date('25-07-2048', 'dd-mm-yyyy'), '6', '25', '207', '07', '2048', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17740, to_date('26-07-2048', 'dd-mm-yyyy'), '7', '26', '208', '07', '2048', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17741, to_date('27-07-2048', 'dd-mm-yyyy'), '1', '27', '209', '07', '2048', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17742, to_date('28-07-2048', 'dd-mm-yyyy'), '2', '28', '210', '07', '2048', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17743, to_date('29-07-2048', 'dd-mm-yyyy'), '3', '29', '211', '07', '2048', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17744, to_date('30-07-2048', 'dd-mm-yyyy'), '4', '30', '212', '07', '2048', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17745, to_date('31-07-2048', 'dd-mm-yyyy'), '5', '31', '213', '07', '2048', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17746, to_date('01-08-2048', 'dd-mm-yyyy'), '6', '01', '214', '08', '2048', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17747, to_date('02-08-2048', 'dd-mm-yyyy'), '7', '02', '215', '08', '2048', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17748, to_date('03-08-2048', 'dd-mm-yyyy'), '1', '03', '216', '08', '2048', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17749, to_date('04-08-2048', 'dd-mm-yyyy'), '2', '04', '217', '08', '2048', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17750, to_date('05-08-2048', 'dd-mm-yyyy'), '3', '05', '218', '08', '2048', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17751, to_date('06-08-2048', 'dd-mm-yyyy'), '4', '06', '219', '08', '2048', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17752, to_date('07-08-2048', 'dd-mm-yyyy'), '5', '07', '220', '08', '2048', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17753, to_date('08-08-2048', 'dd-mm-yyyy'), '6', '08', '221', '08', '2048', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17754, to_date('09-08-2048', 'dd-mm-yyyy'), '7', '09', '222', '08', '2048', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17755, to_date('10-08-2048', 'dd-mm-yyyy'), '1', '10', '223', '08', '2048', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17756, to_date('11-08-2048', 'dd-mm-yyyy'), '2', '11', '224', '08', '2048', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17757, to_date('12-08-2048', 'dd-mm-yyyy'), '3', '12', '225', '08', '2048', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17758, to_date('13-08-2048', 'dd-mm-yyyy'), '4', '13', '226', '08', '2048', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17759, to_date('14-08-2048', 'dd-mm-yyyy'), '5', '14', '227', '08', '2048', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17760, to_date('15-08-2048', 'dd-mm-yyyy'), '6', '15', '228', '08', '2048', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17761, to_date('16-08-2048', 'dd-mm-yyyy'), '7', '16', '229', '08', '2048', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17762, to_date('17-08-2048', 'dd-mm-yyyy'), '1', '17', '230', '08', '2048', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17763, to_date('18-08-2048', 'dd-mm-yyyy'), '2', '18', '231', '08', '2048', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17764, to_date('19-08-2048', 'dd-mm-yyyy'), '3', '19', '232', '08', '2048', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17765, to_date('20-08-2048', 'dd-mm-yyyy'), '4', '20', '233', '08', '2048', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17766, to_date('21-08-2048', 'dd-mm-yyyy'), '5', '21', '234', '08', '2048', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17767, to_date('22-08-2048', 'dd-mm-yyyy'), '6', '22', '235', '08', '2048', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17768, to_date('23-08-2048', 'dd-mm-yyyy'), '7', '23', '236', '08', '2048', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17769, to_date('24-08-2048', 'dd-mm-yyyy'), '1', '24', '237', '08', '2048', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17770, to_date('25-08-2048', 'dd-mm-yyyy'), '2', '25', '238', '08', '2048', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17771, to_date('26-08-2048', 'dd-mm-yyyy'), '3', '26', '239', '08', '2048', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17772, to_date('27-08-2048', 'dd-mm-yyyy'), '4', '27', '240', '08', '2048', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17773, to_date('28-08-2048', 'dd-mm-yyyy'), '5', '28', '241', '08', '2048', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17774, to_date('29-08-2048', 'dd-mm-yyyy'), '6', '29', '242', '08', '2048', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17775, to_date('30-08-2048', 'dd-mm-yyyy'), '7', '30', '243', '08', '2048', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17776, to_date('31-08-2048', 'dd-mm-yyyy'), '1', '31', '244', '08', '2048', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17777, to_date('01-09-2048', 'dd-mm-yyyy'), '2', '01', '245', '09', '2048', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17778, to_date('02-09-2048', 'dd-mm-yyyy'), '3', '02', '246', '09', '2048', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17779, to_date('03-09-2048', 'dd-mm-yyyy'), '4', '03', '247', '09', '2048', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17780, to_date('04-09-2048', 'dd-mm-yyyy'), '5', '04', '248', '09', '2048', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17781, to_date('05-09-2048', 'dd-mm-yyyy'), '6', '05', '249', '09', '2048', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17782, to_date('06-09-2048', 'dd-mm-yyyy'), '7', '06', '250', '09', '2048', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12907, to_date('03-05-2035', 'dd-mm-yyyy'), '4', '03', '123', '05', '2035', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12908, to_date('04-05-2035', 'dd-mm-yyyy'), '5', '04', '124', '05', '2035', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12909, to_date('05-05-2035', 'dd-mm-yyyy'), '6', '05', '125', '05', '2035', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12910, to_date('06-05-2035', 'dd-mm-yyyy'), '7', '06', '126', '05', '2035', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12911, to_date('07-05-2035', 'dd-mm-yyyy'), '1', '07', '127', '05', '2035', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12912, to_date('08-05-2035', 'dd-mm-yyyy'), '2', '08', '128', '05', '2035', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12913, to_date('09-05-2035', 'dd-mm-yyyy'), '3', '09', '129', '05', '2035', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12914, to_date('10-05-2035', 'dd-mm-yyyy'), '4', '10', '130', '05', '2035', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12915, to_date('11-05-2035', 'dd-mm-yyyy'), '5', '11', '131', '05', '2035', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12916, to_date('12-05-2035', 'dd-mm-yyyy'), '6', '12', '132', '05', '2035', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12917, to_date('13-05-2035', 'dd-mm-yyyy'), '7', '13', '133', '05', '2035', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12918, to_date('14-05-2035', 'dd-mm-yyyy'), '1', '14', '134', '05', '2035', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12919, to_date('15-05-2035', 'dd-mm-yyyy'), '2', '15', '135', '05', '2035', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12920, to_date('16-05-2035', 'dd-mm-yyyy'), '3', '16', '136', '05', '2035', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12921, to_date('17-05-2035', 'dd-mm-yyyy'), '4', '17', '137', '05', '2035', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12922, to_date('18-05-2035', 'dd-mm-yyyy'), '5', '18', '138', '05', '2035', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12923, to_date('19-05-2035', 'dd-mm-yyyy'), '6', '19', '139', '05', '2035', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12924, to_date('20-05-2035', 'dd-mm-yyyy'), '7', '20', '140', '05', '2035', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12925, to_date('21-05-2035', 'dd-mm-yyyy'), '1', '21', '141', '05', '2035', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12926, to_date('22-05-2035', 'dd-mm-yyyy'), '2', '22', '142', '05', '2035', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12927, to_date('23-05-2035', 'dd-mm-yyyy'), '3', '23', '143', '05', '2035', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12928, to_date('24-05-2035', 'dd-mm-yyyy'), '4', '24', '144', '05', '2035', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12929, to_date('25-05-2035', 'dd-mm-yyyy'), '5', '25', '145', '05', '2035', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12930, to_date('26-05-2035', 'dd-mm-yyyy'), '6', '26', '146', '05', '2035', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12931, to_date('27-05-2035', 'dd-mm-yyyy'), '7', '27', '147', '05', '2035', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12932, to_date('28-05-2035', 'dd-mm-yyyy'), '1', '28', '148', '05', '2035', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12933, to_date('29-05-2035', 'dd-mm-yyyy'), '2', '29', '149', '05', '2035', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12934, to_date('30-05-2035', 'dd-mm-yyyy'), '3', '30', '150', '05', '2035', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12935, to_date('31-05-2035', 'dd-mm-yyyy'), '4', '31', '151', '05', '2035', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12936, to_date('01-06-2035', 'dd-mm-yyyy'), '5', '01', '152', '06', '2035', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12937, to_date('02-06-2035', 'dd-mm-yyyy'), '6', '02', '153', '06', '2035', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12938, to_date('03-06-2035', 'dd-mm-yyyy'), '7', '03', '154', '06', '2035', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12939, to_date('04-06-2035', 'dd-mm-yyyy'), '1', '04', '155', '06', '2035', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12940, to_date('05-06-2035', 'dd-mm-yyyy'), '2', '05', '156', '06', '2035', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12941, to_date('06-06-2035', 'dd-mm-yyyy'), '3', '06', '157', '06', '2035', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12942, to_date('07-06-2035', 'dd-mm-yyyy'), '4', '07', '158', '06', '2035', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12943, to_date('08-06-2035', 'dd-mm-yyyy'), '5', '08', '159', '06', '2035', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12944, to_date('09-06-2035', 'dd-mm-yyyy'), '6', '09', '160', '06', '2035', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12945, to_date('10-06-2035', 'dd-mm-yyyy'), '7', '10', '161', '06', '2035', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12946, to_date('11-06-2035', 'dd-mm-yyyy'), '1', '11', '162', '06', '2035', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12947, to_date('12-06-2035', 'dd-mm-yyyy'), '2', '12', '163', '06', '2035', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12948, to_date('13-06-2035', 'dd-mm-yyyy'), '3', '13', '164', '06', '2035', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12949, to_date('14-06-2035', 'dd-mm-yyyy'), '4', '14', '165', '06', '2035', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12950, to_date('15-06-2035', 'dd-mm-yyyy'), '5', '15', '166', '06', '2035', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12951, to_date('16-06-2035', 'dd-mm-yyyy'), '6', '16', '167', '06', '2035', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12952, to_date('17-06-2035', 'dd-mm-yyyy'), '7', '17', '168', '06', '2035', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12953, to_date('18-06-2035', 'dd-mm-yyyy'), '1', '18', '169', '06', '2035', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12954, to_date('19-06-2035', 'dd-mm-yyyy'), '2', '19', '170', '06', '2035', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12955, to_date('20-06-2035', 'dd-mm-yyyy'), '3', '20', '171', '06', '2035', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12956, to_date('21-06-2035', 'dd-mm-yyyy'), '4', '21', '172', '06', '2035', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12957, to_date('22-06-2035', 'dd-mm-yyyy'), '5', '22', '173', '06', '2035', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12958, to_date('23-06-2035', 'dd-mm-yyyy'), '6', '23', '174', '06', '2035', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12959, to_date('24-06-2035', 'dd-mm-yyyy'), '7', '24', '175', '06', '2035', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12960, to_date('25-06-2035', 'dd-mm-yyyy'), '1', '25', '176', '06', '2035', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12961, to_date('26-06-2035', 'dd-mm-yyyy'), '2', '26', '177', '06', '2035', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12962, to_date('27-06-2035', 'dd-mm-yyyy'), '3', '27', '178', '06', '2035', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12963, to_date('28-06-2035', 'dd-mm-yyyy'), '4', '28', '179', '06', '2035', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12964, to_date('29-06-2035', 'dd-mm-yyyy'), '5', '29', '180', '06', '2035', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12965, to_date('30-06-2035', 'dd-mm-yyyy'), '6', '30', '181', '06', '2035', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12966, to_date('01-07-2035', 'dd-mm-yyyy'), '7', '01', '182', '07', '2035', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12967, to_date('02-07-2035', 'dd-mm-yyyy'), '1', '02', '183', '07', '2035', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12968, to_date('03-07-2035', 'dd-mm-yyyy'), '2', '03', '184', '07', '2035', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12969, to_date('04-07-2035', 'dd-mm-yyyy'), '3', '04', '185', '07', '2035', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12970, to_date('05-07-2035', 'dd-mm-yyyy'), '4', '05', '186', '07', '2035', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12971, to_date('06-07-2035', 'dd-mm-yyyy'), '5', '06', '187', '07', '2035', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12972, to_date('07-07-2035', 'dd-mm-yyyy'), '6', '07', '188', '07', '2035', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12973, to_date('08-07-2035', 'dd-mm-yyyy'), '7', '08', '189', '07', '2035', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12974, to_date('09-07-2035', 'dd-mm-yyyy'), '1', '09', '190', '07', '2035', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12975, to_date('10-07-2035', 'dd-mm-yyyy'), '2', '10', '191', '07', '2035', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12976, to_date('11-07-2035', 'dd-mm-yyyy'), '3', '11', '192', '07', '2035', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12977, to_date('12-07-2035', 'dd-mm-yyyy'), '4', '12', '193', '07', '2035', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12978, to_date('13-07-2035', 'dd-mm-yyyy'), '5', '13', '194', '07', '2035', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12979, to_date('14-07-2035', 'dd-mm-yyyy'), '6', '14', '195', '07', '2035', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12980, to_date('15-07-2035', 'dd-mm-yyyy'), '7', '15', '196', '07', '2035', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12981, to_date('16-07-2035', 'dd-mm-yyyy'), '1', '16', '197', '07', '2035', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12982, to_date('17-07-2035', 'dd-mm-yyyy'), '2', '17', '198', '07', '2035', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12983, to_date('18-07-2035', 'dd-mm-yyyy'), '3', '18', '199', '07', '2035', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12984, to_date('19-07-2035', 'dd-mm-yyyy'), '4', '19', '200', '07', '2035', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12985, to_date('20-07-2035', 'dd-mm-yyyy'), '5', '20', '201', '07', '2035', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12986, to_date('21-07-2035', 'dd-mm-yyyy'), '6', '21', '202', '07', '2035', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12987, to_date('22-07-2035', 'dd-mm-yyyy'), '7', '22', '203', '07', '2035', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12988, to_date('23-07-2035', 'dd-mm-yyyy'), '1', '23', '204', '07', '2035', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12989, to_date('24-07-2035', 'dd-mm-yyyy'), '2', '24', '205', '07', '2035', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12990, to_date('25-07-2035', 'dd-mm-yyyy'), '3', '25', '206', '07', '2035', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12991, to_date('26-07-2035', 'dd-mm-yyyy'), '4', '26', '207', '07', '2035', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12992, to_date('27-07-2035', 'dd-mm-yyyy'), '5', '27', '208', '07', '2035', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12993, to_date('28-07-2035', 'dd-mm-yyyy'), '6', '28', '209', '07', '2035', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12994, to_date('29-07-2035', 'dd-mm-yyyy'), '7', '29', '210', '07', '2035', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12995, to_date('30-07-2035', 'dd-mm-yyyy'), '1', '30', '211', '07', '2035', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12996, to_date('31-07-2035', 'dd-mm-yyyy'), '2', '31', '212', '07', '2035', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12997, to_date('01-08-2035', 'dd-mm-yyyy'), '3', '01', '213', '08', '2035', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12998, to_date('02-08-2035', 'dd-mm-yyyy'), '4', '02', '214', '08', '2035', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (12999, to_date('03-08-2035', 'dd-mm-yyyy'), '5', '03', '215', '08', '2035', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13000, to_date('04-08-2035', 'dd-mm-yyyy'), '6', '04', '216', '08', '2035', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13001, to_date('05-08-2035', 'dd-mm-yyyy'), '7', '05', '217', '08', '2035', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13002, to_date('06-08-2035', 'dd-mm-yyyy'), '1', '06', '218', '08', '2035', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13003, to_date('07-08-2035', 'dd-mm-yyyy'), '2', '07', '219', '08', '2035', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13004, to_date('08-08-2035', 'dd-mm-yyyy'), '3', '08', '220', '08', '2035', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13005, to_date('09-08-2035', 'dd-mm-yyyy'), '4', '09', '221', '08', '2035', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13006, to_date('10-08-2035', 'dd-mm-yyyy'), '5', '10', '222', '08', '2035', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13007, to_date('11-08-2035', 'dd-mm-yyyy'), '6', '11', '223', '08', '2035', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13008, to_date('12-08-2035', 'dd-mm-yyyy'), '7', '12', '224', '08', '2035', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13009, to_date('13-08-2035', 'dd-mm-yyyy'), '1', '13', '225', '08', '2035', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13010, to_date('14-08-2035', 'dd-mm-yyyy'), '2', '14', '226', '08', '2035', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13011, to_date('15-08-2035', 'dd-mm-yyyy'), '3', '15', '227', '08', '2035', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13012, to_date('16-08-2035', 'dd-mm-yyyy'), '4', '16', '228', '08', '2035', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14603, to_date('24-12-2039', 'dd-mm-yyyy'), '6', '24', '358', '12', '2039', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14604, to_date('25-12-2039', 'dd-mm-yyyy'), '7', '25', '359', '12', '2039', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14605, to_date('26-12-2039', 'dd-mm-yyyy'), '1', '26', '360', '12', '2039', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14606, to_date('27-12-2039', 'dd-mm-yyyy'), '2', '27', '361', '12', '2039', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14607, to_date('28-12-2039', 'dd-mm-yyyy'), '3', '28', '362', '12', '2039', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14608, to_date('29-12-2039', 'dd-mm-yyyy'), '4', '29', '363', '12', '2039', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14609, to_date('30-12-2039', 'dd-mm-yyyy'), '5', '30', '364', '12', '2039', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14610, to_date('31-12-2039', 'dd-mm-yyyy'), '6', '31', '365', '12', '2039', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14611, to_date('01-01-2040', 'dd-mm-yyyy'), '7', '01', '001', '01', '2040', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14612, to_date('02-01-2040', 'dd-mm-yyyy'), '1', '02', '002', '01', '2040', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14613, to_date('03-01-2040', 'dd-mm-yyyy'), '2', '03', '003', '01', '2040', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14614, to_date('04-01-2040', 'dd-mm-yyyy'), '3', '04', '004', '01', '2040', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14615, to_date('05-01-2040', 'dd-mm-yyyy'), '4', '05', '005', '01', '2040', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14616, to_date('06-01-2040', 'dd-mm-yyyy'), '5', '06', '006', '01', '2040', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14617, to_date('07-01-2040', 'dd-mm-yyyy'), '6', '07', '007', '01', '2040', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14618, to_date('08-01-2040', 'dd-mm-yyyy'), '7', '08', '008', '01', '2040', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14619, to_date('09-01-2040', 'dd-mm-yyyy'), '1', '09', '009', '01', '2040', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14620, to_date('10-01-2040', 'dd-mm-yyyy'), '2', '10', '010', '01', '2040', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14621, to_date('11-01-2040', 'dd-mm-yyyy'), '3', '11', '011', '01', '2040', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14622, to_date('12-01-2040', 'dd-mm-yyyy'), '4', '12', '012', '01', '2040', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14623, to_date('13-01-2040', 'dd-mm-yyyy'), '5', '13', '013', '01', '2040', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14624, to_date('14-01-2040', 'dd-mm-yyyy'), '6', '14', '014', '01', '2040', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14625, to_date('15-01-2040', 'dd-mm-yyyy'), '7', '15', '015', '01', '2040', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14626, to_date('16-01-2040', 'dd-mm-yyyy'), '1', '16', '016', '01', '2040', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14627, to_date('17-01-2040', 'dd-mm-yyyy'), '2', '17', '017', '01', '2040', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14628, to_date('18-01-2040', 'dd-mm-yyyy'), '3', '18', '018', '01', '2040', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14629, to_date('19-01-2040', 'dd-mm-yyyy'), '4', '19', '019', '01', '2040', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14630, to_date('20-01-2040', 'dd-mm-yyyy'), '5', '20', '020', '01', '2040', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14631, to_date('21-01-2040', 'dd-mm-yyyy'), '6', '21', '021', '01', '2040', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14632, to_date('22-01-2040', 'dd-mm-yyyy'), '7', '22', '022', '01', '2040', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14633, to_date('23-01-2040', 'dd-mm-yyyy'), '1', '23', '023', '01', '2040', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14634, to_date('24-01-2040', 'dd-mm-yyyy'), '2', '24', '024', '01', '2040', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14635, to_date('25-01-2040', 'dd-mm-yyyy'), '3', '25', '025', '01', '2040', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14636, to_date('26-01-2040', 'dd-mm-yyyy'), '4', '26', '026', '01', '2040', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14637, to_date('27-01-2040', 'dd-mm-yyyy'), '5', '27', '027', '01', '2040', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14638, to_date('28-01-2040', 'dd-mm-yyyy'), '6', '28', '028', '01', '2040', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14639, to_date('29-01-2040', 'dd-mm-yyyy'), '7', '29', '029', '01', '2040', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14640, to_date('30-01-2040', 'dd-mm-yyyy'), '1', '30', '030', '01', '2040', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
commit;
prompt 21000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14641, to_date('31-01-2040', 'dd-mm-yyyy'), '2', '31', '031', '01', '2040', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14642, to_date('01-02-2040', 'dd-mm-yyyy'), '3', '01', '032', '02', '2040', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14643, to_date('02-02-2040', 'dd-mm-yyyy'), '4', '02', '033', '02', '2040', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14644, to_date('03-02-2040', 'dd-mm-yyyy'), '5', '03', '034', '02', '2040', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14645, to_date('04-02-2040', 'dd-mm-yyyy'), '6', '04', '035', '02', '2040', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14646, to_date('05-02-2040', 'dd-mm-yyyy'), '7', '05', '036', '02', '2040', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14647, to_date('06-02-2040', 'dd-mm-yyyy'), '1', '06', '037', '02', '2040', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14648, to_date('07-02-2040', 'dd-mm-yyyy'), '2', '07', '038', '02', '2040', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14649, to_date('08-02-2040', 'dd-mm-yyyy'), '3', '08', '039', '02', '2040', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14650, to_date('09-02-2040', 'dd-mm-yyyy'), '4', '09', '040', '02', '2040', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14651, to_date('10-02-2040', 'dd-mm-yyyy'), '5', '10', '041', '02', '2040', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14652, to_date('11-02-2040', 'dd-mm-yyyy'), '6', '11', '042', '02', '2040', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14653, to_date('12-02-2040', 'dd-mm-yyyy'), '7', '12', '043', '02', '2040', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14654, to_date('13-02-2040', 'dd-mm-yyyy'), '1', '13', '044', '02', '2040', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14655, to_date('14-02-2040', 'dd-mm-yyyy'), '2', '14', '045', '02', '2040', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14656, to_date('15-02-2040', 'dd-mm-yyyy'), '3', '15', '046', '02', '2040', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14657, to_date('16-02-2040', 'dd-mm-yyyy'), '4', '16', '047', '02', '2040', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14658, to_date('17-02-2040', 'dd-mm-yyyy'), '5', '17', '048', '02', '2040', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14659, to_date('18-02-2040', 'dd-mm-yyyy'), '6', '18', '049', '02', '2040', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14660, to_date('19-02-2040', 'dd-mm-yyyy'), '7', '19', '050', '02', '2040', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14661, to_date('20-02-2040', 'dd-mm-yyyy'), '1', '20', '051', '02', '2040', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14662, to_date('21-02-2040', 'dd-mm-yyyy'), '2', '21', '052', '02', '2040', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14663, to_date('22-02-2040', 'dd-mm-yyyy'), '3', '22', '053', '02', '2040', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14664, to_date('23-02-2040', 'dd-mm-yyyy'), '4', '23', '054', '02', '2040', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14665, to_date('24-02-2040', 'dd-mm-yyyy'), '5', '24', '055', '02', '2040', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14666, to_date('25-02-2040', 'dd-mm-yyyy'), '6', '25', '056', '02', '2040', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14667, to_date('26-02-2040', 'dd-mm-yyyy'), '7', '26', '057', '02', '2040', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14668, to_date('27-02-2040', 'dd-mm-yyyy'), '1', '27', '058', '02', '2040', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14669, to_date('28-02-2040', 'dd-mm-yyyy'), '2', '28', '059', '02', '2040', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14670, to_date('29-02-2040', 'dd-mm-yyyy'), '3', '29', '060', '02', '2040', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14671, to_date('01-03-2040', 'dd-mm-yyyy'), '4', '01', '061', '03', '2040', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14672, to_date('02-03-2040', 'dd-mm-yyyy'), '5', '02', '062', '03', '2040', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14673, to_date('03-03-2040', 'dd-mm-yyyy'), '6', '03', '063', '03', '2040', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14674, to_date('04-03-2040', 'dd-mm-yyyy'), '7', '04', '064', '03', '2040', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14675, to_date('05-03-2040', 'dd-mm-yyyy'), '1', '05', '065', '03', '2040', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14676, to_date('06-03-2040', 'dd-mm-yyyy'), '2', '06', '066', '03', '2040', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14677, to_date('07-03-2040', 'dd-mm-yyyy'), '3', '07', '067', '03', '2040', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14678, to_date('08-03-2040', 'dd-mm-yyyy'), '4', '08', '068', '03', '2040', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14679, to_date('09-03-2040', 'dd-mm-yyyy'), '5', '09', '069', '03', '2040', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14680, to_date('10-03-2040', 'dd-mm-yyyy'), '6', '10', '070', '03', '2040', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14681, to_date('11-03-2040', 'dd-mm-yyyy'), '7', '11', '071', '03', '2040', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14682, to_date('12-03-2040', 'dd-mm-yyyy'), '1', '12', '072', '03', '2040', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14683, to_date('13-03-2040', 'dd-mm-yyyy'), '2', '13', '073', '03', '2040', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14684, to_date('14-03-2040', 'dd-mm-yyyy'), '3', '14', '074', '03', '2040', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14685, to_date('15-03-2040', 'dd-mm-yyyy'), '4', '15', '075', '03', '2040', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14686, to_date('16-03-2040', 'dd-mm-yyyy'), '5', '16', '076', '03', '2040', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14687, to_date('17-03-2040', 'dd-mm-yyyy'), '6', '17', '077', '03', '2040', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14688, to_date('18-03-2040', 'dd-mm-yyyy'), '7', '18', '078', '03', '2040', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14689, to_date('19-03-2040', 'dd-mm-yyyy'), '1', '19', '079', '03', '2040', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14690, to_date('20-03-2040', 'dd-mm-yyyy'), '2', '20', '080', '03', '2040', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14691, to_date('21-03-2040', 'dd-mm-yyyy'), '3', '21', '081', '03', '2040', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14692, to_date('22-03-2040', 'dd-mm-yyyy'), '4', '22', '082', '03', '2040', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14693, to_date('23-03-2040', 'dd-mm-yyyy'), '5', '23', '083', '03', '2040', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14694, to_date('24-03-2040', 'dd-mm-yyyy'), '6', '24', '084', '03', '2040', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14695, to_date('25-03-2040', 'dd-mm-yyyy'), '7', '25', '085', '03', '2040', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14696, to_date('26-03-2040', 'dd-mm-yyyy'), '1', '26', '086', '03', '2040', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14697, to_date('27-03-2040', 'dd-mm-yyyy'), '2', '27', '087', '03', '2040', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14698, to_date('28-03-2040', 'dd-mm-yyyy'), '3', '28', '088', '03', '2040', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14699, to_date('29-03-2040', 'dd-mm-yyyy'), '4', '29', '089', '03', '2040', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14700, to_date('30-03-2040', 'dd-mm-yyyy'), '5', '30', '090', '03', '2040', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14701, to_date('31-03-2040', 'dd-mm-yyyy'), '6', '31', '091', '03', '2040', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14702, to_date('01-04-2040', 'dd-mm-yyyy'), '7', '01', '092', '04', '2040', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14703, to_date('02-04-2040', 'dd-mm-yyyy'), '1', '02', '093', '04', '2040', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14704, to_date('03-04-2040', 'dd-mm-yyyy'), '2', '03', '094', '04', '2040', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14705, to_date('04-04-2040', 'dd-mm-yyyy'), '3', '04', '095', '04', '2040', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14706, to_date('05-04-2040', 'dd-mm-yyyy'), '4', '05', '096', '04', '2040', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14707, to_date('06-04-2040', 'dd-mm-yyyy'), '5', '06', '097', '04', '2040', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14708, to_date('07-04-2040', 'dd-mm-yyyy'), '6', '07', '098', '04', '2040', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16193, to_date('01-05-2044', 'dd-mm-yyyy'), '7', '01', '122', '05', '2044', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16194, to_date('02-05-2044', 'dd-mm-yyyy'), '1', '02', '123', '05', '2044', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16195, to_date('03-05-2044', 'dd-mm-yyyy'), '2', '03', '124', '05', '2044', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16196, to_date('04-05-2044', 'dd-mm-yyyy'), '3', '04', '125', '05', '2044', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16197, to_date('05-05-2044', 'dd-mm-yyyy'), '4', '05', '126', '05', '2044', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16198, to_date('06-05-2044', 'dd-mm-yyyy'), '5', '06', '127', '05', '2044', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16199, to_date('07-05-2044', 'dd-mm-yyyy'), '6', '07', '128', '05', '2044', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16200, to_date('08-05-2044', 'dd-mm-yyyy'), '7', '08', '129', '05', '2044', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16201, to_date('09-05-2044', 'dd-mm-yyyy'), '1', '09', '130', '05', '2044', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16202, to_date('10-05-2044', 'dd-mm-yyyy'), '2', '10', '131', '05', '2044', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16203, to_date('11-05-2044', 'dd-mm-yyyy'), '3', '11', '132', '05', '2044', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16204, to_date('12-05-2044', 'dd-mm-yyyy'), '4', '12', '133', '05', '2044', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16205, to_date('13-05-2044', 'dd-mm-yyyy'), '5', '13', '134', '05', '2044', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16206, to_date('14-05-2044', 'dd-mm-yyyy'), '6', '14', '135', '05', '2044', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16207, to_date('15-05-2044', 'dd-mm-yyyy'), '7', '15', '136', '05', '2044', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16208, to_date('16-05-2044', 'dd-mm-yyyy'), '1', '16', '137', '05', '2044', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16209, to_date('17-05-2044', 'dd-mm-yyyy'), '2', '17', '138', '05', '2044', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16210, to_date('18-05-2044', 'dd-mm-yyyy'), '3', '18', '139', '05', '2044', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16211, to_date('19-05-2044', 'dd-mm-yyyy'), '4', '19', '140', '05', '2044', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16212, to_date('20-05-2044', 'dd-mm-yyyy'), '5', '20', '141', '05', '2044', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16213, to_date('21-05-2044', 'dd-mm-yyyy'), '6', '21', '142', '05', '2044', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16214, to_date('22-05-2044', 'dd-mm-yyyy'), '7', '22', '143', '05', '2044', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16215, to_date('23-05-2044', 'dd-mm-yyyy'), '1', '23', '144', '05', '2044', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16216, to_date('24-05-2044', 'dd-mm-yyyy'), '2', '24', '145', '05', '2044', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16217, to_date('25-05-2044', 'dd-mm-yyyy'), '3', '25', '146', '05', '2044', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16218, to_date('26-05-2044', 'dd-mm-yyyy'), '4', '26', '147', '05', '2044', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16219, to_date('27-05-2044', 'dd-mm-yyyy'), '5', '27', '148', '05', '2044', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16220, to_date('28-05-2044', 'dd-mm-yyyy'), '6', '28', '149', '05', '2044', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16221, to_date('29-05-2044', 'dd-mm-yyyy'), '7', '29', '150', '05', '2044', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16222, to_date('30-05-2044', 'dd-mm-yyyy'), '1', '30', '151', '05', '2044', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16223, to_date('31-05-2044', 'dd-mm-yyyy'), '2', '31', '152', '05', '2044', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16224, to_date('01-06-2044', 'dd-mm-yyyy'), '3', '01', '153', '06', '2044', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16225, to_date('02-06-2044', 'dd-mm-yyyy'), '4', '02', '154', '06', '2044', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16226, to_date('03-06-2044', 'dd-mm-yyyy'), '5', '03', '155', '06', '2044', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16227, to_date('04-06-2044', 'dd-mm-yyyy'), '6', '04', '156', '06', '2044', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16228, to_date('05-06-2044', 'dd-mm-yyyy'), '7', '05', '157', '06', '2044', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16229, to_date('06-06-2044', 'dd-mm-yyyy'), '1', '06', '158', '06', '2044', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16230, to_date('07-06-2044', 'dd-mm-yyyy'), '2', '07', '159', '06', '2044', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16231, to_date('08-06-2044', 'dd-mm-yyyy'), '3', '08', '160', '06', '2044', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16232, to_date('09-06-2044', 'dd-mm-yyyy'), '4', '09', '161', '06', '2044', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16233, to_date('10-06-2044', 'dd-mm-yyyy'), '5', '10', '162', '06', '2044', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16234, to_date('11-06-2044', 'dd-mm-yyyy'), '6', '11', '163', '06', '2044', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16235, to_date('12-06-2044', 'dd-mm-yyyy'), '7', '12', '164', '06', '2044', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16236, to_date('13-06-2044', 'dd-mm-yyyy'), '1', '13', '165', '06', '2044', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16237, to_date('14-06-2044', 'dd-mm-yyyy'), '2', '14', '166', '06', '2044', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16238, to_date('15-06-2044', 'dd-mm-yyyy'), '3', '15', '167', '06', '2044', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16239, to_date('16-06-2044', 'dd-mm-yyyy'), '4', '16', '168', '06', '2044', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16240, to_date('17-06-2044', 'dd-mm-yyyy'), '5', '17', '169', '06', '2044', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16241, to_date('18-06-2044', 'dd-mm-yyyy'), '6', '18', '170', '06', '2044', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16242, to_date('19-06-2044', 'dd-mm-yyyy'), '7', '19', '171', '06', '2044', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16243, to_date('20-06-2044', 'dd-mm-yyyy'), '1', '20', '172', '06', '2044', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16244, to_date('21-06-2044', 'dd-mm-yyyy'), '2', '21', '173', '06', '2044', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16245, to_date('22-06-2044', 'dd-mm-yyyy'), '3', '22', '174', '06', '2044', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16246, to_date('23-06-2044', 'dd-mm-yyyy'), '4', '23', '175', '06', '2044', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16247, to_date('24-06-2044', 'dd-mm-yyyy'), '5', '24', '176', '06', '2044', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16248, to_date('25-06-2044', 'dd-mm-yyyy'), '6', '25', '177', '06', '2044', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16249, to_date('26-06-2044', 'dd-mm-yyyy'), '7', '26', '178', '06', '2044', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16250, to_date('27-06-2044', 'dd-mm-yyyy'), '1', '27', '179', '06', '2044', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16251, to_date('28-06-2044', 'dd-mm-yyyy'), '2', '28', '180', '06', '2044', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16252, to_date('29-06-2044', 'dd-mm-yyyy'), '3', '29', '181', '06', '2044', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16253, to_date('30-06-2044', 'dd-mm-yyyy'), '4', '30', '182', '06', '2044', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16254, to_date('01-07-2044', 'dd-mm-yyyy'), '5', '01', '183', '07', '2044', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16255, to_date('02-07-2044', 'dd-mm-yyyy'), '6', '02', '184', '07', '2044', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16256, to_date('03-07-2044', 'dd-mm-yyyy'), '7', '03', '185', '07', '2044', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16257, to_date('04-07-2044', 'dd-mm-yyyy'), '1', '04', '186', '07', '2044', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16258, to_date('05-07-2044', 'dd-mm-yyyy'), '2', '05', '187', '07', '2044', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16259, to_date('06-07-2044', 'dd-mm-yyyy'), '3', '06', '188', '07', '2044', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16260, to_date('07-07-2044', 'dd-mm-yyyy'), '4', '07', '189', '07', '2044', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16261, to_date('08-07-2044', 'dd-mm-yyyy'), '5', '08', '190', '07', '2044', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16262, to_date('09-07-2044', 'dd-mm-yyyy'), '6', '09', '191', '07', '2044', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16263, to_date('10-07-2044', 'dd-mm-yyyy'), '7', '10', '192', '07', '2044', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16264, to_date('11-07-2044', 'dd-mm-yyyy'), '1', '11', '193', '07', '2044', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16265, to_date('12-07-2044', 'dd-mm-yyyy'), '2', '12', '194', '07', '2044', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16266, to_date('13-07-2044', 'dd-mm-yyyy'), '3', '13', '195', '07', '2044', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16267, to_date('14-07-2044', 'dd-mm-yyyy'), '4', '14', '196', '07', '2044', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16268, to_date('15-07-2044', 'dd-mm-yyyy'), '5', '15', '197', '07', '2044', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16269, to_date('16-07-2044', 'dd-mm-yyyy'), '6', '16', '198', '07', '2044', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16270, to_date('17-07-2044', 'dd-mm-yyyy'), '7', '17', '199', '07', '2044', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16271, to_date('18-07-2044', 'dd-mm-yyyy'), '1', '18', '200', '07', '2044', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16272, to_date('19-07-2044', 'dd-mm-yyyy'), '2', '19', '201', '07', '2044', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16273, to_date('20-07-2044', 'dd-mm-yyyy'), '3', '20', '202', '07', '2044', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16274, to_date('21-07-2044', 'dd-mm-yyyy'), '4', '21', '203', '07', '2044', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16275, to_date('22-07-2044', 'dd-mm-yyyy'), '5', '22', '204', '07', '2044', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16276, to_date('23-07-2044', 'dd-mm-yyyy'), '6', '23', '205', '07', '2044', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16277, to_date('24-07-2044', 'dd-mm-yyyy'), '7', '24', '206', '07', '2044', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16278, to_date('25-07-2044', 'dd-mm-yyyy'), '1', '25', '207', '07', '2044', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16279, to_date('26-07-2044', 'dd-mm-yyyy'), '2', '26', '208', '07', '2044', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16280, to_date('27-07-2044', 'dd-mm-yyyy'), '3', '27', '209', '07', '2044', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16281, to_date('28-07-2044', 'dd-mm-yyyy'), '4', '28', '210', '07', '2044', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16282, to_date('29-07-2044', 'dd-mm-yyyy'), '5', '29', '211', '07', '2044', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16283, to_date('30-07-2044', 'dd-mm-yyyy'), '6', '30', '212', '07', '2044', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16284, to_date('31-07-2044', 'dd-mm-yyyy'), '7', '31', '213', '07', '2044', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16285, to_date('01-08-2044', 'dd-mm-yyyy'), '1', '01', '214', '08', '2044', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16286, to_date('02-08-2044', 'dd-mm-yyyy'), '2', '02', '215', '08', '2044', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16287, to_date('03-08-2044', 'dd-mm-yyyy'), '3', '03', '216', '08', '2044', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16288, to_date('04-08-2044', 'dd-mm-yyyy'), '4', '04', '217', '08', '2044', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16289, to_date('05-08-2044', 'dd-mm-yyyy'), '5', '05', '218', '08', '2044', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16290, to_date('06-08-2044', 'dd-mm-yyyy'), '6', '06', '219', '08', '2044', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16291, to_date('07-08-2044', 'dd-mm-yyyy'), '7', '07', '220', '08', '2044', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16292, to_date('08-08-2044', 'dd-mm-yyyy'), '1', '08', '221', '08', '2044', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16293, to_date('09-08-2044', 'dd-mm-yyyy'), '2', '09', '222', '08', '2044', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16294, to_date('10-08-2044', 'dd-mm-yyyy'), '3', '10', '223', '08', '2044', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16295, to_date('11-08-2044', 'dd-mm-yyyy'), '4', '11', '224', '08', '2044', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16296, to_date('12-08-2044', 'dd-mm-yyyy'), '5', '12', '225', '08', '2044', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16297, to_date('13-08-2044', 'dd-mm-yyyy'), '6', '13', '226', '08', '2044', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16298, to_date('14-08-2044', 'dd-mm-yyyy'), '7', '14', '227', '08', '2044', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17783, to_date('07-09-2048', 'dd-mm-yyyy'), '1', '07', '251', '09', '2048', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17784, to_date('08-09-2048', 'dd-mm-yyyy'), '2', '08', '252', '09', '2048', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17785, to_date('09-09-2048', 'dd-mm-yyyy'), '3', '09', '253', '09', '2048', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17786, to_date('10-09-2048', 'dd-mm-yyyy'), '4', '10', '254', '09', '2048', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17787, to_date('11-09-2048', 'dd-mm-yyyy'), '5', '11', '255', '09', '2048', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17788, to_date('12-09-2048', 'dd-mm-yyyy'), '6', '12', '256', '09', '2048', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17789, to_date('13-09-2048', 'dd-mm-yyyy'), '7', '13', '257', '09', '2048', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17790, to_date('14-09-2048', 'dd-mm-yyyy'), '1', '14', '258', '09', '2048', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17791, to_date('15-09-2048', 'dd-mm-yyyy'), '2', '15', '259', '09', '2048', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17792, to_date('16-09-2048', 'dd-mm-yyyy'), '3', '16', '260', '09', '2048', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17793, to_date('17-09-2048', 'dd-mm-yyyy'), '4', '17', '261', '09', '2048', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17794, to_date('18-09-2048', 'dd-mm-yyyy'), '5', '18', '262', '09', '2048', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17795, to_date('19-09-2048', 'dd-mm-yyyy'), '6', '19', '263', '09', '2048', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17796, to_date('20-09-2048', 'dd-mm-yyyy'), '7', '20', '264', '09', '2048', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17797, to_date('21-09-2048', 'dd-mm-yyyy'), '1', '21', '265', '09', '2048', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17798, to_date('22-09-2048', 'dd-mm-yyyy'), '2', '22', '266', '09', '2048', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17799, to_date('23-09-2048', 'dd-mm-yyyy'), '3', '23', '267', '09', '2048', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17800, to_date('24-09-2048', 'dd-mm-yyyy'), '4', '24', '268', '09', '2048', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17801, to_date('25-09-2048', 'dd-mm-yyyy'), '5', '25', '269', '09', '2048', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17802, to_date('26-09-2048', 'dd-mm-yyyy'), '6', '26', '270', '09', '2048', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17803, to_date('27-09-2048', 'dd-mm-yyyy'), '7', '27', '271', '09', '2048', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17804, to_date('28-09-2048', 'dd-mm-yyyy'), '1', '28', '272', '09', '2048', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17805, to_date('29-09-2048', 'dd-mm-yyyy'), '2', '29', '273', '09', '2048', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17806, to_date('30-09-2048', 'dd-mm-yyyy'), '3', '30', '274', '09', '2048', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17807, to_date('01-10-2048', 'dd-mm-yyyy'), '4', '01', '275', '10', '2048', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17808, to_date('02-10-2048', 'dd-mm-yyyy'), '5', '02', '276', '10', '2048', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17809, to_date('03-10-2048', 'dd-mm-yyyy'), '6', '03', '277', '10', '2048', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17810, to_date('04-10-2048', 'dd-mm-yyyy'), '7', '04', '278', '10', '2048', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17811, to_date('05-10-2048', 'dd-mm-yyyy'), '1', '05', '279', '10', '2048', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17812, to_date('06-10-2048', 'dd-mm-yyyy'), '2', '06', '280', '10', '2048', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17813, to_date('07-10-2048', 'dd-mm-yyyy'), '3', '07', '281', '10', '2048', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17814, to_date('08-10-2048', 'dd-mm-yyyy'), '4', '08', '282', '10', '2048', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17815, to_date('09-10-2048', 'dd-mm-yyyy'), '5', '09', '283', '10', '2048', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17816, to_date('10-10-2048', 'dd-mm-yyyy'), '6', '10', '284', '10', '2048', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17817, to_date('11-10-2048', 'dd-mm-yyyy'), '7', '11', '285', '10', '2048', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17818, to_date('12-10-2048', 'dd-mm-yyyy'), '1', '12', '286', '10', '2048', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17819, to_date('13-10-2048', 'dd-mm-yyyy'), '2', '13', '287', '10', '2048', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17820, to_date('14-10-2048', 'dd-mm-yyyy'), '3', '14', '288', '10', '2048', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17821, to_date('15-10-2048', 'dd-mm-yyyy'), '4', '15', '289', '10', '2048', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17822, to_date('16-10-2048', 'dd-mm-yyyy'), '5', '16', '290', '10', '2048', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17823, to_date('17-10-2048', 'dd-mm-yyyy'), '6', '17', '291', '10', '2048', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17824, to_date('18-10-2048', 'dd-mm-yyyy'), '7', '18', '292', '10', '2048', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17825, to_date('19-10-2048', 'dd-mm-yyyy'), '1', '19', '293', '10', '2048', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17826, to_date('20-10-2048', 'dd-mm-yyyy'), '2', '20', '294', '10', '2048', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17827, to_date('21-10-2048', 'dd-mm-yyyy'), '3', '21', '295', '10', '2048', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17828, to_date('22-10-2048', 'dd-mm-yyyy'), '4', '22', '296', '10', '2048', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17829, to_date('23-10-2048', 'dd-mm-yyyy'), '5', '23', '297', '10', '2048', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17830, to_date('24-10-2048', 'dd-mm-yyyy'), '6', '24', '298', '10', '2048', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17831, to_date('25-10-2048', 'dd-mm-yyyy'), '7', '25', '299', '10', '2048', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17832, to_date('26-10-2048', 'dd-mm-yyyy'), '1', '26', '300', '10', '2048', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17833, to_date('27-10-2048', 'dd-mm-yyyy'), '2', '27', '301', '10', '2048', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17834, to_date('28-10-2048', 'dd-mm-yyyy'), '3', '28', '302', '10', '2048', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17835, to_date('29-10-2048', 'dd-mm-yyyy'), '4', '29', '303', '10', '2048', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17836, to_date('30-10-2048', 'dd-mm-yyyy'), '5', '30', '304', '10', '2048', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17837, to_date('31-10-2048', 'dd-mm-yyyy'), '6', '31', '305', '10', '2048', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17838, to_date('01-11-2048', 'dd-mm-yyyy'), '7', '01', '306', '11', '2048', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17839, to_date('02-11-2048', 'dd-mm-yyyy'), '1', '02', '307', '11', '2048', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17840, to_date('03-11-2048', 'dd-mm-yyyy'), '2', '03', '308', '11', '2048', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17841, to_date('04-11-2048', 'dd-mm-yyyy'), '3', '04', '309', '11', '2048', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17842, to_date('05-11-2048', 'dd-mm-yyyy'), '4', '05', '310', '11', '2048', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17843, to_date('06-11-2048', 'dd-mm-yyyy'), '5', '06', '311', '11', '2048', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17844, to_date('07-11-2048', 'dd-mm-yyyy'), '6', '07', '312', '11', '2048', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17845, to_date('08-11-2048', 'dd-mm-yyyy'), '7', '08', '313', '11', '2048', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17846, to_date('09-11-2048', 'dd-mm-yyyy'), '1', '09', '314', '11', '2048', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17847, to_date('10-11-2048', 'dd-mm-yyyy'), '2', '10', '315', '11', '2048', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17848, to_date('11-11-2048', 'dd-mm-yyyy'), '3', '11', '316', '11', '2048', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17849, to_date('12-11-2048', 'dd-mm-yyyy'), '4', '12', '317', '11', '2048', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17850, to_date('13-11-2048', 'dd-mm-yyyy'), '5', '13', '318', '11', '2048', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17851, to_date('14-11-2048', 'dd-mm-yyyy'), '6', '14', '319', '11', '2048', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17852, to_date('15-11-2048', 'dd-mm-yyyy'), '7', '15', '320', '11', '2048', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17853, to_date('16-11-2048', 'dd-mm-yyyy'), '1', '16', '321', '11', '2048', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17854, to_date('17-11-2048', 'dd-mm-yyyy'), '2', '17', '322', '11', '2048', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17855, to_date('18-11-2048', 'dd-mm-yyyy'), '3', '18', '323', '11', '2048', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17856, to_date('19-11-2048', 'dd-mm-yyyy'), '4', '19', '324', '11', '2048', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17857, to_date('20-11-2048', 'dd-mm-yyyy'), '5', '20', '325', '11', '2048', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17858, to_date('21-11-2048', 'dd-mm-yyyy'), '6', '21', '326', '11', '2048', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17859, to_date('22-11-2048', 'dd-mm-yyyy'), '7', '22', '327', '11', '2048', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17860, to_date('23-11-2048', 'dd-mm-yyyy'), '1', '23', '328', '11', '2048', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17861, to_date('24-11-2048', 'dd-mm-yyyy'), '2', '24', '329', '11', '2048', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17862, to_date('25-11-2048', 'dd-mm-yyyy'), '3', '25', '330', '11', '2048', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17863, to_date('26-11-2048', 'dd-mm-yyyy'), '4', '26', '331', '11', '2048', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17864, to_date('27-11-2048', 'dd-mm-yyyy'), '5', '27', '332', '11', '2048', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17865, to_date('28-11-2048', 'dd-mm-yyyy'), '6', '28', '333', '11', '2048', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17866, to_date('29-11-2048', 'dd-mm-yyyy'), '7', '29', '334', '11', '2048', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17867, to_date('30-11-2048', 'dd-mm-yyyy'), '1', '30', '335', '11', '2048', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17868, to_date('01-12-2048', 'dd-mm-yyyy'), '2', '01', '336', '12', '2048', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17869, to_date('02-12-2048', 'dd-mm-yyyy'), '3', '02', '337', '12', '2048', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17870, to_date('03-12-2048', 'dd-mm-yyyy'), '4', '03', '338', '12', '2048', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17871, to_date('04-12-2048', 'dd-mm-yyyy'), '5', '04', '339', '12', '2048', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17872, to_date('05-12-2048', 'dd-mm-yyyy'), '6', '05', '340', '12', '2048', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17873, to_date('06-12-2048', 'dd-mm-yyyy'), '7', '06', '341', '12', '2048', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17874, to_date('07-12-2048', 'dd-mm-yyyy'), '1', '07', '342', '12', '2048', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17875, to_date('08-12-2048', 'dd-mm-yyyy'), '2', '08', '343', '12', '2048', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17876, to_date('09-12-2048', 'dd-mm-yyyy'), '3', '09', '344', '12', '2048', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17877, to_date('10-12-2048', 'dd-mm-yyyy'), '4', '10', '345', '12', '2048', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17878, to_date('11-12-2048', 'dd-mm-yyyy'), '5', '11', '346', '12', '2048', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17879, to_date('12-12-2048', 'dd-mm-yyyy'), '6', '12', '347', '12', '2048', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17880, to_date('13-12-2048', 'dd-mm-yyyy'), '7', '13', '348', '12', '2048', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17881, to_date('14-12-2048', 'dd-mm-yyyy'), '1', '14', '349', '12', '2048', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17882, to_date('15-12-2048', 'dd-mm-yyyy'), '2', '15', '350', '12', '2048', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17883, to_date('16-12-2048', 'dd-mm-yyyy'), '3', '16', '351', '12', '2048', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17884, to_date('17-12-2048', 'dd-mm-yyyy'), '4', '17', '352', '12', '2048', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17885, to_date('18-12-2048', 'dd-mm-yyyy'), '5', '18', '353', '12', '2048', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17886, to_date('19-12-2048', 'dd-mm-yyyy'), '6', '19', '354', '12', '2048', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17887, to_date('20-12-2048', 'dd-mm-yyyy'), '7', '20', '355', '12', '2048', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17888, to_date('21-12-2048', 'dd-mm-yyyy'), '1', '21', '356', '12', '2048', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13013, to_date('17-08-2035', 'dd-mm-yyyy'), '5', '17', '229', '08', '2035', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13014, to_date('18-08-2035', 'dd-mm-yyyy'), '6', '18', '230', '08', '2035', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13015, to_date('19-08-2035', 'dd-mm-yyyy'), '7', '19', '231', '08', '2035', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13016, to_date('20-08-2035', 'dd-mm-yyyy'), '1', '20', '232', '08', '2035', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13017, to_date('21-08-2035', 'dd-mm-yyyy'), '2', '21', '233', '08', '2035', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13018, to_date('22-08-2035', 'dd-mm-yyyy'), '3', '22', '234', '08', '2035', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13019, to_date('23-08-2035', 'dd-mm-yyyy'), '4', '23', '235', '08', '2035', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13020, to_date('24-08-2035', 'dd-mm-yyyy'), '5', '24', '236', '08', '2035', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13021, to_date('25-08-2035', 'dd-mm-yyyy'), '6', '25', '237', '08', '2035', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13022, to_date('26-08-2035', 'dd-mm-yyyy'), '7', '26', '238', '08', '2035', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13023, to_date('27-08-2035', 'dd-mm-yyyy'), '1', '27', '239', '08', '2035', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13024, to_date('28-08-2035', 'dd-mm-yyyy'), '2', '28', '240', '08', '2035', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13025, to_date('29-08-2035', 'dd-mm-yyyy'), '3', '29', '241', '08', '2035', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13026, to_date('30-08-2035', 'dd-mm-yyyy'), '4', '30', '242', '08', '2035', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13027, to_date('31-08-2035', 'dd-mm-yyyy'), '5', '31', '243', '08', '2035', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13028, to_date('01-09-2035', 'dd-mm-yyyy'), '6', '01', '244', '09', '2035', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13029, to_date('02-09-2035', 'dd-mm-yyyy'), '7', '02', '245', '09', '2035', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13030, to_date('03-09-2035', 'dd-mm-yyyy'), '1', '03', '246', '09', '2035', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13031, to_date('04-09-2035', 'dd-mm-yyyy'), '2', '04', '247', '09', '2035', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13032, to_date('05-09-2035', 'dd-mm-yyyy'), '3', '05', '248', '09', '2035', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13033, to_date('06-09-2035', 'dd-mm-yyyy'), '4', '06', '249', '09', '2035', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13034, to_date('07-09-2035', 'dd-mm-yyyy'), '5', '07', '250', '09', '2035', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13035, to_date('08-09-2035', 'dd-mm-yyyy'), '6', '08', '251', '09', '2035', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13036, to_date('09-09-2035', 'dd-mm-yyyy'), '7', '09', '252', '09', '2035', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13037, to_date('10-09-2035', 'dd-mm-yyyy'), '1', '10', '253', '09', '2035', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13038, to_date('11-09-2035', 'dd-mm-yyyy'), '2', '11', '254', '09', '2035', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13039, to_date('12-09-2035', 'dd-mm-yyyy'), '3', '12', '255', '09', '2035', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13040, to_date('13-09-2035', 'dd-mm-yyyy'), '4', '13', '256', '09', '2035', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13041, to_date('14-09-2035', 'dd-mm-yyyy'), '5', '14', '257', '09', '2035', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13042, to_date('15-09-2035', 'dd-mm-yyyy'), '6', '15', '258', '09', '2035', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13043, to_date('16-09-2035', 'dd-mm-yyyy'), '7', '16', '259', '09', '2035', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13044, to_date('17-09-2035', 'dd-mm-yyyy'), '1', '17', '260', '09', '2035', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13045, to_date('18-09-2035', 'dd-mm-yyyy'), '2', '18', '261', '09', '2035', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13046, to_date('19-09-2035', 'dd-mm-yyyy'), '3', '19', '262', '09', '2035', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13047, to_date('20-09-2035', 'dd-mm-yyyy'), '4', '20', '263', '09', '2035', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13048, to_date('21-09-2035', 'dd-mm-yyyy'), '5', '21', '264', '09', '2035', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13049, to_date('22-09-2035', 'dd-mm-yyyy'), '6', '22', '265', '09', '2035', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13050, to_date('23-09-2035', 'dd-mm-yyyy'), '7', '23', '266', '09', '2035', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13051, to_date('24-09-2035', 'dd-mm-yyyy'), '1', '24', '267', '09', '2035', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13052, to_date('25-09-2035', 'dd-mm-yyyy'), '2', '25', '268', '09', '2035', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13053, to_date('26-09-2035', 'dd-mm-yyyy'), '3', '26', '269', '09', '2035', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13054, to_date('27-09-2035', 'dd-mm-yyyy'), '4', '27', '270', '09', '2035', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13055, to_date('28-09-2035', 'dd-mm-yyyy'), '5', '28', '271', '09', '2035', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13056, to_date('29-09-2035', 'dd-mm-yyyy'), '6', '29', '272', '09', '2035', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13057, to_date('30-09-2035', 'dd-mm-yyyy'), '7', '30', '273', '09', '2035', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13058, to_date('01-10-2035', 'dd-mm-yyyy'), '1', '01', '274', '10', '2035', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13059, to_date('02-10-2035', 'dd-mm-yyyy'), '2', '02', '275', '10', '2035', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13060, to_date('03-10-2035', 'dd-mm-yyyy'), '3', '03', '276', '10', '2035', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13061, to_date('04-10-2035', 'dd-mm-yyyy'), '4', '04', '277', '10', '2035', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13062, to_date('05-10-2035', 'dd-mm-yyyy'), '5', '05', '278', '10', '2035', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13063, to_date('06-10-2035', 'dd-mm-yyyy'), '6', '06', '279', '10', '2035', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13064, to_date('07-10-2035', 'dd-mm-yyyy'), '7', '07', '280', '10', '2035', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13065, to_date('08-10-2035', 'dd-mm-yyyy'), '1', '08', '281', '10', '2035', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13066, to_date('09-10-2035', 'dd-mm-yyyy'), '2', '09', '282', '10', '2035', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13067, to_date('10-10-2035', 'dd-mm-yyyy'), '3', '10', '283', '10', '2035', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13068, to_date('11-10-2035', 'dd-mm-yyyy'), '4', '11', '284', '10', '2035', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13069, to_date('12-10-2035', 'dd-mm-yyyy'), '5', '12', '285', '10', '2035', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13070, to_date('13-10-2035', 'dd-mm-yyyy'), '6', '13', '286', '10', '2035', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13071, to_date('14-10-2035', 'dd-mm-yyyy'), '7', '14', '287', '10', '2035', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13072, to_date('15-10-2035', 'dd-mm-yyyy'), '1', '15', '288', '10', '2035', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13073, to_date('16-10-2035', 'dd-mm-yyyy'), '2', '16', '289', '10', '2035', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13074, to_date('17-10-2035', 'dd-mm-yyyy'), '3', '17', '290', '10', '2035', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13075, to_date('18-10-2035', 'dd-mm-yyyy'), '4', '18', '291', '10', '2035', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13076, to_date('19-10-2035', 'dd-mm-yyyy'), '5', '19', '292', '10', '2035', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13077, to_date('20-10-2035', 'dd-mm-yyyy'), '6', '20', '293', '10', '2035', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13078, to_date('21-10-2035', 'dd-mm-yyyy'), '7', '21', '294', '10', '2035', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13079, to_date('22-10-2035', 'dd-mm-yyyy'), '1', '22', '295', '10', '2035', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13080, to_date('23-10-2035', 'dd-mm-yyyy'), '2', '23', '296', '10', '2035', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13081, to_date('24-10-2035', 'dd-mm-yyyy'), '3', '24', '297', '10', '2035', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13082, to_date('25-10-2035', 'dd-mm-yyyy'), '4', '25', '298', '10', '2035', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13083, to_date('26-10-2035', 'dd-mm-yyyy'), '5', '26', '299', '10', '2035', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13084, to_date('27-10-2035', 'dd-mm-yyyy'), '6', '27', '300', '10', '2035', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13085, to_date('28-10-2035', 'dd-mm-yyyy'), '7', '28', '301', '10', '2035', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13086, to_date('29-10-2035', 'dd-mm-yyyy'), '1', '29', '302', '10', '2035', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13087, to_date('30-10-2035', 'dd-mm-yyyy'), '2', '30', '303', '10', '2035', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13088, to_date('31-10-2035', 'dd-mm-yyyy'), '3', '31', '304', '10', '2035', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13089, to_date('01-11-2035', 'dd-mm-yyyy'), '4', '01', '305', '11', '2035', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13090, to_date('02-11-2035', 'dd-mm-yyyy'), '5', '02', '306', '11', '2035', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13091, to_date('03-11-2035', 'dd-mm-yyyy'), '6', '03', '307', '11', '2035', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13092, to_date('04-11-2035', 'dd-mm-yyyy'), '7', '04', '308', '11', '2035', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13093, to_date('05-11-2035', 'dd-mm-yyyy'), '1', '05', '309', '11', '2035', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13094, to_date('06-11-2035', 'dd-mm-yyyy'), '2', '06', '310', '11', '2035', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13095, to_date('07-11-2035', 'dd-mm-yyyy'), '3', '07', '311', '11', '2035', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13096, to_date('08-11-2035', 'dd-mm-yyyy'), '4', '08', '312', '11', '2035', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13097, to_date('09-11-2035', 'dd-mm-yyyy'), '5', '09', '313', '11', '2035', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13098, to_date('10-11-2035', 'dd-mm-yyyy'), '6', '10', '314', '11', '2035', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13099, to_date('11-11-2035', 'dd-mm-yyyy'), '7', '11', '315', '11', '2035', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13100, to_date('12-11-2035', 'dd-mm-yyyy'), '1', '12', '316', '11', '2035', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13101, to_date('13-11-2035', 'dd-mm-yyyy'), '2', '13', '317', '11', '2035', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13102, to_date('14-11-2035', 'dd-mm-yyyy'), '3', '14', '318', '11', '2035', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13103, to_date('15-11-2035', 'dd-mm-yyyy'), '4', '15', '319', '11', '2035', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13104, to_date('16-11-2035', 'dd-mm-yyyy'), '5', '16', '320', '11', '2035', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13105, to_date('17-11-2035', 'dd-mm-yyyy'), '6', '17', '321', '11', '2035', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13106, to_date('18-11-2035', 'dd-mm-yyyy'), '7', '18', '322', '11', '2035', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13107, to_date('19-11-2035', 'dd-mm-yyyy'), '1', '19', '323', '11', '2035', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13108, to_date('20-11-2035', 'dd-mm-yyyy'), '2', '20', '324', '11', '2035', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13109, to_date('21-11-2035', 'dd-mm-yyyy'), '3', '21', '325', '11', '2035', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13110, to_date('22-11-2035', 'dd-mm-yyyy'), '4', '22', '326', '11', '2035', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13111, to_date('23-11-2035', 'dd-mm-yyyy'), '5', '23', '327', '11', '2035', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13112, to_date('24-11-2035', 'dd-mm-yyyy'), '6', '24', '328', '11', '2035', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13113, to_date('25-11-2035', 'dd-mm-yyyy'), '7', '25', '329', '11', '2035', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13114, to_date('26-11-2035', 'dd-mm-yyyy'), '1', '26', '330', '11', '2035', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13115, to_date('27-11-2035', 'dd-mm-yyyy'), '2', '27', '331', '11', '2035', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13116, to_date('28-11-2035', 'dd-mm-yyyy'), '3', '28', '332', '11', '2035', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13117, to_date('29-11-2035', 'dd-mm-yyyy'), '4', '29', '333', '11', '2035', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13118, to_date('30-11-2035', 'dd-mm-yyyy'), '5', '30', '334', '11', '2035', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14709, to_date('08-04-2040', 'dd-mm-yyyy'), '7', '08', '099', '04', '2040', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14710, to_date('09-04-2040', 'dd-mm-yyyy'), '1', '09', '100', '04', '2040', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14711, to_date('10-04-2040', 'dd-mm-yyyy'), '2', '10', '101', '04', '2040', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14712, to_date('11-04-2040', 'dd-mm-yyyy'), '3', '11', '102', '04', '2040', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14713, to_date('12-04-2040', 'dd-mm-yyyy'), '4', '12', '103', '04', '2040', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14714, to_date('13-04-2040', 'dd-mm-yyyy'), '5', '13', '104', '04', '2040', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14715, to_date('14-04-2040', 'dd-mm-yyyy'), '6', '14', '105', '04', '2040', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14716, to_date('15-04-2040', 'dd-mm-yyyy'), '7', '15', '106', '04', '2040', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14717, to_date('16-04-2040', 'dd-mm-yyyy'), '1', '16', '107', '04', '2040', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14718, to_date('17-04-2040', 'dd-mm-yyyy'), '2', '17', '108', '04', '2040', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14719, to_date('18-04-2040', 'dd-mm-yyyy'), '3', '18', '109', '04', '2040', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14720, to_date('19-04-2040', 'dd-mm-yyyy'), '4', '19', '110', '04', '2040', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14721, to_date('20-04-2040', 'dd-mm-yyyy'), '5', '20', '111', '04', '2040', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14722, to_date('21-04-2040', 'dd-mm-yyyy'), '6', '21', '112', '04', '2040', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14723, to_date('22-04-2040', 'dd-mm-yyyy'), '7', '22', '113', '04', '2040', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14724, to_date('23-04-2040', 'dd-mm-yyyy'), '1', '23', '114', '04', '2040', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14725, to_date('24-04-2040', 'dd-mm-yyyy'), '2', '24', '115', '04', '2040', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14726, to_date('25-04-2040', 'dd-mm-yyyy'), '3', '25', '116', '04', '2040', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14727, to_date('26-04-2040', 'dd-mm-yyyy'), '4', '26', '117', '04', '2040', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14728, to_date('27-04-2040', 'dd-mm-yyyy'), '5', '27', '118', '04', '2040', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14729, to_date('28-04-2040', 'dd-mm-yyyy'), '6', '28', '119', '04', '2040', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14730, to_date('29-04-2040', 'dd-mm-yyyy'), '7', '29', '120', '04', '2040', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14731, to_date('30-04-2040', 'dd-mm-yyyy'), '1', '30', '121', '04', '2040', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14732, to_date('01-05-2040', 'dd-mm-yyyy'), '2', '01', '122', '05', '2040', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14733, to_date('02-05-2040', 'dd-mm-yyyy'), '3', '02', '123', '05', '2040', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14734, to_date('03-05-2040', 'dd-mm-yyyy'), '4', '03', '124', '05', '2040', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14735, to_date('04-05-2040', 'dd-mm-yyyy'), '5', '04', '125', '05', '2040', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14736, to_date('05-05-2040', 'dd-mm-yyyy'), '6', '05', '126', '05', '2040', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14737, to_date('06-05-2040', 'dd-mm-yyyy'), '7', '06', '127', '05', '2040', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14738, to_date('07-05-2040', 'dd-mm-yyyy'), '1', '07', '128', '05', '2040', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14739, to_date('08-05-2040', 'dd-mm-yyyy'), '2', '08', '129', '05', '2040', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14740, to_date('09-05-2040', 'dd-mm-yyyy'), '3', '09', '130', '05', '2040', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14741, to_date('10-05-2040', 'dd-mm-yyyy'), '4', '10', '131', '05', '2040', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14742, to_date('11-05-2040', 'dd-mm-yyyy'), '5', '11', '132', '05', '2040', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14743, to_date('12-05-2040', 'dd-mm-yyyy'), '6', '12', '133', '05', '2040', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14744, to_date('13-05-2040', 'dd-mm-yyyy'), '7', '13', '134', '05', '2040', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14745, to_date('14-05-2040', 'dd-mm-yyyy'), '1', '14', '135', '05', '2040', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14746, to_date('15-05-2040', 'dd-mm-yyyy'), '2', '15', '136', '05', '2040', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14747, to_date('16-05-2040', 'dd-mm-yyyy'), '3', '16', '137', '05', '2040', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14748, to_date('17-05-2040', 'dd-mm-yyyy'), '4', '17', '138', '05', '2040', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14749, to_date('18-05-2040', 'dd-mm-yyyy'), '5', '18', '139', '05', '2040', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14750, to_date('19-05-2040', 'dd-mm-yyyy'), '6', '19', '140', '05', '2040', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14751, to_date('20-05-2040', 'dd-mm-yyyy'), '7', '20', '141', '05', '2040', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14752, to_date('21-05-2040', 'dd-mm-yyyy'), '1', '21', '142', '05', '2040', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14753, to_date('22-05-2040', 'dd-mm-yyyy'), '2', '22', '143', '05', '2040', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14754, to_date('23-05-2040', 'dd-mm-yyyy'), '3', '23', '144', '05', '2040', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14755, to_date('24-05-2040', 'dd-mm-yyyy'), '4', '24', '145', '05', '2040', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14756, to_date('25-05-2040', 'dd-mm-yyyy'), '5', '25', '146', '05', '2040', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14757, to_date('26-05-2040', 'dd-mm-yyyy'), '6', '26', '147', '05', '2040', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14758, to_date('27-05-2040', 'dd-mm-yyyy'), '7', '27', '148', '05', '2040', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14759, to_date('28-05-2040', 'dd-mm-yyyy'), '1', '28', '149', '05', '2040', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14760, to_date('29-05-2040', 'dd-mm-yyyy'), '2', '29', '150', '05', '2040', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14761, to_date('30-05-2040', 'dd-mm-yyyy'), '3', '30', '151', '05', '2040', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14762, to_date('31-05-2040', 'dd-mm-yyyy'), '4', '31', '152', '05', '2040', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14763, to_date('01-06-2040', 'dd-mm-yyyy'), '5', '01', '153', '06', '2040', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14764, to_date('02-06-2040', 'dd-mm-yyyy'), '6', '02', '154', '06', '2040', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14765, to_date('03-06-2040', 'dd-mm-yyyy'), '7', '03', '155', '06', '2040', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14766, to_date('04-06-2040', 'dd-mm-yyyy'), '1', '04', '156', '06', '2040', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14767, to_date('05-06-2040', 'dd-mm-yyyy'), '2', '05', '157', '06', '2040', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14768, to_date('06-06-2040', 'dd-mm-yyyy'), '3', '06', '158', '06', '2040', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14769, to_date('07-06-2040', 'dd-mm-yyyy'), '4', '07', '159', '06', '2040', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14770, to_date('08-06-2040', 'dd-mm-yyyy'), '5', '08', '160', '06', '2040', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14771, to_date('09-06-2040', 'dd-mm-yyyy'), '6', '09', '161', '06', '2040', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14772, to_date('10-06-2040', 'dd-mm-yyyy'), '7', '10', '162', '06', '2040', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14773, to_date('11-06-2040', 'dd-mm-yyyy'), '1', '11', '163', '06', '2040', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14774, to_date('12-06-2040', 'dd-mm-yyyy'), '2', '12', '164', '06', '2040', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14775, to_date('13-06-2040', 'dd-mm-yyyy'), '3', '13', '165', '06', '2040', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14776, to_date('14-06-2040', 'dd-mm-yyyy'), '4', '14', '166', '06', '2040', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14777, to_date('15-06-2040', 'dd-mm-yyyy'), '5', '15', '167', '06', '2040', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14778, to_date('16-06-2040', 'dd-mm-yyyy'), '6', '16', '168', '06', '2040', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14779, to_date('17-06-2040', 'dd-mm-yyyy'), '7', '17', '169', '06', '2040', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14780, to_date('18-06-2040', 'dd-mm-yyyy'), '1', '18', '170', '06', '2040', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14781, to_date('19-06-2040', 'dd-mm-yyyy'), '2', '19', '171', '06', '2040', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14782, to_date('20-06-2040', 'dd-mm-yyyy'), '3', '20', '172', '06', '2040', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14783, to_date('21-06-2040', 'dd-mm-yyyy'), '4', '21', '173', '06', '2040', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14784, to_date('22-06-2040', 'dd-mm-yyyy'), '5', '22', '174', '06', '2040', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14785, to_date('23-06-2040', 'dd-mm-yyyy'), '6', '23', '175', '06', '2040', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14786, to_date('24-06-2040', 'dd-mm-yyyy'), '7', '24', '176', '06', '2040', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14787, to_date('25-06-2040', 'dd-mm-yyyy'), '1', '25', '177', '06', '2040', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14788, to_date('26-06-2040', 'dd-mm-yyyy'), '2', '26', '178', '06', '2040', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14789, to_date('27-06-2040', 'dd-mm-yyyy'), '3', '27', '179', '06', '2040', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14790, to_date('28-06-2040', 'dd-mm-yyyy'), '4', '28', '180', '06', '2040', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14791, to_date('29-06-2040', 'dd-mm-yyyy'), '5', '29', '181', '06', '2040', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14792, to_date('30-06-2040', 'dd-mm-yyyy'), '6', '30', '182', '06', '2040', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14793, to_date('01-07-2040', 'dd-mm-yyyy'), '7', '01', '183', '07', '2040', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14794, to_date('02-07-2040', 'dd-mm-yyyy'), '1', '02', '184', '07', '2040', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14795, to_date('03-07-2040', 'dd-mm-yyyy'), '2', '03', '185', '07', '2040', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14796, to_date('04-07-2040', 'dd-mm-yyyy'), '3', '04', '186', '07', '2040', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14797, to_date('05-07-2040', 'dd-mm-yyyy'), '4', '05', '187', '07', '2040', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14798, to_date('06-07-2040', 'dd-mm-yyyy'), '5', '06', '188', '07', '2040', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14799, to_date('07-07-2040', 'dd-mm-yyyy'), '6', '07', '189', '07', '2040', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14800, to_date('08-07-2040', 'dd-mm-yyyy'), '7', '08', '190', '07', '2040', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14801, to_date('09-07-2040', 'dd-mm-yyyy'), '1', '09', '191', '07', '2040', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14802, to_date('10-07-2040', 'dd-mm-yyyy'), '2', '10', '192', '07', '2040', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14803, to_date('11-07-2040', 'dd-mm-yyyy'), '3', '11', '193', '07', '2040', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14804, to_date('12-07-2040', 'dd-mm-yyyy'), '4', '12', '194', '07', '2040', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14805, to_date('13-07-2040', 'dd-mm-yyyy'), '5', '13', '195', '07', '2040', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14806, to_date('14-07-2040', 'dd-mm-yyyy'), '6', '14', '196', '07', '2040', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14807, to_date('15-07-2040', 'dd-mm-yyyy'), '7', '15', '197', '07', '2040', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14808, to_date('16-07-2040', 'dd-mm-yyyy'), '1', '16', '198', '07', '2040', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14809, to_date('17-07-2040', 'dd-mm-yyyy'), '2', '17', '199', '07', '2040', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14810, to_date('18-07-2040', 'dd-mm-yyyy'), '3', '18', '200', '07', '2040', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14811, to_date('19-07-2040', 'dd-mm-yyyy'), '4', '19', '201', '07', '2040', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14812, to_date('20-07-2040', 'dd-mm-yyyy'), '5', '20', '202', '07', '2040', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14813, to_date('21-07-2040', 'dd-mm-yyyy'), '6', '21', '203', '07', '2040', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14814, to_date('22-07-2040', 'dd-mm-yyyy'), '7', '22', '204', '07', '2040', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16299, to_date('15-08-2044', 'dd-mm-yyyy'), '1', '15', '228', '08', '2044', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16300, to_date('16-08-2044', 'dd-mm-yyyy'), '2', '16', '229', '08', '2044', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16301, to_date('17-08-2044', 'dd-mm-yyyy'), '3', '17', '230', '08', '2044', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16302, to_date('18-08-2044', 'dd-mm-yyyy'), '4', '18', '231', '08', '2044', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16303, to_date('19-08-2044', 'dd-mm-yyyy'), '5', '19', '232', '08', '2044', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16304, to_date('20-08-2044', 'dd-mm-yyyy'), '6', '20', '233', '08', '2044', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16305, to_date('21-08-2044', 'dd-mm-yyyy'), '7', '21', '234', '08', '2044', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16306, to_date('22-08-2044', 'dd-mm-yyyy'), '1', '22', '235', '08', '2044', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16307, to_date('23-08-2044', 'dd-mm-yyyy'), '2', '23', '236', '08', '2044', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16308, to_date('24-08-2044', 'dd-mm-yyyy'), '3', '24', '237', '08', '2044', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16309, to_date('25-08-2044', 'dd-mm-yyyy'), '4', '25', '238', '08', '2044', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16310, to_date('26-08-2044', 'dd-mm-yyyy'), '5', '26', '239', '08', '2044', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16311, to_date('27-08-2044', 'dd-mm-yyyy'), '6', '27', '240', '08', '2044', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16312, to_date('28-08-2044', 'dd-mm-yyyy'), '7', '28', '241', '08', '2044', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16313, to_date('29-08-2044', 'dd-mm-yyyy'), '1', '29', '242', '08', '2044', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16314, to_date('30-08-2044', 'dd-mm-yyyy'), '2', '30', '243', '08', '2044', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16315, to_date('31-08-2044', 'dd-mm-yyyy'), '3', '31', '244', '08', '2044', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16316, to_date('01-09-2044', 'dd-mm-yyyy'), '4', '01', '245', '09', '2044', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16317, to_date('02-09-2044', 'dd-mm-yyyy'), '5', '02', '246', '09', '2044', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16318, to_date('03-09-2044', 'dd-mm-yyyy'), '6', '03', '247', '09', '2044', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16319, to_date('04-09-2044', 'dd-mm-yyyy'), '7', '04', '248', '09', '2044', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16320, to_date('05-09-2044', 'dd-mm-yyyy'), '1', '05', '249', '09', '2044', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16321, to_date('06-09-2044', 'dd-mm-yyyy'), '2', '06', '250', '09', '2044', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16322, to_date('07-09-2044', 'dd-mm-yyyy'), '3', '07', '251', '09', '2044', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16323, to_date('08-09-2044', 'dd-mm-yyyy'), '4', '08', '252', '09', '2044', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16324, to_date('09-09-2044', 'dd-mm-yyyy'), '5', '09', '253', '09', '2044', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16325, to_date('10-09-2044', 'dd-mm-yyyy'), '6', '10', '254', '09', '2044', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16326, to_date('11-09-2044', 'dd-mm-yyyy'), '7', '11', '255', '09', '2044', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16327, to_date('12-09-2044', 'dd-mm-yyyy'), '1', '12', '256', '09', '2044', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16328, to_date('13-09-2044', 'dd-mm-yyyy'), '2', '13', '257', '09', '2044', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16329, to_date('14-09-2044', 'dd-mm-yyyy'), '3', '14', '258', '09', '2044', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16330, to_date('15-09-2044', 'dd-mm-yyyy'), '4', '15', '259', '09', '2044', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16331, to_date('16-09-2044', 'dd-mm-yyyy'), '5', '16', '260', '09', '2044', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16332, to_date('17-09-2044', 'dd-mm-yyyy'), '6', '17', '261', '09', '2044', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16333, to_date('18-09-2044', 'dd-mm-yyyy'), '7', '18', '262', '09', '2044', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16334, to_date('19-09-2044', 'dd-mm-yyyy'), '1', '19', '263', '09', '2044', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16335, to_date('20-09-2044', 'dd-mm-yyyy'), '2', '20', '264', '09', '2044', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16336, to_date('21-09-2044', 'dd-mm-yyyy'), '3', '21', '265', '09', '2044', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16337, to_date('22-09-2044', 'dd-mm-yyyy'), '4', '22', '266', '09', '2044', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16338, to_date('23-09-2044', 'dd-mm-yyyy'), '5', '23', '267', '09', '2044', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16339, to_date('24-09-2044', 'dd-mm-yyyy'), '6', '24', '268', '09', '2044', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16340, to_date('25-09-2044', 'dd-mm-yyyy'), '7', '25', '269', '09', '2044', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16341, to_date('26-09-2044', 'dd-mm-yyyy'), '1', '26', '270', '09', '2044', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16342, to_date('27-09-2044', 'dd-mm-yyyy'), '2', '27', '271', '09', '2044', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16343, to_date('28-09-2044', 'dd-mm-yyyy'), '3', '28', '272', '09', '2044', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16344, to_date('29-09-2044', 'dd-mm-yyyy'), '4', '29', '273', '09', '2044', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16345, to_date('30-09-2044', 'dd-mm-yyyy'), '5', '30', '274', '09', '2044', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16346, to_date('01-10-2044', 'dd-mm-yyyy'), '6', '01', '275', '10', '2044', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16347, to_date('02-10-2044', 'dd-mm-yyyy'), '7', '02', '276', '10', '2044', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16348, to_date('03-10-2044', 'dd-mm-yyyy'), '1', '03', '277', '10', '2044', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16349, to_date('04-10-2044', 'dd-mm-yyyy'), '2', '04', '278', '10', '2044', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16350, to_date('05-10-2044', 'dd-mm-yyyy'), '3', '05', '279', '10', '2044', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16351, to_date('06-10-2044', 'dd-mm-yyyy'), '4', '06', '280', '10', '2044', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16352, to_date('07-10-2044', 'dd-mm-yyyy'), '5', '07', '281', '10', '2044', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16353, to_date('08-10-2044', 'dd-mm-yyyy'), '6', '08', '282', '10', '2044', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16354, to_date('09-10-2044', 'dd-mm-yyyy'), '7', '09', '283', '10', '2044', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16355, to_date('10-10-2044', 'dd-mm-yyyy'), '1', '10', '284', '10', '2044', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16356, to_date('11-10-2044', 'dd-mm-yyyy'), '2', '11', '285', '10', '2044', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16357, to_date('12-10-2044', 'dd-mm-yyyy'), '3', '12', '286', '10', '2044', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16358, to_date('13-10-2044', 'dd-mm-yyyy'), '4', '13', '287', '10', '2044', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16359, to_date('14-10-2044', 'dd-mm-yyyy'), '5', '14', '288', '10', '2044', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16360, to_date('15-10-2044', 'dd-mm-yyyy'), '6', '15', '289', '10', '2044', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16361, to_date('16-10-2044', 'dd-mm-yyyy'), '7', '16', '290', '10', '2044', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16362, to_date('17-10-2044', 'dd-mm-yyyy'), '1', '17', '291', '10', '2044', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16363, to_date('18-10-2044', 'dd-mm-yyyy'), '2', '18', '292', '10', '2044', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16364, to_date('19-10-2044', 'dd-mm-yyyy'), '3', '19', '293', '10', '2044', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16365, to_date('20-10-2044', 'dd-mm-yyyy'), '4', '20', '294', '10', '2044', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16366, to_date('21-10-2044', 'dd-mm-yyyy'), '5', '21', '295', '10', '2044', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16367, to_date('22-10-2044', 'dd-mm-yyyy'), '6', '22', '296', '10', '2044', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16368, to_date('23-10-2044', 'dd-mm-yyyy'), '7', '23', '297', '10', '2044', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16369, to_date('24-10-2044', 'dd-mm-yyyy'), '1', '24', '298', '10', '2044', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16370, to_date('25-10-2044', 'dd-mm-yyyy'), '2', '25', '299', '10', '2044', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16371, to_date('26-10-2044', 'dd-mm-yyyy'), '3', '26', '300', '10', '2044', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16372, to_date('27-10-2044', 'dd-mm-yyyy'), '4', '27', '301', '10', '2044', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16373, to_date('28-10-2044', 'dd-mm-yyyy'), '5', '28', '302', '10', '2044', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16374, to_date('29-10-2044', 'dd-mm-yyyy'), '6', '29', '303', '10', '2044', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16375, to_date('30-10-2044', 'dd-mm-yyyy'), '7', '30', '304', '10', '2044', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16376, to_date('31-10-2044', 'dd-mm-yyyy'), '1', '31', '305', '10', '2044', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16377, to_date('01-11-2044', 'dd-mm-yyyy'), '2', '01', '306', '11', '2044', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16378, to_date('02-11-2044', 'dd-mm-yyyy'), '3', '02', '307', '11', '2044', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16379, to_date('03-11-2044', 'dd-mm-yyyy'), '4', '03', '308', '11', '2044', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16380, to_date('04-11-2044', 'dd-mm-yyyy'), '5', '04', '309', '11', '2044', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16381, to_date('05-11-2044', 'dd-mm-yyyy'), '6', '05', '310', '11', '2044', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16382, to_date('06-11-2044', 'dd-mm-yyyy'), '7', '06', '311', '11', '2044', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16383, to_date('07-11-2044', 'dd-mm-yyyy'), '1', '07', '312', '11', '2044', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16384, to_date('08-11-2044', 'dd-mm-yyyy'), '2', '08', '313', '11', '2044', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16385, to_date('09-11-2044', 'dd-mm-yyyy'), '3', '09', '314', '11', '2044', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16386, to_date('10-11-2044', 'dd-mm-yyyy'), '4', '10', '315', '11', '2044', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16387, to_date('11-11-2044', 'dd-mm-yyyy'), '5', '11', '316', '11', '2044', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16388, to_date('12-11-2044', 'dd-mm-yyyy'), '6', '12', '317', '11', '2044', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16389, to_date('13-11-2044', 'dd-mm-yyyy'), '7', '13', '318', '11', '2044', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16390, to_date('14-11-2044', 'dd-mm-yyyy'), '1', '14', '319', '11', '2044', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16391, to_date('15-11-2044', 'dd-mm-yyyy'), '2', '15', '320', '11', '2044', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16392, to_date('16-11-2044', 'dd-mm-yyyy'), '3', '16', '321', '11', '2044', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16393, to_date('17-11-2044', 'dd-mm-yyyy'), '4', '17', '322', '11', '2044', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16394, to_date('18-11-2044', 'dd-mm-yyyy'), '5', '18', '323', '11', '2044', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16395, to_date('19-11-2044', 'dd-mm-yyyy'), '6', '19', '324', '11', '2044', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16396, to_date('20-11-2044', 'dd-mm-yyyy'), '7', '20', '325', '11', '2044', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16397, to_date('21-11-2044', 'dd-mm-yyyy'), '1', '21', '326', '11', '2044', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16398, to_date('22-11-2044', 'dd-mm-yyyy'), '2', '22', '327', '11', '2044', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16399, to_date('23-11-2044', 'dd-mm-yyyy'), '3', '23', '328', '11', '2044', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16400, to_date('24-11-2044', 'dd-mm-yyyy'), '4', '24', '329', '11', '2044', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16401, to_date('25-11-2044', 'dd-mm-yyyy'), '5', '25', '330', '11', '2044', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16402, to_date('26-11-2044', 'dd-mm-yyyy'), '6', '26', '331', '11', '2044', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16403, to_date('27-11-2044', 'dd-mm-yyyy'), '7', '27', '332', '11', '2044', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16404, to_date('28-11-2044', 'dd-mm-yyyy'), '1', '28', '333', '11', '2044', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17889, to_date('22-12-2048', 'dd-mm-yyyy'), '2', '22', '357', '12', '2048', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17890, to_date('23-12-2048', 'dd-mm-yyyy'), '3', '23', '358', '12', '2048', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17891, to_date('24-12-2048', 'dd-mm-yyyy'), '4', '24', '359', '12', '2048', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17892, to_date('25-12-2048', 'dd-mm-yyyy'), '5', '25', '360', '12', '2048', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17893, to_date('26-12-2048', 'dd-mm-yyyy'), '6', '26', '361', '12', '2048', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17894, to_date('27-12-2048', 'dd-mm-yyyy'), '7', '27', '362', '12', '2048', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17895, to_date('28-12-2048', 'dd-mm-yyyy'), '1', '28', '363', '12', '2048', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17896, to_date('29-12-2048', 'dd-mm-yyyy'), '2', '29', '364', '12', '2048', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17897, to_date('30-12-2048', 'dd-mm-yyyy'), '3', '30', '365', '12', '2048', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17898, to_date('31-12-2048', 'dd-mm-yyyy'), '4', '31', '366', '12', '2048', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17899, to_date('01-01-2049', 'dd-mm-yyyy'), '5', '01', '001', '01', '2049', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17900, to_date('02-01-2049', 'dd-mm-yyyy'), '6', '02', '002', '01', '2049', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17901, to_date('03-01-2049', 'dd-mm-yyyy'), '7', '03', '003', '01', '2049', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17902, to_date('04-01-2049', 'dd-mm-yyyy'), '1', '04', '004', '01', '2049', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17903, to_date('05-01-2049', 'dd-mm-yyyy'), '2', '05', '005', '01', '2049', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17904, to_date('06-01-2049', 'dd-mm-yyyy'), '3', '06', '006', '01', '2049', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17905, to_date('07-01-2049', 'dd-mm-yyyy'), '4', '07', '007', '01', '2049', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17906, to_date('08-01-2049', 'dd-mm-yyyy'), '5', '08', '008', '01', '2049', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17907, to_date('09-01-2049', 'dd-mm-yyyy'), '6', '09', '009', '01', '2049', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17908, to_date('10-01-2049', 'dd-mm-yyyy'), '7', '10', '010', '01', '2049', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17909, to_date('11-01-2049', 'dd-mm-yyyy'), '1', '11', '011', '01', '2049', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17910, to_date('12-01-2049', 'dd-mm-yyyy'), '2', '12', '012', '01', '2049', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17911, to_date('13-01-2049', 'dd-mm-yyyy'), '3', '13', '013', '01', '2049', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17912, to_date('14-01-2049', 'dd-mm-yyyy'), '4', '14', '014', '01', '2049', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17913, to_date('15-01-2049', 'dd-mm-yyyy'), '5', '15', '015', '01', '2049', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17914, to_date('16-01-2049', 'dd-mm-yyyy'), '6', '16', '016', '01', '2049', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17915, to_date('17-01-2049', 'dd-mm-yyyy'), '7', '17', '017', '01', '2049', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17916, to_date('18-01-2049', 'dd-mm-yyyy'), '1', '18', '018', '01', '2049', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17917, to_date('19-01-2049', 'dd-mm-yyyy'), '2', '19', '019', '01', '2049', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17918, to_date('20-01-2049', 'dd-mm-yyyy'), '3', '20', '020', '01', '2049', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17919, to_date('21-01-2049', 'dd-mm-yyyy'), '4', '21', '021', '01', '2049', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17920, to_date('22-01-2049', 'dd-mm-yyyy'), '5', '22', '022', '01', '2049', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17921, to_date('23-01-2049', 'dd-mm-yyyy'), '6', '23', '023', '01', '2049', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17922, to_date('24-01-2049', 'dd-mm-yyyy'), '7', '24', '024', '01', '2049', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17923, to_date('25-01-2049', 'dd-mm-yyyy'), '1', '25', '025', '01', '2049', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17924, to_date('26-01-2049', 'dd-mm-yyyy'), '2', '26', '026', '01', '2049', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17925, to_date('27-01-2049', 'dd-mm-yyyy'), '3', '27', '027', '01', '2049', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17926, to_date('28-01-2049', 'dd-mm-yyyy'), '4', '28', '028', '01', '2049', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17927, to_date('29-01-2049', 'dd-mm-yyyy'), '5', '29', '029', '01', '2049', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17928, to_date('30-01-2049', 'dd-mm-yyyy'), '6', '30', '030', '01', '2049', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17929, to_date('31-01-2049', 'dd-mm-yyyy'), '7', '31', '031', '01', '2049', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17930, to_date('01-02-2049', 'dd-mm-yyyy'), '1', '01', '032', '02', '2049', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17931, to_date('02-02-2049', 'dd-mm-yyyy'), '2', '02', '033', '02', '2049', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17932, to_date('03-02-2049', 'dd-mm-yyyy'), '3', '03', '034', '02', '2049', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17933, to_date('04-02-2049', 'dd-mm-yyyy'), '4', '04', '035', '02', '2049', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17934, to_date('05-02-2049', 'dd-mm-yyyy'), '5', '05', '036', '02', '2049', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17935, to_date('06-02-2049', 'dd-mm-yyyy'), '6', '06', '037', '02', '2049', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17936, to_date('07-02-2049', 'dd-mm-yyyy'), '7', '07', '038', '02', '2049', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17937, to_date('08-02-2049', 'dd-mm-yyyy'), '1', '08', '039', '02', '2049', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17938, to_date('09-02-2049', 'dd-mm-yyyy'), '2', '09', '040', '02', '2049', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17939, to_date('10-02-2049', 'dd-mm-yyyy'), '3', '10', '041', '02', '2049', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17940, to_date('11-02-2049', 'dd-mm-yyyy'), '4', '11', '042', '02', '2049', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17941, to_date('12-02-2049', 'dd-mm-yyyy'), '5', '12', '043', '02', '2049', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17942, to_date('13-02-2049', 'dd-mm-yyyy'), '6', '13', '044', '02', '2049', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17943, to_date('14-02-2049', 'dd-mm-yyyy'), '7', '14', '045', '02', '2049', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17944, to_date('15-02-2049', 'dd-mm-yyyy'), '1', '15', '046', '02', '2049', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17945, to_date('16-02-2049', 'dd-mm-yyyy'), '2', '16', '047', '02', '2049', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17946, to_date('17-02-2049', 'dd-mm-yyyy'), '3', '17', '048', '02', '2049', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17947, to_date('18-02-2049', 'dd-mm-yyyy'), '4', '18', '049', '02', '2049', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17948, to_date('19-02-2049', 'dd-mm-yyyy'), '5', '19', '050', '02', '2049', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17949, to_date('20-02-2049', 'dd-mm-yyyy'), '6', '20', '051', '02', '2049', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17950, to_date('21-02-2049', 'dd-mm-yyyy'), '7', '21', '052', '02', '2049', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17951, to_date('22-02-2049', 'dd-mm-yyyy'), '1', '22', '053', '02', '2049', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17952, to_date('23-02-2049', 'dd-mm-yyyy'), '2', '23', '054', '02', '2049', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17953, to_date('24-02-2049', 'dd-mm-yyyy'), '3', '24', '055', '02', '2049', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17954, to_date('25-02-2049', 'dd-mm-yyyy'), '4', '25', '056', '02', '2049', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17955, to_date('26-02-2049', 'dd-mm-yyyy'), '5', '26', '057', '02', '2049', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17956, to_date('27-02-2049', 'dd-mm-yyyy'), '6', '27', '058', '02', '2049', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17957, to_date('28-02-2049', 'dd-mm-yyyy'), '7', '28', '059', '02', '2049', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17958, to_date('01-03-2049', 'dd-mm-yyyy'), '1', '01', '060', '03', '2049', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17959, to_date('02-03-2049', 'dd-mm-yyyy'), '2', '02', '061', '03', '2049', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17960, to_date('03-03-2049', 'dd-mm-yyyy'), '3', '03', '062', '03', '2049', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17961, to_date('04-03-2049', 'dd-mm-yyyy'), '4', '04', '063', '03', '2049', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17962, to_date('05-03-2049', 'dd-mm-yyyy'), '5', '05', '064', '03', '2049', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17963, to_date('06-03-2049', 'dd-mm-yyyy'), '6', '06', '065', '03', '2049', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17964, to_date('07-03-2049', 'dd-mm-yyyy'), '7', '07', '066', '03', '2049', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17965, to_date('08-03-2049', 'dd-mm-yyyy'), '1', '08', '067', '03', '2049', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17966, to_date('09-03-2049', 'dd-mm-yyyy'), '2', '09', '068', '03', '2049', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17967, to_date('10-03-2049', 'dd-mm-yyyy'), '3', '10', '069', '03', '2049', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17968, to_date('11-03-2049', 'dd-mm-yyyy'), '4', '11', '070', '03', '2049', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17969, to_date('12-03-2049', 'dd-mm-yyyy'), '5', '12', '071', '03', '2049', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17970, to_date('13-03-2049', 'dd-mm-yyyy'), '6', '13', '072', '03', '2049', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17971, to_date('14-03-2049', 'dd-mm-yyyy'), '7', '14', '073', '03', '2049', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17972, to_date('15-03-2049', 'dd-mm-yyyy'), '1', '15', '074', '03', '2049', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17973, to_date('16-03-2049', 'dd-mm-yyyy'), '2', '16', '075', '03', '2049', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17974, to_date('17-03-2049', 'dd-mm-yyyy'), '3', '17', '076', '03', '2049', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17975, to_date('18-03-2049', 'dd-mm-yyyy'), '4', '18', '077', '03', '2049', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17976, to_date('19-03-2049', 'dd-mm-yyyy'), '5', '19', '078', '03', '2049', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17977, to_date('20-03-2049', 'dd-mm-yyyy'), '6', '20', '079', '03', '2049', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17978, to_date('21-03-2049', 'dd-mm-yyyy'), '7', '21', '080', '03', '2049', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17979, to_date('22-03-2049', 'dd-mm-yyyy'), '1', '22', '081', '03', '2049', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17980, to_date('23-03-2049', 'dd-mm-yyyy'), '2', '23', '082', '03', '2049', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17981, to_date('24-03-2049', 'dd-mm-yyyy'), '3', '24', '083', '03', '2049', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17982, to_date('25-03-2049', 'dd-mm-yyyy'), '4', '25', '084', '03', '2049', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17983, to_date('26-03-2049', 'dd-mm-yyyy'), '5', '26', '085', '03', '2049', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17984, to_date('27-03-2049', 'dd-mm-yyyy'), '6', '27', '086', '03', '2049', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17985, to_date('28-03-2049', 'dd-mm-yyyy'), '7', '28', '087', '03', '2049', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17986, to_date('29-03-2049', 'dd-mm-yyyy'), '1', '29', '088', '03', '2049', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17987, to_date('30-03-2049', 'dd-mm-yyyy'), '2', '30', '089', '03', '2049', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17988, to_date('31-03-2049', 'dd-mm-yyyy'), '3', '31', '090', '03', '2049', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17989, to_date('01-04-2049', 'dd-mm-yyyy'), '4', '01', '091', '04', '2049', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17990, to_date('02-04-2049', 'dd-mm-yyyy'), '5', '02', '092', '04', '2049', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17991, to_date('03-04-2049', 'dd-mm-yyyy'), '6', '03', '093', '04', '2049', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17992, to_date('04-04-2049', 'dd-mm-yyyy'), '7', '04', '094', '04', '2049', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17993, to_date('05-04-2049', 'dd-mm-yyyy'), '1', '05', '095', '04', '2049', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17994, to_date('06-04-2049', 'dd-mm-yyyy'), '2', '06', '096', '04', '2049', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13119, to_date('01-12-2035', 'dd-mm-yyyy'), '6', '01', '335', '12', '2035', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13120, to_date('02-12-2035', 'dd-mm-yyyy'), '7', '02', '336', '12', '2035', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13121, to_date('03-12-2035', 'dd-mm-yyyy'), '1', '03', '337', '12', '2035', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13122, to_date('04-12-2035', 'dd-mm-yyyy'), '2', '04', '338', '12', '2035', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13123, to_date('05-12-2035', 'dd-mm-yyyy'), '3', '05', '339', '12', '2035', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13124, to_date('06-12-2035', 'dd-mm-yyyy'), '4', '06', '340', '12', '2035', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13125, to_date('07-12-2035', 'dd-mm-yyyy'), '5', '07', '341', '12', '2035', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13126, to_date('08-12-2035', 'dd-mm-yyyy'), '6', '08', '342', '12', '2035', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13127, to_date('09-12-2035', 'dd-mm-yyyy'), '7', '09', '343', '12', '2035', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13128, to_date('10-12-2035', 'dd-mm-yyyy'), '1', '10', '344', '12', '2035', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13129, to_date('11-12-2035', 'dd-mm-yyyy'), '2', '11', '345', '12', '2035', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13130, to_date('12-12-2035', 'dd-mm-yyyy'), '3', '12', '346', '12', '2035', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13131, to_date('13-12-2035', 'dd-mm-yyyy'), '4', '13', '347', '12', '2035', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13132, to_date('14-12-2035', 'dd-mm-yyyy'), '5', '14', '348', '12', '2035', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13133, to_date('15-12-2035', 'dd-mm-yyyy'), '6', '15', '349', '12', '2035', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13134, to_date('16-12-2035', 'dd-mm-yyyy'), '7', '16', '350', '12', '2035', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13135, to_date('17-12-2035', 'dd-mm-yyyy'), '1', '17', '351', '12', '2035', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13136, to_date('18-12-2035', 'dd-mm-yyyy'), '2', '18', '352', '12', '2035', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13137, to_date('19-12-2035', 'dd-mm-yyyy'), '3', '19', '353', '12', '2035', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13138, to_date('20-12-2035', 'dd-mm-yyyy'), '4', '20', '354', '12', '2035', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13139, to_date('21-12-2035', 'dd-mm-yyyy'), '5', '21', '355', '12', '2035', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13140, to_date('22-12-2035', 'dd-mm-yyyy'), '6', '22', '356', '12', '2035', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13141, to_date('23-12-2035', 'dd-mm-yyyy'), '7', '23', '357', '12', '2035', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13142, to_date('24-12-2035', 'dd-mm-yyyy'), '1', '24', '358', '12', '2035', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13143, to_date('25-12-2035', 'dd-mm-yyyy'), '2', '25', '359', '12', '2035', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13144, to_date('26-12-2035', 'dd-mm-yyyy'), '3', '26', '360', '12', '2035', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13145, to_date('27-12-2035', 'dd-mm-yyyy'), '4', '27', '361', '12', '2035', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13146, to_date('28-12-2035', 'dd-mm-yyyy'), '5', '28', '362', '12', '2035', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13147, to_date('29-12-2035', 'dd-mm-yyyy'), '6', '29', '363', '12', '2035', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13148, to_date('30-12-2035', 'dd-mm-yyyy'), '7', '30', '364', '12', '2035', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13149, to_date('31-12-2035', 'dd-mm-yyyy'), '1', '31', '365', '12', '2035', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13150, to_date('01-01-2036', 'dd-mm-yyyy'), '2', '01', '001', '01', '2036', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13151, to_date('02-01-2036', 'dd-mm-yyyy'), '3', '02', '002', '01', '2036', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13152, to_date('03-01-2036', 'dd-mm-yyyy'), '4', '03', '003', '01', '2036', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13153, to_date('04-01-2036', 'dd-mm-yyyy'), '5', '04', '004', '01', '2036', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13154, to_date('05-01-2036', 'dd-mm-yyyy'), '6', '05', '005', '01', '2036', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13155, to_date('06-01-2036', 'dd-mm-yyyy'), '7', '06', '006', '01', '2036', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13156, to_date('07-01-2036', 'dd-mm-yyyy'), '1', '07', '007', '01', '2036', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13157, to_date('08-01-2036', 'dd-mm-yyyy'), '2', '08', '008', '01', '2036', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13158, to_date('09-01-2036', 'dd-mm-yyyy'), '3', '09', '009', '01', '2036', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13159, to_date('10-01-2036', 'dd-mm-yyyy'), '4', '10', '010', '01', '2036', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13160, to_date('11-01-2036', 'dd-mm-yyyy'), '5', '11', '011', '01', '2036', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13161, to_date('12-01-2036', 'dd-mm-yyyy'), '6', '12', '012', '01', '2036', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13162, to_date('13-01-2036', 'dd-mm-yyyy'), '7', '13', '013', '01', '2036', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13163, to_date('14-01-2036', 'dd-mm-yyyy'), '1', '14', '014', '01', '2036', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13164, to_date('15-01-2036', 'dd-mm-yyyy'), '2', '15', '015', '01', '2036', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13165, to_date('16-01-2036', 'dd-mm-yyyy'), '3', '16', '016', '01', '2036', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13166, to_date('17-01-2036', 'dd-mm-yyyy'), '4', '17', '017', '01', '2036', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13167, to_date('18-01-2036', 'dd-mm-yyyy'), '5', '18', '018', '01', '2036', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13168, to_date('19-01-2036', 'dd-mm-yyyy'), '6', '19', '019', '01', '2036', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13169, to_date('20-01-2036', 'dd-mm-yyyy'), '7', '20', '020', '01', '2036', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13170, to_date('21-01-2036', 'dd-mm-yyyy'), '1', '21', '021', '01', '2036', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13171, to_date('22-01-2036', 'dd-mm-yyyy'), '2', '22', '022', '01', '2036', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13172, to_date('23-01-2036', 'dd-mm-yyyy'), '3', '23', '023', '01', '2036', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13173, to_date('24-01-2036', 'dd-mm-yyyy'), '4', '24', '024', '01', '2036', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13174, to_date('25-01-2036', 'dd-mm-yyyy'), '5', '25', '025', '01', '2036', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13175, to_date('26-01-2036', 'dd-mm-yyyy'), '6', '26', '026', '01', '2036', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13176, to_date('27-01-2036', 'dd-mm-yyyy'), '7', '27', '027', '01', '2036', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13177, to_date('28-01-2036', 'dd-mm-yyyy'), '1', '28', '028', '01', '2036', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13178, to_date('29-01-2036', 'dd-mm-yyyy'), '2', '29', '029', '01', '2036', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13179, to_date('30-01-2036', 'dd-mm-yyyy'), '3', '30', '030', '01', '2036', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13180, to_date('31-01-2036', 'dd-mm-yyyy'), '4', '31', '031', '01', '2036', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13181, to_date('01-02-2036', 'dd-mm-yyyy'), '5', '01', '032', '02', '2036', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13182, to_date('02-02-2036', 'dd-mm-yyyy'), '6', '02', '033', '02', '2036', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13183, to_date('03-02-2036', 'dd-mm-yyyy'), '7', '03', '034', '02', '2036', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13184, to_date('04-02-2036', 'dd-mm-yyyy'), '1', '04', '035', '02', '2036', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13185, to_date('05-02-2036', 'dd-mm-yyyy'), '2', '05', '036', '02', '2036', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13186, to_date('06-02-2036', 'dd-mm-yyyy'), '3', '06', '037', '02', '2036', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13187, to_date('07-02-2036', 'dd-mm-yyyy'), '4', '07', '038', '02', '2036', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13188, to_date('08-02-2036', 'dd-mm-yyyy'), '5', '08', '039', '02', '2036', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13189, to_date('09-02-2036', 'dd-mm-yyyy'), '6', '09', '040', '02', '2036', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13190, to_date('10-02-2036', 'dd-mm-yyyy'), '7', '10', '041', '02', '2036', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13191, to_date('11-02-2036', 'dd-mm-yyyy'), '1', '11', '042', '02', '2036', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13192, to_date('12-02-2036', 'dd-mm-yyyy'), '2', '12', '043', '02', '2036', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13193, to_date('13-02-2036', 'dd-mm-yyyy'), '3', '13', '044', '02', '2036', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13194, to_date('14-02-2036', 'dd-mm-yyyy'), '4', '14', '045', '02', '2036', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13195, to_date('15-02-2036', 'dd-mm-yyyy'), '5', '15', '046', '02', '2036', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13196, to_date('16-02-2036', 'dd-mm-yyyy'), '6', '16', '047', '02', '2036', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13197, to_date('17-02-2036', 'dd-mm-yyyy'), '7', '17', '048', '02', '2036', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13198, to_date('18-02-2036', 'dd-mm-yyyy'), '1', '18', '049', '02', '2036', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13199, to_date('19-02-2036', 'dd-mm-yyyy'), '2', '19', '050', '02', '2036', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13200, to_date('20-02-2036', 'dd-mm-yyyy'), '3', '20', '051', '02', '2036', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13201, to_date('21-02-2036', 'dd-mm-yyyy'), '4', '21', '052', '02', '2036', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13202, to_date('22-02-2036', 'dd-mm-yyyy'), '5', '22', '053', '02', '2036', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13203, to_date('23-02-2036', 'dd-mm-yyyy'), '6', '23', '054', '02', '2036', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13204, to_date('24-02-2036', 'dd-mm-yyyy'), '7', '24', '055', '02', '2036', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13205, to_date('25-02-2036', 'dd-mm-yyyy'), '1', '25', '056', '02', '2036', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13206, to_date('26-02-2036', 'dd-mm-yyyy'), '2', '26', '057', '02', '2036', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13207, to_date('27-02-2036', 'dd-mm-yyyy'), '3', '27', '058', '02', '2036', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13208, to_date('28-02-2036', 'dd-mm-yyyy'), '4', '28', '059', '02', '2036', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13209, to_date('29-02-2036', 'dd-mm-yyyy'), '5', '29', '060', '02', '2036', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13210, to_date('01-03-2036', 'dd-mm-yyyy'), '6', '01', '061', '03', '2036', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13211, to_date('02-03-2036', 'dd-mm-yyyy'), '7', '02', '062', '03', '2036', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13212, to_date('03-03-2036', 'dd-mm-yyyy'), '1', '03', '063', '03', '2036', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13213, to_date('04-03-2036', 'dd-mm-yyyy'), '2', '04', '064', '03', '2036', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13214, to_date('05-03-2036', 'dd-mm-yyyy'), '3', '05', '065', '03', '2036', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13215, to_date('06-03-2036', 'dd-mm-yyyy'), '4', '06', '066', '03', '2036', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13216, to_date('07-03-2036', 'dd-mm-yyyy'), '5', '07', '067', '03', '2036', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13217, to_date('08-03-2036', 'dd-mm-yyyy'), '6', '08', '068', '03', '2036', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13218, to_date('09-03-2036', 'dd-mm-yyyy'), '7', '09', '069', '03', '2036', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13219, to_date('10-03-2036', 'dd-mm-yyyy'), '1', '10', '070', '03', '2036', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13220, to_date('11-03-2036', 'dd-mm-yyyy'), '2', '11', '071', '03', '2036', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13221, to_date('12-03-2036', 'dd-mm-yyyy'), '3', '12', '072', '03', '2036', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13222, to_date('13-03-2036', 'dd-mm-yyyy'), '4', '13', '073', '03', '2036', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13223, to_date('14-03-2036', 'dd-mm-yyyy'), '5', '14', '074', '03', '2036', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13224, to_date('15-03-2036', 'dd-mm-yyyy'), '6', '15', '075', '03', '2036', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14815, to_date('23-07-2040', 'dd-mm-yyyy'), '1', '23', '205', '07', '2040', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14816, to_date('24-07-2040', 'dd-mm-yyyy'), '2', '24', '206', '07', '2040', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14817, to_date('25-07-2040', 'dd-mm-yyyy'), '3', '25', '207', '07', '2040', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14818, to_date('26-07-2040', 'dd-mm-yyyy'), '4', '26', '208', '07', '2040', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14819, to_date('27-07-2040', 'dd-mm-yyyy'), '5', '27', '209', '07', '2040', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14820, to_date('28-07-2040', 'dd-mm-yyyy'), '6', '28', '210', '07', '2040', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14821, to_date('29-07-2040', 'dd-mm-yyyy'), '7', '29', '211', '07', '2040', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14822, to_date('30-07-2040', 'dd-mm-yyyy'), '1', '30', '212', '07', '2040', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14823, to_date('31-07-2040', 'dd-mm-yyyy'), '2', '31', '213', '07', '2040', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14824, to_date('01-08-2040', 'dd-mm-yyyy'), '3', '01', '214', '08', '2040', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14825, to_date('02-08-2040', 'dd-mm-yyyy'), '4', '02', '215', '08', '2040', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14826, to_date('03-08-2040', 'dd-mm-yyyy'), '5', '03', '216', '08', '2040', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14827, to_date('04-08-2040', 'dd-mm-yyyy'), '6', '04', '217', '08', '2040', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14828, to_date('05-08-2040', 'dd-mm-yyyy'), '7', '05', '218', '08', '2040', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14829, to_date('06-08-2040', 'dd-mm-yyyy'), '1', '06', '219', '08', '2040', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14830, to_date('07-08-2040', 'dd-mm-yyyy'), '2', '07', '220', '08', '2040', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14831, to_date('08-08-2040', 'dd-mm-yyyy'), '3', '08', '221', '08', '2040', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14832, to_date('09-08-2040', 'dd-mm-yyyy'), '4', '09', '222', '08', '2040', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14833, to_date('10-08-2040', 'dd-mm-yyyy'), '5', '10', '223', '08', '2040', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14834, to_date('11-08-2040', 'dd-mm-yyyy'), '6', '11', '224', '08', '2040', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14835, to_date('12-08-2040', 'dd-mm-yyyy'), '7', '12', '225', '08', '2040', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14836, to_date('13-08-2040', 'dd-mm-yyyy'), '1', '13', '226', '08', '2040', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14837, to_date('14-08-2040', 'dd-mm-yyyy'), '2', '14', '227', '08', '2040', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14838, to_date('15-08-2040', 'dd-mm-yyyy'), '3', '15', '228', '08', '2040', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14839, to_date('16-08-2040', 'dd-mm-yyyy'), '4', '16', '229', '08', '2040', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14840, to_date('17-08-2040', 'dd-mm-yyyy'), '5', '17', '230', '08', '2040', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14841, to_date('18-08-2040', 'dd-mm-yyyy'), '6', '18', '231', '08', '2040', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14842, to_date('19-08-2040', 'dd-mm-yyyy'), '7', '19', '232', '08', '2040', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14843, to_date('20-08-2040', 'dd-mm-yyyy'), '1', '20', '233', '08', '2040', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14844, to_date('21-08-2040', 'dd-mm-yyyy'), '2', '21', '234', '08', '2040', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14845, to_date('22-08-2040', 'dd-mm-yyyy'), '3', '22', '235', '08', '2040', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14846, to_date('23-08-2040', 'dd-mm-yyyy'), '4', '23', '236', '08', '2040', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14847, to_date('24-08-2040', 'dd-mm-yyyy'), '5', '24', '237', '08', '2040', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14848, to_date('25-08-2040', 'dd-mm-yyyy'), '6', '25', '238', '08', '2040', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14849, to_date('26-08-2040', 'dd-mm-yyyy'), '7', '26', '239', '08', '2040', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14850, to_date('27-08-2040', 'dd-mm-yyyy'), '1', '27', '240', '08', '2040', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14851, to_date('28-08-2040', 'dd-mm-yyyy'), '2', '28', '241', '08', '2040', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14852, to_date('29-08-2040', 'dd-mm-yyyy'), '3', '29', '242', '08', '2040', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14853, to_date('30-08-2040', 'dd-mm-yyyy'), '4', '30', '243', '08', '2040', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14854, to_date('31-08-2040', 'dd-mm-yyyy'), '5', '31', '244', '08', '2040', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14855, to_date('01-09-2040', 'dd-mm-yyyy'), '6', '01', '245', '09', '2040', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14856, to_date('02-09-2040', 'dd-mm-yyyy'), '7', '02', '246', '09', '2040', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14857, to_date('03-09-2040', 'dd-mm-yyyy'), '1', '03', '247', '09', '2040', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14858, to_date('04-09-2040', 'dd-mm-yyyy'), '2', '04', '248', '09', '2040', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14859, to_date('05-09-2040', 'dd-mm-yyyy'), '3', '05', '249', '09', '2040', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14860, to_date('06-09-2040', 'dd-mm-yyyy'), '4', '06', '250', '09', '2040', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14861, to_date('07-09-2040', 'dd-mm-yyyy'), '5', '07', '251', '09', '2040', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14862, to_date('08-09-2040', 'dd-mm-yyyy'), '6', '08', '252', '09', '2040', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14863, to_date('09-09-2040', 'dd-mm-yyyy'), '7', '09', '253', '09', '2040', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14864, to_date('10-09-2040', 'dd-mm-yyyy'), '1', '10', '254', '09', '2040', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14865, to_date('11-09-2040', 'dd-mm-yyyy'), '2', '11', '255', '09', '2040', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14866, to_date('12-09-2040', 'dd-mm-yyyy'), '3', '12', '256', '09', '2040', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14867, to_date('13-09-2040', 'dd-mm-yyyy'), '4', '13', '257', '09', '2040', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14868, to_date('14-09-2040', 'dd-mm-yyyy'), '5', '14', '258', '09', '2040', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14869, to_date('15-09-2040', 'dd-mm-yyyy'), '6', '15', '259', '09', '2040', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14870, to_date('16-09-2040', 'dd-mm-yyyy'), '7', '16', '260', '09', '2040', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14871, to_date('17-09-2040', 'dd-mm-yyyy'), '1', '17', '261', '09', '2040', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14872, to_date('18-09-2040', 'dd-mm-yyyy'), '2', '18', '262', '09', '2040', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14873, to_date('19-09-2040', 'dd-mm-yyyy'), '3', '19', '263', '09', '2040', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14874, to_date('20-09-2040', 'dd-mm-yyyy'), '4', '20', '264', '09', '2040', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14875, to_date('21-09-2040', 'dd-mm-yyyy'), '5', '21', '265', '09', '2040', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14876, to_date('22-09-2040', 'dd-mm-yyyy'), '6', '22', '266', '09', '2040', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14877, to_date('23-09-2040', 'dd-mm-yyyy'), '7', '23', '267', '09', '2040', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14878, to_date('24-09-2040', 'dd-mm-yyyy'), '1', '24', '268', '09', '2040', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14879, to_date('25-09-2040', 'dd-mm-yyyy'), '2', '25', '269', '09', '2040', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14880, to_date('26-09-2040', 'dd-mm-yyyy'), '3', '26', '270', '09', '2040', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14881, to_date('27-09-2040', 'dd-mm-yyyy'), '4', '27', '271', '09', '2040', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14882, to_date('28-09-2040', 'dd-mm-yyyy'), '5', '28', '272', '09', '2040', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14883, to_date('29-09-2040', 'dd-mm-yyyy'), '6', '29', '273', '09', '2040', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14884, to_date('30-09-2040', 'dd-mm-yyyy'), '7', '30', '274', '09', '2040', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14885, to_date('01-10-2040', 'dd-mm-yyyy'), '1', '01', '275', '10', '2040', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14886, to_date('02-10-2040', 'dd-mm-yyyy'), '2', '02', '276', '10', '2040', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14887, to_date('03-10-2040', 'dd-mm-yyyy'), '3', '03', '277', '10', '2040', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14888, to_date('04-10-2040', 'dd-mm-yyyy'), '4', '04', '278', '10', '2040', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14889, to_date('05-10-2040', 'dd-mm-yyyy'), '5', '05', '279', '10', '2040', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14890, to_date('06-10-2040', 'dd-mm-yyyy'), '6', '06', '280', '10', '2040', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14891, to_date('07-10-2040', 'dd-mm-yyyy'), '7', '07', '281', '10', '2040', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14892, to_date('08-10-2040', 'dd-mm-yyyy'), '1', '08', '282', '10', '2040', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14893, to_date('09-10-2040', 'dd-mm-yyyy'), '2', '09', '283', '10', '2040', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14894, to_date('10-10-2040', 'dd-mm-yyyy'), '3', '10', '284', '10', '2040', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14895, to_date('11-10-2040', 'dd-mm-yyyy'), '4', '11', '285', '10', '2040', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14896, to_date('12-10-2040', 'dd-mm-yyyy'), '5', '12', '286', '10', '2040', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14897, to_date('13-10-2040', 'dd-mm-yyyy'), '6', '13', '287', '10', '2040', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14898, to_date('14-10-2040', 'dd-mm-yyyy'), '7', '14', '288', '10', '2040', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14899, to_date('15-10-2040', 'dd-mm-yyyy'), '1', '15', '289', '10', '2040', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14900, to_date('16-10-2040', 'dd-mm-yyyy'), '2', '16', '290', '10', '2040', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14901, to_date('17-10-2040', 'dd-mm-yyyy'), '3', '17', '291', '10', '2040', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14902, to_date('18-10-2040', 'dd-mm-yyyy'), '4', '18', '292', '10', '2040', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14903, to_date('19-10-2040', 'dd-mm-yyyy'), '5', '19', '293', '10', '2040', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14904, to_date('20-10-2040', 'dd-mm-yyyy'), '6', '20', '294', '10', '2040', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14905, to_date('21-10-2040', 'dd-mm-yyyy'), '7', '21', '295', '10', '2040', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14906, to_date('22-10-2040', 'dd-mm-yyyy'), '1', '22', '296', '10', '2040', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14907, to_date('23-10-2040', 'dd-mm-yyyy'), '2', '23', '297', '10', '2040', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14908, to_date('24-10-2040', 'dd-mm-yyyy'), '3', '24', '298', '10', '2040', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14909, to_date('25-10-2040', 'dd-mm-yyyy'), '4', '25', '299', '10', '2040', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14910, to_date('26-10-2040', 'dd-mm-yyyy'), '5', '26', '300', '10', '2040', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14911, to_date('27-10-2040', 'dd-mm-yyyy'), '6', '27', '301', '10', '2040', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14912, to_date('28-10-2040', 'dd-mm-yyyy'), '7', '28', '302', '10', '2040', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14913, to_date('29-10-2040', 'dd-mm-yyyy'), '1', '29', '303', '10', '2040', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14914, to_date('30-10-2040', 'dd-mm-yyyy'), '2', '30', '304', '10', '2040', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14915, to_date('31-10-2040', 'dd-mm-yyyy'), '3', '31', '305', '10', '2040', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14916, to_date('01-11-2040', 'dd-mm-yyyy'), '4', '01', '306', '11', '2040', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14917, to_date('02-11-2040', 'dd-mm-yyyy'), '5', '02', '307', '11', '2040', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14918, to_date('03-11-2040', 'dd-mm-yyyy'), '6', '03', '308', '11', '2040', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14919, to_date('04-11-2040', 'dd-mm-yyyy'), '7', '04', '309', '11', '2040', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14920, to_date('05-11-2040', 'dd-mm-yyyy'), '1', '05', '310', '11', '2040', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16405, to_date('29-11-2044', 'dd-mm-yyyy'), '2', '29', '334', '11', '2044', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16406, to_date('30-11-2044', 'dd-mm-yyyy'), '3', '30', '335', '11', '2044', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16407, to_date('01-12-2044', 'dd-mm-yyyy'), '4', '01', '336', '12', '2044', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16408, to_date('02-12-2044', 'dd-mm-yyyy'), '5', '02', '337', '12', '2044', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16409, to_date('03-12-2044', 'dd-mm-yyyy'), '6', '03', '338', '12', '2044', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16410, to_date('04-12-2044', 'dd-mm-yyyy'), '7', '04', '339', '12', '2044', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16411, to_date('05-12-2044', 'dd-mm-yyyy'), '1', '05', '340', '12', '2044', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16412, to_date('06-12-2044', 'dd-mm-yyyy'), '2', '06', '341', '12', '2044', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16413, to_date('07-12-2044', 'dd-mm-yyyy'), '3', '07', '342', '12', '2044', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16414, to_date('08-12-2044', 'dd-mm-yyyy'), '4', '08', '343', '12', '2044', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16415, to_date('09-12-2044', 'dd-mm-yyyy'), '5', '09', '344', '12', '2044', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16416, to_date('10-12-2044', 'dd-mm-yyyy'), '6', '10', '345', '12', '2044', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16417, to_date('11-12-2044', 'dd-mm-yyyy'), '7', '11', '346', '12', '2044', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16418, to_date('12-12-2044', 'dd-mm-yyyy'), '1', '12', '347', '12', '2044', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16419, to_date('13-12-2044', 'dd-mm-yyyy'), '2', '13', '348', '12', '2044', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16420, to_date('14-12-2044', 'dd-mm-yyyy'), '3', '14', '349', '12', '2044', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16421, to_date('15-12-2044', 'dd-mm-yyyy'), '4', '15', '350', '12', '2044', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16422, to_date('16-12-2044', 'dd-mm-yyyy'), '5', '16', '351', '12', '2044', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16423, to_date('17-12-2044', 'dd-mm-yyyy'), '6', '17', '352', '12', '2044', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16424, to_date('18-12-2044', 'dd-mm-yyyy'), '7', '18', '353', '12', '2044', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16425, to_date('19-12-2044', 'dd-mm-yyyy'), '1', '19', '354', '12', '2044', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16426, to_date('20-12-2044', 'dd-mm-yyyy'), '2', '20', '355', '12', '2044', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16427, to_date('21-12-2044', 'dd-mm-yyyy'), '3', '21', '356', '12', '2044', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16428, to_date('22-12-2044', 'dd-mm-yyyy'), '4', '22', '357', '12', '2044', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16429, to_date('23-12-2044', 'dd-mm-yyyy'), '5', '23', '358', '12', '2044', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16430, to_date('24-12-2044', 'dd-mm-yyyy'), '6', '24', '359', '12', '2044', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16431, to_date('25-12-2044', 'dd-mm-yyyy'), '7', '25', '360', '12', '2044', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16432, to_date('26-12-2044', 'dd-mm-yyyy'), '1', '26', '361', '12', '2044', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16433, to_date('27-12-2044', 'dd-mm-yyyy'), '2', '27', '362', '12', '2044', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16434, to_date('28-12-2044', 'dd-mm-yyyy'), '3', '28', '363', '12', '2044', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16435, to_date('29-12-2044', 'dd-mm-yyyy'), '4', '29', '364', '12', '2044', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16436, to_date('30-12-2044', 'dd-mm-yyyy'), '5', '30', '365', '12', '2044', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16437, to_date('31-12-2044', 'dd-mm-yyyy'), '6', '31', '366', '12', '2044', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16438, to_date('01-01-2045', 'dd-mm-yyyy'), '7', '01', '001', '01', '2045', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16439, to_date('02-01-2045', 'dd-mm-yyyy'), '1', '02', '002', '01', '2045', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16440, to_date('03-01-2045', 'dd-mm-yyyy'), '2', '03', '003', '01', '2045', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16441, to_date('04-01-2045', 'dd-mm-yyyy'), '3', '04', '004', '01', '2045', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16442, to_date('05-01-2045', 'dd-mm-yyyy'), '4', '05', '005', '01', '2045', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16443, to_date('06-01-2045', 'dd-mm-yyyy'), '5', '06', '006', '01', '2045', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16444, to_date('07-01-2045', 'dd-mm-yyyy'), '6', '07', '007', '01', '2045', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16445, to_date('08-01-2045', 'dd-mm-yyyy'), '7', '08', '008', '01', '2045', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16446, to_date('09-01-2045', 'dd-mm-yyyy'), '1', '09', '009', '01', '2045', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16447, to_date('10-01-2045', 'dd-mm-yyyy'), '2', '10', '010', '01', '2045', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16448, to_date('11-01-2045', 'dd-mm-yyyy'), '3', '11', '011', '01', '2045', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16449, to_date('12-01-2045', 'dd-mm-yyyy'), '4', '12', '012', '01', '2045', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16450, to_date('13-01-2045', 'dd-mm-yyyy'), '5', '13', '013', '01', '2045', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16451, to_date('14-01-2045', 'dd-mm-yyyy'), '6', '14', '014', '01', '2045', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16452, to_date('15-01-2045', 'dd-mm-yyyy'), '7', '15', '015', '01', '2045', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16453, to_date('16-01-2045', 'dd-mm-yyyy'), '1', '16', '016', '01', '2045', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16454, to_date('17-01-2045', 'dd-mm-yyyy'), '2', '17', '017', '01', '2045', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16455, to_date('18-01-2045', 'dd-mm-yyyy'), '3', '18', '018', '01', '2045', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16456, to_date('19-01-2045', 'dd-mm-yyyy'), '4', '19', '019', '01', '2045', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16457, to_date('20-01-2045', 'dd-mm-yyyy'), '5', '20', '020', '01', '2045', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16458, to_date('21-01-2045', 'dd-mm-yyyy'), '6', '21', '021', '01', '2045', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16459, to_date('22-01-2045', 'dd-mm-yyyy'), '7', '22', '022', '01', '2045', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16460, to_date('23-01-2045', 'dd-mm-yyyy'), '1', '23', '023', '01', '2045', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16461, to_date('24-01-2045', 'dd-mm-yyyy'), '2', '24', '024', '01', '2045', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16462, to_date('25-01-2045', 'dd-mm-yyyy'), '3', '25', '025', '01', '2045', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16463, to_date('26-01-2045', 'dd-mm-yyyy'), '4', '26', '026', '01', '2045', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16464, to_date('27-01-2045', 'dd-mm-yyyy'), '5', '27', '027', '01', '2045', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16465, to_date('28-01-2045', 'dd-mm-yyyy'), '6', '28', '028', '01', '2045', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16466, to_date('29-01-2045', 'dd-mm-yyyy'), '7', '29', '029', '01', '2045', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16467, to_date('30-01-2045', 'dd-mm-yyyy'), '1', '30', '030', '01', '2045', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16468, to_date('31-01-2045', 'dd-mm-yyyy'), '2', '31', '031', '01', '2045', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16469, to_date('01-02-2045', 'dd-mm-yyyy'), '3', '01', '032', '02', '2045', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16470, to_date('02-02-2045', 'dd-mm-yyyy'), '4', '02', '033', '02', '2045', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16471, to_date('03-02-2045', 'dd-mm-yyyy'), '5', '03', '034', '02', '2045', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16472, to_date('04-02-2045', 'dd-mm-yyyy'), '6', '04', '035', '02', '2045', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16473, to_date('05-02-2045', 'dd-mm-yyyy'), '7', '05', '036', '02', '2045', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16474, to_date('06-02-2045', 'dd-mm-yyyy'), '1', '06', '037', '02', '2045', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16475, to_date('07-02-2045', 'dd-mm-yyyy'), '2', '07', '038', '02', '2045', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16476, to_date('08-02-2045', 'dd-mm-yyyy'), '3', '08', '039', '02', '2045', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16477, to_date('09-02-2045', 'dd-mm-yyyy'), '4', '09', '040', '02', '2045', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16478, to_date('10-02-2045', 'dd-mm-yyyy'), '5', '10', '041', '02', '2045', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16479, to_date('11-02-2045', 'dd-mm-yyyy'), '6', '11', '042', '02', '2045', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16480, to_date('12-02-2045', 'dd-mm-yyyy'), '7', '12', '043', '02', '2045', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16481, to_date('13-02-2045', 'dd-mm-yyyy'), '1', '13', '044', '02', '2045', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16482, to_date('14-02-2045', 'dd-mm-yyyy'), '2', '14', '045', '02', '2045', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16483, to_date('15-02-2045', 'dd-mm-yyyy'), '3', '15', '046', '02', '2045', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16484, to_date('16-02-2045', 'dd-mm-yyyy'), '4', '16', '047', '02', '2045', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16485, to_date('17-02-2045', 'dd-mm-yyyy'), '5', '17', '048', '02', '2045', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16486, to_date('18-02-2045', 'dd-mm-yyyy'), '6', '18', '049', '02', '2045', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16487, to_date('19-02-2045', 'dd-mm-yyyy'), '7', '19', '050', '02', '2045', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16488, to_date('20-02-2045', 'dd-mm-yyyy'), '1', '20', '051', '02', '2045', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
commit;
prompt 22000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16489, to_date('21-02-2045', 'dd-mm-yyyy'), '2', '21', '052', '02', '2045', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16490, to_date('22-02-2045', 'dd-mm-yyyy'), '3', '22', '053', '02', '2045', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16491, to_date('23-02-2045', 'dd-mm-yyyy'), '4', '23', '054', '02', '2045', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16492, to_date('24-02-2045', 'dd-mm-yyyy'), '5', '24', '055', '02', '2045', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16493, to_date('25-02-2045', 'dd-mm-yyyy'), '6', '25', '056', '02', '2045', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16494, to_date('26-02-2045', 'dd-mm-yyyy'), '7', '26', '057', '02', '2045', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16495, to_date('27-02-2045', 'dd-mm-yyyy'), '1', '27', '058', '02', '2045', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16496, to_date('28-02-2045', 'dd-mm-yyyy'), '2', '28', '059', '02', '2045', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16497, to_date('01-03-2045', 'dd-mm-yyyy'), '3', '01', '060', '03', '2045', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16498, to_date('02-03-2045', 'dd-mm-yyyy'), '4', '02', '061', '03', '2045', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16499, to_date('03-03-2045', 'dd-mm-yyyy'), '5', '03', '062', '03', '2045', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16500, to_date('04-03-2045', 'dd-mm-yyyy'), '6', '04', '063', '03', '2045', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16501, to_date('05-03-2045', 'dd-mm-yyyy'), '7', '05', '064', '03', '2045', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16502, to_date('06-03-2045', 'dd-mm-yyyy'), '1', '06', '065', '03', '2045', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16503, to_date('07-03-2045', 'dd-mm-yyyy'), '2', '07', '066', '03', '2045', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16504, to_date('08-03-2045', 'dd-mm-yyyy'), '3', '08', '067', '03', '2045', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16505, to_date('09-03-2045', 'dd-mm-yyyy'), '4', '09', '068', '03', '2045', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16506, to_date('10-03-2045', 'dd-mm-yyyy'), '5', '10', '069', '03', '2045', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16507, to_date('11-03-2045', 'dd-mm-yyyy'), '6', '11', '070', '03', '2045', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16508, to_date('12-03-2045', 'dd-mm-yyyy'), '7', '12', '071', '03', '2045', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16509, to_date('13-03-2045', 'dd-mm-yyyy'), '1', '13', '072', '03', '2045', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16510, to_date('14-03-2045', 'dd-mm-yyyy'), '2', '14', '073', '03', '2045', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17995, to_date('07-04-2049', 'dd-mm-yyyy'), '3', '07', '097', '04', '2049', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17996, to_date('08-04-2049', 'dd-mm-yyyy'), '4', '08', '098', '04', '2049', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17997, to_date('09-04-2049', 'dd-mm-yyyy'), '5', '09', '099', '04', '2049', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17998, to_date('10-04-2049', 'dd-mm-yyyy'), '6', '10', '100', '04', '2049', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17999, to_date('11-04-2049', 'dd-mm-yyyy'), '7', '11', '101', '04', '2049', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18000, to_date('12-04-2049', 'dd-mm-yyyy'), '1', '12', '102', '04', '2049', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18001, to_date('13-04-2049', 'dd-mm-yyyy'), '2', '13', '103', '04', '2049', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18002, to_date('14-04-2049', 'dd-mm-yyyy'), '3', '14', '104', '04', '2049', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18003, to_date('15-04-2049', 'dd-mm-yyyy'), '4', '15', '105', '04', '2049', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18004, to_date('16-04-2049', 'dd-mm-yyyy'), '5', '16', '106', '04', '2049', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18005, to_date('17-04-2049', 'dd-mm-yyyy'), '6', '17', '107', '04', '2049', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18006, to_date('18-04-2049', 'dd-mm-yyyy'), '7', '18', '108', '04', '2049', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18007, to_date('19-04-2049', 'dd-mm-yyyy'), '1', '19', '109', '04', '2049', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18008, to_date('20-04-2049', 'dd-mm-yyyy'), '2', '20', '110', '04', '2049', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18009, to_date('21-04-2049', 'dd-mm-yyyy'), '3', '21', '111', '04', '2049', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18010, to_date('22-04-2049', 'dd-mm-yyyy'), '4', '22', '112', '04', '2049', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18011, to_date('23-04-2049', 'dd-mm-yyyy'), '5', '23', '113', '04', '2049', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18012, to_date('24-04-2049', 'dd-mm-yyyy'), '6', '24', '114', '04', '2049', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18013, to_date('25-04-2049', 'dd-mm-yyyy'), '7', '25', '115', '04', '2049', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18014, to_date('26-04-2049', 'dd-mm-yyyy'), '1', '26', '116', '04', '2049', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18015, to_date('27-04-2049', 'dd-mm-yyyy'), '2', '27', '117', '04', '2049', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18016, to_date('28-04-2049', 'dd-mm-yyyy'), '3', '28', '118', '04', '2049', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18017, to_date('29-04-2049', 'dd-mm-yyyy'), '4', '29', '119', '04', '2049', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18018, to_date('30-04-2049', 'dd-mm-yyyy'), '5', '30', '120', '04', '2049', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18019, to_date('01-05-2049', 'dd-mm-yyyy'), '6', '01', '121', '05', '2049', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18020, to_date('02-05-2049', 'dd-mm-yyyy'), '7', '02', '122', '05', '2049', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18021, to_date('03-05-2049', 'dd-mm-yyyy'), '1', '03', '123', '05', '2049', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18022, to_date('04-05-2049', 'dd-mm-yyyy'), '2', '04', '124', '05', '2049', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18023, to_date('05-05-2049', 'dd-mm-yyyy'), '3', '05', '125', '05', '2049', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18024, to_date('06-05-2049', 'dd-mm-yyyy'), '4', '06', '126', '05', '2049', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18025, to_date('07-05-2049', 'dd-mm-yyyy'), '5', '07', '127', '05', '2049', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18026, to_date('08-05-2049', 'dd-mm-yyyy'), '6', '08', '128', '05', '2049', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18027, to_date('09-05-2049', 'dd-mm-yyyy'), '7', '09', '129', '05', '2049', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18028, to_date('10-05-2049', 'dd-mm-yyyy'), '1', '10', '130', '05', '2049', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18029, to_date('11-05-2049', 'dd-mm-yyyy'), '2', '11', '131', '05', '2049', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18030, to_date('12-05-2049', 'dd-mm-yyyy'), '3', '12', '132', '05', '2049', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18031, to_date('13-05-2049', 'dd-mm-yyyy'), '4', '13', '133', '05', '2049', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18032, to_date('14-05-2049', 'dd-mm-yyyy'), '5', '14', '134', '05', '2049', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18033, to_date('15-05-2049', 'dd-mm-yyyy'), '6', '15', '135', '05', '2049', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18034, to_date('16-05-2049', 'dd-mm-yyyy'), '7', '16', '136', '05', '2049', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18035, to_date('17-05-2049', 'dd-mm-yyyy'), '1', '17', '137', '05', '2049', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18036, to_date('18-05-2049', 'dd-mm-yyyy'), '2', '18', '138', '05', '2049', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18037, to_date('19-05-2049', 'dd-mm-yyyy'), '3', '19', '139', '05', '2049', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18038, to_date('20-05-2049', 'dd-mm-yyyy'), '4', '20', '140', '05', '2049', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18039, to_date('21-05-2049', 'dd-mm-yyyy'), '5', '21', '141', '05', '2049', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18040, to_date('22-05-2049', 'dd-mm-yyyy'), '6', '22', '142', '05', '2049', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18041, to_date('23-05-2049', 'dd-mm-yyyy'), '7', '23', '143', '05', '2049', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18042, to_date('24-05-2049', 'dd-mm-yyyy'), '1', '24', '144', '05', '2049', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18043, to_date('25-05-2049', 'dd-mm-yyyy'), '2', '25', '145', '05', '2049', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18044, to_date('26-05-2049', 'dd-mm-yyyy'), '3', '26', '146', '05', '2049', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18045, to_date('27-05-2049', 'dd-mm-yyyy'), '4', '27', '147', '05', '2049', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18046, to_date('28-05-2049', 'dd-mm-yyyy'), '5', '28', '148', '05', '2049', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18047, to_date('29-05-2049', 'dd-mm-yyyy'), '6', '29', '149', '05', '2049', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18048, to_date('30-05-2049', 'dd-mm-yyyy'), '7', '30', '150', '05', '2049', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18049, to_date('31-05-2049', 'dd-mm-yyyy'), '1', '31', '151', '05', '2049', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18050, to_date('01-06-2049', 'dd-mm-yyyy'), '2', '01', '152', '06', '2049', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18051, to_date('02-06-2049', 'dd-mm-yyyy'), '3', '02', '153', '06', '2049', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18052, to_date('03-06-2049', 'dd-mm-yyyy'), '4', '03', '154', '06', '2049', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18053, to_date('04-06-2049', 'dd-mm-yyyy'), '5', '04', '155', '06', '2049', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18054, to_date('05-06-2049', 'dd-mm-yyyy'), '6', '05', '156', '06', '2049', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18055, to_date('06-06-2049', 'dd-mm-yyyy'), '7', '06', '157', '06', '2049', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18056, to_date('07-06-2049', 'dd-mm-yyyy'), '1', '07', '158', '06', '2049', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18057, to_date('08-06-2049', 'dd-mm-yyyy'), '2', '08', '159', '06', '2049', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18058, to_date('09-06-2049', 'dd-mm-yyyy'), '3', '09', '160', '06', '2049', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18059, to_date('10-06-2049', 'dd-mm-yyyy'), '4', '10', '161', '06', '2049', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18060, to_date('11-06-2049', 'dd-mm-yyyy'), '5', '11', '162', '06', '2049', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18061, to_date('12-06-2049', 'dd-mm-yyyy'), '6', '12', '163', '06', '2049', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18062, to_date('13-06-2049', 'dd-mm-yyyy'), '7', '13', '164', '06', '2049', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18063, to_date('14-06-2049', 'dd-mm-yyyy'), '1', '14', '165', '06', '2049', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18064, to_date('15-06-2049', 'dd-mm-yyyy'), '2', '15', '166', '06', '2049', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18065, to_date('16-06-2049', 'dd-mm-yyyy'), '3', '16', '167', '06', '2049', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18066, to_date('17-06-2049', 'dd-mm-yyyy'), '4', '17', '168', '06', '2049', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18067, to_date('18-06-2049', 'dd-mm-yyyy'), '5', '18', '169', '06', '2049', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18068, to_date('19-06-2049', 'dd-mm-yyyy'), '6', '19', '170', '06', '2049', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18069, to_date('20-06-2049', 'dd-mm-yyyy'), '7', '20', '171', '06', '2049', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18070, to_date('21-06-2049', 'dd-mm-yyyy'), '1', '21', '172', '06', '2049', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18071, to_date('22-06-2049', 'dd-mm-yyyy'), '2', '22', '173', '06', '2049', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18072, to_date('23-06-2049', 'dd-mm-yyyy'), '3', '23', '174', '06', '2049', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18073, to_date('24-06-2049', 'dd-mm-yyyy'), '4', '24', '175', '06', '2049', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18074, to_date('25-06-2049', 'dd-mm-yyyy'), '5', '25', '176', '06', '2049', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18075, to_date('26-06-2049', 'dd-mm-yyyy'), '6', '26', '177', '06', '2049', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18076, to_date('27-06-2049', 'dd-mm-yyyy'), '7', '27', '178', '06', '2049', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18077, to_date('28-06-2049', 'dd-mm-yyyy'), '1', '28', '179', '06', '2049', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18078, to_date('29-06-2049', 'dd-mm-yyyy'), '2', '29', '180', '06', '2049', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18079, to_date('30-06-2049', 'dd-mm-yyyy'), '3', '30', '181', '06', '2049', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18080, to_date('01-07-2049', 'dd-mm-yyyy'), '4', '01', '182', '07', '2049', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18081, to_date('02-07-2049', 'dd-mm-yyyy'), '5', '02', '183', '07', '2049', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18082, to_date('03-07-2049', 'dd-mm-yyyy'), '6', '03', '184', '07', '2049', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18083, to_date('04-07-2049', 'dd-mm-yyyy'), '7', '04', '185', '07', '2049', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18084, to_date('05-07-2049', 'dd-mm-yyyy'), '1', '05', '186', '07', '2049', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18085, to_date('06-07-2049', 'dd-mm-yyyy'), '2', '06', '187', '07', '2049', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18086, to_date('07-07-2049', 'dd-mm-yyyy'), '3', '07', '188', '07', '2049', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18087, to_date('08-07-2049', 'dd-mm-yyyy'), '4', '08', '189', '07', '2049', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18088, to_date('09-07-2049', 'dd-mm-yyyy'), '5', '09', '190', '07', '2049', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18089, to_date('10-07-2049', 'dd-mm-yyyy'), '6', '10', '191', '07', '2049', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18090, to_date('11-07-2049', 'dd-mm-yyyy'), '7', '11', '192', '07', '2049', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18091, to_date('12-07-2049', 'dd-mm-yyyy'), '1', '12', '193', '07', '2049', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18092, to_date('13-07-2049', 'dd-mm-yyyy'), '2', '13', '194', '07', '2049', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18093, to_date('14-07-2049', 'dd-mm-yyyy'), '3', '14', '195', '07', '2049', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18094, to_date('15-07-2049', 'dd-mm-yyyy'), '4', '15', '196', '07', '2049', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18095, to_date('16-07-2049', 'dd-mm-yyyy'), '5', '16', '197', '07', '2049', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18096, to_date('17-07-2049', 'dd-mm-yyyy'), '6', '17', '198', '07', '2049', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18097, to_date('18-07-2049', 'dd-mm-yyyy'), '7', '18', '199', '07', '2049', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18098, to_date('19-07-2049', 'dd-mm-yyyy'), '1', '19', '200', '07', '2049', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18099, to_date('20-07-2049', 'dd-mm-yyyy'), '2', '20', '201', '07', '2049', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18100, to_date('21-07-2049', 'dd-mm-yyyy'), '3', '21', '202', '07', '2049', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13225, to_date('16-03-2036', 'dd-mm-yyyy'), '7', '16', '076', '03', '2036', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13226, to_date('17-03-2036', 'dd-mm-yyyy'), '1', '17', '077', '03', '2036', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13227, to_date('18-03-2036', 'dd-mm-yyyy'), '2', '18', '078', '03', '2036', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13228, to_date('19-03-2036', 'dd-mm-yyyy'), '3', '19', '079', '03', '2036', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13229, to_date('20-03-2036', 'dd-mm-yyyy'), '4', '20', '080', '03', '2036', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13230, to_date('21-03-2036', 'dd-mm-yyyy'), '5', '21', '081', '03', '2036', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13231, to_date('22-03-2036', 'dd-mm-yyyy'), '6', '22', '082', '03', '2036', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13232, to_date('23-03-2036', 'dd-mm-yyyy'), '7', '23', '083', '03', '2036', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13233, to_date('24-03-2036', 'dd-mm-yyyy'), '1', '24', '084', '03', '2036', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13234, to_date('25-03-2036', 'dd-mm-yyyy'), '2', '25', '085', '03', '2036', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13235, to_date('26-03-2036', 'dd-mm-yyyy'), '3', '26', '086', '03', '2036', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13236, to_date('27-03-2036', 'dd-mm-yyyy'), '4', '27', '087', '03', '2036', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13237, to_date('28-03-2036', 'dd-mm-yyyy'), '5', '28', '088', '03', '2036', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13238, to_date('29-03-2036', 'dd-mm-yyyy'), '6', '29', '089', '03', '2036', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13239, to_date('30-03-2036', 'dd-mm-yyyy'), '7', '30', '090', '03', '2036', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13240, to_date('31-03-2036', 'dd-mm-yyyy'), '1', '31', '091', '03', '2036', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13241, to_date('01-04-2036', 'dd-mm-yyyy'), '2', '01', '092', '04', '2036', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13242, to_date('02-04-2036', 'dd-mm-yyyy'), '3', '02', '093', '04', '2036', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13243, to_date('03-04-2036', 'dd-mm-yyyy'), '4', '03', '094', '04', '2036', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13244, to_date('04-04-2036', 'dd-mm-yyyy'), '5', '04', '095', '04', '2036', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13245, to_date('05-04-2036', 'dd-mm-yyyy'), '6', '05', '096', '04', '2036', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13246, to_date('06-04-2036', 'dd-mm-yyyy'), '7', '06', '097', '04', '2036', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13247, to_date('07-04-2036', 'dd-mm-yyyy'), '1', '07', '098', '04', '2036', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13248, to_date('08-04-2036', 'dd-mm-yyyy'), '2', '08', '099', '04', '2036', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13249, to_date('09-04-2036', 'dd-mm-yyyy'), '3', '09', '100', '04', '2036', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13250, to_date('10-04-2036', 'dd-mm-yyyy'), '4', '10', '101', '04', '2036', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13251, to_date('11-04-2036', 'dd-mm-yyyy'), '5', '11', '102', '04', '2036', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13252, to_date('12-04-2036', 'dd-mm-yyyy'), '6', '12', '103', '04', '2036', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13253, to_date('13-04-2036', 'dd-mm-yyyy'), '7', '13', '104', '04', '2036', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13254, to_date('14-04-2036', 'dd-mm-yyyy'), '1', '14', '105', '04', '2036', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13255, to_date('15-04-2036', 'dd-mm-yyyy'), '2', '15', '106', '04', '2036', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13256, to_date('16-04-2036', 'dd-mm-yyyy'), '3', '16', '107', '04', '2036', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13257, to_date('17-04-2036', 'dd-mm-yyyy'), '4', '17', '108', '04', '2036', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13258, to_date('18-04-2036', 'dd-mm-yyyy'), '5', '18', '109', '04', '2036', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13259, to_date('19-04-2036', 'dd-mm-yyyy'), '6', '19', '110', '04', '2036', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13260, to_date('20-04-2036', 'dd-mm-yyyy'), '7', '20', '111', '04', '2036', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13261, to_date('21-04-2036', 'dd-mm-yyyy'), '1', '21', '112', '04', '2036', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13262, to_date('22-04-2036', 'dd-mm-yyyy'), '2', '22', '113', '04', '2036', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13263, to_date('23-04-2036', 'dd-mm-yyyy'), '3', '23', '114', '04', '2036', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13264, to_date('24-04-2036', 'dd-mm-yyyy'), '4', '24', '115', '04', '2036', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13265, to_date('25-04-2036', 'dd-mm-yyyy'), '5', '25', '116', '04', '2036', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13266, to_date('26-04-2036', 'dd-mm-yyyy'), '6', '26', '117', '04', '2036', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13267, to_date('27-04-2036', 'dd-mm-yyyy'), '7', '27', '118', '04', '2036', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13268, to_date('28-04-2036', 'dd-mm-yyyy'), '1', '28', '119', '04', '2036', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13269, to_date('29-04-2036', 'dd-mm-yyyy'), '2', '29', '120', '04', '2036', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13270, to_date('30-04-2036', 'dd-mm-yyyy'), '3', '30', '121', '04', '2036', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13271, to_date('01-05-2036', 'dd-mm-yyyy'), '4', '01', '122', '05', '2036', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13272, to_date('02-05-2036', 'dd-mm-yyyy'), '5', '02', '123', '05', '2036', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13273, to_date('03-05-2036', 'dd-mm-yyyy'), '6', '03', '124', '05', '2036', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13274, to_date('04-05-2036', 'dd-mm-yyyy'), '7', '04', '125', '05', '2036', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13275, to_date('05-05-2036', 'dd-mm-yyyy'), '1', '05', '126', '05', '2036', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13276, to_date('06-05-2036', 'dd-mm-yyyy'), '2', '06', '127', '05', '2036', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13277, to_date('07-05-2036', 'dd-mm-yyyy'), '3', '07', '128', '05', '2036', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13278, to_date('08-05-2036', 'dd-mm-yyyy'), '4', '08', '129', '05', '2036', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13279, to_date('09-05-2036', 'dd-mm-yyyy'), '5', '09', '130', '05', '2036', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13280, to_date('10-05-2036', 'dd-mm-yyyy'), '6', '10', '131', '05', '2036', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13281, to_date('11-05-2036', 'dd-mm-yyyy'), '7', '11', '132', '05', '2036', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13282, to_date('12-05-2036', 'dd-mm-yyyy'), '1', '12', '133', '05', '2036', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13283, to_date('13-05-2036', 'dd-mm-yyyy'), '2', '13', '134', '05', '2036', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13284, to_date('14-05-2036', 'dd-mm-yyyy'), '3', '14', '135', '05', '2036', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13285, to_date('15-05-2036', 'dd-mm-yyyy'), '4', '15', '136', '05', '2036', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13286, to_date('16-05-2036', 'dd-mm-yyyy'), '5', '16', '137', '05', '2036', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13287, to_date('17-05-2036', 'dd-mm-yyyy'), '6', '17', '138', '05', '2036', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13288, to_date('18-05-2036', 'dd-mm-yyyy'), '7', '18', '139', '05', '2036', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13289, to_date('19-05-2036', 'dd-mm-yyyy'), '1', '19', '140', '05', '2036', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13290, to_date('20-05-2036', 'dd-mm-yyyy'), '2', '20', '141', '05', '2036', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13291, to_date('21-05-2036', 'dd-mm-yyyy'), '3', '21', '142', '05', '2036', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13292, to_date('22-05-2036', 'dd-mm-yyyy'), '4', '22', '143', '05', '2036', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13293, to_date('23-05-2036', 'dd-mm-yyyy'), '5', '23', '144', '05', '2036', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13294, to_date('24-05-2036', 'dd-mm-yyyy'), '6', '24', '145', '05', '2036', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13295, to_date('25-05-2036', 'dd-mm-yyyy'), '7', '25', '146', '05', '2036', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13296, to_date('26-05-2036', 'dd-mm-yyyy'), '1', '26', '147', '05', '2036', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13297, to_date('27-05-2036', 'dd-mm-yyyy'), '2', '27', '148', '05', '2036', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13298, to_date('28-05-2036', 'dd-mm-yyyy'), '3', '28', '149', '05', '2036', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13299, to_date('29-05-2036', 'dd-mm-yyyy'), '4', '29', '150', '05', '2036', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13300, to_date('30-05-2036', 'dd-mm-yyyy'), '5', '30', '151', '05', '2036', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13301, to_date('31-05-2036', 'dd-mm-yyyy'), '6', '31', '152', '05', '2036', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13302, to_date('01-06-2036', 'dd-mm-yyyy'), '7', '01', '153', '06', '2036', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13303, to_date('02-06-2036', 'dd-mm-yyyy'), '1', '02', '154', '06', '2036', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13304, to_date('03-06-2036', 'dd-mm-yyyy'), '2', '03', '155', '06', '2036', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13305, to_date('04-06-2036', 'dd-mm-yyyy'), '3', '04', '156', '06', '2036', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13306, to_date('05-06-2036', 'dd-mm-yyyy'), '4', '05', '157', '06', '2036', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13307, to_date('06-06-2036', 'dd-mm-yyyy'), '5', '06', '158', '06', '2036', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13308, to_date('07-06-2036', 'dd-mm-yyyy'), '6', '07', '159', '06', '2036', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13309, to_date('08-06-2036', 'dd-mm-yyyy'), '7', '08', '160', '06', '2036', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13310, to_date('09-06-2036', 'dd-mm-yyyy'), '1', '09', '161', '06', '2036', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13311, to_date('10-06-2036', 'dd-mm-yyyy'), '2', '10', '162', '06', '2036', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13312, to_date('11-06-2036', 'dd-mm-yyyy'), '3', '11', '163', '06', '2036', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13313, to_date('12-06-2036', 'dd-mm-yyyy'), '4', '12', '164', '06', '2036', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13314, to_date('13-06-2036', 'dd-mm-yyyy'), '5', '13', '165', '06', '2036', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13315, to_date('14-06-2036', 'dd-mm-yyyy'), '6', '14', '166', '06', '2036', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13316, to_date('15-06-2036', 'dd-mm-yyyy'), '7', '15', '167', '06', '2036', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13317, to_date('16-06-2036', 'dd-mm-yyyy'), '1', '16', '168', '06', '2036', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13318, to_date('17-06-2036', 'dd-mm-yyyy'), '2', '17', '169', '06', '2036', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13319, to_date('18-06-2036', 'dd-mm-yyyy'), '3', '18', '170', '06', '2036', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13320, to_date('19-06-2036', 'dd-mm-yyyy'), '4', '19', '171', '06', '2036', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13321, to_date('20-06-2036', 'dd-mm-yyyy'), '5', '20', '172', '06', '2036', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13322, to_date('21-06-2036', 'dd-mm-yyyy'), '6', '21', '173', '06', '2036', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13323, to_date('22-06-2036', 'dd-mm-yyyy'), '7', '22', '174', '06', '2036', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13324, to_date('23-06-2036', 'dd-mm-yyyy'), '1', '23', '175', '06', '2036', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13325, to_date('24-06-2036', 'dd-mm-yyyy'), '2', '24', '176', '06', '2036', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13326, to_date('25-06-2036', 'dd-mm-yyyy'), '3', '25', '177', '06', '2036', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13327, to_date('26-06-2036', 'dd-mm-yyyy'), '4', '26', '178', '06', '2036', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13328, to_date('27-06-2036', 'dd-mm-yyyy'), '5', '27', '179', '06', '2036', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13329, to_date('28-06-2036', 'dd-mm-yyyy'), '6', '28', '180', '06', '2036', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13330, to_date('29-06-2036', 'dd-mm-yyyy'), '7', '29', '181', '06', '2036', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14921, to_date('06-11-2040', 'dd-mm-yyyy'), '2', '06', '311', '11', '2040', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14922, to_date('07-11-2040', 'dd-mm-yyyy'), '3', '07', '312', '11', '2040', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14923, to_date('08-11-2040', 'dd-mm-yyyy'), '4', '08', '313', '11', '2040', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14924, to_date('09-11-2040', 'dd-mm-yyyy'), '5', '09', '314', '11', '2040', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14925, to_date('10-11-2040', 'dd-mm-yyyy'), '6', '10', '315', '11', '2040', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14926, to_date('11-11-2040', 'dd-mm-yyyy'), '7', '11', '316', '11', '2040', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14927, to_date('12-11-2040', 'dd-mm-yyyy'), '1', '12', '317', '11', '2040', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14928, to_date('13-11-2040', 'dd-mm-yyyy'), '2', '13', '318', '11', '2040', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14929, to_date('14-11-2040', 'dd-mm-yyyy'), '3', '14', '319', '11', '2040', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14930, to_date('15-11-2040', 'dd-mm-yyyy'), '4', '15', '320', '11', '2040', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14931, to_date('16-11-2040', 'dd-mm-yyyy'), '5', '16', '321', '11', '2040', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14932, to_date('17-11-2040', 'dd-mm-yyyy'), '6', '17', '322', '11', '2040', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14933, to_date('18-11-2040', 'dd-mm-yyyy'), '7', '18', '323', '11', '2040', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14934, to_date('19-11-2040', 'dd-mm-yyyy'), '1', '19', '324', '11', '2040', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14935, to_date('20-11-2040', 'dd-mm-yyyy'), '2', '20', '325', '11', '2040', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14936, to_date('21-11-2040', 'dd-mm-yyyy'), '3', '21', '326', '11', '2040', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14937, to_date('22-11-2040', 'dd-mm-yyyy'), '4', '22', '327', '11', '2040', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14938, to_date('23-11-2040', 'dd-mm-yyyy'), '5', '23', '328', '11', '2040', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14939, to_date('24-11-2040', 'dd-mm-yyyy'), '6', '24', '329', '11', '2040', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14940, to_date('25-11-2040', 'dd-mm-yyyy'), '7', '25', '330', '11', '2040', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14941, to_date('26-11-2040', 'dd-mm-yyyy'), '1', '26', '331', '11', '2040', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14942, to_date('27-11-2040', 'dd-mm-yyyy'), '2', '27', '332', '11', '2040', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14943, to_date('28-11-2040', 'dd-mm-yyyy'), '3', '28', '333', '11', '2040', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14944, to_date('29-11-2040', 'dd-mm-yyyy'), '4', '29', '334', '11', '2040', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14945, to_date('30-11-2040', 'dd-mm-yyyy'), '5', '30', '335', '11', '2040', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14946, to_date('01-12-2040', 'dd-mm-yyyy'), '6', '01', '336', '12', '2040', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14947, to_date('02-12-2040', 'dd-mm-yyyy'), '7', '02', '337', '12', '2040', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14948, to_date('03-12-2040', 'dd-mm-yyyy'), '1', '03', '338', '12', '2040', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14949, to_date('04-12-2040', 'dd-mm-yyyy'), '2', '04', '339', '12', '2040', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14950, to_date('05-12-2040', 'dd-mm-yyyy'), '3', '05', '340', '12', '2040', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14951, to_date('06-12-2040', 'dd-mm-yyyy'), '4', '06', '341', '12', '2040', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14952, to_date('07-12-2040', 'dd-mm-yyyy'), '5', '07', '342', '12', '2040', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14953, to_date('08-12-2040', 'dd-mm-yyyy'), '6', '08', '343', '12', '2040', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14954, to_date('09-12-2040', 'dd-mm-yyyy'), '7', '09', '344', '12', '2040', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14955, to_date('10-12-2040', 'dd-mm-yyyy'), '1', '10', '345', '12', '2040', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14956, to_date('11-12-2040', 'dd-mm-yyyy'), '2', '11', '346', '12', '2040', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14957, to_date('12-12-2040', 'dd-mm-yyyy'), '3', '12', '347', '12', '2040', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14958, to_date('13-12-2040', 'dd-mm-yyyy'), '4', '13', '348', '12', '2040', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14959, to_date('14-12-2040', 'dd-mm-yyyy'), '5', '14', '349', '12', '2040', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14960, to_date('15-12-2040', 'dd-mm-yyyy'), '6', '15', '350', '12', '2040', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14961, to_date('16-12-2040', 'dd-mm-yyyy'), '7', '16', '351', '12', '2040', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14962, to_date('17-12-2040', 'dd-mm-yyyy'), '1', '17', '352', '12', '2040', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14963, to_date('18-12-2040', 'dd-mm-yyyy'), '2', '18', '353', '12', '2040', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14964, to_date('19-12-2040', 'dd-mm-yyyy'), '3', '19', '354', '12', '2040', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14965, to_date('20-12-2040', 'dd-mm-yyyy'), '4', '20', '355', '12', '2040', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14966, to_date('21-12-2040', 'dd-mm-yyyy'), '5', '21', '356', '12', '2040', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14967, to_date('22-12-2040', 'dd-mm-yyyy'), '6', '22', '357', '12', '2040', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14968, to_date('23-12-2040', 'dd-mm-yyyy'), '7', '23', '358', '12', '2040', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14969, to_date('24-12-2040', 'dd-mm-yyyy'), '1', '24', '359', '12', '2040', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14970, to_date('25-12-2040', 'dd-mm-yyyy'), '2', '25', '360', '12', '2040', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14971, to_date('26-12-2040', 'dd-mm-yyyy'), '3', '26', '361', '12', '2040', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14972, to_date('27-12-2040', 'dd-mm-yyyy'), '4', '27', '362', '12', '2040', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14973, to_date('28-12-2040', 'dd-mm-yyyy'), '5', '28', '363', '12', '2040', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14974, to_date('29-12-2040', 'dd-mm-yyyy'), '6', '29', '364', '12', '2040', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14975, to_date('30-12-2040', 'dd-mm-yyyy'), '7', '30', '365', '12', '2040', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14976, to_date('31-12-2040', 'dd-mm-yyyy'), '1', '31', '366', '12', '2040', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14977, to_date('01-01-2041', 'dd-mm-yyyy'), '2', '01', '001', '01', '2041', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14978, to_date('02-01-2041', 'dd-mm-yyyy'), '3', '02', '002', '01', '2041', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14979, to_date('03-01-2041', 'dd-mm-yyyy'), '4', '03', '003', '01', '2041', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14980, to_date('04-01-2041', 'dd-mm-yyyy'), '5', '04', '004', '01', '2041', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14981, to_date('05-01-2041', 'dd-mm-yyyy'), '6', '05', '005', '01', '2041', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14982, to_date('06-01-2041', 'dd-mm-yyyy'), '7', '06', '006', '01', '2041', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14983, to_date('07-01-2041', 'dd-mm-yyyy'), '1', '07', '007', '01', '2041', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14984, to_date('08-01-2041', 'dd-mm-yyyy'), '2', '08', '008', '01', '2041', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14985, to_date('09-01-2041', 'dd-mm-yyyy'), '3', '09', '009', '01', '2041', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14986, to_date('10-01-2041', 'dd-mm-yyyy'), '4', '10', '010', '01', '2041', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14987, to_date('11-01-2041', 'dd-mm-yyyy'), '5', '11', '011', '01', '2041', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14988, to_date('12-01-2041', 'dd-mm-yyyy'), '6', '12', '012', '01', '2041', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14989, to_date('13-01-2041', 'dd-mm-yyyy'), '7', '13', '013', '01', '2041', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14990, to_date('14-01-2041', 'dd-mm-yyyy'), '1', '14', '014', '01', '2041', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14991, to_date('15-01-2041', 'dd-mm-yyyy'), '2', '15', '015', '01', '2041', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14992, to_date('16-01-2041', 'dd-mm-yyyy'), '3', '16', '016', '01', '2041', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14993, to_date('17-01-2041', 'dd-mm-yyyy'), '4', '17', '017', '01', '2041', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14994, to_date('18-01-2041', 'dd-mm-yyyy'), '5', '18', '018', '01', '2041', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14995, to_date('19-01-2041', 'dd-mm-yyyy'), '6', '19', '019', '01', '2041', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14996, to_date('20-01-2041', 'dd-mm-yyyy'), '7', '20', '020', '01', '2041', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14997, to_date('21-01-2041', 'dd-mm-yyyy'), '1', '21', '021', '01', '2041', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14998, to_date('22-01-2041', 'dd-mm-yyyy'), '2', '22', '022', '01', '2041', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14999, to_date('23-01-2041', 'dd-mm-yyyy'), '3', '23', '023', '01', '2041', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15000, to_date('24-01-2041', 'dd-mm-yyyy'), '4', '24', '024', '01', '2041', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15001, to_date('25-01-2041', 'dd-mm-yyyy'), '5', '25', '025', '01', '2041', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15002, to_date('26-01-2041', 'dd-mm-yyyy'), '6', '26', '026', '01', '2041', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15003, to_date('27-01-2041', 'dd-mm-yyyy'), '7', '27', '027', '01', '2041', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15004, to_date('28-01-2041', 'dd-mm-yyyy'), '1', '28', '028', '01', '2041', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15005, to_date('29-01-2041', 'dd-mm-yyyy'), '2', '29', '029', '01', '2041', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15006, to_date('30-01-2041', 'dd-mm-yyyy'), '3', '30', '030', '01', '2041', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15007, to_date('31-01-2041', 'dd-mm-yyyy'), '4', '31', '031', '01', '2041', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15008, to_date('01-02-2041', 'dd-mm-yyyy'), '5', '01', '032', '02', '2041', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15009, to_date('02-02-2041', 'dd-mm-yyyy'), '6', '02', '033', '02', '2041', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15010, to_date('03-02-2041', 'dd-mm-yyyy'), '7', '03', '034', '02', '2041', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15011, to_date('04-02-2041', 'dd-mm-yyyy'), '1', '04', '035', '02', '2041', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15012, to_date('05-02-2041', 'dd-mm-yyyy'), '2', '05', '036', '02', '2041', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15013, to_date('06-02-2041', 'dd-mm-yyyy'), '3', '06', '037', '02', '2041', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15014, to_date('07-02-2041', 'dd-mm-yyyy'), '4', '07', '038', '02', '2041', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15015, to_date('08-02-2041', 'dd-mm-yyyy'), '5', '08', '039', '02', '2041', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15016, to_date('09-02-2041', 'dd-mm-yyyy'), '6', '09', '040', '02', '2041', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15017, to_date('10-02-2041', 'dd-mm-yyyy'), '7', '10', '041', '02', '2041', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15018, to_date('11-02-2041', 'dd-mm-yyyy'), '1', '11', '042', '02', '2041', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15019, to_date('12-02-2041', 'dd-mm-yyyy'), '2', '12', '043', '02', '2041', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15020, to_date('13-02-2041', 'dd-mm-yyyy'), '3', '13', '044', '02', '2041', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15021, to_date('14-02-2041', 'dd-mm-yyyy'), '4', '14', '045', '02', '2041', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15022, to_date('15-02-2041', 'dd-mm-yyyy'), '5', '15', '046', '02', '2041', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15023, to_date('16-02-2041', 'dd-mm-yyyy'), '6', '16', '047', '02', '2041', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15024, to_date('17-02-2041', 'dd-mm-yyyy'), '7', '17', '048', '02', '2041', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15025, to_date('18-02-2041', 'dd-mm-yyyy'), '1', '18', '049', '02', '2041', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15026, to_date('19-02-2041', 'dd-mm-yyyy'), '2', '19', '050', '02', '2041', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16511, to_date('15-03-2045', 'dd-mm-yyyy'), '3', '15', '074', '03', '2045', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16512, to_date('16-03-2045', 'dd-mm-yyyy'), '4', '16', '075', '03', '2045', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16513, to_date('17-03-2045', 'dd-mm-yyyy'), '5', '17', '076', '03', '2045', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16514, to_date('18-03-2045', 'dd-mm-yyyy'), '6', '18', '077', '03', '2045', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16515, to_date('19-03-2045', 'dd-mm-yyyy'), '7', '19', '078', '03', '2045', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16516, to_date('20-03-2045', 'dd-mm-yyyy'), '1', '20', '079', '03', '2045', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16517, to_date('21-03-2045', 'dd-mm-yyyy'), '2', '21', '080', '03', '2045', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16518, to_date('22-03-2045', 'dd-mm-yyyy'), '3', '22', '081', '03', '2045', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16519, to_date('23-03-2045', 'dd-mm-yyyy'), '4', '23', '082', '03', '2045', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16520, to_date('24-03-2045', 'dd-mm-yyyy'), '5', '24', '083', '03', '2045', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16521, to_date('25-03-2045', 'dd-mm-yyyy'), '6', '25', '084', '03', '2045', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16522, to_date('26-03-2045', 'dd-mm-yyyy'), '7', '26', '085', '03', '2045', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16523, to_date('27-03-2045', 'dd-mm-yyyy'), '1', '27', '086', '03', '2045', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16524, to_date('28-03-2045', 'dd-mm-yyyy'), '2', '28', '087', '03', '2045', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16525, to_date('29-03-2045', 'dd-mm-yyyy'), '3', '29', '088', '03', '2045', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16526, to_date('30-03-2045', 'dd-mm-yyyy'), '4', '30', '089', '03', '2045', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16527, to_date('31-03-2045', 'dd-mm-yyyy'), '5', '31', '090', '03', '2045', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16528, to_date('01-04-2045', 'dd-mm-yyyy'), '6', '01', '091', '04', '2045', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16529, to_date('02-04-2045', 'dd-mm-yyyy'), '7', '02', '092', '04', '2045', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16530, to_date('03-04-2045', 'dd-mm-yyyy'), '1', '03', '093', '04', '2045', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16531, to_date('04-04-2045', 'dd-mm-yyyy'), '2', '04', '094', '04', '2045', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16532, to_date('05-04-2045', 'dd-mm-yyyy'), '3', '05', '095', '04', '2045', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16533, to_date('06-04-2045', 'dd-mm-yyyy'), '4', '06', '096', '04', '2045', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16534, to_date('07-04-2045', 'dd-mm-yyyy'), '5', '07', '097', '04', '2045', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16535, to_date('08-04-2045', 'dd-mm-yyyy'), '6', '08', '098', '04', '2045', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16536, to_date('09-04-2045', 'dd-mm-yyyy'), '7', '09', '099', '04', '2045', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16537, to_date('10-04-2045', 'dd-mm-yyyy'), '1', '10', '100', '04', '2045', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16538, to_date('11-04-2045', 'dd-mm-yyyy'), '2', '11', '101', '04', '2045', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16539, to_date('12-04-2045', 'dd-mm-yyyy'), '3', '12', '102', '04', '2045', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16540, to_date('13-04-2045', 'dd-mm-yyyy'), '4', '13', '103', '04', '2045', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16541, to_date('14-04-2045', 'dd-mm-yyyy'), '5', '14', '104', '04', '2045', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16542, to_date('15-04-2045', 'dd-mm-yyyy'), '6', '15', '105', '04', '2045', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16543, to_date('16-04-2045', 'dd-mm-yyyy'), '7', '16', '106', '04', '2045', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16544, to_date('17-04-2045', 'dd-mm-yyyy'), '1', '17', '107', '04', '2045', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16545, to_date('18-04-2045', 'dd-mm-yyyy'), '2', '18', '108', '04', '2045', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16546, to_date('19-04-2045', 'dd-mm-yyyy'), '3', '19', '109', '04', '2045', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16547, to_date('20-04-2045', 'dd-mm-yyyy'), '4', '20', '110', '04', '2045', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16548, to_date('21-04-2045', 'dd-mm-yyyy'), '5', '21', '111', '04', '2045', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16549, to_date('22-04-2045', 'dd-mm-yyyy'), '6', '22', '112', '04', '2045', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16550, to_date('23-04-2045', 'dd-mm-yyyy'), '7', '23', '113', '04', '2045', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16551, to_date('24-04-2045', 'dd-mm-yyyy'), '1', '24', '114', '04', '2045', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16552, to_date('25-04-2045', 'dd-mm-yyyy'), '2', '25', '115', '04', '2045', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16553, to_date('26-04-2045', 'dd-mm-yyyy'), '3', '26', '116', '04', '2045', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16554, to_date('27-04-2045', 'dd-mm-yyyy'), '4', '27', '117', '04', '2045', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16555, to_date('28-04-2045', 'dd-mm-yyyy'), '5', '28', '118', '04', '2045', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16556, to_date('29-04-2045', 'dd-mm-yyyy'), '6', '29', '119', '04', '2045', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16557, to_date('30-04-2045', 'dd-mm-yyyy'), '7', '30', '120', '04', '2045', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16558, to_date('01-05-2045', 'dd-mm-yyyy'), '1', '01', '121', '05', '2045', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16559, to_date('02-05-2045', 'dd-mm-yyyy'), '2', '02', '122', '05', '2045', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16560, to_date('03-05-2045', 'dd-mm-yyyy'), '3', '03', '123', '05', '2045', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16561, to_date('04-05-2045', 'dd-mm-yyyy'), '4', '04', '124', '05', '2045', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16562, to_date('05-05-2045', 'dd-mm-yyyy'), '5', '05', '125', '05', '2045', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16563, to_date('06-05-2045', 'dd-mm-yyyy'), '6', '06', '126', '05', '2045', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16564, to_date('07-05-2045', 'dd-mm-yyyy'), '7', '07', '127', '05', '2045', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16565, to_date('08-05-2045', 'dd-mm-yyyy'), '1', '08', '128', '05', '2045', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16566, to_date('09-05-2045', 'dd-mm-yyyy'), '2', '09', '129', '05', '2045', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16567, to_date('10-05-2045', 'dd-mm-yyyy'), '3', '10', '130', '05', '2045', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16568, to_date('11-05-2045', 'dd-mm-yyyy'), '4', '11', '131', '05', '2045', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16569, to_date('12-05-2045', 'dd-mm-yyyy'), '5', '12', '132', '05', '2045', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16570, to_date('13-05-2045', 'dd-mm-yyyy'), '6', '13', '133', '05', '2045', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16571, to_date('14-05-2045', 'dd-mm-yyyy'), '7', '14', '134', '05', '2045', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16572, to_date('15-05-2045', 'dd-mm-yyyy'), '1', '15', '135', '05', '2045', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16573, to_date('16-05-2045', 'dd-mm-yyyy'), '2', '16', '136', '05', '2045', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16574, to_date('17-05-2045', 'dd-mm-yyyy'), '3', '17', '137', '05', '2045', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16575, to_date('18-05-2045', 'dd-mm-yyyy'), '4', '18', '138', '05', '2045', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16576, to_date('19-05-2045', 'dd-mm-yyyy'), '5', '19', '139', '05', '2045', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16577, to_date('20-05-2045', 'dd-mm-yyyy'), '6', '20', '140', '05', '2045', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16578, to_date('21-05-2045', 'dd-mm-yyyy'), '7', '21', '141', '05', '2045', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16579, to_date('22-05-2045', 'dd-mm-yyyy'), '1', '22', '142', '05', '2045', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16580, to_date('23-05-2045', 'dd-mm-yyyy'), '2', '23', '143', '05', '2045', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16581, to_date('24-05-2045', 'dd-mm-yyyy'), '3', '24', '144', '05', '2045', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16582, to_date('25-05-2045', 'dd-mm-yyyy'), '4', '25', '145', '05', '2045', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16583, to_date('26-05-2045', 'dd-mm-yyyy'), '5', '26', '146', '05', '2045', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16584, to_date('27-05-2045', 'dd-mm-yyyy'), '6', '27', '147', '05', '2045', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16585, to_date('28-05-2045', 'dd-mm-yyyy'), '7', '28', '148', '05', '2045', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16586, to_date('29-05-2045', 'dd-mm-yyyy'), '1', '29', '149', '05', '2045', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16587, to_date('30-05-2045', 'dd-mm-yyyy'), '2', '30', '150', '05', '2045', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16588, to_date('31-05-2045', 'dd-mm-yyyy'), '3', '31', '151', '05', '2045', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16589, to_date('01-06-2045', 'dd-mm-yyyy'), '4', '01', '152', '06', '2045', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16590, to_date('02-06-2045', 'dd-mm-yyyy'), '5', '02', '153', '06', '2045', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16591, to_date('03-06-2045', 'dd-mm-yyyy'), '6', '03', '154', '06', '2045', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16592, to_date('04-06-2045', 'dd-mm-yyyy'), '7', '04', '155', '06', '2045', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16593, to_date('05-06-2045', 'dd-mm-yyyy'), '1', '05', '156', '06', '2045', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16594, to_date('06-06-2045', 'dd-mm-yyyy'), '2', '06', '157', '06', '2045', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16595, to_date('07-06-2045', 'dd-mm-yyyy'), '3', '07', '158', '06', '2045', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16596, to_date('08-06-2045', 'dd-mm-yyyy'), '4', '08', '159', '06', '2045', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16597, to_date('09-06-2045', 'dd-mm-yyyy'), '5', '09', '160', '06', '2045', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16598, to_date('10-06-2045', 'dd-mm-yyyy'), '6', '10', '161', '06', '2045', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16599, to_date('11-06-2045', 'dd-mm-yyyy'), '7', '11', '162', '06', '2045', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16600, to_date('12-06-2045', 'dd-mm-yyyy'), '1', '12', '163', '06', '2045', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16601, to_date('13-06-2045', 'dd-mm-yyyy'), '2', '13', '164', '06', '2045', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16602, to_date('14-06-2045', 'dd-mm-yyyy'), '3', '14', '165', '06', '2045', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16603, to_date('15-06-2045', 'dd-mm-yyyy'), '4', '15', '166', '06', '2045', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16604, to_date('16-06-2045', 'dd-mm-yyyy'), '5', '16', '167', '06', '2045', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16605, to_date('17-06-2045', 'dd-mm-yyyy'), '6', '17', '168', '06', '2045', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16606, to_date('18-06-2045', 'dd-mm-yyyy'), '7', '18', '169', '06', '2045', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16607, to_date('19-06-2045', 'dd-mm-yyyy'), '1', '19', '170', '06', '2045', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16608, to_date('20-06-2045', 'dd-mm-yyyy'), '2', '20', '171', '06', '2045', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16609, to_date('21-06-2045', 'dd-mm-yyyy'), '3', '21', '172', '06', '2045', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16610, to_date('22-06-2045', 'dd-mm-yyyy'), '4', '22', '173', '06', '2045', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16611, to_date('23-06-2045', 'dd-mm-yyyy'), '5', '23', '174', '06', '2045', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16612, to_date('24-06-2045', 'dd-mm-yyyy'), '6', '24', '175', '06', '2045', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16613, to_date('25-06-2045', 'dd-mm-yyyy'), '7', '25', '176', '06', '2045', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16614, to_date('26-06-2045', 'dd-mm-yyyy'), '1', '26', '177', '06', '2045', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16615, to_date('27-06-2045', 'dd-mm-yyyy'), '2', '27', '178', '06', '2045', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16616, to_date('28-06-2045', 'dd-mm-yyyy'), '3', '28', '179', '06', '2045', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18101, to_date('22-07-2049', 'dd-mm-yyyy'), '4', '22', '203', '07', '2049', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18102, to_date('23-07-2049', 'dd-mm-yyyy'), '5', '23', '204', '07', '2049', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18103, to_date('24-07-2049', 'dd-mm-yyyy'), '6', '24', '205', '07', '2049', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18104, to_date('25-07-2049', 'dd-mm-yyyy'), '7', '25', '206', '07', '2049', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18105, to_date('26-07-2049', 'dd-mm-yyyy'), '1', '26', '207', '07', '2049', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18106, to_date('27-07-2049', 'dd-mm-yyyy'), '2', '27', '208', '07', '2049', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18107, to_date('28-07-2049', 'dd-mm-yyyy'), '3', '28', '209', '07', '2049', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18108, to_date('29-07-2049', 'dd-mm-yyyy'), '4', '29', '210', '07', '2049', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18109, to_date('30-07-2049', 'dd-mm-yyyy'), '5', '30', '211', '07', '2049', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18110, to_date('31-07-2049', 'dd-mm-yyyy'), '6', '31', '212', '07', '2049', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18111, to_date('01-08-2049', 'dd-mm-yyyy'), '7', '01', '213', '08', '2049', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18112, to_date('02-08-2049', 'dd-mm-yyyy'), '1', '02', '214', '08', '2049', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18113, to_date('03-08-2049', 'dd-mm-yyyy'), '2', '03', '215', '08', '2049', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18114, to_date('04-08-2049', 'dd-mm-yyyy'), '3', '04', '216', '08', '2049', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18115, to_date('05-08-2049', 'dd-mm-yyyy'), '4', '05', '217', '08', '2049', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18116, to_date('06-08-2049', 'dd-mm-yyyy'), '5', '06', '218', '08', '2049', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18117, to_date('07-08-2049', 'dd-mm-yyyy'), '6', '07', '219', '08', '2049', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18118, to_date('08-08-2049', 'dd-mm-yyyy'), '7', '08', '220', '08', '2049', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18119, to_date('09-08-2049', 'dd-mm-yyyy'), '1', '09', '221', '08', '2049', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18120, to_date('10-08-2049', 'dd-mm-yyyy'), '2', '10', '222', '08', '2049', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18121, to_date('11-08-2049', 'dd-mm-yyyy'), '3', '11', '223', '08', '2049', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18122, to_date('12-08-2049', 'dd-mm-yyyy'), '4', '12', '224', '08', '2049', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18123, to_date('13-08-2049', 'dd-mm-yyyy'), '5', '13', '225', '08', '2049', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18124, to_date('14-08-2049', 'dd-mm-yyyy'), '6', '14', '226', '08', '2049', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18125, to_date('15-08-2049', 'dd-mm-yyyy'), '7', '15', '227', '08', '2049', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18126, to_date('16-08-2049', 'dd-mm-yyyy'), '1', '16', '228', '08', '2049', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18127, to_date('17-08-2049', 'dd-mm-yyyy'), '2', '17', '229', '08', '2049', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18128, to_date('18-08-2049', 'dd-mm-yyyy'), '3', '18', '230', '08', '2049', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18129, to_date('19-08-2049', 'dd-mm-yyyy'), '4', '19', '231', '08', '2049', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18130, to_date('20-08-2049', 'dd-mm-yyyy'), '5', '20', '232', '08', '2049', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18131, to_date('21-08-2049', 'dd-mm-yyyy'), '6', '21', '233', '08', '2049', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18132, to_date('22-08-2049', 'dd-mm-yyyy'), '7', '22', '234', '08', '2049', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18133, to_date('23-08-2049', 'dd-mm-yyyy'), '1', '23', '235', '08', '2049', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18134, to_date('24-08-2049', 'dd-mm-yyyy'), '2', '24', '236', '08', '2049', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18135, to_date('25-08-2049', 'dd-mm-yyyy'), '3', '25', '237', '08', '2049', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18136, to_date('26-08-2049', 'dd-mm-yyyy'), '4', '26', '238', '08', '2049', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18137, to_date('27-08-2049', 'dd-mm-yyyy'), '5', '27', '239', '08', '2049', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18138, to_date('28-08-2049', 'dd-mm-yyyy'), '6', '28', '240', '08', '2049', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18139, to_date('29-08-2049', 'dd-mm-yyyy'), '7', '29', '241', '08', '2049', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18140, to_date('30-08-2049', 'dd-mm-yyyy'), '1', '30', '242', '08', '2049', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18141, to_date('31-08-2049', 'dd-mm-yyyy'), '2', '31', '243', '08', '2049', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18142, to_date('01-09-2049', 'dd-mm-yyyy'), '3', '01', '244', '09', '2049', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18143, to_date('02-09-2049', 'dd-mm-yyyy'), '4', '02', '245', '09', '2049', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18144, to_date('03-09-2049', 'dd-mm-yyyy'), '5', '03', '246', '09', '2049', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18145, to_date('04-09-2049', 'dd-mm-yyyy'), '6', '04', '247', '09', '2049', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18146, to_date('05-09-2049', 'dd-mm-yyyy'), '7', '05', '248', '09', '2049', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18147, to_date('06-09-2049', 'dd-mm-yyyy'), '1', '06', '249', '09', '2049', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18148, to_date('07-09-2049', 'dd-mm-yyyy'), '2', '07', '250', '09', '2049', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18149, to_date('08-09-2049', 'dd-mm-yyyy'), '3', '08', '251', '09', '2049', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18150, to_date('09-09-2049', 'dd-mm-yyyy'), '4', '09', '252', '09', '2049', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18151, to_date('10-09-2049', 'dd-mm-yyyy'), '5', '10', '253', '09', '2049', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18152, to_date('11-09-2049', 'dd-mm-yyyy'), '6', '11', '254', '09', '2049', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18153, to_date('12-09-2049', 'dd-mm-yyyy'), '7', '12', '255', '09', '2049', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18154, to_date('13-09-2049', 'dd-mm-yyyy'), '1', '13', '256', '09', '2049', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18155, to_date('14-09-2049', 'dd-mm-yyyy'), '2', '14', '257', '09', '2049', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18156, to_date('15-09-2049', 'dd-mm-yyyy'), '3', '15', '258', '09', '2049', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18157, to_date('16-09-2049', 'dd-mm-yyyy'), '4', '16', '259', '09', '2049', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18158, to_date('17-09-2049', 'dd-mm-yyyy'), '5', '17', '260', '09', '2049', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18159, to_date('18-09-2049', 'dd-mm-yyyy'), '6', '18', '261', '09', '2049', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18160, to_date('19-09-2049', 'dd-mm-yyyy'), '7', '19', '262', '09', '2049', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18161, to_date('20-09-2049', 'dd-mm-yyyy'), '1', '20', '263', '09', '2049', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18162, to_date('21-09-2049', 'dd-mm-yyyy'), '2', '21', '264', '09', '2049', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18163, to_date('22-09-2049', 'dd-mm-yyyy'), '3', '22', '265', '09', '2049', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18164, to_date('23-09-2049', 'dd-mm-yyyy'), '4', '23', '266', '09', '2049', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18165, to_date('24-09-2049', 'dd-mm-yyyy'), '5', '24', '267', '09', '2049', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18166, to_date('25-09-2049', 'dd-mm-yyyy'), '6', '25', '268', '09', '2049', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18167, to_date('26-09-2049', 'dd-mm-yyyy'), '7', '26', '269', '09', '2049', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18168, to_date('27-09-2049', 'dd-mm-yyyy'), '1', '27', '270', '09', '2049', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18169, to_date('28-09-2049', 'dd-mm-yyyy'), '2', '28', '271', '09', '2049', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18170, to_date('29-09-2049', 'dd-mm-yyyy'), '3', '29', '272', '09', '2049', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18171, to_date('30-09-2049', 'dd-mm-yyyy'), '4', '30', '273', '09', '2049', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18172, to_date('01-10-2049', 'dd-mm-yyyy'), '5', '01', '274', '10', '2049', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18173, to_date('02-10-2049', 'dd-mm-yyyy'), '6', '02', '275', '10', '2049', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18174, to_date('03-10-2049', 'dd-mm-yyyy'), '7', '03', '276', '10', '2049', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18175, to_date('04-10-2049', 'dd-mm-yyyy'), '1', '04', '277', '10', '2049', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18176, to_date('05-10-2049', 'dd-mm-yyyy'), '2', '05', '278', '10', '2049', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18177, to_date('06-10-2049', 'dd-mm-yyyy'), '3', '06', '279', '10', '2049', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18178, to_date('07-10-2049', 'dd-mm-yyyy'), '4', '07', '280', '10', '2049', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18179, to_date('08-10-2049', 'dd-mm-yyyy'), '5', '08', '281', '10', '2049', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18180, to_date('09-10-2049', 'dd-mm-yyyy'), '6', '09', '282', '10', '2049', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18181, to_date('10-10-2049', 'dd-mm-yyyy'), '7', '10', '283', '10', '2049', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18182, to_date('11-10-2049', 'dd-mm-yyyy'), '1', '11', '284', '10', '2049', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18183, to_date('12-10-2049', 'dd-mm-yyyy'), '2', '12', '285', '10', '2049', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18184, to_date('13-10-2049', 'dd-mm-yyyy'), '3', '13', '286', '10', '2049', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18185, to_date('14-10-2049', 'dd-mm-yyyy'), '4', '14', '287', '10', '2049', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18186, to_date('15-10-2049', 'dd-mm-yyyy'), '5', '15', '288', '10', '2049', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18187, to_date('16-10-2049', 'dd-mm-yyyy'), '6', '16', '289', '10', '2049', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18188, to_date('17-10-2049', 'dd-mm-yyyy'), '7', '17', '290', '10', '2049', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18189, to_date('18-10-2049', 'dd-mm-yyyy'), '1', '18', '291', '10', '2049', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18190, to_date('19-10-2049', 'dd-mm-yyyy'), '2', '19', '292', '10', '2049', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18191, to_date('20-10-2049', 'dd-mm-yyyy'), '3', '20', '293', '10', '2049', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18192, to_date('21-10-2049', 'dd-mm-yyyy'), '4', '21', '294', '10', '2049', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18193, to_date('22-10-2049', 'dd-mm-yyyy'), '5', '22', '295', '10', '2049', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18194, to_date('23-10-2049', 'dd-mm-yyyy'), '6', '23', '296', '10', '2049', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18195, to_date('24-10-2049', 'dd-mm-yyyy'), '7', '24', '297', '10', '2049', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18196, to_date('25-10-2049', 'dd-mm-yyyy'), '1', '25', '298', '10', '2049', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18197, to_date('26-10-2049', 'dd-mm-yyyy'), '2', '26', '299', '10', '2049', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18198, to_date('27-10-2049', 'dd-mm-yyyy'), '3', '27', '300', '10', '2049', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18199, to_date('28-10-2049', 'dd-mm-yyyy'), '4', '28', '301', '10', '2049', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18200, to_date('29-10-2049', 'dd-mm-yyyy'), '5', '29', '302', '10', '2049', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18201, to_date('30-10-2049', 'dd-mm-yyyy'), '6', '30', '303', '10', '2049', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18202, to_date('31-10-2049', 'dd-mm-yyyy'), '7', '31', '304', '10', '2049', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18203, to_date('01-11-2049', 'dd-mm-yyyy'), '1', '01', '305', '11', '2049', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18204, to_date('02-11-2049', 'dd-mm-yyyy'), '2', '02', '306', '11', '2049', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18205, to_date('03-11-2049', 'dd-mm-yyyy'), '3', '03', '307', '11', '2049', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18206, to_date('04-11-2049', 'dd-mm-yyyy'), '4', '04', '308', '11', '2049', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13331, to_date('30-06-2036', 'dd-mm-yyyy'), '1', '30', '182', '06', '2036', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13332, to_date('01-07-2036', 'dd-mm-yyyy'), '2', '01', '183', '07', '2036', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13333, to_date('02-07-2036', 'dd-mm-yyyy'), '3', '02', '184', '07', '2036', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13334, to_date('03-07-2036', 'dd-mm-yyyy'), '4', '03', '185', '07', '2036', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13335, to_date('04-07-2036', 'dd-mm-yyyy'), '5', '04', '186', '07', '2036', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13336, to_date('05-07-2036', 'dd-mm-yyyy'), '6', '05', '187', '07', '2036', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13337, to_date('06-07-2036', 'dd-mm-yyyy'), '7', '06', '188', '07', '2036', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13338, to_date('07-07-2036', 'dd-mm-yyyy'), '1', '07', '189', '07', '2036', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13339, to_date('08-07-2036', 'dd-mm-yyyy'), '2', '08', '190', '07', '2036', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13340, to_date('09-07-2036', 'dd-mm-yyyy'), '3', '09', '191', '07', '2036', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13341, to_date('10-07-2036', 'dd-mm-yyyy'), '4', '10', '192', '07', '2036', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13342, to_date('11-07-2036', 'dd-mm-yyyy'), '5', '11', '193', '07', '2036', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13343, to_date('12-07-2036', 'dd-mm-yyyy'), '6', '12', '194', '07', '2036', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13344, to_date('13-07-2036', 'dd-mm-yyyy'), '7', '13', '195', '07', '2036', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13345, to_date('14-07-2036', 'dd-mm-yyyy'), '1', '14', '196', '07', '2036', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13346, to_date('15-07-2036', 'dd-mm-yyyy'), '2', '15', '197', '07', '2036', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13347, to_date('16-07-2036', 'dd-mm-yyyy'), '3', '16', '198', '07', '2036', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13348, to_date('17-07-2036', 'dd-mm-yyyy'), '4', '17', '199', '07', '2036', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13349, to_date('18-07-2036', 'dd-mm-yyyy'), '5', '18', '200', '07', '2036', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13350, to_date('19-07-2036', 'dd-mm-yyyy'), '6', '19', '201', '07', '2036', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13351, to_date('20-07-2036', 'dd-mm-yyyy'), '7', '20', '202', '07', '2036', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13352, to_date('21-07-2036', 'dd-mm-yyyy'), '1', '21', '203', '07', '2036', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13353, to_date('22-07-2036', 'dd-mm-yyyy'), '2', '22', '204', '07', '2036', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13354, to_date('23-07-2036', 'dd-mm-yyyy'), '3', '23', '205', '07', '2036', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13355, to_date('24-07-2036', 'dd-mm-yyyy'), '4', '24', '206', '07', '2036', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13356, to_date('25-07-2036', 'dd-mm-yyyy'), '5', '25', '207', '07', '2036', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13357, to_date('26-07-2036', 'dd-mm-yyyy'), '6', '26', '208', '07', '2036', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13358, to_date('27-07-2036', 'dd-mm-yyyy'), '7', '27', '209', '07', '2036', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13359, to_date('28-07-2036', 'dd-mm-yyyy'), '1', '28', '210', '07', '2036', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13360, to_date('29-07-2036', 'dd-mm-yyyy'), '2', '29', '211', '07', '2036', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13361, to_date('30-07-2036', 'dd-mm-yyyy'), '3', '30', '212', '07', '2036', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13362, to_date('31-07-2036', 'dd-mm-yyyy'), '4', '31', '213', '07', '2036', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13363, to_date('01-08-2036', 'dd-mm-yyyy'), '5', '01', '214', '08', '2036', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13364, to_date('02-08-2036', 'dd-mm-yyyy'), '6', '02', '215', '08', '2036', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13365, to_date('03-08-2036', 'dd-mm-yyyy'), '7', '03', '216', '08', '2036', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13366, to_date('04-08-2036', 'dd-mm-yyyy'), '1', '04', '217', '08', '2036', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13367, to_date('05-08-2036', 'dd-mm-yyyy'), '2', '05', '218', '08', '2036', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13368, to_date('06-08-2036', 'dd-mm-yyyy'), '3', '06', '219', '08', '2036', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13369, to_date('07-08-2036', 'dd-mm-yyyy'), '4', '07', '220', '08', '2036', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13370, to_date('08-08-2036', 'dd-mm-yyyy'), '5', '08', '221', '08', '2036', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13371, to_date('09-08-2036', 'dd-mm-yyyy'), '6', '09', '222', '08', '2036', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13372, to_date('10-08-2036', 'dd-mm-yyyy'), '7', '10', '223', '08', '2036', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13373, to_date('11-08-2036', 'dd-mm-yyyy'), '1', '11', '224', '08', '2036', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13374, to_date('12-08-2036', 'dd-mm-yyyy'), '2', '12', '225', '08', '2036', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13375, to_date('13-08-2036', 'dd-mm-yyyy'), '3', '13', '226', '08', '2036', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13376, to_date('14-08-2036', 'dd-mm-yyyy'), '4', '14', '227', '08', '2036', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13377, to_date('15-08-2036', 'dd-mm-yyyy'), '5', '15', '228', '08', '2036', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13378, to_date('16-08-2036', 'dd-mm-yyyy'), '6', '16', '229', '08', '2036', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13379, to_date('17-08-2036', 'dd-mm-yyyy'), '7', '17', '230', '08', '2036', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13380, to_date('18-08-2036', 'dd-mm-yyyy'), '1', '18', '231', '08', '2036', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13381, to_date('19-08-2036', 'dd-mm-yyyy'), '2', '19', '232', '08', '2036', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13382, to_date('20-08-2036', 'dd-mm-yyyy'), '3', '20', '233', '08', '2036', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13383, to_date('21-08-2036', 'dd-mm-yyyy'), '4', '21', '234', '08', '2036', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13384, to_date('22-08-2036', 'dd-mm-yyyy'), '5', '22', '235', '08', '2036', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13385, to_date('23-08-2036', 'dd-mm-yyyy'), '6', '23', '236', '08', '2036', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13386, to_date('24-08-2036', 'dd-mm-yyyy'), '7', '24', '237', '08', '2036', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13387, to_date('25-08-2036', 'dd-mm-yyyy'), '1', '25', '238', '08', '2036', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13388, to_date('26-08-2036', 'dd-mm-yyyy'), '2', '26', '239', '08', '2036', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13389, to_date('27-08-2036', 'dd-mm-yyyy'), '3', '27', '240', '08', '2036', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13390, to_date('28-08-2036', 'dd-mm-yyyy'), '4', '28', '241', '08', '2036', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13391, to_date('29-08-2036', 'dd-mm-yyyy'), '5', '29', '242', '08', '2036', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13392, to_date('30-08-2036', 'dd-mm-yyyy'), '6', '30', '243', '08', '2036', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13393, to_date('31-08-2036', 'dd-mm-yyyy'), '7', '31', '244', '08', '2036', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13394, to_date('01-09-2036', 'dd-mm-yyyy'), '1', '01', '245', '09', '2036', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13395, to_date('02-09-2036', 'dd-mm-yyyy'), '2', '02', '246', '09', '2036', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13396, to_date('03-09-2036', 'dd-mm-yyyy'), '3', '03', '247', '09', '2036', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13397, to_date('04-09-2036', 'dd-mm-yyyy'), '4', '04', '248', '09', '2036', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13398, to_date('05-09-2036', 'dd-mm-yyyy'), '5', '05', '249', '09', '2036', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13399, to_date('06-09-2036', 'dd-mm-yyyy'), '6', '06', '250', '09', '2036', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13400, to_date('07-09-2036', 'dd-mm-yyyy'), '7', '07', '251', '09', '2036', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13401, to_date('08-09-2036', 'dd-mm-yyyy'), '1', '08', '252', '09', '2036', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13402, to_date('09-09-2036', 'dd-mm-yyyy'), '2', '09', '253', '09', '2036', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13403, to_date('10-09-2036', 'dd-mm-yyyy'), '3', '10', '254', '09', '2036', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13404, to_date('11-09-2036', 'dd-mm-yyyy'), '4', '11', '255', '09', '2036', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13405, to_date('12-09-2036', 'dd-mm-yyyy'), '5', '12', '256', '09', '2036', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13406, to_date('13-09-2036', 'dd-mm-yyyy'), '6', '13', '257', '09', '2036', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13407, to_date('14-09-2036', 'dd-mm-yyyy'), '7', '14', '258', '09', '2036', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13408, to_date('15-09-2036', 'dd-mm-yyyy'), '1', '15', '259', '09', '2036', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13409, to_date('16-09-2036', 'dd-mm-yyyy'), '2', '16', '260', '09', '2036', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13410, to_date('17-09-2036', 'dd-mm-yyyy'), '3', '17', '261', '09', '2036', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13411, to_date('18-09-2036', 'dd-mm-yyyy'), '4', '18', '262', '09', '2036', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13412, to_date('19-09-2036', 'dd-mm-yyyy'), '5', '19', '263', '09', '2036', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13413, to_date('20-09-2036', 'dd-mm-yyyy'), '6', '20', '264', '09', '2036', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13414, to_date('21-09-2036', 'dd-mm-yyyy'), '7', '21', '265', '09', '2036', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13415, to_date('22-09-2036', 'dd-mm-yyyy'), '1', '22', '266', '09', '2036', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13416, to_date('23-09-2036', 'dd-mm-yyyy'), '2', '23', '267', '09', '2036', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13417, to_date('24-09-2036', 'dd-mm-yyyy'), '3', '24', '268', '09', '2036', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13418, to_date('25-09-2036', 'dd-mm-yyyy'), '4', '25', '269', '09', '2036', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13419, to_date('26-09-2036', 'dd-mm-yyyy'), '5', '26', '270', '09', '2036', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13420, to_date('27-09-2036', 'dd-mm-yyyy'), '6', '27', '271', '09', '2036', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13421, to_date('28-09-2036', 'dd-mm-yyyy'), '7', '28', '272', '09', '2036', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13422, to_date('29-09-2036', 'dd-mm-yyyy'), '1', '29', '273', '09', '2036', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13423, to_date('30-09-2036', 'dd-mm-yyyy'), '2', '30', '274', '09', '2036', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13424, to_date('01-10-2036', 'dd-mm-yyyy'), '3', '01', '275', '10', '2036', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13425, to_date('02-10-2036', 'dd-mm-yyyy'), '4', '02', '276', '10', '2036', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13426, to_date('03-10-2036', 'dd-mm-yyyy'), '5', '03', '277', '10', '2036', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13427, to_date('04-10-2036', 'dd-mm-yyyy'), '6', '04', '278', '10', '2036', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13428, to_date('05-10-2036', 'dd-mm-yyyy'), '7', '05', '279', '10', '2036', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13429, to_date('06-10-2036', 'dd-mm-yyyy'), '1', '06', '280', '10', '2036', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13430, to_date('07-10-2036', 'dd-mm-yyyy'), '2', '07', '281', '10', '2036', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13431, to_date('08-10-2036', 'dd-mm-yyyy'), '3', '08', '282', '10', '2036', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13432, to_date('09-10-2036', 'dd-mm-yyyy'), '4', '09', '283', '10', '2036', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13433, to_date('10-10-2036', 'dd-mm-yyyy'), '5', '10', '284', '10', '2036', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13434, to_date('11-10-2036', 'dd-mm-yyyy'), '6', '11', '285', '10', '2036', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13435, to_date('12-10-2036', 'dd-mm-yyyy'), '7', '12', '286', '10', '2036', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13436, to_date('13-10-2036', 'dd-mm-yyyy'), '1', '13', '287', '10', '2036', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15027, to_date('20-02-2041', 'dd-mm-yyyy'), '3', '20', '051', '02', '2041', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15028, to_date('21-02-2041', 'dd-mm-yyyy'), '4', '21', '052', '02', '2041', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15029, to_date('22-02-2041', 'dd-mm-yyyy'), '5', '22', '053', '02', '2041', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15030, to_date('23-02-2041', 'dd-mm-yyyy'), '6', '23', '054', '02', '2041', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15031, to_date('24-02-2041', 'dd-mm-yyyy'), '7', '24', '055', '02', '2041', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15032, to_date('25-02-2041', 'dd-mm-yyyy'), '1', '25', '056', '02', '2041', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15033, to_date('26-02-2041', 'dd-mm-yyyy'), '2', '26', '057', '02', '2041', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15034, to_date('27-02-2041', 'dd-mm-yyyy'), '3', '27', '058', '02', '2041', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15035, to_date('28-02-2041', 'dd-mm-yyyy'), '4', '28', '059', '02', '2041', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15036, to_date('01-03-2041', 'dd-mm-yyyy'), '5', '01', '060', '03', '2041', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15037, to_date('02-03-2041', 'dd-mm-yyyy'), '6', '02', '061', '03', '2041', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15038, to_date('03-03-2041', 'dd-mm-yyyy'), '7', '03', '062', '03', '2041', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15039, to_date('04-03-2041', 'dd-mm-yyyy'), '1', '04', '063', '03', '2041', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15040, to_date('05-03-2041', 'dd-mm-yyyy'), '2', '05', '064', '03', '2041', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15041, to_date('06-03-2041', 'dd-mm-yyyy'), '3', '06', '065', '03', '2041', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15042, to_date('07-03-2041', 'dd-mm-yyyy'), '4', '07', '066', '03', '2041', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15043, to_date('08-03-2041', 'dd-mm-yyyy'), '5', '08', '067', '03', '2041', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15044, to_date('09-03-2041', 'dd-mm-yyyy'), '6', '09', '068', '03', '2041', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15045, to_date('10-03-2041', 'dd-mm-yyyy'), '7', '10', '069', '03', '2041', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15046, to_date('11-03-2041', 'dd-mm-yyyy'), '1', '11', '070', '03', '2041', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15047, to_date('12-03-2041', 'dd-mm-yyyy'), '2', '12', '071', '03', '2041', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15048, to_date('13-03-2041', 'dd-mm-yyyy'), '3', '13', '072', '03', '2041', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15049, to_date('14-03-2041', 'dd-mm-yyyy'), '4', '14', '073', '03', '2041', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15050, to_date('15-03-2041', 'dd-mm-yyyy'), '5', '15', '074', '03', '2041', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15051, to_date('16-03-2041', 'dd-mm-yyyy'), '6', '16', '075', '03', '2041', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15052, to_date('17-03-2041', 'dd-mm-yyyy'), '7', '17', '076', '03', '2041', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15053, to_date('18-03-2041', 'dd-mm-yyyy'), '1', '18', '077', '03', '2041', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15054, to_date('19-03-2041', 'dd-mm-yyyy'), '2', '19', '078', '03', '2041', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15055, to_date('20-03-2041', 'dd-mm-yyyy'), '3', '20', '079', '03', '2041', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15056, to_date('21-03-2041', 'dd-mm-yyyy'), '4', '21', '080', '03', '2041', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15057, to_date('22-03-2041', 'dd-mm-yyyy'), '5', '22', '081', '03', '2041', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15058, to_date('23-03-2041', 'dd-mm-yyyy'), '6', '23', '082', '03', '2041', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15059, to_date('24-03-2041', 'dd-mm-yyyy'), '7', '24', '083', '03', '2041', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15060, to_date('25-03-2041', 'dd-mm-yyyy'), '1', '25', '084', '03', '2041', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15061, to_date('26-03-2041', 'dd-mm-yyyy'), '2', '26', '085', '03', '2041', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15062, to_date('27-03-2041', 'dd-mm-yyyy'), '3', '27', '086', '03', '2041', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15063, to_date('28-03-2041', 'dd-mm-yyyy'), '4', '28', '087', '03', '2041', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15064, to_date('29-03-2041', 'dd-mm-yyyy'), '5', '29', '088', '03', '2041', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15065, to_date('30-03-2041', 'dd-mm-yyyy'), '6', '30', '089', '03', '2041', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15066, to_date('31-03-2041', 'dd-mm-yyyy'), '7', '31', '090', '03', '2041', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15067, to_date('01-04-2041', 'dd-mm-yyyy'), '1', '01', '091', '04', '2041', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15068, to_date('02-04-2041', 'dd-mm-yyyy'), '2', '02', '092', '04', '2041', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15069, to_date('03-04-2041', 'dd-mm-yyyy'), '3', '03', '093', '04', '2041', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15070, to_date('04-04-2041', 'dd-mm-yyyy'), '4', '04', '094', '04', '2041', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15071, to_date('05-04-2041', 'dd-mm-yyyy'), '5', '05', '095', '04', '2041', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15072, to_date('06-04-2041', 'dd-mm-yyyy'), '6', '06', '096', '04', '2041', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15073, to_date('07-04-2041', 'dd-mm-yyyy'), '7', '07', '097', '04', '2041', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15074, to_date('08-04-2041', 'dd-mm-yyyy'), '1', '08', '098', '04', '2041', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15075, to_date('09-04-2041', 'dd-mm-yyyy'), '2', '09', '099', '04', '2041', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15076, to_date('10-04-2041', 'dd-mm-yyyy'), '3', '10', '100', '04', '2041', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15077, to_date('11-04-2041', 'dd-mm-yyyy'), '4', '11', '101', '04', '2041', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15078, to_date('12-04-2041', 'dd-mm-yyyy'), '5', '12', '102', '04', '2041', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15079, to_date('13-04-2041', 'dd-mm-yyyy'), '6', '13', '103', '04', '2041', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15080, to_date('14-04-2041', 'dd-mm-yyyy'), '7', '14', '104', '04', '2041', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15081, to_date('15-04-2041', 'dd-mm-yyyy'), '1', '15', '105', '04', '2041', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15082, to_date('16-04-2041', 'dd-mm-yyyy'), '2', '16', '106', '04', '2041', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15083, to_date('17-04-2041', 'dd-mm-yyyy'), '3', '17', '107', '04', '2041', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15084, to_date('18-04-2041', 'dd-mm-yyyy'), '4', '18', '108', '04', '2041', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15085, to_date('19-04-2041', 'dd-mm-yyyy'), '5', '19', '109', '04', '2041', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15086, to_date('20-04-2041', 'dd-mm-yyyy'), '6', '20', '110', '04', '2041', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15087, to_date('21-04-2041', 'dd-mm-yyyy'), '7', '21', '111', '04', '2041', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15088, to_date('22-04-2041', 'dd-mm-yyyy'), '1', '22', '112', '04', '2041', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15089, to_date('23-04-2041', 'dd-mm-yyyy'), '2', '23', '113', '04', '2041', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15090, to_date('24-04-2041', 'dd-mm-yyyy'), '3', '24', '114', '04', '2041', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15091, to_date('25-04-2041', 'dd-mm-yyyy'), '4', '25', '115', '04', '2041', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15092, to_date('26-04-2041', 'dd-mm-yyyy'), '5', '26', '116', '04', '2041', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15093, to_date('27-04-2041', 'dd-mm-yyyy'), '6', '27', '117', '04', '2041', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15094, to_date('28-04-2041', 'dd-mm-yyyy'), '7', '28', '118', '04', '2041', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15095, to_date('29-04-2041', 'dd-mm-yyyy'), '1', '29', '119', '04', '2041', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15096, to_date('30-04-2041', 'dd-mm-yyyy'), '2', '30', '120', '04', '2041', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15097, to_date('01-05-2041', 'dd-mm-yyyy'), '3', '01', '121', '05', '2041', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15098, to_date('02-05-2041', 'dd-mm-yyyy'), '4', '02', '122', '05', '2041', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15099, to_date('03-05-2041', 'dd-mm-yyyy'), '5', '03', '123', '05', '2041', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15100, to_date('04-05-2041', 'dd-mm-yyyy'), '6', '04', '124', '05', '2041', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15101, to_date('05-05-2041', 'dd-mm-yyyy'), '7', '05', '125', '05', '2041', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15102, to_date('06-05-2041', 'dd-mm-yyyy'), '1', '06', '126', '05', '2041', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15103, to_date('07-05-2041', 'dd-mm-yyyy'), '2', '07', '127', '05', '2041', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15104, to_date('08-05-2041', 'dd-mm-yyyy'), '3', '08', '128', '05', '2041', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15105, to_date('09-05-2041', 'dd-mm-yyyy'), '4', '09', '129', '05', '2041', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15106, to_date('10-05-2041', 'dd-mm-yyyy'), '5', '10', '130', '05', '2041', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15107, to_date('11-05-2041', 'dd-mm-yyyy'), '6', '11', '131', '05', '2041', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15108, to_date('12-05-2041', 'dd-mm-yyyy'), '7', '12', '132', '05', '2041', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15109, to_date('13-05-2041', 'dd-mm-yyyy'), '1', '13', '133', '05', '2041', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15110, to_date('14-05-2041', 'dd-mm-yyyy'), '2', '14', '134', '05', '2041', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15111, to_date('15-05-2041', 'dd-mm-yyyy'), '3', '15', '135', '05', '2041', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15112, to_date('16-05-2041', 'dd-mm-yyyy'), '4', '16', '136', '05', '2041', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15113, to_date('17-05-2041', 'dd-mm-yyyy'), '5', '17', '137', '05', '2041', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15114, to_date('18-05-2041', 'dd-mm-yyyy'), '6', '18', '138', '05', '2041', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15115, to_date('19-05-2041', 'dd-mm-yyyy'), '7', '19', '139', '05', '2041', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15116, to_date('20-05-2041', 'dd-mm-yyyy'), '1', '20', '140', '05', '2041', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15117, to_date('21-05-2041', 'dd-mm-yyyy'), '2', '21', '141', '05', '2041', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15118, to_date('22-05-2041', 'dd-mm-yyyy'), '3', '22', '142', '05', '2041', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15119, to_date('23-05-2041', 'dd-mm-yyyy'), '4', '23', '143', '05', '2041', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15120, to_date('24-05-2041', 'dd-mm-yyyy'), '5', '24', '144', '05', '2041', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15121, to_date('25-05-2041', 'dd-mm-yyyy'), '6', '25', '145', '05', '2041', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15122, to_date('26-05-2041', 'dd-mm-yyyy'), '7', '26', '146', '05', '2041', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15123, to_date('27-05-2041', 'dd-mm-yyyy'), '1', '27', '147', '05', '2041', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15124, to_date('28-05-2041', 'dd-mm-yyyy'), '2', '28', '148', '05', '2041', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15125, to_date('29-05-2041', 'dd-mm-yyyy'), '3', '29', '149', '05', '2041', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15126, to_date('30-05-2041', 'dd-mm-yyyy'), '4', '30', '150', '05', '2041', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15127, to_date('31-05-2041', 'dd-mm-yyyy'), '5', '31', '151', '05', '2041', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15128, to_date('01-06-2041', 'dd-mm-yyyy'), '6', '01', '152', '06', '2041', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15129, to_date('02-06-2041', 'dd-mm-yyyy'), '7', '02', '153', '06', '2041', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15130, to_date('03-06-2041', 'dd-mm-yyyy'), '1', '03', '154', '06', '2041', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15131, to_date('04-06-2041', 'dd-mm-yyyy'), '2', '04', '155', '06', '2041', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15132, to_date('05-06-2041', 'dd-mm-yyyy'), '3', '05', '156', '06', '2041', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16617, to_date('29-06-2045', 'dd-mm-yyyy'), '4', '29', '180', '06', '2045', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16618, to_date('30-06-2045', 'dd-mm-yyyy'), '5', '30', '181', '06', '2045', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16619, to_date('01-07-2045', 'dd-mm-yyyy'), '6', '01', '182', '07', '2045', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16620, to_date('02-07-2045', 'dd-mm-yyyy'), '7', '02', '183', '07', '2045', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16621, to_date('03-07-2045', 'dd-mm-yyyy'), '1', '03', '184', '07', '2045', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16622, to_date('04-07-2045', 'dd-mm-yyyy'), '2', '04', '185', '07', '2045', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16623, to_date('05-07-2045', 'dd-mm-yyyy'), '3', '05', '186', '07', '2045', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16624, to_date('06-07-2045', 'dd-mm-yyyy'), '4', '06', '187', '07', '2045', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16625, to_date('07-07-2045', 'dd-mm-yyyy'), '5', '07', '188', '07', '2045', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16626, to_date('08-07-2045', 'dd-mm-yyyy'), '6', '08', '189', '07', '2045', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16627, to_date('09-07-2045', 'dd-mm-yyyy'), '7', '09', '190', '07', '2045', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16628, to_date('10-07-2045', 'dd-mm-yyyy'), '1', '10', '191', '07', '2045', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16629, to_date('11-07-2045', 'dd-mm-yyyy'), '2', '11', '192', '07', '2045', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16630, to_date('12-07-2045', 'dd-mm-yyyy'), '3', '12', '193', '07', '2045', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16631, to_date('13-07-2045', 'dd-mm-yyyy'), '4', '13', '194', '07', '2045', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16632, to_date('14-07-2045', 'dd-mm-yyyy'), '5', '14', '195', '07', '2045', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16633, to_date('15-07-2045', 'dd-mm-yyyy'), '6', '15', '196', '07', '2045', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16634, to_date('16-07-2045', 'dd-mm-yyyy'), '7', '16', '197', '07', '2045', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16635, to_date('17-07-2045', 'dd-mm-yyyy'), '1', '17', '198', '07', '2045', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16636, to_date('18-07-2045', 'dd-mm-yyyy'), '2', '18', '199', '07', '2045', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16637, to_date('19-07-2045', 'dd-mm-yyyy'), '3', '19', '200', '07', '2045', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16638, to_date('20-07-2045', 'dd-mm-yyyy'), '4', '20', '201', '07', '2045', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16639, to_date('21-07-2045', 'dd-mm-yyyy'), '5', '21', '202', '07', '2045', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16640, to_date('22-07-2045', 'dd-mm-yyyy'), '6', '22', '203', '07', '2045', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16641, to_date('23-07-2045', 'dd-mm-yyyy'), '7', '23', '204', '07', '2045', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16642, to_date('24-07-2045', 'dd-mm-yyyy'), '1', '24', '205', '07', '2045', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16643, to_date('25-07-2045', 'dd-mm-yyyy'), '2', '25', '206', '07', '2045', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16644, to_date('26-07-2045', 'dd-mm-yyyy'), '3', '26', '207', '07', '2045', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16645, to_date('27-07-2045', 'dd-mm-yyyy'), '4', '27', '208', '07', '2045', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16646, to_date('28-07-2045', 'dd-mm-yyyy'), '5', '28', '209', '07', '2045', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16647, to_date('29-07-2045', 'dd-mm-yyyy'), '6', '29', '210', '07', '2045', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16648, to_date('30-07-2045', 'dd-mm-yyyy'), '7', '30', '211', '07', '2045', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16649, to_date('31-07-2045', 'dd-mm-yyyy'), '1', '31', '212', '07', '2045', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16650, to_date('01-08-2045', 'dd-mm-yyyy'), '2', '01', '213', '08', '2045', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16651, to_date('02-08-2045', 'dd-mm-yyyy'), '3', '02', '214', '08', '2045', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16652, to_date('03-08-2045', 'dd-mm-yyyy'), '4', '03', '215', '08', '2045', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16653, to_date('04-08-2045', 'dd-mm-yyyy'), '5', '04', '216', '08', '2045', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16654, to_date('05-08-2045', 'dd-mm-yyyy'), '6', '05', '217', '08', '2045', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16655, to_date('06-08-2045', 'dd-mm-yyyy'), '7', '06', '218', '08', '2045', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16656, to_date('07-08-2045', 'dd-mm-yyyy'), '1', '07', '219', '08', '2045', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16657, to_date('08-08-2045', 'dd-mm-yyyy'), '2', '08', '220', '08', '2045', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16658, to_date('09-08-2045', 'dd-mm-yyyy'), '3', '09', '221', '08', '2045', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16659, to_date('10-08-2045', 'dd-mm-yyyy'), '4', '10', '222', '08', '2045', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16660, to_date('11-08-2045', 'dd-mm-yyyy'), '5', '11', '223', '08', '2045', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16661, to_date('12-08-2045', 'dd-mm-yyyy'), '6', '12', '224', '08', '2045', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16662, to_date('13-08-2045', 'dd-mm-yyyy'), '7', '13', '225', '08', '2045', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16663, to_date('14-08-2045', 'dd-mm-yyyy'), '1', '14', '226', '08', '2045', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16664, to_date('15-08-2045', 'dd-mm-yyyy'), '2', '15', '227', '08', '2045', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16665, to_date('16-08-2045', 'dd-mm-yyyy'), '3', '16', '228', '08', '2045', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16666, to_date('17-08-2045', 'dd-mm-yyyy'), '4', '17', '229', '08', '2045', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16667, to_date('18-08-2045', 'dd-mm-yyyy'), '5', '18', '230', '08', '2045', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16668, to_date('19-08-2045', 'dd-mm-yyyy'), '6', '19', '231', '08', '2045', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16669, to_date('20-08-2045', 'dd-mm-yyyy'), '7', '20', '232', '08', '2045', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16670, to_date('21-08-2045', 'dd-mm-yyyy'), '1', '21', '233', '08', '2045', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16671, to_date('22-08-2045', 'dd-mm-yyyy'), '2', '22', '234', '08', '2045', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16672, to_date('23-08-2045', 'dd-mm-yyyy'), '3', '23', '235', '08', '2045', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16673, to_date('24-08-2045', 'dd-mm-yyyy'), '4', '24', '236', '08', '2045', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16674, to_date('25-08-2045', 'dd-mm-yyyy'), '5', '25', '237', '08', '2045', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16675, to_date('26-08-2045', 'dd-mm-yyyy'), '6', '26', '238', '08', '2045', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16676, to_date('27-08-2045', 'dd-mm-yyyy'), '7', '27', '239', '08', '2045', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16677, to_date('28-08-2045', 'dd-mm-yyyy'), '1', '28', '240', '08', '2045', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16678, to_date('29-08-2045', 'dd-mm-yyyy'), '2', '29', '241', '08', '2045', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16679, to_date('30-08-2045', 'dd-mm-yyyy'), '3', '30', '242', '08', '2045', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16680, to_date('31-08-2045', 'dd-mm-yyyy'), '4', '31', '243', '08', '2045', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16681, to_date('01-09-2045', 'dd-mm-yyyy'), '5', '01', '244', '09', '2045', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16682, to_date('02-09-2045', 'dd-mm-yyyy'), '6', '02', '245', '09', '2045', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16683, to_date('03-09-2045', 'dd-mm-yyyy'), '7', '03', '246', '09', '2045', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16684, to_date('04-09-2045', 'dd-mm-yyyy'), '1', '04', '247', '09', '2045', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16685, to_date('05-09-2045', 'dd-mm-yyyy'), '2', '05', '248', '09', '2045', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16686, to_date('06-09-2045', 'dd-mm-yyyy'), '3', '06', '249', '09', '2045', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16687, to_date('07-09-2045', 'dd-mm-yyyy'), '4', '07', '250', '09', '2045', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16688, to_date('08-09-2045', 'dd-mm-yyyy'), '5', '08', '251', '09', '2045', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16689, to_date('09-09-2045', 'dd-mm-yyyy'), '6', '09', '252', '09', '2045', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16690, to_date('10-09-2045', 'dd-mm-yyyy'), '7', '10', '253', '09', '2045', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16691, to_date('11-09-2045', 'dd-mm-yyyy'), '1', '11', '254', '09', '2045', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16692, to_date('12-09-2045', 'dd-mm-yyyy'), '2', '12', '255', '09', '2045', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16693, to_date('13-09-2045', 'dd-mm-yyyy'), '3', '13', '256', '09', '2045', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16694, to_date('14-09-2045', 'dd-mm-yyyy'), '4', '14', '257', '09', '2045', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16695, to_date('15-09-2045', 'dd-mm-yyyy'), '5', '15', '258', '09', '2045', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16696, to_date('16-09-2045', 'dd-mm-yyyy'), '6', '16', '259', '09', '2045', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16697, to_date('17-09-2045', 'dd-mm-yyyy'), '7', '17', '260', '09', '2045', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16698, to_date('18-09-2045', 'dd-mm-yyyy'), '1', '18', '261', '09', '2045', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16699, to_date('19-09-2045', 'dd-mm-yyyy'), '2', '19', '262', '09', '2045', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16700, to_date('20-09-2045', 'dd-mm-yyyy'), '3', '20', '263', '09', '2045', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16701, to_date('21-09-2045', 'dd-mm-yyyy'), '4', '21', '264', '09', '2045', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16702, to_date('22-09-2045', 'dd-mm-yyyy'), '5', '22', '265', '09', '2045', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16703, to_date('23-09-2045', 'dd-mm-yyyy'), '6', '23', '266', '09', '2045', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16704, to_date('24-09-2045', 'dd-mm-yyyy'), '7', '24', '267', '09', '2045', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16705, to_date('25-09-2045', 'dd-mm-yyyy'), '1', '25', '268', '09', '2045', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16706, to_date('26-09-2045', 'dd-mm-yyyy'), '2', '26', '269', '09', '2045', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16707, to_date('27-09-2045', 'dd-mm-yyyy'), '3', '27', '270', '09', '2045', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16708, to_date('28-09-2045', 'dd-mm-yyyy'), '4', '28', '271', '09', '2045', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16709, to_date('29-09-2045', 'dd-mm-yyyy'), '5', '29', '272', '09', '2045', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16710, to_date('30-09-2045', 'dd-mm-yyyy'), '6', '30', '273', '09', '2045', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16711, to_date('01-10-2045', 'dd-mm-yyyy'), '7', '01', '274', '10', '2045', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16712, to_date('02-10-2045', 'dd-mm-yyyy'), '1', '02', '275', '10', '2045', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16713, to_date('03-10-2045', 'dd-mm-yyyy'), '2', '03', '276', '10', '2045', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16714, to_date('04-10-2045', 'dd-mm-yyyy'), '3', '04', '277', '10', '2045', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16715, to_date('05-10-2045', 'dd-mm-yyyy'), '4', '05', '278', '10', '2045', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16716, to_date('06-10-2045', 'dd-mm-yyyy'), '5', '06', '279', '10', '2045', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16717, to_date('07-10-2045', 'dd-mm-yyyy'), '6', '07', '280', '10', '2045', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16718, to_date('08-10-2045', 'dd-mm-yyyy'), '7', '08', '281', '10', '2045', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16719, to_date('09-10-2045', 'dd-mm-yyyy'), '1', '09', '282', '10', '2045', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16720, to_date('10-10-2045', 'dd-mm-yyyy'), '2', '10', '283', '10', '2045', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16721, to_date('11-10-2045', 'dd-mm-yyyy'), '3', '11', '284', '10', '2045', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16722, to_date('12-10-2045', 'dd-mm-yyyy'), '4', '12', '285', '10', '2045', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18207, to_date('05-11-2049', 'dd-mm-yyyy'), '5', '05', '309', '11', '2049', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18208, to_date('06-11-2049', 'dd-mm-yyyy'), '6', '06', '310', '11', '2049', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18209, to_date('07-11-2049', 'dd-mm-yyyy'), '7', '07', '311', '11', '2049', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18210, to_date('08-11-2049', 'dd-mm-yyyy'), '1', '08', '312', '11', '2049', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18211, to_date('09-11-2049', 'dd-mm-yyyy'), '2', '09', '313', '11', '2049', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18212, to_date('10-11-2049', 'dd-mm-yyyy'), '3', '10', '314', '11', '2049', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18213, to_date('11-11-2049', 'dd-mm-yyyy'), '4', '11', '315', '11', '2049', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18214, to_date('12-11-2049', 'dd-mm-yyyy'), '5', '12', '316', '11', '2049', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18215, to_date('13-11-2049', 'dd-mm-yyyy'), '6', '13', '317', '11', '2049', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18216, to_date('14-11-2049', 'dd-mm-yyyy'), '7', '14', '318', '11', '2049', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18217, to_date('15-11-2049', 'dd-mm-yyyy'), '1', '15', '319', '11', '2049', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18218, to_date('16-11-2049', 'dd-mm-yyyy'), '2', '16', '320', '11', '2049', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18219, to_date('17-11-2049', 'dd-mm-yyyy'), '3', '17', '321', '11', '2049', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18220, to_date('18-11-2049', 'dd-mm-yyyy'), '4', '18', '322', '11', '2049', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18221, to_date('19-11-2049', 'dd-mm-yyyy'), '5', '19', '323', '11', '2049', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18222, to_date('20-11-2049', 'dd-mm-yyyy'), '6', '20', '324', '11', '2049', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18223, to_date('21-11-2049', 'dd-mm-yyyy'), '7', '21', '325', '11', '2049', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18224, to_date('22-11-2049', 'dd-mm-yyyy'), '1', '22', '326', '11', '2049', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18225, to_date('23-11-2049', 'dd-mm-yyyy'), '2', '23', '327', '11', '2049', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18226, to_date('24-11-2049', 'dd-mm-yyyy'), '3', '24', '328', '11', '2049', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18227, to_date('25-11-2049', 'dd-mm-yyyy'), '4', '25', '329', '11', '2049', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18228, to_date('26-11-2049', 'dd-mm-yyyy'), '5', '26', '330', '11', '2049', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18229, to_date('27-11-2049', 'dd-mm-yyyy'), '6', '27', '331', '11', '2049', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18230, to_date('28-11-2049', 'dd-mm-yyyy'), '7', '28', '332', '11', '2049', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18231, to_date('29-11-2049', 'dd-mm-yyyy'), '1', '29', '333', '11', '2049', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18232, to_date('30-11-2049', 'dd-mm-yyyy'), '2', '30', '334', '11', '2049', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18233, to_date('01-12-2049', 'dd-mm-yyyy'), '3', '01', '335', '12', '2049', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18234, to_date('02-12-2049', 'dd-mm-yyyy'), '4', '02', '336', '12', '2049', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18235, to_date('03-12-2049', 'dd-mm-yyyy'), '5', '03', '337', '12', '2049', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18236, to_date('04-12-2049', 'dd-mm-yyyy'), '6', '04', '338', '12', '2049', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18237, to_date('05-12-2049', 'dd-mm-yyyy'), '7', '05', '339', '12', '2049', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18238, to_date('06-12-2049', 'dd-mm-yyyy'), '1', '06', '340', '12', '2049', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18239, to_date('07-12-2049', 'dd-mm-yyyy'), '2', '07', '341', '12', '2049', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18240, to_date('08-12-2049', 'dd-mm-yyyy'), '3', '08', '342', '12', '2049', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18241, to_date('09-12-2049', 'dd-mm-yyyy'), '4', '09', '343', '12', '2049', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18242, to_date('10-12-2049', 'dd-mm-yyyy'), '5', '10', '344', '12', '2049', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18243, to_date('11-12-2049', 'dd-mm-yyyy'), '6', '11', '345', '12', '2049', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18244, to_date('12-12-2049', 'dd-mm-yyyy'), '7', '12', '346', '12', '2049', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18245, to_date('13-12-2049', 'dd-mm-yyyy'), '1', '13', '347', '12', '2049', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18246, to_date('14-12-2049', 'dd-mm-yyyy'), '2', '14', '348', '12', '2049', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18247, to_date('15-12-2049', 'dd-mm-yyyy'), '3', '15', '349', '12', '2049', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18248, to_date('16-12-2049', 'dd-mm-yyyy'), '4', '16', '350', '12', '2049', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18249, to_date('17-12-2049', 'dd-mm-yyyy'), '5', '17', '351', '12', '2049', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18250, to_date('18-12-2049', 'dd-mm-yyyy'), '6', '18', '352', '12', '2049', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18251, to_date('19-12-2049', 'dd-mm-yyyy'), '7', '19', '353', '12', '2049', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18252, to_date('20-12-2049', 'dd-mm-yyyy'), '1', '20', '354', '12', '2049', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18253, to_date('21-12-2049', 'dd-mm-yyyy'), '2', '21', '355', '12', '2049', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18254, to_date('22-12-2049', 'dd-mm-yyyy'), '3', '22', '356', '12', '2049', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18255, to_date('23-12-2049', 'dd-mm-yyyy'), '4', '23', '357', '12', '2049', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18256, to_date('24-12-2049', 'dd-mm-yyyy'), '5', '24', '358', '12', '2049', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18257, to_date('25-12-2049', 'dd-mm-yyyy'), '6', '25', '359', '12', '2049', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18258, to_date('26-12-2049', 'dd-mm-yyyy'), '7', '26', '360', '12', '2049', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18259, to_date('27-12-2049', 'dd-mm-yyyy'), '1', '27', '361', '12', '2049', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18260, to_date('28-12-2049', 'dd-mm-yyyy'), '2', '28', '362', '12', '2049', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18261, to_date('29-12-2049', 'dd-mm-yyyy'), '3', '29', '363', '12', '2049', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18262, to_date('30-12-2049', 'dd-mm-yyyy'), '4', '30', '364', '12', '2049', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18263, to_date('31-12-2049', 'dd-mm-yyyy'), '5', '31', '365', '12', '2049', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18264, to_date('01-01-2050', 'dd-mm-yyyy'), '6', '01', '001', '01', '2050', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18265, to_date('02-01-2050', 'dd-mm-yyyy'), '7', '02', '002', '01', '2050', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18266, to_date('03-01-2050', 'dd-mm-yyyy'), '1', '03', '003', '01', '2050', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18267, to_date('04-01-2050', 'dd-mm-yyyy'), '2', '04', '004', '01', '2050', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18268, to_date('05-01-2050', 'dd-mm-yyyy'), '3', '05', '005', '01', '2050', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18269, to_date('06-01-2050', 'dd-mm-yyyy'), '4', '06', '006', '01', '2050', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18270, to_date('07-01-2050', 'dd-mm-yyyy'), '5', '07', '007', '01', '2050', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18271, to_date('08-01-2050', 'dd-mm-yyyy'), '6', '08', '008', '01', '2050', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18272, to_date('09-01-2050', 'dd-mm-yyyy'), '7', '09', '009', '01', '2050', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18273, to_date('10-01-2050', 'dd-mm-yyyy'), '1', '10', '010', '01', '2050', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18274, to_date('11-01-2050', 'dd-mm-yyyy'), '2', '11', '011', '01', '2050', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18275, to_date('12-01-2050', 'dd-mm-yyyy'), '3', '12', '012', '01', '2050', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18276, to_date('13-01-2050', 'dd-mm-yyyy'), '4', '13', '013', '01', '2050', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18277, to_date('14-01-2050', 'dd-mm-yyyy'), '5', '14', '014', '01', '2050', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18278, to_date('15-01-2050', 'dd-mm-yyyy'), '6', '15', '015', '01', '2050', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18279, to_date('16-01-2050', 'dd-mm-yyyy'), '7', '16', '016', '01', '2050', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18280, to_date('17-01-2050', 'dd-mm-yyyy'), '1', '17', '017', '01', '2050', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18281, to_date('18-01-2050', 'dd-mm-yyyy'), '2', '18', '018', '01', '2050', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18282, to_date('19-01-2050', 'dd-mm-yyyy'), '3', '19', '019', '01', '2050', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18283, to_date('20-01-2050', 'dd-mm-yyyy'), '4', '20', '020', '01', '2050', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18284, to_date('21-01-2050', 'dd-mm-yyyy'), '5', '21', '021', '01', '2050', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18285, to_date('22-01-2050', 'dd-mm-yyyy'), '6', '22', '022', '01', '2050', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18286, to_date('23-01-2050', 'dd-mm-yyyy'), '7', '23', '023', '01', '2050', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18287, to_date('24-01-2050', 'dd-mm-yyyy'), '1', '24', '024', '01', '2050', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18288, to_date('25-01-2050', 'dd-mm-yyyy'), '2', '25', '025', '01', '2050', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18289, to_date('26-01-2050', 'dd-mm-yyyy'), '3', '26', '026', '01', '2050', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18290, to_date('27-01-2050', 'dd-mm-yyyy'), '4', '27', '027', '01', '2050', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18291, to_date('28-01-2050', 'dd-mm-yyyy'), '5', '28', '028', '01', '2050', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18292, to_date('29-01-2050', 'dd-mm-yyyy'), '6', '29', '029', '01', '2050', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18293, to_date('30-01-2050', 'dd-mm-yyyy'), '7', '30', '030', '01', '2050', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18294, to_date('31-01-2050', 'dd-mm-yyyy'), '1', '31', '031', '01', '2050', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18295, to_date('01-02-2050', 'dd-mm-yyyy'), '2', '01', '032', '02', '2050', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18296, to_date('02-02-2050', 'dd-mm-yyyy'), '3', '02', '033', '02', '2050', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18297, to_date('03-02-2050', 'dd-mm-yyyy'), '4', '03', '034', '02', '2050', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18298, to_date('04-02-2050', 'dd-mm-yyyy'), '5', '04', '035', '02', '2050', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18299, to_date('05-02-2050', 'dd-mm-yyyy'), '6', '05', '036', '02', '2050', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18300, to_date('06-02-2050', 'dd-mm-yyyy'), '7', '06', '037', '02', '2050', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18301, to_date('07-02-2050', 'dd-mm-yyyy'), '1', '07', '038', '02', '2050', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18302, to_date('08-02-2050', 'dd-mm-yyyy'), '2', '08', '039', '02', '2050', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18303, to_date('09-02-2050', 'dd-mm-yyyy'), '3', '09', '040', '02', '2050', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18304, to_date('10-02-2050', 'dd-mm-yyyy'), '4', '10', '041', '02', '2050', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18305, to_date('11-02-2050', 'dd-mm-yyyy'), '5', '11', '042', '02', '2050', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18306, to_date('12-02-2050', 'dd-mm-yyyy'), '6', '12', '043', '02', '2050', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18307, to_date('13-02-2050', 'dd-mm-yyyy'), '7', '13', '044', '02', '2050', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18308, to_date('14-02-2050', 'dd-mm-yyyy'), '1', '14', '045', '02', '2050', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18309, to_date('15-02-2050', 'dd-mm-yyyy'), '2', '15', '046', '02', '2050', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18310, to_date('16-02-2050', 'dd-mm-yyyy'), '3', '16', '047', '02', '2050', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18311, to_date('17-02-2050', 'dd-mm-yyyy'), '4', '17', '048', '02', '2050', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18312, to_date('18-02-2050', 'dd-mm-yyyy'), '5', '18', '049', '02', '2050', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13437, to_date('14-10-2036', 'dd-mm-yyyy'), '2', '14', '288', '10', '2036', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13438, to_date('15-10-2036', 'dd-mm-yyyy'), '3', '15', '289', '10', '2036', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13439, to_date('16-10-2036', 'dd-mm-yyyy'), '4', '16', '290', '10', '2036', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13440, to_date('17-10-2036', 'dd-mm-yyyy'), '5', '17', '291', '10', '2036', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13441, to_date('18-10-2036', 'dd-mm-yyyy'), '6', '18', '292', '10', '2036', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13442, to_date('19-10-2036', 'dd-mm-yyyy'), '7', '19', '293', '10', '2036', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13443, to_date('20-10-2036', 'dd-mm-yyyy'), '1', '20', '294', '10', '2036', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13444, to_date('21-10-2036', 'dd-mm-yyyy'), '2', '21', '295', '10', '2036', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13445, to_date('22-10-2036', 'dd-mm-yyyy'), '3', '22', '296', '10', '2036', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13446, to_date('23-10-2036', 'dd-mm-yyyy'), '4', '23', '297', '10', '2036', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13447, to_date('24-10-2036', 'dd-mm-yyyy'), '5', '24', '298', '10', '2036', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13448, to_date('25-10-2036', 'dd-mm-yyyy'), '6', '25', '299', '10', '2036', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13449, to_date('26-10-2036', 'dd-mm-yyyy'), '7', '26', '300', '10', '2036', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13450, to_date('27-10-2036', 'dd-mm-yyyy'), '1', '27', '301', '10', '2036', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13451, to_date('28-10-2036', 'dd-mm-yyyy'), '2', '28', '302', '10', '2036', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13452, to_date('29-10-2036', 'dd-mm-yyyy'), '3', '29', '303', '10', '2036', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13453, to_date('30-10-2036', 'dd-mm-yyyy'), '4', '30', '304', '10', '2036', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13454, to_date('31-10-2036', 'dd-mm-yyyy'), '5', '31', '305', '10', '2036', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13455, to_date('01-11-2036', 'dd-mm-yyyy'), '6', '01', '306', '11', '2036', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13456, to_date('02-11-2036', 'dd-mm-yyyy'), '7', '02', '307', '11', '2036', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13457, to_date('03-11-2036', 'dd-mm-yyyy'), '1', '03', '308', '11', '2036', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13458, to_date('04-11-2036', 'dd-mm-yyyy'), '2', '04', '309', '11', '2036', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13459, to_date('05-11-2036', 'dd-mm-yyyy'), '3', '05', '310', '11', '2036', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13460, to_date('06-11-2036', 'dd-mm-yyyy'), '4', '06', '311', '11', '2036', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
commit;
prompt 23000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13461, to_date('07-11-2036', 'dd-mm-yyyy'), '5', '07', '312', '11', '2036', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13462, to_date('08-11-2036', 'dd-mm-yyyy'), '6', '08', '313', '11', '2036', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13463, to_date('09-11-2036', 'dd-mm-yyyy'), '7', '09', '314', '11', '2036', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13464, to_date('10-11-2036', 'dd-mm-yyyy'), '1', '10', '315', '11', '2036', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13465, to_date('11-11-2036', 'dd-mm-yyyy'), '2', '11', '316', '11', '2036', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13466, to_date('12-11-2036', 'dd-mm-yyyy'), '3', '12', '317', '11', '2036', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13467, to_date('13-11-2036', 'dd-mm-yyyy'), '4', '13', '318', '11', '2036', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13468, to_date('14-11-2036', 'dd-mm-yyyy'), '5', '14', '319', '11', '2036', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13469, to_date('15-11-2036', 'dd-mm-yyyy'), '6', '15', '320', '11', '2036', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13470, to_date('16-11-2036', 'dd-mm-yyyy'), '7', '16', '321', '11', '2036', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13471, to_date('17-11-2036', 'dd-mm-yyyy'), '1', '17', '322', '11', '2036', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13472, to_date('18-11-2036', 'dd-mm-yyyy'), '2', '18', '323', '11', '2036', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13473, to_date('19-11-2036', 'dd-mm-yyyy'), '3', '19', '324', '11', '2036', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13474, to_date('20-11-2036', 'dd-mm-yyyy'), '4', '20', '325', '11', '2036', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13475, to_date('21-11-2036', 'dd-mm-yyyy'), '5', '21', '326', '11', '2036', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13476, to_date('22-11-2036', 'dd-mm-yyyy'), '6', '22', '327', '11', '2036', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13477, to_date('23-11-2036', 'dd-mm-yyyy'), '7', '23', '328', '11', '2036', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13478, to_date('24-11-2036', 'dd-mm-yyyy'), '1', '24', '329', '11', '2036', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13479, to_date('25-11-2036', 'dd-mm-yyyy'), '2', '25', '330', '11', '2036', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13480, to_date('26-11-2036', 'dd-mm-yyyy'), '3', '26', '331', '11', '2036', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13481, to_date('27-11-2036', 'dd-mm-yyyy'), '4', '27', '332', '11', '2036', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13482, to_date('28-11-2036', 'dd-mm-yyyy'), '5', '28', '333', '11', '2036', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13483, to_date('29-11-2036', 'dd-mm-yyyy'), '6', '29', '334', '11', '2036', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13484, to_date('30-11-2036', 'dd-mm-yyyy'), '7', '30', '335', '11', '2036', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13485, to_date('01-12-2036', 'dd-mm-yyyy'), '1', '01', '336', '12', '2036', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13486, to_date('02-12-2036', 'dd-mm-yyyy'), '2', '02', '337', '12', '2036', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13487, to_date('03-12-2036', 'dd-mm-yyyy'), '3', '03', '338', '12', '2036', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13488, to_date('04-12-2036', 'dd-mm-yyyy'), '4', '04', '339', '12', '2036', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13489, to_date('05-12-2036', 'dd-mm-yyyy'), '5', '05', '340', '12', '2036', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13490, to_date('06-12-2036', 'dd-mm-yyyy'), '6', '06', '341', '12', '2036', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13491, to_date('07-12-2036', 'dd-mm-yyyy'), '7', '07', '342', '12', '2036', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13492, to_date('08-12-2036', 'dd-mm-yyyy'), '1', '08', '343', '12', '2036', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13493, to_date('09-12-2036', 'dd-mm-yyyy'), '2', '09', '344', '12', '2036', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13494, to_date('10-12-2036', 'dd-mm-yyyy'), '3', '10', '345', '12', '2036', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13495, to_date('11-12-2036', 'dd-mm-yyyy'), '4', '11', '346', '12', '2036', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13496, to_date('12-12-2036', 'dd-mm-yyyy'), '5', '12', '347', '12', '2036', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13497, to_date('13-12-2036', 'dd-mm-yyyy'), '6', '13', '348', '12', '2036', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13498, to_date('14-12-2036', 'dd-mm-yyyy'), '7', '14', '349', '12', '2036', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13499, to_date('15-12-2036', 'dd-mm-yyyy'), '1', '15', '350', '12', '2036', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13500, to_date('16-12-2036', 'dd-mm-yyyy'), '2', '16', '351', '12', '2036', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13501, to_date('17-12-2036', 'dd-mm-yyyy'), '3', '17', '352', '12', '2036', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13502, to_date('18-12-2036', 'dd-mm-yyyy'), '4', '18', '353', '12', '2036', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13503, to_date('19-12-2036', 'dd-mm-yyyy'), '5', '19', '354', '12', '2036', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13504, to_date('20-12-2036', 'dd-mm-yyyy'), '6', '20', '355', '12', '2036', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13505, to_date('21-12-2036', 'dd-mm-yyyy'), '7', '21', '356', '12', '2036', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13506, to_date('22-12-2036', 'dd-mm-yyyy'), '1', '22', '357', '12', '2036', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13507, to_date('23-12-2036', 'dd-mm-yyyy'), '2', '23', '358', '12', '2036', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13508, to_date('24-12-2036', 'dd-mm-yyyy'), '3', '24', '359', '12', '2036', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13509, to_date('25-12-2036', 'dd-mm-yyyy'), '4', '25', '360', '12', '2036', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13510, to_date('26-12-2036', 'dd-mm-yyyy'), '5', '26', '361', '12', '2036', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13511, to_date('27-12-2036', 'dd-mm-yyyy'), '6', '27', '362', '12', '2036', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13512, to_date('28-12-2036', 'dd-mm-yyyy'), '7', '28', '363', '12', '2036', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13513, to_date('29-12-2036', 'dd-mm-yyyy'), '1', '29', '364', '12', '2036', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13514, to_date('30-12-2036', 'dd-mm-yyyy'), '2', '30', '365', '12', '2036', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13515, to_date('31-12-2036', 'dd-mm-yyyy'), '3', '31', '366', '12', '2036', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13516, to_date('01-01-2037', 'dd-mm-yyyy'), '4', '01', '001', '01', '2037', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13517, to_date('02-01-2037', 'dd-mm-yyyy'), '5', '02', '002', '01', '2037', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13518, to_date('03-01-2037', 'dd-mm-yyyy'), '6', '03', '003', '01', '2037', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13519, to_date('04-01-2037', 'dd-mm-yyyy'), '7', '04', '004', '01', '2037', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13520, to_date('05-01-2037', 'dd-mm-yyyy'), '1', '05', '005', '01', '2037', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13521, to_date('06-01-2037', 'dd-mm-yyyy'), '2', '06', '006', '01', '2037', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13522, to_date('07-01-2037', 'dd-mm-yyyy'), '3', '07', '007', '01', '2037', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13523, to_date('08-01-2037', 'dd-mm-yyyy'), '4', '08', '008', '01', '2037', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13524, to_date('09-01-2037', 'dd-mm-yyyy'), '5', '09', '009', '01', '2037', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13525, to_date('10-01-2037', 'dd-mm-yyyy'), '6', '10', '010', '01', '2037', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13526, to_date('11-01-2037', 'dd-mm-yyyy'), '7', '11', '011', '01', '2037', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13527, to_date('12-01-2037', 'dd-mm-yyyy'), '1', '12', '012', '01', '2037', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13528, to_date('13-01-2037', 'dd-mm-yyyy'), '2', '13', '013', '01', '2037', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13529, to_date('14-01-2037', 'dd-mm-yyyy'), '3', '14', '014', '01', '2037', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13530, to_date('15-01-2037', 'dd-mm-yyyy'), '4', '15', '015', '01', '2037', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13531, to_date('16-01-2037', 'dd-mm-yyyy'), '5', '16', '016', '01', '2037', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13532, to_date('17-01-2037', 'dd-mm-yyyy'), '6', '17', '017', '01', '2037', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13533, to_date('18-01-2037', 'dd-mm-yyyy'), '7', '18', '018', '01', '2037', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13534, to_date('19-01-2037', 'dd-mm-yyyy'), '1', '19', '019', '01', '2037', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13535, to_date('20-01-2037', 'dd-mm-yyyy'), '2', '20', '020', '01', '2037', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13536, to_date('21-01-2037', 'dd-mm-yyyy'), '3', '21', '021', '01', '2037', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13537, to_date('22-01-2037', 'dd-mm-yyyy'), '4', '22', '022', '01', '2037', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13538, to_date('23-01-2037', 'dd-mm-yyyy'), '5', '23', '023', '01', '2037', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13539, to_date('24-01-2037', 'dd-mm-yyyy'), '6', '24', '024', '01', '2037', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13540, to_date('25-01-2037', 'dd-mm-yyyy'), '7', '25', '025', '01', '2037', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13541, to_date('26-01-2037', 'dd-mm-yyyy'), '1', '26', '026', '01', '2037', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13542, to_date('27-01-2037', 'dd-mm-yyyy'), '2', '27', '027', '01', '2037', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15133, to_date('06-06-2041', 'dd-mm-yyyy'), '4', '06', '157', '06', '2041', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15134, to_date('07-06-2041', 'dd-mm-yyyy'), '5', '07', '158', '06', '2041', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15135, to_date('08-06-2041', 'dd-mm-yyyy'), '6', '08', '159', '06', '2041', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15136, to_date('09-06-2041', 'dd-mm-yyyy'), '7', '09', '160', '06', '2041', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15137, to_date('10-06-2041', 'dd-mm-yyyy'), '1', '10', '161', '06', '2041', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15138, to_date('11-06-2041', 'dd-mm-yyyy'), '2', '11', '162', '06', '2041', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15139, to_date('12-06-2041', 'dd-mm-yyyy'), '3', '12', '163', '06', '2041', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15140, to_date('13-06-2041', 'dd-mm-yyyy'), '4', '13', '164', '06', '2041', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15141, to_date('14-06-2041', 'dd-mm-yyyy'), '5', '14', '165', '06', '2041', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15142, to_date('15-06-2041', 'dd-mm-yyyy'), '6', '15', '166', '06', '2041', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15143, to_date('16-06-2041', 'dd-mm-yyyy'), '7', '16', '167', '06', '2041', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15144, to_date('17-06-2041', 'dd-mm-yyyy'), '1', '17', '168', '06', '2041', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15145, to_date('18-06-2041', 'dd-mm-yyyy'), '2', '18', '169', '06', '2041', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15146, to_date('19-06-2041', 'dd-mm-yyyy'), '3', '19', '170', '06', '2041', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15147, to_date('20-06-2041', 'dd-mm-yyyy'), '4', '20', '171', '06', '2041', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15148, to_date('21-06-2041', 'dd-mm-yyyy'), '5', '21', '172', '06', '2041', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15149, to_date('22-06-2041', 'dd-mm-yyyy'), '6', '22', '173', '06', '2041', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15150, to_date('23-06-2041', 'dd-mm-yyyy'), '7', '23', '174', '06', '2041', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15151, to_date('24-06-2041', 'dd-mm-yyyy'), '1', '24', '175', '06', '2041', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15152, to_date('25-06-2041', 'dd-mm-yyyy'), '2', '25', '176', '06', '2041', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15153, to_date('26-06-2041', 'dd-mm-yyyy'), '3', '26', '177', '06', '2041', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15154, to_date('27-06-2041', 'dd-mm-yyyy'), '4', '27', '178', '06', '2041', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15155, to_date('28-06-2041', 'dd-mm-yyyy'), '5', '28', '179', '06', '2041', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15156, to_date('29-06-2041', 'dd-mm-yyyy'), '6', '29', '180', '06', '2041', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15157, to_date('30-06-2041', 'dd-mm-yyyy'), '7', '30', '181', '06', '2041', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15158, to_date('01-07-2041', 'dd-mm-yyyy'), '1', '01', '182', '07', '2041', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15159, to_date('02-07-2041', 'dd-mm-yyyy'), '2', '02', '183', '07', '2041', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15160, to_date('03-07-2041', 'dd-mm-yyyy'), '3', '03', '184', '07', '2041', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15161, to_date('04-07-2041', 'dd-mm-yyyy'), '4', '04', '185', '07', '2041', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15162, to_date('05-07-2041', 'dd-mm-yyyy'), '5', '05', '186', '07', '2041', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15163, to_date('06-07-2041', 'dd-mm-yyyy'), '6', '06', '187', '07', '2041', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15164, to_date('07-07-2041', 'dd-mm-yyyy'), '7', '07', '188', '07', '2041', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15165, to_date('08-07-2041', 'dd-mm-yyyy'), '1', '08', '189', '07', '2041', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15166, to_date('09-07-2041', 'dd-mm-yyyy'), '2', '09', '190', '07', '2041', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15167, to_date('10-07-2041', 'dd-mm-yyyy'), '3', '10', '191', '07', '2041', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15168, to_date('11-07-2041', 'dd-mm-yyyy'), '4', '11', '192', '07', '2041', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15169, to_date('12-07-2041', 'dd-mm-yyyy'), '5', '12', '193', '07', '2041', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15170, to_date('13-07-2041', 'dd-mm-yyyy'), '6', '13', '194', '07', '2041', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15171, to_date('14-07-2041', 'dd-mm-yyyy'), '7', '14', '195', '07', '2041', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15172, to_date('15-07-2041', 'dd-mm-yyyy'), '1', '15', '196', '07', '2041', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15173, to_date('16-07-2041', 'dd-mm-yyyy'), '2', '16', '197', '07', '2041', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15174, to_date('17-07-2041', 'dd-mm-yyyy'), '3', '17', '198', '07', '2041', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15175, to_date('18-07-2041', 'dd-mm-yyyy'), '4', '18', '199', '07', '2041', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15176, to_date('19-07-2041', 'dd-mm-yyyy'), '5', '19', '200', '07', '2041', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15177, to_date('20-07-2041', 'dd-mm-yyyy'), '6', '20', '201', '07', '2041', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15178, to_date('21-07-2041', 'dd-mm-yyyy'), '7', '21', '202', '07', '2041', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15179, to_date('22-07-2041', 'dd-mm-yyyy'), '1', '22', '203', '07', '2041', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15180, to_date('23-07-2041', 'dd-mm-yyyy'), '2', '23', '204', '07', '2041', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15181, to_date('24-07-2041', 'dd-mm-yyyy'), '3', '24', '205', '07', '2041', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15182, to_date('25-07-2041', 'dd-mm-yyyy'), '4', '25', '206', '07', '2041', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15183, to_date('26-07-2041', 'dd-mm-yyyy'), '5', '26', '207', '07', '2041', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15184, to_date('27-07-2041', 'dd-mm-yyyy'), '6', '27', '208', '07', '2041', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15185, to_date('28-07-2041', 'dd-mm-yyyy'), '7', '28', '209', '07', '2041', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15186, to_date('29-07-2041', 'dd-mm-yyyy'), '1', '29', '210', '07', '2041', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15187, to_date('30-07-2041', 'dd-mm-yyyy'), '2', '30', '211', '07', '2041', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15188, to_date('31-07-2041', 'dd-mm-yyyy'), '3', '31', '212', '07', '2041', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15189, to_date('01-08-2041', 'dd-mm-yyyy'), '4', '01', '213', '08', '2041', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15190, to_date('02-08-2041', 'dd-mm-yyyy'), '5', '02', '214', '08', '2041', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15191, to_date('03-08-2041', 'dd-mm-yyyy'), '6', '03', '215', '08', '2041', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15192, to_date('04-08-2041', 'dd-mm-yyyy'), '7', '04', '216', '08', '2041', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15193, to_date('05-08-2041', 'dd-mm-yyyy'), '1', '05', '217', '08', '2041', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15194, to_date('06-08-2041', 'dd-mm-yyyy'), '2', '06', '218', '08', '2041', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15195, to_date('07-08-2041', 'dd-mm-yyyy'), '3', '07', '219', '08', '2041', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15196, to_date('08-08-2041', 'dd-mm-yyyy'), '4', '08', '220', '08', '2041', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15197, to_date('09-08-2041', 'dd-mm-yyyy'), '5', '09', '221', '08', '2041', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15198, to_date('10-08-2041', 'dd-mm-yyyy'), '6', '10', '222', '08', '2041', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15199, to_date('11-08-2041', 'dd-mm-yyyy'), '7', '11', '223', '08', '2041', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15200, to_date('12-08-2041', 'dd-mm-yyyy'), '1', '12', '224', '08', '2041', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15201, to_date('13-08-2041', 'dd-mm-yyyy'), '2', '13', '225', '08', '2041', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15202, to_date('14-08-2041', 'dd-mm-yyyy'), '3', '14', '226', '08', '2041', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15203, to_date('15-08-2041', 'dd-mm-yyyy'), '4', '15', '227', '08', '2041', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15204, to_date('16-08-2041', 'dd-mm-yyyy'), '5', '16', '228', '08', '2041', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15205, to_date('17-08-2041', 'dd-mm-yyyy'), '6', '17', '229', '08', '2041', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15206, to_date('18-08-2041', 'dd-mm-yyyy'), '7', '18', '230', '08', '2041', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15207, to_date('19-08-2041', 'dd-mm-yyyy'), '1', '19', '231', '08', '2041', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15208, to_date('20-08-2041', 'dd-mm-yyyy'), '2', '20', '232', '08', '2041', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15209, to_date('21-08-2041', 'dd-mm-yyyy'), '3', '21', '233', '08', '2041', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15210, to_date('22-08-2041', 'dd-mm-yyyy'), '4', '22', '234', '08', '2041', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15211, to_date('23-08-2041', 'dd-mm-yyyy'), '5', '23', '235', '08', '2041', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15212, to_date('24-08-2041', 'dd-mm-yyyy'), '6', '24', '236', '08', '2041', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15213, to_date('25-08-2041', 'dd-mm-yyyy'), '7', '25', '237', '08', '2041', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15214, to_date('26-08-2041', 'dd-mm-yyyy'), '1', '26', '238', '08', '2041', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15215, to_date('27-08-2041', 'dd-mm-yyyy'), '2', '27', '239', '08', '2041', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15216, to_date('28-08-2041', 'dd-mm-yyyy'), '3', '28', '240', '08', '2041', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15217, to_date('29-08-2041', 'dd-mm-yyyy'), '4', '29', '241', '08', '2041', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15218, to_date('30-08-2041', 'dd-mm-yyyy'), '5', '30', '242', '08', '2041', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15219, to_date('31-08-2041', 'dd-mm-yyyy'), '6', '31', '243', '08', '2041', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15220, to_date('01-09-2041', 'dd-mm-yyyy'), '7', '01', '244', '09', '2041', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15221, to_date('02-09-2041', 'dd-mm-yyyy'), '1', '02', '245', '09', '2041', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15222, to_date('03-09-2041', 'dd-mm-yyyy'), '2', '03', '246', '09', '2041', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15223, to_date('04-09-2041', 'dd-mm-yyyy'), '3', '04', '247', '09', '2041', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15224, to_date('05-09-2041', 'dd-mm-yyyy'), '4', '05', '248', '09', '2041', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15225, to_date('06-09-2041', 'dd-mm-yyyy'), '5', '06', '249', '09', '2041', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15226, to_date('07-09-2041', 'dd-mm-yyyy'), '6', '07', '250', '09', '2041', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15227, to_date('08-09-2041', 'dd-mm-yyyy'), '7', '08', '251', '09', '2041', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15228, to_date('09-09-2041', 'dd-mm-yyyy'), '1', '09', '252', '09', '2041', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15229, to_date('10-09-2041', 'dd-mm-yyyy'), '2', '10', '253', '09', '2041', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15230, to_date('11-09-2041', 'dd-mm-yyyy'), '3', '11', '254', '09', '2041', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15231, to_date('12-09-2041', 'dd-mm-yyyy'), '4', '12', '255', '09', '2041', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15232, to_date('13-09-2041', 'dd-mm-yyyy'), '5', '13', '256', '09', '2041', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15233, to_date('14-09-2041', 'dd-mm-yyyy'), '6', '14', '257', '09', '2041', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15234, to_date('15-09-2041', 'dd-mm-yyyy'), '7', '15', '258', '09', '2041', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15235, to_date('16-09-2041', 'dd-mm-yyyy'), '1', '16', '259', '09', '2041', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15236, to_date('17-09-2041', 'dd-mm-yyyy'), '2', '17', '260', '09', '2041', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15237, to_date('18-09-2041', 'dd-mm-yyyy'), '3', '18', '261', '09', '2041', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15238, to_date('19-09-2041', 'dd-mm-yyyy'), '4', '19', '262', '09', '2041', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16723, to_date('13-10-2045', 'dd-mm-yyyy'), '5', '13', '286', '10', '2045', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16724, to_date('14-10-2045', 'dd-mm-yyyy'), '6', '14', '287', '10', '2045', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16725, to_date('15-10-2045', 'dd-mm-yyyy'), '7', '15', '288', '10', '2045', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16726, to_date('16-10-2045', 'dd-mm-yyyy'), '1', '16', '289', '10', '2045', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16727, to_date('17-10-2045', 'dd-mm-yyyy'), '2', '17', '290', '10', '2045', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16728, to_date('18-10-2045', 'dd-mm-yyyy'), '3', '18', '291', '10', '2045', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16729, to_date('19-10-2045', 'dd-mm-yyyy'), '4', '19', '292', '10', '2045', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16730, to_date('20-10-2045', 'dd-mm-yyyy'), '5', '20', '293', '10', '2045', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16731, to_date('21-10-2045', 'dd-mm-yyyy'), '6', '21', '294', '10', '2045', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16732, to_date('22-10-2045', 'dd-mm-yyyy'), '7', '22', '295', '10', '2045', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16733, to_date('23-10-2045', 'dd-mm-yyyy'), '1', '23', '296', '10', '2045', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16734, to_date('24-10-2045', 'dd-mm-yyyy'), '2', '24', '297', '10', '2045', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16735, to_date('25-10-2045', 'dd-mm-yyyy'), '3', '25', '298', '10', '2045', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16736, to_date('26-10-2045', 'dd-mm-yyyy'), '4', '26', '299', '10', '2045', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16737, to_date('27-10-2045', 'dd-mm-yyyy'), '5', '27', '300', '10', '2045', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16738, to_date('28-10-2045', 'dd-mm-yyyy'), '6', '28', '301', '10', '2045', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16739, to_date('29-10-2045', 'dd-mm-yyyy'), '7', '29', '302', '10', '2045', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16740, to_date('30-10-2045', 'dd-mm-yyyy'), '1', '30', '303', '10', '2045', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16741, to_date('31-10-2045', 'dd-mm-yyyy'), '2', '31', '304', '10', '2045', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16742, to_date('01-11-2045', 'dd-mm-yyyy'), '3', '01', '305', '11', '2045', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16743, to_date('02-11-2045', 'dd-mm-yyyy'), '4', '02', '306', '11', '2045', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16744, to_date('03-11-2045', 'dd-mm-yyyy'), '5', '03', '307', '11', '2045', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16745, to_date('04-11-2045', 'dd-mm-yyyy'), '6', '04', '308', '11', '2045', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16746, to_date('05-11-2045', 'dd-mm-yyyy'), '7', '05', '309', '11', '2045', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16747, to_date('06-11-2045', 'dd-mm-yyyy'), '1', '06', '310', '11', '2045', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16748, to_date('07-11-2045', 'dd-mm-yyyy'), '2', '07', '311', '11', '2045', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16749, to_date('08-11-2045', 'dd-mm-yyyy'), '3', '08', '312', '11', '2045', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16750, to_date('09-11-2045', 'dd-mm-yyyy'), '4', '09', '313', '11', '2045', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16751, to_date('10-11-2045', 'dd-mm-yyyy'), '5', '10', '314', '11', '2045', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16752, to_date('11-11-2045', 'dd-mm-yyyy'), '6', '11', '315', '11', '2045', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16753, to_date('12-11-2045', 'dd-mm-yyyy'), '7', '12', '316', '11', '2045', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16754, to_date('13-11-2045', 'dd-mm-yyyy'), '1', '13', '317', '11', '2045', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16755, to_date('14-11-2045', 'dd-mm-yyyy'), '2', '14', '318', '11', '2045', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16756, to_date('15-11-2045', 'dd-mm-yyyy'), '3', '15', '319', '11', '2045', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16757, to_date('16-11-2045', 'dd-mm-yyyy'), '4', '16', '320', '11', '2045', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16758, to_date('17-11-2045', 'dd-mm-yyyy'), '5', '17', '321', '11', '2045', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16759, to_date('18-11-2045', 'dd-mm-yyyy'), '6', '18', '322', '11', '2045', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16760, to_date('19-11-2045', 'dd-mm-yyyy'), '7', '19', '323', '11', '2045', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16761, to_date('20-11-2045', 'dd-mm-yyyy'), '1', '20', '324', '11', '2045', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16762, to_date('21-11-2045', 'dd-mm-yyyy'), '2', '21', '325', '11', '2045', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16763, to_date('22-11-2045', 'dd-mm-yyyy'), '3', '22', '326', '11', '2045', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16764, to_date('23-11-2045', 'dd-mm-yyyy'), '4', '23', '327', '11', '2045', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16765, to_date('24-11-2045', 'dd-mm-yyyy'), '5', '24', '328', '11', '2045', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16766, to_date('25-11-2045', 'dd-mm-yyyy'), '6', '25', '329', '11', '2045', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16767, to_date('26-11-2045', 'dd-mm-yyyy'), '7', '26', '330', '11', '2045', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16768, to_date('27-11-2045', 'dd-mm-yyyy'), '1', '27', '331', '11', '2045', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16769, to_date('28-11-2045', 'dd-mm-yyyy'), '2', '28', '332', '11', '2045', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16770, to_date('29-11-2045', 'dd-mm-yyyy'), '3', '29', '333', '11', '2045', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16771, to_date('30-11-2045', 'dd-mm-yyyy'), '4', '30', '334', '11', '2045', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16772, to_date('01-12-2045', 'dd-mm-yyyy'), '5', '01', '335', '12', '2045', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16773, to_date('02-12-2045', 'dd-mm-yyyy'), '6', '02', '336', '12', '2045', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16774, to_date('03-12-2045', 'dd-mm-yyyy'), '7', '03', '337', '12', '2045', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16775, to_date('04-12-2045', 'dd-mm-yyyy'), '1', '04', '338', '12', '2045', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16776, to_date('05-12-2045', 'dd-mm-yyyy'), '2', '05', '339', '12', '2045', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16777, to_date('06-12-2045', 'dd-mm-yyyy'), '3', '06', '340', '12', '2045', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16778, to_date('07-12-2045', 'dd-mm-yyyy'), '4', '07', '341', '12', '2045', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16779, to_date('08-12-2045', 'dd-mm-yyyy'), '5', '08', '342', '12', '2045', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16780, to_date('09-12-2045', 'dd-mm-yyyy'), '6', '09', '343', '12', '2045', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16781, to_date('10-12-2045', 'dd-mm-yyyy'), '7', '10', '344', '12', '2045', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16782, to_date('11-12-2045', 'dd-mm-yyyy'), '1', '11', '345', '12', '2045', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16783, to_date('12-12-2045', 'dd-mm-yyyy'), '2', '12', '346', '12', '2045', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16784, to_date('13-12-2045', 'dd-mm-yyyy'), '3', '13', '347', '12', '2045', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16785, to_date('14-12-2045', 'dd-mm-yyyy'), '4', '14', '348', '12', '2045', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16786, to_date('15-12-2045', 'dd-mm-yyyy'), '5', '15', '349', '12', '2045', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16787, to_date('16-12-2045', 'dd-mm-yyyy'), '6', '16', '350', '12', '2045', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16788, to_date('17-12-2045', 'dd-mm-yyyy'), '7', '17', '351', '12', '2045', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16789, to_date('18-12-2045', 'dd-mm-yyyy'), '1', '18', '352', '12', '2045', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16790, to_date('19-12-2045', 'dd-mm-yyyy'), '2', '19', '353', '12', '2045', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16791, to_date('20-12-2045', 'dd-mm-yyyy'), '3', '20', '354', '12', '2045', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16792, to_date('21-12-2045', 'dd-mm-yyyy'), '4', '21', '355', '12', '2045', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16793, to_date('22-12-2045', 'dd-mm-yyyy'), '5', '22', '356', '12', '2045', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16794, to_date('23-12-2045', 'dd-mm-yyyy'), '6', '23', '357', '12', '2045', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16795, to_date('24-12-2045', 'dd-mm-yyyy'), '7', '24', '358', '12', '2045', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16796, to_date('25-12-2045', 'dd-mm-yyyy'), '1', '25', '359', '12', '2045', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16797, to_date('26-12-2045', 'dd-mm-yyyy'), '2', '26', '360', '12', '2045', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16798, to_date('27-12-2045', 'dd-mm-yyyy'), '3', '27', '361', '12', '2045', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16799, to_date('28-12-2045', 'dd-mm-yyyy'), '4', '28', '362', '12', '2045', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16800, to_date('29-12-2045', 'dd-mm-yyyy'), '5', '29', '363', '12', '2045', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16801, to_date('30-12-2045', 'dd-mm-yyyy'), '6', '30', '364', '12', '2045', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16802, to_date('31-12-2045', 'dd-mm-yyyy'), '7', '31', '365', '12', '2045', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16803, to_date('01-01-2046', 'dd-mm-yyyy'), '1', '01', '001', '01', '2046', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16804, to_date('02-01-2046', 'dd-mm-yyyy'), '2', '02', '002', '01', '2046', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16805, to_date('03-01-2046', 'dd-mm-yyyy'), '3', '03', '003', '01', '2046', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16806, to_date('04-01-2046', 'dd-mm-yyyy'), '4', '04', '004', '01', '2046', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16807, to_date('05-01-2046', 'dd-mm-yyyy'), '5', '05', '005', '01', '2046', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16808, to_date('06-01-2046', 'dd-mm-yyyy'), '6', '06', '006', '01', '2046', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16809, to_date('07-01-2046', 'dd-mm-yyyy'), '7', '07', '007', '01', '2046', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16810, to_date('08-01-2046', 'dd-mm-yyyy'), '1', '08', '008', '01', '2046', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16811, to_date('09-01-2046', 'dd-mm-yyyy'), '2', '09', '009', '01', '2046', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16812, to_date('10-01-2046', 'dd-mm-yyyy'), '3', '10', '010', '01', '2046', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16813, to_date('11-01-2046', 'dd-mm-yyyy'), '4', '11', '011', '01', '2046', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16814, to_date('12-01-2046', 'dd-mm-yyyy'), '5', '12', '012', '01', '2046', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16815, to_date('13-01-2046', 'dd-mm-yyyy'), '6', '13', '013', '01', '2046', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16816, to_date('14-01-2046', 'dd-mm-yyyy'), '7', '14', '014', '01', '2046', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16817, to_date('15-01-2046', 'dd-mm-yyyy'), '1', '15', '015', '01', '2046', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16818, to_date('16-01-2046', 'dd-mm-yyyy'), '2', '16', '016', '01', '2046', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16819, to_date('17-01-2046', 'dd-mm-yyyy'), '3', '17', '017', '01', '2046', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16820, to_date('18-01-2046', 'dd-mm-yyyy'), '4', '18', '018', '01', '2046', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16821, to_date('19-01-2046', 'dd-mm-yyyy'), '5', '19', '019', '01', '2046', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16822, to_date('20-01-2046', 'dd-mm-yyyy'), '6', '20', '020', '01', '2046', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16823, to_date('21-01-2046', 'dd-mm-yyyy'), '7', '21', '021', '01', '2046', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16824, to_date('22-01-2046', 'dd-mm-yyyy'), '1', '22', '022', '01', '2046', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16825, to_date('23-01-2046', 'dd-mm-yyyy'), '2', '23', '023', '01', '2046', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16826, to_date('24-01-2046', 'dd-mm-yyyy'), '3', '24', '024', '01', '2046', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16827, to_date('25-01-2046', 'dd-mm-yyyy'), '4', '25', '025', '01', '2046', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16828, to_date('26-01-2046', 'dd-mm-yyyy'), '5', '26', '026', '01', '2046', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18313, to_date('19-02-2050', 'dd-mm-yyyy'), '6', '19', '050', '02', '2050', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18314, to_date('20-02-2050', 'dd-mm-yyyy'), '7', '20', '051', '02', '2050', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18315, to_date('21-02-2050', 'dd-mm-yyyy'), '1', '21', '052', '02', '2050', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18316, to_date('22-02-2050', 'dd-mm-yyyy'), '2', '22', '053', '02', '2050', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18317, to_date('23-02-2050', 'dd-mm-yyyy'), '3', '23', '054', '02', '2050', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18318, to_date('24-02-2050', 'dd-mm-yyyy'), '4', '24', '055', '02', '2050', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18319, to_date('25-02-2050', 'dd-mm-yyyy'), '5', '25', '056', '02', '2050', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18320, to_date('26-02-2050', 'dd-mm-yyyy'), '6', '26', '057', '02', '2050', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18321, to_date('27-02-2050', 'dd-mm-yyyy'), '7', '27', '058', '02', '2050', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18322, to_date('28-02-2050', 'dd-mm-yyyy'), '1', '28', '059', '02', '2050', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18323, to_date('01-03-2050', 'dd-mm-yyyy'), '2', '01', '060', '03', '2050', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18324, to_date('02-03-2050', 'dd-mm-yyyy'), '3', '02', '061', '03', '2050', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18325, to_date('03-03-2050', 'dd-mm-yyyy'), '4', '03', '062', '03', '2050', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18326, to_date('04-03-2050', 'dd-mm-yyyy'), '5', '04', '063', '03', '2050', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18327, to_date('05-03-2050', 'dd-mm-yyyy'), '6', '05', '064', '03', '2050', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18328, to_date('06-03-2050', 'dd-mm-yyyy'), '7', '06', '065', '03', '2050', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18329, to_date('07-03-2050', 'dd-mm-yyyy'), '1', '07', '066', '03', '2050', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18330, to_date('08-03-2050', 'dd-mm-yyyy'), '2', '08', '067', '03', '2050', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18331, to_date('09-03-2050', 'dd-mm-yyyy'), '3', '09', '068', '03', '2050', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18332, to_date('10-03-2050', 'dd-mm-yyyy'), '4', '10', '069', '03', '2050', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18333, to_date('11-03-2050', 'dd-mm-yyyy'), '5', '11', '070', '03', '2050', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18334, to_date('12-03-2050', 'dd-mm-yyyy'), '6', '12', '071', '03', '2050', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18335, to_date('13-03-2050', 'dd-mm-yyyy'), '7', '13', '072', '03', '2050', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18336, to_date('14-03-2050', 'dd-mm-yyyy'), '1', '14', '073', '03', '2050', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18337, to_date('15-03-2050', 'dd-mm-yyyy'), '2', '15', '074', '03', '2050', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18338, to_date('16-03-2050', 'dd-mm-yyyy'), '3', '16', '075', '03', '2050', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18339, to_date('17-03-2050', 'dd-mm-yyyy'), '4', '17', '076', '03', '2050', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18340, to_date('18-03-2050', 'dd-mm-yyyy'), '5', '18', '077', '03', '2050', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18341, to_date('19-03-2050', 'dd-mm-yyyy'), '6', '19', '078', '03', '2050', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18342, to_date('20-03-2050', 'dd-mm-yyyy'), '7', '20', '079', '03', '2050', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18343, to_date('21-03-2050', 'dd-mm-yyyy'), '1', '21', '080', '03', '2050', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18344, to_date('22-03-2050', 'dd-mm-yyyy'), '2', '22', '081', '03', '2050', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18345, to_date('23-03-2050', 'dd-mm-yyyy'), '3', '23', '082', '03', '2050', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18346, to_date('24-03-2050', 'dd-mm-yyyy'), '4', '24', '083', '03', '2050', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18347, to_date('25-03-2050', 'dd-mm-yyyy'), '5', '25', '084', '03', '2050', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18348, to_date('26-03-2050', 'dd-mm-yyyy'), '6', '26', '085', '03', '2050', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18349, to_date('27-03-2050', 'dd-mm-yyyy'), '7', '27', '086', '03', '2050', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18350, to_date('28-03-2050', 'dd-mm-yyyy'), '1', '28', '087', '03', '2050', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18351, to_date('29-03-2050', 'dd-mm-yyyy'), '2', '29', '088', '03', '2050', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18352, to_date('30-03-2050', 'dd-mm-yyyy'), '3', '30', '089', '03', '2050', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18353, to_date('31-03-2050', 'dd-mm-yyyy'), '4', '31', '090', '03', '2050', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18354, to_date('01-04-2050', 'dd-mm-yyyy'), '5', '01', '091', '04', '2050', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18355, to_date('02-04-2050', 'dd-mm-yyyy'), '6', '02', '092', '04', '2050', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18356, to_date('03-04-2050', 'dd-mm-yyyy'), '7', '03', '093', '04', '2050', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18357, to_date('04-04-2050', 'dd-mm-yyyy'), '1', '04', '094', '04', '2050', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18358, to_date('05-04-2050', 'dd-mm-yyyy'), '2', '05', '095', '04', '2050', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18359, to_date('06-04-2050', 'dd-mm-yyyy'), '3', '06', '096', '04', '2050', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18360, to_date('07-04-2050', 'dd-mm-yyyy'), '4', '07', '097', '04', '2050', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18361, to_date('08-04-2050', 'dd-mm-yyyy'), '5', '08', '098', '04', '2050', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18362, to_date('09-04-2050', 'dd-mm-yyyy'), '6', '09', '099', '04', '2050', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18363, to_date('10-04-2050', 'dd-mm-yyyy'), '7', '10', '100', '04', '2050', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18364, to_date('11-04-2050', 'dd-mm-yyyy'), '1', '11', '101', '04', '2050', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18365, to_date('12-04-2050', 'dd-mm-yyyy'), '2', '12', '102', '04', '2050', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18366, to_date('13-04-2050', 'dd-mm-yyyy'), '3', '13', '103', '04', '2050', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18367, to_date('14-04-2050', 'dd-mm-yyyy'), '4', '14', '104', '04', '2050', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18368, to_date('15-04-2050', 'dd-mm-yyyy'), '5', '15', '105', '04', '2050', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18369, to_date('16-04-2050', 'dd-mm-yyyy'), '6', '16', '106', '04', '2050', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18370, to_date('17-04-2050', 'dd-mm-yyyy'), '7', '17', '107', '04', '2050', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18371, to_date('18-04-2050', 'dd-mm-yyyy'), '1', '18', '108', '04', '2050', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18372, to_date('19-04-2050', 'dd-mm-yyyy'), '2', '19', '109', '04', '2050', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18373, to_date('20-04-2050', 'dd-mm-yyyy'), '3', '20', '110', '04', '2050', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18374, to_date('21-04-2050', 'dd-mm-yyyy'), '4', '21', '111', '04', '2050', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18375, to_date('22-04-2050', 'dd-mm-yyyy'), '5', '22', '112', '04', '2050', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18376, to_date('23-04-2050', 'dd-mm-yyyy'), '6', '23', '113', '04', '2050', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18377, to_date('24-04-2050', 'dd-mm-yyyy'), '7', '24', '114', '04', '2050', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18378, to_date('25-04-2050', 'dd-mm-yyyy'), '1', '25', '115', '04', '2050', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18379, to_date('26-04-2050', 'dd-mm-yyyy'), '2', '26', '116', '04', '2050', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18380, to_date('27-04-2050', 'dd-mm-yyyy'), '3', '27', '117', '04', '2050', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18381, to_date('28-04-2050', 'dd-mm-yyyy'), '4', '28', '118', '04', '2050', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18382, to_date('29-04-2050', 'dd-mm-yyyy'), '5', '29', '119', '04', '2050', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18383, to_date('30-04-2050', 'dd-mm-yyyy'), '6', '30', '120', '04', '2050', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18384, to_date('01-05-2050', 'dd-mm-yyyy'), '7', '01', '121', '05', '2050', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18385, to_date('02-05-2050', 'dd-mm-yyyy'), '1', '02', '122', '05', '2050', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18386, to_date('03-05-2050', 'dd-mm-yyyy'), '2', '03', '123', '05', '2050', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18387, to_date('04-05-2050', 'dd-mm-yyyy'), '3', '04', '124', '05', '2050', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18388, to_date('05-05-2050', 'dd-mm-yyyy'), '4', '05', '125', '05', '2050', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18389, to_date('06-05-2050', 'dd-mm-yyyy'), '5', '06', '126', '05', '2050', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18390, to_date('07-05-2050', 'dd-mm-yyyy'), '6', '07', '127', '05', '2050', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18391, to_date('08-05-2050', 'dd-mm-yyyy'), '7', '08', '128', '05', '2050', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18392, to_date('09-05-2050', 'dd-mm-yyyy'), '1', '09', '129', '05', '2050', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18393, to_date('10-05-2050', 'dd-mm-yyyy'), '2', '10', '130', '05', '2050', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18394, to_date('11-05-2050', 'dd-mm-yyyy'), '3', '11', '131', '05', '2050', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18395, to_date('12-05-2050', 'dd-mm-yyyy'), '4', '12', '132', '05', '2050', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18396, to_date('13-05-2050', 'dd-mm-yyyy'), '5', '13', '133', '05', '2050', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18397, to_date('14-05-2050', 'dd-mm-yyyy'), '6', '14', '134', '05', '2050', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18398, to_date('15-05-2050', 'dd-mm-yyyy'), '7', '15', '135', '05', '2050', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18399, to_date('16-05-2050', 'dd-mm-yyyy'), '1', '16', '136', '05', '2050', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18400, to_date('17-05-2050', 'dd-mm-yyyy'), '2', '17', '137', '05', '2050', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18401, to_date('18-05-2050', 'dd-mm-yyyy'), '3', '18', '138', '05', '2050', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18402, to_date('19-05-2050', 'dd-mm-yyyy'), '4', '19', '139', '05', '2050', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18403, to_date('20-05-2050', 'dd-mm-yyyy'), '5', '20', '140', '05', '2050', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18404, to_date('21-05-2050', 'dd-mm-yyyy'), '6', '21', '141', '05', '2050', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18405, to_date('22-05-2050', 'dd-mm-yyyy'), '7', '22', '142', '05', '2050', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18406, to_date('23-05-2050', 'dd-mm-yyyy'), '1', '23', '143', '05', '2050', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18407, to_date('24-05-2050', 'dd-mm-yyyy'), '2', '24', '144', '05', '2050', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18408, to_date('25-05-2050', 'dd-mm-yyyy'), '3', '25', '145', '05', '2050', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18409, to_date('26-05-2050', 'dd-mm-yyyy'), '4', '26', '146', '05', '2050', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18410, to_date('27-05-2050', 'dd-mm-yyyy'), '5', '27', '147', '05', '2050', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18411, to_date('28-05-2050', 'dd-mm-yyyy'), '6', '28', '148', '05', '2050', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18412, to_date('29-05-2050', 'dd-mm-yyyy'), '7', '29', '149', '05', '2050', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18413, to_date('30-05-2050', 'dd-mm-yyyy'), '1', '30', '150', '05', '2050', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18414, to_date('31-05-2050', 'dd-mm-yyyy'), '2', '31', '151', '05', '2050', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18415, to_date('01-06-2050', 'dd-mm-yyyy'), '3', '01', '152', '06', '2050', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18416, to_date('02-06-2050', 'dd-mm-yyyy'), '4', '02', '153', '06', '2050', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18417, to_date('03-06-2050', 'dd-mm-yyyy'), '5', '03', '154', '06', '2050', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18418, to_date('04-06-2050', 'dd-mm-yyyy'), '6', '04', '155', '06', '2050', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13543, to_date('28-01-2037', 'dd-mm-yyyy'), '3', '28', '028', '01', '2037', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13544, to_date('29-01-2037', 'dd-mm-yyyy'), '4', '29', '029', '01', '2037', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13545, to_date('30-01-2037', 'dd-mm-yyyy'), '5', '30', '030', '01', '2037', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13546, to_date('31-01-2037', 'dd-mm-yyyy'), '6', '31', '031', '01', '2037', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13547, to_date('01-02-2037', 'dd-mm-yyyy'), '7', '01', '032', '02', '2037', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13548, to_date('02-02-2037', 'dd-mm-yyyy'), '1', '02', '033', '02', '2037', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13549, to_date('03-02-2037', 'dd-mm-yyyy'), '2', '03', '034', '02', '2037', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13550, to_date('04-02-2037', 'dd-mm-yyyy'), '3', '04', '035', '02', '2037', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13551, to_date('05-02-2037', 'dd-mm-yyyy'), '4', '05', '036', '02', '2037', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13552, to_date('06-02-2037', 'dd-mm-yyyy'), '5', '06', '037', '02', '2037', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13553, to_date('07-02-2037', 'dd-mm-yyyy'), '6', '07', '038', '02', '2037', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13554, to_date('08-02-2037', 'dd-mm-yyyy'), '7', '08', '039', '02', '2037', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13555, to_date('09-02-2037', 'dd-mm-yyyy'), '1', '09', '040', '02', '2037', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13556, to_date('10-02-2037', 'dd-mm-yyyy'), '2', '10', '041', '02', '2037', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13557, to_date('11-02-2037', 'dd-mm-yyyy'), '3', '11', '042', '02', '2037', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13558, to_date('12-02-2037', 'dd-mm-yyyy'), '4', '12', '043', '02', '2037', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13559, to_date('13-02-2037', 'dd-mm-yyyy'), '5', '13', '044', '02', '2037', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13560, to_date('14-02-2037', 'dd-mm-yyyy'), '6', '14', '045', '02', '2037', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13561, to_date('15-02-2037', 'dd-mm-yyyy'), '7', '15', '046', '02', '2037', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13562, to_date('16-02-2037', 'dd-mm-yyyy'), '1', '16', '047', '02', '2037', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13563, to_date('17-02-2037', 'dd-mm-yyyy'), '2', '17', '048', '02', '2037', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13564, to_date('18-02-2037', 'dd-mm-yyyy'), '3', '18', '049', '02', '2037', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13565, to_date('19-02-2037', 'dd-mm-yyyy'), '4', '19', '050', '02', '2037', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13566, to_date('20-02-2037', 'dd-mm-yyyy'), '5', '20', '051', '02', '2037', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13567, to_date('21-02-2037', 'dd-mm-yyyy'), '6', '21', '052', '02', '2037', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13568, to_date('22-02-2037', 'dd-mm-yyyy'), '7', '22', '053', '02', '2037', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13569, to_date('23-02-2037', 'dd-mm-yyyy'), '1', '23', '054', '02', '2037', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13570, to_date('24-02-2037', 'dd-mm-yyyy'), '2', '24', '055', '02', '2037', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13571, to_date('25-02-2037', 'dd-mm-yyyy'), '3', '25', '056', '02', '2037', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13572, to_date('26-02-2037', 'dd-mm-yyyy'), '4', '26', '057', '02', '2037', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13573, to_date('27-02-2037', 'dd-mm-yyyy'), '5', '27', '058', '02', '2037', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13574, to_date('28-02-2037', 'dd-mm-yyyy'), '6', '28', '059', '02', '2037', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13575, to_date('01-03-2037', 'dd-mm-yyyy'), '7', '01', '060', '03', '2037', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13576, to_date('02-03-2037', 'dd-mm-yyyy'), '1', '02', '061', '03', '2037', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13577, to_date('03-03-2037', 'dd-mm-yyyy'), '2', '03', '062', '03', '2037', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13578, to_date('04-03-2037', 'dd-mm-yyyy'), '3', '04', '063', '03', '2037', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13579, to_date('05-03-2037', 'dd-mm-yyyy'), '4', '05', '064', '03', '2037', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13580, to_date('06-03-2037', 'dd-mm-yyyy'), '5', '06', '065', '03', '2037', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13581, to_date('07-03-2037', 'dd-mm-yyyy'), '6', '07', '066', '03', '2037', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13582, to_date('08-03-2037', 'dd-mm-yyyy'), '7', '08', '067', '03', '2037', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13583, to_date('09-03-2037', 'dd-mm-yyyy'), '1', '09', '068', '03', '2037', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13584, to_date('10-03-2037', 'dd-mm-yyyy'), '2', '10', '069', '03', '2037', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13585, to_date('11-03-2037', 'dd-mm-yyyy'), '3', '11', '070', '03', '2037', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13586, to_date('12-03-2037', 'dd-mm-yyyy'), '4', '12', '071', '03', '2037', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13587, to_date('13-03-2037', 'dd-mm-yyyy'), '5', '13', '072', '03', '2037', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13588, to_date('14-03-2037', 'dd-mm-yyyy'), '6', '14', '073', '03', '2037', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13589, to_date('15-03-2037', 'dd-mm-yyyy'), '7', '15', '074', '03', '2037', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13590, to_date('16-03-2037', 'dd-mm-yyyy'), '1', '16', '075', '03', '2037', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13591, to_date('17-03-2037', 'dd-mm-yyyy'), '2', '17', '076', '03', '2037', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13592, to_date('18-03-2037', 'dd-mm-yyyy'), '3', '18', '077', '03', '2037', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13593, to_date('19-03-2037', 'dd-mm-yyyy'), '4', '19', '078', '03', '2037', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13594, to_date('20-03-2037', 'dd-mm-yyyy'), '5', '20', '079', '03', '2037', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13595, to_date('21-03-2037', 'dd-mm-yyyy'), '6', '21', '080', '03', '2037', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13596, to_date('22-03-2037', 'dd-mm-yyyy'), '7', '22', '081', '03', '2037', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13597, to_date('23-03-2037', 'dd-mm-yyyy'), '1', '23', '082', '03', '2037', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13598, to_date('24-03-2037', 'dd-mm-yyyy'), '2', '24', '083', '03', '2037', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13599, to_date('25-03-2037', 'dd-mm-yyyy'), '3', '25', '084', '03', '2037', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13600, to_date('26-03-2037', 'dd-mm-yyyy'), '4', '26', '085', '03', '2037', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13601, to_date('27-03-2037', 'dd-mm-yyyy'), '5', '27', '086', '03', '2037', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13602, to_date('28-03-2037', 'dd-mm-yyyy'), '6', '28', '087', '03', '2037', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13603, to_date('29-03-2037', 'dd-mm-yyyy'), '7', '29', '088', '03', '2037', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13604, to_date('30-03-2037', 'dd-mm-yyyy'), '1', '30', '089', '03', '2037', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13605, to_date('31-03-2037', 'dd-mm-yyyy'), '2', '31', '090', '03', '2037', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13606, to_date('01-04-2037', 'dd-mm-yyyy'), '3', '01', '091', '04', '2037', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13607, to_date('02-04-2037', 'dd-mm-yyyy'), '4', '02', '092', '04', '2037', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13608, to_date('03-04-2037', 'dd-mm-yyyy'), '5', '03', '093', '04', '2037', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13609, to_date('04-04-2037', 'dd-mm-yyyy'), '6', '04', '094', '04', '2037', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13610, to_date('05-04-2037', 'dd-mm-yyyy'), '7', '05', '095', '04', '2037', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13611, to_date('06-04-2037', 'dd-mm-yyyy'), '1', '06', '096', '04', '2037', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13612, to_date('07-04-2037', 'dd-mm-yyyy'), '2', '07', '097', '04', '2037', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13613, to_date('08-04-2037', 'dd-mm-yyyy'), '3', '08', '098', '04', '2037', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13614, to_date('09-04-2037', 'dd-mm-yyyy'), '4', '09', '099', '04', '2037', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13615, to_date('10-04-2037', 'dd-mm-yyyy'), '5', '10', '100', '04', '2037', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13616, to_date('11-04-2037', 'dd-mm-yyyy'), '6', '11', '101', '04', '2037', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13617, to_date('12-04-2037', 'dd-mm-yyyy'), '7', '12', '102', '04', '2037', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13618, to_date('13-04-2037', 'dd-mm-yyyy'), '1', '13', '103', '04', '2037', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13619, to_date('14-04-2037', 'dd-mm-yyyy'), '2', '14', '104', '04', '2037', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13620, to_date('15-04-2037', 'dd-mm-yyyy'), '3', '15', '105', '04', '2037', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13621, to_date('16-04-2037', 'dd-mm-yyyy'), '4', '16', '106', '04', '2037', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13622, to_date('17-04-2037', 'dd-mm-yyyy'), '5', '17', '107', '04', '2037', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13623, to_date('18-04-2037', 'dd-mm-yyyy'), '6', '18', '108', '04', '2037', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13624, to_date('19-04-2037', 'dd-mm-yyyy'), '7', '19', '109', '04', '2037', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13625, to_date('20-04-2037', 'dd-mm-yyyy'), '1', '20', '110', '04', '2037', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13626, to_date('21-04-2037', 'dd-mm-yyyy'), '2', '21', '111', '04', '2037', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13627, to_date('22-04-2037', 'dd-mm-yyyy'), '3', '22', '112', '04', '2037', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13628, to_date('23-04-2037', 'dd-mm-yyyy'), '4', '23', '113', '04', '2037', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13629, to_date('24-04-2037', 'dd-mm-yyyy'), '5', '24', '114', '04', '2037', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13630, to_date('25-04-2037', 'dd-mm-yyyy'), '6', '25', '115', '04', '2037', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13631, to_date('26-04-2037', 'dd-mm-yyyy'), '7', '26', '116', '04', '2037', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13632, to_date('27-04-2037', 'dd-mm-yyyy'), '1', '27', '117', '04', '2037', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13633, to_date('28-04-2037', 'dd-mm-yyyy'), '2', '28', '118', '04', '2037', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13634, to_date('29-04-2037', 'dd-mm-yyyy'), '3', '29', '119', '04', '2037', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13635, to_date('30-04-2037', 'dd-mm-yyyy'), '4', '30', '120', '04', '2037', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13636, to_date('01-05-2037', 'dd-mm-yyyy'), '5', '01', '121', '05', '2037', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13637, to_date('02-05-2037', 'dd-mm-yyyy'), '6', '02', '122', '05', '2037', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13638, to_date('03-05-2037', 'dd-mm-yyyy'), '7', '03', '123', '05', '2037', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13639, to_date('04-05-2037', 'dd-mm-yyyy'), '1', '04', '124', '05', '2037', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13640, to_date('05-05-2037', 'dd-mm-yyyy'), '2', '05', '125', '05', '2037', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13641, to_date('06-05-2037', 'dd-mm-yyyy'), '3', '06', '126', '05', '2037', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13642, to_date('07-05-2037', 'dd-mm-yyyy'), '4', '07', '127', '05', '2037', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13643, to_date('08-05-2037', 'dd-mm-yyyy'), '5', '08', '128', '05', '2037', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13644, to_date('09-05-2037', 'dd-mm-yyyy'), '6', '09', '129', '05', '2037', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13645, to_date('10-05-2037', 'dd-mm-yyyy'), '7', '10', '130', '05', '2037', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13646, to_date('11-05-2037', 'dd-mm-yyyy'), '1', '11', '131', '05', '2037', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13647, to_date('12-05-2037', 'dd-mm-yyyy'), '2', '12', '132', '05', '2037', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13648, to_date('13-05-2037', 'dd-mm-yyyy'), '3', '13', '133', '05', '2037', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15239, to_date('20-09-2041', 'dd-mm-yyyy'), '5', '20', '263', '09', '2041', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15240, to_date('21-09-2041', 'dd-mm-yyyy'), '6', '21', '264', '09', '2041', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15241, to_date('22-09-2041', 'dd-mm-yyyy'), '7', '22', '265', '09', '2041', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15242, to_date('23-09-2041', 'dd-mm-yyyy'), '1', '23', '266', '09', '2041', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15243, to_date('24-09-2041', 'dd-mm-yyyy'), '2', '24', '267', '09', '2041', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15244, to_date('25-09-2041', 'dd-mm-yyyy'), '3', '25', '268', '09', '2041', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15245, to_date('26-09-2041', 'dd-mm-yyyy'), '4', '26', '269', '09', '2041', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15246, to_date('27-09-2041', 'dd-mm-yyyy'), '5', '27', '270', '09', '2041', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15247, to_date('28-09-2041', 'dd-mm-yyyy'), '6', '28', '271', '09', '2041', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15248, to_date('29-09-2041', 'dd-mm-yyyy'), '7', '29', '272', '09', '2041', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15249, to_date('30-09-2041', 'dd-mm-yyyy'), '1', '30', '273', '09', '2041', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15250, to_date('01-10-2041', 'dd-mm-yyyy'), '2', '01', '274', '10', '2041', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15251, to_date('02-10-2041', 'dd-mm-yyyy'), '3', '02', '275', '10', '2041', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15252, to_date('03-10-2041', 'dd-mm-yyyy'), '4', '03', '276', '10', '2041', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15253, to_date('04-10-2041', 'dd-mm-yyyy'), '5', '04', '277', '10', '2041', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15254, to_date('05-10-2041', 'dd-mm-yyyy'), '6', '05', '278', '10', '2041', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15255, to_date('06-10-2041', 'dd-mm-yyyy'), '7', '06', '279', '10', '2041', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15256, to_date('07-10-2041', 'dd-mm-yyyy'), '1', '07', '280', '10', '2041', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15257, to_date('08-10-2041', 'dd-mm-yyyy'), '2', '08', '281', '10', '2041', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15258, to_date('09-10-2041', 'dd-mm-yyyy'), '3', '09', '282', '10', '2041', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15259, to_date('10-10-2041', 'dd-mm-yyyy'), '4', '10', '283', '10', '2041', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15260, to_date('11-10-2041', 'dd-mm-yyyy'), '5', '11', '284', '10', '2041', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15261, to_date('12-10-2041', 'dd-mm-yyyy'), '6', '12', '285', '10', '2041', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15262, to_date('13-10-2041', 'dd-mm-yyyy'), '7', '13', '286', '10', '2041', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15263, to_date('14-10-2041', 'dd-mm-yyyy'), '1', '14', '287', '10', '2041', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15264, to_date('15-10-2041', 'dd-mm-yyyy'), '2', '15', '288', '10', '2041', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15265, to_date('16-10-2041', 'dd-mm-yyyy'), '3', '16', '289', '10', '2041', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15266, to_date('17-10-2041', 'dd-mm-yyyy'), '4', '17', '290', '10', '2041', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15267, to_date('18-10-2041', 'dd-mm-yyyy'), '5', '18', '291', '10', '2041', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15268, to_date('19-10-2041', 'dd-mm-yyyy'), '6', '19', '292', '10', '2041', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15269, to_date('20-10-2041', 'dd-mm-yyyy'), '7', '20', '293', '10', '2041', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15270, to_date('21-10-2041', 'dd-mm-yyyy'), '1', '21', '294', '10', '2041', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15271, to_date('22-10-2041', 'dd-mm-yyyy'), '2', '22', '295', '10', '2041', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15272, to_date('23-10-2041', 'dd-mm-yyyy'), '3', '23', '296', '10', '2041', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15273, to_date('24-10-2041', 'dd-mm-yyyy'), '4', '24', '297', '10', '2041', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15274, to_date('25-10-2041', 'dd-mm-yyyy'), '5', '25', '298', '10', '2041', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15275, to_date('26-10-2041', 'dd-mm-yyyy'), '6', '26', '299', '10', '2041', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15276, to_date('27-10-2041', 'dd-mm-yyyy'), '7', '27', '300', '10', '2041', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15277, to_date('28-10-2041', 'dd-mm-yyyy'), '1', '28', '301', '10', '2041', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15278, to_date('29-10-2041', 'dd-mm-yyyy'), '2', '29', '302', '10', '2041', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15279, to_date('30-10-2041', 'dd-mm-yyyy'), '3', '30', '303', '10', '2041', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15280, to_date('31-10-2041', 'dd-mm-yyyy'), '4', '31', '304', '10', '2041', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15281, to_date('01-11-2041', 'dd-mm-yyyy'), '5', '01', '305', '11', '2041', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15282, to_date('02-11-2041', 'dd-mm-yyyy'), '6', '02', '306', '11', '2041', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15283, to_date('03-11-2041', 'dd-mm-yyyy'), '7', '03', '307', '11', '2041', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15284, to_date('04-11-2041', 'dd-mm-yyyy'), '1', '04', '308', '11', '2041', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15285, to_date('05-11-2041', 'dd-mm-yyyy'), '2', '05', '309', '11', '2041', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15286, to_date('06-11-2041', 'dd-mm-yyyy'), '3', '06', '310', '11', '2041', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15287, to_date('07-11-2041', 'dd-mm-yyyy'), '4', '07', '311', '11', '2041', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15288, to_date('08-11-2041', 'dd-mm-yyyy'), '5', '08', '312', '11', '2041', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15289, to_date('09-11-2041', 'dd-mm-yyyy'), '6', '09', '313', '11', '2041', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15290, to_date('10-11-2041', 'dd-mm-yyyy'), '7', '10', '314', '11', '2041', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15291, to_date('11-11-2041', 'dd-mm-yyyy'), '1', '11', '315', '11', '2041', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15292, to_date('12-11-2041', 'dd-mm-yyyy'), '2', '12', '316', '11', '2041', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15293, to_date('13-11-2041', 'dd-mm-yyyy'), '3', '13', '317', '11', '2041', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15294, to_date('14-11-2041', 'dd-mm-yyyy'), '4', '14', '318', '11', '2041', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15295, to_date('15-11-2041', 'dd-mm-yyyy'), '5', '15', '319', '11', '2041', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15296, to_date('16-11-2041', 'dd-mm-yyyy'), '6', '16', '320', '11', '2041', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15297, to_date('17-11-2041', 'dd-mm-yyyy'), '7', '17', '321', '11', '2041', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15298, to_date('18-11-2041', 'dd-mm-yyyy'), '1', '18', '322', '11', '2041', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15299, to_date('19-11-2041', 'dd-mm-yyyy'), '2', '19', '323', '11', '2041', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15300, to_date('20-11-2041', 'dd-mm-yyyy'), '3', '20', '324', '11', '2041', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15301, to_date('21-11-2041', 'dd-mm-yyyy'), '4', '21', '325', '11', '2041', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15302, to_date('22-11-2041', 'dd-mm-yyyy'), '5', '22', '326', '11', '2041', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15303, to_date('23-11-2041', 'dd-mm-yyyy'), '6', '23', '327', '11', '2041', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15304, to_date('24-11-2041', 'dd-mm-yyyy'), '7', '24', '328', '11', '2041', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15305, to_date('25-11-2041', 'dd-mm-yyyy'), '1', '25', '329', '11', '2041', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15306, to_date('26-11-2041', 'dd-mm-yyyy'), '2', '26', '330', '11', '2041', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15307, to_date('27-11-2041', 'dd-mm-yyyy'), '3', '27', '331', '11', '2041', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15308, to_date('28-11-2041', 'dd-mm-yyyy'), '4', '28', '332', '11', '2041', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15309, to_date('29-11-2041', 'dd-mm-yyyy'), '5', '29', '333', '11', '2041', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15310, to_date('30-11-2041', 'dd-mm-yyyy'), '6', '30', '334', '11', '2041', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15311, to_date('01-12-2041', 'dd-mm-yyyy'), '7', '01', '335', '12', '2041', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15312, to_date('02-12-2041', 'dd-mm-yyyy'), '1', '02', '336', '12', '2041', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15313, to_date('03-12-2041', 'dd-mm-yyyy'), '2', '03', '337', '12', '2041', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15314, to_date('04-12-2041', 'dd-mm-yyyy'), '3', '04', '338', '12', '2041', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15315, to_date('05-12-2041', 'dd-mm-yyyy'), '4', '05', '339', '12', '2041', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15316, to_date('06-12-2041', 'dd-mm-yyyy'), '5', '06', '340', '12', '2041', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15317, to_date('07-12-2041', 'dd-mm-yyyy'), '6', '07', '341', '12', '2041', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15318, to_date('08-12-2041', 'dd-mm-yyyy'), '7', '08', '342', '12', '2041', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15319, to_date('09-12-2041', 'dd-mm-yyyy'), '1', '09', '343', '12', '2041', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15320, to_date('10-12-2041', 'dd-mm-yyyy'), '2', '10', '344', '12', '2041', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15321, to_date('11-12-2041', 'dd-mm-yyyy'), '3', '11', '345', '12', '2041', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15322, to_date('12-12-2041', 'dd-mm-yyyy'), '4', '12', '346', '12', '2041', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15323, to_date('13-12-2041', 'dd-mm-yyyy'), '5', '13', '347', '12', '2041', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15324, to_date('14-12-2041', 'dd-mm-yyyy'), '6', '14', '348', '12', '2041', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15325, to_date('15-12-2041', 'dd-mm-yyyy'), '7', '15', '349', '12', '2041', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15326, to_date('16-12-2041', 'dd-mm-yyyy'), '1', '16', '350', '12', '2041', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15327, to_date('17-12-2041', 'dd-mm-yyyy'), '2', '17', '351', '12', '2041', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15328, to_date('18-12-2041', 'dd-mm-yyyy'), '3', '18', '352', '12', '2041', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15329, to_date('19-12-2041', 'dd-mm-yyyy'), '4', '19', '353', '12', '2041', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15330, to_date('20-12-2041', 'dd-mm-yyyy'), '5', '20', '354', '12', '2041', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15331, to_date('21-12-2041', 'dd-mm-yyyy'), '6', '21', '355', '12', '2041', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15332, to_date('22-12-2041', 'dd-mm-yyyy'), '7', '22', '356', '12', '2041', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15333, to_date('23-12-2041', 'dd-mm-yyyy'), '1', '23', '357', '12', '2041', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15334, to_date('24-12-2041', 'dd-mm-yyyy'), '2', '24', '358', '12', '2041', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15335, to_date('25-12-2041', 'dd-mm-yyyy'), '3', '25', '359', '12', '2041', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15336, to_date('26-12-2041', 'dd-mm-yyyy'), '4', '26', '360', '12', '2041', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15337, to_date('27-12-2041', 'dd-mm-yyyy'), '5', '27', '361', '12', '2041', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15338, to_date('28-12-2041', 'dd-mm-yyyy'), '6', '28', '362', '12', '2041', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15339, to_date('29-12-2041', 'dd-mm-yyyy'), '7', '29', '363', '12', '2041', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15340, to_date('30-12-2041', 'dd-mm-yyyy'), '1', '30', '364', '12', '2041', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15341, to_date('31-12-2041', 'dd-mm-yyyy'), '2', '31', '365', '12', '2041', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15342, to_date('01-01-2042', 'dd-mm-yyyy'), '3', '01', '001', '01', '2042', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15343, to_date('02-01-2042', 'dd-mm-yyyy'), '4', '02', '002', '01', '2042', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15344, to_date('03-01-2042', 'dd-mm-yyyy'), '5', '03', '003', '01', '2042', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16829, to_date('27-01-2046', 'dd-mm-yyyy'), '6', '27', '027', '01', '2046', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16830, to_date('28-01-2046', 'dd-mm-yyyy'), '7', '28', '028', '01', '2046', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16831, to_date('29-01-2046', 'dd-mm-yyyy'), '1', '29', '029', '01', '2046', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16832, to_date('30-01-2046', 'dd-mm-yyyy'), '2', '30', '030', '01', '2046', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16833, to_date('31-01-2046', 'dd-mm-yyyy'), '3', '31', '031', '01', '2046', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16834, to_date('01-02-2046', 'dd-mm-yyyy'), '4', '01', '032', '02', '2046', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16835, to_date('02-02-2046', 'dd-mm-yyyy'), '5', '02', '033', '02', '2046', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16836, to_date('03-02-2046', 'dd-mm-yyyy'), '6', '03', '034', '02', '2046', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16837, to_date('04-02-2046', 'dd-mm-yyyy'), '7', '04', '035', '02', '2046', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16838, to_date('05-02-2046', 'dd-mm-yyyy'), '1', '05', '036', '02', '2046', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16839, to_date('06-02-2046', 'dd-mm-yyyy'), '2', '06', '037', '02', '2046', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16840, to_date('07-02-2046', 'dd-mm-yyyy'), '3', '07', '038', '02', '2046', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16841, to_date('08-02-2046', 'dd-mm-yyyy'), '4', '08', '039', '02', '2046', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16842, to_date('09-02-2046', 'dd-mm-yyyy'), '5', '09', '040', '02', '2046', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16843, to_date('10-02-2046', 'dd-mm-yyyy'), '6', '10', '041', '02', '2046', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16844, to_date('11-02-2046', 'dd-mm-yyyy'), '7', '11', '042', '02', '2046', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16845, to_date('12-02-2046', 'dd-mm-yyyy'), '1', '12', '043', '02', '2046', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16846, to_date('13-02-2046', 'dd-mm-yyyy'), '2', '13', '044', '02', '2046', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16847, to_date('14-02-2046', 'dd-mm-yyyy'), '3', '14', '045', '02', '2046', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16848, to_date('15-02-2046', 'dd-mm-yyyy'), '4', '15', '046', '02', '2046', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16849, to_date('16-02-2046', 'dd-mm-yyyy'), '5', '16', '047', '02', '2046', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16850, to_date('17-02-2046', 'dd-mm-yyyy'), '6', '17', '048', '02', '2046', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16851, to_date('18-02-2046', 'dd-mm-yyyy'), '7', '18', '049', '02', '2046', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16852, to_date('19-02-2046', 'dd-mm-yyyy'), '1', '19', '050', '02', '2046', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16853, to_date('20-02-2046', 'dd-mm-yyyy'), '2', '20', '051', '02', '2046', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16854, to_date('21-02-2046', 'dd-mm-yyyy'), '3', '21', '052', '02', '2046', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16855, to_date('22-02-2046', 'dd-mm-yyyy'), '4', '22', '053', '02', '2046', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16856, to_date('23-02-2046', 'dd-mm-yyyy'), '5', '23', '054', '02', '2046', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16857, to_date('24-02-2046', 'dd-mm-yyyy'), '6', '24', '055', '02', '2046', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16858, to_date('25-02-2046', 'dd-mm-yyyy'), '7', '25', '056', '02', '2046', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16859, to_date('26-02-2046', 'dd-mm-yyyy'), '1', '26', '057', '02', '2046', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16860, to_date('27-02-2046', 'dd-mm-yyyy'), '2', '27', '058', '02', '2046', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16861, to_date('28-02-2046', 'dd-mm-yyyy'), '3', '28', '059', '02', '2046', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16862, to_date('01-03-2046', 'dd-mm-yyyy'), '4', '01', '060', '03', '2046', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16863, to_date('02-03-2046', 'dd-mm-yyyy'), '5', '02', '061', '03', '2046', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16864, to_date('03-03-2046', 'dd-mm-yyyy'), '6', '03', '062', '03', '2046', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16865, to_date('04-03-2046', 'dd-mm-yyyy'), '7', '04', '063', '03', '2046', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16866, to_date('05-03-2046', 'dd-mm-yyyy'), '1', '05', '064', '03', '2046', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16867, to_date('06-03-2046', 'dd-mm-yyyy'), '2', '06', '065', '03', '2046', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16868, to_date('07-03-2046', 'dd-mm-yyyy'), '3', '07', '066', '03', '2046', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16869, to_date('08-03-2046', 'dd-mm-yyyy'), '4', '08', '067', '03', '2046', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16870, to_date('09-03-2046', 'dd-mm-yyyy'), '5', '09', '068', '03', '2046', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16871, to_date('10-03-2046', 'dd-mm-yyyy'), '6', '10', '069', '03', '2046', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16872, to_date('11-03-2046', 'dd-mm-yyyy'), '7', '11', '070', '03', '2046', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16873, to_date('12-03-2046', 'dd-mm-yyyy'), '1', '12', '071', '03', '2046', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16874, to_date('13-03-2046', 'dd-mm-yyyy'), '2', '13', '072', '03', '2046', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16875, to_date('14-03-2046', 'dd-mm-yyyy'), '3', '14', '073', '03', '2046', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16876, to_date('15-03-2046', 'dd-mm-yyyy'), '4', '15', '074', '03', '2046', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16877, to_date('16-03-2046', 'dd-mm-yyyy'), '5', '16', '075', '03', '2046', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16878, to_date('17-03-2046', 'dd-mm-yyyy'), '6', '17', '076', '03', '2046', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16879, to_date('18-03-2046', 'dd-mm-yyyy'), '7', '18', '077', '03', '2046', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16880, to_date('19-03-2046', 'dd-mm-yyyy'), '1', '19', '078', '03', '2046', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16881, to_date('20-03-2046', 'dd-mm-yyyy'), '2', '20', '079', '03', '2046', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16882, to_date('21-03-2046', 'dd-mm-yyyy'), '3', '21', '080', '03', '2046', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16883, to_date('22-03-2046', 'dd-mm-yyyy'), '4', '22', '081', '03', '2046', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16884, to_date('23-03-2046', 'dd-mm-yyyy'), '5', '23', '082', '03', '2046', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16885, to_date('24-03-2046', 'dd-mm-yyyy'), '6', '24', '083', '03', '2046', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16886, to_date('25-03-2046', 'dd-mm-yyyy'), '7', '25', '084', '03', '2046', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16887, to_date('26-03-2046', 'dd-mm-yyyy'), '1', '26', '085', '03', '2046', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16888, to_date('27-03-2046', 'dd-mm-yyyy'), '2', '27', '086', '03', '2046', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16889, to_date('28-03-2046', 'dd-mm-yyyy'), '3', '28', '087', '03', '2046', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16890, to_date('29-03-2046', 'dd-mm-yyyy'), '4', '29', '088', '03', '2046', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16891, to_date('30-03-2046', 'dd-mm-yyyy'), '5', '30', '089', '03', '2046', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16892, to_date('31-03-2046', 'dd-mm-yyyy'), '6', '31', '090', '03', '2046', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16893, to_date('01-04-2046', 'dd-mm-yyyy'), '7', '01', '091', '04', '2046', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16894, to_date('02-04-2046', 'dd-mm-yyyy'), '1', '02', '092', '04', '2046', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16895, to_date('03-04-2046', 'dd-mm-yyyy'), '2', '03', '093', '04', '2046', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16896, to_date('04-04-2046', 'dd-mm-yyyy'), '3', '04', '094', '04', '2046', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16897, to_date('05-04-2046', 'dd-mm-yyyy'), '4', '05', '095', '04', '2046', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16898, to_date('06-04-2046', 'dd-mm-yyyy'), '5', '06', '096', '04', '2046', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16899, to_date('07-04-2046', 'dd-mm-yyyy'), '6', '07', '097', '04', '2046', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16900, to_date('08-04-2046', 'dd-mm-yyyy'), '7', '08', '098', '04', '2046', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16901, to_date('09-04-2046', 'dd-mm-yyyy'), '1', '09', '099', '04', '2046', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16902, to_date('10-04-2046', 'dd-mm-yyyy'), '2', '10', '100', '04', '2046', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16903, to_date('11-04-2046', 'dd-mm-yyyy'), '3', '11', '101', '04', '2046', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16904, to_date('12-04-2046', 'dd-mm-yyyy'), '4', '12', '102', '04', '2046', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16905, to_date('13-04-2046', 'dd-mm-yyyy'), '5', '13', '103', '04', '2046', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16906, to_date('14-04-2046', 'dd-mm-yyyy'), '6', '14', '104', '04', '2046', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16907, to_date('15-04-2046', 'dd-mm-yyyy'), '7', '15', '105', '04', '2046', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16908, to_date('16-04-2046', 'dd-mm-yyyy'), '1', '16', '106', '04', '2046', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16909, to_date('17-04-2046', 'dd-mm-yyyy'), '2', '17', '107', '04', '2046', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16910, to_date('18-04-2046', 'dd-mm-yyyy'), '3', '18', '108', '04', '2046', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16911, to_date('19-04-2046', 'dd-mm-yyyy'), '4', '19', '109', '04', '2046', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16912, to_date('20-04-2046', 'dd-mm-yyyy'), '5', '20', '110', '04', '2046', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16913, to_date('21-04-2046', 'dd-mm-yyyy'), '6', '21', '111', '04', '2046', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16914, to_date('22-04-2046', 'dd-mm-yyyy'), '7', '22', '112', '04', '2046', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16915, to_date('23-04-2046', 'dd-mm-yyyy'), '1', '23', '113', '04', '2046', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16916, to_date('24-04-2046', 'dd-mm-yyyy'), '2', '24', '114', '04', '2046', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16917, to_date('25-04-2046', 'dd-mm-yyyy'), '3', '25', '115', '04', '2046', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16918, to_date('26-04-2046', 'dd-mm-yyyy'), '4', '26', '116', '04', '2046', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16919, to_date('27-04-2046', 'dd-mm-yyyy'), '5', '27', '117', '04', '2046', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16920, to_date('28-04-2046', 'dd-mm-yyyy'), '6', '28', '118', '04', '2046', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16921, to_date('29-04-2046', 'dd-mm-yyyy'), '7', '29', '119', '04', '2046', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16922, to_date('30-04-2046', 'dd-mm-yyyy'), '1', '30', '120', '04', '2046', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16923, to_date('01-05-2046', 'dd-mm-yyyy'), '2', '01', '121', '05', '2046', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16924, to_date('02-05-2046', 'dd-mm-yyyy'), '3', '02', '122', '05', '2046', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16925, to_date('03-05-2046', 'dd-mm-yyyy'), '4', '03', '123', '05', '2046', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16926, to_date('04-05-2046', 'dd-mm-yyyy'), '5', '04', '124', '05', '2046', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16927, to_date('05-05-2046', 'dd-mm-yyyy'), '6', '05', '125', '05', '2046', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16928, to_date('06-05-2046', 'dd-mm-yyyy'), '7', '06', '126', '05', '2046', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16929, to_date('07-05-2046', 'dd-mm-yyyy'), '1', '07', '127', '05', '2046', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16930, to_date('08-05-2046', 'dd-mm-yyyy'), '2', '08', '128', '05', '2046', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16931, to_date('09-05-2046', 'dd-mm-yyyy'), '3', '09', '129', '05', '2046', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16932, to_date('10-05-2046', 'dd-mm-yyyy'), '4', '10', '130', '05', '2046', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16933, to_date('11-05-2046', 'dd-mm-yyyy'), '5', '11', '131', '05', '2046', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16934, to_date('12-05-2046', 'dd-mm-yyyy'), '6', '12', '132', '05', '2046', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18419, to_date('05-06-2050', 'dd-mm-yyyy'), '7', '05', '156', '06', '2050', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18420, to_date('06-06-2050', 'dd-mm-yyyy'), '1', '06', '157', '06', '2050', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18421, to_date('07-06-2050', 'dd-mm-yyyy'), '2', '07', '158', '06', '2050', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18422, to_date('08-06-2050', 'dd-mm-yyyy'), '3', '08', '159', '06', '2050', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18423, to_date('09-06-2050', 'dd-mm-yyyy'), '4', '09', '160', '06', '2050', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18424, to_date('10-06-2050', 'dd-mm-yyyy'), '5', '10', '161', '06', '2050', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18425, to_date('11-06-2050', 'dd-mm-yyyy'), '6', '11', '162', '06', '2050', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18426, to_date('12-06-2050', 'dd-mm-yyyy'), '7', '12', '163', '06', '2050', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18427, to_date('13-06-2050', 'dd-mm-yyyy'), '1', '13', '164', '06', '2050', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18428, to_date('14-06-2050', 'dd-mm-yyyy'), '2', '14', '165', '06', '2050', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18429, to_date('15-06-2050', 'dd-mm-yyyy'), '3', '15', '166', '06', '2050', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18430, to_date('16-06-2050', 'dd-mm-yyyy'), '4', '16', '167', '06', '2050', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18431, to_date('17-06-2050', 'dd-mm-yyyy'), '5', '17', '168', '06', '2050', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18432, to_date('18-06-2050', 'dd-mm-yyyy'), '6', '18', '169', '06', '2050', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18433, to_date('19-06-2050', 'dd-mm-yyyy'), '7', '19', '170', '06', '2050', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18434, to_date('20-06-2050', 'dd-mm-yyyy'), '1', '20', '171', '06', '2050', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18435, to_date('21-06-2050', 'dd-mm-yyyy'), '2', '21', '172', '06', '2050', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18436, to_date('22-06-2050', 'dd-mm-yyyy'), '3', '22', '173', '06', '2050', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18437, to_date('23-06-2050', 'dd-mm-yyyy'), '4', '23', '174', '06', '2050', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18438, to_date('24-06-2050', 'dd-mm-yyyy'), '5', '24', '175', '06', '2050', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18439, to_date('25-06-2050', 'dd-mm-yyyy'), '6', '25', '176', '06', '2050', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18440, to_date('26-06-2050', 'dd-mm-yyyy'), '7', '26', '177', '06', '2050', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18441, to_date('27-06-2050', 'dd-mm-yyyy'), '1', '27', '178', '06', '2050', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18442, to_date('28-06-2050', 'dd-mm-yyyy'), '2', '28', '179', '06', '2050', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18443, to_date('29-06-2050', 'dd-mm-yyyy'), '3', '29', '180', '06', '2050', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18444, to_date('30-06-2050', 'dd-mm-yyyy'), '4', '30', '181', '06', '2050', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18445, to_date('01-07-2050', 'dd-mm-yyyy'), '5', '01', '182', '07', '2050', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18446, to_date('02-07-2050', 'dd-mm-yyyy'), '6', '02', '183', '07', '2050', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18447, to_date('03-07-2050', 'dd-mm-yyyy'), '7', '03', '184', '07', '2050', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18448, to_date('04-07-2050', 'dd-mm-yyyy'), '1', '04', '185', '07', '2050', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18449, to_date('05-07-2050', 'dd-mm-yyyy'), '2', '05', '186', '07', '2050', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18450, to_date('06-07-2050', 'dd-mm-yyyy'), '3', '06', '187', '07', '2050', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18451, to_date('07-07-2050', 'dd-mm-yyyy'), '4', '07', '188', '07', '2050', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18452, to_date('08-07-2050', 'dd-mm-yyyy'), '5', '08', '189', '07', '2050', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18453, to_date('09-07-2050', 'dd-mm-yyyy'), '6', '09', '190', '07', '2050', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18454, to_date('10-07-2050', 'dd-mm-yyyy'), '7', '10', '191', '07', '2050', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18455, to_date('11-07-2050', 'dd-mm-yyyy'), '1', '11', '192', '07', '2050', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18456, to_date('12-07-2050', 'dd-mm-yyyy'), '2', '12', '193', '07', '2050', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18457, to_date('13-07-2050', 'dd-mm-yyyy'), '3', '13', '194', '07', '2050', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18458, to_date('14-07-2050', 'dd-mm-yyyy'), '4', '14', '195', '07', '2050', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18459, to_date('15-07-2050', 'dd-mm-yyyy'), '5', '15', '196', '07', '2050', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18460, to_date('16-07-2050', 'dd-mm-yyyy'), '6', '16', '197', '07', '2050', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18461, to_date('17-07-2050', 'dd-mm-yyyy'), '7', '17', '198', '07', '2050', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18462, to_date('18-07-2050', 'dd-mm-yyyy'), '1', '18', '199', '07', '2050', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18463, to_date('19-07-2050', 'dd-mm-yyyy'), '2', '19', '200', '07', '2050', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18464, to_date('20-07-2050', 'dd-mm-yyyy'), '3', '20', '201', '07', '2050', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18465, to_date('21-07-2050', 'dd-mm-yyyy'), '4', '21', '202', '07', '2050', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18466, to_date('22-07-2050', 'dd-mm-yyyy'), '5', '22', '203', '07', '2050', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18467, to_date('23-07-2050', 'dd-mm-yyyy'), '6', '23', '204', '07', '2050', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18468, to_date('24-07-2050', 'dd-mm-yyyy'), '7', '24', '205', '07', '2050', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18469, to_date('25-07-2050', 'dd-mm-yyyy'), '1', '25', '206', '07', '2050', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18470, to_date('26-07-2050', 'dd-mm-yyyy'), '2', '26', '207', '07', '2050', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18471, to_date('27-07-2050', 'dd-mm-yyyy'), '3', '27', '208', '07', '2050', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18472, to_date('28-07-2050', 'dd-mm-yyyy'), '4', '28', '209', '07', '2050', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18473, to_date('29-07-2050', 'dd-mm-yyyy'), '5', '29', '210', '07', '2050', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18474, to_date('30-07-2050', 'dd-mm-yyyy'), '6', '30', '211', '07', '2050', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18475, to_date('31-07-2050', 'dd-mm-yyyy'), '7', '31', '212', '07', '2050', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18476, to_date('01-08-2050', 'dd-mm-yyyy'), '1', '01', '213', '08', '2050', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18477, to_date('02-08-2050', 'dd-mm-yyyy'), '2', '02', '214', '08', '2050', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18478, to_date('03-08-2050', 'dd-mm-yyyy'), '3', '03', '215', '08', '2050', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18479, to_date('04-08-2050', 'dd-mm-yyyy'), '4', '04', '216', '08', '2050', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18480, to_date('05-08-2050', 'dd-mm-yyyy'), '5', '05', '217', '08', '2050', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18481, to_date('06-08-2050', 'dd-mm-yyyy'), '6', '06', '218', '08', '2050', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18482, to_date('07-08-2050', 'dd-mm-yyyy'), '7', '07', '219', '08', '2050', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18483, to_date('08-08-2050', 'dd-mm-yyyy'), '1', '08', '220', '08', '2050', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18484, to_date('09-08-2050', 'dd-mm-yyyy'), '2', '09', '221', '08', '2050', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18485, to_date('10-08-2050', 'dd-mm-yyyy'), '3', '10', '222', '08', '2050', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18486, to_date('11-08-2050', 'dd-mm-yyyy'), '4', '11', '223', '08', '2050', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18487, to_date('12-08-2050', 'dd-mm-yyyy'), '5', '12', '224', '08', '2050', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18488, to_date('13-08-2050', 'dd-mm-yyyy'), '6', '13', '225', '08', '2050', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18489, to_date('14-08-2050', 'dd-mm-yyyy'), '7', '14', '226', '08', '2050', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18490, to_date('15-08-2050', 'dd-mm-yyyy'), '1', '15', '227', '08', '2050', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18491, to_date('16-08-2050', 'dd-mm-yyyy'), '2', '16', '228', '08', '2050', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18492, to_date('17-08-2050', 'dd-mm-yyyy'), '3', '17', '229', '08', '2050', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18493, to_date('18-08-2050', 'dd-mm-yyyy'), '4', '18', '230', '08', '2050', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18494, to_date('19-08-2050', 'dd-mm-yyyy'), '5', '19', '231', '08', '2050', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18495, to_date('20-08-2050', 'dd-mm-yyyy'), '6', '20', '232', '08', '2050', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18496, to_date('21-08-2050', 'dd-mm-yyyy'), '7', '21', '233', '08', '2050', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18497, to_date('22-08-2050', 'dd-mm-yyyy'), '1', '22', '234', '08', '2050', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18498, to_date('23-08-2050', 'dd-mm-yyyy'), '2', '23', '235', '08', '2050', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18499, to_date('24-08-2050', 'dd-mm-yyyy'), '3', '24', '236', '08', '2050', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18500, to_date('25-08-2050', 'dd-mm-yyyy'), '4', '25', '237', '08', '2050', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18501, to_date('26-08-2050', 'dd-mm-yyyy'), '5', '26', '238', '08', '2050', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18502, to_date('27-08-2050', 'dd-mm-yyyy'), '6', '27', '239', '08', '2050', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18503, to_date('28-08-2050', 'dd-mm-yyyy'), '7', '28', '240', '08', '2050', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18504, to_date('29-08-2050', 'dd-mm-yyyy'), '1', '29', '241', '08', '2050', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18505, to_date('30-08-2050', 'dd-mm-yyyy'), '2', '30', '242', '08', '2050', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18506, to_date('31-08-2050', 'dd-mm-yyyy'), '3', '31', '243', '08', '2050', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18507, to_date('01-09-2050', 'dd-mm-yyyy'), '4', '01', '244', '09', '2050', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18508, to_date('02-09-2050', 'dd-mm-yyyy'), '5', '02', '245', '09', '2050', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18509, to_date('03-09-2050', 'dd-mm-yyyy'), '6', '03', '246', '09', '2050', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18510, to_date('04-09-2050', 'dd-mm-yyyy'), '7', '04', '247', '09', '2050', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18511, to_date('05-09-2050', 'dd-mm-yyyy'), '1', '05', '248', '09', '2050', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18512, to_date('06-09-2050', 'dd-mm-yyyy'), '2', '06', '249', '09', '2050', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18513, to_date('07-09-2050', 'dd-mm-yyyy'), '3', '07', '250', '09', '2050', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18514, to_date('08-09-2050', 'dd-mm-yyyy'), '4', '08', '251', '09', '2050', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18515, to_date('09-09-2050', 'dd-mm-yyyy'), '5', '09', '252', '09', '2050', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18516, to_date('10-09-2050', 'dd-mm-yyyy'), '6', '10', '253', '09', '2050', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18517, to_date('11-09-2050', 'dd-mm-yyyy'), '7', '11', '254', '09', '2050', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18518, to_date('12-09-2050', 'dd-mm-yyyy'), '1', '12', '255', '09', '2050', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18519, to_date('13-09-2050', 'dd-mm-yyyy'), '2', '13', '256', '09', '2050', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18520, to_date('14-09-2050', 'dd-mm-yyyy'), '3', '14', '257', '09', '2050', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18521, to_date('15-09-2050', 'dd-mm-yyyy'), '4', '15', '258', '09', '2050', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18522, to_date('16-09-2050', 'dd-mm-yyyy'), '5', '16', '259', '09', '2050', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18523, to_date('17-09-2050', 'dd-mm-yyyy'), '6', '17', '260', '09', '2050', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18524, to_date('18-09-2050', 'dd-mm-yyyy'), '7', '18', '261', '09', '2050', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13649, to_date('14-05-2037', 'dd-mm-yyyy'), '4', '14', '134', '05', '2037', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13650, to_date('15-05-2037', 'dd-mm-yyyy'), '5', '15', '135', '05', '2037', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13651, to_date('16-05-2037', 'dd-mm-yyyy'), '6', '16', '136', '05', '2037', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13652, to_date('17-05-2037', 'dd-mm-yyyy'), '7', '17', '137', '05', '2037', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13653, to_date('18-05-2037', 'dd-mm-yyyy'), '1', '18', '138', '05', '2037', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13654, to_date('19-05-2037', 'dd-mm-yyyy'), '2', '19', '139', '05', '2037', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13655, to_date('20-05-2037', 'dd-mm-yyyy'), '3', '20', '140', '05', '2037', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13656, to_date('21-05-2037', 'dd-mm-yyyy'), '4', '21', '141', '05', '2037', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13657, to_date('22-05-2037', 'dd-mm-yyyy'), '5', '22', '142', '05', '2037', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13658, to_date('23-05-2037', 'dd-mm-yyyy'), '6', '23', '143', '05', '2037', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13659, to_date('24-05-2037', 'dd-mm-yyyy'), '7', '24', '144', '05', '2037', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13660, to_date('25-05-2037', 'dd-mm-yyyy'), '1', '25', '145', '05', '2037', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13661, to_date('26-05-2037', 'dd-mm-yyyy'), '2', '26', '146', '05', '2037', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13662, to_date('27-05-2037', 'dd-mm-yyyy'), '3', '27', '147', '05', '2037', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13663, to_date('28-05-2037', 'dd-mm-yyyy'), '4', '28', '148', '05', '2037', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13664, to_date('29-05-2037', 'dd-mm-yyyy'), '5', '29', '149', '05', '2037', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13665, to_date('30-05-2037', 'dd-mm-yyyy'), '6', '30', '150', '05', '2037', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13666, to_date('31-05-2037', 'dd-mm-yyyy'), '7', '31', '151', '05', '2037', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13667, to_date('01-06-2037', 'dd-mm-yyyy'), '1', '01', '152', '06', '2037', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13668, to_date('02-06-2037', 'dd-mm-yyyy'), '2', '02', '153', '06', '2037', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13669, to_date('03-06-2037', 'dd-mm-yyyy'), '3', '03', '154', '06', '2037', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13670, to_date('04-06-2037', 'dd-mm-yyyy'), '4', '04', '155', '06', '2037', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13671, to_date('05-06-2037', 'dd-mm-yyyy'), '5', '05', '156', '06', '2037', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13672, to_date('06-06-2037', 'dd-mm-yyyy'), '6', '06', '157', '06', '2037', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13673, to_date('07-06-2037', 'dd-mm-yyyy'), '7', '07', '158', '06', '2037', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13674, to_date('08-06-2037', 'dd-mm-yyyy'), '1', '08', '159', '06', '2037', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13675, to_date('09-06-2037', 'dd-mm-yyyy'), '2', '09', '160', '06', '2037', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13676, to_date('10-06-2037', 'dd-mm-yyyy'), '3', '10', '161', '06', '2037', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13677, to_date('11-06-2037', 'dd-mm-yyyy'), '4', '11', '162', '06', '2037', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13678, to_date('12-06-2037', 'dd-mm-yyyy'), '5', '12', '163', '06', '2037', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13679, to_date('13-06-2037', 'dd-mm-yyyy'), '6', '13', '164', '06', '2037', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13680, to_date('14-06-2037', 'dd-mm-yyyy'), '7', '14', '165', '06', '2037', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13681, to_date('15-06-2037', 'dd-mm-yyyy'), '1', '15', '166', '06', '2037', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13682, to_date('16-06-2037', 'dd-mm-yyyy'), '2', '16', '167', '06', '2037', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13683, to_date('17-06-2037', 'dd-mm-yyyy'), '3', '17', '168', '06', '2037', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13684, to_date('18-06-2037', 'dd-mm-yyyy'), '4', '18', '169', '06', '2037', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13685, to_date('19-06-2037', 'dd-mm-yyyy'), '5', '19', '170', '06', '2037', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13686, to_date('20-06-2037', 'dd-mm-yyyy'), '6', '20', '171', '06', '2037', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13687, to_date('21-06-2037', 'dd-mm-yyyy'), '7', '21', '172', '06', '2037', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13688, to_date('22-06-2037', 'dd-mm-yyyy'), '1', '22', '173', '06', '2037', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13689, to_date('23-06-2037', 'dd-mm-yyyy'), '2', '23', '174', '06', '2037', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13690, to_date('24-06-2037', 'dd-mm-yyyy'), '3', '24', '175', '06', '2037', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13691, to_date('25-06-2037', 'dd-mm-yyyy'), '4', '25', '176', '06', '2037', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13692, to_date('26-06-2037', 'dd-mm-yyyy'), '5', '26', '177', '06', '2037', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13693, to_date('27-06-2037', 'dd-mm-yyyy'), '6', '27', '178', '06', '2037', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13694, to_date('28-06-2037', 'dd-mm-yyyy'), '7', '28', '179', '06', '2037', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13695, to_date('29-06-2037', 'dd-mm-yyyy'), '1', '29', '180', '06', '2037', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13696, to_date('30-06-2037', 'dd-mm-yyyy'), '2', '30', '181', '06', '2037', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13697, to_date('01-07-2037', 'dd-mm-yyyy'), '3', '01', '182', '07', '2037', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13698, to_date('02-07-2037', 'dd-mm-yyyy'), '4', '02', '183', '07', '2037', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13699, to_date('03-07-2037', 'dd-mm-yyyy'), '5', '03', '184', '07', '2037', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13700, to_date('04-07-2037', 'dd-mm-yyyy'), '6', '04', '185', '07', '2037', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13701, to_date('05-07-2037', 'dd-mm-yyyy'), '7', '05', '186', '07', '2037', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13702, to_date('06-07-2037', 'dd-mm-yyyy'), '1', '06', '187', '07', '2037', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13703, to_date('07-07-2037', 'dd-mm-yyyy'), '2', '07', '188', '07', '2037', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13704, to_date('08-07-2037', 'dd-mm-yyyy'), '3', '08', '189', '07', '2037', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13705, to_date('09-07-2037', 'dd-mm-yyyy'), '4', '09', '190', '07', '2037', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13706, to_date('10-07-2037', 'dd-mm-yyyy'), '5', '10', '191', '07', '2037', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13707, to_date('11-07-2037', 'dd-mm-yyyy'), '6', '11', '192', '07', '2037', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13708, to_date('12-07-2037', 'dd-mm-yyyy'), '7', '12', '193', '07', '2037', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13709, to_date('13-07-2037', 'dd-mm-yyyy'), '1', '13', '194', '07', '2037', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13710, to_date('14-07-2037', 'dd-mm-yyyy'), '2', '14', '195', '07', '2037', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13711, to_date('15-07-2037', 'dd-mm-yyyy'), '3', '15', '196', '07', '2037', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13712, to_date('16-07-2037', 'dd-mm-yyyy'), '4', '16', '197', '07', '2037', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13713, to_date('17-07-2037', 'dd-mm-yyyy'), '5', '17', '198', '07', '2037', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13714, to_date('18-07-2037', 'dd-mm-yyyy'), '6', '18', '199', '07', '2037', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13715, to_date('19-07-2037', 'dd-mm-yyyy'), '7', '19', '200', '07', '2037', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13716, to_date('20-07-2037', 'dd-mm-yyyy'), '1', '20', '201', '07', '2037', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13717, to_date('21-07-2037', 'dd-mm-yyyy'), '2', '21', '202', '07', '2037', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13718, to_date('22-07-2037', 'dd-mm-yyyy'), '3', '22', '203', '07', '2037', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13719, to_date('23-07-2037', 'dd-mm-yyyy'), '4', '23', '204', '07', '2037', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13720, to_date('24-07-2037', 'dd-mm-yyyy'), '5', '24', '205', '07', '2037', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13721, to_date('25-07-2037', 'dd-mm-yyyy'), '6', '25', '206', '07', '2037', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13722, to_date('26-07-2037', 'dd-mm-yyyy'), '7', '26', '207', '07', '2037', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13723, to_date('27-07-2037', 'dd-mm-yyyy'), '1', '27', '208', '07', '2037', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13724, to_date('28-07-2037', 'dd-mm-yyyy'), '2', '28', '209', '07', '2037', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13725, to_date('29-07-2037', 'dd-mm-yyyy'), '3', '29', '210', '07', '2037', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13726, to_date('30-07-2037', 'dd-mm-yyyy'), '4', '30', '211', '07', '2037', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13727, to_date('31-07-2037', 'dd-mm-yyyy'), '5', '31', '212', '07', '2037', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13728, to_date('01-08-2037', 'dd-mm-yyyy'), '6', '01', '213', '08', '2037', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13729, to_date('02-08-2037', 'dd-mm-yyyy'), '7', '02', '214', '08', '2037', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13730, to_date('03-08-2037', 'dd-mm-yyyy'), '1', '03', '215', '08', '2037', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13731, to_date('04-08-2037', 'dd-mm-yyyy'), '2', '04', '216', '08', '2037', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13732, to_date('05-08-2037', 'dd-mm-yyyy'), '3', '05', '217', '08', '2037', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13733, to_date('06-08-2037', 'dd-mm-yyyy'), '4', '06', '218', '08', '2037', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13734, to_date('07-08-2037', 'dd-mm-yyyy'), '5', '07', '219', '08', '2037', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13735, to_date('08-08-2037', 'dd-mm-yyyy'), '6', '08', '220', '08', '2037', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13736, to_date('09-08-2037', 'dd-mm-yyyy'), '7', '09', '221', '08', '2037', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13737, to_date('10-08-2037', 'dd-mm-yyyy'), '1', '10', '222', '08', '2037', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13738, to_date('11-08-2037', 'dd-mm-yyyy'), '2', '11', '223', '08', '2037', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13739, to_date('12-08-2037', 'dd-mm-yyyy'), '3', '12', '224', '08', '2037', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13740, to_date('13-08-2037', 'dd-mm-yyyy'), '4', '13', '225', '08', '2037', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13741, to_date('14-08-2037', 'dd-mm-yyyy'), '5', '14', '226', '08', '2037', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13742, to_date('15-08-2037', 'dd-mm-yyyy'), '6', '15', '227', '08', '2037', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13743, to_date('16-08-2037', 'dd-mm-yyyy'), '7', '16', '228', '08', '2037', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13744, to_date('17-08-2037', 'dd-mm-yyyy'), '1', '17', '229', '08', '2037', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13745, to_date('18-08-2037', 'dd-mm-yyyy'), '2', '18', '230', '08', '2037', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13746, to_date('19-08-2037', 'dd-mm-yyyy'), '3', '19', '231', '08', '2037', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13747, to_date('20-08-2037', 'dd-mm-yyyy'), '4', '20', '232', '08', '2037', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13748, to_date('21-08-2037', 'dd-mm-yyyy'), '5', '21', '233', '08', '2037', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13749, to_date('22-08-2037', 'dd-mm-yyyy'), '6', '22', '234', '08', '2037', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13750, to_date('23-08-2037', 'dd-mm-yyyy'), '7', '23', '235', '08', '2037', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13751, to_date('24-08-2037', 'dd-mm-yyyy'), '1', '24', '236', '08', '2037', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13752, to_date('25-08-2037', 'dd-mm-yyyy'), '2', '25', '237', '08', '2037', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13753, to_date('26-08-2037', 'dd-mm-yyyy'), '3', '26', '238', '08', '2037', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13754, to_date('27-08-2037', 'dd-mm-yyyy'), '4', '27', '239', '08', '2037', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15345, to_date('04-01-2042', 'dd-mm-yyyy'), '6', '04', '004', '01', '2042', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15346, to_date('05-01-2042', 'dd-mm-yyyy'), '7', '05', '005', '01', '2042', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15347, to_date('06-01-2042', 'dd-mm-yyyy'), '1', '06', '006', '01', '2042', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15348, to_date('07-01-2042', 'dd-mm-yyyy'), '2', '07', '007', '01', '2042', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15349, to_date('08-01-2042', 'dd-mm-yyyy'), '3', '08', '008', '01', '2042', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15350, to_date('09-01-2042', 'dd-mm-yyyy'), '4', '09', '009', '01', '2042', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15351, to_date('10-01-2042', 'dd-mm-yyyy'), '5', '10', '010', '01', '2042', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15352, to_date('11-01-2042', 'dd-mm-yyyy'), '6', '11', '011', '01', '2042', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15353, to_date('12-01-2042', 'dd-mm-yyyy'), '7', '12', '012', '01', '2042', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15354, to_date('13-01-2042', 'dd-mm-yyyy'), '1', '13', '013', '01', '2042', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15355, to_date('14-01-2042', 'dd-mm-yyyy'), '2', '14', '014', '01', '2042', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15356, to_date('15-01-2042', 'dd-mm-yyyy'), '3', '15', '015', '01', '2042', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15357, to_date('16-01-2042', 'dd-mm-yyyy'), '4', '16', '016', '01', '2042', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15358, to_date('17-01-2042', 'dd-mm-yyyy'), '5', '17', '017', '01', '2042', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15359, to_date('18-01-2042', 'dd-mm-yyyy'), '6', '18', '018', '01', '2042', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15360, to_date('19-01-2042', 'dd-mm-yyyy'), '7', '19', '019', '01', '2042', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15361, to_date('20-01-2042', 'dd-mm-yyyy'), '1', '20', '020', '01', '2042', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15362, to_date('21-01-2042', 'dd-mm-yyyy'), '2', '21', '021', '01', '2042', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15363, to_date('22-01-2042', 'dd-mm-yyyy'), '3', '22', '022', '01', '2042', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15364, to_date('23-01-2042', 'dd-mm-yyyy'), '4', '23', '023', '01', '2042', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15365, to_date('24-01-2042', 'dd-mm-yyyy'), '5', '24', '024', '01', '2042', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15366, to_date('25-01-2042', 'dd-mm-yyyy'), '6', '25', '025', '01', '2042', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15367, to_date('26-01-2042', 'dd-mm-yyyy'), '7', '26', '026', '01', '2042', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15368, to_date('27-01-2042', 'dd-mm-yyyy'), '1', '27', '027', '01', '2042', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15369, to_date('28-01-2042', 'dd-mm-yyyy'), '2', '28', '028', '01', '2042', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15370, to_date('29-01-2042', 'dd-mm-yyyy'), '3', '29', '029', '01', '2042', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15371, to_date('30-01-2042', 'dd-mm-yyyy'), '4', '30', '030', '01', '2042', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15372, to_date('31-01-2042', 'dd-mm-yyyy'), '5', '31', '031', '01', '2042', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15373, to_date('01-02-2042', 'dd-mm-yyyy'), '6', '01', '032', '02', '2042', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15374, to_date('02-02-2042', 'dd-mm-yyyy'), '7', '02', '033', '02', '2042', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15375, to_date('03-02-2042', 'dd-mm-yyyy'), '1', '03', '034', '02', '2042', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15376, to_date('04-02-2042', 'dd-mm-yyyy'), '2', '04', '035', '02', '2042', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15377, to_date('05-02-2042', 'dd-mm-yyyy'), '3', '05', '036', '02', '2042', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15378, to_date('06-02-2042', 'dd-mm-yyyy'), '4', '06', '037', '02', '2042', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15379, to_date('07-02-2042', 'dd-mm-yyyy'), '5', '07', '038', '02', '2042', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15380, to_date('08-02-2042', 'dd-mm-yyyy'), '6', '08', '039', '02', '2042', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15381, to_date('09-02-2042', 'dd-mm-yyyy'), '7', '09', '040', '02', '2042', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15382, to_date('10-02-2042', 'dd-mm-yyyy'), '1', '10', '041', '02', '2042', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15383, to_date('11-02-2042', 'dd-mm-yyyy'), '2', '11', '042', '02', '2042', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15384, to_date('12-02-2042', 'dd-mm-yyyy'), '3', '12', '043', '02', '2042', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15385, to_date('13-02-2042', 'dd-mm-yyyy'), '4', '13', '044', '02', '2042', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15386, to_date('14-02-2042', 'dd-mm-yyyy'), '5', '14', '045', '02', '2042', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15387, to_date('15-02-2042', 'dd-mm-yyyy'), '6', '15', '046', '02', '2042', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15388, to_date('16-02-2042', 'dd-mm-yyyy'), '7', '16', '047', '02', '2042', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15389, to_date('17-02-2042', 'dd-mm-yyyy'), '1', '17', '048', '02', '2042', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15390, to_date('18-02-2042', 'dd-mm-yyyy'), '2', '18', '049', '02', '2042', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15391, to_date('19-02-2042', 'dd-mm-yyyy'), '3', '19', '050', '02', '2042', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15392, to_date('20-02-2042', 'dd-mm-yyyy'), '4', '20', '051', '02', '2042', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15393, to_date('21-02-2042', 'dd-mm-yyyy'), '5', '21', '052', '02', '2042', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15394, to_date('22-02-2042', 'dd-mm-yyyy'), '6', '22', '053', '02', '2042', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15395, to_date('23-02-2042', 'dd-mm-yyyy'), '7', '23', '054', '02', '2042', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15396, to_date('24-02-2042', 'dd-mm-yyyy'), '1', '24', '055', '02', '2042', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15397, to_date('25-02-2042', 'dd-mm-yyyy'), '2', '25', '056', '02', '2042', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15398, to_date('26-02-2042', 'dd-mm-yyyy'), '3', '26', '057', '02', '2042', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15399, to_date('27-02-2042', 'dd-mm-yyyy'), '4', '27', '058', '02', '2042', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15400, to_date('28-02-2042', 'dd-mm-yyyy'), '5', '28', '059', '02', '2042', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15401, to_date('01-03-2042', 'dd-mm-yyyy'), '6', '01', '060', '03', '2042', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15402, to_date('02-03-2042', 'dd-mm-yyyy'), '7', '02', '061', '03', '2042', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15403, to_date('03-03-2042', 'dd-mm-yyyy'), '1', '03', '062', '03', '2042', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15404, to_date('04-03-2042', 'dd-mm-yyyy'), '2', '04', '063', '03', '2042', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15405, to_date('05-03-2042', 'dd-mm-yyyy'), '3', '05', '064', '03', '2042', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15406, to_date('06-03-2042', 'dd-mm-yyyy'), '4', '06', '065', '03', '2042', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15407, to_date('07-03-2042', 'dd-mm-yyyy'), '5', '07', '066', '03', '2042', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15408, to_date('08-03-2042', 'dd-mm-yyyy'), '6', '08', '067', '03', '2042', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15409, to_date('09-03-2042', 'dd-mm-yyyy'), '7', '09', '068', '03', '2042', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15410, to_date('10-03-2042', 'dd-mm-yyyy'), '1', '10', '069', '03', '2042', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15411, to_date('11-03-2042', 'dd-mm-yyyy'), '2', '11', '070', '03', '2042', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15412, to_date('12-03-2042', 'dd-mm-yyyy'), '3', '12', '071', '03', '2042', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15413, to_date('13-03-2042', 'dd-mm-yyyy'), '4', '13', '072', '03', '2042', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15414, to_date('14-03-2042', 'dd-mm-yyyy'), '5', '14', '073', '03', '2042', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
commit;
prompt 24000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15415, to_date('15-03-2042', 'dd-mm-yyyy'), '6', '15', '074', '03', '2042', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15416, to_date('16-03-2042', 'dd-mm-yyyy'), '7', '16', '075', '03', '2042', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15417, to_date('17-03-2042', 'dd-mm-yyyy'), '1', '17', '076', '03', '2042', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15418, to_date('18-03-2042', 'dd-mm-yyyy'), '2', '18', '077', '03', '2042', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15419, to_date('19-03-2042', 'dd-mm-yyyy'), '3', '19', '078', '03', '2042', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15420, to_date('20-03-2042', 'dd-mm-yyyy'), '4', '20', '079', '03', '2042', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15421, to_date('21-03-2042', 'dd-mm-yyyy'), '5', '21', '080', '03', '2042', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15422, to_date('22-03-2042', 'dd-mm-yyyy'), '6', '22', '081', '03', '2042', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15423, to_date('23-03-2042', 'dd-mm-yyyy'), '7', '23', '082', '03', '2042', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15424, to_date('24-03-2042', 'dd-mm-yyyy'), '1', '24', '083', '03', '2042', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15425, to_date('25-03-2042', 'dd-mm-yyyy'), '2', '25', '084', '03', '2042', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15426, to_date('26-03-2042', 'dd-mm-yyyy'), '3', '26', '085', '03', '2042', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15427, to_date('27-03-2042', 'dd-mm-yyyy'), '4', '27', '086', '03', '2042', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15428, to_date('28-03-2042', 'dd-mm-yyyy'), '5', '28', '087', '03', '2042', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15429, to_date('29-03-2042', 'dd-mm-yyyy'), '6', '29', '088', '03', '2042', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15430, to_date('30-03-2042', 'dd-mm-yyyy'), '7', '30', '089', '03', '2042', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15431, to_date('31-03-2042', 'dd-mm-yyyy'), '1', '31', '090', '03', '2042', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15432, to_date('01-04-2042', 'dd-mm-yyyy'), '2', '01', '091', '04', '2042', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15433, to_date('02-04-2042', 'dd-mm-yyyy'), '3', '02', '092', '04', '2042', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15434, to_date('03-04-2042', 'dd-mm-yyyy'), '4', '03', '093', '04', '2042', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15435, to_date('04-04-2042', 'dd-mm-yyyy'), '5', '04', '094', '04', '2042', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15436, to_date('05-04-2042', 'dd-mm-yyyy'), '6', '05', '095', '04', '2042', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15437, to_date('06-04-2042', 'dd-mm-yyyy'), '7', '06', '096', '04', '2042', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15438, to_date('07-04-2042', 'dd-mm-yyyy'), '1', '07', '097', '04', '2042', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15439, to_date('08-04-2042', 'dd-mm-yyyy'), '2', '08', '098', '04', '2042', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15440, to_date('09-04-2042', 'dd-mm-yyyy'), '3', '09', '099', '04', '2042', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15441, to_date('10-04-2042', 'dd-mm-yyyy'), '4', '10', '100', '04', '2042', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15442, to_date('11-04-2042', 'dd-mm-yyyy'), '5', '11', '101', '04', '2042', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15443, to_date('12-04-2042', 'dd-mm-yyyy'), '6', '12', '102', '04', '2042', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15444, to_date('13-04-2042', 'dd-mm-yyyy'), '7', '13', '103', '04', '2042', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15445, to_date('14-04-2042', 'dd-mm-yyyy'), '1', '14', '104', '04', '2042', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15446, to_date('15-04-2042', 'dd-mm-yyyy'), '2', '15', '105', '04', '2042', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15447, to_date('16-04-2042', 'dd-mm-yyyy'), '3', '16', '106', '04', '2042', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15448, to_date('17-04-2042', 'dd-mm-yyyy'), '4', '17', '107', '04', '2042', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15449, to_date('18-04-2042', 'dd-mm-yyyy'), '5', '18', '108', '04', '2042', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15450, to_date('19-04-2042', 'dd-mm-yyyy'), '6', '19', '109', '04', '2042', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16935, to_date('13-05-2046', 'dd-mm-yyyy'), '7', '13', '133', '05', '2046', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16936, to_date('14-05-2046', 'dd-mm-yyyy'), '1', '14', '134', '05', '2046', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16937, to_date('15-05-2046', 'dd-mm-yyyy'), '2', '15', '135', '05', '2046', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16938, to_date('16-05-2046', 'dd-mm-yyyy'), '3', '16', '136', '05', '2046', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16939, to_date('17-05-2046', 'dd-mm-yyyy'), '4', '17', '137', '05', '2046', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16940, to_date('18-05-2046', 'dd-mm-yyyy'), '5', '18', '138', '05', '2046', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16941, to_date('19-05-2046', 'dd-mm-yyyy'), '6', '19', '139', '05', '2046', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16942, to_date('20-05-2046', 'dd-mm-yyyy'), '7', '20', '140', '05', '2046', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16943, to_date('21-05-2046', 'dd-mm-yyyy'), '1', '21', '141', '05', '2046', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16944, to_date('22-05-2046', 'dd-mm-yyyy'), '2', '22', '142', '05', '2046', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16945, to_date('23-05-2046', 'dd-mm-yyyy'), '3', '23', '143', '05', '2046', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16946, to_date('24-05-2046', 'dd-mm-yyyy'), '4', '24', '144', '05', '2046', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16947, to_date('25-05-2046', 'dd-mm-yyyy'), '5', '25', '145', '05', '2046', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16948, to_date('26-05-2046', 'dd-mm-yyyy'), '6', '26', '146', '05', '2046', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16949, to_date('27-05-2046', 'dd-mm-yyyy'), '7', '27', '147', '05', '2046', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16950, to_date('28-05-2046', 'dd-mm-yyyy'), '1', '28', '148', '05', '2046', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16951, to_date('29-05-2046', 'dd-mm-yyyy'), '2', '29', '149', '05', '2046', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16952, to_date('30-05-2046', 'dd-mm-yyyy'), '3', '30', '150', '05', '2046', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16953, to_date('31-05-2046', 'dd-mm-yyyy'), '4', '31', '151', '05', '2046', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16954, to_date('01-06-2046', 'dd-mm-yyyy'), '5', '01', '152', '06', '2046', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16955, to_date('02-06-2046', 'dd-mm-yyyy'), '6', '02', '153', '06', '2046', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16956, to_date('03-06-2046', 'dd-mm-yyyy'), '7', '03', '154', '06', '2046', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16957, to_date('04-06-2046', 'dd-mm-yyyy'), '1', '04', '155', '06', '2046', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16958, to_date('05-06-2046', 'dd-mm-yyyy'), '2', '05', '156', '06', '2046', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16959, to_date('06-06-2046', 'dd-mm-yyyy'), '3', '06', '157', '06', '2046', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16960, to_date('07-06-2046', 'dd-mm-yyyy'), '4', '07', '158', '06', '2046', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16961, to_date('08-06-2046', 'dd-mm-yyyy'), '5', '08', '159', '06', '2046', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16962, to_date('09-06-2046', 'dd-mm-yyyy'), '6', '09', '160', '06', '2046', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16963, to_date('10-06-2046', 'dd-mm-yyyy'), '7', '10', '161', '06', '2046', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16964, to_date('11-06-2046', 'dd-mm-yyyy'), '1', '11', '162', '06', '2046', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16965, to_date('12-06-2046', 'dd-mm-yyyy'), '2', '12', '163', '06', '2046', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16966, to_date('13-06-2046', 'dd-mm-yyyy'), '3', '13', '164', '06', '2046', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16967, to_date('14-06-2046', 'dd-mm-yyyy'), '4', '14', '165', '06', '2046', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16968, to_date('15-06-2046', 'dd-mm-yyyy'), '5', '15', '166', '06', '2046', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16969, to_date('16-06-2046', 'dd-mm-yyyy'), '6', '16', '167', '06', '2046', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16970, to_date('17-06-2046', 'dd-mm-yyyy'), '7', '17', '168', '06', '2046', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16971, to_date('18-06-2046', 'dd-mm-yyyy'), '1', '18', '169', '06', '2046', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16972, to_date('19-06-2046', 'dd-mm-yyyy'), '2', '19', '170', '06', '2046', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16973, to_date('20-06-2046', 'dd-mm-yyyy'), '3', '20', '171', '06', '2046', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16974, to_date('21-06-2046', 'dd-mm-yyyy'), '4', '21', '172', '06', '2046', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16975, to_date('22-06-2046', 'dd-mm-yyyy'), '5', '22', '173', '06', '2046', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16976, to_date('23-06-2046', 'dd-mm-yyyy'), '6', '23', '174', '06', '2046', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16977, to_date('24-06-2046', 'dd-mm-yyyy'), '7', '24', '175', '06', '2046', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16978, to_date('25-06-2046', 'dd-mm-yyyy'), '1', '25', '176', '06', '2046', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16979, to_date('26-06-2046', 'dd-mm-yyyy'), '2', '26', '177', '06', '2046', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16980, to_date('27-06-2046', 'dd-mm-yyyy'), '3', '27', '178', '06', '2046', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16981, to_date('28-06-2046', 'dd-mm-yyyy'), '4', '28', '179', '06', '2046', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16982, to_date('29-06-2046', 'dd-mm-yyyy'), '5', '29', '180', '06', '2046', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16983, to_date('30-06-2046', 'dd-mm-yyyy'), '6', '30', '181', '06', '2046', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16984, to_date('01-07-2046', 'dd-mm-yyyy'), '7', '01', '182', '07', '2046', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16985, to_date('02-07-2046', 'dd-mm-yyyy'), '1', '02', '183', '07', '2046', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16986, to_date('03-07-2046', 'dd-mm-yyyy'), '2', '03', '184', '07', '2046', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16987, to_date('04-07-2046', 'dd-mm-yyyy'), '3', '04', '185', '07', '2046', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16988, to_date('05-07-2046', 'dd-mm-yyyy'), '4', '05', '186', '07', '2046', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16989, to_date('06-07-2046', 'dd-mm-yyyy'), '5', '06', '187', '07', '2046', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16990, to_date('07-07-2046', 'dd-mm-yyyy'), '6', '07', '188', '07', '2046', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16991, to_date('08-07-2046', 'dd-mm-yyyy'), '7', '08', '189', '07', '2046', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16992, to_date('09-07-2046', 'dd-mm-yyyy'), '1', '09', '190', '07', '2046', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16993, to_date('10-07-2046', 'dd-mm-yyyy'), '2', '10', '191', '07', '2046', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16994, to_date('11-07-2046', 'dd-mm-yyyy'), '3', '11', '192', '07', '2046', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16995, to_date('12-07-2046', 'dd-mm-yyyy'), '4', '12', '193', '07', '2046', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16996, to_date('13-07-2046', 'dd-mm-yyyy'), '5', '13', '194', '07', '2046', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16997, to_date('14-07-2046', 'dd-mm-yyyy'), '6', '14', '195', '07', '2046', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16998, to_date('15-07-2046', 'dd-mm-yyyy'), '7', '15', '196', '07', '2046', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (16999, to_date('16-07-2046', 'dd-mm-yyyy'), '1', '16', '197', '07', '2046', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17000, to_date('17-07-2046', 'dd-mm-yyyy'), '2', '17', '198', '07', '2046', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17001, to_date('18-07-2046', 'dd-mm-yyyy'), '3', '18', '199', '07', '2046', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17002, to_date('19-07-2046', 'dd-mm-yyyy'), '4', '19', '200', '07', '2046', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17003, to_date('20-07-2046', 'dd-mm-yyyy'), '5', '20', '201', '07', '2046', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17004, to_date('21-07-2046', 'dd-mm-yyyy'), '6', '21', '202', '07', '2046', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17005, to_date('22-07-2046', 'dd-mm-yyyy'), '7', '22', '203', '07', '2046', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17006, to_date('23-07-2046', 'dd-mm-yyyy'), '1', '23', '204', '07', '2046', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17007, to_date('24-07-2046', 'dd-mm-yyyy'), '2', '24', '205', '07', '2046', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17008, to_date('25-07-2046', 'dd-mm-yyyy'), '3', '25', '206', '07', '2046', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17009, to_date('26-07-2046', 'dd-mm-yyyy'), '4', '26', '207', '07', '2046', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17010, to_date('27-07-2046', 'dd-mm-yyyy'), '5', '27', '208', '07', '2046', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17011, to_date('28-07-2046', 'dd-mm-yyyy'), '6', '28', '209', '07', '2046', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17012, to_date('29-07-2046', 'dd-mm-yyyy'), '7', '29', '210', '07', '2046', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17013, to_date('30-07-2046', 'dd-mm-yyyy'), '1', '30', '211', '07', '2046', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17014, to_date('31-07-2046', 'dd-mm-yyyy'), '2', '31', '212', '07', '2046', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17015, to_date('01-08-2046', 'dd-mm-yyyy'), '3', '01', '213', '08', '2046', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17016, to_date('02-08-2046', 'dd-mm-yyyy'), '4', '02', '214', '08', '2046', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17017, to_date('03-08-2046', 'dd-mm-yyyy'), '5', '03', '215', '08', '2046', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17018, to_date('04-08-2046', 'dd-mm-yyyy'), '6', '04', '216', '08', '2046', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17019, to_date('05-08-2046', 'dd-mm-yyyy'), '7', '05', '217', '08', '2046', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17020, to_date('06-08-2046', 'dd-mm-yyyy'), '1', '06', '218', '08', '2046', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17021, to_date('07-08-2046', 'dd-mm-yyyy'), '2', '07', '219', '08', '2046', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17022, to_date('08-08-2046', 'dd-mm-yyyy'), '3', '08', '220', '08', '2046', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17023, to_date('09-08-2046', 'dd-mm-yyyy'), '4', '09', '221', '08', '2046', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17024, to_date('10-08-2046', 'dd-mm-yyyy'), '5', '10', '222', '08', '2046', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17025, to_date('11-08-2046', 'dd-mm-yyyy'), '6', '11', '223', '08', '2046', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17026, to_date('12-08-2046', 'dd-mm-yyyy'), '7', '12', '224', '08', '2046', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17027, to_date('13-08-2046', 'dd-mm-yyyy'), '1', '13', '225', '08', '2046', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17028, to_date('14-08-2046', 'dd-mm-yyyy'), '2', '14', '226', '08', '2046', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17029, to_date('15-08-2046', 'dd-mm-yyyy'), '3', '15', '227', '08', '2046', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17030, to_date('16-08-2046', 'dd-mm-yyyy'), '4', '16', '228', '08', '2046', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17031, to_date('17-08-2046', 'dd-mm-yyyy'), '5', '17', '229', '08', '2046', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17032, to_date('18-08-2046', 'dd-mm-yyyy'), '6', '18', '230', '08', '2046', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17033, to_date('19-08-2046', 'dd-mm-yyyy'), '7', '19', '231', '08', '2046', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17034, to_date('20-08-2046', 'dd-mm-yyyy'), '1', '20', '232', '08', '2046', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17035, to_date('21-08-2046', 'dd-mm-yyyy'), '2', '21', '233', '08', '2046', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17036, to_date('22-08-2046', 'dd-mm-yyyy'), '3', '22', '234', '08', '2046', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17037, to_date('23-08-2046', 'dd-mm-yyyy'), '4', '23', '235', '08', '2046', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17038, to_date('24-08-2046', 'dd-mm-yyyy'), '5', '24', '236', '08', '2046', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17039, to_date('25-08-2046', 'dd-mm-yyyy'), '6', '25', '237', '08', '2046', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17040, to_date('26-08-2046', 'dd-mm-yyyy'), '7', '26', '238', '08', '2046', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18525, to_date('19-09-2050', 'dd-mm-yyyy'), '1', '19', '262', '09', '2050', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18526, to_date('20-09-2050', 'dd-mm-yyyy'), '2', '20', '263', '09', '2050', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18527, to_date('21-09-2050', 'dd-mm-yyyy'), '3', '21', '264', '09', '2050', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18528, to_date('22-09-2050', 'dd-mm-yyyy'), '4', '22', '265', '09', '2050', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18529, to_date('23-09-2050', 'dd-mm-yyyy'), '5', '23', '266', '09', '2050', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18530, to_date('24-09-2050', 'dd-mm-yyyy'), '6', '24', '267', '09', '2050', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18531, to_date('25-09-2050', 'dd-mm-yyyy'), '7', '25', '268', '09', '2050', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18532, to_date('26-09-2050', 'dd-mm-yyyy'), '1', '26', '269', '09', '2050', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18533, to_date('27-09-2050', 'dd-mm-yyyy'), '2', '27', '270', '09', '2050', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18534, to_date('28-09-2050', 'dd-mm-yyyy'), '3', '28', '271', '09', '2050', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18535, to_date('29-09-2050', 'dd-mm-yyyy'), '4', '29', '272', '09', '2050', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18536, to_date('30-09-2050', 'dd-mm-yyyy'), '5', '30', '273', '09', '2050', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18537, to_date('01-10-2050', 'dd-mm-yyyy'), '6', '01', '274', '10', '2050', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18538, to_date('02-10-2050', 'dd-mm-yyyy'), '7', '02', '275', '10', '2050', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18539, to_date('03-10-2050', 'dd-mm-yyyy'), '1', '03', '276', '10', '2050', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18540, to_date('04-10-2050', 'dd-mm-yyyy'), '2', '04', '277', '10', '2050', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18541, to_date('05-10-2050', 'dd-mm-yyyy'), '3', '05', '278', '10', '2050', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18542, to_date('06-10-2050', 'dd-mm-yyyy'), '4', '06', '279', '10', '2050', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18543, to_date('07-10-2050', 'dd-mm-yyyy'), '5', '07', '280', '10', '2050', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18544, to_date('08-10-2050', 'dd-mm-yyyy'), '6', '08', '281', '10', '2050', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18545, to_date('09-10-2050', 'dd-mm-yyyy'), '7', '09', '282', '10', '2050', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18546, to_date('10-10-2050', 'dd-mm-yyyy'), '1', '10', '283', '10', '2050', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18547, to_date('11-10-2050', 'dd-mm-yyyy'), '2', '11', '284', '10', '2050', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18548, to_date('12-10-2050', 'dd-mm-yyyy'), '3', '12', '285', '10', '2050', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18549, to_date('13-10-2050', 'dd-mm-yyyy'), '4', '13', '286', '10', '2050', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18550, to_date('14-10-2050', 'dd-mm-yyyy'), '5', '14', '287', '10', '2050', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18551, to_date('15-10-2050', 'dd-mm-yyyy'), '6', '15', '288', '10', '2050', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18552, to_date('16-10-2050', 'dd-mm-yyyy'), '7', '16', '289', '10', '2050', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18553, to_date('17-10-2050', 'dd-mm-yyyy'), '1', '17', '290', '10', '2050', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18554, to_date('18-10-2050', 'dd-mm-yyyy'), '2', '18', '291', '10', '2050', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18555, to_date('19-10-2050', 'dd-mm-yyyy'), '3', '19', '292', '10', '2050', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18556, to_date('20-10-2050', 'dd-mm-yyyy'), '4', '20', '293', '10', '2050', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18557, to_date('21-10-2050', 'dd-mm-yyyy'), '5', '21', '294', '10', '2050', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18558, to_date('22-10-2050', 'dd-mm-yyyy'), '6', '22', '295', '10', '2050', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18559, to_date('23-10-2050', 'dd-mm-yyyy'), '7', '23', '296', '10', '2050', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18560, to_date('24-10-2050', 'dd-mm-yyyy'), '1', '24', '297', '10', '2050', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18561, to_date('25-10-2050', 'dd-mm-yyyy'), '2', '25', '298', '10', '2050', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18562, to_date('26-10-2050', 'dd-mm-yyyy'), '3', '26', '299', '10', '2050', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18563, to_date('27-10-2050', 'dd-mm-yyyy'), '4', '27', '300', '10', '2050', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18564, to_date('28-10-2050', 'dd-mm-yyyy'), '5', '28', '301', '10', '2050', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18565, to_date('29-10-2050', 'dd-mm-yyyy'), '6', '29', '302', '10', '2050', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18566, to_date('30-10-2050', 'dd-mm-yyyy'), '7', '30', '303', '10', '2050', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18567, to_date('31-10-2050', 'dd-mm-yyyy'), '1', '31', '304', '10', '2050', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18568, to_date('01-11-2050', 'dd-mm-yyyy'), '2', '01', '305', '11', '2050', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18569, to_date('02-11-2050', 'dd-mm-yyyy'), '3', '02', '306', '11', '2050', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18570, to_date('03-11-2050', 'dd-mm-yyyy'), '4', '03', '307', '11', '2050', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18571, to_date('04-11-2050', 'dd-mm-yyyy'), '5', '04', '308', '11', '2050', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18572, to_date('05-11-2050', 'dd-mm-yyyy'), '6', '05', '309', '11', '2050', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18573, to_date('06-11-2050', 'dd-mm-yyyy'), '7', '06', '310', '11', '2050', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18574, to_date('07-11-2050', 'dd-mm-yyyy'), '1', '07', '311', '11', '2050', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18575, to_date('08-11-2050', 'dd-mm-yyyy'), '2', '08', '312', '11', '2050', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18576, to_date('09-11-2050', 'dd-mm-yyyy'), '3', '09', '313', '11', '2050', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18577, to_date('10-11-2050', 'dd-mm-yyyy'), '4', '10', '314', '11', '2050', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18578, to_date('11-11-2050', 'dd-mm-yyyy'), '5', '11', '315', '11', '2050', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18579, to_date('12-11-2050', 'dd-mm-yyyy'), '6', '12', '316', '11', '2050', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18580, to_date('13-11-2050', 'dd-mm-yyyy'), '7', '13', '317', '11', '2050', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18581, to_date('14-11-2050', 'dd-mm-yyyy'), '1', '14', '318', '11', '2050', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18582, to_date('15-11-2050', 'dd-mm-yyyy'), '2', '15', '319', '11', '2050', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18583, to_date('16-11-2050', 'dd-mm-yyyy'), '3', '16', '320', '11', '2050', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18584, to_date('17-11-2050', 'dd-mm-yyyy'), '4', '17', '321', '11', '2050', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18585, to_date('18-11-2050', 'dd-mm-yyyy'), '5', '18', '322', '11', '2050', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18586, to_date('19-11-2050', 'dd-mm-yyyy'), '6', '19', '323', '11', '2050', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18587, to_date('20-11-2050', 'dd-mm-yyyy'), '7', '20', '324', '11', '2050', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18588, to_date('21-11-2050', 'dd-mm-yyyy'), '1', '21', '325', '11', '2050', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18589, to_date('22-11-2050', 'dd-mm-yyyy'), '2', '22', '326', '11', '2050', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18590, to_date('23-11-2050', 'dd-mm-yyyy'), '3', '23', '327', '11', '2050', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18591, to_date('24-11-2050', 'dd-mm-yyyy'), '4', '24', '328', '11', '2050', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18592, to_date('25-11-2050', 'dd-mm-yyyy'), '5', '25', '329', '11', '2050', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18593, to_date('26-11-2050', 'dd-mm-yyyy'), '6', '26', '330', '11', '2050', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18594, to_date('27-11-2050', 'dd-mm-yyyy'), '7', '27', '331', '11', '2050', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18595, to_date('28-11-2050', 'dd-mm-yyyy'), '1', '28', '332', '11', '2050', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18596, to_date('29-11-2050', 'dd-mm-yyyy'), '2', '29', '333', '11', '2050', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18597, to_date('30-11-2050', 'dd-mm-yyyy'), '3', '30', '334', '11', '2050', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18598, to_date('01-12-2050', 'dd-mm-yyyy'), '4', '01', '335', '12', '2050', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18599, to_date('02-12-2050', 'dd-mm-yyyy'), '5', '02', '336', '12', '2050', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18600, to_date('03-12-2050', 'dd-mm-yyyy'), '6', '03', '337', '12', '2050', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18601, to_date('04-12-2050', 'dd-mm-yyyy'), '7', '04', '338', '12', '2050', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18602, to_date('05-12-2050', 'dd-mm-yyyy'), '1', '05', '339', '12', '2050', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18603, to_date('06-12-2050', 'dd-mm-yyyy'), '2', '06', '340', '12', '2050', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18604, to_date('07-12-2050', 'dd-mm-yyyy'), '3', '07', '341', '12', '2050', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18605, to_date('08-12-2050', 'dd-mm-yyyy'), '4', '08', '342', '12', '2050', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18606, to_date('09-12-2050', 'dd-mm-yyyy'), '5', '09', '343', '12', '2050', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18607, to_date('10-12-2050', 'dd-mm-yyyy'), '6', '10', '344', '12', '2050', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18608, to_date('11-12-2050', 'dd-mm-yyyy'), '7', '11', '345', '12', '2050', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18609, to_date('12-12-2050', 'dd-mm-yyyy'), '1', '12', '346', '12', '2050', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18610, to_date('13-12-2050', 'dd-mm-yyyy'), '2', '13', '347', '12', '2050', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18611, to_date('14-12-2050', 'dd-mm-yyyy'), '3', '14', '348', '12', '2050', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18612, to_date('15-12-2050', 'dd-mm-yyyy'), '4', '15', '349', '12', '2050', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18613, to_date('16-12-2050', 'dd-mm-yyyy'), '5', '16', '350', '12', '2050', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18614, to_date('17-12-2050', 'dd-mm-yyyy'), '6', '17', '351', '12', '2050', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18615, to_date('18-12-2050', 'dd-mm-yyyy'), '7', '18', '352', '12', '2050', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18616, to_date('19-12-2050', 'dd-mm-yyyy'), '1', '19', '353', '12', '2050', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18617, to_date('20-12-2050', 'dd-mm-yyyy'), '2', '20', '354', '12', '2050', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18618, to_date('21-12-2050', 'dd-mm-yyyy'), '3', '21', '355', '12', '2050', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18619, to_date('22-12-2050', 'dd-mm-yyyy'), '4', '22', '356', '12', '2050', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18620, to_date('23-12-2050', 'dd-mm-yyyy'), '5', '23', '357', '12', '2050', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18621, to_date('24-12-2050', 'dd-mm-yyyy'), '6', '24', '358', '12', '2050', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18622, to_date('25-12-2050', 'dd-mm-yyyy'), '7', '25', '359', '12', '2050', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18623, to_date('26-12-2050', 'dd-mm-yyyy'), '1', '26', '360', '12', '2050', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18624, to_date('27-12-2050', 'dd-mm-yyyy'), '2', '27', '361', '12', '2050', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18625, to_date('28-12-2050', 'dd-mm-yyyy'), '3', '28', '362', '12', '2050', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18626, to_date('29-12-2050', 'dd-mm-yyyy'), '4', '29', '363', '12', '2050', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18627, to_date('30-12-2050', 'dd-mm-yyyy'), '5', '30', '364', '12', '2050', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18628, to_date('31-12-2050', 'dd-mm-yyyy'), '6', '31', '365', '12', '2050', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18629, to_date('01-01-2051', 'dd-mm-yyyy'), '7', '01', '001', '01', '2051', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18630, to_date('02-01-2051', 'dd-mm-yyyy'), '1', '02', '002', '01', '2051', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13755, to_date('28-08-2037', 'dd-mm-yyyy'), '5', '28', '240', '08', '2037', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13756, to_date('29-08-2037', 'dd-mm-yyyy'), '6', '29', '241', '08', '2037', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13757, to_date('30-08-2037', 'dd-mm-yyyy'), '7', '30', '242', '08', '2037', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13758, to_date('31-08-2037', 'dd-mm-yyyy'), '1', '31', '243', '08', '2037', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13759, to_date('01-09-2037', 'dd-mm-yyyy'), '2', '01', '244', '09', '2037', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13760, to_date('02-09-2037', 'dd-mm-yyyy'), '3', '02', '245', '09', '2037', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13761, to_date('03-09-2037', 'dd-mm-yyyy'), '4', '03', '246', '09', '2037', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13762, to_date('04-09-2037', 'dd-mm-yyyy'), '5', '04', '247', '09', '2037', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13763, to_date('05-09-2037', 'dd-mm-yyyy'), '6', '05', '248', '09', '2037', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13764, to_date('06-09-2037', 'dd-mm-yyyy'), '7', '06', '249', '09', '2037', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13765, to_date('07-09-2037', 'dd-mm-yyyy'), '1', '07', '250', '09', '2037', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13766, to_date('08-09-2037', 'dd-mm-yyyy'), '2', '08', '251', '09', '2037', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13767, to_date('09-09-2037', 'dd-mm-yyyy'), '3', '09', '252', '09', '2037', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13768, to_date('10-09-2037', 'dd-mm-yyyy'), '4', '10', '253', '09', '2037', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13769, to_date('11-09-2037', 'dd-mm-yyyy'), '5', '11', '254', '09', '2037', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13770, to_date('12-09-2037', 'dd-mm-yyyy'), '6', '12', '255', '09', '2037', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13771, to_date('13-09-2037', 'dd-mm-yyyy'), '7', '13', '256', '09', '2037', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13772, to_date('14-09-2037', 'dd-mm-yyyy'), '1', '14', '257', '09', '2037', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13773, to_date('15-09-2037', 'dd-mm-yyyy'), '2', '15', '258', '09', '2037', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13774, to_date('16-09-2037', 'dd-mm-yyyy'), '3', '16', '259', '09', '2037', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13775, to_date('17-09-2037', 'dd-mm-yyyy'), '4', '17', '260', '09', '2037', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13776, to_date('18-09-2037', 'dd-mm-yyyy'), '5', '18', '261', '09', '2037', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13777, to_date('19-09-2037', 'dd-mm-yyyy'), '6', '19', '262', '09', '2037', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13778, to_date('20-09-2037', 'dd-mm-yyyy'), '7', '20', '263', '09', '2037', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13779, to_date('21-09-2037', 'dd-mm-yyyy'), '1', '21', '264', '09', '2037', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13780, to_date('22-09-2037', 'dd-mm-yyyy'), '2', '22', '265', '09', '2037', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13781, to_date('23-09-2037', 'dd-mm-yyyy'), '3', '23', '266', '09', '2037', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13782, to_date('24-09-2037', 'dd-mm-yyyy'), '4', '24', '267', '09', '2037', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13783, to_date('25-09-2037', 'dd-mm-yyyy'), '5', '25', '268', '09', '2037', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13784, to_date('26-09-2037', 'dd-mm-yyyy'), '6', '26', '269', '09', '2037', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13785, to_date('27-09-2037', 'dd-mm-yyyy'), '7', '27', '270', '09', '2037', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13786, to_date('28-09-2037', 'dd-mm-yyyy'), '1', '28', '271', '09', '2037', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13787, to_date('29-09-2037', 'dd-mm-yyyy'), '2', '29', '272', '09', '2037', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13788, to_date('30-09-2037', 'dd-mm-yyyy'), '3', '30', '273', '09', '2037', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13789, to_date('01-10-2037', 'dd-mm-yyyy'), '4', '01', '274', '10', '2037', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13790, to_date('02-10-2037', 'dd-mm-yyyy'), '5', '02', '275', '10', '2037', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13791, to_date('03-10-2037', 'dd-mm-yyyy'), '6', '03', '276', '10', '2037', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13792, to_date('04-10-2037', 'dd-mm-yyyy'), '7', '04', '277', '10', '2037', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13793, to_date('05-10-2037', 'dd-mm-yyyy'), '1', '05', '278', '10', '2037', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13794, to_date('06-10-2037', 'dd-mm-yyyy'), '2', '06', '279', '10', '2037', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13795, to_date('07-10-2037', 'dd-mm-yyyy'), '3', '07', '280', '10', '2037', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13796, to_date('08-10-2037', 'dd-mm-yyyy'), '4', '08', '281', '10', '2037', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13797, to_date('09-10-2037', 'dd-mm-yyyy'), '5', '09', '282', '10', '2037', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13798, to_date('10-10-2037', 'dd-mm-yyyy'), '6', '10', '283', '10', '2037', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13799, to_date('11-10-2037', 'dd-mm-yyyy'), '7', '11', '284', '10', '2037', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13800, to_date('12-10-2037', 'dd-mm-yyyy'), '1', '12', '285', '10', '2037', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13801, to_date('13-10-2037', 'dd-mm-yyyy'), '2', '13', '286', '10', '2037', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13802, to_date('14-10-2037', 'dd-mm-yyyy'), '3', '14', '287', '10', '2037', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13803, to_date('15-10-2037', 'dd-mm-yyyy'), '4', '15', '288', '10', '2037', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13804, to_date('16-10-2037', 'dd-mm-yyyy'), '5', '16', '289', '10', '2037', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13805, to_date('17-10-2037', 'dd-mm-yyyy'), '6', '17', '290', '10', '2037', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13806, to_date('18-10-2037', 'dd-mm-yyyy'), '7', '18', '291', '10', '2037', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13807, to_date('19-10-2037', 'dd-mm-yyyy'), '1', '19', '292', '10', '2037', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13808, to_date('20-10-2037', 'dd-mm-yyyy'), '2', '20', '293', '10', '2037', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13809, to_date('21-10-2037', 'dd-mm-yyyy'), '3', '21', '294', '10', '2037', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13810, to_date('22-10-2037', 'dd-mm-yyyy'), '4', '22', '295', '10', '2037', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13811, to_date('23-10-2037', 'dd-mm-yyyy'), '5', '23', '296', '10', '2037', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13812, to_date('24-10-2037', 'dd-mm-yyyy'), '6', '24', '297', '10', '2037', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13813, to_date('25-10-2037', 'dd-mm-yyyy'), '7', '25', '298', '10', '2037', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13814, to_date('26-10-2037', 'dd-mm-yyyy'), '1', '26', '299', '10', '2037', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13815, to_date('27-10-2037', 'dd-mm-yyyy'), '2', '27', '300', '10', '2037', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13816, to_date('28-10-2037', 'dd-mm-yyyy'), '3', '28', '301', '10', '2037', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13817, to_date('29-10-2037', 'dd-mm-yyyy'), '4', '29', '302', '10', '2037', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13818, to_date('30-10-2037', 'dd-mm-yyyy'), '5', '30', '303', '10', '2037', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13819, to_date('31-10-2037', 'dd-mm-yyyy'), '6', '31', '304', '10', '2037', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13820, to_date('01-11-2037', 'dd-mm-yyyy'), '7', '01', '305', '11', '2037', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13821, to_date('02-11-2037', 'dd-mm-yyyy'), '1', '02', '306', '11', '2037', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13822, to_date('03-11-2037', 'dd-mm-yyyy'), '2', '03', '307', '11', '2037', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13823, to_date('04-11-2037', 'dd-mm-yyyy'), '3', '04', '308', '11', '2037', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13824, to_date('05-11-2037', 'dd-mm-yyyy'), '4', '05', '309', '11', '2037', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13825, to_date('06-11-2037', 'dd-mm-yyyy'), '5', '06', '310', '11', '2037', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13826, to_date('07-11-2037', 'dd-mm-yyyy'), '6', '07', '311', '11', '2037', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13827, to_date('08-11-2037', 'dd-mm-yyyy'), '7', '08', '312', '11', '2037', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13828, to_date('09-11-2037', 'dd-mm-yyyy'), '1', '09', '313', '11', '2037', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13829, to_date('10-11-2037', 'dd-mm-yyyy'), '2', '10', '314', '11', '2037', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13830, to_date('11-11-2037', 'dd-mm-yyyy'), '3', '11', '315', '11', '2037', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13831, to_date('12-11-2037', 'dd-mm-yyyy'), '4', '12', '316', '11', '2037', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13832, to_date('13-11-2037', 'dd-mm-yyyy'), '5', '13', '317', '11', '2037', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13833, to_date('14-11-2037', 'dd-mm-yyyy'), '6', '14', '318', '11', '2037', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13834, to_date('15-11-2037', 'dd-mm-yyyy'), '7', '15', '319', '11', '2037', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13835, to_date('16-11-2037', 'dd-mm-yyyy'), '1', '16', '320', '11', '2037', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13836, to_date('17-11-2037', 'dd-mm-yyyy'), '2', '17', '321', '11', '2037', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13837, to_date('18-11-2037', 'dd-mm-yyyy'), '3', '18', '322', '11', '2037', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13838, to_date('19-11-2037', 'dd-mm-yyyy'), '4', '19', '323', '11', '2037', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13839, to_date('20-11-2037', 'dd-mm-yyyy'), '5', '20', '324', '11', '2037', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13840, to_date('21-11-2037', 'dd-mm-yyyy'), '6', '21', '325', '11', '2037', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13841, to_date('22-11-2037', 'dd-mm-yyyy'), '7', '22', '326', '11', '2037', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13842, to_date('23-11-2037', 'dd-mm-yyyy'), '1', '23', '327', '11', '2037', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13843, to_date('24-11-2037', 'dd-mm-yyyy'), '2', '24', '328', '11', '2037', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13844, to_date('25-11-2037', 'dd-mm-yyyy'), '3', '25', '329', '11', '2037', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13845, to_date('26-11-2037', 'dd-mm-yyyy'), '4', '26', '330', '11', '2037', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13846, to_date('27-11-2037', 'dd-mm-yyyy'), '5', '27', '331', '11', '2037', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13847, to_date('28-11-2037', 'dd-mm-yyyy'), '6', '28', '332', '11', '2037', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13848, to_date('29-11-2037', 'dd-mm-yyyy'), '7', '29', '333', '11', '2037', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13849, to_date('30-11-2037', 'dd-mm-yyyy'), '1', '30', '334', '11', '2037', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13850, to_date('01-12-2037', 'dd-mm-yyyy'), '2', '01', '335', '12', '2037', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13851, to_date('02-12-2037', 'dd-mm-yyyy'), '3', '02', '336', '12', '2037', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13852, to_date('03-12-2037', 'dd-mm-yyyy'), '4', '03', '337', '12', '2037', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13853, to_date('04-12-2037', 'dd-mm-yyyy'), '5', '04', '338', '12', '2037', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13854, to_date('05-12-2037', 'dd-mm-yyyy'), '6', '05', '339', '12', '2037', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13855, to_date('06-12-2037', 'dd-mm-yyyy'), '7', '06', '340', '12', '2037', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13856, to_date('07-12-2037', 'dd-mm-yyyy'), '1', '07', '341', '12', '2037', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13857, to_date('08-12-2037', 'dd-mm-yyyy'), '2', '08', '342', '12', '2037', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13858, to_date('09-12-2037', 'dd-mm-yyyy'), '3', '09', '343', '12', '2037', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13859, to_date('10-12-2037', 'dd-mm-yyyy'), '4', '10', '344', '12', '2037', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13860, to_date('11-12-2037', 'dd-mm-yyyy'), '5', '11', '345', '12', '2037', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15451, to_date('20-04-2042', 'dd-mm-yyyy'), '7', '20', '110', '04', '2042', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15452, to_date('21-04-2042', 'dd-mm-yyyy'), '1', '21', '111', '04', '2042', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15453, to_date('22-04-2042', 'dd-mm-yyyy'), '2', '22', '112', '04', '2042', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15454, to_date('23-04-2042', 'dd-mm-yyyy'), '3', '23', '113', '04', '2042', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15455, to_date('24-04-2042', 'dd-mm-yyyy'), '4', '24', '114', '04', '2042', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15456, to_date('25-04-2042', 'dd-mm-yyyy'), '5', '25', '115', '04', '2042', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15457, to_date('26-04-2042', 'dd-mm-yyyy'), '6', '26', '116', '04', '2042', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15458, to_date('27-04-2042', 'dd-mm-yyyy'), '7', '27', '117', '04', '2042', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15459, to_date('28-04-2042', 'dd-mm-yyyy'), '1', '28', '118', '04', '2042', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15460, to_date('29-04-2042', 'dd-mm-yyyy'), '2', '29', '119', '04', '2042', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15461, to_date('30-04-2042', 'dd-mm-yyyy'), '3', '30', '120', '04', '2042', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15462, to_date('01-05-2042', 'dd-mm-yyyy'), '4', '01', '121', '05', '2042', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15463, to_date('02-05-2042', 'dd-mm-yyyy'), '5', '02', '122', '05', '2042', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15464, to_date('03-05-2042', 'dd-mm-yyyy'), '6', '03', '123', '05', '2042', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15465, to_date('04-05-2042', 'dd-mm-yyyy'), '7', '04', '124', '05', '2042', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15466, to_date('05-05-2042', 'dd-mm-yyyy'), '1', '05', '125', '05', '2042', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15467, to_date('06-05-2042', 'dd-mm-yyyy'), '2', '06', '126', '05', '2042', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15468, to_date('07-05-2042', 'dd-mm-yyyy'), '3', '07', '127', '05', '2042', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15469, to_date('08-05-2042', 'dd-mm-yyyy'), '4', '08', '128', '05', '2042', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15470, to_date('09-05-2042', 'dd-mm-yyyy'), '5', '09', '129', '05', '2042', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15471, to_date('10-05-2042', 'dd-mm-yyyy'), '6', '10', '130', '05', '2042', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15472, to_date('11-05-2042', 'dd-mm-yyyy'), '7', '11', '131', '05', '2042', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15473, to_date('12-05-2042', 'dd-mm-yyyy'), '1', '12', '132', '05', '2042', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15474, to_date('13-05-2042', 'dd-mm-yyyy'), '2', '13', '133', '05', '2042', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15475, to_date('14-05-2042', 'dd-mm-yyyy'), '3', '14', '134', '05', '2042', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15476, to_date('15-05-2042', 'dd-mm-yyyy'), '4', '15', '135', '05', '2042', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15477, to_date('16-05-2042', 'dd-mm-yyyy'), '5', '16', '136', '05', '2042', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15478, to_date('17-05-2042', 'dd-mm-yyyy'), '6', '17', '137', '05', '2042', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15479, to_date('18-05-2042', 'dd-mm-yyyy'), '7', '18', '138', '05', '2042', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15480, to_date('19-05-2042', 'dd-mm-yyyy'), '1', '19', '139', '05', '2042', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15481, to_date('20-05-2042', 'dd-mm-yyyy'), '2', '20', '140', '05', '2042', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15482, to_date('21-05-2042', 'dd-mm-yyyy'), '3', '21', '141', '05', '2042', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15483, to_date('22-05-2042', 'dd-mm-yyyy'), '4', '22', '142', '05', '2042', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15484, to_date('23-05-2042', 'dd-mm-yyyy'), '5', '23', '143', '05', '2042', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15485, to_date('24-05-2042', 'dd-mm-yyyy'), '6', '24', '144', '05', '2042', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15486, to_date('25-05-2042', 'dd-mm-yyyy'), '7', '25', '145', '05', '2042', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15487, to_date('26-05-2042', 'dd-mm-yyyy'), '1', '26', '146', '05', '2042', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15488, to_date('27-05-2042', 'dd-mm-yyyy'), '2', '27', '147', '05', '2042', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15489, to_date('28-05-2042', 'dd-mm-yyyy'), '3', '28', '148', '05', '2042', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15490, to_date('29-05-2042', 'dd-mm-yyyy'), '4', '29', '149', '05', '2042', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15491, to_date('30-05-2042', 'dd-mm-yyyy'), '5', '30', '150', '05', '2042', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15492, to_date('31-05-2042', 'dd-mm-yyyy'), '6', '31', '151', '05', '2042', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15493, to_date('01-06-2042', 'dd-mm-yyyy'), '7', '01', '152', '06', '2042', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15494, to_date('02-06-2042', 'dd-mm-yyyy'), '1', '02', '153', '06', '2042', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15495, to_date('03-06-2042', 'dd-mm-yyyy'), '2', '03', '154', '06', '2042', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15496, to_date('04-06-2042', 'dd-mm-yyyy'), '3', '04', '155', '06', '2042', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15497, to_date('05-06-2042', 'dd-mm-yyyy'), '4', '05', '156', '06', '2042', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15498, to_date('06-06-2042', 'dd-mm-yyyy'), '5', '06', '157', '06', '2042', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15499, to_date('07-06-2042', 'dd-mm-yyyy'), '6', '07', '158', '06', '2042', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15500, to_date('08-06-2042', 'dd-mm-yyyy'), '7', '08', '159', '06', '2042', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15501, to_date('09-06-2042', 'dd-mm-yyyy'), '1', '09', '160', '06', '2042', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15502, to_date('10-06-2042', 'dd-mm-yyyy'), '2', '10', '161', '06', '2042', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15503, to_date('11-06-2042', 'dd-mm-yyyy'), '3', '11', '162', '06', '2042', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15504, to_date('12-06-2042', 'dd-mm-yyyy'), '4', '12', '163', '06', '2042', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15505, to_date('13-06-2042', 'dd-mm-yyyy'), '5', '13', '164', '06', '2042', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15506, to_date('14-06-2042', 'dd-mm-yyyy'), '6', '14', '165', '06', '2042', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15507, to_date('15-06-2042', 'dd-mm-yyyy'), '7', '15', '166', '06', '2042', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15508, to_date('16-06-2042', 'dd-mm-yyyy'), '1', '16', '167', '06', '2042', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15509, to_date('17-06-2042', 'dd-mm-yyyy'), '2', '17', '168', '06', '2042', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15510, to_date('18-06-2042', 'dd-mm-yyyy'), '3', '18', '169', '06', '2042', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15511, to_date('19-06-2042', 'dd-mm-yyyy'), '4', '19', '170', '06', '2042', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15512, to_date('20-06-2042', 'dd-mm-yyyy'), '5', '20', '171', '06', '2042', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15513, to_date('21-06-2042', 'dd-mm-yyyy'), '6', '21', '172', '06', '2042', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15514, to_date('22-06-2042', 'dd-mm-yyyy'), '7', '22', '173', '06', '2042', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15515, to_date('23-06-2042', 'dd-mm-yyyy'), '1', '23', '174', '06', '2042', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15516, to_date('24-06-2042', 'dd-mm-yyyy'), '2', '24', '175', '06', '2042', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15517, to_date('25-06-2042', 'dd-mm-yyyy'), '3', '25', '176', '06', '2042', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15518, to_date('26-06-2042', 'dd-mm-yyyy'), '4', '26', '177', '06', '2042', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15519, to_date('27-06-2042', 'dd-mm-yyyy'), '5', '27', '178', '06', '2042', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15520, to_date('28-06-2042', 'dd-mm-yyyy'), '6', '28', '179', '06', '2042', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15521, to_date('29-06-2042', 'dd-mm-yyyy'), '7', '29', '180', '06', '2042', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15522, to_date('30-06-2042', 'dd-mm-yyyy'), '1', '30', '181', '06', '2042', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15523, to_date('01-07-2042', 'dd-mm-yyyy'), '2', '01', '182', '07', '2042', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15524, to_date('02-07-2042', 'dd-mm-yyyy'), '3', '02', '183', '07', '2042', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15525, to_date('03-07-2042', 'dd-mm-yyyy'), '4', '03', '184', '07', '2042', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15526, to_date('04-07-2042', 'dd-mm-yyyy'), '5', '04', '185', '07', '2042', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15527, to_date('05-07-2042', 'dd-mm-yyyy'), '6', '05', '186', '07', '2042', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15528, to_date('06-07-2042', 'dd-mm-yyyy'), '7', '06', '187', '07', '2042', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15529, to_date('07-07-2042', 'dd-mm-yyyy'), '1', '07', '188', '07', '2042', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15530, to_date('08-07-2042', 'dd-mm-yyyy'), '2', '08', '189', '07', '2042', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15531, to_date('09-07-2042', 'dd-mm-yyyy'), '3', '09', '190', '07', '2042', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15532, to_date('10-07-2042', 'dd-mm-yyyy'), '4', '10', '191', '07', '2042', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15533, to_date('11-07-2042', 'dd-mm-yyyy'), '5', '11', '192', '07', '2042', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15534, to_date('12-07-2042', 'dd-mm-yyyy'), '6', '12', '193', '07', '2042', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15535, to_date('13-07-2042', 'dd-mm-yyyy'), '7', '13', '194', '07', '2042', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15536, to_date('14-07-2042', 'dd-mm-yyyy'), '1', '14', '195', '07', '2042', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15537, to_date('15-07-2042', 'dd-mm-yyyy'), '2', '15', '196', '07', '2042', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15538, to_date('16-07-2042', 'dd-mm-yyyy'), '3', '16', '197', '07', '2042', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15539, to_date('17-07-2042', 'dd-mm-yyyy'), '4', '17', '198', '07', '2042', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15540, to_date('18-07-2042', 'dd-mm-yyyy'), '5', '18', '199', '07', '2042', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15541, to_date('19-07-2042', 'dd-mm-yyyy'), '6', '19', '200', '07', '2042', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15542, to_date('20-07-2042', 'dd-mm-yyyy'), '7', '20', '201', '07', '2042', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15543, to_date('21-07-2042', 'dd-mm-yyyy'), '1', '21', '202', '07', '2042', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15544, to_date('22-07-2042', 'dd-mm-yyyy'), '2', '22', '203', '07', '2042', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15545, to_date('23-07-2042', 'dd-mm-yyyy'), '3', '23', '204', '07', '2042', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15546, to_date('24-07-2042', 'dd-mm-yyyy'), '4', '24', '205', '07', '2042', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15547, to_date('25-07-2042', 'dd-mm-yyyy'), '5', '25', '206', '07', '2042', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15548, to_date('26-07-2042', 'dd-mm-yyyy'), '6', '26', '207', '07', '2042', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15549, to_date('27-07-2042', 'dd-mm-yyyy'), '7', '27', '208', '07', '2042', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15550, to_date('28-07-2042', 'dd-mm-yyyy'), '1', '28', '209', '07', '2042', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15551, to_date('29-07-2042', 'dd-mm-yyyy'), '2', '29', '210', '07', '2042', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15552, to_date('30-07-2042', 'dd-mm-yyyy'), '3', '30', '211', '07', '2042', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15553, to_date('31-07-2042', 'dd-mm-yyyy'), '4', '31', '212', '07', '2042', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15554, to_date('01-08-2042', 'dd-mm-yyyy'), '5', '01', '213', '08', '2042', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15555, to_date('02-08-2042', 'dd-mm-yyyy'), '6', '02', '214', '08', '2042', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15556, to_date('03-08-2042', 'dd-mm-yyyy'), '7', '03', '215', '08', '2042', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17041, to_date('27-08-2046', 'dd-mm-yyyy'), '1', '27', '239', '08', '2046', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17042, to_date('28-08-2046', 'dd-mm-yyyy'), '2', '28', '240', '08', '2046', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17043, to_date('29-08-2046', 'dd-mm-yyyy'), '3', '29', '241', '08', '2046', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17044, to_date('30-08-2046', 'dd-mm-yyyy'), '4', '30', '242', '08', '2046', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17045, to_date('31-08-2046', 'dd-mm-yyyy'), '5', '31', '243', '08', '2046', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17046, to_date('01-09-2046', 'dd-mm-yyyy'), '6', '01', '244', '09', '2046', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17047, to_date('02-09-2046', 'dd-mm-yyyy'), '7', '02', '245', '09', '2046', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17048, to_date('03-09-2046', 'dd-mm-yyyy'), '1', '03', '246', '09', '2046', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17049, to_date('04-09-2046', 'dd-mm-yyyy'), '2', '04', '247', '09', '2046', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17050, to_date('05-09-2046', 'dd-mm-yyyy'), '3', '05', '248', '09', '2046', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17051, to_date('06-09-2046', 'dd-mm-yyyy'), '4', '06', '249', '09', '2046', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17052, to_date('07-09-2046', 'dd-mm-yyyy'), '5', '07', '250', '09', '2046', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17053, to_date('08-09-2046', 'dd-mm-yyyy'), '6', '08', '251', '09', '2046', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17054, to_date('09-09-2046', 'dd-mm-yyyy'), '7', '09', '252', '09', '2046', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17055, to_date('10-09-2046', 'dd-mm-yyyy'), '1', '10', '253', '09', '2046', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17056, to_date('11-09-2046', 'dd-mm-yyyy'), '2', '11', '254', '09', '2046', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17057, to_date('12-09-2046', 'dd-mm-yyyy'), '3', '12', '255', '09', '2046', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17058, to_date('13-09-2046', 'dd-mm-yyyy'), '4', '13', '256', '09', '2046', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17059, to_date('14-09-2046', 'dd-mm-yyyy'), '5', '14', '257', '09', '2046', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17060, to_date('15-09-2046', 'dd-mm-yyyy'), '6', '15', '258', '09', '2046', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17061, to_date('16-09-2046', 'dd-mm-yyyy'), '7', '16', '259', '09', '2046', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17062, to_date('17-09-2046', 'dd-mm-yyyy'), '1', '17', '260', '09', '2046', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17063, to_date('18-09-2046', 'dd-mm-yyyy'), '2', '18', '261', '09', '2046', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17064, to_date('19-09-2046', 'dd-mm-yyyy'), '3', '19', '262', '09', '2046', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17065, to_date('20-09-2046', 'dd-mm-yyyy'), '4', '20', '263', '09', '2046', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17066, to_date('21-09-2046', 'dd-mm-yyyy'), '5', '21', '264', '09', '2046', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17067, to_date('22-09-2046', 'dd-mm-yyyy'), '6', '22', '265', '09', '2046', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17068, to_date('23-09-2046', 'dd-mm-yyyy'), '7', '23', '266', '09', '2046', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17069, to_date('24-09-2046', 'dd-mm-yyyy'), '1', '24', '267', '09', '2046', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17070, to_date('25-09-2046', 'dd-mm-yyyy'), '2', '25', '268', '09', '2046', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17071, to_date('26-09-2046', 'dd-mm-yyyy'), '3', '26', '269', '09', '2046', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17072, to_date('27-09-2046', 'dd-mm-yyyy'), '4', '27', '270', '09', '2046', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17073, to_date('28-09-2046', 'dd-mm-yyyy'), '5', '28', '271', '09', '2046', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17074, to_date('29-09-2046', 'dd-mm-yyyy'), '6', '29', '272', '09', '2046', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17075, to_date('30-09-2046', 'dd-mm-yyyy'), '7', '30', '273', '09', '2046', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17076, to_date('01-10-2046', 'dd-mm-yyyy'), '1', '01', '274', '10', '2046', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17077, to_date('02-10-2046', 'dd-mm-yyyy'), '2', '02', '275', '10', '2046', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17078, to_date('03-10-2046', 'dd-mm-yyyy'), '3', '03', '276', '10', '2046', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17079, to_date('04-10-2046', 'dd-mm-yyyy'), '4', '04', '277', '10', '2046', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17080, to_date('05-10-2046', 'dd-mm-yyyy'), '5', '05', '278', '10', '2046', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17081, to_date('06-10-2046', 'dd-mm-yyyy'), '6', '06', '279', '10', '2046', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17082, to_date('07-10-2046', 'dd-mm-yyyy'), '7', '07', '280', '10', '2046', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17083, to_date('08-10-2046', 'dd-mm-yyyy'), '1', '08', '281', '10', '2046', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17084, to_date('09-10-2046', 'dd-mm-yyyy'), '2', '09', '282', '10', '2046', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17085, to_date('10-10-2046', 'dd-mm-yyyy'), '3', '10', '283', '10', '2046', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17086, to_date('11-10-2046', 'dd-mm-yyyy'), '4', '11', '284', '10', '2046', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17087, to_date('12-10-2046', 'dd-mm-yyyy'), '5', '12', '285', '10', '2046', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17088, to_date('13-10-2046', 'dd-mm-yyyy'), '6', '13', '286', '10', '2046', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17089, to_date('14-10-2046', 'dd-mm-yyyy'), '7', '14', '287', '10', '2046', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17090, to_date('15-10-2046', 'dd-mm-yyyy'), '1', '15', '288', '10', '2046', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17091, to_date('16-10-2046', 'dd-mm-yyyy'), '2', '16', '289', '10', '2046', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17092, to_date('17-10-2046', 'dd-mm-yyyy'), '3', '17', '290', '10', '2046', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17093, to_date('18-10-2046', 'dd-mm-yyyy'), '4', '18', '291', '10', '2046', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17094, to_date('19-10-2046', 'dd-mm-yyyy'), '5', '19', '292', '10', '2046', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17095, to_date('20-10-2046', 'dd-mm-yyyy'), '6', '20', '293', '10', '2046', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17096, to_date('21-10-2046', 'dd-mm-yyyy'), '7', '21', '294', '10', '2046', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17097, to_date('22-10-2046', 'dd-mm-yyyy'), '1', '22', '295', '10', '2046', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17098, to_date('23-10-2046', 'dd-mm-yyyy'), '2', '23', '296', '10', '2046', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17099, to_date('24-10-2046', 'dd-mm-yyyy'), '3', '24', '297', '10', '2046', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17100, to_date('25-10-2046', 'dd-mm-yyyy'), '4', '25', '298', '10', '2046', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17101, to_date('26-10-2046', 'dd-mm-yyyy'), '5', '26', '299', '10', '2046', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17102, to_date('27-10-2046', 'dd-mm-yyyy'), '6', '27', '300', '10', '2046', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17103, to_date('28-10-2046', 'dd-mm-yyyy'), '7', '28', '301', '10', '2046', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17104, to_date('29-10-2046', 'dd-mm-yyyy'), '1', '29', '302', '10', '2046', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17105, to_date('30-10-2046', 'dd-mm-yyyy'), '2', '30', '303', '10', '2046', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17106, to_date('31-10-2046', 'dd-mm-yyyy'), '3', '31', '304', '10', '2046', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17107, to_date('01-11-2046', 'dd-mm-yyyy'), '4', '01', '305', '11', '2046', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17108, to_date('02-11-2046', 'dd-mm-yyyy'), '5', '02', '306', '11', '2046', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17109, to_date('03-11-2046', 'dd-mm-yyyy'), '6', '03', '307', '11', '2046', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17110, to_date('04-11-2046', 'dd-mm-yyyy'), '7', '04', '308', '11', '2046', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17111, to_date('05-11-2046', 'dd-mm-yyyy'), '1', '05', '309', '11', '2046', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17112, to_date('06-11-2046', 'dd-mm-yyyy'), '2', '06', '310', '11', '2046', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17113, to_date('07-11-2046', 'dd-mm-yyyy'), '3', '07', '311', '11', '2046', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17114, to_date('08-11-2046', 'dd-mm-yyyy'), '4', '08', '312', '11', '2046', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17115, to_date('09-11-2046', 'dd-mm-yyyy'), '5', '09', '313', '11', '2046', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17116, to_date('10-11-2046', 'dd-mm-yyyy'), '6', '10', '314', '11', '2046', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17117, to_date('11-11-2046', 'dd-mm-yyyy'), '7', '11', '315', '11', '2046', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17118, to_date('12-11-2046', 'dd-mm-yyyy'), '1', '12', '316', '11', '2046', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17119, to_date('13-11-2046', 'dd-mm-yyyy'), '2', '13', '317', '11', '2046', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17120, to_date('14-11-2046', 'dd-mm-yyyy'), '3', '14', '318', '11', '2046', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17121, to_date('15-11-2046', 'dd-mm-yyyy'), '4', '15', '319', '11', '2046', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17122, to_date('16-11-2046', 'dd-mm-yyyy'), '5', '16', '320', '11', '2046', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17123, to_date('17-11-2046', 'dd-mm-yyyy'), '6', '17', '321', '11', '2046', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17124, to_date('18-11-2046', 'dd-mm-yyyy'), '7', '18', '322', '11', '2046', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17125, to_date('19-11-2046', 'dd-mm-yyyy'), '1', '19', '323', '11', '2046', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17126, to_date('20-11-2046', 'dd-mm-yyyy'), '2', '20', '324', '11', '2046', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17127, to_date('21-11-2046', 'dd-mm-yyyy'), '3', '21', '325', '11', '2046', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17128, to_date('22-11-2046', 'dd-mm-yyyy'), '4', '22', '326', '11', '2046', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17129, to_date('23-11-2046', 'dd-mm-yyyy'), '5', '23', '327', '11', '2046', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17130, to_date('24-11-2046', 'dd-mm-yyyy'), '6', '24', '328', '11', '2046', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17131, to_date('25-11-2046', 'dd-mm-yyyy'), '7', '25', '329', '11', '2046', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17132, to_date('26-11-2046', 'dd-mm-yyyy'), '1', '26', '330', '11', '2046', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17133, to_date('27-11-2046', 'dd-mm-yyyy'), '2', '27', '331', '11', '2046', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17134, to_date('28-11-2046', 'dd-mm-yyyy'), '3', '28', '332', '11', '2046', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17135, to_date('29-11-2046', 'dd-mm-yyyy'), '4', '29', '333', '11', '2046', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17136, to_date('30-11-2046', 'dd-mm-yyyy'), '5', '30', '334', '11', '2046', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17137, to_date('01-12-2046', 'dd-mm-yyyy'), '6', '01', '335', '12', '2046', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17138, to_date('02-12-2046', 'dd-mm-yyyy'), '7', '02', '336', '12', '2046', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17139, to_date('03-12-2046', 'dd-mm-yyyy'), '1', '03', '337', '12', '2046', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17140, to_date('04-12-2046', 'dd-mm-yyyy'), '2', '04', '338', '12', '2046', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17141, to_date('05-12-2046', 'dd-mm-yyyy'), '3', '05', '339', '12', '2046', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17142, to_date('06-12-2046', 'dd-mm-yyyy'), '4', '06', '340', '12', '2046', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17143, to_date('07-12-2046', 'dd-mm-yyyy'), '5', '07', '341', '12', '2046', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17144, to_date('08-12-2046', 'dd-mm-yyyy'), '6', '08', '342', '12', '2046', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17145, to_date('09-12-2046', 'dd-mm-yyyy'), '7', '09', '343', '12', '2046', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17146, to_date('10-12-2046', 'dd-mm-yyyy'), '1', '10', '344', '12', '2046', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18631, to_date('03-01-2051', 'dd-mm-yyyy'), '2', '03', '003', '01', '2051', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18632, to_date('04-01-2051', 'dd-mm-yyyy'), '3', '04', '004', '01', '2051', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18633, to_date('05-01-2051', 'dd-mm-yyyy'), '4', '05', '005', '01', '2051', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18634, to_date('06-01-2051', 'dd-mm-yyyy'), '5', '06', '006', '01', '2051', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18635, to_date('07-01-2051', 'dd-mm-yyyy'), '6', '07', '007', '01', '2051', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18636, to_date('08-01-2051', 'dd-mm-yyyy'), '7', '08', '008', '01', '2051', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18637, to_date('09-01-2051', 'dd-mm-yyyy'), '1', '09', '009', '01', '2051', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18638, to_date('10-01-2051', 'dd-mm-yyyy'), '2', '10', '010', '01', '2051', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18639, to_date('11-01-2051', 'dd-mm-yyyy'), '3', '11', '011', '01', '2051', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18640, to_date('12-01-2051', 'dd-mm-yyyy'), '4', '12', '012', '01', '2051', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18641, to_date('13-01-2051', 'dd-mm-yyyy'), '5', '13', '013', '01', '2051', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18642, to_date('14-01-2051', 'dd-mm-yyyy'), '6', '14', '014', '01', '2051', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18643, to_date('15-01-2051', 'dd-mm-yyyy'), '7', '15', '015', '01', '2051', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18644, to_date('16-01-2051', 'dd-mm-yyyy'), '1', '16', '016', '01', '2051', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18645, to_date('17-01-2051', 'dd-mm-yyyy'), '2', '17', '017', '01', '2051', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18646, to_date('18-01-2051', 'dd-mm-yyyy'), '3', '18', '018', '01', '2051', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18647, to_date('19-01-2051', 'dd-mm-yyyy'), '4', '19', '019', '01', '2051', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18648, to_date('20-01-2051', 'dd-mm-yyyy'), '5', '20', '020', '01', '2051', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18649, to_date('21-01-2051', 'dd-mm-yyyy'), '6', '21', '021', '01', '2051', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18650, to_date('22-01-2051', 'dd-mm-yyyy'), '7', '22', '022', '01', '2051', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18651, to_date('23-01-2051', 'dd-mm-yyyy'), '1', '23', '023', '01', '2051', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18652, to_date('24-01-2051', 'dd-mm-yyyy'), '2', '24', '024', '01', '2051', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18653, to_date('25-01-2051', 'dd-mm-yyyy'), '3', '25', '025', '01', '2051', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18654, to_date('26-01-2051', 'dd-mm-yyyy'), '4', '26', '026', '01', '2051', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18655, to_date('27-01-2051', 'dd-mm-yyyy'), '5', '27', '027', '01', '2051', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18656, to_date('28-01-2051', 'dd-mm-yyyy'), '6', '28', '028', '01', '2051', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18657, to_date('29-01-2051', 'dd-mm-yyyy'), '7', '29', '029', '01', '2051', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18658, to_date('30-01-2051', 'dd-mm-yyyy'), '1', '30', '030', '01', '2051', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18659, to_date('31-01-2051', 'dd-mm-yyyy'), '2', '31', '031', '01', '2051', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18660, to_date('01-02-2051', 'dd-mm-yyyy'), '3', '01', '032', '02', '2051', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18661, to_date('02-02-2051', 'dd-mm-yyyy'), '4', '02', '033', '02', '2051', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18662, to_date('03-02-2051', 'dd-mm-yyyy'), '5', '03', '034', '02', '2051', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18663, to_date('04-02-2051', 'dd-mm-yyyy'), '6', '04', '035', '02', '2051', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18664, to_date('05-02-2051', 'dd-mm-yyyy'), '7', '05', '036', '02', '2051', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18665, to_date('06-02-2051', 'dd-mm-yyyy'), '1', '06', '037', '02', '2051', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18666, to_date('07-02-2051', 'dd-mm-yyyy'), '2', '07', '038', '02', '2051', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18667, to_date('08-02-2051', 'dd-mm-yyyy'), '3', '08', '039', '02', '2051', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18668, to_date('09-02-2051', 'dd-mm-yyyy'), '4', '09', '040', '02', '2051', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18669, to_date('10-02-2051', 'dd-mm-yyyy'), '5', '10', '041', '02', '2051', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18670, to_date('11-02-2051', 'dd-mm-yyyy'), '6', '11', '042', '02', '2051', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18671, to_date('12-02-2051', 'dd-mm-yyyy'), '7', '12', '043', '02', '2051', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18672, to_date('13-02-2051', 'dd-mm-yyyy'), '1', '13', '044', '02', '2051', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18673, to_date('14-02-2051', 'dd-mm-yyyy'), '2', '14', '045', '02', '2051', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18674, to_date('15-02-2051', 'dd-mm-yyyy'), '3', '15', '046', '02', '2051', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18675, to_date('16-02-2051', 'dd-mm-yyyy'), '4', '16', '047', '02', '2051', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18676, to_date('17-02-2051', 'dd-mm-yyyy'), '5', '17', '048', '02', '2051', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18677, to_date('18-02-2051', 'dd-mm-yyyy'), '6', '18', '049', '02', '2051', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18678, to_date('19-02-2051', 'dd-mm-yyyy'), '7', '19', '050', '02', '2051', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18679, to_date('20-02-2051', 'dd-mm-yyyy'), '1', '20', '051', '02', '2051', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18680, to_date('21-02-2051', 'dd-mm-yyyy'), '2', '21', '052', '02', '2051', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18681, to_date('22-02-2051', 'dd-mm-yyyy'), '3', '22', '053', '02', '2051', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18682, to_date('23-02-2051', 'dd-mm-yyyy'), '4', '23', '054', '02', '2051', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18683, to_date('24-02-2051', 'dd-mm-yyyy'), '5', '24', '055', '02', '2051', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18684, to_date('25-02-2051', 'dd-mm-yyyy'), '6', '25', '056', '02', '2051', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18685, to_date('26-02-2051', 'dd-mm-yyyy'), '7', '26', '057', '02', '2051', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18686, to_date('27-02-2051', 'dd-mm-yyyy'), '1', '27', '058', '02', '2051', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18687, to_date('28-02-2051', 'dd-mm-yyyy'), '2', '28', '059', '02', '2051', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18688, to_date('01-03-2051', 'dd-mm-yyyy'), '3', '01', '060', '03', '2051', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18689, to_date('02-03-2051', 'dd-mm-yyyy'), '4', '02', '061', '03', '2051', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18690, to_date('03-03-2051', 'dd-mm-yyyy'), '5', '03', '062', '03', '2051', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18691, to_date('04-03-2051', 'dd-mm-yyyy'), '6', '04', '063', '03', '2051', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18692, to_date('05-03-2051', 'dd-mm-yyyy'), '7', '05', '064', '03', '2051', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18693, to_date('06-03-2051', 'dd-mm-yyyy'), '1', '06', '065', '03', '2051', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18694, to_date('07-03-2051', 'dd-mm-yyyy'), '2', '07', '066', '03', '2051', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18695, to_date('08-03-2051', 'dd-mm-yyyy'), '3', '08', '067', '03', '2051', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18696, to_date('09-03-2051', 'dd-mm-yyyy'), '4', '09', '068', '03', '2051', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18697, to_date('10-03-2051', 'dd-mm-yyyy'), '5', '10', '069', '03', '2051', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18698, to_date('11-03-2051', 'dd-mm-yyyy'), '6', '11', '070', '03', '2051', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18699, to_date('12-03-2051', 'dd-mm-yyyy'), '7', '12', '071', '03', '2051', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18700, to_date('13-03-2051', 'dd-mm-yyyy'), '1', '13', '072', '03', '2051', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18701, to_date('14-03-2051', 'dd-mm-yyyy'), '2', '14', '073', '03', '2051', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18702, to_date('15-03-2051', 'dd-mm-yyyy'), '3', '15', '074', '03', '2051', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18703, to_date('16-03-2051', 'dd-mm-yyyy'), '4', '16', '075', '03', '2051', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18704, to_date('17-03-2051', 'dd-mm-yyyy'), '5', '17', '076', '03', '2051', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18705, to_date('18-03-2051', 'dd-mm-yyyy'), '6', '18', '077', '03', '2051', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18706, to_date('19-03-2051', 'dd-mm-yyyy'), '7', '19', '078', '03', '2051', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18707, to_date('20-03-2051', 'dd-mm-yyyy'), '1', '20', '079', '03', '2051', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18708, to_date('21-03-2051', 'dd-mm-yyyy'), '2', '21', '080', '03', '2051', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18709, to_date('22-03-2051', 'dd-mm-yyyy'), '3', '22', '081', '03', '2051', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18710, to_date('23-03-2051', 'dd-mm-yyyy'), '4', '23', '082', '03', '2051', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18711, to_date('24-03-2051', 'dd-mm-yyyy'), '5', '24', '083', '03', '2051', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18712, to_date('25-03-2051', 'dd-mm-yyyy'), '6', '25', '084', '03', '2051', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18713, to_date('26-03-2051', 'dd-mm-yyyy'), '7', '26', '085', '03', '2051', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18714, to_date('27-03-2051', 'dd-mm-yyyy'), '1', '27', '086', '03', '2051', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18715, to_date('28-03-2051', 'dd-mm-yyyy'), '2', '28', '087', '03', '2051', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18716, to_date('29-03-2051', 'dd-mm-yyyy'), '3', '29', '088', '03', '2051', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18717, to_date('30-03-2051', 'dd-mm-yyyy'), '4', '30', '089', '03', '2051', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18718, to_date('31-03-2051', 'dd-mm-yyyy'), '5', '31', '090', '03', '2051', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18719, to_date('01-04-2051', 'dd-mm-yyyy'), '6', '01', '091', '04', '2051', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18720, to_date('02-04-2051', 'dd-mm-yyyy'), '7', '02', '092', '04', '2051', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18721, to_date('03-04-2051', 'dd-mm-yyyy'), '1', '03', '093', '04', '2051', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18722, to_date('04-04-2051', 'dd-mm-yyyy'), '2', '04', '094', '04', '2051', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18723, to_date('05-04-2051', 'dd-mm-yyyy'), '3', '05', '095', '04', '2051', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18724, to_date('06-04-2051', 'dd-mm-yyyy'), '4', '06', '096', '04', '2051', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18725, to_date('07-04-2051', 'dd-mm-yyyy'), '5', '07', '097', '04', '2051', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18726, to_date('08-04-2051', 'dd-mm-yyyy'), '6', '08', '098', '04', '2051', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18727, to_date('09-04-2051', 'dd-mm-yyyy'), '7', '09', '099', '04', '2051', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18728, to_date('10-04-2051', 'dd-mm-yyyy'), '1', '10', '100', '04', '2051', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18729, to_date('11-04-2051', 'dd-mm-yyyy'), '2', '11', '101', '04', '2051', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18730, to_date('12-04-2051', 'dd-mm-yyyy'), '3', '12', '102', '04', '2051', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18731, to_date('13-04-2051', 'dd-mm-yyyy'), '4', '13', '103', '04', '2051', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18732, to_date('14-04-2051', 'dd-mm-yyyy'), '5', '14', '104', '04', '2051', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18733, to_date('15-04-2051', 'dd-mm-yyyy'), '6', '15', '105', '04', '2051', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18734, to_date('16-04-2051', 'dd-mm-yyyy'), '7', '16', '106', '04', '2051', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18735, to_date('17-04-2051', 'dd-mm-yyyy'), '1', '17', '107', '04', '2051', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18736, to_date('18-04-2051', 'dd-mm-yyyy'), '2', '18', '108', '04', '2051', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13861, to_date('12-12-2037', 'dd-mm-yyyy'), '6', '12', '346', '12', '2037', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13862, to_date('13-12-2037', 'dd-mm-yyyy'), '7', '13', '347', '12', '2037', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13863, to_date('14-12-2037', 'dd-mm-yyyy'), '1', '14', '348', '12', '2037', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13864, to_date('15-12-2037', 'dd-mm-yyyy'), '2', '15', '349', '12', '2037', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13865, to_date('16-12-2037', 'dd-mm-yyyy'), '3', '16', '350', '12', '2037', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13866, to_date('17-12-2037', 'dd-mm-yyyy'), '4', '17', '351', '12', '2037', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13867, to_date('18-12-2037', 'dd-mm-yyyy'), '5', '18', '352', '12', '2037', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13868, to_date('19-12-2037', 'dd-mm-yyyy'), '6', '19', '353', '12', '2037', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13869, to_date('20-12-2037', 'dd-mm-yyyy'), '7', '20', '354', '12', '2037', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13870, to_date('21-12-2037', 'dd-mm-yyyy'), '1', '21', '355', '12', '2037', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13871, to_date('22-12-2037', 'dd-mm-yyyy'), '2', '22', '356', '12', '2037', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13872, to_date('23-12-2037', 'dd-mm-yyyy'), '3', '23', '357', '12', '2037', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13873, to_date('24-12-2037', 'dd-mm-yyyy'), '4', '24', '358', '12', '2037', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13874, to_date('25-12-2037', 'dd-mm-yyyy'), '5', '25', '359', '12', '2037', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13875, to_date('26-12-2037', 'dd-mm-yyyy'), '6', '26', '360', '12', '2037', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13876, to_date('27-12-2037', 'dd-mm-yyyy'), '7', '27', '361', '12', '2037', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13877, to_date('28-12-2037', 'dd-mm-yyyy'), '1', '28', '362', '12', '2037', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13878, to_date('29-12-2037', 'dd-mm-yyyy'), '2', '29', '363', '12', '2037', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13879, to_date('30-12-2037', 'dd-mm-yyyy'), '3', '30', '364', '12', '2037', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13880, to_date('31-12-2037', 'dd-mm-yyyy'), '4', '31', '365', '12', '2037', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13881, to_date('01-01-2038', 'dd-mm-yyyy'), '5', '01', '001', '01', '2038', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13882, to_date('02-01-2038', 'dd-mm-yyyy'), '6', '02', '002', '01', '2038', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13883, to_date('03-01-2038', 'dd-mm-yyyy'), '7', '03', '003', '01', '2038', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13884, to_date('04-01-2038', 'dd-mm-yyyy'), '1', '04', '004', '01', '2038', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13885, to_date('05-01-2038', 'dd-mm-yyyy'), '2', '05', '005', '01', '2038', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13886, to_date('06-01-2038', 'dd-mm-yyyy'), '3', '06', '006', '01', '2038', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13887, to_date('07-01-2038', 'dd-mm-yyyy'), '4', '07', '007', '01', '2038', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13888, to_date('08-01-2038', 'dd-mm-yyyy'), '5', '08', '008', '01', '2038', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13889, to_date('09-01-2038', 'dd-mm-yyyy'), '6', '09', '009', '01', '2038', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13890, to_date('10-01-2038', 'dd-mm-yyyy'), '7', '10', '010', '01', '2038', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13891, to_date('11-01-2038', 'dd-mm-yyyy'), '1', '11', '011', '01', '2038', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13892, to_date('12-01-2038', 'dd-mm-yyyy'), '2', '12', '012', '01', '2038', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13893, to_date('13-01-2038', 'dd-mm-yyyy'), '3', '13', '013', '01', '2038', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13894, to_date('14-01-2038', 'dd-mm-yyyy'), '4', '14', '014', '01', '2038', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13895, to_date('15-01-2038', 'dd-mm-yyyy'), '5', '15', '015', '01', '2038', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13896, to_date('16-01-2038', 'dd-mm-yyyy'), '6', '16', '016', '01', '2038', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13897, to_date('17-01-2038', 'dd-mm-yyyy'), '7', '17', '017', '01', '2038', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13898, to_date('18-01-2038', 'dd-mm-yyyy'), '1', '18', '018', '01', '2038', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13899, to_date('19-01-2038', 'dd-mm-yyyy'), '2', '19', '019', '01', '2038', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13900, to_date('20-01-2038', 'dd-mm-yyyy'), '3', '20', '020', '01', '2038', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13901, to_date('21-01-2038', 'dd-mm-yyyy'), '4', '21', '021', '01', '2038', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13902, to_date('22-01-2038', 'dd-mm-yyyy'), '5', '22', '022', '01', '2038', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13903, to_date('23-01-2038', 'dd-mm-yyyy'), '6', '23', '023', '01', '2038', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13904, to_date('24-01-2038', 'dd-mm-yyyy'), '7', '24', '024', '01', '2038', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13905, to_date('25-01-2038', 'dd-mm-yyyy'), '1', '25', '025', '01', '2038', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13906, to_date('26-01-2038', 'dd-mm-yyyy'), '2', '26', '026', '01', '2038', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13907, to_date('27-01-2038', 'dd-mm-yyyy'), '3', '27', '027', '01', '2038', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13908, to_date('28-01-2038', 'dd-mm-yyyy'), '4', '28', '028', '01', '2038', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13909, to_date('29-01-2038', 'dd-mm-yyyy'), '5', '29', '029', '01', '2038', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13910, to_date('30-01-2038', 'dd-mm-yyyy'), '6', '30', '030', '01', '2038', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13911, to_date('31-01-2038', 'dd-mm-yyyy'), '7', '31', '031', '01', '2038', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13912, to_date('01-02-2038', 'dd-mm-yyyy'), '1', '01', '032', '02', '2038', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13913, to_date('02-02-2038', 'dd-mm-yyyy'), '2', '02', '033', '02', '2038', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13914, to_date('03-02-2038', 'dd-mm-yyyy'), '3', '03', '034', '02', '2038', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13915, to_date('04-02-2038', 'dd-mm-yyyy'), '4', '04', '035', '02', '2038', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13916, to_date('05-02-2038', 'dd-mm-yyyy'), '5', '05', '036', '02', '2038', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13917, to_date('06-02-2038', 'dd-mm-yyyy'), '6', '06', '037', '02', '2038', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13918, to_date('07-02-2038', 'dd-mm-yyyy'), '7', '07', '038', '02', '2038', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13919, to_date('08-02-2038', 'dd-mm-yyyy'), '1', '08', '039', '02', '2038', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13920, to_date('09-02-2038', 'dd-mm-yyyy'), '2', '09', '040', '02', '2038', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13921, to_date('10-02-2038', 'dd-mm-yyyy'), '3', '10', '041', '02', '2038', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13922, to_date('11-02-2038', 'dd-mm-yyyy'), '4', '11', '042', '02', '2038', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13923, to_date('12-02-2038', 'dd-mm-yyyy'), '5', '12', '043', '02', '2038', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13924, to_date('13-02-2038', 'dd-mm-yyyy'), '6', '13', '044', '02', '2038', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13925, to_date('14-02-2038', 'dd-mm-yyyy'), '7', '14', '045', '02', '2038', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13926, to_date('15-02-2038', 'dd-mm-yyyy'), '1', '15', '046', '02', '2038', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13927, to_date('16-02-2038', 'dd-mm-yyyy'), '2', '16', '047', '02', '2038', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13928, to_date('17-02-2038', 'dd-mm-yyyy'), '3', '17', '048', '02', '2038', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13929, to_date('18-02-2038', 'dd-mm-yyyy'), '4', '18', '049', '02', '2038', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13930, to_date('19-02-2038', 'dd-mm-yyyy'), '5', '19', '050', '02', '2038', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13931, to_date('20-02-2038', 'dd-mm-yyyy'), '6', '20', '051', '02', '2038', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13932, to_date('21-02-2038', 'dd-mm-yyyy'), '7', '21', '052', '02', '2038', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13933, to_date('22-02-2038', 'dd-mm-yyyy'), '1', '22', '053', '02', '2038', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13934, to_date('23-02-2038', 'dd-mm-yyyy'), '2', '23', '054', '02', '2038', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13935, to_date('24-02-2038', 'dd-mm-yyyy'), '3', '24', '055', '02', '2038', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13936, to_date('25-02-2038', 'dd-mm-yyyy'), '4', '25', '056', '02', '2038', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13937, to_date('26-02-2038', 'dd-mm-yyyy'), '5', '26', '057', '02', '2038', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13938, to_date('27-02-2038', 'dd-mm-yyyy'), '6', '27', '058', '02', '2038', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13939, to_date('28-02-2038', 'dd-mm-yyyy'), '7', '28', '059', '02', '2038', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13940, to_date('01-03-2038', 'dd-mm-yyyy'), '1', '01', '060', '03', '2038', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13941, to_date('02-03-2038', 'dd-mm-yyyy'), '2', '02', '061', '03', '2038', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13942, to_date('03-03-2038', 'dd-mm-yyyy'), '3', '03', '062', '03', '2038', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13943, to_date('04-03-2038', 'dd-mm-yyyy'), '4', '04', '063', '03', '2038', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13944, to_date('05-03-2038', 'dd-mm-yyyy'), '5', '05', '064', '03', '2038', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13945, to_date('06-03-2038', 'dd-mm-yyyy'), '6', '06', '065', '03', '2038', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13946, to_date('07-03-2038', 'dd-mm-yyyy'), '7', '07', '066', '03', '2038', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13947, to_date('08-03-2038', 'dd-mm-yyyy'), '1', '08', '067', '03', '2038', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13948, to_date('09-03-2038', 'dd-mm-yyyy'), '2', '09', '068', '03', '2038', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13949, to_date('10-03-2038', 'dd-mm-yyyy'), '3', '10', '069', '03', '2038', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13950, to_date('11-03-2038', 'dd-mm-yyyy'), '4', '11', '070', '03', '2038', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13951, to_date('12-03-2038', 'dd-mm-yyyy'), '5', '12', '071', '03', '2038', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13952, to_date('13-03-2038', 'dd-mm-yyyy'), '6', '13', '072', '03', '2038', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13953, to_date('14-03-2038', 'dd-mm-yyyy'), '7', '14', '073', '03', '2038', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13954, to_date('15-03-2038', 'dd-mm-yyyy'), '1', '15', '074', '03', '2038', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13955, to_date('16-03-2038', 'dd-mm-yyyy'), '2', '16', '075', '03', '2038', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13956, to_date('17-03-2038', 'dd-mm-yyyy'), '3', '17', '076', '03', '2038', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13957, to_date('18-03-2038', 'dd-mm-yyyy'), '4', '18', '077', '03', '2038', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13958, to_date('19-03-2038', 'dd-mm-yyyy'), '5', '19', '078', '03', '2038', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13959, to_date('20-03-2038', 'dd-mm-yyyy'), '6', '20', '079', '03', '2038', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13960, to_date('21-03-2038', 'dd-mm-yyyy'), '7', '21', '080', '03', '2038', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13961, to_date('22-03-2038', 'dd-mm-yyyy'), '1', '22', '081', '03', '2038', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13962, to_date('23-03-2038', 'dd-mm-yyyy'), '2', '23', '082', '03', '2038', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13963, to_date('24-03-2038', 'dd-mm-yyyy'), '3', '24', '083', '03', '2038', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13964, to_date('25-03-2038', 'dd-mm-yyyy'), '4', '25', '084', '03', '2038', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13965, to_date('26-03-2038', 'dd-mm-yyyy'), '5', '26', '085', '03', '2038', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13966, to_date('27-03-2038', 'dd-mm-yyyy'), '6', '27', '086', '03', '2038', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15557, to_date('04-08-2042', 'dd-mm-yyyy'), '1', '04', '216', '08', '2042', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15558, to_date('05-08-2042', 'dd-mm-yyyy'), '2', '05', '217', '08', '2042', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15559, to_date('06-08-2042', 'dd-mm-yyyy'), '3', '06', '218', '08', '2042', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15560, to_date('07-08-2042', 'dd-mm-yyyy'), '4', '07', '219', '08', '2042', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15561, to_date('08-08-2042', 'dd-mm-yyyy'), '5', '08', '220', '08', '2042', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15562, to_date('09-08-2042', 'dd-mm-yyyy'), '6', '09', '221', '08', '2042', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15563, to_date('10-08-2042', 'dd-mm-yyyy'), '7', '10', '222', '08', '2042', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15564, to_date('11-08-2042', 'dd-mm-yyyy'), '1', '11', '223', '08', '2042', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15565, to_date('12-08-2042', 'dd-mm-yyyy'), '2', '12', '224', '08', '2042', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15566, to_date('13-08-2042', 'dd-mm-yyyy'), '3', '13', '225', '08', '2042', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15567, to_date('14-08-2042', 'dd-mm-yyyy'), '4', '14', '226', '08', '2042', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15568, to_date('15-08-2042', 'dd-mm-yyyy'), '5', '15', '227', '08', '2042', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15569, to_date('16-08-2042', 'dd-mm-yyyy'), '6', '16', '228', '08', '2042', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15570, to_date('17-08-2042', 'dd-mm-yyyy'), '7', '17', '229', '08', '2042', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15571, to_date('18-08-2042', 'dd-mm-yyyy'), '1', '18', '230', '08', '2042', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15572, to_date('19-08-2042', 'dd-mm-yyyy'), '2', '19', '231', '08', '2042', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15573, to_date('20-08-2042', 'dd-mm-yyyy'), '3', '20', '232', '08', '2042', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15574, to_date('21-08-2042', 'dd-mm-yyyy'), '4', '21', '233', '08', '2042', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15575, to_date('22-08-2042', 'dd-mm-yyyy'), '5', '22', '234', '08', '2042', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15576, to_date('23-08-2042', 'dd-mm-yyyy'), '6', '23', '235', '08', '2042', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15577, to_date('24-08-2042', 'dd-mm-yyyy'), '7', '24', '236', '08', '2042', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15578, to_date('25-08-2042', 'dd-mm-yyyy'), '1', '25', '237', '08', '2042', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15579, to_date('26-08-2042', 'dd-mm-yyyy'), '2', '26', '238', '08', '2042', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15580, to_date('27-08-2042', 'dd-mm-yyyy'), '3', '27', '239', '08', '2042', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15581, to_date('28-08-2042', 'dd-mm-yyyy'), '4', '28', '240', '08', '2042', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15582, to_date('29-08-2042', 'dd-mm-yyyy'), '5', '29', '241', '08', '2042', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15583, to_date('30-08-2042', 'dd-mm-yyyy'), '6', '30', '242', '08', '2042', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15584, to_date('31-08-2042', 'dd-mm-yyyy'), '7', '31', '243', '08', '2042', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15585, to_date('01-09-2042', 'dd-mm-yyyy'), '1', '01', '244', '09', '2042', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15586, to_date('02-09-2042', 'dd-mm-yyyy'), '2', '02', '245', '09', '2042', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15587, to_date('03-09-2042', 'dd-mm-yyyy'), '3', '03', '246', '09', '2042', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15588, to_date('04-09-2042', 'dd-mm-yyyy'), '4', '04', '247', '09', '2042', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15589, to_date('05-09-2042', 'dd-mm-yyyy'), '5', '05', '248', '09', '2042', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15590, to_date('06-09-2042', 'dd-mm-yyyy'), '6', '06', '249', '09', '2042', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15591, to_date('07-09-2042', 'dd-mm-yyyy'), '7', '07', '250', '09', '2042', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15592, to_date('08-09-2042', 'dd-mm-yyyy'), '1', '08', '251', '09', '2042', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15593, to_date('09-09-2042', 'dd-mm-yyyy'), '2', '09', '252', '09', '2042', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15594, to_date('10-09-2042', 'dd-mm-yyyy'), '3', '10', '253', '09', '2042', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15595, to_date('11-09-2042', 'dd-mm-yyyy'), '4', '11', '254', '09', '2042', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15596, to_date('12-09-2042', 'dd-mm-yyyy'), '5', '12', '255', '09', '2042', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15597, to_date('13-09-2042', 'dd-mm-yyyy'), '6', '13', '256', '09', '2042', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15598, to_date('14-09-2042', 'dd-mm-yyyy'), '7', '14', '257', '09', '2042', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15599, to_date('15-09-2042', 'dd-mm-yyyy'), '1', '15', '258', '09', '2042', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15600, to_date('16-09-2042', 'dd-mm-yyyy'), '2', '16', '259', '09', '2042', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15601, to_date('17-09-2042', 'dd-mm-yyyy'), '3', '17', '260', '09', '2042', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15602, to_date('18-09-2042', 'dd-mm-yyyy'), '4', '18', '261', '09', '2042', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15603, to_date('19-09-2042', 'dd-mm-yyyy'), '5', '19', '262', '09', '2042', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15604, to_date('20-09-2042', 'dd-mm-yyyy'), '6', '20', '263', '09', '2042', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15605, to_date('21-09-2042', 'dd-mm-yyyy'), '7', '21', '264', '09', '2042', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15606, to_date('22-09-2042', 'dd-mm-yyyy'), '1', '22', '265', '09', '2042', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15607, to_date('23-09-2042', 'dd-mm-yyyy'), '2', '23', '266', '09', '2042', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15608, to_date('24-09-2042', 'dd-mm-yyyy'), '3', '24', '267', '09', '2042', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15609, to_date('25-09-2042', 'dd-mm-yyyy'), '4', '25', '268', '09', '2042', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15610, to_date('26-09-2042', 'dd-mm-yyyy'), '5', '26', '269', '09', '2042', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15611, to_date('27-09-2042', 'dd-mm-yyyy'), '6', '27', '270', '09', '2042', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15612, to_date('28-09-2042', 'dd-mm-yyyy'), '7', '28', '271', '09', '2042', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15613, to_date('29-09-2042', 'dd-mm-yyyy'), '1', '29', '272', '09', '2042', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15614, to_date('30-09-2042', 'dd-mm-yyyy'), '2', '30', '273', '09', '2042', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15615, to_date('01-10-2042', 'dd-mm-yyyy'), '3', '01', '274', '10', '2042', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15616, to_date('02-10-2042', 'dd-mm-yyyy'), '4', '02', '275', '10', '2042', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15617, to_date('03-10-2042', 'dd-mm-yyyy'), '5', '03', '276', '10', '2042', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15618, to_date('04-10-2042', 'dd-mm-yyyy'), '6', '04', '277', '10', '2042', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15619, to_date('05-10-2042', 'dd-mm-yyyy'), '7', '05', '278', '10', '2042', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15620, to_date('06-10-2042', 'dd-mm-yyyy'), '1', '06', '279', '10', '2042', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15621, to_date('07-10-2042', 'dd-mm-yyyy'), '2', '07', '280', '10', '2042', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15622, to_date('08-10-2042', 'dd-mm-yyyy'), '3', '08', '281', '10', '2042', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15623, to_date('09-10-2042', 'dd-mm-yyyy'), '4', '09', '282', '10', '2042', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15624, to_date('10-10-2042', 'dd-mm-yyyy'), '5', '10', '283', '10', '2042', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15625, to_date('11-10-2042', 'dd-mm-yyyy'), '6', '11', '284', '10', '2042', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15626, to_date('12-10-2042', 'dd-mm-yyyy'), '7', '12', '285', '10', '2042', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15627, to_date('13-10-2042', 'dd-mm-yyyy'), '1', '13', '286', '10', '2042', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15628, to_date('14-10-2042', 'dd-mm-yyyy'), '2', '14', '287', '10', '2042', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15629, to_date('15-10-2042', 'dd-mm-yyyy'), '3', '15', '288', '10', '2042', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15630, to_date('16-10-2042', 'dd-mm-yyyy'), '4', '16', '289', '10', '2042', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15631, to_date('17-10-2042', 'dd-mm-yyyy'), '5', '17', '290', '10', '2042', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15632, to_date('18-10-2042', 'dd-mm-yyyy'), '6', '18', '291', '10', '2042', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15633, to_date('19-10-2042', 'dd-mm-yyyy'), '7', '19', '292', '10', '2042', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15634, to_date('20-10-2042', 'dd-mm-yyyy'), '1', '20', '293', '10', '2042', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15635, to_date('21-10-2042', 'dd-mm-yyyy'), '2', '21', '294', '10', '2042', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15636, to_date('22-10-2042', 'dd-mm-yyyy'), '3', '22', '295', '10', '2042', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15637, to_date('23-10-2042', 'dd-mm-yyyy'), '4', '23', '296', '10', '2042', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15638, to_date('24-10-2042', 'dd-mm-yyyy'), '5', '24', '297', '10', '2042', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15639, to_date('25-10-2042', 'dd-mm-yyyy'), '6', '25', '298', '10', '2042', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15640, to_date('26-10-2042', 'dd-mm-yyyy'), '7', '26', '299', '10', '2042', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15641, to_date('27-10-2042', 'dd-mm-yyyy'), '1', '27', '300', '10', '2042', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15642, to_date('28-10-2042', 'dd-mm-yyyy'), '2', '28', '301', '10', '2042', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15643, to_date('29-10-2042', 'dd-mm-yyyy'), '3', '29', '302', '10', '2042', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15644, to_date('30-10-2042', 'dd-mm-yyyy'), '4', '30', '303', '10', '2042', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15645, to_date('31-10-2042', 'dd-mm-yyyy'), '5', '31', '304', '10', '2042', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15646, to_date('01-11-2042', 'dd-mm-yyyy'), '6', '01', '305', '11', '2042', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15647, to_date('02-11-2042', 'dd-mm-yyyy'), '7', '02', '306', '11', '2042', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15648, to_date('03-11-2042', 'dd-mm-yyyy'), '1', '03', '307', '11', '2042', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15649, to_date('04-11-2042', 'dd-mm-yyyy'), '2', '04', '308', '11', '2042', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15650, to_date('05-11-2042', 'dd-mm-yyyy'), '3', '05', '309', '11', '2042', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15651, to_date('06-11-2042', 'dd-mm-yyyy'), '4', '06', '310', '11', '2042', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15652, to_date('07-11-2042', 'dd-mm-yyyy'), '5', '07', '311', '11', '2042', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15653, to_date('08-11-2042', 'dd-mm-yyyy'), '6', '08', '312', '11', '2042', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15654, to_date('09-11-2042', 'dd-mm-yyyy'), '7', '09', '313', '11', '2042', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15655, to_date('10-11-2042', 'dd-mm-yyyy'), '1', '10', '314', '11', '2042', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15656, to_date('11-11-2042', 'dd-mm-yyyy'), '2', '11', '315', '11', '2042', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15657, to_date('12-11-2042', 'dd-mm-yyyy'), '3', '12', '316', '11', '2042', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15658, to_date('13-11-2042', 'dd-mm-yyyy'), '4', '13', '317', '11', '2042', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15659, to_date('14-11-2042', 'dd-mm-yyyy'), '5', '14', '318', '11', '2042', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15660, to_date('15-11-2042', 'dd-mm-yyyy'), '6', '15', '319', '11', '2042', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15661, to_date('16-11-2042', 'dd-mm-yyyy'), '7', '16', '320', '11', '2042', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15662, to_date('17-11-2042', 'dd-mm-yyyy'), '1', '17', '321', '11', '2042', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17147, to_date('11-12-2046', 'dd-mm-yyyy'), '2', '11', '345', '12', '2046', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17148, to_date('12-12-2046', 'dd-mm-yyyy'), '3', '12', '346', '12', '2046', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17149, to_date('13-12-2046', 'dd-mm-yyyy'), '4', '13', '347', '12', '2046', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17150, to_date('14-12-2046', 'dd-mm-yyyy'), '5', '14', '348', '12', '2046', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17151, to_date('15-12-2046', 'dd-mm-yyyy'), '6', '15', '349', '12', '2046', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17152, to_date('16-12-2046', 'dd-mm-yyyy'), '7', '16', '350', '12', '2046', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17153, to_date('17-12-2046', 'dd-mm-yyyy'), '1', '17', '351', '12', '2046', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17154, to_date('18-12-2046', 'dd-mm-yyyy'), '2', '18', '352', '12', '2046', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17155, to_date('19-12-2046', 'dd-mm-yyyy'), '3', '19', '353', '12', '2046', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17156, to_date('20-12-2046', 'dd-mm-yyyy'), '4', '20', '354', '12', '2046', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17157, to_date('21-12-2046', 'dd-mm-yyyy'), '5', '21', '355', '12', '2046', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17158, to_date('22-12-2046', 'dd-mm-yyyy'), '6', '22', '356', '12', '2046', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17159, to_date('23-12-2046', 'dd-mm-yyyy'), '7', '23', '357', '12', '2046', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17160, to_date('24-12-2046', 'dd-mm-yyyy'), '1', '24', '358', '12', '2046', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17161, to_date('25-12-2046', 'dd-mm-yyyy'), '2', '25', '359', '12', '2046', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17162, to_date('26-12-2046', 'dd-mm-yyyy'), '3', '26', '360', '12', '2046', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17163, to_date('27-12-2046', 'dd-mm-yyyy'), '4', '27', '361', '12', '2046', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17164, to_date('28-12-2046', 'dd-mm-yyyy'), '5', '28', '362', '12', '2046', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17165, to_date('29-12-2046', 'dd-mm-yyyy'), '6', '29', '363', '12', '2046', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17166, to_date('30-12-2046', 'dd-mm-yyyy'), '7', '30', '364', '12', '2046', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17167, to_date('31-12-2046', 'dd-mm-yyyy'), '1', '31', '365', '12', '2046', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17168, to_date('01-01-2047', 'dd-mm-yyyy'), '2', '01', '001', '01', '2047', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17169, to_date('02-01-2047', 'dd-mm-yyyy'), '3', '02', '002', '01', '2047', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17170, to_date('03-01-2047', 'dd-mm-yyyy'), '4', '03', '003', '01', '2047', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17171, to_date('04-01-2047', 'dd-mm-yyyy'), '5', '04', '004', '01', '2047', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17172, to_date('05-01-2047', 'dd-mm-yyyy'), '6', '05', '005', '01', '2047', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17173, to_date('06-01-2047', 'dd-mm-yyyy'), '7', '06', '006', '01', '2047', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17174, to_date('07-01-2047', 'dd-mm-yyyy'), '1', '07', '007', '01', '2047', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17175, to_date('08-01-2047', 'dd-mm-yyyy'), '2', '08', '008', '01', '2047', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17176, to_date('09-01-2047', 'dd-mm-yyyy'), '3', '09', '009', '01', '2047', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17177, to_date('10-01-2047', 'dd-mm-yyyy'), '4', '10', '010', '01', '2047', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17178, to_date('11-01-2047', 'dd-mm-yyyy'), '5', '11', '011', '01', '2047', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17179, to_date('12-01-2047', 'dd-mm-yyyy'), '6', '12', '012', '01', '2047', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17180, to_date('13-01-2047', 'dd-mm-yyyy'), '7', '13', '013', '01', '2047', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17181, to_date('14-01-2047', 'dd-mm-yyyy'), '1', '14', '014', '01', '2047', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17182, to_date('15-01-2047', 'dd-mm-yyyy'), '2', '15', '015', '01', '2047', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17183, to_date('16-01-2047', 'dd-mm-yyyy'), '3', '16', '016', '01', '2047', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17184, to_date('17-01-2047', 'dd-mm-yyyy'), '4', '17', '017', '01', '2047', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17185, to_date('18-01-2047', 'dd-mm-yyyy'), '5', '18', '018', '01', '2047', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17186, to_date('19-01-2047', 'dd-mm-yyyy'), '6', '19', '019', '01', '2047', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17187, to_date('20-01-2047', 'dd-mm-yyyy'), '7', '20', '020', '01', '2047', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17188, to_date('21-01-2047', 'dd-mm-yyyy'), '1', '21', '021', '01', '2047', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17189, to_date('22-01-2047', 'dd-mm-yyyy'), '2', '22', '022', '01', '2047', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17190, to_date('23-01-2047', 'dd-mm-yyyy'), '3', '23', '023', '01', '2047', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17191, to_date('24-01-2047', 'dd-mm-yyyy'), '4', '24', '024', '01', '2047', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17192, to_date('25-01-2047', 'dd-mm-yyyy'), '5', '25', '025', '01', '2047', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17193, to_date('26-01-2047', 'dd-mm-yyyy'), '6', '26', '026', '01', '2047', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17194, to_date('27-01-2047', 'dd-mm-yyyy'), '7', '27', '027', '01', '2047', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17195, to_date('28-01-2047', 'dd-mm-yyyy'), '1', '28', '028', '01', '2047', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17196, to_date('29-01-2047', 'dd-mm-yyyy'), '2', '29', '029', '01', '2047', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17197, to_date('30-01-2047', 'dd-mm-yyyy'), '3', '30', '030', '01', '2047', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17198, to_date('31-01-2047', 'dd-mm-yyyy'), '4', '31', '031', '01', '2047', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17199, to_date('01-02-2047', 'dd-mm-yyyy'), '5', '01', '032', '02', '2047', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17200, to_date('02-02-2047', 'dd-mm-yyyy'), '6', '02', '033', '02', '2047', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17201, to_date('03-02-2047', 'dd-mm-yyyy'), '7', '03', '034', '02', '2047', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17202, to_date('04-02-2047', 'dd-mm-yyyy'), '1', '04', '035', '02', '2047', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17203, to_date('05-02-2047', 'dd-mm-yyyy'), '2', '05', '036', '02', '2047', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17204, to_date('06-02-2047', 'dd-mm-yyyy'), '3', '06', '037', '02', '2047', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17205, to_date('07-02-2047', 'dd-mm-yyyy'), '4', '07', '038', '02', '2047', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17206, to_date('08-02-2047', 'dd-mm-yyyy'), '5', '08', '039', '02', '2047', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17207, to_date('09-02-2047', 'dd-mm-yyyy'), '6', '09', '040', '02', '2047', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17208, to_date('10-02-2047', 'dd-mm-yyyy'), '7', '10', '041', '02', '2047', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17209, to_date('11-02-2047', 'dd-mm-yyyy'), '1', '11', '042', '02', '2047', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17210, to_date('12-02-2047', 'dd-mm-yyyy'), '2', '12', '043', '02', '2047', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17211, to_date('13-02-2047', 'dd-mm-yyyy'), '3', '13', '044', '02', '2047', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17212, to_date('14-02-2047', 'dd-mm-yyyy'), '4', '14', '045', '02', '2047', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17213, to_date('15-02-2047', 'dd-mm-yyyy'), '5', '15', '046', '02', '2047', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17214, to_date('16-02-2047', 'dd-mm-yyyy'), '6', '16', '047', '02', '2047', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17215, to_date('17-02-2047', 'dd-mm-yyyy'), '7', '17', '048', '02', '2047', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17216, to_date('18-02-2047', 'dd-mm-yyyy'), '1', '18', '049', '02', '2047', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17217, to_date('19-02-2047', 'dd-mm-yyyy'), '2', '19', '050', '02', '2047', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17218, to_date('20-02-2047', 'dd-mm-yyyy'), '3', '20', '051', '02', '2047', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17219, to_date('21-02-2047', 'dd-mm-yyyy'), '4', '21', '052', '02', '2047', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17220, to_date('22-02-2047', 'dd-mm-yyyy'), '5', '22', '053', '02', '2047', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17221, to_date('23-02-2047', 'dd-mm-yyyy'), '6', '23', '054', '02', '2047', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17222, to_date('24-02-2047', 'dd-mm-yyyy'), '7', '24', '055', '02', '2047', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17223, to_date('25-02-2047', 'dd-mm-yyyy'), '1', '25', '056', '02', '2047', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17224, to_date('26-02-2047', 'dd-mm-yyyy'), '2', '26', '057', '02', '2047', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17225, to_date('27-02-2047', 'dd-mm-yyyy'), '3', '27', '058', '02', '2047', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17226, to_date('28-02-2047', 'dd-mm-yyyy'), '4', '28', '059', '02', '2047', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17227, to_date('01-03-2047', 'dd-mm-yyyy'), '5', '01', '060', '03', '2047', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17228, to_date('02-03-2047', 'dd-mm-yyyy'), '6', '02', '061', '03', '2047', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17229, to_date('03-03-2047', 'dd-mm-yyyy'), '7', '03', '062', '03', '2047', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17230, to_date('04-03-2047', 'dd-mm-yyyy'), '1', '04', '063', '03', '2047', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17231, to_date('05-03-2047', 'dd-mm-yyyy'), '2', '05', '064', '03', '2047', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17232, to_date('06-03-2047', 'dd-mm-yyyy'), '3', '06', '065', '03', '2047', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17233, to_date('07-03-2047', 'dd-mm-yyyy'), '4', '07', '066', '03', '2047', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17234, to_date('08-03-2047', 'dd-mm-yyyy'), '5', '08', '067', '03', '2047', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17235, to_date('09-03-2047', 'dd-mm-yyyy'), '6', '09', '068', '03', '2047', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17236, to_date('10-03-2047', 'dd-mm-yyyy'), '7', '10', '069', '03', '2047', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17237, to_date('11-03-2047', 'dd-mm-yyyy'), '1', '11', '070', '03', '2047', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17238, to_date('12-03-2047', 'dd-mm-yyyy'), '2', '12', '071', '03', '2047', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17239, to_date('13-03-2047', 'dd-mm-yyyy'), '3', '13', '072', '03', '2047', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17240, to_date('14-03-2047', 'dd-mm-yyyy'), '4', '14', '073', '03', '2047', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17241, to_date('15-03-2047', 'dd-mm-yyyy'), '5', '15', '074', '03', '2047', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17242, to_date('16-03-2047', 'dd-mm-yyyy'), '6', '16', '075', '03', '2047', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17243, to_date('17-03-2047', 'dd-mm-yyyy'), '7', '17', '076', '03', '2047', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17244, to_date('18-03-2047', 'dd-mm-yyyy'), '1', '18', '077', '03', '2047', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17245, to_date('19-03-2047', 'dd-mm-yyyy'), '2', '19', '078', '03', '2047', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17246, to_date('20-03-2047', 'dd-mm-yyyy'), '3', '20', '079', '03', '2047', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17247, to_date('21-03-2047', 'dd-mm-yyyy'), '4', '21', '080', '03', '2047', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17248, to_date('22-03-2047', 'dd-mm-yyyy'), '5', '22', '081', '03', '2047', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17249, to_date('23-03-2047', 'dd-mm-yyyy'), '6', '23', '082', '03', '2047', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17250, to_date('24-03-2047', 'dd-mm-yyyy'), '7', '24', '083', '03', '2047', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17251, to_date('25-03-2047', 'dd-mm-yyyy'), '1', '25', '084', '03', '2047', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17252, to_date('26-03-2047', 'dd-mm-yyyy'), '2', '26', '085', '03', '2047', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18737, to_date('19-04-2051', 'dd-mm-yyyy'), '3', '19', '109', '04', '2051', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18738, to_date('20-04-2051', 'dd-mm-yyyy'), '4', '20', '110', '04', '2051', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18739, to_date('21-04-2051', 'dd-mm-yyyy'), '5', '21', '111', '04', '2051', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18740, to_date('22-04-2051', 'dd-mm-yyyy'), '6', '22', '112', '04', '2051', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18741, to_date('23-04-2051', 'dd-mm-yyyy'), '7', '23', '113', '04', '2051', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18742, to_date('24-04-2051', 'dd-mm-yyyy'), '1', '24', '114', '04', '2051', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18743, to_date('25-04-2051', 'dd-mm-yyyy'), '2', '25', '115', '04', '2051', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18744, to_date('26-04-2051', 'dd-mm-yyyy'), '3', '26', '116', '04', '2051', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18745, to_date('27-04-2051', 'dd-mm-yyyy'), '4', '27', '117', '04', '2051', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18746, to_date('28-04-2051', 'dd-mm-yyyy'), '5', '28', '118', '04', '2051', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
commit;
prompt 25000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18747, to_date('29-04-2051', 'dd-mm-yyyy'), '6', '29', '119', '04', '2051', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18748, to_date('30-04-2051', 'dd-mm-yyyy'), '7', '30', '120', '04', '2051', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18749, to_date('01-05-2051', 'dd-mm-yyyy'), '1', '01', '121', '05', '2051', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18750, to_date('02-05-2051', 'dd-mm-yyyy'), '2', '02', '122', '05', '2051', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18751, to_date('03-05-2051', 'dd-mm-yyyy'), '3', '03', '123', '05', '2051', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18752, to_date('04-05-2051', 'dd-mm-yyyy'), '4', '04', '124', '05', '2051', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18753, to_date('05-05-2051', 'dd-mm-yyyy'), '5', '05', '125', '05', '2051', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18754, to_date('06-05-2051', 'dd-mm-yyyy'), '6', '06', '126', '05', '2051', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18755, to_date('07-05-2051', 'dd-mm-yyyy'), '7', '07', '127', '05', '2051', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18756, to_date('08-05-2051', 'dd-mm-yyyy'), '1', '08', '128', '05', '2051', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18757, to_date('09-05-2051', 'dd-mm-yyyy'), '2', '09', '129', '05', '2051', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18758, to_date('10-05-2051', 'dd-mm-yyyy'), '3', '10', '130', '05', '2051', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18759, to_date('11-05-2051', 'dd-mm-yyyy'), '4', '11', '131', '05', '2051', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18760, to_date('12-05-2051', 'dd-mm-yyyy'), '5', '12', '132', '05', '2051', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18761, to_date('13-05-2051', 'dd-mm-yyyy'), '6', '13', '133', '05', '2051', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18762, to_date('14-05-2051', 'dd-mm-yyyy'), '7', '14', '134', '05', '2051', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18763, to_date('15-05-2051', 'dd-mm-yyyy'), '1', '15', '135', '05', '2051', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18764, to_date('16-05-2051', 'dd-mm-yyyy'), '2', '16', '136', '05', '2051', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18765, to_date('17-05-2051', 'dd-mm-yyyy'), '3', '17', '137', '05', '2051', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18766, to_date('18-05-2051', 'dd-mm-yyyy'), '4', '18', '138', '05', '2051', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18767, to_date('19-05-2051', 'dd-mm-yyyy'), '5', '19', '139', '05', '2051', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18768, to_date('20-05-2051', 'dd-mm-yyyy'), '6', '20', '140', '05', '2051', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18769, to_date('21-05-2051', 'dd-mm-yyyy'), '7', '21', '141', '05', '2051', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18770, to_date('22-05-2051', 'dd-mm-yyyy'), '1', '22', '142', '05', '2051', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18771, to_date('23-05-2051', 'dd-mm-yyyy'), '2', '23', '143', '05', '2051', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18772, to_date('24-05-2051', 'dd-mm-yyyy'), '3', '24', '144', '05', '2051', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18773, to_date('25-05-2051', 'dd-mm-yyyy'), '4', '25', '145', '05', '2051', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18774, to_date('26-05-2051', 'dd-mm-yyyy'), '5', '26', '146', '05', '2051', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18775, to_date('27-05-2051', 'dd-mm-yyyy'), '6', '27', '147', '05', '2051', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18776, to_date('28-05-2051', 'dd-mm-yyyy'), '7', '28', '148', '05', '2051', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18777, to_date('29-05-2051', 'dd-mm-yyyy'), '1', '29', '149', '05', '2051', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18778, to_date('30-05-2051', 'dd-mm-yyyy'), '2', '30', '150', '05', '2051', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18779, to_date('31-05-2051', 'dd-mm-yyyy'), '3', '31', '151', '05', '2051', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18780, to_date('01-06-2051', 'dd-mm-yyyy'), '4', '01', '152', '06', '2051', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18781, to_date('02-06-2051', 'dd-mm-yyyy'), '5', '02', '153', '06', '2051', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18782, to_date('03-06-2051', 'dd-mm-yyyy'), '6', '03', '154', '06', '2051', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18783, to_date('04-06-2051', 'dd-mm-yyyy'), '7', '04', '155', '06', '2051', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18784, to_date('05-06-2051', 'dd-mm-yyyy'), '1', '05', '156', '06', '2051', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18785, to_date('06-06-2051', 'dd-mm-yyyy'), '2', '06', '157', '06', '2051', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18786, to_date('07-06-2051', 'dd-mm-yyyy'), '3', '07', '158', '06', '2051', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18787, to_date('08-06-2051', 'dd-mm-yyyy'), '4', '08', '159', '06', '2051', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18788, to_date('09-06-2051', 'dd-mm-yyyy'), '5', '09', '160', '06', '2051', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18789, to_date('10-06-2051', 'dd-mm-yyyy'), '6', '10', '161', '06', '2051', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18790, to_date('11-06-2051', 'dd-mm-yyyy'), '7', '11', '162', '06', '2051', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18791, to_date('12-06-2051', 'dd-mm-yyyy'), '1', '12', '163', '06', '2051', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18792, to_date('13-06-2051', 'dd-mm-yyyy'), '2', '13', '164', '06', '2051', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18793, to_date('14-06-2051', 'dd-mm-yyyy'), '3', '14', '165', '06', '2051', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18794, to_date('15-06-2051', 'dd-mm-yyyy'), '4', '15', '166', '06', '2051', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18795, to_date('16-06-2051', 'dd-mm-yyyy'), '5', '16', '167', '06', '2051', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18796, to_date('17-06-2051', 'dd-mm-yyyy'), '6', '17', '168', '06', '2051', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18797, to_date('18-06-2051', 'dd-mm-yyyy'), '7', '18', '169', '06', '2051', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18798, to_date('19-06-2051', 'dd-mm-yyyy'), '1', '19', '170', '06', '2051', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18799, to_date('20-06-2051', 'dd-mm-yyyy'), '2', '20', '171', '06', '2051', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18800, to_date('21-06-2051', 'dd-mm-yyyy'), '3', '21', '172', '06', '2051', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18801, to_date('22-06-2051', 'dd-mm-yyyy'), '4', '22', '173', '06', '2051', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18802, to_date('23-06-2051', 'dd-mm-yyyy'), '5', '23', '174', '06', '2051', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18803, to_date('24-06-2051', 'dd-mm-yyyy'), '6', '24', '175', '06', '2051', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18804, to_date('25-06-2051', 'dd-mm-yyyy'), '7', '25', '176', '06', '2051', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18805, to_date('26-06-2051', 'dd-mm-yyyy'), '1', '26', '177', '06', '2051', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18806, to_date('27-06-2051', 'dd-mm-yyyy'), '2', '27', '178', '06', '2051', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18807, to_date('28-06-2051', 'dd-mm-yyyy'), '3', '28', '179', '06', '2051', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18808, to_date('29-06-2051', 'dd-mm-yyyy'), '4', '29', '180', '06', '2051', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18809, to_date('30-06-2051', 'dd-mm-yyyy'), '5', '30', '181', '06', '2051', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18810, to_date('01-07-2051', 'dd-mm-yyyy'), '6', '01', '182', '07', '2051', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18811, to_date('02-07-2051', 'dd-mm-yyyy'), '7', '02', '183', '07', '2051', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18812, to_date('03-07-2051', 'dd-mm-yyyy'), '1', '03', '184', '07', '2051', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18813, to_date('04-07-2051', 'dd-mm-yyyy'), '2', '04', '185', '07', '2051', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18814, to_date('05-07-2051', 'dd-mm-yyyy'), '3', '05', '186', '07', '2051', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18815, to_date('06-07-2051', 'dd-mm-yyyy'), '4', '06', '187', '07', '2051', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18816, to_date('07-07-2051', 'dd-mm-yyyy'), '5', '07', '188', '07', '2051', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18817, to_date('08-07-2051', 'dd-mm-yyyy'), '6', '08', '189', '07', '2051', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18818, to_date('09-07-2051', 'dd-mm-yyyy'), '7', '09', '190', '07', '2051', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18819, to_date('10-07-2051', 'dd-mm-yyyy'), '1', '10', '191', '07', '2051', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18820, to_date('11-07-2051', 'dd-mm-yyyy'), '2', '11', '192', '07', '2051', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18821, to_date('12-07-2051', 'dd-mm-yyyy'), '3', '12', '193', '07', '2051', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18822, to_date('13-07-2051', 'dd-mm-yyyy'), '4', '13', '194', '07', '2051', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18823, to_date('14-07-2051', 'dd-mm-yyyy'), '5', '14', '195', '07', '2051', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18824, to_date('15-07-2051', 'dd-mm-yyyy'), '6', '15', '196', '07', '2051', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18825, to_date('16-07-2051', 'dd-mm-yyyy'), '7', '16', '197', '07', '2051', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18826, to_date('17-07-2051', 'dd-mm-yyyy'), '1', '17', '198', '07', '2051', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18827, to_date('18-07-2051', 'dd-mm-yyyy'), '2', '18', '199', '07', '2051', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18828, to_date('19-07-2051', 'dd-mm-yyyy'), '3', '19', '200', '07', '2051', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18829, to_date('20-07-2051', 'dd-mm-yyyy'), '4', '20', '201', '07', '2051', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18830, to_date('21-07-2051', 'dd-mm-yyyy'), '5', '21', '202', '07', '2051', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18831, to_date('22-07-2051', 'dd-mm-yyyy'), '6', '22', '203', '07', '2051', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18832, to_date('23-07-2051', 'dd-mm-yyyy'), '7', '23', '204', '07', '2051', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18833, to_date('24-07-2051', 'dd-mm-yyyy'), '1', '24', '205', '07', '2051', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18834, to_date('25-07-2051', 'dd-mm-yyyy'), '2', '25', '206', '07', '2051', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18835, to_date('26-07-2051', 'dd-mm-yyyy'), '3', '26', '207', '07', '2051', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18836, to_date('27-07-2051', 'dd-mm-yyyy'), '4', '27', '208', '07', '2051', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18837, to_date('28-07-2051', 'dd-mm-yyyy'), '5', '28', '209', '07', '2051', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18838, to_date('29-07-2051', 'dd-mm-yyyy'), '6', '29', '210', '07', '2051', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18839, to_date('30-07-2051', 'dd-mm-yyyy'), '7', '30', '211', '07', '2051', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18840, to_date('31-07-2051', 'dd-mm-yyyy'), '1', '31', '212', '07', '2051', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18841, to_date('01-08-2051', 'dd-mm-yyyy'), '2', '01', '213', '08', '2051', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18842, to_date('02-08-2051', 'dd-mm-yyyy'), '3', '02', '214', '08', '2051', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13967, to_date('28-03-2038', 'dd-mm-yyyy'), '7', '28', '087', '03', '2038', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13968, to_date('29-03-2038', 'dd-mm-yyyy'), '1', '29', '088', '03', '2038', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13969, to_date('30-03-2038', 'dd-mm-yyyy'), '2', '30', '089', '03', '2038', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13970, to_date('31-03-2038', 'dd-mm-yyyy'), '3', '31', '090', '03', '2038', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13971, to_date('01-04-2038', 'dd-mm-yyyy'), '4', '01', '091', '04', '2038', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13972, to_date('02-04-2038', 'dd-mm-yyyy'), '5', '02', '092', '04', '2038', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13973, to_date('03-04-2038', 'dd-mm-yyyy'), '6', '03', '093', '04', '2038', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13974, to_date('04-04-2038', 'dd-mm-yyyy'), '7', '04', '094', '04', '2038', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13975, to_date('05-04-2038', 'dd-mm-yyyy'), '1', '05', '095', '04', '2038', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13976, to_date('06-04-2038', 'dd-mm-yyyy'), '2', '06', '096', '04', '2038', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13977, to_date('07-04-2038', 'dd-mm-yyyy'), '3', '07', '097', '04', '2038', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13978, to_date('08-04-2038', 'dd-mm-yyyy'), '4', '08', '098', '04', '2038', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13979, to_date('09-04-2038', 'dd-mm-yyyy'), '5', '09', '099', '04', '2038', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13980, to_date('10-04-2038', 'dd-mm-yyyy'), '6', '10', '100', '04', '2038', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13981, to_date('11-04-2038', 'dd-mm-yyyy'), '7', '11', '101', '04', '2038', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13982, to_date('12-04-2038', 'dd-mm-yyyy'), '1', '12', '102', '04', '2038', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13983, to_date('13-04-2038', 'dd-mm-yyyy'), '2', '13', '103', '04', '2038', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13984, to_date('14-04-2038', 'dd-mm-yyyy'), '3', '14', '104', '04', '2038', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13985, to_date('15-04-2038', 'dd-mm-yyyy'), '4', '15', '105', '04', '2038', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13986, to_date('16-04-2038', 'dd-mm-yyyy'), '5', '16', '106', '04', '2038', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13987, to_date('17-04-2038', 'dd-mm-yyyy'), '6', '17', '107', '04', '2038', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13988, to_date('18-04-2038', 'dd-mm-yyyy'), '7', '18', '108', '04', '2038', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13989, to_date('19-04-2038', 'dd-mm-yyyy'), '1', '19', '109', '04', '2038', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13990, to_date('20-04-2038', 'dd-mm-yyyy'), '2', '20', '110', '04', '2038', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13991, to_date('21-04-2038', 'dd-mm-yyyy'), '3', '21', '111', '04', '2038', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13992, to_date('22-04-2038', 'dd-mm-yyyy'), '4', '22', '112', '04', '2038', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13993, to_date('23-04-2038', 'dd-mm-yyyy'), '5', '23', '113', '04', '2038', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13994, to_date('24-04-2038', 'dd-mm-yyyy'), '6', '24', '114', '04', '2038', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13995, to_date('25-04-2038', 'dd-mm-yyyy'), '7', '25', '115', '04', '2038', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13996, to_date('26-04-2038', 'dd-mm-yyyy'), '1', '26', '116', '04', '2038', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13997, to_date('27-04-2038', 'dd-mm-yyyy'), '2', '27', '117', '04', '2038', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13998, to_date('28-04-2038', 'dd-mm-yyyy'), '3', '28', '118', '04', '2038', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (13999, to_date('29-04-2038', 'dd-mm-yyyy'), '4', '29', '119', '04', '2038', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14000, to_date('30-04-2038', 'dd-mm-yyyy'), '5', '30', '120', '04', '2038', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14001, to_date('01-05-2038', 'dd-mm-yyyy'), '6', '01', '121', '05', '2038', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14002, to_date('02-05-2038', 'dd-mm-yyyy'), '7', '02', '122', '05', '2038', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14003, to_date('03-05-2038', 'dd-mm-yyyy'), '1', '03', '123', '05', '2038', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14004, to_date('04-05-2038', 'dd-mm-yyyy'), '2', '04', '124', '05', '2038', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14005, to_date('05-05-2038', 'dd-mm-yyyy'), '3', '05', '125', '05', '2038', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14006, to_date('06-05-2038', 'dd-mm-yyyy'), '4', '06', '126', '05', '2038', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14007, to_date('07-05-2038', 'dd-mm-yyyy'), '5', '07', '127', '05', '2038', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14008, to_date('08-05-2038', 'dd-mm-yyyy'), '6', '08', '128', '05', '2038', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14009, to_date('09-05-2038', 'dd-mm-yyyy'), '7', '09', '129', '05', '2038', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14010, to_date('10-05-2038', 'dd-mm-yyyy'), '1', '10', '130', '05', '2038', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14011, to_date('11-05-2038', 'dd-mm-yyyy'), '2', '11', '131', '05', '2038', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14012, to_date('12-05-2038', 'dd-mm-yyyy'), '3', '12', '132', '05', '2038', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14013, to_date('13-05-2038', 'dd-mm-yyyy'), '4', '13', '133', '05', '2038', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14014, to_date('14-05-2038', 'dd-mm-yyyy'), '5', '14', '134', '05', '2038', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14015, to_date('15-05-2038', 'dd-mm-yyyy'), '6', '15', '135', '05', '2038', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14016, to_date('16-05-2038', 'dd-mm-yyyy'), '7', '16', '136', '05', '2038', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14017, to_date('17-05-2038', 'dd-mm-yyyy'), '1', '17', '137', '05', '2038', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14018, to_date('18-05-2038', 'dd-mm-yyyy'), '2', '18', '138', '05', '2038', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14019, to_date('19-05-2038', 'dd-mm-yyyy'), '3', '19', '139', '05', '2038', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14020, to_date('20-05-2038', 'dd-mm-yyyy'), '4', '20', '140', '05', '2038', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14021, to_date('21-05-2038', 'dd-mm-yyyy'), '5', '21', '141', '05', '2038', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14022, to_date('22-05-2038', 'dd-mm-yyyy'), '6', '22', '142', '05', '2038', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14023, to_date('23-05-2038', 'dd-mm-yyyy'), '7', '23', '143', '05', '2038', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14024, to_date('24-05-2038', 'dd-mm-yyyy'), '1', '24', '144', '05', '2038', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14025, to_date('25-05-2038', 'dd-mm-yyyy'), '2', '25', '145', '05', '2038', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14026, to_date('26-05-2038', 'dd-mm-yyyy'), '3', '26', '146', '05', '2038', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14027, to_date('27-05-2038', 'dd-mm-yyyy'), '4', '27', '147', '05', '2038', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14028, to_date('28-05-2038', 'dd-mm-yyyy'), '5', '28', '148', '05', '2038', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14029, to_date('29-05-2038', 'dd-mm-yyyy'), '6', '29', '149', '05', '2038', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14030, to_date('30-05-2038', 'dd-mm-yyyy'), '7', '30', '150', '05', '2038', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14031, to_date('31-05-2038', 'dd-mm-yyyy'), '1', '31', '151', '05', '2038', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14032, to_date('01-06-2038', 'dd-mm-yyyy'), '2', '01', '152', '06', '2038', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14033, to_date('02-06-2038', 'dd-mm-yyyy'), '3', '02', '153', '06', '2038', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14034, to_date('03-06-2038', 'dd-mm-yyyy'), '4', '03', '154', '06', '2038', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14035, to_date('04-06-2038', 'dd-mm-yyyy'), '5', '04', '155', '06', '2038', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14036, to_date('05-06-2038', 'dd-mm-yyyy'), '6', '05', '156', '06', '2038', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14037, to_date('06-06-2038', 'dd-mm-yyyy'), '7', '06', '157', '06', '2038', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14038, to_date('07-06-2038', 'dd-mm-yyyy'), '1', '07', '158', '06', '2038', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14039, to_date('08-06-2038', 'dd-mm-yyyy'), '2', '08', '159', '06', '2038', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14040, to_date('09-06-2038', 'dd-mm-yyyy'), '3', '09', '160', '06', '2038', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14041, to_date('10-06-2038', 'dd-mm-yyyy'), '4', '10', '161', '06', '2038', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14042, to_date('11-06-2038', 'dd-mm-yyyy'), '5', '11', '162', '06', '2038', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14043, to_date('12-06-2038', 'dd-mm-yyyy'), '6', '12', '163', '06', '2038', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14044, to_date('13-06-2038', 'dd-mm-yyyy'), '7', '13', '164', '06', '2038', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14045, to_date('14-06-2038', 'dd-mm-yyyy'), '1', '14', '165', '06', '2038', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14046, to_date('15-06-2038', 'dd-mm-yyyy'), '2', '15', '166', '06', '2038', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14047, to_date('16-06-2038', 'dd-mm-yyyy'), '3', '16', '167', '06', '2038', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14048, to_date('17-06-2038', 'dd-mm-yyyy'), '4', '17', '168', '06', '2038', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14049, to_date('18-06-2038', 'dd-mm-yyyy'), '5', '18', '169', '06', '2038', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14050, to_date('19-06-2038', 'dd-mm-yyyy'), '6', '19', '170', '06', '2038', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14051, to_date('20-06-2038', 'dd-mm-yyyy'), '7', '20', '171', '06', '2038', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14052, to_date('21-06-2038', 'dd-mm-yyyy'), '1', '21', '172', '06', '2038', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14053, to_date('22-06-2038', 'dd-mm-yyyy'), '2', '22', '173', '06', '2038', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14054, to_date('23-06-2038', 'dd-mm-yyyy'), '3', '23', '174', '06', '2038', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14055, to_date('24-06-2038', 'dd-mm-yyyy'), '4', '24', '175', '06', '2038', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14056, to_date('25-06-2038', 'dd-mm-yyyy'), '5', '25', '176', '06', '2038', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14057, to_date('26-06-2038', 'dd-mm-yyyy'), '6', '26', '177', '06', '2038', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14058, to_date('27-06-2038', 'dd-mm-yyyy'), '7', '27', '178', '06', '2038', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14059, to_date('28-06-2038', 'dd-mm-yyyy'), '1', '28', '179', '06', '2038', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14060, to_date('29-06-2038', 'dd-mm-yyyy'), '2', '29', '180', '06', '2038', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14061, to_date('30-06-2038', 'dd-mm-yyyy'), '3', '30', '181', '06', '2038', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14062, to_date('01-07-2038', 'dd-mm-yyyy'), '4', '01', '182', '07', '2038', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14063, to_date('02-07-2038', 'dd-mm-yyyy'), '5', '02', '183', '07', '2038', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14064, to_date('03-07-2038', 'dd-mm-yyyy'), '6', '03', '184', '07', '2038', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14065, to_date('04-07-2038', 'dd-mm-yyyy'), '7', '04', '185', '07', '2038', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14066, to_date('05-07-2038', 'dd-mm-yyyy'), '1', '05', '186', '07', '2038', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14067, to_date('06-07-2038', 'dd-mm-yyyy'), '2', '06', '187', '07', '2038', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14068, to_date('07-07-2038', 'dd-mm-yyyy'), '3', '07', '188', '07', '2038', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14069, to_date('08-07-2038', 'dd-mm-yyyy'), '4', '08', '189', '07', '2038', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14070, to_date('09-07-2038', 'dd-mm-yyyy'), '5', '09', '190', '07', '2038', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14071, to_date('10-07-2038', 'dd-mm-yyyy'), '6', '10', '191', '07', '2038', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14072, to_date('11-07-2038', 'dd-mm-yyyy'), '7', '11', '192', '07', '2038', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15663, to_date('18-11-2042', 'dd-mm-yyyy'), '2', '18', '322', '11', '2042', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15664, to_date('19-11-2042', 'dd-mm-yyyy'), '3', '19', '323', '11', '2042', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15665, to_date('20-11-2042', 'dd-mm-yyyy'), '4', '20', '324', '11', '2042', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15666, to_date('21-11-2042', 'dd-mm-yyyy'), '5', '21', '325', '11', '2042', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15667, to_date('22-11-2042', 'dd-mm-yyyy'), '6', '22', '326', '11', '2042', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15668, to_date('23-11-2042', 'dd-mm-yyyy'), '7', '23', '327', '11', '2042', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15669, to_date('24-11-2042', 'dd-mm-yyyy'), '1', '24', '328', '11', '2042', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15670, to_date('25-11-2042', 'dd-mm-yyyy'), '2', '25', '329', '11', '2042', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15671, to_date('26-11-2042', 'dd-mm-yyyy'), '3', '26', '330', '11', '2042', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15672, to_date('27-11-2042', 'dd-mm-yyyy'), '4', '27', '331', '11', '2042', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15673, to_date('28-11-2042', 'dd-mm-yyyy'), '5', '28', '332', '11', '2042', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15674, to_date('29-11-2042', 'dd-mm-yyyy'), '6', '29', '333', '11', '2042', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15675, to_date('30-11-2042', 'dd-mm-yyyy'), '7', '30', '334', '11', '2042', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15676, to_date('01-12-2042', 'dd-mm-yyyy'), '1', '01', '335', '12', '2042', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15677, to_date('02-12-2042', 'dd-mm-yyyy'), '2', '02', '336', '12', '2042', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15678, to_date('03-12-2042', 'dd-mm-yyyy'), '3', '03', '337', '12', '2042', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15679, to_date('04-12-2042', 'dd-mm-yyyy'), '4', '04', '338', '12', '2042', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15680, to_date('05-12-2042', 'dd-mm-yyyy'), '5', '05', '339', '12', '2042', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15681, to_date('06-12-2042', 'dd-mm-yyyy'), '6', '06', '340', '12', '2042', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15682, to_date('07-12-2042', 'dd-mm-yyyy'), '7', '07', '341', '12', '2042', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15683, to_date('08-12-2042', 'dd-mm-yyyy'), '1', '08', '342', '12', '2042', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15684, to_date('09-12-2042', 'dd-mm-yyyy'), '2', '09', '343', '12', '2042', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15685, to_date('10-12-2042', 'dd-mm-yyyy'), '3', '10', '344', '12', '2042', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15686, to_date('11-12-2042', 'dd-mm-yyyy'), '4', '11', '345', '12', '2042', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15687, to_date('12-12-2042', 'dd-mm-yyyy'), '5', '12', '346', '12', '2042', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15688, to_date('13-12-2042', 'dd-mm-yyyy'), '6', '13', '347', '12', '2042', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15689, to_date('14-12-2042', 'dd-mm-yyyy'), '7', '14', '348', '12', '2042', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15690, to_date('15-12-2042', 'dd-mm-yyyy'), '1', '15', '349', '12', '2042', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15691, to_date('16-12-2042', 'dd-mm-yyyy'), '2', '16', '350', '12', '2042', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15692, to_date('17-12-2042', 'dd-mm-yyyy'), '3', '17', '351', '12', '2042', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15693, to_date('18-12-2042', 'dd-mm-yyyy'), '4', '18', '352', '12', '2042', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15694, to_date('19-12-2042', 'dd-mm-yyyy'), '5', '19', '353', '12', '2042', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15695, to_date('20-12-2042', 'dd-mm-yyyy'), '6', '20', '354', '12', '2042', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15696, to_date('21-12-2042', 'dd-mm-yyyy'), '7', '21', '355', '12', '2042', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15697, to_date('22-12-2042', 'dd-mm-yyyy'), '1', '22', '356', '12', '2042', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15698, to_date('23-12-2042', 'dd-mm-yyyy'), '2', '23', '357', '12', '2042', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15699, to_date('24-12-2042', 'dd-mm-yyyy'), '3', '24', '358', '12', '2042', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15700, to_date('25-12-2042', 'dd-mm-yyyy'), '4', '25', '359', '12', '2042', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15701, to_date('26-12-2042', 'dd-mm-yyyy'), '5', '26', '360', '12', '2042', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15702, to_date('27-12-2042', 'dd-mm-yyyy'), '6', '27', '361', '12', '2042', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15703, to_date('28-12-2042', 'dd-mm-yyyy'), '7', '28', '362', '12', '2042', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15704, to_date('29-12-2042', 'dd-mm-yyyy'), '1', '29', '363', '12', '2042', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15705, to_date('30-12-2042', 'dd-mm-yyyy'), '2', '30', '364', '12', '2042', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15706, to_date('31-12-2042', 'dd-mm-yyyy'), '3', '31', '365', '12', '2042', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15707, to_date('01-01-2043', 'dd-mm-yyyy'), '4', '01', '001', '01', '2043', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15708, to_date('02-01-2043', 'dd-mm-yyyy'), '5', '02', '002', '01', '2043', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15709, to_date('03-01-2043', 'dd-mm-yyyy'), '6', '03', '003', '01', '2043', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15710, to_date('04-01-2043', 'dd-mm-yyyy'), '7', '04', '004', '01', '2043', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15711, to_date('05-01-2043', 'dd-mm-yyyy'), '1', '05', '005', '01', '2043', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15712, to_date('06-01-2043', 'dd-mm-yyyy'), '2', '06', '006', '01', '2043', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15713, to_date('07-01-2043', 'dd-mm-yyyy'), '3', '07', '007', '01', '2043', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15714, to_date('08-01-2043', 'dd-mm-yyyy'), '4', '08', '008', '01', '2043', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15715, to_date('09-01-2043', 'dd-mm-yyyy'), '5', '09', '009', '01', '2043', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15716, to_date('10-01-2043', 'dd-mm-yyyy'), '6', '10', '010', '01', '2043', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15717, to_date('11-01-2043', 'dd-mm-yyyy'), '7', '11', '011', '01', '2043', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15718, to_date('12-01-2043', 'dd-mm-yyyy'), '1', '12', '012', '01', '2043', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15719, to_date('13-01-2043', 'dd-mm-yyyy'), '2', '13', '013', '01', '2043', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15720, to_date('14-01-2043', 'dd-mm-yyyy'), '3', '14', '014', '01', '2043', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15721, to_date('15-01-2043', 'dd-mm-yyyy'), '4', '15', '015', '01', '2043', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15722, to_date('16-01-2043', 'dd-mm-yyyy'), '5', '16', '016', '01', '2043', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15723, to_date('17-01-2043', 'dd-mm-yyyy'), '6', '17', '017', '01', '2043', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15724, to_date('18-01-2043', 'dd-mm-yyyy'), '7', '18', '018', '01', '2043', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15725, to_date('19-01-2043', 'dd-mm-yyyy'), '1', '19', '019', '01', '2043', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15726, to_date('20-01-2043', 'dd-mm-yyyy'), '2', '20', '020', '01', '2043', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15727, to_date('21-01-2043', 'dd-mm-yyyy'), '3', '21', '021', '01', '2043', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15728, to_date('22-01-2043', 'dd-mm-yyyy'), '4', '22', '022', '01', '2043', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15729, to_date('23-01-2043', 'dd-mm-yyyy'), '5', '23', '023', '01', '2043', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15730, to_date('24-01-2043', 'dd-mm-yyyy'), '6', '24', '024', '01', '2043', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15731, to_date('25-01-2043', 'dd-mm-yyyy'), '7', '25', '025', '01', '2043', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15732, to_date('26-01-2043', 'dd-mm-yyyy'), '1', '26', '026', '01', '2043', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15733, to_date('27-01-2043', 'dd-mm-yyyy'), '2', '27', '027', '01', '2043', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15734, to_date('28-01-2043', 'dd-mm-yyyy'), '3', '28', '028', '01', '2043', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15735, to_date('29-01-2043', 'dd-mm-yyyy'), '4', '29', '029', '01', '2043', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15736, to_date('30-01-2043', 'dd-mm-yyyy'), '5', '30', '030', '01', '2043', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15737, to_date('31-01-2043', 'dd-mm-yyyy'), '6', '31', '031', '01', '2043', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15738, to_date('01-02-2043', 'dd-mm-yyyy'), '7', '01', '032', '02', '2043', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15739, to_date('02-02-2043', 'dd-mm-yyyy'), '1', '02', '033', '02', '2043', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15740, to_date('03-02-2043', 'dd-mm-yyyy'), '2', '03', '034', '02', '2043', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15741, to_date('04-02-2043', 'dd-mm-yyyy'), '3', '04', '035', '02', '2043', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15742, to_date('05-02-2043', 'dd-mm-yyyy'), '4', '05', '036', '02', '2043', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15743, to_date('06-02-2043', 'dd-mm-yyyy'), '5', '06', '037', '02', '2043', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15744, to_date('07-02-2043', 'dd-mm-yyyy'), '6', '07', '038', '02', '2043', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15745, to_date('08-02-2043', 'dd-mm-yyyy'), '7', '08', '039', '02', '2043', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15746, to_date('09-02-2043', 'dd-mm-yyyy'), '1', '09', '040', '02', '2043', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15747, to_date('10-02-2043', 'dd-mm-yyyy'), '2', '10', '041', '02', '2043', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15748, to_date('11-02-2043', 'dd-mm-yyyy'), '3', '11', '042', '02', '2043', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15749, to_date('12-02-2043', 'dd-mm-yyyy'), '4', '12', '043', '02', '2043', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15750, to_date('13-02-2043', 'dd-mm-yyyy'), '5', '13', '044', '02', '2043', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15751, to_date('14-02-2043', 'dd-mm-yyyy'), '6', '14', '045', '02', '2043', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15752, to_date('15-02-2043', 'dd-mm-yyyy'), '7', '15', '046', '02', '2043', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15753, to_date('16-02-2043', 'dd-mm-yyyy'), '1', '16', '047', '02', '2043', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15754, to_date('17-02-2043', 'dd-mm-yyyy'), '2', '17', '048', '02', '2043', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15755, to_date('18-02-2043', 'dd-mm-yyyy'), '3', '18', '049', '02', '2043', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15756, to_date('19-02-2043', 'dd-mm-yyyy'), '4', '19', '050', '02', '2043', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15757, to_date('20-02-2043', 'dd-mm-yyyy'), '5', '20', '051', '02', '2043', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15758, to_date('21-02-2043', 'dd-mm-yyyy'), '6', '21', '052', '02', '2043', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15759, to_date('22-02-2043', 'dd-mm-yyyy'), '7', '22', '053', '02', '2043', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15760, to_date('23-02-2043', 'dd-mm-yyyy'), '1', '23', '054', '02', '2043', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15761, to_date('24-02-2043', 'dd-mm-yyyy'), '2', '24', '055', '02', '2043', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15762, to_date('25-02-2043', 'dd-mm-yyyy'), '3', '25', '056', '02', '2043', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15763, to_date('26-02-2043', 'dd-mm-yyyy'), '4', '26', '057', '02', '2043', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15764, to_date('27-02-2043', 'dd-mm-yyyy'), '5', '27', '058', '02', '2043', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15765, to_date('28-02-2043', 'dd-mm-yyyy'), '6', '28', '059', '02', '2043', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15766, to_date('01-03-2043', 'dd-mm-yyyy'), '7', '01', '060', '03', '2043', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15767, to_date('02-03-2043', 'dd-mm-yyyy'), '1', '02', '061', '03', '2043', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15768, to_date('03-03-2043', 'dd-mm-yyyy'), '2', '03', '062', '03', '2043', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17253, to_date('27-03-2047', 'dd-mm-yyyy'), '3', '27', '086', '03', '2047', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17254, to_date('28-03-2047', 'dd-mm-yyyy'), '4', '28', '087', '03', '2047', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17255, to_date('29-03-2047', 'dd-mm-yyyy'), '5', '29', '088', '03', '2047', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17256, to_date('30-03-2047', 'dd-mm-yyyy'), '6', '30', '089', '03', '2047', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17257, to_date('31-03-2047', 'dd-mm-yyyy'), '7', '31', '090', '03', '2047', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17258, to_date('01-04-2047', 'dd-mm-yyyy'), '1', '01', '091', '04', '2047', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17259, to_date('02-04-2047', 'dd-mm-yyyy'), '2', '02', '092', '04', '2047', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17260, to_date('03-04-2047', 'dd-mm-yyyy'), '3', '03', '093', '04', '2047', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17261, to_date('04-04-2047', 'dd-mm-yyyy'), '4', '04', '094', '04', '2047', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17262, to_date('05-04-2047', 'dd-mm-yyyy'), '5', '05', '095', '04', '2047', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17263, to_date('06-04-2047', 'dd-mm-yyyy'), '6', '06', '096', '04', '2047', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17264, to_date('07-04-2047', 'dd-mm-yyyy'), '7', '07', '097', '04', '2047', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17265, to_date('08-04-2047', 'dd-mm-yyyy'), '1', '08', '098', '04', '2047', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17266, to_date('09-04-2047', 'dd-mm-yyyy'), '2', '09', '099', '04', '2047', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17267, to_date('10-04-2047', 'dd-mm-yyyy'), '3', '10', '100', '04', '2047', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17268, to_date('11-04-2047', 'dd-mm-yyyy'), '4', '11', '101', '04', '2047', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17269, to_date('12-04-2047', 'dd-mm-yyyy'), '5', '12', '102', '04', '2047', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17270, to_date('13-04-2047', 'dd-mm-yyyy'), '6', '13', '103', '04', '2047', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17271, to_date('14-04-2047', 'dd-mm-yyyy'), '7', '14', '104', '04', '2047', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17272, to_date('15-04-2047', 'dd-mm-yyyy'), '1', '15', '105', '04', '2047', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17273, to_date('16-04-2047', 'dd-mm-yyyy'), '2', '16', '106', '04', '2047', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17274, to_date('17-04-2047', 'dd-mm-yyyy'), '3', '17', '107', '04', '2047', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17275, to_date('18-04-2047', 'dd-mm-yyyy'), '4', '18', '108', '04', '2047', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17276, to_date('19-04-2047', 'dd-mm-yyyy'), '5', '19', '109', '04', '2047', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17277, to_date('20-04-2047', 'dd-mm-yyyy'), '6', '20', '110', '04', '2047', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17278, to_date('21-04-2047', 'dd-mm-yyyy'), '7', '21', '111', '04', '2047', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17279, to_date('22-04-2047', 'dd-mm-yyyy'), '1', '22', '112', '04', '2047', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17280, to_date('23-04-2047', 'dd-mm-yyyy'), '2', '23', '113', '04', '2047', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17281, to_date('24-04-2047', 'dd-mm-yyyy'), '3', '24', '114', '04', '2047', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17282, to_date('25-04-2047', 'dd-mm-yyyy'), '4', '25', '115', '04', '2047', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17283, to_date('26-04-2047', 'dd-mm-yyyy'), '5', '26', '116', '04', '2047', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17284, to_date('27-04-2047', 'dd-mm-yyyy'), '6', '27', '117', '04', '2047', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17285, to_date('28-04-2047', 'dd-mm-yyyy'), '7', '28', '118', '04', '2047', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17286, to_date('29-04-2047', 'dd-mm-yyyy'), '1', '29', '119', '04', '2047', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17287, to_date('30-04-2047', 'dd-mm-yyyy'), '2', '30', '120', '04', '2047', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17288, to_date('01-05-2047', 'dd-mm-yyyy'), '3', '01', '121', '05', '2047', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17289, to_date('02-05-2047', 'dd-mm-yyyy'), '4', '02', '122', '05', '2047', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17290, to_date('03-05-2047', 'dd-mm-yyyy'), '5', '03', '123', '05', '2047', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17291, to_date('04-05-2047', 'dd-mm-yyyy'), '6', '04', '124', '05', '2047', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17292, to_date('05-05-2047', 'dd-mm-yyyy'), '7', '05', '125', '05', '2047', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17293, to_date('06-05-2047', 'dd-mm-yyyy'), '1', '06', '126', '05', '2047', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17294, to_date('07-05-2047', 'dd-mm-yyyy'), '2', '07', '127', '05', '2047', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17295, to_date('08-05-2047', 'dd-mm-yyyy'), '3', '08', '128', '05', '2047', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17296, to_date('09-05-2047', 'dd-mm-yyyy'), '4', '09', '129', '05', '2047', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17297, to_date('10-05-2047', 'dd-mm-yyyy'), '5', '10', '130', '05', '2047', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17298, to_date('11-05-2047', 'dd-mm-yyyy'), '6', '11', '131', '05', '2047', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17299, to_date('12-05-2047', 'dd-mm-yyyy'), '7', '12', '132', '05', '2047', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17300, to_date('13-05-2047', 'dd-mm-yyyy'), '1', '13', '133', '05', '2047', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17301, to_date('14-05-2047', 'dd-mm-yyyy'), '2', '14', '134', '05', '2047', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17302, to_date('15-05-2047', 'dd-mm-yyyy'), '3', '15', '135', '05', '2047', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17303, to_date('16-05-2047', 'dd-mm-yyyy'), '4', '16', '136', '05', '2047', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17304, to_date('17-05-2047', 'dd-mm-yyyy'), '5', '17', '137', '05', '2047', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17305, to_date('18-05-2047', 'dd-mm-yyyy'), '6', '18', '138', '05', '2047', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17306, to_date('19-05-2047', 'dd-mm-yyyy'), '7', '19', '139', '05', '2047', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17307, to_date('20-05-2047', 'dd-mm-yyyy'), '1', '20', '140', '05', '2047', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17308, to_date('21-05-2047', 'dd-mm-yyyy'), '2', '21', '141', '05', '2047', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17309, to_date('22-05-2047', 'dd-mm-yyyy'), '3', '22', '142', '05', '2047', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17310, to_date('23-05-2047', 'dd-mm-yyyy'), '4', '23', '143', '05', '2047', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17311, to_date('24-05-2047', 'dd-mm-yyyy'), '5', '24', '144', '05', '2047', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17312, to_date('25-05-2047', 'dd-mm-yyyy'), '6', '25', '145', '05', '2047', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17313, to_date('26-05-2047', 'dd-mm-yyyy'), '7', '26', '146', '05', '2047', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17314, to_date('27-05-2047', 'dd-mm-yyyy'), '1', '27', '147', '05', '2047', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17315, to_date('28-05-2047', 'dd-mm-yyyy'), '2', '28', '148', '05', '2047', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17316, to_date('29-05-2047', 'dd-mm-yyyy'), '3', '29', '149', '05', '2047', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17317, to_date('30-05-2047', 'dd-mm-yyyy'), '4', '30', '150', '05', '2047', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17318, to_date('31-05-2047', 'dd-mm-yyyy'), '5', '31', '151', '05', '2047', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17319, to_date('01-06-2047', 'dd-mm-yyyy'), '6', '01', '152', '06', '2047', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17320, to_date('02-06-2047', 'dd-mm-yyyy'), '7', '02', '153', '06', '2047', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17321, to_date('03-06-2047', 'dd-mm-yyyy'), '1', '03', '154', '06', '2047', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17322, to_date('04-06-2047', 'dd-mm-yyyy'), '2', '04', '155', '06', '2047', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17323, to_date('05-06-2047', 'dd-mm-yyyy'), '3', '05', '156', '06', '2047', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17324, to_date('06-06-2047', 'dd-mm-yyyy'), '4', '06', '157', '06', '2047', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17325, to_date('07-06-2047', 'dd-mm-yyyy'), '5', '07', '158', '06', '2047', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17326, to_date('08-06-2047', 'dd-mm-yyyy'), '6', '08', '159', '06', '2047', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17327, to_date('09-06-2047', 'dd-mm-yyyy'), '7', '09', '160', '06', '2047', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17328, to_date('10-06-2047', 'dd-mm-yyyy'), '1', '10', '161', '06', '2047', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17329, to_date('11-06-2047', 'dd-mm-yyyy'), '2', '11', '162', '06', '2047', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17330, to_date('12-06-2047', 'dd-mm-yyyy'), '3', '12', '163', '06', '2047', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17331, to_date('13-06-2047', 'dd-mm-yyyy'), '4', '13', '164', '06', '2047', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17332, to_date('14-06-2047', 'dd-mm-yyyy'), '5', '14', '165', '06', '2047', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17333, to_date('15-06-2047', 'dd-mm-yyyy'), '6', '15', '166', '06', '2047', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17334, to_date('16-06-2047', 'dd-mm-yyyy'), '7', '16', '167', '06', '2047', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17335, to_date('17-06-2047', 'dd-mm-yyyy'), '1', '17', '168', '06', '2047', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17336, to_date('18-06-2047', 'dd-mm-yyyy'), '2', '18', '169', '06', '2047', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17337, to_date('19-06-2047', 'dd-mm-yyyy'), '3', '19', '170', '06', '2047', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17338, to_date('20-06-2047', 'dd-mm-yyyy'), '4', '20', '171', '06', '2047', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17339, to_date('21-06-2047', 'dd-mm-yyyy'), '5', '21', '172', '06', '2047', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17340, to_date('22-06-2047', 'dd-mm-yyyy'), '6', '22', '173', '06', '2047', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17341, to_date('23-06-2047', 'dd-mm-yyyy'), '7', '23', '174', '06', '2047', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17342, to_date('24-06-2047', 'dd-mm-yyyy'), '1', '24', '175', '06', '2047', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17343, to_date('25-06-2047', 'dd-mm-yyyy'), '2', '25', '176', '06', '2047', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17344, to_date('26-06-2047', 'dd-mm-yyyy'), '3', '26', '177', '06', '2047', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17345, to_date('27-06-2047', 'dd-mm-yyyy'), '4', '27', '178', '06', '2047', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17346, to_date('28-06-2047', 'dd-mm-yyyy'), '5', '28', '179', '06', '2047', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17347, to_date('29-06-2047', 'dd-mm-yyyy'), '6', '29', '180', '06', '2047', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17348, to_date('30-06-2047', 'dd-mm-yyyy'), '7', '30', '181', '06', '2047', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17349, to_date('01-07-2047', 'dd-mm-yyyy'), '1', '01', '182', '07', '2047', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17350, to_date('02-07-2047', 'dd-mm-yyyy'), '2', '02', '183', '07', '2047', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17351, to_date('03-07-2047', 'dd-mm-yyyy'), '3', '03', '184', '07', '2047', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17352, to_date('04-07-2047', 'dd-mm-yyyy'), '4', '04', '185', '07', '2047', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17353, to_date('05-07-2047', 'dd-mm-yyyy'), '5', '05', '186', '07', '2047', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17354, to_date('06-07-2047', 'dd-mm-yyyy'), '6', '06', '187', '07', '2047', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17355, to_date('07-07-2047', 'dd-mm-yyyy'), '7', '07', '188', '07', '2047', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17356, to_date('08-07-2047', 'dd-mm-yyyy'), '1', '08', '189', '07', '2047', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17357, to_date('09-07-2047', 'dd-mm-yyyy'), '2', '09', '190', '07', '2047', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17358, to_date('10-07-2047', 'dd-mm-yyyy'), '3', '10', '191', '07', '2047', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18843, to_date('03-08-2051', 'dd-mm-yyyy'), '4', '03', '215', '08', '2051', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18844, to_date('04-08-2051', 'dd-mm-yyyy'), '5', '04', '216', '08', '2051', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18845, to_date('05-08-2051', 'dd-mm-yyyy'), '6', '05', '217', '08', '2051', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18846, to_date('06-08-2051', 'dd-mm-yyyy'), '7', '06', '218', '08', '2051', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18847, to_date('07-08-2051', 'dd-mm-yyyy'), '1', '07', '219', '08', '2051', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18848, to_date('08-08-2051', 'dd-mm-yyyy'), '2', '08', '220', '08', '2051', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18849, to_date('09-08-2051', 'dd-mm-yyyy'), '3', '09', '221', '08', '2051', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18850, to_date('10-08-2051', 'dd-mm-yyyy'), '4', '10', '222', '08', '2051', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18851, to_date('11-08-2051', 'dd-mm-yyyy'), '5', '11', '223', '08', '2051', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18852, to_date('12-08-2051', 'dd-mm-yyyy'), '6', '12', '224', '08', '2051', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18853, to_date('13-08-2051', 'dd-mm-yyyy'), '7', '13', '225', '08', '2051', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18854, to_date('14-08-2051', 'dd-mm-yyyy'), '1', '14', '226', '08', '2051', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18855, to_date('15-08-2051', 'dd-mm-yyyy'), '2', '15', '227', '08', '2051', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18856, to_date('16-08-2051', 'dd-mm-yyyy'), '3', '16', '228', '08', '2051', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18857, to_date('17-08-2051', 'dd-mm-yyyy'), '4', '17', '229', '08', '2051', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18858, to_date('18-08-2051', 'dd-mm-yyyy'), '5', '18', '230', '08', '2051', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18859, to_date('19-08-2051', 'dd-mm-yyyy'), '6', '19', '231', '08', '2051', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18860, to_date('20-08-2051', 'dd-mm-yyyy'), '7', '20', '232', '08', '2051', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18861, to_date('21-08-2051', 'dd-mm-yyyy'), '1', '21', '233', '08', '2051', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18862, to_date('22-08-2051', 'dd-mm-yyyy'), '2', '22', '234', '08', '2051', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18863, to_date('23-08-2051', 'dd-mm-yyyy'), '3', '23', '235', '08', '2051', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18864, to_date('24-08-2051', 'dd-mm-yyyy'), '4', '24', '236', '08', '2051', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18865, to_date('25-08-2051', 'dd-mm-yyyy'), '5', '25', '237', '08', '2051', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18866, to_date('26-08-2051', 'dd-mm-yyyy'), '6', '26', '238', '08', '2051', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18867, to_date('27-08-2051', 'dd-mm-yyyy'), '7', '27', '239', '08', '2051', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18868, to_date('28-08-2051', 'dd-mm-yyyy'), '1', '28', '240', '08', '2051', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18869, to_date('29-08-2051', 'dd-mm-yyyy'), '2', '29', '241', '08', '2051', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18870, to_date('30-08-2051', 'dd-mm-yyyy'), '3', '30', '242', '08', '2051', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18871, to_date('31-08-2051', 'dd-mm-yyyy'), '4', '31', '243', '08', '2051', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18872, to_date('01-09-2051', 'dd-mm-yyyy'), '5', '01', '244', '09', '2051', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18873, to_date('02-09-2051', 'dd-mm-yyyy'), '6', '02', '245', '09', '2051', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18874, to_date('03-09-2051', 'dd-mm-yyyy'), '7', '03', '246', '09', '2051', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18875, to_date('04-09-2051', 'dd-mm-yyyy'), '1', '04', '247', '09', '2051', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18876, to_date('05-09-2051', 'dd-mm-yyyy'), '2', '05', '248', '09', '2051', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18877, to_date('06-09-2051', 'dd-mm-yyyy'), '3', '06', '249', '09', '2051', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18878, to_date('07-09-2051', 'dd-mm-yyyy'), '4', '07', '250', '09', '2051', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18879, to_date('08-09-2051', 'dd-mm-yyyy'), '5', '08', '251', '09', '2051', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18880, to_date('09-09-2051', 'dd-mm-yyyy'), '6', '09', '252', '09', '2051', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18881, to_date('10-09-2051', 'dd-mm-yyyy'), '7', '10', '253', '09', '2051', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18882, to_date('11-09-2051', 'dd-mm-yyyy'), '1', '11', '254', '09', '2051', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18883, to_date('12-09-2051', 'dd-mm-yyyy'), '2', '12', '255', '09', '2051', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18884, to_date('13-09-2051', 'dd-mm-yyyy'), '3', '13', '256', '09', '2051', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18885, to_date('14-09-2051', 'dd-mm-yyyy'), '4', '14', '257', '09', '2051', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18886, to_date('15-09-2051', 'dd-mm-yyyy'), '5', '15', '258', '09', '2051', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18887, to_date('16-09-2051', 'dd-mm-yyyy'), '6', '16', '259', '09', '2051', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18888, to_date('17-09-2051', 'dd-mm-yyyy'), '7', '17', '260', '09', '2051', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18889, to_date('18-09-2051', 'dd-mm-yyyy'), '1', '18', '261', '09', '2051', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18890, to_date('19-09-2051', 'dd-mm-yyyy'), '2', '19', '262', '09', '2051', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18891, to_date('20-09-2051', 'dd-mm-yyyy'), '3', '20', '263', '09', '2051', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18892, to_date('21-09-2051', 'dd-mm-yyyy'), '4', '21', '264', '09', '2051', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18893, to_date('22-09-2051', 'dd-mm-yyyy'), '5', '22', '265', '09', '2051', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18894, to_date('23-09-2051', 'dd-mm-yyyy'), '6', '23', '266', '09', '2051', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18895, to_date('24-09-2051', 'dd-mm-yyyy'), '7', '24', '267', '09', '2051', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18896, to_date('25-09-2051', 'dd-mm-yyyy'), '1', '25', '268', '09', '2051', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18897, to_date('26-09-2051', 'dd-mm-yyyy'), '2', '26', '269', '09', '2051', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18898, to_date('27-09-2051', 'dd-mm-yyyy'), '3', '27', '270', '09', '2051', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18899, to_date('28-09-2051', 'dd-mm-yyyy'), '4', '28', '271', '09', '2051', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18900, to_date('29-09-2051', 'dd-mm-yyyy'), '5', '29', '272', '09', '2051', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18901, to_date('30-09-2051', 'dd-mm-yyyy'), '6', '30', '273', '09', '2051', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18902, to_date('01-10-2051', 'dd-mm-yyyy'), '7', '01', '274', '10', '2051', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18903, to_date('02-10-2051', 'dd-mm-yyyy'), '1', '02', '275', '10', '2051', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18904, to_date('03-10-2051', 'dd-mm-yyyy'), '2', '03', '276', '10', '2051', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18905, to_date('04-10-2051', 'dd-mm-yyyy'), '3', '04', '277', '10', '2051', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18906, to_date('05-10-2051', 'dd-mm-yyyy'), '4', '05', '278', '10', '2051', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18907, to_date('06-10-2051', 'dd-mm-yyyy'), '5', '06', '279', '10', '2051', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18908, to_date('07-10-2051', 'dd-mm-yyyy'), '6', '07', '280', '10', '2051', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18909, to_date('08-10-2051', 'dd-mm-yyyy'), '7', '08', '281', '10', '2051', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18910, to_date('09-10-2051', 'dd-mm-yyyy'), '1', '09', '282', '10', '2051', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18911, to_date('10-10-2051', 'dd-mm-yyyy'), '2', '10', '283', '10', '2051', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18912, to_date('11-10-2051', 'dd-mm-yyyy'), '3', '11', '284', '10', '2051', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18913, to_date('12-10-2051', 'dd-mm-yyyy'), '4', '12', '285', '10', '2051', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18914, to_date('13-10-2051', 'dd-mm-yyyy'), '5', '13', '286', '10', '2051', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18915, to_date('14-10-2051', 'dd-mm-yyyy'), '6', '14', '287', '10', '2051', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18916, to_date('15-10-2051', 'dd-mm-yyyy'), '7', '15', '288', '10', '2051', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18917, to_date('16-10-2051', 'dd-mm-yyyy'), '1', '16', '289', '10', '2051', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18918, to_date('17-10-2051', 'dd-mm-yyyy'), '2', '17', '290', '10', '2051', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18919, to_date('18-10-2051', 'dd-mm-yyyy'), '3', '18', '291', '10', '2051', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18920, to_date('19-10-2051', 'dd-mm-yyyy'), '4', '19', '292', '10', '2051', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18921, to_date('20-10-2051', 'dd-mm-yyyy'), '5', '20', '293', '10', '2051', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18922, to_date('21-10-2051', 'dd-mm-yyyy'), '6', '21', '294', '10', '2051', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18923, to_date('22-10-2051', 'dd-mm-yyyy'), '7', '22', '295', '10', '2051', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18924, to_date('23-10-2051', 'dd-mm-yyyy'), '1', '23', '296', '10', '2051', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18925, to_date('24-10-2051', 'dd-mm-yyyy'), '2', '24', '297', '10', '2051', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18926, to_date('25-10-2051', 'dd-mm-yyyy'), '3', '25', '298', '10', '2051', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18927, to_date('26-10-2051', 'dd-mm-yyyy'), '4', '26', '299', '10', '2051', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18928, to_date('27-10-2051', 'dd-mm-yyyy'), '5', '27', '300', '10', '2051', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18929, to_date('28-10-2051', 'dd-mm-yyyy'), '6', '28', '301', '10', '2051', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18930, to_date('29-10-2051', 'dd-mm-yyyy'), '7', '29', '302', '10', '2051', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18931, to_date('30-10-2051', 'dd-mm-yyyy'), '1', '30', '303', '10', '2051', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18932, to_date('31-10-2051', 'dd-mm-yyyy'), '2', '31', '304', '10', '2051', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18933, to_date('01-11-2051', 'dd-mm-yyyy'), '3', '01', '305', '11', '2051', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18934, to_date('02-11-2051', 'dd-mm-yyyy'), '4', '02', '306', '11', '2051', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18935, to_date('03-11-2051', 'dd-mm-yyyy'), '5', '03', '307', '11', '2051', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18936, to_date('04-11-2051', 'dd-mm-yyyy'), '6', '04', '308', '11', '2051', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18937, to_date('05-11-2051', 'dd-mm-yyyy'), '7', '05', '309', '11', '2051', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18938, to_date('06-11-2051', 'dd-mm-yyyy'), '1', '06', '310', '11', '2051', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18939, to_date('07-11-2051', 'dd-mm-yyyy'), '2', '07', '311', '11', '2051', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18940, to_date('08-11-2051', 'dd-mm-yyyy'), '3', '08', '312', '11', '2051', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18941, to_date('09-11-2051', 'dd-mm-yyyy'), '4', '09', '313', '11', '2051', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18942, to_date('10-11-2051', 'dd-mm-yyyy'), '5', '10', '314', '11', '2051', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18943, to_date('11-11-2051', 'dd-mm-yyyy'), '6', '11', '315', '11', '2051', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18944, to_date('12-11-2051', 'dd-mm-yyyy'), '7', '12', '316', '11', '2051', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18945, to_date('13-11-2051', 'dd-mm-yyyy'), '1', '13', '317', '11', '2051', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18946, to_date('14-11-2051', 'dd-mm-yyyy'), '2', '14', '318', '11', '2051', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18947, to_date('15-11-2051', 'dd-mm-yyyy'), '3', '15', '319', '11', '2051', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18948, to_date('16-11-2051', 'dd-mm-yyyy'), '4', '16', '320', '11', '2051', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14073, to_date('12-07-2038', 'dd-mm-yyyy'), '1', '12', '193', '07', '2038', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14074, to_date('13-07-2038', 'dd-mm-yyyy'), '2', '13', '194', '07', '2038', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14075, to_date('14-07-2038', 'dd-mm-yyyy'), '3', '14', '195', '07', '2038', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14076, to_date('15-07-2038', 'dd-mm-yyyy'), '4', '15', '196', '07', '2038', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14077, to_date('16-07-2038', 'dd-mm-yyyy'), '5', '16', '197', '07', '2038', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14078, to_date('17-07-2038', 'dd-mm-yyyy'), '6', '17', '198', '07', '2038', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14079, to_date('18-07-2038', 'dd-mm-yyyy'), '7', '18', '199', '07', '2038', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14080, to_date('19-07-2038', 'dd-mm-yyyy'), '1', '19', '200', '07', '2038', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14081, to_date('20-07-2038', 'dd-mm-yyyy'), '2', '20', '201', '07', '2038', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14082, to_date('21-07-2038', 'dd-mm-yyyy'), '3', '21', '202', '07', '2038', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14083, to_date('22-07-2038', 'dd-mm-yyyy'), '4', '22', '203', '07', '2038', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14084, to_date('23-07-2038', 'dd-mm-yyyy'), '5', '23', '204', '07', '2038', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14085, to_date('24-07-2038', 'dd-mm-yyyy'), '6', '24', '205', '07', '2038', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14086, to_date('25-07-2038', 'dd-mm-yyyy'), '7', '25', '206', '07', '2038', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14087, to_date('26-07-2038', 'dd-mm-yyyy'), '1', '26', '207', '07', '2038', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14088, to_date('27-07-2038', 'dd-mm-yyyy'), '2', '27', '208', '07', '2038', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14089, to_date('28-07-2038', 'dd-mm-yyyy'), '3', '28', '209', '07', '2038', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14090, to_date('29-07-2038', 'dd-mm-yyyy'), '4', '29', '210', '07', '2038', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14091, to_date('30-07-2038', 'dd-mm-yyyy'), '5', '30', '211', '07', '2038', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14092, to_date('31-07-2038', 'dd-mm-yyyy'), '6', '31', '212', '07', '2038', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14093, to_date('01-08-2038', 'dd-mm-yyyy'), '7', '01', '213', '08', '2038', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14094, to_date('02-08-2038', 'dd-mm-yyyy'), '1', '02', '214', '08', '2038', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14095, to_date('03-08-2038', 'dd-mm-yyyy'), '2', '03', '215', '08', '2038', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14096, to_date('04-08-2038', 'dd-mm-yyyy'), '3', '04', '216', '08', '2038', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14097, to_date('05-08-2038', 'dd-mm-yyyy'), '4', '05', '217', '08', '2038', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14098, to_date('06-08-2038', 'dd-mm-yyyy'), '5', '06', '218', '08', '2038', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14099, to_date('07-08-2038', 'dd-mm-yyyy'), '6', '07', '219', '08', '2038', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14100, to_date('08-08-2038', 'dd-mm-yyyy'), '7', '08', '220', '08', '2038', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14101, to_date('09-08-2038', 'dd-mm-yyyy'), '1', '09', '221', '08', '2038', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14102, to_date('10-08-2038', 'dd-mm-yyyy'), '2', '10', '222', '08', '2038', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14103, to_date('11-08-2038', 'dd-mm-yyyy'), '3', '11', '223', '08', '2038', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14104, to_date('12-08-2038', 'dd-mm-yyyy'), '4', '12', '224', '08', '2038', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14105, to_date('13-08-2038', 'dd-mm-yyyy'), '5', '13', '225', '08', '2038', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14106, to_date('14-08-2038', 'dd-mm-yyyy'), '6', '14', '226', '08', '2038', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14107, to_date('15-08-2038', 'dd-mm-yyyy'), '7', '15', '227', '08', '2038', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14108, to_date('16-08-2038', 'dd-mm-yyyy'), '1', '16', '228', '08', '2038', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14109, to_date('17-08-2038', 'dd-mm-yyyy'), '2', '17', '229', '08', '2038', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14110, to_date('18-08-2038', 'dd-mm-yyyy'), '3', '18', '230', '08', '2038', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14111, to_date('19-08-2038', 'dd-mm-yyyy'), '4', '19', '231', '08', '2038', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14112, to_date('20-08-2038', 'dd-mm-yyyy'), '5', '20', '232', '08', '2038', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14113, to_date('21-08-2038', 'dd-mm-yyyy'), '6', '21', '233', '08', '2038', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14114, to_date('22-08-2038', 'dd-mm-yyyy'), '7', '22', '234', '08', '2038', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14115, to_date('23-08-2038', 'dd-mm-yyyy'), '1', '23', '235', '08', '2038', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14116, to_date('24-08-2038', 'dd-mm-yyyy'), '2', '24', '236', '08', '2038', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14117, to_date('25-08-2038', 'dd-mm-yyyy'), '3', '25', '237', '08', '2038', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14118, to_date('26-08-2038', 'dd-mm-yyyy'), '4', '26', '238', '08', '2038', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14119, to_date('27-08-2038', 'dd-mm-yyyy'), '5', '27', '239', '08', '2038', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14120, to_date('28-08-2038', 'dd-mm-yyyy'), '6', '28', '240', '08', '2038', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14121, to_date('29-08-2038', 'dd-mm-yyyy'), '7', '29', '241', '08', '2038', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14122, to_date('30-08-2038', 'dd-mm-yyyy'), '1', '30', '242', '08', '2038', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14123, to_date('31-08-2038', 'dd-mm-yyyy'), '2', '31', '243', '08', '2038', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14124, to_date('01-09-2038', 'dd-mm-yyyy'), '3', '01', '244', '09', '2038', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14125, to_date('02-09-2038', 'dd-mm-yyyy'), '4', '02', '245', '09', '2038', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14126, to_date('03-09-2038', 'dd-mm-yyyy'), '5', '03', '246', '09', '2038', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14127, to_date('04-09-2038', 'dd-mm-yyyy'), '6', '04', '247', '09', '2038', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14128, to_date('05-09-2038', 'dd-mm-yyyy'), '7', '05', '248', '09', '2038', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14129, to_date('06-09-2038', 'dd-mm-yyyy'), '1', '06', '249', '09', '2038', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14130, to_date('07-09-2038', 'dd-mm-yyyy'), '2', '07', '250', '09', '2038', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14131, to_date('08-09-2038', 'dd-mm-yyyy'), '3', '08', '251', '09', '2038', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14132, to_date('09-09-2038', 'dd-mm-yyyy'), '4', '09', '252', '09', '2038', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14133, to_date('10-09-2038', 'dd-mm-yyyy'), '5', '10', '253', '09', '2038', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14134, to_date('11-09-2038', 'dd-mm-yyyy'), '6', '11', '254', '09', '2038', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14135, to_date('12-09-2038', 'dd-mm-yyyy'), '7', '12', '255', '09', '2038', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14136, to_date('13-09-2038', 'dd-mm-yyyy'), '1', '13', '256', '09', '2038', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14137, to_date('14-09-2038', 'dd-mm-yyyy'), '2', '14', '257', '09', '2038', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14138, to_date('15-09-2038', 'dd-mm-yyyy'), '3', '15', '258', '09', '2038', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14139, to_date('16-09-2038', 'dd-mm-yyyy'), '4', '16', '259', '09', '2038', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14140, to_date('17-09-2038', 'dd-mm-yyyy'), '5', '17', '260', '09', '2038', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14141, to_date('18-09-2038', 'dd-mm-yyyy'), '6', '18', '261', '09', '2038', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14142, to_date('19-09-2038', 'dd-mm-yyyy'), '7', '19', '262', '09', '2038', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14143, to_date('20-09-2038', 'dd-mm-yyyy'), '1', '20', '263', '09', '2038', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14144, to_date('21-09-2038', 'dd-mm-yyyy'), '2', '21', '264', '09', '2038', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14145, to_date('22-09-2038', 'dd-mm-yyyy'), '3', '22', '265', '09', '2038', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14146, to_date('23-09-2038', 'dd-mm-yyyy'), '4', '23', '266', '09', '2038', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14147, to_date('24-09-2038', 'dd-mm-yyyy'), '5', '24', '267', '09', '2038', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14148, to_date('25-09-2038', 'dd-mm-yyyy'), '6', '25', '268', '09', '2038', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14149, to_date('26-09-2038', 'dd-mm-yyyy'), '7', '26', '269', '09', '2038', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14150, to_date('27-09-2038', 'dd-mm-yyyy'), '1', '27', '270', '09', '2038', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14151, to_date('28-09-2038', 'dd-mm-yyyy'), '2', '28', '271', '09', '2038', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14152, to_date('29-09-2038', 'dd-mm-yyyy'), '3', '29', '272', '09', '2038', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14153, to_date('30-09-2038', 'dd-mm-yyyy'), '4', '30', '273', '09', '2038', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14154, to_date('01-10-2038', 'dd-mm-yyyy'), '5', '01', '274', '10', '2038', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14155, to_date('02-10-2038', 'dd-mm-yyyy'), '6', '02', '275', '10', '2038', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14156, to_date('03-10-2038', 'dd-mm-yyyy'), '7', '03', '276', '10', '2038', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14157, to_date('04-10-2038', 'dd-mm-yyyy'), '1', '04', '277', '10', '2038', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14158, to_date('05-10-2038', 'dd-mm-yyyy'), '2', '05', '278', '10', '2038', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14159, to_date('06-10-2038', 'dd-mm-yyyy'), '3', '06', '279', '10', '2038', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14160, to_date('07-10-2038', 'dd-mm-yyyy'), '4', '07', '280', '10', '2038', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14161, to_date('08-10-2038', 'dd-mm-yyyy'), '5', '08', '281', '10', '2038', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14162, to_date('09-10-2038', 'dd-mm-yyyy'), '6', '09', '282', '10', '2038', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14163, to_date('10-10-2038', 'dd-mm-yyyy'), '7', '10', '283', '10', '2038', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14164, to_date('11-10-2038', 'dd-mm-yyyy'), '1', '11', '284', '10', '2038', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14165, to_date('12-10-2038', 'dd-mm-yyyy'), '2', '12', '285', '10', '2038', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14166, to_date('13-10-2038', 'dd-mm-yyyy'), '3', '13', '286', '10', '2038', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14167, to_date('14-10-2038', 'dd-mm-yyyy'), '4', '14', '287', '10', '2038', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14168, to_date('15-10-2038', 'dd-mm-yyyy'), '5', '15', '288', '10', '2038', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14169, to_date('16-10-2038', 'dd-mm-yyyy'), '6', '16', '289', '10', '2038', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14170, to_date('17-10-2038', 'dd-mm-yyyy'), '7', '17', '290', '10', '2038', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14171, to_date('18-10-2038', 'dd-mm-yyyy'), '1', '18', '291', '10', '2038', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14172, to_date('19-10-2038', 'dd-mm-yyyy'), '2', '19', '292', '10', '2038', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14173, to_date('20-10-2038', 'dd-mm-yyyy'), '3', '20', '293', '10', '2038', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14174, to_date('21-10-2038', 'dd-mm-yyyy'), '4', '21', '294', '10', '2038', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14175, to_date('22-10-2038', 'dd-mm-yyyy'), '5', '22', '295', '10', '2038', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14176, to_date('23-10-2038', 'dd-mm-yyyy'), '6', '23', '296', '10', '2038', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14177, to_date('24-10-2038', 'dd-mm-yyyy'), '7', '24', '297', '10', '2038', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14178, to_date('25-10-2038', 'dd-mm-yyyy'), '1', '25', '298', '10', '2038', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15769, to_date('04-03-2043', 'dd-mm-yyyy'), '3', '04', '063', '03', '2043', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15770, to_date('05-03-2043', 'dd-mm-yyyy'), '4', '05', '064', '03', '2043', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15771, to_date('06-03-2043', 'dd-mm-yyyy'), '5', '06', '065', '03', '2043', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15772, to_date('07-03-2043', 'dd-mm-yyyy'), '6', '07', '066', '03', '2043', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15773, to_date('08-03-2043', 'dd-mm-yyyy'), '7', '08', '067', '03', '2043', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15774, to_date('09-03-2043', 'dd-mm-yyyy'), '1', '09', '068', '03', '2043', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15775, to_date('10-03-2043', 'dd-mm-yyyy'), '2', '10', '069', '03', '2043', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15776, to_date('11-03-2043', 'dd-mm-yyyy'), '3', '11', '070', '03', '2043', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15777, to_date('12-03-2043', 'dd-mm-yyyy'), '4', '12', '071', '03', '2043', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15778, to_date('13-03-2043', 'dd-mm-yyyy'), '5', '13', '072', '03', '2043', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15779, to_date('14-03-2043', 'dd-mm-yyyy'), '6', '14', '073', '03', '2043', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15780, to_date('15-03-2043', 'dd-mm-yyyy'), '7', '15', '074', '03', '2043', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15781, to_date('16-03-2043', 'dd-mm-yyyy'), '1', '16', '075', '03', '2043', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15782, to_date('17-03-2043', 'dd-mm-yyyy'), '2', '17', '076', '03', '2043', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15783, to_date('18-03-2043', 'dd-mm-yyyy'), '3', '18', '077', '03', '2043', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15784, to_date('19-03-2043', 'dd-mm-yyyy'), '4', '19', '078', '03', '2043', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15785, to_date('20-03-2043', 'dd-mm-yyyy'), '5', '20', '079', '03', '2043', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15786, to_date('21-03-2043', 'dd-mm-yyyy'), '6', '21', '080', '03', '2043', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15787, to_date('22-03-2043', 'dd-mm-yyyy'), '7', '22', '081', '03', '2043', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15788, to_date('23-03-2043', 'dd-mm-yyyy'), '1', '23', '082', '03', '2043', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15789, to_date('24-03-2043', 'dd-mm-yyyy'), '2', '24', '083', '03', '2043', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15790, to_date('25-03-2043', 'dd-mm-yyyy'), '3', '25', '084', '03', '2043', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15791, to_date('26-03-2043', 'dd-mm-yyyy'), '4', '26', '085', '03', '2043', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15792, to_date('27-03-2043', 'dd-mm-yyyy'), '5', '27', '086', '03', '2043', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15793, to_date('28-03-2043', 'dd-mm-yyyy'), '6', '28', '087', '03', '2043', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15794, to_date('29-03-2043', 'dd-mm-yyyy'), '7', '29', '088', '03', '2043', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15795, to_date('30-03-2043', 'dd-mm-yyyy'), '1', '30', '089', '03', '2043', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15796, to_date('31-03-2043', 'dd-mm-yyyy'), '2', '31', '090', '03', '2043', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15797, to_date('01-04-2043', 'dd-mm-yyyy'), '3', '01', '091', '04', '2043', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15798, to_date('02-04-2043', 'dd-mm-yyyy'), '4', '02', '092', '04', '2043', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15799, to_date('03-04-2043', 'dd-mm-yyyy'), '5', '03', '093', '04', '2043', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15800, to_date('04-04-2043', 'dd-mm-yyyy'), '6', '04', '094', '04', '2043', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15801, to_date('05-04-2043', 'dd-mm-yyyy'), '7', '05', '095', '04', '2043', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15802, to_date('06-04-2043', 'dd-mm-yyyy'), '1', '06', '096', '04', '2043', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15803, to_date('07-04-2043', 'dd-mm-yyyy'), '2', '07', '097', '04', '2043', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15804, to_date('08-04-2043', 'dd-mm-yyyy'), '3', '08', '098', '04', '2043', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15805, to_date('09-04-2043', 'dd-mm-yyyy'), '4', '09', '099', '04', '2043', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15806, to_date('10-04-2043', 'dd-mm-yyyy'), '5', '10', '100', '04', '2043', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15807, to_date('11-04-2043', 'dd-mm-yyyy'), '6', '11', '101', '04', '2043', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15808, to_date('12-04-2043', 'dd-mm-yyyy'), '7', '12', '102', '04', '2043', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15809, to_date('13-04-2043', 'dd-mm-yyyy'), '1', '13', '103', '04', '2043', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15810, to_date('14-04-2043', 'dd-mm-yyyy'), '2', '14', '104', '04', '2043', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15811, to_date('15-04-2043', 'dd-mm-yyyy'), '3', '15', '105', '04', '2043', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15812, to_date('16-04-2043', 'dd-mm-yyyy'), '4', '16', '106', '04', '2043', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15813, to_date('17-04-2043', 'dd-mm-yyyy'), '5', '17', '107', '04', '2043', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15814, to_date('18-04-2043', 'dd-mm-yyyy'), '6', '18', '108', '04', '2043', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15815, to_date('19-04-2043', 'dd-mm-yyyy'), '7', '19', '109', '04', '2043', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15816, to_date('20-04-2043', 'dd-mm-yyyy'), '1', '20', '110', '04', '2043', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15817, to_date('21-04-2043', 'dd-mm-yyyy'), '2', '21', '111', '04', '2043', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15818, to_date('22-04-2043', 'dd-mm-yyyy'), '3', '22', '112', '04', '2043', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15819, to_date('23-04-2043', 'dd-mm-yyyy'), '4', '23', '113', '04', '2043', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15820, to_date('24-04-2043', 'dd-mm-yyyy'), '5', '24', '114', '04', '2043', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15821, to_date('25-04-2043', 'dd-mm-yyyy'), '6', '25', '115', '04', '2043', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15822, to_date('26-04-2043', 'dd-mm-yyyy'), '7', '26', '116', '04', '2043', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15823, to_date('27-04-2043', 'dd-mm-yyyy'), '1', '27', '117', '04', '2043', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15824, to_date('28-04-2043', 'dd-mm-yyyy'), '2', '28', '118', '04', '2043', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15825, to_date('29-04-2043', 'dd-mm-yyyy'), '3', '29', '119', '04', '2043', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15826, to_date('30-04-2043', 'dd-mm-yyyy'), '4', '30', '120', '04', '2043', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15827, to_date('01-05-2043', 'dd-mm-yyyy'), '5', '01', '121', '05', '2043', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15828, to_date('02-05-2043', 'dd-mm-yyyy'), '6', '02', '122', '05', '2043', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15829, to_date('03-05-2043', 'dd-mm-yyyy'), '7', '03', '123', '05', '2043', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15830, to_date('04-05-2043', 'dd-mm-yyyy'), '1', '04', '124', '05', '2043', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15831, to_date('05-05-2043', 'dd-mm-yyyy'), '2', '05', '125', '05', '2043', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15832, to_date('06-05-2043', 'dd-mm-yyyy'), '3', '06', '126', '05', '2043', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15833, to_date('07-05-2043', 'dd-mm-yyyy'), '4', '07', '127', '05', '2043', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15834, to_date('08-05-2043', 'dd-mm-yyyy'), '5', '08', '128', '05', '2043', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15835, to_date('09-05-2043', 'dd-mm-yyyy'), '6', '09', '129', '05', '2043', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15836, to_date('10-05-2043', 'dd-mm-yyyy'), '7', '10', '130', '05', '2043', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15837, to_date('11-05-2043', 'dd-mm-yyyy'), '1', '11', '131', '05', '2043', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15838, to_date('12-05-2043', 'dd-mm-yyyy'), '2', '12', '132', '05', '2043', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15839, to_date('13-05-2043', 'dd-mm-yyyy'), '3', '13', '133', '05', '2043', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15840, to_date('14-05-2043', 'dd-mm-yyyy'), '4', '14', '134', '05', '2043', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15841, to_date('15-05-2043', 'dd-mm-yyyy'), '5', '15', '135', '05', '2043', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15842, to_date('16-05-2043', 'dd-mm-yyyy'), '6', '16', '136', '05', '2043', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15843, to_date('17-05-2043', 'dd-mm-yyyy'), '7', '17', '137', '05', '2043', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15844, to_date('18-05-2043', 'dd-mm-yyyy'), '1', '18', '138', '05', '2043', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15845, to_date('19-05-2043', 'dd-mm-yyyy'), '2', '19', '139', '05', '2043', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15846, to_date('20-05-2043', 'dd-mm-yyyy'), '3', '20', '140', '05', '2043', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15847, to_date('21-05-2043', 'dd-mm-yyyy'), '4', '21', '141', '05', '2043', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15848, to_date('22-05-2043', 'dd-mm-yyyy'), '5', '22', '142', '05', '2043', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15849, to_date('23-05-2043', 'dd-mm-yyyy'), '6', '23', '143', '05', '2043', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15850, to_date('24-05-2043', 'dd-mm-yyyy'), '7', '24', '144', '05', '2043', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15851, to_date('25-05-2043', 'dd-mm-yyyy'), '1', '25', '145', '05', '2043', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15852, to_date('26-05-2043', 'dd-mm-yyyy'), '2', '26', '146', '05', '2043', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15853, to_date('27-05-2043', 'dd-mm-yyyy'), '3', '27', '147', '05', '2043', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15854, to_date('28-05-2043', 'dd-mm-yyyy'), '4', '28', '148', '05', '2043', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15855, to_date('29-05-2043', 'dd-mm-yyyy'), '5', '29', '149', '05', '2043', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15856, to_date('30-05-2043', 'dd-mm-yyyy'), '6', '30', '150', '05', '2043', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15857, to_date('31-05-2043', 'dd-mm-yyyy'), '7', '31', '151', '05', '2043', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15858, to_date('01-06-2043', 'dd-mm-yyyy'), '1', '01', '152', '06', '2043', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15859, to_date('02-06-2043', 'dd-mm-yyyy'), '2', '02', '153', '06', '2043', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15860, to_date('03-06-2043', 'dd-mm-yyyy'), '3', '03', '154', '06', '2043', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15861, to_date('04-06-2043', 'dd-mm-yyyy'), '4', '04', '155', '06', '2043', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15862, to_date('05-06-2043', 'dd-mm-yyyy'), '5', '05', '156', '06', '2043', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15863, to_date('06-06-2043', 'dd-mm-yyyy'), '6', '06', '157', '06', '2043', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15864, to_date('07-06-2043', 'dd-mm-yyyy'), '7', '07', '158', '06', '2043', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15865, to_date('08-06-2043', 'dd-mm-yyyy'), '1', '08', '159', '06', '2043', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15866, to_date('09-06-2043', 'dd-mm-yyyy'), '2', '09', '160', '06', '2043', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15867, to_date('10-06-2043', 'dd-mm-yyyy'), '3', '10', '161', '06', '2043', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15868, to_date('11-06-2043', 'dd-mm-yyyy'), '4', '11', '162', '06', '2043', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15869, to_date('12-06-2043', 'dd-mm-yyyy'), '5', '12', '163', '06', '2043', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15870, to_date('13-06-2043', 'dd-mm-yyyy'), '6', '13', '164', '06', '2043', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15871, to_date('14-06-2043', 'dd-mm-yyyy'), '7', '14', '165', '06', '2043', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15872, to_date('15-06-2043', 'dd-mm-yyyy'), '1', '15', '166', '06', '2043', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15873, to_date('16-06-2043', 'dd-mm-yyyy'), '2', '16', '167', '06', '2043', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (15874, to_date('17-06-2043', 'dd-mm-yyyy'), '3', '17', '168', '06', '2043', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17359, to_date('11-07-2047', 'dd-mm-yyyy'), '4', '11', '192', '07', '2047', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17360, to_date('12-07-2047', 'dd-mm-yyyy'), '5', '12', '193', '07', '2047', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17361, to_date('13-07-2047', 'dd-mm-yyyy'), '6', '13', '194', '07', '2047', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17362, to_date('14-07-2047', 'dd-mm-yyyy'), '7', '14', '195', '07', '2047', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17363, to_date('15-07-2047', 'dd-mm-yyyy'), '1', '15', '196', '07', '2047', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17364, to_date('16-07-2047', 'dd-mm-yyyy'), '2', '16', '197', '07', '2047', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17365, to_date('17-07-2047', 'dd-mm-yyyy'), '3', '17', '198', '07', '2047', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17366, to_date('18-07-2047', 'dd-mm-yyyy'), '4', '18', '199', '07', '2047', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17367, to_date('19-07-2047', 'dd-mm-yyyy'), '5', '19', '200', '07', '2047', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17368, to_date('20-07-2047', 'dd-mm-yyyy'), '6', '20', '201', '07', '2047', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17369, to_date('21-07-2047', 'dd-mm-yyyy'), '7', '21', '202', '07', '2047', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17370, to_date('22-07-2047', 'dd-mm-yyyy'), '1', '22', '203', '07', '2047', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17371, to_date('23-07-2047', 'dd-mm-yyyy'), '2', '23', '204', '07', '2047', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17372, to_date('24-07-2047', 'dd-mm-yyyy'), '3', '24', '205', '07', '2047', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17373, to_date('25-07-2047', 'dd-mm-yyyy'), '4', '25', '206', '07', '2047', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17374, to_date('26-07-2047', 'dd-mm-yyyy'), '5', '26', '207', '07', '2047', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17375, to_date('27-07-2047', 'dd-mm-yyyy'), '6', '27', '208', '07', '2047', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17376, to_date('28-07-2047', 'dd-mm-yyyy'), '7', '28', '209', '07', '2047', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17377, to_date('29-07-2047', 'dd-mm-yyyy'), '1', '29', '210', '07', '2047', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17378, to_date('30-07-2047', 'dd-mm-yyyy'), '2', '30', '211', '07', '2047', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17379, to_date('31-07-2047', 'dd-mm-yyyy'), '3', '31', '212', '07', '2047', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17380, to_date('01-08-2047', 'dd-mm-yyyy'), '4', '01', '213', '08', '2047', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17381, to_date('02-08-2047', 'dd-mm-yyyy'), '5', '02', '214', '08', '2047', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17382, to_date('03-08-2047', 'dd-mm-yyyy'), '6', '03', '215', '08', '2047', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17383, to_date('04-08-2047', 'dd-mm-yyyy'), '7', '04', '216', '08', '2047', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17384, to_date('05-08-2047', 'dd-mm-yyyy'), '1', '05', '217', '08', '2047', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17385, to_date('06-08-2047', 'dd-mm-yyyy'), '2', '06', '218', '08', '2047', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17386, to_date('07-08-2047', 'dd-mm-yyyy'), '3', '07', '219', '08', '2047', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17387, to_date('08-08-2047', 'dd-mm-yyyy'), '4', '08', '220', '08', '2047', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17388, to_date('09-08-2047', 'dd-mm-yyyy'), '5', '09', '221', '08', '2047', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17389, to_date('10-08-2047', 'dd-mm-yyyy'), '6', '10', '222', '08', '2047', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17390, to_date('11-08-2047', 'dd-mm-yyyy'), '7', '11', '223', '08', '2047', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17391, to_date('12-08-2047', 'dd-mm-yyyy'), '1', '12', '224', '08', '2047', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17392, to_date('13-08-2047', 'dd-mm-yyyy'), '2', '13', '225', '08', '2047', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17393, to_date('14-08-2047', 'dd-mm-yyyy'), '3', '14', '226', '08', '2047', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17394, to_date('15-08-2047', 'dd-mm-yyyy'), '4', '15', '227', '08', '2047', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17395, to_date('16-08-2047', 'dd-mm-yyyy'), '5', '16', '228', '08', '2047', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17396, to_date('17-08-2047', 'dd-mm-yyyy'), '6', '17', '229', '08', '2047', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17397, to_date('18-08-2047', 'dd-mm-yyyy'), '7', '18', '230', '08', '2047', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17398, to_date('19-08-2047', 'dd-mm-yyyy'), '1', '19', '231', '08', '2047', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17399, to_date('20-08-2047', 'dd-mm-yyyy'), '2', '20', '232', '08', '2047', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17400, to_date('21-08-2047', 'dd-mm-yyyy'), '3', '21', '233', '08', '2047', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17401, to_date('22-08-2047', 'dd-mm-yyyy'), '4', '22', '234', '08', '2047', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17402, to_date('23-08-2047', 'dd-mm-yyyy'), '5', '23', '235', '08', '2047', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17403, to_date('24-08-2047', 'dd-mm-yyyy'), '6', '24', '236', '08', '2047', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17404, to_date('25-08-2047', 'dd-mm-yyyy'), '7', '25', '237', '08', '2047', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17405, to_date('26-08-2047', 'dd-mm-yyyy'), '1', '26', '238', '08', '2047', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17406, to_date('27-08-2047', 'dd-mm-yyyy'), '2', '27', '239', '08', '2047', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17407, to_date('28-08-2047', 'dd-mm-yyyy'), '3', '28', '240', '08', '2047', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17408, to_date('29-08-2047', 'dd-mm-yyyy'), '4', '29', '241', '08', '2047', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17409, to_date('30-08-2047', 'dd-mm-yyyy'), '5', '30', '242', '08', '2047', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17410, to_date('31-08-2047', 'dd-mm-yyyy'), '6', '31', '243', '08', '2047', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17411, to_date('01-09-2047', 'dd-mm-yyyy'), '7', '01', '244', '09', '2047', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17412, to_date('02-09-2047', 'dd-mm-yyyy'), '1', '02', '245', '09', '2047', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17413, to_date('03-09-2047', 'dd-mm-yyyy'), '2', '03', '246', '09', '2047', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17414, to_date('04-09-2047', 'dd-mm-yyyy'), '3', '04', '247', '09', '2047', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17415, to_date('05-09-2047', 'dd-mm-yyyy'), '4', '05', '248', '09', '2047', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17416, to_date('06-09-2047', 'dd-mm-yyyy'), '5', '06', '249', '09', '2047', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17417, to_date('07-09-2047', 'dd-mm-yyyy'), '6', '07', '250', '09', '2047', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17418, to_date('08-09-2047', 'dd-mm-yyyy'), '7', '08', '251', '09', '2047', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17419, to_date('09-09-2047', 'dd-mm-yyyy'), '1', '09', '252', '09', '2047', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17420, to_date('10-09-2047', 'dd-mm-yyyy'), '2', '10', '253', '09', '2047', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17421, to_date('11-09-2047', 'dd-mm-yyyy'), '3', '11', '254', '09', '2047', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17422, to_date('12-09-2047', 'dd-mm-yyyy'), '4', '12', '255', '09', '2047', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17423, to_date('13-09-2047', 'dd-mm-yyyy'), '5', '13', '256', '09', '2047', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17424, to_date('14-09-2047', 'dd-mm-yyyy'), '6', '14', '257', '09', '2047', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17425, to_date('15-09-2047', 'dd-mm-yyyy'), '7', '15', '258', '09', '2047', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17426, to_date('16-09-2047', 'dd-mm-yyyy'), '1', '16', '259', '09', '2047', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17427, to_date('17-09-2047', 'dd-mm-yyyy'), '2', '17', '260', '09', '2047', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17428, to_date('18-09-2047', 'dd-mm-yyyy'), '3', '18', '261', '09', '2047', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17429, to_date('19-09-2047', 'dd-mm-yyyy'), '4', '19', '262', '09', '2047', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17430, to_date('20-09-2047', 'dd-mm-yyyy'), '5', '20', '263', '09', '2047', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17431, to_date('21-09-2047', 'dd-mm-yyyy'), '6', '21', '264', '09', '2047', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17432, to_date('22-09-2047', 'dd-mm-yyyy'), '7', '22', '265', '09', '2047', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17433, to_date('23-09-2047', 'dd-mm-yyyy'), '1', '23', '266', '09', '2047', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17434, to_date('24-09-2047', 'dd-mm-yyyy'), '2', '24', '267', '09', '2047', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17435, to_date('25-09-2047', 'dd-mm-yyyy'), '3', '25', '268', '09', '2047', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17436, to_date('26-09-2047', 'dd-mm-yyyy'), '4', '26', '269', '09', '2047', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17437, to_date('27-09-2047', 'dd-mm-yyyy'), '5', '27', '270', '09', '2047', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17438, to_date('28-09-2047', 'dd-mm-yyyy'), '6', '28', '271', '09', '2047', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17439, to_date('29-09-2047', 'dd-mm-yyyy'), '7', '29', '272', '09', '2047', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17440, to_date('30-09-2047', 'dd-mm-yyyy'), '1', '30', '273', '09', '2047', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17441, to_date('01-10-2047', 'dd-mm-yyyy'), '2', '01', '274', '10', '2047', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17442, to_date('02-10-2047', 'dd-mm-yyyy'), '3', '02', '275', '10', '2047', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17443, to_date('03-10-2047', 'dd-mm-yyyy'), '4', '03', '276', '10', '2047', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17444, to_date('04-10-2047', 'dd-mm-yyyy'), '5', '04', '277', '10', '2047', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17445, to_date('05-10-2047', 'dd-mm-yyyy'), '6', '05', '278', '10', '2047', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17446, to_date('06-10-2047', 'dd-mm-yyyy'), '7', '06', '279', '10', '2047', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17447, to_date('07-10-2047', 'dd-mm-yyyy'), '1', '07', '280', '10', '2047', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17448, to_date('08-10-2047', 'dd-mm-yyyy'), '2', '08', '281', '10', '2047', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17449, to_date('09-10-2047', 'dd-mm-yyyy'), '3', '09', '282', '10', '2047', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17450, to_date('10-10-2047', 'dd-mm-yyyy'), '4', '10', '283', '10', '2047', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17451, to_date('11-10-2047', 'dd-mm-yyyy'), '5', '11', '284', '10', '2047', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17452, to_date('12-10-2047', 'dd-mm-yyyy'), '6', '12', '285', '10', '2047', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17453, to_date('13-10-2047', 'dd-mm-yyyy'), '7', '13', '286', '10', '2047', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17454, to_date('14-10-2047', 'dd-mm-yyyy'), '1', '14', '287', '10', '2047', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17455, to_date('15-10-2047', 'dd-mm-yyyy'), '2', '15', '288', '10', '2047', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17456, to_date('16-10-2047', 'dd-mm-yyyy'), '3', '16', '289', '10', '2047', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17457, to_date('17-10-2047', 'dd-mm-yyyy'), '4', '17', '290', '10', '2047', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17458, to_date('18-10-2047', 'dd-mm-yyyy'), '5', '18', '291', '10', '2047', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17459, to_date('19-10-2047', 'dd-mm-yyyy'), '6', '19', '292', '10', '2047', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17460, to_date('20-10-2047', 'dd-mm-yyyy'), '7', '20', '293', '10', '2047', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17461, to_date('21-10-2047', 'dd-mm-yyyy'), '1', '21', '294', '10', '2047', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17462, to_date('22-10-2047', 'dd-mm-yyyy'), '2', '22', '295', '10', '2047', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17463, to_date('23-10-2047', 'dd-mm-yyyy'), '3', '23', '296', '10', '2047', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (17464, to_date('24-10-2047', 'dd-mm-yyyy'), '4', '24', '297', '10', '2047', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18949, to_date('17-11-2051', 'dd-mm-yyyy'), '5', '17', '321', '11', '2051', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18950, to_date('18-11-2051', 'dd-mm-yyyy'), '6', '18', '322', '11', '2051', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18951, to_date('19-11-2051', 'dd-mm-yyyy'), '7', '19', '323', '11', '2051', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18952, to_date('20-11-2051', 'dd-mm-yyyy'), '1', '20', '324', '11', '2051', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18953, to_date('21-11-2051', 'dd-mm-yyyy'), '2', '21', '325', '11', '2051', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18954, to_date('22-11-2051', 'dd-mm-yyyy'), '3', '22', '326', '11', '2051', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18955, to_date('23-11-2051', 'dd-mm-yyyy'), '4', '23', '327', '11', '2051', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18956, to_date('24-11-2051', 'dd-mm-yyyy'), '5', '24', '328', '11', '2051', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18957, to_date('25-11-2051', 'dd-mm-yyyy'), '6', '25', '329', '11', '2051', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18958, to_date('26-11-2051', 'dd-mm-yyyy'), '7', '26', '330', '11', '2051', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18959, to_date('27-11-2051', 'dd-mm-yyyy'), '1', '27', '331', '11', '2051', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18960, to_date('28-11-2051', 'dd-mm-yyyy'), '2', '28', '332', '11', '2051', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18961, to_date('29-11-2051', 'dd-mm-yyyy'), '3', '29', '333', '11', '2051', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18962, to_date('30-11-2051', 'dd-mm-yyyy'), '4', '30', '334', '11', '2051', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18963, to_date('01-12-2051', 'dd-mm-yyyy'), '5', '01', '335', '12', '2051', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18964, to_date('02-12-2051', 'dd-mm-yyyy'), '6', '02', '336', '12', '2051', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18965, to_date('03-12-2051', 'dd-mm-yyyy'), '7', '03', '337', '12', '2051', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18966, to_date('04-12-2051', 'dd-mm-yyyy'), '1', '04', '338', '12', '2051', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18967, to_date('05-12-2051', 'dd-mm-yyyy'), '2', '05', '339', '12', '2051', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18968, to_date('06-12-2051', 'dd-mm-yyyy'), '3', '06', '340', '12', '2051', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18969, to_date('07-12-2051', 'dd-mm-yyyy'), '4', '07', '341', '12', '2051', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18970, to_date('08-12-2051', 'dd-mm-yyyy'), '5', '08', '342', '12', '2051', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18971, to_date('09-12-2051', 'dd-mm-yyyy'), '6', '09', '343', '12', '2051', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18972, to_date('10-12-2051', 'dd-mm-yyyy'), '7', '10', '344', '12', '2051', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18973, to_date('11-12-2051', 'dd-mm-yyyy'), '1', '11', '345', '12', '2051', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18974, to_date('12-12-2051', 'dd-mm-yyyy'), '2', '12', '346', '12', '2051', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18975, to_date('13-12-2051', 'dd-mm-yyyy'), '3', '13', '347', '12', '2051', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18976, to_date('14-12-2051', 'dd-mm-yyyy'), '4', '14', '348', '12', '2051', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18977, to_date('15-12-2051', 'dd-mm-yyyy'), '5', '15', '349', '12', '2051', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18978, to_date('16-12-2051', 'dd-mm-yyyy'), '6', '16', '350', '12', '2051', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18979, to_date('17-12-2051', 'dd-mm-yyyy'), '7', '17', '351', '12', '2051', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18980, to_date('18-12-2051', 'dd-mm-yyyy'), '1', '18', '352', '12', '2051', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18981, to_date('19-12-2051', 'dd-mm-yyyy'), '2', '19', '353', '12', '2051', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18982, to_date('20-12-2051', 'dd-mm-yyyy'), '3', '20', '354', '12', '2051', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18983, to_date('21-12-2051', 'dd-mm-yyyy'), '4', '21', '355', '12', '2051', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18984, to_date('22-12-2051', 'dd-mm-yyyy'), '5', '22', '356', '12', '2051', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18985, to_date('23-12-2051', 'dd-mm-yyyy'), '6', '23', '357', '12', '2051', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18986, to_date('24-12-2051', 'dd-mm-yyyy'), '7', '24', '358', '12', '2051', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18987, to_date('25-12-2051', 'dd-mm-yyyy'), '1', '25', '359', '12', '2051', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18988, to_date('26-12-2051', 'dd-mm-yyyy'), '2', '26', '360', '12', '2051', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18989, to_date('27-12-2051', 'dd-mm-yyyy'), '3', '27', '361', '12', '2051', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18990, to_date('28-12-2051', 'dd-mm-yyyy'), '4', '28', '362', '12', '2051', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18991, to_date('29-12-2051', 'dd-mm-yyyy'), '5', '29', '363', '12', '2051', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18992, to_date('30-12-2051', 'dd-mm-yyyy'), '6', '30', '364', '12', '2051', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18993, to_date('31-12-2051', 'dd-mm-yyyy'), '7', '31', '365', '12', '2051', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18994, to_date('01-01-2052', 'dd-mm-yyyy'), '1', '01', '001', '01', '2052', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18995, to_date('02-01-2052', 'dd-mm-yyyy'), '2', '02', '002', '01', '2052', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18996, to_date('03-01-2052', 'dd-mm-yyyy'), '3', '03', '003', '01', '2052', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18997, to_date('04-01-2052', 'dd-mm-yyyy'), '4', '04', '004', '01', '2052', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18998, to_date('05-01-2052', 'dd-mm-yyyy'), '5', '05', '005', '01', '2052', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (18999, to_date('06-01-2052', 'dd-mm-yyyy'), '6', '06', '006', '01', '2052', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19000, to_date('07-01-2052', 'dd-mm-yyyy'), '7', '07', '007', '01', '2052', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19001, to_date('08-01-2052', 'dd-mm-yyyy'), '1', '08', '008', '01', '2052', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19002, to_date('09-01-2052', 'dd-mm-yyyy'), '2', '09', '009', '01', '2052', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19003, to_date('10-01-2052', 'dd-mm-yyyy'), '3', '10', '010', '01', '2052', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19004, to_date('11-01-2052', 'dd-mm-yyyy'), '4', '11', '011', '01', '2052', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19005, to_date('12-01-2052', 'dd-mm-yyyy'), '5', '12', '012', '01', '2052', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19006, to_date('13-01-2052', 'dd-mm-yyyy'), '6', '13', '013', '01', '2052', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19007, to_date('14-01-2052', 'dd-mm-yyyy'), '7', '14', '014', '01', '2052', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19008, to_date('15-01-2052', 'dd-mm-yyyy'), '1', '15', '015', '01', '2052', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19009, to_date('16-01-2052', 'dd-mm-yyyy'), '2', '16', '016', '01', '2052', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19010, to_date('17-01-2052', 'dd-mm-yyyy'), '3', '17', '017', '01', '2052', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19011, to_date('18-01-2052', 'dd-mm-yyyy'), '4', '18', '018', '01', '2052', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19012, to_date('19-01-2052', 'dd-mm-yyyy'), '5', '19', '019', '01', '2052', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19013, to_date('20-01-2052', 'dd-mm-yyyy'), '6', '20', '020', '01', '2052', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19014, to_date('21-01-2052', 'dd-mm-yyyy'), '7', '21', '021', '01', '2052', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19015, to_date('22-01-2052', 'dd-mm-yyyy'), '1', '22', '022', '01', '2052', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19016, to_date('23-01-2052', 'dd-mm-yyyy'), '2', '23', '023', '01', '2052', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19017, to_date('24-01-2052', 'dd-mm-yyyy'), '3', '24', '024', '01', '2052', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19018, to_date('25-01-2052', 'dd-mm-yyyy'), '4', '25', '025', '01', '2052', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19019, to_date('26-01-2052', 'dd-mm-yyyy'), '5', '26', '026', '01', '2052', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19020, to_date('27-01-2052', 'dd-mm-yyyy'), '6', '27', '027', '01', '2052', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19021, to_date('28-01-2052', 'dd-mm-yyyy'), '7', '28', '028', '01', '2052', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19022, to_date('29-01-2052', 'dd-mm-yyyy'), '1', '29', '029', '01', '2052', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19023, to_date('30-01-2052', 'dd-mm-yyyy'), '2', '30', '030', '01', '2052', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19024, to_date('31-01-2052', 'dd-mm-yyyy'), '3', '31', '031', '01', '2052', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19025, to_date('01-02-2052', 'dd-mm-yyyy'), '4', '01', '032', '02', '2052', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19026, to_date('02-02-2052', 'dd-mm-yyyy'), '5', '02', '033', '02', '2052', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19027, to_date('03-02-2052', 'dd-mm-yyyy'), '6', '03', '034', '02', '2052', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19028, to_date('04-02-2052', 'dd-mm-yyyy'), '7', '04', '035', '02', '2052', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19029, to_date('05-02-2052', 'dd-mm-yyyy'), '1', '05', '036', '02', '2052', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19030, to_date('06-02-2052', 'dd-mm-yyyy'), '2', '06', '037', '02', '2052', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19031, to_date('07-02-2052', 'dd-mm-yyyy'), '3', '07', '038', '02', '2052', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19032, to_date('08-02-2052', 'dd-mm-yyyy'), '4', '08', '039', '02', '2052', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19033, to_date('09-02-2052', 'dd-mm-yyyy'), '5', '09', '040', '02', '2052', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19034, to_date('10-02-2052', 'dd-mm-yyyy'), '6', '10', '041', '02', '2052', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19035, to_date('11-02-2052', 'dd-mm-yyyy'), '7', '11', '042', '02', '2052', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19036, to_date('12-02-2052', 'dd-mm-yyyy'), '1', '12', '043', '02', '2052', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19037, to_date('13-02-2052', 'dd-mm-yyyy'), '2', '13', '044', '02', '2052', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19038, to_date('14-02-2052', 'dd-mm-yyyy'), '3', '14', '045', '02', '2052', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19039, to_date('15-02-2052', 'dd-mm-yyyy'), '4', '15', '046', '02', '2052', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19040, to_date('16-02-2052', 'dd-mm-yyyy'), '5', '16', '047', '02', '2052', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19041, to_date('17-02-2052', 'dd-mm-yyyy'), '6', '17', '048', '02', '2052', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19042, to_date('18-02-2052', 'dd-mm-yyyy'), '7', '18', '049', '02', '2052', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19043, to_date('19-02-2052', 'dd-mm-yyyy'), '1', '19', '050', '02', '2052', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19044, to_date('20-02-2052', 'dd-mm-yyyy'), '2', '20', '051', '02', '2052', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19045, to_date('21-02-2052', 'dd-mm-yyyy'), '3', '21', '052', '02', '2052', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19046, to_date('22-02-2052', 'dd-mm-yyyy'), '4', '22', '053', '02', '2052', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19047, to_date('23-02-2052', 'dd-mm-yyyy'), '5', '23', '054', '02', '2052', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19048, to_date('24-02-2052', 'dd-mm-yyyy'), '6', '24', '055', '02', '2052', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19049, to_date('25-02-2052', 'dd-mm-yyyy'), '7', '25', '056', '02', '2052', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19050, to_date('26-02-2052', 'dd-mm-yyyy'), '1', '26', '057', '02', '2052', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19051, to_date('27-02-2052', 'dd-mm-yyyy'), '2', '27', '058', '02', '2052', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19052, to_date('28-02-2052', 'dd-mm-yyyy'), '3', '28', '059', '02', '2052', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19053, to_date('29-02-2052', 'dd-mm-yyyy'), '4', '29', '060', '02', '2052', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (19054, to_date('01-03-2052', 'dd-mm-yyyy'), '5', '01', '061', '03', '2052', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14179, to_date('26-10-2038', 'dd-mm-yyyy'), '2', '26', '299', '10', '2038', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14180, to_date('27-10-2038', 'dd-mm-yyyy'), '3', '27', '300', '10', '2038', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14181, to_date('28-10-2038', 'dd-mm-yyyy'), '4', '28', '301', '10', '2038', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14182, to_date('29-10-2038', 'dd-mm-yyyy'), '5', '29', '302', '10', '2038', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14183, to_date('30-10-2038', 'dd-mm-yyyy'), '6', '30', '303', '10', '2038', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14184, to_date('31-10-2038', 'dd-mm-yyyy'), '7', '31', '304', '10', '2038', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14185, to_date('01-11-2038', 'dd-mm-yyyy'), '1', '01', '305', '11', '2038', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14186, to_date('02-11-2038', 'dd-mm-yyyy'), '2', '02', '306', '11', '2038', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14187, to_date('03-11-2038', 'dd-mm-yyyy'), '3', '03', '307', '11', '2038', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14188, to_date('04-11-2038', 'dd-mm-yyyy'), '4', '04', '308', '11', '2038', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14189, to_date('05-11-2038', 'dd-mm-yyyy'), '5', '05', '309', '11', '2038', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14190, to_date('06-11-2038', 'dd-mm-yyyy'), '6', '06', '310', '11', '2038', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14191, to_date('07-11-2038', 'dd-mm-yyyy'), '7', '07', '311', '11', '2038', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14192, to_date('08-11-2038', 'dd-mm-yyyy'), '1', '08', '312', '11', '2038', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14193, to_date('09-11-2038', 'dd-mm-yyyy'), '2', '09', '313', '11', '2038', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14194, to_date('10-11-2038', 'dd-mm-yyyy'), '3', '10', '314', '11', '2038', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14195, to_date('11-11-2038', 'dd-mm-yyyy'), '4', '11', '315', '11', '2038', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14196, to_date('12-11-2038', 'dd-mm-yyyy'), '5', '12', '316', '11', '2038', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14197, to_date('13-11-2038', 'dd-mm-yyyy'), '6', '13', '317', '11', '2038', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14198, to_date('14-11-2038', 'dd-mm-yyyy'), '7', '14', '318', '11', '2038', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14199, to_date('15-11-2038', 'dd-mm-yyyy'), '1', '15', '319', '11', '2038', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14200, to_date('16-11-2038', 'dd-mm-yyyy'), '2', '16', '320', '11', '2038', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14201, to_date('17-11-2038', 'dd-mm-yyyy'), '3', '17', '321', '11', '2038', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14202, to_date('18-11-2038', 'dd-mm-yyyy'), '4', '18', '322', '11', '2038', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14203, to_date('19-11-2038', 'dd-mm-yyyy'), '5', '19', '323', '11', '2038', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14204, to_date('20-11-2038', 'dd-mm-yyyy'), '6', '20', '324', '11', '2038', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14205, to_date('21-11-2038', 'dd-mm-yyyy'), '7', '21', '325', '11', '2038', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14206, to_date('22-11-2038', 'dd-mm-yyyy'), '1', '22', '326', '11', '2038', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14207, to_date('23-11-2038', 'dd-mm-yyyy'), '2', '23', '327', '11', '2038', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14208, to_date('24-11-2038', 'dd-mm-yyyy'), '3', '24', '328', '11', '2038', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14209, to_date('25-11-2038', 'dd-mm-yyyy'), '4', '25', '329', '11', '2038', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14210, to_date('26-11-2038', 'dd-mm-yyyy'), '5', '26', '330', '11', '2038', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14211, to_date('27-11-2038', 'dd-mm-yyyy'), '6', '27', '331', '11', '2038', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14212, to_date('28-11-2038', 'dd-mm-yyyy'), '7', '28', '332', '11', '2038', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14213, to_date('29-11-2038', 'dd-mm-yyyy'), '1', '29', '333', '11', '2038', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14214, to_date('30-11-2038', 'dd-mm-yyyy'), '2', '30', '334', '11', '2038', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14215, to_date('01-12-2038', 'dd-mm-yyyy'), '3', '01', '335', '12', '2038', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14216, to_date('02-12-2038', 'dd-mm-yyyy'), '4', '02', '336', '12', '2038', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14217, to_date('03-12-2038', 'dd-mm-yyyy'), '5', '03', '337', '12', '2038', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14218, to_date('04-12-2038', 'dd-mm-yyyy'), '6', '04', '338', '12', '2038', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14219, to_date('05-12-2038', 'dd-mm-yyyy'), '7', '05', '339', '12', '2038', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14220, to_date('06-12-2038', 'dd-mm-yyyy'), '1', '06', '340', '12', '2038', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14221, to_date('07-12-2038', 'dd-mm-yyyy'), '2', '07', '341', '12', '2038', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14222, to_date('08-12-2038', 'dd-mm-yyyy'), '3', '08', '342', '12', '2038', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14223, to_date('09-12-2038', 'dd-mm-yyyy'), '4', '09', '343', '12', '2038', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14224, to_date('10-12-2038', 'dd-mm-yyyy'), '5', '10', '344', '12', '2038', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14225, to_date('11-12-2038', 'dd-mm-yyyy'), '6', '11', '345', '12', '2038', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14226, to_date('12-12-2038', 'dd-mm-yyyy'), '7', '12', '346', '12', '2038', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14227, to_date('13-12-2038', 'dd-mm-yyyy'), '1', '13', '347', '12', '2038', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14228, to_date('14-12-2038', 'dd-mm-yyyy'), '2', '14', '348', '12', '2038', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14229, to_date('15-12-2038', 'dd-mm-yyyy'), '3', '15', '349', '12', '2038', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14230, to_date('16-12-2038', 'dd-mm-yyyy'), '4', '16', '350', '12', '2038', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14231, to_date('17-12-2038', 'dd-mm-yyyy'), '5', '17', '351', '12', '2038', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14232, to_date('18-12-2038', 'dd-mm-yyyy'), '6', '18', '352', '12', '2038', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14233, to_date('19-12-2038', 'dd-mm-yyyy'), '7', '19', '353', '12', '2038', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14234, to_date('20-12-2038', 'dd-mm-yyyy'), '1', '20', '354', '12', '2038', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
commit;
prompt 26000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14235, to_date('21-12-2038', 'dd-mm-yyyy'), '2', '21', '355', '12', '2038', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14236, to_date('22-12-2038', 'dd-mm-yyyy'), '3', '22', '356', '12', '2038', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14237, to_date('23-12-2038', 'dd-mm-yyyy'), '4', '23', '357', '12', '2038', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14238, to_date('24-12-2038', 'dd-mm-yyyy'), '5', '24', '358', '12', '2038', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14239, to_date('25-12-2038', 'dd-mm-yyyy'), '6', '25', '359', '12', '2038', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14240, to_date('26-12-2038', 'dd-mm-yyyy'), '7', '26', '360', '12', '2038', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14241, to_date('27-12-2038', 'dd-mm-yyyy'), '1', '27', '361', '12', '2038', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14242, to_date('28-12-2038', 'dd-mm-yyyy'), '2', '28', '362', '12', '2038', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14243, to_date('29-12-2038', 'dd-mm-yyyy'), '3', '29', '363', '12', '2038', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14244, to_date('30-12-2038', 'dd-mm-yyyy'), '4', '30', '364', '12', '2038', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14245, to_date('31-12-2038', 'dd-mm-yyyy'), '5', '31', '365', '12', '2038', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14246, to_date('01-01-2039', 'dd-mm-yyyy'), '6', '01', '001', '01', '2039', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14247, to_date('02-01-2039', 'dd-mm-yyyy'), '7', '02', '002', '01', '2039', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14248, to_date('03-01-2039', 'dd-mm-yyyy'), '1', '03', '003', '01', '2039', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14249, to_date('04-01-2039', 'dd-mm-yyyy'), '2', '04', '004', '01', '2039', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14250, to_date('05-01-2039', 'dd-mm-yyyy'), '3', '05', '005', '01', '2039', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14251, to_date('06-01-2039', 'dd-mm-yyyy'), '4', '06', '006', '01', '2039', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14252, to_date('07-01-2039', 'dd-mm-yyyy'), '5', '07', '007', '01', '2039', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14253, to_date('08-01-2039', 'dd-mm-yyyy'), '6', '08', '008', '01', '2039', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14254, to_date('09-01-2039', 'dd-mm-yyyy'), '7', '09', '009', '01', '2039', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14255, to_date('10-01-2039', 'dd-mm-yyyy'), '1', '10', '010', '01', '2039', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14256, to_date('11-01-2039', 'dd-mm-yyyy'), '2', '11', '011', '01', '2039', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14257, to_date('12-01-2039', 'dd-mm-yyyy'), '3', '12', '012', '01', '2039', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14258, to_date('13-01-2039', 'dd-mm-yyyy'), '4', '13', '013', '01', '2039', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14259, to_date('14-01-2039', 'dd-mm-yyyy'), '5', '14', '014', '01', '2039', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14260, to_date('15-01-2039', 'dd-mm-yyyy'), '6', '15', '015', '01', '2039', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14261, to_date('16-01-2039', 'dd-mm-yyyy'), '7', '16', '016', '01', '2039', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14262, to_date('17-01-2039', 'dd-mm-yyyy'), '1', '17', '017', '01', '2039', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14263, to_date('18-01-2039', 'dd-mm-yyyy'), '2', '18', '018', '01', '2039', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14264, to_date('19-01-2039', 'dd-mm-yyyy'), '3', '19', '019', '01', '2039', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14265, to_date('20-01-2039', 'dd-mm-yyyy'), '4', '20', '020', '01', '2039', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14266, to_date('21-01-2039', 'dd-mm-yyyy'), '5', '21', '021', '01', '2039', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14267, to_date('22-01-2039', 'dd-mm-yyyy'), '6', '22', '022', '01', '2039', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14268, to_date('23-01-2039', 'dd-mm-yyyy'), '7', '23', '023', '01', '2039', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14269, to_date('24-01-2039', 'dd-mm-yyyy'), '1', '24', '024', '01', '2039', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14270, to_date('25-01-2039', 'dd-mm-yyyy'), '2', '25', '025', '01', '2039', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14271, to_date('26-01-2039', 'dd-mm-yyyy'), '3', '26', '026', '01', '2039', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14272, to_date('27-01-2039', 'dd-mm-yyyy'), '4', '27', '027', '01', '2039', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14273, to_date('28-01-2039', 'dd-mm-yyyy'), '5', '28', '028', '01', '2039', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14274, to_date('29-01-2039', 'dd-mm-yyyy'), '6', '29', '029', '01', '2039', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14275, to_date('30-01-2039', 'dd-mm-yyyy'), '7', '30', '030', '01', '2039', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14276, to_date('31-01-2039', 'dd-mm-yyyy'), '1', '31', '031', '01', '2039', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14277, to_date('01-02-2039', 'dd-mm-yyyy'), '2', '01', '032', '02', '2039', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14278, to_date('02-02-2039', 'dd-mm-yyyy'), '3', '02', '033', '02', '2039', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14279, to_date('03-02-2039', 'dd-mm-yyyy'), '4', '03', '034', '02', '2039', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14280, to_date('04-02-2039', 'dd-mm-yyyy'), '5', '04', '035', '02', '2039', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14281, to_date('05-02-2039', 'dd-mm-yyyy'), '6', '05', '036', '02', '2039', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14282, to_date('06-02-2039', 'dd-mm-yyyy'), '7', '06', '037', '02', '2039', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14283, to_date('07-02-2039', 'dd-mm-yyyy'), '1', '07', '038', '02', '2039', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (14284, to_date('08-02-2039', 'dd-mm-yyyy'), '2', '08', '039', '02', '2039', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34319, to_date('16-12-2093', 'dd-mm-yyyy'), '3', '16', '350', '12', '2093', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34320, to_date('17-12-2093', 'dd-mm-yyyy'), '4', '17', '351', '12', '2093', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34321, to_date('18-12-2093', 'dd-mm-yyyy'), '5', '18', '352', '12', '2093', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34322, to_date('19-12-2093', 'dd-mm-yyyy'), '6', '19', '353', '12', '2093', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34323, to_date('20-12-2093', 'dd-mm-yyyy'), '7', '20', '354', '12', '2093', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34324, to_date('21-12-2093', 'dd-mm-yyyy'), '1', '21', '355', '12', '2093', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34325, to_date('22-12-2093', 'dd-mm-yyyy'), '2', '22', '356', '12', '2093', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34326, to_date('23-12-2093', 'dd-mm-yyyy'), '3', '23', '357', '12', '2093', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34327, to_date('24-12-2093', 'dd-mm-yyyy'), '4', '24', '358', '12', '2093', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34328, to_date('25-12-2093', 'dd-mm-yyyy'), '5', '25', '359', '12', '2093', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34329, to_date('26-12-2093', 'dd-mm-yyyy'), '6', '26', '360', '12', '2093', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34330, to_date('27-12-2093', 'dd-mm-yyyy'), '7', '27', '361', '12', '2093', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34331, to_date('28-12-2093', 'dd-mm-yyyy'), '1', '28', '362', '12', '2093', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34332, to_date('29-12-2093', 'dd-mm-yyyy'), '2', '29', '363', '12', '2093', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34333, to_date('30-12-2093', 'dd-mm-yyyy'), '3', '30', '364', '12', '2093', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34334, to_date('31-12-2093', 'dd-mm-yyyy'), '4', '31', '365', '12', '2093', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34335, to_date('01-01-2094', 'dd-mm-yyyy'), '5', '01', '001', '01', '2094', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34336, to_date('02-01-2094', 'dd-mm-yyyy'), '6', '02', '002', '01', '2094', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34337, to_date('03-01-2094', 'dd-mm-yyyy'), '7', '03', '003', '01', '2094', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34338, to_date('04-01-2094', 'dd-mm-yyyy'), '1', '04', '004', '01', '2094', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34339, to_date('05-01-2094', 'dd-mm-yyyy'), '2', '05', '005', '01', '2094', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34340, to_date('06-01-2094', 'dd-mm-yyyy'), '3', '06', '006', '01', '2094', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34341, to_date('07-01-2094', 'dd-mm-yyyy'), '4', '07', '007', '01', '2094', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34342, to_date('08-01-2094', 'dd-mm-yyyy'), '5', '08', '008', '01', '2094', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34343, to_date('09-01-2094', 'dd-mm-yyyy'), '6', '09', '009', '01', '2094', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34344, to_date('10-01-2094', 'dd-mm-yyyy'), '7', '10', '010', '01', '2094', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34345, to_date('11-01-2094', 'dd-mm-yyyy'), '1', '11', '011', '01', '2094', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34346, to_date('12-01-2094', 'dd-mm-yyyy'), '2', '12', '012', '01', '2094', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34347, to_date('13-01-2094', 'dd-mm-yyyy'), '3', '13', '013', '01', '2094', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34348, to_date('14-01-2094', 'dd-mm-yyyy'), '4', '14', '014', '01', '2094', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34349, to_date('15-01-2094', 'dd-mm-yyyy'), '5', '15', '015', '01', '2094', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34350, to_date('16-01-2094', 'dd-mm-yyyy'), '6', '16', '016', '01', '2094', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34351, to_date('17-01-2094', 'dd-mm-yyyy'), '7', '17', '017', '01', '2094', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34352, to_date('18-01-2094', 'dd-mm-yyyy'), '1', '18', '018', '01', '2094', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34353, to_date('19-01-2094', 'dd-mm-yyyy'), '2', '19', '019', '01', '2094', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34354, to_date('20-01-2094', 'dd-mm-yyyy'), '3', '20', '020', '01', '2094', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34355, to_date('21-01-2094', 'dd-mm-yyyy'), '4', '21', '021', '01', '2094', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34356, to_date('22-01-2094', 'dd-mm-yyyy'), '5', '22', '022', '01', '2094', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34357, to_date('23-01-2094', 'dd-mm-yyyy'), '6', '23', '023', '01', '2094', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34358, to_date('24-01-2094', 'dd-mm-yyyy'), '7', '24', '024', '01', '2094', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34359, to_date('25-01-2094', 'dd-mm-yyyy'), '1', '25', '025', '01', '2094', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34360, to_date('26-01-2094', 'dd-mm-yyyy'), '2', '26', '026', '01', '2094', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34361, to_date('27-01-2094', 'dd-mm-yyyy'), '3', '27', '027', '01', '2094', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34362, to_date('28-01-2094', 'dd-mm-yyyy'), '4', '28', '028', '01', '2094', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34363, to_date('29-01-2094', 'dd-mm-yyyy'), '5', '29', '029', '01', '2094', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34364, to_date('30-01-2094', 'dd-mm-yyyy'), '6', '30', '030', '01', '2094', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34365, to_date('31-01-2094', 'dd-mm-yyyy'), '7', '31', '031', '01', '2094', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34366, to_date('01-02-2094', 'dd-mm-yyyy'), '1', '01', '032', '02', '2094', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34367, to_date('02-02-2094', 'dd-mm-yyyy'), '2', '02', '033', '02', '2094', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34368, to_date('03-02-2094', 'dd-mm-yyyy'), '3', '03', '034', '02', '2094', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34369, to_date('04-02-2094', 'dd-mm-yyyy'), '4', '04', '035', '02', '2094', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34370, to_date('05-02-2094', 'dd-mm-yyyy'), '5', '05', '036', '02', '2094', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34371, to_date('06-02-2094', 'dd-mm-yyyy'), '6', '06', '037', '02', '2094', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34372, to_date('07-02-2094', 'dd-mm-yyyy'), '7', '07', '038', '02', '2094', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34373, to_date('08-02-2094', 'dd-mm-yyyy'), '1', '08', '039', '02', '2094', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34374, to_date('09-02-2094', 'dd-mm-yyyy'), '2', '09', '040', '02', '2094', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34375, to_date('10-02-2094', 'dd-mm-yyyy'), '3', '10', '041', '02', '2094', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34376, to_date('11-02-2094', 'dd-mm-yyyy'), '4', '11', '042', '02', '2094', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34377, to_date('12-02-2094', 'dd-mm-yyyy'), '5', '12', '043', '02', '2094', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34378, to_date('13-02-2094', 'dd-mm-yyyy'), '6', '13', '044', '02', '2094', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34379, to_date('14-02-2094', 'dd-mm-yyyy'), '7', '14', '045', '02', '2094', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34380, to_date('15-02-2094', 'dd-mm-yyyy'), '1', '15', '046', '02', '2094', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34381, to_date('16-02-2094', 'dd-mm-yyyy'), '2', '16', '047', '02', '2094', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34382, to_date('17-02-2094', 'dd-mm-yyyy'), '3', '17', '048', '02', '2094', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34383, to_date('18-02-2094', 'dd-mm-yyyy'), '4', '18', '049', '02', '2094', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34384, to_date('19-02-2094', 'dd-mm-yyyy'), '5', '19', '050', '02', '2094', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34385, to_date('20-02-2094', 'dd-mm-yyyy'), '6', '20', '051', '02', '2094', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34386, to_date('21-02-2094', 'dd-mm-yyyy'), '7', '21', '052', '02', '2094', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34387, to_date('22-02-2094', 'dd-mm-yyyy'), '1', '22', '053', '02', '2094', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34388, to_date('23-02-2094', 'dd-mm-yyyy'), '2', '23', '054', '02', '2094', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34389, to_date('24-02-2094', 'dd-mm-yyyy'), '3', '24', '055', '02', '2094', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34390, to_date('25-02-2094', 'dd-mm-yyyy'), '4', '25', '056', '02', '2094', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34391, to_date('26-02-2094', 'dd-mm-yyyy'), '5', '26', '057', '02', '2094', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34392, to_date('27-02-2094', 'dd-mm-yyyy'), '6', '27', '058', '02', '2094', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34393, to_date('28-02-2094', 'dd-mm-yyyy'), '7', '28', '059', '02', '2094', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34394, to_date('01-03-2094', 'dd-mm-yyyy'), '1', '01', '060', '03', '2094', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34395, to_date('02-03-2094', 'dd-mm-yyyy'), '2', '02', '061', '03', '2094', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34396, to_date('03-03-2094', 'dd-mm-yyyy'), '3', '03', '062', '03', '2094', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34397, to_date('04-03-2094', 'dd-mm-yyyy'), '4', '04', '063', '03', '2094', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34398, to_date('05-03-2094', 'dd-mm-yyyy'), '5', '05', '064', '03', '2094', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34399, to_date('06-03-2094', 'dd-mm-yyyy'), '6', '06', '065', '03', '2094', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34400, to_date('07-03-2094', 'dd-mm-yyyy'), '7', '07', '066', '03', '2094', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34401, to_date('08-03-2094', 'dd-mm-yyyy'), '1', '08', '067', '03', '2094', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34402, to_date('09-03-2094', 'dd-mm-yyyy'), '2', '09', '068', '03', '2094', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34403, to_date('10-03-2094', 'dd-mm-yyyy'), '3', '10', '069', '03', '2094', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34404, to_date('11-03-2094', 'dd-mm-yyyy'), '4', '11', '070', '03', '2094', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34405, to_date('12-03-2094', 'dd-mm-yyyy'), '5', '12', '071', '03', '2094', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34406, to_date('13-03-2094', 'dd-mm-yyyy'), '6', '13', '072', '03', '2094', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34407, to_date('14-03-2094', 'dd-mm-yyyy'), '7', '14', '073', '03', '2094', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34408, to_date('15-03-2094', 'dd-mm-yyyy'), '1', '15', '074', '03', '2094', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34409, to_date('16-03-2094', 'dd-mm-yyyy'), '2', '16', '075', '03', '2094', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34410, to_date('17-03-2094', 'dd-mm-yyyy'), '3', '17', '076', '03', '2094', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34411, to_date('18-03-2094', 'dd-mm-yyyy'), '4', '18', '077', '03', '2094', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34412, to_date('19-03-2094', 'dd-mm-yyyy'), '5', '19', '078', '03', '2094', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34413, to_date('20-03-2094', 'dd-mm-yyyy'), '6', '20', '079', '03', '2094', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34414, to_date('21-03-2094', 'dd-mm-yyyy'), '7', '21', '080', '03', '2094', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34415, to_date('22-03-2094', 'dd-mm-yyyy'), '1', '22', '081', '03', '2094', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34416, to_date('23-03-2094', 'dd-mm-yyyy'), '2', '23', '082', '03', '2094', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34417, to_date('24-03-2094', 'dd-mm-yyyy'), '3', '24', '083', '03', '2094', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34418, to_date('25-03-2094', 'dd-mm-yyyy'), '4', '25', '084', '03', '2094', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34419, to_date('26-03-2094', 'dd-mm-yyyy'), '5', '26', '085', '03', '2094', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34420, to_date('27-03-2094', 'dd-mm-yyyy'), '6', '27', '086', '03', '2094', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34421, to_date('28-03-2094', 'dd-mm-yyyy'), '7', '28', '087', '03', '2094', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34422, to_date('29-03-2094', 'dd-mm-yyyy'), '1', '29', '088', '03', '2094', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34423, to_date('30-03-2094', 'dd-mm-yyyy'), '2', '30', '089', '03', '2094', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34424, to_date('31-03-2094', 'dd-mm-yyyy'), '3', '31', '090', '03', '2094', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35909, to_date('24-04-2098', 'dd-mm-yyyy'), '4', '24', '114', '04', '2098', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35910, to_date('25-04-2098', 'dd-mm-yyyy'), '5', '25', '115', '04', '2098', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35911, to_date('26-04-2098', 'dd-mm-yyyy'), '6', '26', '116', '04', '2098', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35912, to_date('27-04-2098', 'dd-mm-yyyy'), '7', '27', '117', '04', '2098', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35913, to_date('28-04-2098', 'dd-mm-yyyy'), '1', '28', '118', '04', '2098', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35914, to_date('29-04-2098', 'dd-mm-yyyy'), '2', '29', '119', '04', '2098', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35915, to_date('30-04-2098', 'dd-mm-yyyy'), '3', '30', '120', '04', '2098', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35916, to_date('01-05-2098', 'dd-mm-yyyy'), '4', '01', '121', '05', '2098', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35917, to_date('02-05-2098', 'dd-mm-yyyy'), '5', '02', '122', '05', '2098', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35918, to_date('03-05-2098', 'dd-mm-yyyy'), '6', '03', '123', '05', '2098', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35919, to_date('04-05-2098', 'dd-mm-yyyy'), '7', '04', '124', '05', '2098', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35920, to_date('05-05-2098', 'dd-mm-yyyy'), '1', '05', '125', '05', '2098', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35921, to_date('06-05-2098', 'dd-mm-yyyy'), '2', '06', '126', '05', '2098', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35922, to_date('07-05-2098', 'dd-mm-yyyy'), '3', '07', '127', '05', '2098', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35923, to_date('08-05-2098', 'dd-mm-yyyy'), '4', '08', '128', '05', '2098', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35924, to_date('09-05-2098', 'dd-mm-yyyy'), '5', '09', '129', '05', '2098', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35925, to_date('10-05-2098', 'dd-mm-yyyy'), '6', '10', '130', '05', '2098', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35926, to_date('11-05-2098', 'dd-mm-yyyy'), '7', '11', '131', '05', '2098', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35927, to_date('12-05-2098', 'dd-mm-yyyy'), '1', '12', '132', '05', '2098', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35928, to_date('13-05-2098', 'dd-mm-yyyy'), '2', '13', '133', '05', '2098', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35929, to_date('14-05-2098', 'dd-mm-yyyy'), '3', '14', '134', '05', '2098', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35930, to_date('15-05-2098', 'dd-mm-yyyy'), '4', '15', '135', '05', '2098', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35931, to_date('16-05-2098', 'dd-mm-yyyy'), '5', '16', '136', '05', '2098', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35932, to_date('17-05-2098', 'dd-mm-yyyy'), '6', '17', '137', '05', '2098', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35933, to_date('18-05-2098', 'dd-mm-yyyy'), '7', '18', '138', '05', '2098', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35934, to_date('19-05-2098', 'dd-mm-yyyy'), '1', '19', '139', '05', '2098', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35935, to_date('20-05-2098', 'dd-mm-yyyy'), '2', '20', '140', '05', '2098', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35936, to_date('21-05-2098', 'dd-mm-yyyy'), '3', '21', '141', '05', '2098', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35937, to_date('22-05-2098', 'dd-mm-yyyy'), '4', '22', '142', '05', '2098', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35938, to_date('23-05-2098', 'dd-mm-yyyy'), '5', '23', '143', '05', '2098', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35939, to_date('24-05-2098', 'dd-mm-yyyy'), '6', '24', '144', '05', '2098', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35940, to_date('25-05-2098', 'dd-mm-yyyy'), '7', '25', '145', '05', '2098', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35941, to_date('26-05-2098', 'dd-mm-yyyy'), '1', '26', '146', '05', '2098', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35942, to_date('27-05-2098', 'dd-mm-yyyy'), '2', '27', '147', '05', '2098', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35943, to_date('28-05-2098', 'dd-mm-yyyy'), '3', '28', '148', '05', '2098', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35944, to_date('29-05-2098', 'dd-mm-yyyy'), '4', '29', '149', '05', '2098', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35945, to_date('30-05-2098', 'dd-mm-yyyy'), '5', '30', '150', '05', '2098', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35946, to_date('31-05-2098', 'dd-mm-yyyy'), '6', '31', '151', '05', '2098', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35947, to_date('01-06-2098', 'dd-mm-yyyy'), '7', '01', '152', '06', '2098', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35948, to_date('02-06-2098', 'dd-mm-yyyy'), '1', '02', '153', '06', '2098', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35949, to_date('03-06-2098', 'dd-mm-yyyy'), '2', '03', '154', '06', '2098', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35950, to_date('04-06-2098', 'dd-mm-yyyy'), '3', '04', '155', '06', '2098', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35951, to_date('05-06-2098', 'dd-mm-yyyy'), '4', '05', '156', '06', '2098', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35952, to_date('06-06-2098', 'dd-mm-yyyy'), '5', '06', '157', '06', '2098', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35953, to_date('07-06-2098', 'dd-mm-yyyy'), '6', '07', '158', '06', '2098', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35954, to_date('08-06-2098', 'dd-mm-yyyy'), '7', '08', '159', '06', '2098', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35955, to_date('09-06-2098', 'dd-mm-yyyy'), '1', '09', '160', '06', '2098', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35956, to_date('10-06-2098', 'dd-mm-yyyy'), '2', '10', '161', '06', '2098', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35957, to_date('11-06-2098', 'dd-mm-yyyy'), '3', '11', '162', '06', '2098', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35958, to_date('12-06-2098', 'dd-mm-yyyy'), '4', '12', '163', '06', '2098', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35959, to_date('13-06-2098', 'dd-mm-yyyy'), '5', '13', '164', '06', '2098', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35960, to_date('14-06-2098', 'dd-mm-yyyy'), '6', '14', '165', '06', '2098', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35961, to_date('15-06-2098', 'dd-mm-yyyy'), '7', '15', '166', '06', '2098', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35962, to_date('16-06-2098', 'dd-mm-yyyy'), '1', '16', '167', '06', '2098', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35963, to_date('17-06-2098', 'dd-mm-yyyy'), '2', '17', '168', '06', '2098', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35964, to_date('18-06-2098', 'dd-mm-yyyy'), '3', '18', '169', '06', '2098', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35965, to_date('19-06-2098', 'dd-mm-yyyy'), '4', '19', '170', '06', '2098', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35966, to_date('20-06-2098', 'dd-mm-yyyy'), '5', '20', '171', '06', '2098', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35967, to_date('21-06-2098', 'dd-mm-yyyy'), '6', '21', '172', '06', '2098', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35968, to_date('22-06-2098', 'dd-mm-yyyy'), '7', '22', '173', '06', '2098', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35969, to_date('23-06-2098', 'dd-mm-yyyy'), '1', '23', '174', '06', '2098', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35970, to_date('24-06-2098', 'dd-mm-yyyy'), '2', '24', '175', '06', '2098', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35971, to_date('25-06-2098', 'dd-mm-yyyy'), '3', '25', '176', '06', '2098', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35972, to_date('26-06-2098', 'dd-mm-yyyy'), '4', '26', '177', '06', '2098', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35973, to_date('27-06-2098', 'dd-mm-yyyy'), '5', '27', '178', '06', '2098', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35974, to_date('28-06-2098', 'dd-mm-yyyy'), '6', '28', '179', '06', '2098', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35975, to_date('29-06-2098', 'dd-mm-yyyy'), '7', '29', '180', '06', '2098', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35976, to_date('30-06-2098', 'dd-mm-yyyy'), '1', '30', '181', '06', '2098', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35977, to_date('01-07-2098', 'dd-mm-yyyy'), '2', '01', '182', '07', '2098', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35978, to_date('02-07-2098', 'dd-mm-yyyy'), '3', '02', '183', '07', '2098', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35979, to_date('03-07-2098', 'dd-mm-yyyy'), '4', '03', '184', '07', '2098', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35980, to_date('04-07-2098', 'dd-mm-yyyy'), '5', '04', '185', '07', '2098', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35981, to_date('05-07-2098', 'dd-mm-yyyy'), '6', '05', '186', '07', '2098', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35982, to_date('06-07-2098', 'dd-mm-yyyy'), '7', '06', '187', '07', '2098', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35983, to_date('07-07-2098', 'dd-mm-yyyy'), '1', '07', '188', '07', '2098', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35984, to_date('08-07-2098', 'dd-mm-yyyy'), '2', '08', '189', '07', '2098', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35985, to_date('09-07-2098', 'dd-mm-yyyy'), '3', '09', '190', '07', '2098', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35986, to_date('10-07-2098', 'dd-mm-yyyy'), '4', '10', '191', '07', '2098', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35987, to_date('11-07-2098', 'dd-mm-yyyy'), '5', '11', '192', '07', '2098', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35988, to_date('12-07-2098', 'dd-mm-yyyy'), '6', '12', '193', '07', '2098', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35989, to_date('13-07-2098', 'dd-mm-yyyy'), '7', '13', '194', '07', '2098', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35990, to_date('14-07-2098', 'dd-mm-yyyy'), '1', '14', '195', '07', '2098', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35991, to_date('15-07-2098', 'dd-mm-yyyy'), '2', '15', '196', '07', '2098', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35992, to_date('16-07-2098', 'dd-mm-yyyy'), '3', '16', '197', '07', '2098', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35993, to_date('17-07-2098', 'dd-mm-yyyy'), '4', '17', '198', '07', '2098', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35994, to_date('18-07-2098', 'dd-mm-yyyy'), '5', '18', '199', '07', '2098', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35995, to_date('19-07-2098', 'dd-mm-yyyy'), '6', '19', '200', '07', '2098', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35996, to_date('20-07-2098', 'dd-mm-yyyy'), '7', '20', '201', '07', '2098', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35997, to_date('21-07-2098', 'dd-mm-yyyy'), '1', '21', '202', '07', '2098', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35998, to_date('22-07-2098', 'dd-mm-yyyy'), '2', '22', '203', '07', '2098', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35999, to_date('23-07-2098', 'dd-mm-yyyy'), '3', '23', '204', '07', '2098', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36000, to_date('24-07-2098', 'dd-mm-yyyy'), '4', '24', '205', '07', '2098', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36001, to_date('25-07-2098', 'dd-mm-yyyy'), '5', '25', '206', '07', '2098', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36002, to_date('26-07-2098', 'dd-mm-yyyy'), '6', '26', '207', '07', '2098', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36003, to_date('27-07-2098', 'dd-mm-yyyy'), '7', '27', '208', '07', '2098', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36004, to_date('28-07-2098', 'dd-mm-yyyy'), '1', '28', '209', '07', '2098', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36005, to_date('29-07-2098', 'dd-mm-yyyy'), '2', '29', '210', '07', '2098', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36006, to_date('30-07-2098', 'dd-mm-yyyy'), '3', '30', '211', '07', '2098', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36007, to_date('31-07-2098', 'dd-mm-yyyy'), '4', '31', '212', '07', '2098', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36008, to_date('01-08-2098', 'dd-mm-yyyy'), '5', '01', '213', '08', '2098', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36009, to_date('02-08-2098', 'dd-mm-yyyy'), '6', '02', '214', '08', '2098', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36010, to_date('03-08-2098', 'dd-mm-yyyy'), '7', '03', '215', '08', '2098', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36011, to_date('04-08-2098', 'dd-mm-yyyy'), '1', '04', '216', '08', '2098', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36012, to_date('05-08-2098', 'dd-mm-yyyy'), '2', '05', '217', '08', '2098', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36013, to_date('06-08-2098', 'dd-mm-yyyy'), '3', '06', '218', '08', '2098', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36014, to_date('07-08-2098', 'dd-mm-yyyy'), '4', '07', '219', '08', '2098', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32835, to_date('23-11-2089', 'dd-mm-yyyy'), '3', '23', '327', '11', '2089', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32836, to_date('24-11-2089', 'dd-mm-yyyy'), '4', '24', '328', '11', '2089', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32837, to_date('25-11-2089', 'dd-mm-yyyy'), '5', '25', '329', '11', '2089', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32838, to_date('26-11-2089', 'dd-mm-yyyy'), '6', '26', '330', '11', '2089', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32839, to_date('27-11-2089', 'dd-mm-yyyy'), '7', '27', '331', '11', '2089', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32840, to_date('28-11-2089', 'dd-mm-yyyy'), '1', '28', '332', '11', '2089', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32841, to_date('29-11-2089', 'dd-mm-yyyy'), '2', '29', '333', '11', '2089', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32842, to_date('30-11-2089', 'dd-mm-yyyy'), '3', '30', '334', '11', '2089', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32843, to_date('01-12-2089', 'dd-mm-yyyy'), '4', '01', '335', '12', '2089', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32844, to_date('02-12-2089', 'dd-mm-yyyy'), '5', '02', '336', '12', '2089', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32845, to_date('03-12-2089', 'dd-mm-yyyy'), '6', '03', '337', '12', '2089', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32846, to_date('04-12-2089', 'dd-mm-yyyy'), '7', '04', '338', '12', '2089', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32847, to_date('05-12-2089', 'dd-mm-yyyy'), '1', '05', '339', '12', '2089', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32848, to_date('06-12-2089', 'dd-mm-yyyy'), '2', '06', '340', '12', '2089', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32849, to_date('07-12-2089', 'dd-mm-yyyy'), '3', '07', '341', '12', '2089', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32850, to_date('08-12-2089', 'dd-mm-yyyy'), '4', '08', '342', '12', '2089', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32851, to_date('09-12-2089', 'dd-mm-yyyy'), '5', '09', '343', '12', '2089', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32852, to_date('10-12-2089', 'dd-mm-yyyy'), '6', '10', '344', '12', '2089', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32853, to_date('11-12-2089', 'dd-mm-yyyy'), '7', '11', '345', '12', '2089', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32854, to_date('12-12-2089', 'dd-mm-yyyy'), '1', '12', '346', '12', '2089', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32855, to_date('13-12-2089', 'dd-mm-yyyy'), '2', '13', '347', '12', '2089', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32856, to_date('14-12-2089', 'dd-mm-yyyy'), '3', '14', '348', '12', '2089', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32857, to_date('15-12-2089', 'dd-mm-yyyy'), '4', '15', '349', '12', '2089', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32858, to_date('16-12-2089', 'dd-mm-yyyy'), '5', '16', '350', '12', '2089', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32859, to_date('17-12-2089', 'dd-mm-yyyy'), '6', '17', '351', '12', '2089', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32860, to_date('18-12-2089', 'dd-mm-yyyy'), '7', '18', '352', '12', '2089', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32861, to_date('19-12-2089', 'dd-mm-yyyy'), '1', '19', '353', '12', '2089', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32862, to_date('20-12-2089', 'dd-mm-yyyy'), '2', '20', '354', '12', '2089', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32863, to_date('21-12-2089', 'dd-mm-yyyy'), '3', '21', '355', '12', '2089', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32864, to_date('22-12-2089', 'dd-mm-yyyy'), '4', '22', '356', '12', '2089', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32865, to_date('23-12-2089', 'dd-mm-yyyy'), '5', '23', '357', '12', '2089', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32866, to_date('24-12-2089', 'dd-mm-yyyy'), '6', '24', '358', '12', '2089', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32867, to_date('25-12-2089', 'dd-mm-yyyy'), '7', '25', '359', '12', '2089', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32868, to_date('26-12-2089', 'dd-mm-yyyy'), '1', '26', '360', '12', '2089', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32869, to_date('27-12-2089', 'dd-mm-yyyy'), '2', '27', '361', '12', '2089', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32870, to_date('28-12-2089', 'dd-mm-yyyy'), '3', '28', '362', '12', '2089', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32871, to_date('29-12-2089', 'dd-mm-yyyy'), '4', '29', '363', '12', '2089', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32872, to_date('30-12-2089', 'dd-mm-yyyy'), '5', '30', '364', '12', '2089', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32873, to_date('31-12-2089', 'dd-mm-yyyy'), '6', '31', '365', '12', '2089', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32874, to_date('01-01-2090', 'dd-mm-yyyy'), '7', '01', '001', '01', '2090', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32875, to_date('02-01-2090', 'dd-mm-yyyy'), '1', '02', '002', '01', '2090', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32876, to_date('03-01-2090', 'dd-mm-yyyy'), '2', '03', '003', '01', '2090', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32877, to_date('04-01-2090', 'dd-mm-yyyy'), '3', '04', '004', '01', '2090', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32878, to_date('05-01-2090', 'dd-mm-yyyy'), '4', '05', '005', '01', '2090', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32879, to_date('06-01-2090', 'dd-mm-yyyy'), '5', '06', '006', '01', '2090', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32880, to_date('07-01-2090', 'dd-mm-yyyy'), '6', '07', '007', '01', '2090', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32881, to_date('08-01-2090', 'dd-mm-yyyy'), '7', '08', '008', '01', '2090', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32882, to_date('09-01-2090', 'dd-mm-yyyy'), '1', '09', '009', '01', '2090', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32883, to_date('10-01-2090', 'dd-mm-yyyy'), '2', '10', '010', '01', '2090', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32884, to_date('11-01-2090', 'dd-mm-yyyy'), '3', '11', '011', '01', '2090', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32885, to_date('12-01-2090', 'dd-mm-yyyy'), '4', '12', '012', '01', '2090', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32886, to_date('13-01-2090', 'dd-mm-yyyy'), '5', '13', '013', '01', '2090', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32887, to_date('14-01-2090', 'dd-mm-yyyy'), '6', '14', '014', '01', '2090', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32888, to_date('15-01-2090', 'dd-mm-yyyy'), '7', '15', '015', '01', '2090', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32889, to_date('16-01-2090', 'dd-mm-yyyy'), '1', '16', '016', '01', '2090', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32890, to_date('17-01-2090', 'dd-mm-yyyy'), '2', '17', '017', '01', '2090', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32891, to_date('18-01-2090', 'dd-mm-yyyy'), '3', '18', '018', '01', '2090', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32892, to_date('19-01-2090', 'dd-mm-yyyy'), '4', '19', '019', '01', '2090', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32893, to_date('20-01-2090', 'dd-mm-yyyy'), '5', '20', '020', '01', '2090', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32894, to_date('21-01-2090', 'dd-mm-yyyy'), '6', '21', '021', '01', '2090', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32895, to_date('22-01-2090', 'dd-mm-yyyy'), '7', '22', '022', '01', '2090', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32896, to_date('23-01-2090', 'dd-mm-yyyy'), '1', '23', '023', '01', '2090', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32897, to_date('24-01-2090', 'dd-mm-yyyy'), '2', '24', '024', '01', '2090', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32898, to_date('25-01-2090', 'dd-mm-yyyy'), '3', '25', '025', '01', '2090', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32899, to_date('26-01-2090', 'dd-mm-yyyy'), '4', '26', '026', '01', '2090', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32900, to_date('27-01-2090', 'dd-mm-yyyy'), '5', '27', '027', '01', '2090', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32901, to_date('28-01-2090', 'dd-mm-yyyy'), '6', '28', '028', '01', '2090', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32902, to_date('29-01-2090', 'dd-mm-yyyy'), '7', '29', '029', '01', '2090', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32903, to_date('30-01-2090', 'dd-mm-yyyy'), '1', '30', '030', '01', '2090', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32904, to_date('31-01-2090', 'dd-mm-yyyy'), '2', '31', '031', '01', '2090', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32905, to_date('01-02-2090', 'dd-mm-yyyy'), '3', '01', '032', '02', '2090', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32906, to_date('02-02-2090', 'dd-mm-yyyy'), '4', '02', '033', '02', '2090', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32907, to_date('03-02-2090', 'dd-mm-yyyy'), '5', '03', '034', '02', '2090', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32908, to_date('04-02-2090', 'dd-mm-yyyy'), '6', '04', '035', '02', '2090', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32909, to_date('05-02-2090', 'dd-mm-yyyy'), '7', '05', '036', '02', '2090', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32910, to_date('06-02-2090', 'dd-mm-yyyy'), '1', '06', '037', '02', '2090', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32911, to_date('07-02-2090', 'dd-mm-yyyy'), '2', '07', '038', '02', '2090', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32912, to_date('08-02-2090', 'dd-mm-yyyy'), '3', '08', '039', '02', '2090', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32913, to_date('09-02-2090', 'dd-mm-yyyy'), '4', '09', '040', '02', '2090', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32914, to_date('10-02-2090', 'dd-mm-yyyy'), '5', '10', '041', '02', '2090', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32915, to_date('11-02-2090', 'dd-mm-yyyy'), '6', '11', '042', '02', '2090', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32916, to_date('12-02-2090', 'dd-mm-yyyy'), '7', '12', '043', '02', '2090', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32917, to_date('13-02-2090', 'dd-mm-yyyy'), '1', '13', '044', '02', '2090', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32918, to_date('14-02-2090', 'dd-mm-yyyy'), '2', '14', '045', '02', '2090', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32919, to_date('15-02-2090', 'dd-mm-yyyy'), '3', '15', '046', '02', '2090', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32920, to_date('16-02-2090', 'dd-mm-yyyy'), '4', '16', '047', '02', '2090', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32921, to_date('17-02-2090', 'dd-mm-yyyy'), '5', '17', '048', '02', '2090', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32922, to_date('18-02-2090', 'dd-mm-yyyy'), '6', '18', '049', '02', '2090', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32923, to_date('19-02-2090', 'dd-mm-yyyy'), '7', '19', '050', '02', '2090', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32924, to_date('20-02-2090', 'dd-mm-yyyy'), '1', '20', '051', '02', '2090', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32925, to_date('21-02-2090', 'dd-mm-yyyy'), '2', '21', '052', '02', '2090', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32926, to_date('22-02-2090', 'dd-mm-yyyy'), '3', '22', '053', '02', '2090', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32927, to_date('23-02-2090', 'dd-mm-yyyy'), '4', '23', '054', '02', '2090', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32928, to_date('24-02-2090', 'dd-mm-yyyy'), '5', '24', '055', '02', '2090', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32929, to_date('25-02-2090', 'dd-mm-yyyy'), '6', '25', '056', '02', '2090', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32930, to_date('26-02-2090', 'dd-mm-yyyy'), '7', '26', '057', '02', '2090', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32931, to_date('27-02-2090', 'dd-mm-yyyy'), '1', '27', '058', '02', '2090', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32932, to_date('28-02-2090', 'dd-mm-yyyy'), '2', '28', '059', '02', '2090', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32933, to_date('01-03-2090', 'dd-mm-yyyy'), '3', '01', '060', '03', '2090', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32934, to_date('02-03-2090', 'dd-mm-yyyy'), '4', '02', '061', '03', '2090', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32935, to_date('03-03-2090', 'dd-mm-yyyy'), '5', '03', '062', '03', '2090', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32936, to_date('04-03-2090', 'dd-mm-yyyy'), '6', '04', '063', '03', '2090', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32937, to_date('05-03-2090', 'dd-mm-yyyy'), '7', '05', '064', '03', '2090', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32938, to_date('06-03-2090', 'dd-mm-yyyy'), '1', '06', '065', '03', '2090', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32939, to_date('07-03-2090', 'dd-mm-yyyy'), '2', '07', '066', '03', '2090', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32940, to_date('08-03-2090', 'dd-mm-yyyy'), '3', '08', '067', '03', '2090', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34425, to_date('01-04-2094', 'dd-mm-yyyy'), '4', '01', '091', '04', '2094', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34426, to_date('02-04-2094', 'dd-mm-yyyy'), '5', '02', '092', '04', '2094', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34427, to_date('03-04-2094', 'dd-mm-yyyy'), '6', '03', '093', '04', '2094', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34428, to_date('04-04-2094', 'dd-mm-yyyy'), '7', '04', '094', '04', '2094', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34429, to_date('05-04-2094', 'dd-mm-yyyy'), '1', '05', '095', '04', '2094', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34430, to_date('06-04-2094', 'dd-mm-yyyy'), '2', '06', '096', '04', '2094', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34431, to_date('07-04-2094', 'dd-mm-yyyy'), '3', '07', '097', '04', '2094', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34432, to_date('08-04-2094', 'dd-mm-yyyy'), '4', '08', '098', '04', '2094', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34433, to_date('09-04-2094', 'dd-mm-yyyy'), '5', '09', '099', '04', '2094', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34434, to_date('10-04-2094', 'dd-mm-yyyy'), '6', '10', '100', '04', '2094', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34435, to_date('11-04-2094', 'dd-mm-yyyy'), '7', '11', '101', '04', '2094', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34436, to_date('12-04-2094', 'dd-mm-yyyy'), '1', '12', '102', '04', '2094', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34437, to_date('13-04-2094', 'dd-mm-yyyy'), '2', '13', '103', '04', '2094', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34438, to_date('14-04-2094', 'dd-mm-yyyy'), '3', '14', '104', '04', '2094', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34439, to_date('15-04-2094', 'dd-mm-yyyy'), '4', '15', '105', '04', '2094', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34440, to_date('16-04-2094', 'dd-mm-yyyy'), '5', '16', '106', '04', '2094', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34441, to_date('17-04-2094', 'dd-mm-yyyy'), '6', '17', '107', '04', '2094', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34442, to_date('18-04-2094', 'dd-mm-yyyy'), '7', '18', '108', '04', '2094', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34443, to_date('19-04-2094', 'dd-mm-yyyy'), '1', '19', '109', '04', '2094', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34444, to_date('20-04-2094', 'dd-mm-yyyy'), '2', '20', '110', '04', '2094', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34445, to_date('21-04-2094', 'dd-mm-yyyy'), '3', '21', '111', '04', '2094', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34446, to_date('22-04-2094', 'dd-mm-yyyy'), '4', '22', '112', '04', '2094', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34447, to_date('23-04-2094', 'dd-mm-yyyy'), '5', '23', '113', '04', '2094', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34448, to_date('24-04-2094', 'dd-mm-yyyy'), '6', '24', '114', '04', '2094', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34449, to_date('25-04-2094', 'dd-mm-yyyy'), '7', '25', '115', '04', '2094', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34450, to_date('26-04-2094', 'dd-mm-yyyy'), '1', '26', '116', '04', '2094', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34451, to_date('27-04-2094', 'dd-mm-yyyy'), '2', '27', '117', '04', '2094', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34452, to_date('28-04-2094', 'dd-mm-yyyy'), '3', '28', '118', '04', '2094', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34453, to_date('29-04-2094', 'dd-mm-yyyy'), '4', '29', '119', '04', '2094', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34454, to_date('30-04-2094', 'dd-mm-yyyy'), '5', '30', '120', '04', '2094', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34455, to_date('01-05-2094', 'dd-mm-yyyy'), '6', '01', '121', '05', '2094', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34456, to_date('02-05-2094', 'dd-mm-yyyy'), '7', '02', '122', '05', '2094', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34457, to_date('03-05-2094', 'dd-mm-yyyy'), '1', '03', '123', '05', '2094', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34458, to_date('04-05-2094', 'dd-mm-yyyy'), '2', '04', '124', '05', '2094', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34459, to_date('05-05-2094', 'dd-mm-yyyy'), '3', '05', '125', '05', '2094', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34460, to_date('06-05-2094', 'dd-mm-yyyy'), '4', '06', '126', '05', '2094', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34461, to_date('07-05-2094', 'dd-mm-yyyy'), '5', '07', '127', '05', '2094', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34462, to_date('08-05-2094', 'dd-mm-yyyy'), '6', '08', '128', '05', '2094', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34463, to_date('09-05-2094', 'dd-mm-yyyy'), '7', '09', '129', '05', '2094', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34464, to_date('10-05-2094', 'dd-mm-yyyy'), '1', '10', '130', '05', '2094', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34465, to_date('11-05-2094', 'dd-mm-yyyy'), '2', '11', '131', '05', '2094', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34466, to_date('12-05-2094', 'dd-mm-yyyy'), '3', '12', '132', '05', '2094', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34467, to_date('13-05-2094', 'dd-mm-yyyy'), '4', '13', '133', '05', '2094', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34468, to_date('14-05-2094', 'dd-mm-yyyy'), '5', '14', '134', '05', '2094', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34469, to_date('15-05-2094', 'dd-mm-yyyy'), '6', '15', '135', '05', '2094', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34470, to_date('16-05-2094', 'dd-mm-yyyy'), '7', '16', '136', '05', '2094', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34471, to_date('17-05-2094', 'dd-mm-yyyy'), '1', '17', '137', '05', '2094', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34472, to_date('18-05-2094', 'dd-mm-yyyy'), '2', '18', '138', '05', '2094', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34473, to_date('19-05-2094', 'dd-mm-yyyy'), '3', '19', '139', '05', '2094', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34474, to_date('20-05-2094', 'dd-mm-yyyy'), '4', '20', '140', '05', '2094', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34475, to_date('21-05-2094', 'dd-mm-yyyy'), '5', '21', '141', '05', '2094', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34476, to_date('22-05-2094', 'dd-mm-yyyy'), '6', '22', '142', '05', '2094', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34477, to_date('23-05-2094', 'dd-mm-yyyy'), '7', '23', '143', '05', '2094', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34478, to_date('24-05-2094', 'dd-mm-yyyy'), '1', '24', '144', '05', '2094', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34479, to_date('25-05-2094', 'dd-mm-yyyy'), '2', '25', '145', '05', '2094', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34480, to_date('26-05-2094', 'dd-mm-yyyy'), '3', '26', '146', '05', '2094', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34481, to_date('27-05-2094', 'dd-mm-yyyy'), '4', '27', '147', '05', '2094', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34482, to_date('28-05-2094', 'dd-mm-yyyy'), '5', '28', '148', '05', '2094', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34483, to_date('29-05-2094', 'dd-mm-yyyy'), '6', '29', '149', '05', '2094', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34484, to_date('30-05-2094', 'dd-mm-yyyy'), '7', '30', '150', '05', '2094', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34485, to_date('31-05-2094', 'dd-mm-yyyy'), '1', '31', '151', '05', '2094', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34486, to_date('01-06-2094', 'dd-mm-yyyy'), '2', '01', '152', '06', '2094', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34487, to_date('02-06-2094', 'dd-mm-yyyy'), '3', '02', '153', '06', '2094', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34488, to_date('03-06-2094', 'dd-mm-yyyy'), '4', '03', '154', '06', '2094', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34489, to_date('04-06-2094', 'dd-mm-yyyy'), '5', '04', '155', '06', '2094', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34490, to_date('05-06-2094', 'dd-mm-yyyy'), '6', '05', '156', '06', '2094', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34491, to_date('06-06-2094', 'dd-mm-yyyy'), '7', '06', '157', '06', '2094', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34492, to_date('07-06-2094', 'dd-mm-yyyy'), '1', '07', '158', '06', '2094', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34493, to_date('08-06-2094', 'dd-mm-yyyy'), '2', '08', '159', '06', '2094', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34494, to_date('09-06-2094', 'dd-mm-yyyy'), '3', '09', '160', '06', '2094', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34495, to_date('10-06-2094', 'dd-mm-yyyy'), '4', '10', '161', '06', '2094', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34496, to_date('11-06-2094', 'dd-mm-yyyy'), '5', '11', '162', '06', '2094', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34497, to_date('12-06-2094', 'dd-mm-yyyy'), '6', '12', '163', '06', '2094', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34498, to_date('13-06-2094', 'dd-mm-yyyy'), '7', '13', '164', '06', '2094', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34499, to_date('14-06-2094', 'dd-mm-yyyy'), '1', '14', '165', '06', '2094', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34500, to_date('15-06-2094', 'dd-mm-yyyy'), '2', '15', '166', '06', '2094', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34501, to_date('16-06-2094', 'dd-mm-yyyy'), '3', '16', '167', '06', '2094', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34502, to_date('17-06-2094', 'dd-mm-yyyy'), '4', '17', '168', '06', '2094', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34503, to_date('18-06-2094', 'dd-mm-yyyy'), '5', '18', '169', '06', '2094', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34504, to_date('19-06-2094', 'dd-mm-yyyy'), '6', '19', '170', '06', '2094', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34505, to_date('20-06-2094', 'dd-mm-yyyy'), '7', '20', '171', '06', '2094', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34506, to_date('21-06-2094', 'dd-mm-yyyy'), '1', '21', '172', '06', '2094', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34507, to_date('22-06-2094', 'dd-mm-yyyy'), '2', '22', '173', '06', '2094', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34508, to_date('23-06-2094', 'dd-mm-yyyy'), '3', '23', '174', '06', '2094', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34509, to_date('24-06-2094', 'dd-mm-yyyy'), '4', '24', '175', '06', '2094', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34510, to_date('25-06-2094', 'dd-mm-yyyy'), '5', '25', '176', '06', '2094', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34511, to_date('26-06-2094', 'dd-mm-yyyy'), '6', '26', '177', '06', '2094', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34512, to_date('27-06-2094', 'dd-mm-yyyy'), '7', '27', '178', '06', '2094', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34513, to_date('28-06-2094', 'dd-mm-yyyy'), '1', '28', '179', '06', '2094', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34514, to_date('29-06-2094', 'dd-mm-yyyy'), '2', '29', '180', '06', '2094', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34515, to_date('30-06-2094', 'dd-mm-yyyy'), '3', '30', '181', '06', '2094', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34516, to_date('01-07-2094', 'dd-mm-yyyy'), '4', '01', '182', '07', '2094', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34517, to_date('02-07-2094', 'dd-mm-yyyy'), '5', '02', '183', '07', '2094', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34518, to_date('03-07-2094', 'dd-mm-yyyy'), '6', '03', '184', '07', '2094', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34519, to_date('04-07-2094', 'dd-mm-yyyy'), '7', '04', '185', '07', '2094', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34520, to_date('05-07-2094', 'dd-mm-yyyy'), '1', '05', '186', '07', '2094', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34521, to_date('06-07-2094', 'dd-mm-yyyy'), '2', '06', '187', '07', '2094', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34522, to_date('07-07-2094', 'dd-mm-yyyy'), '3', '07', '188', '07', '2094', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34523, to_date('08-07-2094', 'dd-mm-yyyy'), '4', '08', '189', '07', '2094', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34524, to_date('09-07-2094', 'dd-mm-yyyy'), '5', '09', '190', '07', '2094', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34525, to_date('10-07-2094', 'dd-mm-yyyy'), '6', '10', '191', '07', '2094', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34526, to_date('11-07-2094', 'dd-mm-yyyy'), '7', '11', '192', '07', '2094', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34527, to_date('12-07-2094', 'dd-mm-yyyy'), '1', '12', '193', '07', '2094', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34528, to_date('13-07-2094', 'dd-mm-yyyy'), '2', '13', '194', '07', '2094', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34529, to_date('14-07-2094', 'dd-mm-yyyy'), '3', '14', '195', '07', '2094', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34530, to_date('15-07-2094', 'dd-mm-yyyy'), '4', '15', '196', '07', '2094', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36015, to_date('08-08-2098', 'dd-mm-yyyy'), '5', '08', '220', '08', '2098', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36016, to_date('09-08-2098', 'dd-mm-yyyy'), '6', '09', '221', '08', '2098', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36017, to_date('10-08-2098', 'dd-mm-yyyy'), '7', '10', '222', '08', '2098', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36018, to_date('11-08-2098', 'dd-mm-yyyy'), '1', '11', '223', '08', '2098', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36019, to_date('12-08-2098', 'dd-mm-yyyy'), '2', '12', '224', '08', '2098', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36020, to_date('13-08-2098', 'dd-mm-yyyy'), '3', '13', '225', '08', '2098', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36021, to_date('14-08-2098', 'dd-mm-yyyy'), '4', '14', '226', '08', '2098', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36022, to_date('15-08-2098', 'dd-mm-yyyy'), '5', '15', '227', '08', '2098', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36023, to_date('16-08-2098', 'dd-mm-yyyy'), '6', '16', '228', '08', '2098', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36024, to_date('17-08-2098', 'dd-mm-yyyy'), '7', '17', '229', '08', '2098', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36025, to_date('18-08-2098', 'dd-mm-yyyy'), '1', '18', '230', '08', '2098', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36026, to_date('19-08-2098', 'dd-mm-yyyy'), '2', '19', '231', '08', '2098', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36027, to_date('20-08-2098', 'dd-mm-yyyy'), '3', '20', '232', '08', '2098', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36028, to_date('21-08-2098', 'dd-mm-yyyy'), '4', '21', '233', '08', '2098', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36029, to_date('22-08-2098', 'dd-mm-yyyy'), '5', '22', '234', '08', '2098', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36030, to_date('23-08-2098', 'dd-mm-yyyy'), '6', '23', '235', '08', '2098', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36031, to_date('24-08-2098', 'dd-mm-yyyy'), '7', '24', '236', '08', '2098', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36032, to_date('25-08-2098', 'dd-mm-yyyy'), '1', '25', '237', '08', '2098', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36033, to_date('26-08-2098', 'dd-mm-yyyy'), '2', '26', '238', '08', '2098', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36034, to_date('27-08-2098', 'dd-mm-yyyy'), '3', '27', '239', '08', '2098', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36035, to_date('28-08-2098', 'dd-mm-yyyy'), '4', '28', '240', '08', '2098', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36036, to_date('29-08-2098', 'dd-mm-yyyy'), '5', '29', '241', '08', '2098', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36037, to_date('30-08-2098', 'dd-mm-yyyy'), '6', '30', '242', '08', '2098', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36038, to_date('31-08-2098', 'dd-mm-yyyy'), '7', '31', '243', '08', '2098', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36039, to_date('01-09-2098', 'dd-mm-yyyy'), '1', '01', '244', '09', '2098', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36040, to_date('02-09-2098', 'dd-mm-yyyy'), '2', '02', '245', '09', '2098', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36041, to_date('03-09-2098', 'dd-mm-yyyy'), '3', '03', '246', '09', '2098', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36042, to_date('04-09-2098', 'dd-mm-yyyy'), '4', '04', '247', '09', '2098', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36043, to_date('05-09-2098', 'dd-mm-yyyy'), '5', '05', '248', '09', '2098', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36044, to_date('06-09-2098', 'dd-mm-yyyy'), '6', '06', '249', '09', '2098', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36045, to_date('07-09-2098', 'dd-mm-yyyy'), '7', '07', '250', '09', '2098', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36046, to_date('08-09-2098', 'dd-mm-yyyy'), '1', '08', '251', '09', '2098', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36047, to_date('09-09-2098', 'dd-mm-yyyy'), '2', '09', '252', '09', '2098', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36048, to_date('10-09-2098', 'dd-mm-yyyy'), '3', '10', '253', '09', '2098', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36049, to_date('11-09-2098', 'dd-mm-yyyy'), '4', '11', '254', '09', '2098', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36050, to_date('12-09-2098', 'dd-mm-yyyy'), '5', '12', '255', '09', '2098', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36051, to_date('13-09-2098', 'dd-mm-yyyy'), '6', '13', '256', '09', '2098', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36052, to_date('14-09-2098', 'dd-mm-yyyy'), '7', '14', '257', '09', '2098', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36053, to_date('15-09-2098', 'dd-mm-yyyy'), '1', '15', '258', '09', '2098', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36054, to_date('16-09-2098', 'dd-mm-yyyy'), '2', '16', '259', '09', '2098', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36055, to_date('17-09-2098', 'dd-mm-yyyy'), '3', '17', '260', '09', '2098', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36056, to_date('18-09-2098', 'dd-mm-yyyy'), '4', '18', '261', '09', '2098', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36057, to_date('19-09-2098', 'dd-mm-yyyy'), '5', '19', '262', '09', '2098', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36058, to_date('20-09-2098', 'dd-mm-yyyy'), '6', '20', '263', '09', '2098', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36059, to_date('21-09-2098', 'dd-mm-yyyy'), '7', '21', '264', '09', '2098', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36060, to_date('22-09-2098', 'dd-mm-yyyy'), '1', '22', '265', '09', '2098', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36061, to_date('23-09-2098', 'dd-mm-yyyy'), '2', '23', '266', '09', '2098', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36062, to_date('24-09-2098', 'dd-mm-yyyy'), '3', '24', '267', '09', '2098', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36063, to_date('25-09-2098', 'dd-mm-yyyy'), '4', '25', '268', '09', '2098', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36064, to_date('26-09-2098', 'dd-mm-yyyy'), '5', '26', '269', '09', '2098', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36065, to_date('27-09-2098', 'dd-mm-yyyy'), '6', '27', '270', '09', '2098', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36066, to_date('28-09-2098', 'dd-mm-yyyy'), '7', '28', '271', '09', '2098', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36067, to_date('29-09-2098', 'dd-mm-yyyy'), '1', '29', '272', '09', '2098', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36068, to_date('30-09-2098', 'dd-mm-yyyy'), '2', '30', '273', '09', '2098', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36069, to_date('01-10-2098', 'dd-mm-yyyy'), '3', '01', '274', '10', '2098', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36070, to_date('02-10-2098', 'dd-mm-yyyy'), '4', '02', '275', '10', '2098', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36071, to_date('03-10-2098', 'dd-mm-yyyy'), '5', '03', '276', '10', '2098', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36072, to_date('04-10-2098', 'dd-mm-yyyy'), '6', '04', '277', '10', '2098', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36073, to_date('05-10-2098', 'dd-mm-yyyy'), '7', '05', '278', '10', '2098', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36074, to_date('06-10-2098', 'dd-mm-yyyy'), '1', '06', '279', '10', '2098', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36075, to_date('07-10-2098', 'dd-mm-yyyy'), '2', '07', '280', '10', '2098', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36076, to_date('08-10-2098', 'dd-mm-yyyy'), '3', '08', '281', '10', '2098', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36077, to_date('09-10-2098', 'dd-mm-yyyy'), '4', '09', '282', '10', '2098', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36078, to_date('10-10-2098', 'dd-mm-yyyy'), '5', '10', '283', '10', '2098', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36079, to_date('11-10-2098', 'dd-mm-yyyy'), '6', '11', '284', '10', '2098', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36080, to_date('12-10-2098', 'dd-mm-yyyy'), '7', '12', '285', '10', '2098', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36081, to_date('13-10-2098', 'dd-mm-yyyy'), '1', '13', '286', '10', '2098', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36082, to_date('14-10-2098', 'dd-mm-yyyy'), '2', '14', '287', '10', '2098', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36083, to_date('15-10-2098', 'dd-mm-yyyy'), '3', '15', '288', '10', '2098', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36084, to_date('16-10-2098', 'dd-mm-yyyy'), '4', '16', '289', '10', '2098', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36085, to_date('17-10-2098', 'dd-mm-yyyy'), '5', '17', '290', '10', '2098', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36086, to_date('18-10-2098', 'dd-mm-yyyy'), '6', '18', '291', '10', '2098', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36087, to_date('19-10-2098', 'dd-mm-yyyy'), '7', '19', '292', '10', '2098', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36088, to_date('20-10-2098', 'dd-mm-yyyy'), '1', '20', '293', '10', '2098', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36089, to_date('21-10-2098', 'dd-mm-yyyy'), '2', '21', '294', '10', '2098', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36090, to_date('22-10-2098', 'dd-mm-yyyy'), '3', '22', '295', '10', '2098', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36091, to_date('23-10-2098', 'dd-mm-yyyy'), '4', '23', '296', '10', '2098', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36092, to_date('24-10-2098', 'dd-mm-yyyy'), '5', '24', '297', '10', '2098', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36093, to_date('25-10-2098', 'dd-mm-yyyy'), '6', '25', '298', '10', '2098', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36094, to_date('26-10-2098', 'dd-mm-yyyy'), '7', '26', '299', '10', '2098', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36095, to_date('27-10-2098', 'dd-mm-yyyy'), '1', '27', '300', '10', '2098', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36096, to_date('28-10-2098', 'dd-mm-yyyy'), '2', '28', '301', '10', '2098', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36097, to_date('29-10-2098', 'dd-mm-yyyy'), '3', '29', '302', '10', '2098', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36098, to_date('30-10-2098', 'dd-mm-yyyy'), '4', '30', '303', '10', '2098', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36099, to_date('31-10-2098', 'dd-mm-yyyy'), '5', '31', '304', '10', '2098', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36100, to_date('01-11-2098', 'dd-mm-yyyy'), '6', '01', '305', '11', '2098', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36101, to_date('02-11-2098', 'dd-mm-yyyy'), '7', '02', '306', '11', '2098', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36102, to_date('03-11-2098', 'dd-mm-yyyy'), '1', '03', '307', '11', '2098', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36103, to_date('04-11-2098', 'dd-mm-yyyy'), '2', '04', '308', '11', '2098', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36104, to_date('05-11-2098', 'dd-mm-yyyy'), '3', '05', '309', '11', '2098', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36105, to_date('06-11-2098', 'dd-mm-yyyy'), '4', '06', '310', '11', '2098', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36106, to_date('07-11-2098', 'dd-mm-yyyy'), '5', '07', '311', '11', '2098', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36107, to_date('08-11-2098', 'dd-mm-yyyy'), '6', '08', '312', '11', '2098', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36108, to_date('09-11-2098', 'dd-mm-yyyy'), '7', '09', '313', '11', '2098', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36109, to_date('10-11-2098', 'dd-mm-yyyy'), '1', '10', '314', '11', '2098', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36110, to_date('11-11-2098', 'dd-mm-yyyy'), '2', '11', '315', '11', '2098', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36111, to_date('12-11-2098', 'dd-mm-yyyy'), '3', '12', '316', '11', '2098', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36112, to_date('13-11-2098', 'dd-mm-yyyy'), '4', '13', '317', '11', '2098', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36113, to_date('14-11-2098', 'dd-mm-yyyy'), '5', '14', '318', '11', '2098', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36114, to_date('15-11-2098', 'dd-mm-yyyy'), '6', '15', '319', '11', '2098', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36115, to_date('16-11-2098', 'dd-mm-yyyy'), '7', '16', '320', '11', '2098', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36116, to_date('17-11-2098', 'dd-mm-yyyy'), '1', '17', '321', '11', '2098', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36117, to_date('18-11-2098', 'dd-mm-yyyy'), '2', '18', '322', '11', '2098', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36118, to_date('19-11-2098', 'dd-mm-yyyy'), '3', '19', '323', '11', '2098', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36119, to_date('20-11-2098', 'dd-mm-yyyy'), '4', '20', '324', '11', '2098', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36120, to_date('21-11-2098', 'dd-mm-yyyy'), '5', '21', '325', '11', '2098', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32941, to_date('09-03-2090', 'dd-mm-yyyy'), '4', '09', '068', '03', '2090', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32942, to_date('10-03-2090', 'dd-mm-yyyy'), '5', '10', '069', '03', '2090', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32943, to_date('11-03-2090', 'dd-mm-yyyy'), '6', '11', '070', '03', '2090', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32944, to_date('12-03-2090', 'dd-mm-yyyy'), '7', '12', '071', '03', '2090', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32945, to_date('13-03-2090', 'dd-mm-yyyy'), '1', '13', '072', '03', '2090', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32946, to_date('14-03-2090', 'dd-mm-yyyy'), '2', '14', '073', '03', '2090', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32947, to_date('15-03-2090', 'dd-mm-yyyy'), '3', '15', '074', '03', '2090', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32948, to_date('16-03-2090', 'dd-mm-yyyy'), '4', '16', '075', '03', '2090', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32949, to_date('17-03-2090', 'dd-mm-yyyy'), '5', '17', '076', '03', '2090', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32950, to_date('18-03-2090', 'dd-mm-yyyy'), '6', '18', '077', '03', '2090', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32951, to_date('19-03-2090', 'dd-mm-yyyy'), '7', '19', '078', '03', '2090', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32952, to_date('20-03-2090', 'dd-mm-yyyy'), '1', '20', '079', '03', '2090', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32953, to_date('21-03-2090', 'dd-mm-yyyy'), '2', '21', '080', '03', '2090', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32954, to_date('22-03-2090', 'dd-mm-yyyy'), '3', '22', '081', '03', '2090', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32955, to_date('23-03-2090', 'dd-mm-yyyy'), '4', '23', '082', '03', '2090', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32956, to_date('24-03-2090', 'dd-mm-yyyy'), '5', '24', '083', '03', '2090', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32957, to_date('25-03-2090', 'dd-mm-yyyy'), '6', '25', '084', '03', '2090', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32958, to_date('26-03-2090', 'dd-mm-yyyy'), '7', '26', '085', '03', '2090', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32959, to_date('27-03-2090', 'dd-mm-yyyy'), '1', '27', '086', '03', '2090', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32960, to_date('28-03-2090', 'dd-mm-yyyy'), '2', '28', '087', '03', '2090', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32961, to_date('29-03-2090', 'dd-mm-yyyy'), '3', '29', '088', '03', '2090', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32962, to_date('30-03-2090', 'dd-mm-yyyy'), '4', '30', '089', '03', '2090', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32963, to_date('31-03-2090', 'dd-mm-yyyy'), '5', '31', '090', '03', '2090', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32964, to_date('01-04-2090', 'dd-mm-yyyy'), '6', '01', '091', '04', '2090', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32965, to_date('02-04-2090', 'dd-mm-yyyy'), '7', '02', '092', '04', '2090', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32966, to_date('03-04-2090', 'dd-mm-yyyy'), '1', '03', '093', '04', '2090', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32967, to_date('04-04-2090', 'dd-mm-yyyy'), '2', '04', '094', '04', '2090', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32968, to_date('05-04-2090', 'dd-mm-yyyy'), '3', '05', '095', '04', '2090', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32969, to_date('06-04-2090', 'dd-mm-yyyy'), '4', '06', '096', '04', '2090', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32970, to_date('07-04-2090', 'dd-mm-yyyy'), '5', '07', '097', '04', '2090', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32971, to_date('08-04-2090', 'dd-mm-yyyy'), '6', '08', '098', '04', '2090', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32972, to_date('09-04-2090', 'dd-mm-yyyy'), '7', '09', '099', '04', '2090', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32973, to_date('10-04-2090', 'dd-mm-yyyy'), '1', '10', '100', '04', '2090', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32974, to_date('11-04-2090', 'dd-mm-yyyy'), '2', '11', '101', '04', '2090', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32975, to_date('12-04-2090', 'dd-mm-yyyy'), '3', '12', '102', '04', '2090', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32976, to_date('13-04-2090', 'dd-mm-yyyy'), '4', '13', '103', '04', '2090', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32977, to_date('14-04-2090', 'dd-mm-yyyy'), '5', '14', '104', '04', '2090', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32978, to_date('15-04-2090', 'dd-mm-yyyy'), '6', '15', '105', '04', '2090', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32979, to_date('16-04-2090', 'dd-mm-yyyy'), '7', '16', '106', '04', '2090', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32980, to_date('17-04-2090', 'dd-mm-yyyy'), '1', '17', '107', '04', '2090', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32981, to_date('18-04-2090', 'dd-mm-yyyy'), '2', '18', '108', '04', '2090', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32982, to_date('19-04-2090', 'dd-mm-yyyy'), '3', '19', '109', '04', '2090', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32983, to_date('20-04-2090', 'dd-mm-yyyy'), '4', '20', '110', '04', '2090', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32984, to_date('21-04-2090', 'dd-mm-yyyy'), '5', '21', '111', '04', '2090', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32985, to_date('22-04-2090', 'dd-mm-yyyy'), '6', '22', '112', '04', '2090', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32986, to_date('23-04-2090', 'dd-mm-yyyy'), '7', '23', '113', '04', '2090', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32987, to_date('24-04-2090', 'dd-mm-yyyy'), '1', '24', '114', '04', '2090', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32988, to_date('25-04-2090', 'dd-mm-yyyy'), '2', '25', '115', '04', '2090', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32989, to_date('26-04-2090', 'dd-mm-yyyy'), '3', '26', '116', '04', '2090', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32990, to_date('27-04-2090', 'dd-mm-yyyy'), '4', '27', '117', '04', '2090', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32991, to_date('28-04-2090', 'dd-mm-yyyy'), '5', '28', '118', '04', '2090', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32992, to_date('29-04-2090', 'dd-mm-yyyy'), '6', '29', '119', '04', '2090', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32993, to_date('30-04-2090', 'dd-mm-yyyy'), '7', '30', '120', '04', '2090', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32994, to_date('01-05-2090', 'dd-mm-yyyy'), '1', '01', '121', '05', '2090', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32995, to_date('02-05-2090', 'dd-mm-yyyy'), '2', '02', '122', '05', '2090', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32996, to_date('03-05-2090', 'dd-mm-yyyy'), '3', '03', '123', '05', '2090', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32997, to_date('04-05-2090', 'dd-mm-yyyy'), '4', '04', '124', '05', '2090', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32998, to_date('05-05-2090', 'dd-mm-yyyy'), '5', '05', '125', '05', '2090', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32999, to_date('06-05-2090', 'dd-mm-yyyy'), '6', '06', '126', '05', '2090', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33000, to_date('07-05-2090', 'dd-mm-yyyy'), '7', '07', '127', '05', '2090', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33001, to_date('08-05-2090', 'dd-mm-yyyy'), '1', '08', '128', '05', '2090', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33002, to_date('09-05-2090', 'dd-mm-yyyy'), '2', '09', '129', '05', '2090', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33003, to_date('10-05-2090', 'dd-mm-yyyy'), '3', '10', '130', '05', '2090', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33004, to_date('11-05-2090', 'dd-mm-yyyy'), '4', '11', '131', '05', '2090', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33005, to_date('12-05-2090', 'dd-mm-yyyy'), '5', '12', '132', '05', '2090', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33006, to_date('13-05-2090', 'dd-mm-yyyy'), '6', '13', '133', '05', '2090', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33007, to_date('14-05-2090', 'dd-mm-yyyy'), '7', '14', '134', '05', '2090', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33008, to_date('15-05-2090', 'dd-mm-yyyy'), '1', '15', '135', '05', '2090', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33009, to_date('16-05-2090', 'dd-mm-yyyy'), '2', '16', '136', '05', '2090', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33010, to_date('17-05-2090', 'dd-mm-yyyy'), '3', '17', '137', '05', '2090', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33011, to_date('18-05-2090', 'dd-mm-yyyy'), '4', '18', '138', '05', '2090', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33012, to_date('19-05-2090', 'dd-mm-yyyy'), '5', '19', '139', '05', '2090', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33013, to_date('20-05-2090', 'dd-mm-yyyy'), '6', '20', '140', '05', '2090', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33014, to_date('21-05-2090', 'dd-mm-yyyy'), '7', '21', '141', '05', '2090', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33015, to_date('22-05-2090', 'dd-mm-yyyy'), '1', '22', '142', '05', '2090', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33016, to_date('23-05-2090', 'dd-mm-yyyy'), '2', '23', '143', '05', '2090', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33017, to_date('24-05-2090', 'dd-mm-yyyy'), '3', '24', '144', '05', '2090', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33018, to_date('25-05-2090', 'dd-mm-yyyy'), '4', '25', '145', '05', '2090', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33019, to_date('26-05-2090', 'dd-mm-yyyy'), '5', '26', '146', '05', '2090', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33020, to_date('27-05-2090', 'dd-mm-yyyy'), '6', '27', '147', '05', '2090', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33021, to_date('28-05-2090', 'dd-mm-yyyy'), '7', '28', '148', '05', '2090', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33022, to_date('29-05-2090', 'dd-mm-yyyy'), '1', '29', '149', '05', '2090', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33023, to_date('30-05-2090', 'dd-mm-yyyy'), '2', '30', '150', '05', '2090', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33024, to_date('31-05-2090', 'dd-mm-yyyy'), '3', '31', '151', '05', '2090', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33025, to_date('01-06-2090', 'dd-mm-yyyy'), '4', '01', '152', '06', '2090', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33026, to_date('02-06-2090', 'dd-mm-yyyy'), '5', '02', '153', '06', '2090', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33027, to_date('03-06-2090', 'dd-mm-yyyy'), '6', '03', '154', '06', '2090', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33028, to_date('04-06-2090', 'dd-mm-yyyy'), '7', '04', '155', '06', '2090', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33029, to_date('05-06-2090', 'dd-mm-yyyy'), '1', '05', '156', '06', '2090', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33030, to_date('06-06-2090', 'dd-mm-yyyy'), '2', '06', '157', '06', '2090', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33031, to_date('07-06-2090', 'dd-mm-yyyy'), '3', '07', '158', '06', '2090', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33032, to_date('08-06-2090', 'dd-mm-yyyy'), '4', '08', '159', '06', '2090', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33033, to_date('09-06-2090', 'dd-mm-yyyy'), '5', '09', '160', '06', '2090', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33034, to_date('10-06-2090', 'dd-mm-yyyy'), '6', '10', '161', '06', '2090', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33035, to_date('11-06-2090', 'dd-mm-yyyy'), '7', '11', '162', '06', '2090', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33036, to_date('12-06-2090', 'dd-mm-yyyy'), '1', '12', '163', '06', '2090', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33037, to_date('13-06-2090', 'dd-mm-yyyy'), '2', '13', '164', '06', '2090', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33038, to_date('14-06-2090', 'dd-mm-yyyy'), '3', '14', '165', '06', '2090', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33039, to_date('15-06-2090', 'dd-mm-yyyy'), '4', '15', '166', '06', '2090', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33040, to_date('16-06-2090', 'dd-mm-yyyy'), '5', '16', '167', '06', '2090', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33041, to_date('17-06-2090', 'dd-mm-yyyy'), '6', '17', '168', '06', '2090', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33042, to_date('18-06-2090', 'dd-mm-yyyy'), '7', '18', '169', '06', '2090', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33043, to_date('19-06-2090', 'dd-mm-yyyy'), '1', '19', '170', '06', '2090', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33044, to_date('20-06-2090', 'dd-mm-yyyy'), '2', '20', '171', '06', '2090', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33045, to_date('21-06-2090', 'dd-mm-yyyy'), '3', '21', '172', '06', '2090', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33046, to_date('22-06-2090', 'dd-mm-yyyy'), '4', '22', '173', '06', '2090', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34531, to_date('16-07-2094', 'dd-mm-yyyy'), '5', '16', '197', '07', '2094', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34532, to_date('17-07-2094', 'dd-mm-yyyy'), '6', '17', '198', '07', '2094', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34533, to_date('18-07-2094', 'dd-mm-yyyy'), '7', '18', '199', '07', '2094', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34534, to_date('19-07-2094', 'dd-mm-yyyy'), '1', '19', '200', '07', '2094', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34535, to_date('20-07-2094', 'dd-mm-yyyy'), '2', '20', '201', '07', '2094', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34536, to_date('21-07-2094', 'dd-mm-yyyy'), '3', '21', '202', '07', '2094', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34537, to_date('22-07-2094', 'dd-mm-yyyy'), '4', '22', '203', '07', '2094', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34538, to_date('23-07-2094', 'dd-mm-yyyy'), '5', '23', '204', '07', '2094', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34539, to_date('24-07-2094', 'dd-mm-yyyy'), '6', '24', '205', '07', '2094', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34540, to_date('25-07-2094', 'dd-mm-yyyy'), '7', '25', '206', '07', '2094', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34541, to_date('26-07-2094', 'dd-mm-yyyy'), '1', '26', '207', '07', '2094', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34542, to_date('27-07-2094', 'dd-mm-yyyy'), '2', '27', '208', '07', '2094', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34543, to_date('28-07-2094', 'dd-mm-yyyy'), '3', '28', '209', '07', '2094', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34544, to_date('29-07-2094', 'dd-mm-yyyy'), '4', '29', '210', '07', '2094', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34545, to_date('30-07-2094', 'dd-mm-yyyy'), '5', '30', '211', '07', '2094', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34546, to_date('31-07-2094', 'dd-mm-yyyy'), '6', '31', '212', '07', '2094', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34547, to_date('01-08-2094', 'dd-mm-yyyy'), '7', '01', '213', '08', '2094', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34548, to_date('02-08-2094', 'dd-mm-yyyy'), '1', '02', '214', '08', '2094', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34549, to_date('03-08-2094', 'dd-mm-yyyy'), '2', '03', '215', '08', '2094', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34550, to_date('04-08-2094', 'dd-mm-yyyy'), '3', '04', '216', '08', '2094', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34551, to_date('05-08-2094', 'dd-mm-yyyy'), '4', '05', '217', '08', '2094', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34552, to_date('06-08-2094', 'dd-mm-yyyy'), '5', '06', '218', '08', '2094', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34553, to_date('07-08-2094', 'dd-mm-yyyy'), '6', '07', '219', '08', '2094', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34554, to_date('08-08-2094', 'dd-mm-yyyy'), '7', '08', '220', '08', '2094', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34555, to_date('09-08-2094', 'dd-mm-yyyy'), '1', '09', '221', '08', '2094', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34556, to_date('10-08-2094', 'dd-mm-yyyy'), '2', '10', '222', '08', '2094', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34557, to_date('11-08-2094', 'dd-mm-yyyy'), '3', '11', '223', '08', '2094', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34558, to_date('12-08-2094', 'dd-mm-yyyy'), '4', '12', '224', '08', '2094', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34559, to_date('13-08-2094', 'dd-mm-yyyy'), '5', '13', '225', '08', '2094', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34560, to_date('14-08-2094', 'dd-mm-yyyy'), '6', '14', '226', '08', '2094', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34561, to_date('15-08-2094', 'dd-mm-yyyy'), '7', '15', '227', '08', '2094', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34562, to_date('16-08-2094', 'dd-mm-yyyy'), '1', '16', '228', '08', '2094', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34563, to_date('17-08-2094', 'dd-mm-yyyy'), '2', '17', '229', '08', '2094', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34564, to_date('18-08-2094', 'dd-mm-yyyy'), '3', '18', '230', '08', '2094', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34565, to_date('19-08-2094', 'dd-mm-yyyy'), '4', '19', '231', '08', '2094', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34566, to_date('20-08-2094', 'dd-mm-yyyy'), '5', '20', '232', '08', '2094', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34567, to_date('21-08-2094', 'dd-mm-yyyy'), '6', '21', '233', '08', '2094', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34568, to_date('22-08-2094', 'dd-mm-yyyy'), '7', '22', '234', '08', '2094', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34569, to_date('23-08-2094', 'dd-mm-yyyy'), '1', '23', '235', '08', '2094', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34570, to_date('24-08-2094', 'dd-mm-yyyy'), '2', '24', '236', '08', '2094', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34571, to_date('25-08-2094', 'dd-mm-yyyy'), '3', '25', '237', '08', '2094', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34572, to_date('26-08-2094', 'dd-mm-yyyy'), '4', '26', '238', '08', '2094', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34573, to_date('27-08-2094', 'dd-mm-yyyy'), '5', '27', '239', '08', '2094', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34574, to_date('28-08-2094', 'dd-mm-yyyy'), '6', '28', '240', '08', '2094', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34575, to_date('29-08-2094', 'dd-mm-yyyy'), '7', '29', '241', '08', '2094', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34576, to_date('30-08-2094', 'dd-mm-yyyy'), '1', '30', '242', '08', '2094', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34577, to_date('31-08-2094', 'dd-mm-yyyy'), '2', '31', '243', '08', '2094', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34578, to_date('01-09-2094', 'dd-mm-yyyy'), '3', '01', '244', '09', '2094', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34579, to_date('02-09-2094', 'dd-mm-yyyy'), '4', '02', '245', '09', '2094', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34580, to_date('03-09-2094', 'dd-mm-yyyy'), '5', '03', '246', '09', '2094', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34581, to_date('04-09-2094', 'dd-mm-yyyy'), '6', '04', '247', '09', '2094', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34582, to_date('05-09-2094', 'dd-mm-yyyy'), '7', '05', '248', '09', '2094', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34583, to_date('06-09-2094', 'dd-mm-yyyy'), '1', '06', '249', '09', '2094', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34584, to_date('07-09-2094', 'dd-mm-yyyy'), '2', '07', '250', '09', '2094', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34585, to_date('08-09-2094', 'dd-mm-yyyy'), '3', '08', '251', '09', '2094', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34586, to_date('09-09-2094', 'dd-mm-yyyy'), '4', '09', '252', '09', '2094', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34587, to_date('10-09-2094', 'dd-mm-yyyy'), '5', '10', '253', '09', '2094', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34588, to_date('11-09-2094', 'dd-mm-yyyy'), '6', '11', '254', '09', '2094', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34589, to_date('12-09-2094', 'dd-mm-yyyy'), '7', '12', '255', '09', '2094', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34590, to_date('13-09-2094', 'dd-mm-yyyy'), '1', '13', '256', '09', '2094', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34591, to_date('14-09-2094', 'dd-mm-yyyy'), '2', '14', '257', '09', '2094', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34592, to_date('15-09-2094', 'dd-mm-yyyy'), '3', '15', '258', '09', '2094', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34593, to_date('16-09-2094', 'dd-mm-yyyy'), '4', '16', '259', '09', '2094', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34594, to_date('17-09-2094', 'dd-mm-yyyy'), '5', '17', '260', '09', '2094', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34595, to_date('18-09-2094', 'dd-mm-yyyy'), '6', '18', '261', '09', '2094', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34596, to_date('19-09-2094', 'dd-mm-yyyy'), '7', '19', '262', '09', '2094', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34597, to_date('20-09-2094', 'dd-mm-yyyy'), '1', '20', '263', '09', '2094', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34598, to_date('21-09-2094', 'dd-mm-yyyy'), '2', '21', '264', '09', '2094', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34599, to_date('22-09-2094', 'dd-mm-yyyy'), '3', '22', '265', '09', '2094', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34600, to_date('23-09-2094', 'dd-mm-yyyy'), '4', '23', '266', '09', '2094', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34601, to_date('24-09-2094', 'dd-mm-yyyy'), '5', '24', '267', '09', '2094', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34602, to_date('25-09-2094', 'dd-mm-yyyy'), '6', '25', '268', '09', '2094', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34603, to_date('26-09-2094', 'dd-mm-yyyy'), '7', '26', '269', '09', '2094', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34604, to_date('27-09-2094', 'dd-mm-yyyy'), '1', '27', '270', '09', '2094', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34605, to_date('28-09-2094', 'dd-mm-yyyy'), '2', '28', '271', '09', '2094', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34606, to_date('29-09-2094', 'dd-mm-yyyy'), '3', '29', '272', '09', '2094', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34607, to_date('30-09-2094', 'dd-mm-yyyy'), '4', '30', '273', '09', '2094', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34608, to_date('01-10-2094', 'dd-mm-yyyy'), '5', '01', '274', '10', '2094', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34609, to_date('02-10-2094', 'dd-mm-yyyy'), '6', '02', '275', '10', '2094', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34610, to_date('03-10-2094', 'dd-mm-yyyy'), '7', '03', '276', '10', '2094', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34611, to_date('04-10-2094', 'dd-mm-yyyy'), '1', '04', '277', '10', '2094', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34612, to_date('05-10-2094', 'dd-mm-yyyy'), '2', '05', '278', '10', '2094', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34613, to_date('06-10-2094', 'dd-mm-yyyy'), '3', '06', '279', '10', '2094', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34614, to_date('07-10-2094', 'dd-mm-yyyy'), '4', '07', '280', '10', '2094', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34615, to_date('08-10-2094', 'dd-mm-yyyy'), '5', '08', '281', '10', '2094', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34616, to_date('09-10-2094', 'dd-mm-yyyy'), '6', '09', '282', '10', '2094', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34617, to_date('10-10-2094', 'dd-mm-yyyy'), '7', '10', '283', '10', '2094', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34618, to_date('11-10-2094', 'dd-mm-yyyy'), '1', '11', '284', '10', '2094', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34619, to_date('12-10-2094', 'dd-mm-yyyy'), '2', '12', '285', '10', '2094', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34620, to_date('13-10-2094', 'dd-mm-yyyy'), '3', '13', '286', '10', '2094', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34621, to_date('14-10-2094', 'dd-mm-yyyy'), '4', '14', '287', '10', '2094', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34622, to_date('15-10-2094', 'dd-mm-yyyy'), '5', '15', '288', '10', '2094', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34623, to_date('16-10-2094', 'dd-mm-yyyy'), '6', '16', '289', '10', '2094', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34624, to_date('17-10-2094', 'dd-mm-yyyy'), '7', '17', '290', '10', '2094', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34625, to_date('18-10-2094', 'dd-mm-yyyy'), '1', '18', '291', '10', '2094', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34626, to_date('19-10-2094', 'dd-mm-yyyy'), '2', '19', '292', '10', '2094', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34627, to_date('20-10-2094', 'dd-mm-yyyy'), '3', '20', '293', '10', '2094', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34628, to_date('21-10-2094', 'dd-mm-yyyy'), '4', '21', '294', '10', '2094', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34629, to_date('22-10-2094', 'dd-mm-yyyy'), '5', '22', '295', '10', '2094', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34630, to_date('23-10-2094', 'dd-mm-yyyy'), '6', '23', '296', '10', '2094', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34631, to_date('24-10-2094', 'dd-mm-yyyy'), '7', '24', '297', '10', '2094', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34632, to_date('25-10-2094', 'dd-mm-yyyy'), '1', '25', '298', '10', '2094', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34633, to_date('26-10-2094', 'dd-mm-yyyy'), '2', '26', '299', '10', '2094', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34634, to_date('27-10-2094', 'dd-mm-yyyy'), '3', '27', '300', '10', '2094', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34635, to_date('28-10-2094', 'dd-mm-yyyy'), '4', '28', '301', '10', '2094', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34636, to_date('29-10-2094', 'dd-mm-yyyy'), '5', '29', '302', '10', '2094', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36121, to_date('22-11-2098', 'dd-mm-yyyy'), '6', '22', '326', '11', '2098', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36122, to_date('23-11-2098', 'dd-mm-yyyy'), '7', '23', '327', '11', '2098', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36123, to_date('24-11-2098', 'dd-mm-yyyy'), '1', '24', '328', '11', '2098', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36124, to_date('25-11-2098', 'dd-mm-yyyy'), '2', '25', '329', '11', '2098', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36125, to_date('26-11-2098', 'dd-mm-yyyy'), '3', '26', '330', '11', '2098', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36126, to_date('27-11-2098', 'dd-mm-yyyy'), '4', '27', '331', '11', '2098', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36127, to_date('28-11-2098', 'dd-mm-yyyy'), '5', '28', '332', '11', '2098', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36128, to_date('29-11-2098', 'dd-mm-yyyy'), '6', '29', '333', '11', '2098', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36129, to_date('30-11-2098', 'dd-mm-yyyy'), '7', '30', '334', '11', '2098', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36130, to_date('01-12-2098', 'dd-mm-yyyy'), '1', '01', '335', '12', '2098', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36131, to_date('02-12-2098', 'dd-mm-yyyy'), '2', '02', '336', '12', '2098', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36132, to_date('03-12-2098', 'dd-mm-yyyy'), '3', '03', '337', '12', '2098', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36133, to_date('04-12-2098', 'dd-mm-yyyy'), '4', '04', '338', '12', '2098', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36134, to_date('05-12-2098', 'dd-mm-yyyy'), '5', '05', '339', '12', '2098', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36135, to_date('06-12-2098', 'dd-mm-yyyy'), '6', '06', '340', '12', '2098', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36136, to_date('07-12-2098', 'dd-mm-yyyy'), '7', '07', '341', '12', '2098', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36137, to_date('08-12-2098', 'dd-mm-yyyy'), '1', '08', '342', '12', '2098', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36138, to_date('09-12-2098', 'dd-mm-yyyy'), '2', '09', '343', '12', '2098', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36139, to_date('10-12-2098', 'dd-mm-yyyy'), '3', '10', '344', '12', '2098', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36140, to_date('11-12-2098', 'dd-mm-yyyy'), '4', '11', '345', '12', '2098', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36141, to_date('12-12-2098', 'dd-mm-yyyy'), '5', '12', '346', '12', '2098', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36142, to_date('13-12-2098', 'dd-mm-yyyy'), '6', '13', '347', '12', '2098', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36143, to_date('14-12-2098', 'dd-mm-yyyy'), '7', '14', '348', '12', '2098', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36144, to_date('15-12-2098', 'dd-mm-yyyy'), '1', '15', '349', '12', '2098', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36145, to_date('16-12-2098', 'dd-mm-yyyy'), '2', '16', '350', '12', '2098', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36146, to_date('17-12-2098', 'dd-mm-yyyy'), '3', '17', '351', '12', '2098', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36147, to_date('18-12-2098', 'dd-mm-yyyy'), '4', '18', '352', '12', '2098', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36148, to_date('19-12-2098', 'dd-mm-yyyy'), '5', '19', '353', '12', '2098', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36149, to_date('20-12-2098', 'dd-mm-yyyy'), '6', '20', '354', '12', '2098', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36150, to_date('21-12-2098', 'dd-mm-yyyy'), '7', '21', '355', '12', '2098', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36151, to_date('22-12-2098', 'dd-mm-yyyy'), '1', '22', '356', '12', '2098', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36152, to_date('23-12-2098', 'dd-mm-yyyy'), '2', '23', '357', '12', '2098', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36153, to_date('24-12-2098', 'dd-mm-yyyy'), '3', '24', '358', '12', '2098', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36154, to_date('25-12-2098', 'dd-mm-yyyy'), '4', '25', '359', '12', '2098', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36155, to_date('26-12-2098', 'dd-mm-yyyy'), '5', '26', '360', '12', '2098', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36156, to_date('27-12-2098', 'dd-mm-yyyy'), '6', '27', '361', '12', '2098', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36157, to_date('28-12-2098', 'dd-mm-yyyy'), '7', '28', '362', '12', '2098', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36158, to_date('29-12-2098', 'dd-mm-yyyy'), '1', '29', '363', '12', '2098', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36159, to_date('30-12-2098', 'dd-mm-yyyy'), '2', '30', '364', '12', '2098', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36160, to_date('31-12-2098', 'dd-mm-yyyy'), '3', '31', '365', '12', '2098', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36161, to_date('01-01-2099', 'dd-mm-yyyy'), '4', '01', '001', '01', '2099', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36162, to_date('02-01-2099', 'dd-mm-yyyy'), '5', '02', '002', '01', '2099', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36163, to_date('03-01-2099', 'dd-mm-yyyy'), '6', '03', '003', '01', '2099', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36164, to_date('04-01-2099', 'dd-mm-yyyy'), '7', '04', '004', '01', '2099', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36165, to_date('05-01-2099', 'dd-mm-yyyy'), '1', '05', '005', '01', '2099', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36166, to_date('06-01-2099', 'dd-mm-yyyy'), '2', '06', '006', '01', '2099', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36167, to_date('07-01-2099', 'dd-mm-yyyy'), '3', '07', '007', '01', '2099', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36168, to_date('08-01-2099', 'dd-mm-yyyy'), '4', '08', '008', '01', '2099', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36169, to_date('09-01-2099', 'dd-mm-yyyy'), '5', '09', '009', '01', '2099', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36170, to_date('10-01-2099', 'dd-mm-yyyy'), '6', '10', '010', '01', '2099', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36171, to_date('11-01-2099', 'dd-mm-yyyy'), '7', '11', '011', '01', '2099', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36172, to_date('12-01-2099', 'dd-mm-yyyy'), '1', '12', '012', '01', '2099', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36173, to_date('13-01-2099', 'dd-mm-yyyy'), '2', '13', '013', '01', '2099', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36174, to_date('14-01-2099', 'dd-mm-yyyy'), '3', '14', '014', '01', '2099', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36175, to_date('15-01-2099', 'dd-mm-yyyy'), '4', '15', '015', '01', '2099', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36176, to_date('16-01-2099', 'dd-mm-yyyy'), '5', '16', '016', '01', '2099', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36177, to_date('17-01-2099', 'dd-mm-yyyy'), '6', '17', '017', '01', '2099', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36178, to_date('18-01-2099', 'dd-mm-yyyy'), '7', '18', '018', '01', '2099', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36179, to_date('19-01-2099', 'dd-mm-yyyy'), '1', '19', '019', '01', '2099', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36180, to_date('20-01-2099', 'dd-mm-yyyy'), '2', '20', '020', '01', '2099', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36181, to_date('21-01-2099', 'dd-mm-yyyy'), '3', '21', '021', '01', '2099', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36182, to_date('22-01-2099', 'dd-mm-yyyy'), '4', '22', '022', '01', '2099', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36183, to_date('23-01-2099', 'dd-mm-yyyy'), '5', '23', '023', '01', '2099', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36184, to_date('24-01-2099', 'dd-mm-yyyy'), '6', '24', '024', '01', '2099', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36185, to_date('25-01-2099', 'dd-mm-yyyy'), '7', '25', '025', '01', '2099', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36186, to_date('26-01-2099', 'dd-mm-yyyy'), '1', '26', '026', '01', '2099', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36187, to_date('27-01-2099', 'dd-mm-yyyy'), '2', '27', '027', '01', '2099', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36188, to_date('28-01-2099', 'dd-mm-yyyy'), '3', '28', '028', '01', '2099', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36189, to_date('29-01-2099', 'dd-mm-yyyy'), '4', '29', '029', '01', '2099', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36190, to_date('30-01-2099', 'dd-mm-yyyy'), '5', '30', '030', '01', '2099', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36191, to_date('31-01-2099', 'dd-mm-yyyy'), '6', '31', '031', '01', '2099', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36192, to_date('01-02-2099', 'dd-mm-yyyy'), '7', '01', '032', '02', '2099', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36193, to_date('02-02-2099', 'dd-mm-yyyy'), '1', '02', '033', '02', '2099', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36194, to_date('03-02-2099', 'dd-mm-yyyy'), '2', '03', '034', '02', '2099', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36195, to_date('04-02-2099', 'dd-mm-yyyy'), '3', '04', '035', '02', '2099', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36196, to_date('05-02-2099', 'dd-mm-yyyy'), '4', '05', '036', '02', '2099', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36197, to_date('06-02-2099', 'dd-mm-yyyy'), '5', '06', '037', '02', '2099', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36198, to_date('07-02-2099', 'dd-mm-yyyy'), '6', '07', '038', '02', '2099', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36199, to_date('08-02-2099', 'dd-mm-yyyy'), '7', '08', '039', '02', '2099', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36200, to_date('09-02-2099', 'dd-mm-yyyy'), '1', '09', '040', '02', '2099', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36201, to_date('10-02-2099', 'dd-mm-yyyy'), '2', '10', '041', '02', '2099', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36202, to_date('11-02-2099', 'dd-mm-yyyy'), '3', '11', '042', '02', '2099', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36203, to_date('12-02-2099', 'dd-mm-yyyy'), '4', '12', '043', '02', '2099', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36204, to_date('13-02-2099', 'dd-mm-yyyy'), '5', '13', '044', '02', '2099', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36205, to_date('14-02-2099', 'dd-mm-yyyy'), '6', '14', '045', '02', '2099', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36206, to_date('15-02-2099', 'dd-mm-yyyy'), '7', '15', '046', '02', '2099', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36207, to_date('16-02-2099', 'dd-mm-yyyy'), '1', '16', '047', '02', '2099', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36208, to_date('17-02-2099', 'dd-mm-yyyy'), '2', '17', '048', '02', '2099', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36209, to_date('18-02-2099', 'dd-mm-yyyy'), '3', '18', '049', '02', '2099', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36210, to_date('19-02-2099', 'dd-mm-yyyy'), '4', '19', '050', '02', '2099', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36211, to_date('20-02-2099', 'dd-mm-yyyy'), '5', '20', '051', '02', '2099', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36212, to_date('21-02-2099', 'dd-mm-yyyy'), '6', '21', '052', '02', '2099', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36213, to_date('22-02-2099', 'dd-mm-yyyy'), '7', '22', '053', '02', '2099', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36214, to_date('23-02-2099', 'dd-mm-yyyy'), '1', '23', '054', '02', '2099', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36215, to_date('24-02-2099', 'dd-mm-yyyy'), '2', '24', '055', '02', '2099', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36216, to_date('25-02-2099', 'dd-mm-yyyy'), '3', '25', '056', '02', '2099', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36217, to_date('26-02-2099', 'dd-mm-yyyy'), '4', '26', '057', '02', '2099', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36218, to_date('27-02-2099', 'dd-mm-yyyy'), '5', '27', '058', '02', '2099', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36219, to_date('28-02-2099', 'dd-mm-yyyy'), '6', '28', '059', '02', '2099', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36220, to_date('01-03-2099', 'dd-mm-yyyy'), '7', '01', '060', '03', '2099', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36221, to_date('02-03-2099', 'dd-mm-yyyy'), '1', '02', '061', '03', '2099', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36222, to_date('03-03-2099', 'dd-mm-yyyy'), '2', '03', '062', '03', '2099', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36223, to_date('04-03-2099', 'dd-mm-yyyy'), '3', '04', '063', '03', '2099', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36224, to_date('05-03-2099', 'dd-mm-yyyy'), '4', '05', '064', '03', '2099', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36225, to_date('06-03-2099', 'dd-mm-yyyy'), '5', '06', '065', '03', '2099', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36226, to_date('07-03-2099', 'dd-mm-yyyy'), '6', '07', '066', '03', '2099', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33047, to_date('23-06-2090', 'dd-mm-yyyy'), '5', '23', '174', '06', '2090', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33048, to_date('24-06-2090', 'dd-mm-yyyy'), '6', '24', '175', '06', '2090', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33049, to_date('25-06-2090', 'dd-mm-yyyy'), '7', '25', '176', '06', '2090', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33050, to_date('26-06-2090', 'dd-mm-yyyy'), '1', '26', '177', '06', '2090', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33051, to_date('27-06-2090', 'dd-mm-yyyy'), '2', '27', '178', '06', '2090', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33052, to_date('28-06-2090', 'dd-mm-yyyy'), '3', '28', '179', '06', '2090', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33053, to_date('29-06-2090', 'dd-mm-yyyy'), '4', '29', '180', '06', '2090', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33054, to_date('30-06-2090', 'dd-mm-yyyy'), '5', '30', '181', '06', '2090', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33055, to_date('01-07-2090', 'dd-mm-yyyy'), '6', '01', '182', '07', '2090', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33056, to_date('02-07-2090', 'dd-mm-yyyy'), '7', '02', '183', '07', '2090', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33057, to_date('03-07-2090', 'dd-mm-yyyy'), '1', '03', '184', '07', '2090', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33058, to_date('04-07-2090', 'dd-mm-yyyy'), '2', '04', '185', '07', '2090', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33059, to_date('05-07-2090', 'dd-mm-yyyy'), '3', '05', '186', '07', '2090', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33060, to_date('06-07-2090', 'dd-mm-yyyy'), '4', '06', '187', '07', '2090', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33061, to_date('07-07-2090', 'dd-mm-yyyy'), '5', '07', '188', '07', '2090', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33062, to_date('08-07-2090', 'dd-mm-yyyy'), '6', '08', '189', '07', '2090', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33063, to_date('09-07-2090', 'dd-mm-yyyy'), '7', '09', '190', '07', '2090', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33064, to_date('10-07-2090', 'dd-mm-yyyy'), '1', '10', '191', '07', '2090', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33065, to_date('11-07-2090', 'dd-mm-yyyy'), '2', '11', '192', '07', '2090', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33066, to_date('12-07-2090', 'dd-mm-yyyy'), '3', '12', '193', '07', '2090', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33067, to_date('13-07-2090', 'dd-mm-yyyy'), '4', '13', '194', '07', '2090', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33068, to_date('14-07-2090', 'dd-mm-yyyy'), '5', '14', '195', '07', '2090', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33069, to_date('15-07-2090', 'dd-mm-yyyy'), '6', '15', '196', '07', '2090', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33070, to_date('16-07-2090', 'dd-mm-yyyy'), '7', '16', '197', '07', '2090', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33071, to_date('17-07-2090', 'dd-mm-yyyy'), '1', '17', '198', '07', '2090', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33072, to_date('18-07-2090', 'dd-mm-yyyy'), '2', '18', '199', '07', '2090', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33073, to_date('19-07-2090', 'dd-mm-yyyy'), '3', '19', '200', '07', '2090', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33074, to_date('20-07-2090', 'dd-mm-yyyy'), '4', '20', '201', '07', '2090', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33075, to_date('21-07-2090', 'dd-mm-yyyy'), '5', '21', '202', '07', '2090', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33076, to_date('22-07-2090', 'dd-mm-yyyy'), '6', '22', '203', '07', '2090', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33077, to_date('23-07-2090', 'dd-mm-yyyy'), '7', '23', '204', '07', '2090', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33078, to_date('24-07-2090', 'dd-mm-yyyy'), '1', '24', '205', '07', '2090', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33079, to_date('25-07-2090', 'dd-mm-yyyy'), '2', '25', '206', '07', '2090', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33080, to_date('26-07-2090', 'dd-mm-yyyy'), '3', '26', '207', '07', '2090', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33081, to_date('27-07-2090', 'dd-mm-yyyy'), '4', '27', '208', '07', '2090', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33082, to_date('28-07-2090', 'dd-mm-yyyy'), '5', '28', '209', '07', '2090', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33083, to_date('29-07-2090', 'dd-mm-yyyy'), '6', '29', '210', '07', '2090', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33084, to_date('30-07-2090', 'dd-mm-yyyy'), '7', '30', '211', '07', '2090', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33085, to_date('31-07-2090', 'dd-mm-yyyy'), '1', '31', '212', '07', '2090', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33086, to_date('01-08-2090', 'dd-mm-yyyy'), '2', '01', '213', '08', '2090', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33087, to_date('02-08-2090', 'dd-mm-yyyy'), '3', '02', '214', '08', '2090', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33088, to_date('03-08-2090', 'dd-mm-yyyy'), '4', '03', '215', '08', '2090', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33089, to_date('04-08-2090', 'dd-mm-yyyy'), '5', '04', '216', '08', '2090', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33090, to_date('05-08-2090', 'dd-mm-yyyy'), '6', '05', '217', '08', '2090', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33091, to_date('06-08-2090', 'dd-mm-yyyy'), '7', '06', '218', '08', '2090', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33092, to_date('07-08-2090', 'dd-mm-yyyy'), '1', '07', '219', '08', '2090', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33093, to_date('08-08-2090', 'dd-mm-yyyy'), '2', '08', '220', '08', '2090', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33094, to_date('09-08-2090', 'dd-mm-yyyy'), '3', '09', '221', '08', '2090', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33095, to_date('10-08-2090', 'dd-mm-yyyy'), '4', '10', '222', '08', '2090', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33096, to_date('11-08-2090', 'dd-mm-yyyy'), '5', '11', '223', '08', '2090', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33097, to_date('12-08-2090', 'dd-mm-yyyy'), '6', '12', '224', '08', '2090', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33098, to_date('13-08-2090', 'dd-mm-yyyy'), '7', '13', '225', '08', '2090', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33099, to_date('14-08-2090', 'dd-mm-yyyy'), '1', '14', '226', '08', '2090', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33100, to_date('15-08-2090', 'dd-mm-yyyy'), '2', '15', '227', '08', '2090', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33101, to_date('16-08-2090', 'dd-mm-yyyy'), '3', '16', '228', '08', '2090', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33102, to_date('17-08-2090', 'dd-mm-yyyy'), '4', '17', '229', '08', '2090', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33103, to_date('18-08-2090', 'dd-mm-yyyy'), '5', '18', '230', '08', '2090', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33104, to_date('19-08-2090', 'dd-mm-yyyy'), '6', '19', '231', '08', '2090', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33105, to_date('20-08-2090', 'dd-mm-yyyy'), '7', '20', '232', '08', '2090', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33106, to_date('21-08-2090', 'dd-mm-yyyy'), '1', '21', '233', '08', '2090', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33107, to_date('22-08-2090', 'dd-mm-yyyy'), '2', '22', '234', '08', '2090', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33108, to_date('23-08-2090', 'dd-mm-yyyy'), '3', '23', '235', '08', '2090', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33109, to_date('24-08-2090', 'dd-mm-yyyy'), '4', '24', '236', '08', '2090', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33110, to_date('25-08-2090', 'dd-mm-yyyy'), '5', '25', '237', '08', '2090', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33111, to_date('26-08-2090', 'dd-mm-yyyy'), '6', '26', '238', '08', '2090', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33112, to_date('27-08-2090', 'dd-mm-yyyy'), '7', '27', '239', '08', '2090', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33113, to_date('28-08-2090', 'dd-mm-yyyy'), '1', '28', '240', '08', '2090', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33114, to_date('29-08-2090', 'dd-mm-yyyy'), '2', '29', '241', '08', '2090', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33115, to_date('30-08-2090', 'dd-mm-yyyy'), '3', '30', '242', '08', '2090', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33116, to_date('31-08-2090', 'dd-mm-yyyy'), '4', '31', '243', '08', '2090', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33117, to_date('01-09-2090', 'dd-mm-yyyy'), '5', '01', '244', '09', '2090', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33118, to_date('02-09-2090', 'dd-mm-yyyy'), '6', '02', '245', '09', '2090', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33119, to_date('03-09-2090', 'dd-mm-yyyy'), '7', '03', '246', '09', '2090', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33120, to_date('04-09-2090', 'dd-mm-yyyy'), '1', '04', '247', '09', '2090', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33121, to_date('05-09-2090', 'dd-mm-yyyy'), '2', '05', '248', '09', '2090', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33122, to_date('06-09-2090', 'dd-mm-yyyy'), '3', '06', '249', '09', '2090', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33123, to_date('07-09-2090', 'dd-mm-yyyy'), '4', '07', '250', '09', '2090', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33124, to_date('08-09-2090', 'dd-mm-yyyy'), '5', '08', '251', '09', '2090', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33125, to_date('09-09-2090', 'dd-mm-yyyy'), '6', '09', '252', '09', '2090', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33126, to_date('10-09-2090', 'dd-mm-yyyy'), '7', '10', '253', '09', '2090', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33127, to_date('11-09-2090', 'dd-mm-yyyy'), '1', '11', '254', '09', '2090', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33128, to_date('12-09-2090', 'dd-mm-yyyy'), '2', '12', '255', '09', '2090', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33129, to_date('13-09-2090', 'dd-mm-yyyy'), '3', '13', '256', '09', '2090', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33130, to_date('14-09-2090', 'dd-mm-yyyy'), '4', '14', '257', '09', '2090', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33131, to_date('15-09-2090', 'dd-mm-yyyy'), '5', '15', '258', '09', '2090', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33132, to_date('16-09-2090', 'dd-mm-yyyy'), '6', '16', '259', '09', '2090', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33133, to_date('17-09-2090', 'dd-mm-yyyy'), '7', '17', '260', '09', '2090', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33134, to_date('18-09-2090', 'dd-mm-yyyy'), '1', '18', '261', '09', '2090', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33135, to_date('19-09-2090', 'dd-mm-yyyy'), '2', '19', '262', '09', '2090', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33136, to_date('20-09-2090', 'dd-mm-yyyy'), '3', '20', '263', '09', '2090', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33137, to_date('21-09-2090', 'dd-mm-yyyy'), '4', '21', '264', '09', '2090', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33138, to_date('22-09-2090', 'dd-mm-yyyy'), '5', '22', '265', '09', '2090', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33139, to_date('23-09-2090', 'dd-mm-yyyy'), '6', '23', '266', '09', '2090', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33140, to_date('24-09-2090', 'dd-mm-yyyy'), '7', '24', '267', '09', '2090', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33141, to_date('25-09-2090', 'dd-mm-yyyy'), '1', '25', '268', '09', '2090', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33142, to_date('26-09-2090', 'dd-mm-yyyy'), '2', '26', '269', '09', '2090', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33143, to_date('27-09-2090', 'dd-mm-yyyy'), '3', '27', '270', '09', '2090', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33144, to_date('28-09-2090', 'dd-mm-yyyy'), '4', '28', '271', '09', '2090', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33145, to_date('29-09-2090', 'dd-mm-yyyy'), '5', '29', '272', '09', '2090', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33146, to_date('30-09-2090', 'dd-mm-yyyy'), '6', '30', '273', '09', '2090', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33147, to_date('01-10-2090', 'dd-mm-yyyy'), '7', '01', '274', '10', '2090', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33148, to_date('02-10-2090', 'dd-mm-yyyy'), '1', '02', '275', '10', '2090', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
commit;
prompt 27000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33149, to_date('03-10-2090', 'dd-mm-yyyy'), '2', '03', '276', '10', '2090', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33150, to_date('04-10-2090', 'dd-mm-yyyy'), '3', '04', '277', '10', '2090', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33151, to_date('05-10-2090', 'dd-mm-yyyy'), '4', '05', '278', '10', '2090', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33152, to_date('06-10-2090', 'dd-mm-yyyy'), '5', '06', '279', '10', '2090', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34637, to_date('30-10-2094', 'dd-mm-yyyy'), '6', '30', '303', '10', '2094', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34638, to_date('31-10-2094', 'dd-mm-yyyy'), '7', '31', '304', '10', '2094', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34639, to_date('01-11-2094', 'dd-mm-yyyy'), '1', '01', '305', '11', '2094', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34640, to_date('02-11-2094', 'dd-mm-yyyy'), '2', '02', '306', '11', '2094', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34641, to_date('03-11-2094', 'dd-mm-yyyy'), '3', '03', '307', '11', '2094', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34642, to_date('04-11-2094', 'dd-mm-yyyy'), '4', '04', '308', '11', '2094', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34643, to_date('05-11-2094', 'dd-mm-yyyy'), '5', '05', '309', '11', '2094', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34644, to_date('06-11-2094', 'dd-mm-yyyy'), '6', '06', '310', '11', '2094', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34645, to_date('07-11-2094', 'dd-mm-yyyy'), '7', '07', '311', '11', '2094', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34646, to_date('08-11-2094', 'dd-mm-yyyy'), '1', '08', '312', '11', '2094', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34647, to_date('09-11-2094', 'dd-mm-yyyy'), '2', '09', '313', '11', '2094', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34648, to_date('10-11-2094', 'dd-mm-yyyy'), '3', '10', '314', '11', '2094', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34649, to_date('11-11-2094', 'dd-mm-yyyy'), '4', '11', '315', '11', '2094', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34650, to_date('12-11-2094', 'dd-mm-yyyy'), '5', '12', '316', '11', '2094', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34651, to_date('13-11-2094', 'dd-mm-yyyy'), '6', '13', '317', '11', '2094', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34652, to_date('14-11-2094', 'dd-mm-yyyy'), '7', '14', '318', '11', '2094', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34653, to_date('15-11-2094', 'dd-mm-yyyy'), '1', '15', '319', '11', '2094', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34654, to_date('16-11-2094', 'dd-mm-yyyy'), '2', '16', '320', '11', '2094', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34655, to_date('17-11-2094', 'dd-mm-yyyy'), '3', '17', '321', '11', '2094', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34656, to_date('18-11-2094', 'dd-mm-yyyy'), '4', '18', '322', '11', '2094', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34657, to_date('19-11-2094', 'dd-mm-yyyy'), '5', '19', '323', '11', '2094', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34658, to_date('20-11-2094', 'dd-mm-yyyy'), '6', '20', '324', '11', '2094', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34659, to_date('21-11-2094', 'dd-mm-yyyy'), '7', '21', '325', '11', '2094', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34660, to_date('22-11-2094', 'dd-mm-yyyy'), '1', '22', '326', '11', '2094', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34661, to_date('23-11-2094', 'dd-mm-yyyy'), '2', '23', '327', '11', '2094', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34662, to_date('24-11-2094', 'dd-mm-yyyy'), '3', '24', '328', '11', '2094', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34663, to_date('25-11-2094', 'dd-mm-yyyy'), '4', '25', '329', '11', '2094', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34664, to_date('26-11-2094', 'dd-mm-yyyy'), '5', '26', '330', '11', '2094', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34665, to_date('27-11-2094', 'dd-mm-yyyy'), '6', '27', '331', '11', '2094', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34666, to_date('28-11-2094', 'dd-mm-yyyy'), '7', '28', '332', '11', '2094', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34667, to_date('29-11-2094', 'dd-mm-yyyy'), '1', '29', '333', '11', '2094', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34668, to_date('30-11-2094', 'dd-mm-yyyy'), '2', '30', '334', '11', '2094', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34669, to_date('01-12-2094', 'dd-mm-yyyy'), '3', '01', '335', '12', '2094', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34670, to_date('02-12-2094', 'dd-mm-yyyy'), '4', '02', '336', '12', '2094', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34671, to_date('03-12-2094', 'dd-mm-yyyy'), '5', '03', '337', '12', '2094', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34672, to_date('04-12-2094', 'dd-mm-yyyy'), '6', '04', '338', '12', '2094', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34673, to_date('05-12-2094', 'dd-mm-yyyy'), '7', '05', '339', '12', '2094', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34674, to_date('06-12-2094', 'dd-mm-yyyy'), '1', '06', '340', '12', '2094', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34675, to_date('07-12-2094', 'dd-mm-yyyy'), '2', '07', '341', '12', '2094', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34676, to_date('08-12-2094', 'dd-mm-yyyy'), '3', '08', '342', '12', '2094', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34677, to_date('09-12-2094', 'dd-mm-yyyy'), '4', '09', '343', '12', '2094', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34678, to_date('10-12-2094', 'dd-mm-yyyy'), '5', '10', '344', '12', '2094', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34679, to_date('11-12-2094', 'dd-mm-yyyy'), '6', '11', '345', '12', '2094', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34680, to_date('12-12-2094', 'dd-mm-yyyy'), '7', '12', '346', '12', '2094', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34681, to_date('13-12-2094', 'dd-mm-yyyy'), '1', '13', '347', '12', '2094', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34682, to_date('14-12-2094', 'dd-mm-yyyy'), '2', '14', '348', '12', '2094', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34683, to_date('15-12-2094', 'dd-mm-yyyy'), '3', '15', '349', '12', '2094', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34684, to_date('16-12-2094', 'dd-mm-yyyy'), '4', '16', '350', '12', '2094', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34685, to_date('17-12-2094', 'dd-mm-yyyy'), '5', '17', '351', '12', '2094', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34686, to_date('18-12-2094', 'dd-mm-yyyy'), '6', '18', '352', '12', '2094', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34687, to_date('19-12-2094', 'dd-mm-yyyy'), '7', '19', '353', '12', '2094', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34688, to_date('20-12-2094', 'dd-mm-yyyy'), '1', '20', '354', '12', '2094', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34689, to_date('21-12-2094', 'dd-mm-yyyy'), '2', '21', '355', '12', '2094', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34690, to_date('22-12-2094', 'dd-mm-yyyy'), '3', '22', '356', '12', '2094', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34691, to_date('23-12-2094', 'dd-mm-yyyy'), '4', '23', '357', '12', '2094', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34692, to_date('24-12-2094', 'dd-mm-yyyy'), '5', '24', '358', '12', '2094', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34693, to_date('25-12-2094', 'dd-mm-yyyy'), '6', '25', '359', '12', '2094', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34694, to_date('26-12-2094', 'dd-mm-yyyy'), '7', '26', '360', '12', '2094', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34695, to_date('27-12-2094', 'dd-mm-yyyy'), '1', '27', '361', '12', '2094', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34696, to_date('28-12-2094', 'dd-mm-yyyy'), '2', '28', '362', '12', '2094', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34697, to_date('29-12-2094', 'dd-mm-yyyy'), '3', '29', '363', '12', '2094', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34698, to_date('30-12-2094', 'dd-mm-yyyy'), '4', '30', '364', '12', '2094', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34699, to_date('31-12-2094', 'dd-mm-yyyy'), '5', '31', '365', '12', '2094', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34700, to_date('01-01-2095', 'dd-mm-yyyy'), '6', '01', '001', '01', '2095', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34701, to_date('02-01-2095', 'dd-mm-yyyy'), '7', '02', '002', '01', '2095', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34702, to_date('03-01-2095', 'dd-mm-yyyy'), '1', '03', '003', '01', '2095', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34703, to_date('04-01-2095', 'dd-mm-yyyy'), '2', '04', '004', '01', '2095', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34704, to_date('05-01-2095', 'dd-mm-yyyy'), '3', '05', '005', '01', '2095', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34705, to_date('06-01-2095', 'dd-mm-yyyy'), '4', '06', '006', '01', '2095', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34706, to_date('07-01-2095', 'dd-mm-yyyy'), '5', '07', '007', '01', '2095', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34707, to_date('08-01-2095', 'dd-mm-yyyy'), '6', '08', '008', '01', '2095', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34708, to_date('09-01-2095', 'dd-mm-yyyy'), '7', '09', '009', '01', '2095', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34709, to_date('10-01-2095', 'dd-mm-yyyy'), '1', '10', '010', '01', '2095', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34710, to_date('11-01-2095', 'dd-mm-yyyy'), '2', '11', '011', '01', '2095', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34711, to_date('12-01-2095', 'dd-mm-yyyy'), '3', '12', '012', '01', '2095', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34712, to_date('13-01-2095', 'dd-mm-yyyy'), '4', '13', '013', '01', '2095', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34713, to_date('14-01-2095', 'dd-mm-yyyy'), '5', '14', '014', '01', '2095', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34714, to_date('15-01-2095', 'dd-mm-yyyy'), '6', '15', '015', '01', '2095', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34715, to_date('16-01-2095', 'dd-mm-yyyy'), '7', '16', '016', '01', '2095', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34716, to_date('17-01-2095', 'dd-mm-yyyy'), '1', '17', '017', '01', '2095', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34717, to_date('18-01-2095', 'dd-mm-yyyy'), '2', '18', '018', '01', '2095', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34718, to_date('19-01-2095', 'dd-mm-yyyy'), '3', '19', '019', '01', '2095', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34719, to_date('20-01-2095', 'dd-mm-yyyy'), '4', '20', '020', '01', '2095', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34720, to_date('21-01-2095', 'dd-mm-yyyy'), '5', '21', '021', '01', '2095', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34721, to_date('22-01-2095', 'dd-mm-yyyy'), '6', '22', '022', '01', '2095', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34722, to_date('23-01-2095', 'dd-mm-yyyy'), '7', '23', '023', '01', '2095', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34723, to_date('24-01-2095', 'dd-mm-yyyy'), '1', '24', '024', '01', '2095', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34724, to_date('25-01-2095', 'dd-mm-yyyy'), '2', '25', '025', '01', '2095', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34725, to_date('26-01-2095', 'dd-mm-yyyy'), '3', '26', '026', '01', '2095', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34726, to_date('27-01-2095', 'dd-mm-yyyy'), '4', '27', '027', '01', '2095', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34727, to_date('28-01-2095', 'dd-mm-yyyy'), '5', '28', '028', '01', '2095', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34728, to_date('29-01-2095', 'dd-mm-yyyy'), '6', '29', '029', '01', '2095', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34729, to_date('30-01-2095', 'dd-mm-yyyy'), '7', '30', '030', '01', '2095', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34730, to_date('31-01-2095', 'dd-mm-yyyy'), '1', '31', '031', '01', '2095', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34731, to_date('01-02-2095', 'dd-mm-yyyy'), '2', '01', '032', '02', '2095', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34732, to_date('02-02-2095', 'dd-mm-yyyy'), '3', '02', '033', '02', '2095', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34733, to_date('03-02-2095', 'dd-mm-yyyy'), '4', '03', '034', '02', '2095', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34734, to_date('04-02-2095', 'dd-mm-yyyy'), '5', '04', '035', '02', '2095', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34735, to_date('05-02-2095', 'dd-mm-yyyy'), '6', '05', '036', '02', '2095', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34736, to_date('06-02-2095', 'dd-mm-yyyy'), '7', '06', '037', '02', '2095', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34737, to_date('07-02-2095', 'dd-mm-yyyy'), '1', '07', '038', '02', '2095', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34738, to_date('08-02-2095', 'dd-mm-yyyy'), '2', '08', '039', '02', '2095', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34739, to_date('09-02-2095', 'dd-mm-yyyy'), '3', '09', '040', '02', '2095', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34740, to_date('10-02-2095', 'dd-mm-yyyy'), '4', '10', '041', '02', '2095', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34741, to_date('11-02-2095', 'dd-mm-yyyy'), '5', '11', '042', '02', '2095', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34742, to_date('12-02-2095', 'dd-mm-yyyy'), '6', '12', '043', '02', '2095', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36227, to_date('08-03-2099', 'dd-mm-yyyy'), '7', '08', '067', '03', '2099', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36228, to_date('09-03-2099', 'dd-mm-yyyy'), '1', '09', '068', '03', '2099', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36229, to_date('10-03-2099', 'dd-mm-yyyy'), '2', '10', '069', '03', '2099', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36230, to_date('11-03-2099', 'dd-mm-yyyy'), '3', '11', '070', '03', '2099', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36231, to_date('12-03-2099', 'dd-mm-yyyy'), '4', '12', '071', '03', '2099', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36232, to_date('13-03-2099', 'dd-mm-yyyy'), '5', '13', '072', '03', '2099', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36233, to_date('14-03-2099', 'dd-mm-yyyy'), '6', '14', '073', '03', '2099', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36234, to_date('15-03-2099', 'dd-mm-yyyy'), '7', '15', '074', '03', '2099', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36235, to_date('16-03-2099', 'dd-mm-yyyy'), '1', '16', '075', '03', '2099', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36236, to_date('17-03-2099', 'dd-mm-yyyy'), '2', '17', '076', '03', '2099', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36237, to_date('18-03-2099', 'dd-mm-yyyy'), '3', '18', '077', '03', '2099', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36238, to_date('19-03-2099', 'dd-mm-yyyy'), '4', '19', '078', '03', '2099', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36239, to_date('20-03-2099', 'dd-mm-yyyy'), '5', '20', '079', '03', '2099', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36240, to_date('21-03-2099', 'dd-mm-yyyy'), '6', '21', '080', '03', '2099', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36241, to_date('22-03-2099', 'dd-mm-yyyy'), '7', '22', '081', '03', '2099', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36242, to_date('23-03-2099', 'dd-mm-yyyy'), '1', '23', '082', '03', '2099', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36243, to_date('24-03-2099', 'dd-mm-yyyy'), '2', '24', '083', '03', '2099', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36244, to_date('25-03-2099', 'dd-mm-yyyy'), '3', '25', '084', '03', '2099', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36245, to_date('26-03-2099', 'dd-mm-yyyy'), '4', '26', '085', '03', '2099', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36246, to_date('27-03-2099', 'dd-mm-yyyy'), '5', '27', '086', '03', '2099', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36247, to_date('28-03-2099', 'dd-mm-yyyy'), '6', '28', '087', '03', '2099', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36248, to_date('29-03-2099', 'dd-mm-yyyy'), '7', '29', '088', '03', '2099', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36249, to_date('30-03-2099', 'dd-mm-yyyy'), '1', '30', '089', '03', '2099', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36250, to_date('31-03-2099', 'dd-mm-yyyy'), '2', '31', '090', '03', '2099', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36251, to_date('01-04-2099', 'dd-mm-yyyy'), '3', '01', '091', '04', '2099', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36252, to_date('02-04-2099', 'dd-mm-yyyy'), '4', '02', '092', '04', '2099', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36253, to_date('03-04-2099', 'dd-mm-yyyy'), '5', '03', '093', '04', '2099', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36254, to_date('04-04-2099', 'dd-mm-yyyy'), '6', '04', '094', '04', '2099', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36255, to_date('05-04-2099', 'dd-mm-yyyy'), '7', '05', '095', '04', '2099', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36256, to_date('06-04-2099', 'dd-mm-yyyy'), '1', '06', '096', '04', '2099', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36257, to_date('07-04-2099', 'dd-mm-yyyy'), '2', '07', '097', '04', '2099', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36258, to_date('08-04-2099', 'dd-mm-yyyy'), '3', '08', '098', '04', '2099', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36259, to_date('09-04-2099', 'dd-mm-yyyy'), '4', '09', '099', '04', '2099', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36260, to_date('10-04-2099', 'dd-mm-yyyy'), '5', '10', '100', '04', '2099', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36261, to_date('11-04-2099', 'dd-mm-yyyy'), '6', '11', '101', '04', '2099', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36262, to_date('12-04-2099', 'dd-mm-yyyy'), '7', '12', '102', '04', '2099', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36263, to_date('13-04-2099', 'dd-mm-yyyy'), '1', '13', '103', '04', '2099', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36264, to_date('14-04-2099', 'dd-mm-yyyy'), '2', '14', '104', '04', '2099', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36265, to_date('15-04-2099', 'dd-mm-yyyy'), '3', '15', '105', '04', '2099', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36266, to_date('16-04-2099', 'dd-mm-yyyy'), '4', '16', '106', '04', '2099', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36267, to_date('17-04-2099', 'dd-mm-yyyy'), '5', '17', '107', '04', '2099', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36268, to_date('18-04-2099', 'dd-mm-yyyy'), '6', '18', '108', '04', '2099', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36269, to_date('19-04-2099', 'dd-mm-yyyy'), '7', '19', '109', '04', '2099', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36270, to_date('20-04-2099', 'dd-mm-yyyy'), '1', '20', '110', '04', '2099', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36271, to_date('21-04-2099', 'dd-mm-yyyy'), '2', '21', '111', '04', '2099', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36272, to_date('22-04-2099', 'dd-mm-yyyy'), '3', '22', '112', '04', '2099', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36273, to_date('23-04-2099', 'dd-mm-yyyy'), '4', '23', '113', '04', '2099', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36274, to_date('24-04-2099', 'dd-mm-yyyy'), '5', '24', '114', '04', '2099', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36275, to_date('25-04-2099', 'dd-mm-yyyy'), '6', '25', '115', '04', '2099', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36276, to_date('26-04-2099', 'dd-mm-yyyy'), '7', '26', '116', '04', '2099', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36277, to_date('27-04-2099', 'dd-mm-yyyy'), '1', '27', '117', '04', '2099', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36278, to_date('28-04-2099', 'dd-mm-yyyy'), '2', '28', '118', '04', '2099', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36279, to_date('29-04-2099', 'dd-mm-yyyy'), '3', '29', '119', '04', '2099', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36280, to_date('30-04-2099', 'dd-mm-yyyy'), '4', '30', '120', '04', '2099', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36281, to_date('01-05-2099', 'dd-mm-yyyy'), '5', '01', '121', '05', '2099', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36282, to_date('02-05-2099', 'dd-mm-yyyy'), '6', '02', '122', '05', '2099', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36283, to_date('03-05-2099', 'dd-mm-yyyy'), '7', '03', '123', '05', '2099', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36284, to_date('04-05-2099', 'dd-mm-yyyy'), '1', '04', '124', '05', '2099', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36285, to_date('05-05-2099', 'dd-mm-yyyy'), '2', '05', '125', '05', '2099', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36286, to_date('06-05-2099', 'dd-mm-yyyy'), '3', '06', '126', '05', '2099', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36287, to_date('07-05-2099', 'dd-mm-yyyy'), '4', '07', '127', '05', '2099', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36288, to_date('08-05-2099', 'dd-mm-yyyy'), '5', '08', '128', '05', '2099', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36289, to_date('09-05-2099', 'dd-mm-yyyy'), '6', '09', '129', '05', '2099', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36290, to_date('10-05-2099', 'dd-mm-yyyy'), '7', '10', '130', '05', '2099', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36291, to_date('11-05-2099', 'dd-mm-yyyy'), '1', '11', '131', '05', '2099', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36292, to_date('12-05-2099', 'dd-mm-yyyy'), '2', '12', '132', '05', '2099', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36293, to_date('13-05-2099', 'dd-mm-yyyy'), '3', '13', '133', '05', '2099', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36294, to_date('14-05-2099', 'dd-mm-yyyy'), '4', '14', '134', '05', '2099', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36295, to_date('15-05-2099', 'dd-mm-yyyy'), '5', '15', '135', '05', '2099', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36296, to_date('16-05-2099', 'dd-mm-yyyy'), '6', '16', '136', '05', '2099', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36297, to_date('17-05-2099', 'dd-mm-yyyy'), '7', '17', '137', '05', '2099', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36298, to_date('18-05-2099', 'dd-mm-yyyy'), '1', '18', '138', '05', '2099', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36299, to_date('19-05-2099', 'dd-mm-yyyy'), '2', '19', '139', '05', '2099', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36300, to_date('20-05-2099', 'dd-mm-yyyy'), '3', '20', '140', '05', '2099', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36301, to_date('21-05-2099', 'dd-mm-yyyy'), '4', '21', '141', '05', '2099', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36302, to_date('22-05-2099', 'dd-mm-yyyy'), '5', '22', '142', '05', '2099', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36303, to_date('23-05-2099', 'dd-mm-yyyy'), '6', '23', '143', '05', '2099', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36304, to_date('24-05-2099', 'dd-mm-yyyy'), '7', '24', '144', '05', '2099', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36305, to_date('25-05-2099', 'dd-mm-yyyy'), '1', '25', '145', '05', '2099', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36306, to_date('26-05-2099', 'dd-mm-yyyy'), '2', '26', '146', '05', '2099', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36307, to_date('27-05-2099', 'dd-mm-yyyy'), '3', '27', '147', '05', '2099', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36308, to_date('28-05-2099', 'dd-mm-yyyy'), '4', '28', '148', '05', '2099', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36309, to_date('29-05-2099', 'dd-mm-yyyy'), '5', '29', '149', '05', '2099', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36310, to_date('30-05-2099', 'dd-mm-yyyy'), '6', '30', '150', '05', '2099', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36311, to_date('31-05-2099', 'dd-mm-yyyy'), '7', '31', '151', '05', '2099', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36312, to_date('01-06-2099', 'dd-mm-yyyy'), '1', '01', '152', '06', '2099', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36313, to_date('02-06-2099', 'dd-mm-yyyy'), '2', '02', '153', '06', '2099', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36314, to_date('03-06-2099', 'dd-mm-yyyy'), '3', '03', '154', '06', '2099', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36315, to_date('04-06-2099', 'dd-mm-yyyy'), '4', '04', '155', '06', '2099', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36316, to_date('05-06-2099', 'dd-mm-yyyy'), '5', '05', '156', '06', '2099', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36317, to_date('06-06-2099', 'dd-mm-yyyy'), '6', '06', '157', '06', '2099', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36318, to_date('07-06-2099', 'dd-mm-yyyy'), '7', '07', '158', '06', '2099', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36319, to_date('08-06-2099', 'dd-mm-yyyy'), '1', '08', '159', '06', '2099', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36320, to_date('09-06-2099', 'dd-mm-yyyy'), '2', '09', '160', '06', '2099', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36321, to_date('10-06-2099', 'dd-mm-yyyy'), '3', '10', '161', '06', '2099', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36322, to_date('11-06-2099', 'dd-mm-yyyy'), '4', '11', '162', '06', '2099', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36323, to_date('12-06-2099', 'dd-mm-yyyy'), '5', '12', '163', '06', '2099', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36324, to_date('13-06-2099', 'dd-mm-yyyy'), '6', '13', '164', '06', '2099', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36325, to_date('14-06-2099', 'dd-mm-yyyy'), '7', '14', '165', '06', '2099', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36326, to_date('15-06-2099', 'dd-mm-yyyy'), '1', '15', '166', '06', '2099', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36327, to_date('16-06-2099', 'dd-mm-yyyy'), '2', '16', '167', '06', '2099', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36328, to_date('17-06-2099', 'dd-mm-yyyy'), '3', '17', '168', '06', '2099', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36329, to_date('18-06-2099', 'dd-mm-yyyy'), '4', '18', '169', '06', '2099', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36330, to_date('19-06-2099', 'dd-mm-yyyy'), '5', '19', '170', '06', '2099', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36331, to_date('20-06-2099', 'dd-mm-yyyy'), '6', '20', '171', '06', '2099', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36332, to_date('21-06-2099', 'dd-mm-yyyy'), '7', '21', '172', '06', '2099', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33153, to_date('07-10-2090', 'dd-mm-yyyy'), '6', '07', '280', '10', '2090', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33154, to_date('08-10-2090', 'dd-mm-yyyy'), '7', '08', '281', '10', '2090', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33155, to_date('09-10-2090', 'dd-mm-yyyy'), '1', '09', '282', '10', '2090', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33156, to_date('10-10-2090', 'dd-mm-yyyy'), '2', '10', '283', '10', '2090', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33157, to_date('11-10-2090', 'dd-mm-yyyy'), '3', '11', '284', '10', '2090', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33158, to_date('12-10-2090', 'dd-mm-yyyy'), '4', '12', '285', '10', '2090', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33159, to_date('13-10-2090', 'dd-mm-yyyy'), '5', '13', '286', '10', '2090', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33160, to_date('14-10-2090', 'dd-mm-yyyy'), '6', '14', '287', '10', '2090', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33161, to_date('15-10-2090', 'dd-mm-yyyy'), '7', '15', '288', '10', '2090', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33162, to_date('16-10-2090', 'dd-mm-yyyy'), '1', '16', '289', '10', '2090', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33163, to_date('17-10-2090', 'dd-mm-yyyy'), '2', '17', '290', '10', '2090', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33164, to_date('18-10-2090', 'dd-mm-yyyy'), '3', '18', '291', '10', '2090', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33165, to_date('19-10-2090', 'dd-mm-yyyy'), '4', '19', '292', '10', '2090', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33166, to_date('20-10-2090', 'dd-mm-yyyy'), '5', '20', '293', '10', '2090', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33167, to_date('21-10-2090', 'dd-mm-yyyy'), '6', '21', '294', '10', '2090', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33168, to_date('22-10-2090', 'dd-mm-yyyy'), '7', '22', '295', '10', '2090', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33169, to_date('23-10-2090', 'dd-mm-yyyy'), '1', '23', '296', '10', '2090', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33170, to_date('24-10-2090', 'dd-mm-yyyy'), '2', '24', '297', '10', '2090', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33171, to_date('25-10-2090', 'dd-mm-yyyy'), '3', '25', '298', '10', '2090', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33172, to_date('26-10-2090', 'dd-mm-yyyy'), '4', '26', '299', '10', '2090', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33173, to_date('27-10-2090', 'dd-mm-yyyy'), '5', '27', '300', '10', '2090', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33174, to_date('28-10-2090', 'dd-mm-yyyy'), '6', '28', '301', '10', '2090', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33175, to_date('29-10-2090', 'dd-mm-yyyy'), '7', '29', '302', '10', '2090', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33176, to_date('30-10-2090', 'dd-mm-yyyy'), '1', '30', '303', '10', '2090', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33177, to_date('31-10-2090', 'dd-mm-yyyy'), '2', '31', '304', '10', '2090', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33178, to_date('01-11-2090', 'dd-mm-yyyy'), '3', '01', '305', '11', '2090', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33179, to_date('02-11-2090', 'dd-mm-yyyy'), '4', '02', '306', '11', '2090', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33180, to_date('03-11-2090', 'dd-mm-yyyy'), '5', '03', '307', '11', '2090', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33181, to_date('04-11-2090', 'dd-mm-yyyy'), '6', '04', '308', '11', '2090', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33182, to_date('05-11-2090', 'dd-mm-yyyy'), '7', '05', '309', '11', '2090', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33183, to_date('06-11-2090', 'dd-mm-yyyy'), '1', '06', '310', '11', '2090', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33184, to_date('07-11-2090', 'dd-mm-yyyy'), '2', '07', '311', '11', '2090', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33185, to_date('08-11-2090', 'dd-mm-yyyy'), '3', '08', '312', '11', '2090', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33186, to_date('09-11-2090', 'dd-mm-yyyy'), '4', '09', '313', '11', '2090', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33187, to_date('10-11-2090', 'dd-mm-yyyy'), '5', '10', '314', '11', '2090', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33188, to_date('11-11-2090', 'dd-mm-yyyy'), '6', '11', '315', '11', '2090', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33189, to_date('12-11-2090', 'dd-mm-yyyy'), '7', '12', '316', '11', '2090', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33190, to_date('13-11-2090', 'dd-mm-yyyy'), '1', '13', '317', '11', '2090', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33191, to_date('14-11-2090', 'dd-mm-yyyy'), '2', '14', '318', '11', '2090', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33192, to_date('15-11-2090', 'dd-mm-yyyy'), '3', '15', '319', '11', '2090', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33193, to_date('16-11-2090', 'dd-mm-yyyy'), '4', '16', '320', '11', '2090', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33194, to_date('17-11-2090', 'dd-mm-yyyy'), '5', '17', '321', '11', '2090', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33195, to_date('18-11-2090', 'dd-mm-yyyy'), '6', '18', '322', '11', '2090', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33196, to_date('19-11-2090', 'dd-mm-yyyy'), '7', '19', '323', '11', '2090', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33197, to_date('20-11-2090', 'dd-mm-yyyy'), '1', '20', '324', '11', '2090', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33198, to_date('21-11-2090', 'dd-mm-yyyy'), '2', '21', '325', '11', '2090', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33199, to_date('22-11-2090', 'dd-mm-yyyy'), '3', '22', '326', '11', '2090', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33200, to_date('23-11-2090', 'dd-mm-yyyy'), '4', '23', '327', '11', '2090', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33201, to_date('24-11-2090', 'dd-mm-yyyy'), '5', '24', '328', '11', '2090', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33202, to_date('25-11-2090', 'dd-mm-yyyy'), '6', '25', '329', '11', '2090', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33203, to_date('26-11-2090', 'dd-mm-yyyy'), '7', '26', '330', '11', '2090', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33204, to_date('27-11-2090', 'dd-mm-yyyy'), '1', '27', '331', '11', '2090', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33205, to_date('28-11-2090', 'dd-mm-yyyy'), '2', '28', '332', '11', '2090', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33206, to_date('29-11-2090', 'dd-mm-yyyy'), '3', '29', '333', '11', '2090', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33207, to_date('30-11-2090', 'dd-mm-yyyy'), '4', '30', '334', '11', '2090', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33208, to_date('01-12-2090', 'dd-mm-yyyy'), '5', '01', '335', '12', '2090', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33209, to_date('02-12-2090', 'dd-mm-yyyy'), '6', '02', '336', '12', '2090', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33210, to_date('03-12-2090', 'dd-mm-yyyy'), '7', '03', '337', '12', '2090', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33211, to_date('04-12-2090', 'dd-mm-yyyy'), '1', '04', '338', '12', '2090', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33212, to_date('05-12-2090', 'dd-mm-yyyy'), '2', '05', '339', '12', '2090', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33213, to_date('06-12-2090', 'dd-mm-yyyy'), '3', '06', '340', '12', '2090', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33214, to_date('07-12-2090', 'dd-mm-yyyy'), '4', '07', '341', '12', '2090', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33215, to_date('08-12-2090', 'dd-mm-yyyy'), '5', '08', '342', '12', '2090', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33216, to_date('09-12-2090', 'dd-mm-yyyy'), '6', '09', '343', '12', '2090', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33217, to_date('10-12-2090', 'dd-mm-yyyy'), '7', '10', '344', '12', '2090', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33218, to_date('11-12-2090', 'dd-mm-yyyy'), '1', '11', '345', '12', '2090', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33219, to_date('12-12-2090', 'dd-mm-yyyy'), '2', '12', '346', '12', '2090', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33220, to_date('13-12-2090', 'dd-mm-yyyy'), '3', '13', '347', '12', '2090', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33221, to_date('14-12-2090', 'dd-mm-yyyy'), '4', '14', '348', '12', '2090', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33222, to_date('15-12-2090', 'dd-mm-yyyy'), '5', '15', '349', '12', '2090', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33223, to_date('16-12-2090', 'dd-mm-yyyy'), '6', '16', '350', '12', '2090', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33224, to_date('17-12-2090', 'dd-mm-yyyy'), '7', '17', '351', '12', '2090', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33225, to_date('18-12-2090', 'dd-mm-yyyy'), '1', '18', '352', '12', '2090', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33226, to_date('19-12-2090', 'dd-mm-yyyy'), '2', '19', '353', '12', '2090', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33227, to_date('20-12-2090', 'dd-mm-yyyy'), '3', '20', '354', '12', '2090', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33228, to_date('21-12-2090', 'dd-mm-yyyy'), '4', '21', '355', '12', '2090', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33229, to_date('22-12-2090', 'dd-mm-yyyy'), '5', '22', '356', '12', '2090', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33230, to_date('23-12-2090', 'dd-mm-yyyy'), '6', '23', '357', '12', '2090', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33231, to_date('24-12-2090', 'dd-mm-yyyy'), '7', '24', '358', '12', '2090', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33232, to_date('25-12-2090', 'dd-mm-yyyy'), '1', '25', '359', '12', '2090', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33233, to_date('26-12-2090', 'dd-mm-yyyy'), '2', '26', '360', '12', '2090', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33234, to_date('27-12-2090', 'dd-mm-yyyy'), '3', '27', '361', '12', '2090', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33235, to_date('28-12-2090', 'dd-mm-yyyy'), '4', '28', '362', '12', '2090', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33236, to_date('29-12-2090', 'dd-mm-yyyy'), '5', '29', '363', '12', '2090', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33237, to_date('30-12-2090', 'dd-mm-yyyy'), '6', '30', '364', '12', '2090', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33238, to_date('31-12-2090', 'dd-mm-yyyy'), '7', '31', '365', '12', '2090', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33239, to_date('01-01-2091', 'dd-mm-yyyy'), '1', '01', '001', '01', '2091', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33240, to_date('02-01-2091', 'dd-mm-yyyy'), '2', '02', '002', '01', '2091', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33241, to_date('03-01-2091', 'dd-mm-yyyy'), '3', '03', '003', '01', '2091', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33242, to_date('04-01-2091', 'dd-mm-yyyy'), '4', '04', '004', '01', '2091', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33243, to_date('05-01-2091', 'dd-mm-yyyy'), '5', '05', '005', '01', '2091', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33244, to_date('06-01-2091', 'dd-mm-yyyy'), '6', '06', '006', '01', '2091', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33245, to_date('07-01-2091', 'dd-mm-yyyy'), '7', '07', '007', '01', '2091', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33246, to_date('08-01-2091', 'dd-mm-yyyy'), '1', '08', '008', '01', '2091', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33247, to_date('09-01-2091', 'dd-mm-yyyy'), '2', '09', '009', '01', '2091', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33248, to_date('10-01-2091', 'dd-mm-yyyy'), '3', '10', '010', '01', '2091', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33249, to_date('11-01-2091', 'dd-mm-yyyy'), '4', '11', '011', '01', '2091', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33250, to_date('12-01-2091', 'dd-mm-yyyy'), '5', '12', '012', '01', '2091', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33251, to_date('13-01-2091', 'dd-mm-yyyy'), '6', '13', '013', '01', '2091', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33252, to_date('14-01-2091', 'dd-mm-yyyy'), '7', '14', '014', '01', '2091', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33253, to_date('15-01-2091', 'dd-mm-yyyy'), '1', '15', '015', '01', '2091', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33254, to_date('16-01-2091', 'dd-mm-yyyy'), '2', '16', '016', '01', '2091', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33255, to_date('17-01-2091', 'dd-mm-yyyy'), '3', '17', '017', '01', '2091', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33256, to_date('18-01-2091', 'dd-mm-yyyy'), '4', '18', '018', '01', '2091', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33257, to_date('19-01-2091', 'dd-mm-yyyy'), '5', '19', '019', '01', '2091', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33258, to_date('20-01-2091', 'dd-mm-yyyy'), '6', '20', '020', '01', '2091', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34743, to_date('13-02-2095', 'dd-mm-yyyy'), '7', '13', '044', '02', '2095', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34744, to_date('14-02-2095', 'dd-mm-yyyy'), '1', '14', '045', '02', '2095', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34745, to_date('15-02-2095', 'dd-mm-yyyy'), '2', '15', '046', '02', '2095', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34746, to_date('16-02-2095', 'dd-mm-yyyy'), '3', '16', '047', '02', '2095', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34747, to_date('17-02-2095', 'dd-mm-yyyy'), '4', '17', '048', '02', '2095', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34748, to_date('18-02-2095', 'dd-mm-yyyy'), '5', '18', '049', '02', '2095', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34749, to_date('19-02-2095', 'dd-mm-yyyy'), '6', '19', '050', '02', '2095', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34750, to_date('20-02-2095', 'dd-mm-yyyy'), '7', '20', '051', '02', '2095', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34751, to_date('21-02-2095', 'dd-mm-yyyy'), '1', '21', '052', '02', '2095', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34752, to_date('22-02-2095', 'dd-mm-yyyy'), '2', '22', '053', '02', '2095', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34753, to_date('23-02-2095', 'dd-mm-yyyy'), '3', '23', '054', '02', '2095', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34754, to_date('24-02-2095', 'dd-mm-yyyy'), '4', '24', '055', '02', '2095', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34755, to_date('25-02-2095', 'dd-mm-yyyy'), '5', '25', '056', '02', '2095', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34756, to_date('26-02-2095', 'dd-mm-yyyy'), '6', '26', '057', '02', '2095', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34757, to_date('27-02-2095', 'dd-mm-yyyy'), '7', '27', '058', '02', '2095', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34758, to_date('28-02-2095', 'dd-mm-yyyy'), '1', '28', '059', '02', '2095', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34759, to_date('01-03-2095', 'dd-mm-yyyy'), '2', '01', '060', '03', '2095', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34760, to_date('02-03-2095', 'dd-mm-yyyy'), '3', '02', '061', '03', '2095', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34761, to_date('03-03-2095', 'dd-mm-yyyy'), '4', '03', '062', '03', '2095', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34762, to_date('04-03-2095', 'dd-mm-yyyy'), '5', '04', '063', '03', '2095', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34763, to_date('05-03-2095', 'dd-mm-yyyy'), '6', '05', '064', '03', '2095', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34764, to_date('06-03-2095', 'dd-mm-yyyy'), '7', '06', '065', '03', '2095', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34765, to_date('07-03-2095', 'dd-mm-yyyy'), '1', '07', '066', '03', '2095', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34766, to_date('08-03-2095', 'dd-mm-yyyy'), '2', '08', '067', '03', '2095', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34767, to_date('09-03-2095', 'dd-mm-yyyy'), '3', '09', '068', '03', '2095', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34768, to_date('10-03-2095', 'dd-mm-yyyy'), '4', '10', '069', '03', '2095', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34769, to_date('11-03-2095', 'dd-mm-yyyy'), '5', '11', '070', '03', '2095', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34770, to_date('12-03-2095', 'dd-mm-yyyy'), '6', '12', '071', '03', '2095', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34771, to_date('13-03-2095', 'dd-mm-yyyy'), '7', '13', '072', '03', '2095', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34772, to_date('14-03-2095', 'dd-mm-yyyy'), '1', '14', '073', '03', '2095', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34773, to_date('15-03-2095', 'dd-mm-yyyy'), '2', '15', '074', '03', '2095', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34774, to_date('16-03-2095', 'dd-mm-yyyy'), '3', '16', '075', '03', '2095', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34775, to_date('17-03-2095', 'dd-mm-yyyy'), '4', '17', '076', '03', '2095', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34776, to_date('18-03-2095', 'dd-mm-yyyy'), '5', '18', '077', '03', '2095', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34777, to_date('19-03-2095', 'dd-mm-yyyy'), '6', '19', '078', '03', '2095', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34778, to_date('20-03-2095', 'dd-mm-yyyy'), '7', '20', '079', '03', '2095', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34779, to_date('21-03-2095', 'dd-mm-yyyy'), '1', '21', '080', '03', '2095', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34780, to_date('22-03-2095', 'dd-mm-yyyy'), '2', '22', '081', '03', '2095', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34781, to_date('23-03-2095', 'dd-mm-yyyy'), '3', '23', '082', '03', '2095', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34782, to_date('24-03-2095', 'dd-mm-yyyy'), '4', '24', '083', '03', '2095', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34783, to_date('25-03-2095', 'dd-mm-yyyy'), '5', '25', '084', '03', '2095', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34784, to_date('26-03-2095', 'dd-mm-yyyy'), '6', '26', '085', '03', '2095', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34785, to_date('27-03-2095', 'dd-mm-yyyy'), '7', '27', '086', '03', '2095', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34786, to_date('28-03-2095', 'dd-mm-yyyy'), '1', '28', '087', '03', '2095', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34787, to_date('29-03-2095', 'dd-mm-yyyy'), '2', '29', '088', '03', '2095', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34788, to_date('30-03-2095', 'dd-mm-yyyy'), '3', '30', '089', '03', '2095', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34789, to_date('31-03-2095', 'dd-mm-yyyy'), '4', '31', '090', '03', '2095', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34790, to_date('01-04-2095', 'dd-mm-yyyy'), '5', '01', '091', '04', '2095', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34791, to_date('02-04-2095', 'dd-mm-yyyy'), '6', '02', '092', '04', '2095', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34792, to_date('03-04-2095', 'dd-mm-yyyy'), '7', '03', '093', '04', '2095', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34793, to_date('04-04-2095', 'dd-mm-yyyy'), '1', '04', '094', '04', '2095', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34794, to_date('05-04-2095', 'dd-mm-yyyy'), '2', '05', '095', '04', '2095', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34795, to_date('06-04-2095', 'dd-mm-yyyy'), '3', '06', '096', '04', '2095', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34796, to_date('07-04-2095', 'dd-mm-yyyy'), '4', '07', '097', '04', '2095', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34797, to_date('08-04-2095', 'dd-mm-yyyy'), '5', '08', '098', '04', '2095', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34798, to_date('09-04-2095', 'dd-mm-yyyy'), '6', '09', '099', '04', '2095', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34799, to_date('10-04-2095', 'dd-mm-yyyy'), '7', '10', '100', '04', '2095', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34800, to_date('11-04-2095', 'dd-mm-yyyy'), '1', '11', '101', '04', '2095', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34801, to_date('12-04-2095', 'dd-mm-yyyy'), '2', '12', '102', '04', '2095', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34802, to_date('13-04-2095', 'dd-mm-yyyy'), '3', '13', '103', '04', '2095', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34803, to_date('14-04-2095', 'dd-mm-yyyy'), '4', '14', '104', '04', '2095', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34804, to_date('15-04-2095', 'dd-mm-yyyy'), '5', '15', '105', '04', '2095', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34805, to_date('16-04-2095', 'dd-mm-yyyy'), '6', '16', '106', '04', '2095', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34806, to_date('17-04-2095', 'dd-mm-yyyy'), '7', '17', '107', '04', '2095', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34807, to_date('18-04-2095', 'dd-mm-yyyy'), '1', '18', '108', '04', '2095', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34808, to_date('19-04-2095', 'dd-mm-yyyy'), '2', '19', '109', '04', '2095', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34809, to_date('20-04-2095', 'dd-mm-yyyy'), '3', '20', '110', '04', '2095', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34810, to_date('21-04-2095', 'dd-mm-yyyy'), '4', '21', '111', '04', '2095', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34811, to_date('22-04-2095', 'dd-mm-yyyy'), '5', '22', '112', '04', '2095', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34812, to_date('23-04-2095', 'dd-mm-yyyy'), '6', '23', '113', '04', '2095', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34813, to_date('24-04-2095', 'dd-mm-yyyy'), '7', '24', '114', '04', '2095', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34814, to_date('25-04-2095', 'dd-mm-yyyy'), '1', '25', '115', '04', '2095', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34815, to_date('26-04-2095', 'dd-mm-yyyy'), '2', '26', '116', '04', '2095', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34816, to_date('27-04-2095', 'dd-mm-yyyy'), '3', '27', '117', '04', '2095', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34817, to_date('28-04-2095', 'dd-mm-yyyy'), '4', '28', '118', '04', '2095', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34818, to_date('29-04-2095', 'dd-mm-yyyy'), '5', '29', '119', '04', '2095', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34819, to_date('30-04-2095', 'dd-mm-yyyy'), '6', '30', '120', '04', '2095', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34820, to_date('01-05-2095', 'dd-mm-yyyy'), '7', '01', '121', '05', '2095', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34821, to_date('02-05-2095', 'dd-mm-yyyy'), '1', '02', '122', '05', '2095', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34822, to_date('03-05-2095', 'dd-mm-yyyy'), '2', '03', '123', '05', '2095', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34823, to_date('04-05-2095', 'dd-mm-yyyy'), '3', '04', '124', '05', '2095', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34824, to_date('05-05-2095', 'dd-mm-yyyy'), '4', '05', '125', '05', '2095', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34825, to_date('06-05-2095', 'dd-mm-yyyy'), '5', '06', '126', '05', '2095', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34826, to_date('07-05-2095', 'dd-mm-yyyy'), '6', '07', '127', '05', '2095', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34827, to_date('08-05-2095', 'dd-mm-yyyy'), '7', '08', '128', '05', '2095', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34828, to_date('09-05-2095', 'dd-mm-yyyy'), '1', '09', '129', '05', '2095', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34829, to_date('10-05-2095', 'dd-mm-yyyy'), '2', '10', '130', '05', '2095', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34830, to_date('11-05-2095', 'dd-mm-yyyy'), '3', '11', '131', '05', '2095', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34831, to_date('12-05-2095', 'dd-mm-yyyy'), '4', '12', '132', '05', '2095', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34832, to_date('13-05-2095', 'dd-mm-yyyy'), '5', '13', '133', '05', '2095', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34833, to_date('14-05-2095', 'dd-mm-yyyy'), '6', '14', '134', '05', '2095', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34834, to_date('15-05-2095', 'dd-mm-yyyy'), '7', '15', '135', '05', '2095', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34835, to_date('16-05-2095', 'dd-mm-yyyy'), '1', '16', '136', '05', '2095', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34836, to_date('17-05-2095', 'dd-mm-yyyy'), '2', '17', '137', '05', '2095', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34837, to_date('18-05-2095', 'dd-mm-yyyy'), '3', '18', '138', '05', '2095', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34838, to_date('19-05-2095', 'dd-mm-yyyy'), '4', '19', '139', '05', '2095', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34839, to_date('20-05-2095', 'dd-mm-yyyy'), '5', '20', '140', '05', '2095', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34840, to_date('21-05-2095', 'dd-mm-yyyy'), '6', '21', '141', '05', '2095', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34841, to_date('22-05-2095', 'dd-mm-yyyy'), '7', '22', '142', '05', '2095', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34842, to_date('23-05-2095', 'dd-mm-yyyy'), '1', '23', '143', '05', '2095', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34843, to_date('24-05-2095', 'dd-mm-yyyy'), '2', '24', '144', '05', '2095', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34844, to_date('25-05-2095', 'dd-mm-yyyy'), '3', '25', '145', '05', '2095', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34845, to_date('26-05-2095', 'dd-mm-yyyy'), '4', '26', '146', '05', '2095', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34846, to_date('27-05-2095', 'dd-mm-yyyy'), '5', '27', '147', '05', '2095', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34847, to_date('28-05-2095', 'dd-mm-yyyy'), '6', '28', '148', '05', '2095', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34848, to_date('29-05-2095', 'dd-mm-yyyy'), '7', '29', '149', '05', '2095', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36333, to_date('22-06-2099', 'dd-mm-yyyy'), '1', '22', '173', '06', '2099', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36334, to_date('23-06-2099', 'dd-mm-yyyy'), '2', '23', '174', '06', '2099', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36335, to_date('24-06-2099', 'dd-mm-yyyy'), '3', '24', '175', '06', '2099', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36336, to_date('25-06-2099', 'dd-mm-yyyy'), '4', '25', '176', '06', '2099', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36337, to_date('26-06-2099', 'dd-mm-yyyy'), '5', '26', '177', '06', '2099', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36338, to_date('27-06-2099', 'dd-mm-yyyy'), '6', '27', '178', '06', '2099', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36339, to_date('28-06-2099', 'dd-mm-yyyy'), '7', '28', '179', '06', '2099', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36340, to_date('29-06-2099', 'dd-mm-yyyy'), '1', '29', '180', '06', '2099', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36341, to_date('30-06-2099', 'dd-mm-yyyy'), '2', '30', '181', '06', '2099', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36342, to_date('01-07-2099', 'dd-mm-yyyy'), '3', '01', '182', '07', '2099', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36343, to_date('02-07-2099', 'dd-mm-yyyy'), '4', '02', '183', '07', '2099', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36344, to_date('03-07-2099', 'dd-mm-yyyy'), '5', '03', '184', '07', '2099', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36345, to_date('04-07-2099', 'dd-mm-yyyy'), '6', '04', '185', '07', '2099', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36346, to_date('05-07-2099', 'dd-mm-yyyy'), '7', '05', '186', '07', '2099', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36347, to_date('06-07-2099', 'dd-mm-yyyy'), '1', '06', '187', '07', '2099', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36348, to_date('07-07-2099', 'dd-mm-yyyy'), '2', '07', '188', '07', '2099', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36349, to_date('08-07-2099', 'dd-mm-yyyy'), '3', '08', '189', '07', '2099', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36350, to_date('09-07-2099', 'dd-mm-yyyy'), '4', '09', '190', '07', '2099', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36351, to_date('10-07-2099', 'dd-mm-yyyy'), '5', '10', '191', '07', '2099', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36352, to_date('11-07-2099', 'dd-mm-yyyy'), '6', '11', '192', '07', '2099', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36353, to_date('12-07-2099', 'dd-mm-yyyy'), '7', '12', '193', '07', '2099', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36354, to_date('13-07-2099', 'dd-mm-yyyy'), '1', '13', '194', '07', '2099', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36355, to_date('14-07-2099', 'dd-mm-yyyy'), '2', '14', '195', '07', '2099', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36356, to_date('15-07-2099', 'dd-mm-yyyy'), '3', '15', '196', '07', '2099', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36357, to_date('16-07-2099', 'dd-mm-yyyy'), '4', '16', '197', '07', '2099', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36358, to_date('17-07-2099', 'dd-mm-yyyy'), '5', '17', '198', '07', '2099', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36359, to_date('18-07-2099', 'dd-mm-yyyy'), '6', '18', '199', '07', '2099', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36360, to_date('19-07-2099', 'dd-mm-yyyy'), '7', '19', '200', '07', '2099', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36361, to_date('20-07-2099', 'dd-mm-yyyy'), '1', '20', '201', '07', '2099', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36362, to_date('21-07-2099', 'dd-mm-yyyy'), '2', '21', '202', '07', '2099', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36363, to_date('22-07-2099', 'dd-mm-yyyy'), '3', '22', '203', '07', '2099', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36364, to_date('23-07-2099', 'dd-mm-yyyy'), '4', '23', '204', '07', '2099', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36365, to_date('24-07-2099', 'dd-mm-yyyy'), '5', '24', '205', '07', '2099', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36366, to_date('25-07-2099', 'dd-mm-yyyy'), '6', '25', '206', '07', '2099', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36367, to_date('26-07-2099', 'dd-mm-yyyy'), '7', '26', '207', '07', '2099', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36368, to_date('27-07-2099', 'dd-mm-yyyy'), '1', '27', '208', '07', '2099', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36369, to_date('28-07-2099', 'dd-mm-yyyy'), '2', '28', '209', '07', '2099', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36370, to_date('29-07-2099', 'dd-mm-yyyy'), '3', '29', '210', '07', '2099', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36371, to_date('30-07-2099', 'dd-mm-yyyy'), '4', '30', '211', '07', '2099', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36372, to_date('31-07-2099', 'dd-mm-yyyy'), '5', '31', '212', '07', '2099', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36373, to_date('01-08-2099', 'dd-mm-yyyy'), '6', '01', '213', '08', '2099', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36374, to_date('02-08-2099', 'dd-mm-yyyy'), '7', '02', '214', '08', '2099', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36375, to_date('03-08-2099', 'dd-mm-yyyy'), '1', '03', '215', '08', '2099', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36376, to_date('04-08-2099', 'dd-mm-yyyy'), '2', '04', '216', '08', '2099', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36377, to_date('05-08-2099', 'dd-mm-yyyy'), '3', '05', '217', '08', '2099', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36378, to_date('06-08-2099', 'dd-mm-yyyy'), '4', '06', '218', '08', '2099', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36379, to_date('07-08-2099', 'dd-mm-yyyy'), '5', '07', '219', '08', '2099', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36380, to_date('08-08-2099', 'dd-mm-yyyy'), '6', '08', '220', '08', '2099', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36381, to_date('09-08-2099', 'dd-mm-yyyy'), '7', '09', '221', '08', '2099', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36382, to_date('10-08-2099', 'dd-mm-yyyy'), '1', '10', '222', '08', '2099', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36383, to_date('11-08-2099', 'dd-mm-yyyy'), '2', '11', '223', '08', '2099', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36384, to_date('12-08-2099', 'dd-mm-yyyy'), '3', '12', '224', '08', '2099', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36385, to_date('13-08-2099', 'dd-mm-yyyy'), '4', '13', '225', '08', '2099', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36386, to_date('14-08-2099', 'dd-mm-yyyy'), '5', '14', '226', '08', '2099', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36387, to_date('15-08-2099', 'dd-mm-yyyy'), '6', '15', '227', '08', '2099', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36388, to_date('16-08-2099', 'dd-mm-yyyy'), '7', '16', '228', '08', '2099', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36389, to_date('17-08-2099', 'dd-mm-yyyy'), '1', '17', '229', '08', '2099', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36390, to_date('18-08-2099', 'dd-mm-yyyy'), '2', '18', '230', '08', '2099', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36391, to_date('19-08-2099', 'dd-mm-yyyy'), '3', '19', '231', '08', '2099', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36392, to_date('20-08-2099', 'dd-mm-yyyy'), '4', '20', '232', '08', '2099', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36393, to_date('21-08-2099', 'dd-mm-yyyy'), '5', '21', '233', '08', '2099', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36394, to_date('22-08-2099', 'dd-mm-yyyy'), '6', '22', '234', '08', '2099', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36395, to_date('23-08-2099', 'dd-mm-yyyy'), '7', '23', '235', '08', '2099', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36396, to_date('24-08-2099', 'dd-mm-yyyy'), '1', '24', '236', '08', '2099', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36397, to_date('25-08-2099', 'dd-mm-yyyy'), '2', '25', '237', '08', '2099', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36398, to_date('26-08-2099', 'dd-mm-yyyy'), '3', '26', '238', '08', '2099', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36399, to_date('27-08-2099', 'dd-mm-yyyy'), '4', '27', '239', '08', '2099', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36400, to_date('28-08-2099', 'dd-mm-yyyy'), '5', '28', '240', '08', '2099', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36401, to_date('29-08-2099', 'dd-mm-yyyy'), '6', '29', '241', '08', '2099', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36402, to_date('30-08-2099', 'dd-mm-yyyy'), '7', '30', '242', '08', '2099', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36403, to_date('31-08-2099', 'dd-mm-yyyy'), '1', '31', '243', '08', '2099', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36404, to_date('01-09-2099', 'dd-mm-yyyy'), '2', '01', '244', '09', '2099', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36405, to_date('02-09-2099', 'dd-mm-yyyy'), '3', '02', '245', '09', '2099', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36406, to_date('03-09-2099', 'dd-mm-yyyy'), '4', '03', '246', '09', '2099', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36407, to_date('04-09-2099', 'dd-mm-yyyy'), '5', '04', '247', '09', '2099', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36408, to_date('05-09-2099', 'dd-mm-yyyy'), '6', '05', '248', '09', '2099', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36409, to_date('06-09-2099', 'dd-mm-yyyy'), '7', '06', '249', '09', '2099', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36410, to_date('07-09-2099', 'dd-mm-yyyy'), '1', '07', '250', '09', '2099', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36411, to_date('08-09-2099', 'dd-mm-yyyy'), '2', '08', '251', '09', '2099', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36412, to_date('09-09-2099', 'dd-mm-yyyy'), '3', '09', '252', '09', '2099', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36413, to_date('10-09-2099', 'dd-mm-yyyy'), '4', '10', '253', '09', '2099', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36414, to_date('11-09-2099', 'dd-mm-yyyy'), '5', '11', '254', '09', '2099', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36415, to_date('12-09-2099', 'dd-mm-yyyy'), '6', '12', '255', '09', '2099', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36416, to_date('13-09-2099', 'dd-mm-yyyy'), '7', '13', '256', '09', '2099', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36417, to_date('14-09-2099', 'dd-mm-yyyy'), '1', '14', '257', '09', '2099', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36418, to_date('15-09-2099', 'dd-mm-yyyy'), '2', '15', '258', '09', '2099', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36419, to_date('16-09-2099', 'dd-mm-yyyy'), '3', '16', '259', '09', '2099', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36420, to_date('17-09-2099', 'dd-mm-yyyy'), '4', '17', '260', '09', '2099', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36421, to_date('18-09-2099', 'dd-mm-yyyy'), '5', '18', '261', '09', '2099', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36422, to_date('19-09-2099', 'dd-mm-yyyy'), '6', '19', '262', '09', '2099', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36423, to_date('20-09-2099', 'dd-mm-yyyy'), '7', '20', '263', '09', '2099', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36424, to_date('21-09-2099', 'dd-mm-yyyy'), '1', '21', '264', '09', '2099', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36425, to_date('22-09-2099', 'dd-mm-yyyy'), '2', '22', '265', '09', '2099', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36426, to_date('23-09-2099', 'dd-mm-yyyy'), '3', '23', '266', '09', '2099', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36427, to_date('24-09-2099', 'dd-mm-yyyy'), '4', '24', '267', '09', '2099', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36428, to_date('25-09-2099', 'dd-mm-yyyy'), '5', '25', '268', '09', '2099', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36429, to_date('26-09-2099', 'dd-mm-yyyy'), '6', '26', '269', '09', '2099', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36430, to_date('27-09-2099', 'dd-mm-yyyy'), '7', '27', '270', '09', '2099', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36431, to_date('28-09-2099', 'dd-mm-yyyy'), '1', '28', '271', '09', '2099', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36432, to_date('29-09-2099', 'dd-mm-yyyy'), '2', '29', '272', '09', '2099', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36433, to_date('30-09-2099', 'dd-mm-yyyy'), '3', '30', '273', '09', '2099', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36434, to_date('01-10-2099', 'dd-mm-yyyy'), '4', '01', '274', '10', '2099', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36435, to_date('02-10-2099', 'dd-mm-yyyy'), '5', '02', '275', '10', '2099', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36436, to_date('03-10-2099', 'dd-mm-yyyy'), '6', '03', '276', '10', '2099', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36437, to_date('04-10-2099', 'dd-mm-yyyy'), '7', '04', '277', '10', '2099', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36438, to_date('05-10-2099', 'dd-mm-yyyy'), '1', '05', '278', '10', '2099', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33259, to_date('21-01-2091', 'dd-mm-yyyy'), '7', '21', '021', '01', '2091', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33260, to_date('22-01-2091', 'dd-mm-yyyy'), '1', '22', '022', '01', '2091', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33261, to_date('23-01-2091', 'dd-mm-yyyy'), '2', '23', '023', '01', '2091', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33262, to_date('24-01-2091', 'dd-mm-yyyy'), '3', '24', '024', '01', '2091', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33263, to_date('25-01-2091', 'dd-mm-yyyy'), '4', '25', '025', '01', '2091', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33264, to_date('26-01-2091', 'dd-mm-yyyy'), '5', '26', '026', '01', '2091', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33265, to_date('27-01-2091', 'dd-mm-yyyy'), '6', '27', '027', '01', '2091', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33266, to_date('28-01-2091', 'dd-mm-yyyy'), '7', '28', '028', '01', '2091', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33267, to_date('29-01-2091', 'dd-mm-yyyy'), '1', '29', '029', '01', '2091', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33268, to_date('30-01-2091', 'dd-mm-yyyy'), '2', '30', '030', '01', '2091', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33269, to_date('31-01-2091', 'dd-mm-yyyy'), '3', '31', '031', '01', '2091', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33270, to_date('01-02-2091', 'dd-mm-yyyy'), '4', '01', '032', '02', '2091', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33271, to_date('02-02-2091', 'dd-mm-yyyy'), '5', '02', '033', '02', '2091', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33272, to_date('03-02-2091', 'dd-mm-yyyy'), '6', '03', '034', '02', '2091', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33273, to_date('04-02-2091', 'dd-mm-yyyy'), '7', '04', '035', '02', '2091', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33274, to_date('05-02-2091', 'dd-mm-yyyy'), '1', '05', '036', '02', '2091', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33275, to_date('06-02-2091', 'dd-mm-yyyy'), '2', '06', '037', '02', '2091', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33276, to_date('07-02-2091', 'dd-mm-yyyy'), '3', '07', '038', '02', '2091', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33277, to_date('08-02-2091', 'dd-mm-yyyy'), '4', '08', '039', '02', '2091', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33278, to_date('09-02-2091', 'dd-mm-yyyy'), '5', '09', '040', '02', '2091', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33279, to_date('10-02-2091', 'dd-mm-yyyy'), '6', '10', '041', '02', '2091', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33280, to_date('11-02-2091', 'dd-mm-yyyy'), '7', '11', '042', '02', '2091', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33281, to_date('12-02-2091', 'dd-mm-yyyy'), '1', '12', '043', '02', '2091', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33282, to_date('13-02-2091', 'dd-mm-yyyy'), '2', '13', '044', '02', '2091', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33283, to_date('14-02-2091', 'dd-mm-yyyy'), '3', '14', '045', '02', '2091', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33284, to_date('15-02-2091', 'dd-mm-yyyy'), '4', '15', '046', '02', '2091', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33285, to_date('16-02-2091', 'dd-mm-yyyy'), '5', '16', '047', '02', '2091', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33286, to_date('17-02-2091', 'dd-mm-yyyy'), '6', '17', '048', '02', '2091', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33287, to_date('18-02-2091', 'dd-mm-yyyy'), '7', '18', '049', '02', '2091', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33288, to_date('19-02-2091', 'dd-mm-yyyy'), '1', '19', '050', '02', '2091', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33289, to_date('20-02-2091', 'dd-mm-yyyy'), '2', '20', '051', '02', '2091', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33290, to_date('21-02-2091', 'dd-mm-yyyy'), '3', '21', '052', '02', '2091', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33291, to_date('22-02-2091', 'dd-mm-yyyy'), '4', '22', '053', '02', '2091', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33292, to_date('23-02-2091', 'dd-mm-yyyy'), '5', '23', '054', '02', '2091', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33293, to_date('24-02-2091', 'dd-mm-yyyy'), '6', '24', '055', '02', '2091', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33294, to_date('25-02-2091', 'dd-mm-yyyy'), '7', '25', '056', '02', '2091', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33295, to_date('26-02-2091', 'dd-mm-yyyy'), '1', '26', '057', '02', '2091', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33296, to_date('27-02-2091', 'dd-mm-yyyy'), '2', '27', '058', '02', '2091', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33297, to_date('28-02-2091', 'dd-mm-yyyy'), '3', '28', '059', '02', '2091', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33298, to_date('01-03-2091', 'dd-mm-yyyy'), '4', '01', '060', '03', '2091', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33299, to_date('02-03-2091', 'dd-mm-yyyy'), '5', '02', '061', '03', '2091', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33300, to_date('03-03-2091', 'dd-mm-yyyy'), '6', '03', '062', '03', '2091', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33301, to_date('04-03-2091', 'dd-mm-yyyy'), '7', '04', '063', '03', '2091', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33302, to_date('05-03-2091', 'dd-mm-yyyy'), '1', '05', '064', '03', '2091', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33303, to_date('06-03-2091', 'dd-mm-yyyy'), '2', '06', '065', '03', '2091', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33304, to_date('07-03-2091', 'dd-mm-yyyy'), '3', '07', '066', '03', '2091', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33305, to_date('08-03-2091', 'dd-mm-yyyy'), '4', '08', '067', '03', '2091', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33306, to_date('09-03-2091', 'dd-mm-yyyy'), '5', '09', '068', '03', '2091', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33307, to_date('10-03-2091', 'dd-mm-yyyy'), '6', '10', '069', '03', '2091', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33308, to_date('11-03-2091', 'dd-mm-yyyy'), '7', '11', '070', '03', '2091', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33309, to_date('12-03-2091', 'dd-mm-yyyy'), '1', '12', '071', '03', '2091', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33310, to_date('13-03-2091', 'dd-mm-yyyy'), '2', '13', '072', '03', '2091', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33311, to_date('14-03-2091', 'dd-mm-yyyy'), '3', '14', '073', '03', '2091', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33312, to_date('15-03-2091', 'dd-mm-yyyy'), '4', '15', '074', '03', '2091', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33313, to_date('16-03-2091', 'dd-mm-yyyy'), '5', '16', '075', '03', '2091', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33314, to_date('17-03-2091', 'dd-mm-yyyy'), '6', '17', '076', '03', '2091', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33315, to_date('18-03-2091', 'dd-mm-yyyy'), '7', '18', '077', '03', '2091', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33316, to_date('19-03-2091', 'dd-mm-yyyy'), '1', '19', '078', '03', '2091', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33317, to_date('20-03-2091', 'dd-mm-yyyy'), '2', '20', '079', '03', '2091', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33318, to_date('21-03-2091', 'dd-mm-yyyy'), '3', '21', '080', '03', '2091', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33319, to_date('22-03-2091', 'dd-mm-yyyy'), '4', '22', '081', '03', '2091', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33320, to_date('23-03-2091', 'dd-mm-yyyy'), '5', '23', '082', '03', '2091', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33321, to_date('24-03-2091', 'dd-mm-yyyy'), '6', '24', '083', '03', '2091', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33322, to_date('25-03-2091', 'dd-mm-yyyy'), '7', '25', '084', '03', '2091', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33323, to_date('26-03-2091', 'dd-mm-yyyy'), '1', '26', '085', '03', '2091', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33324, to_date('27-03-2091', 'dd-mm-yyyy'), '2', '27', '086', '03', '2091', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33325, to_date('28-03-2091', 'dd-mm-yyyy'), '3', '28', '087', '03', '2091', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33326, to_date('29-03-2091', 'dd-mm-yyyy'), '4', '29', '088', '03', '2091', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33327, to_date('30-03-2091', 'dd-mm-yyyy'), '5', '30', '089', '03', '2091', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33328, to_date('31-03-2091', 'dd-mm-yyyy'), '6', '31', '090', '03', '2091', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33329, to_date('01-04-2091', 'dd-mm-yyyy'), '7', '01', '091', '04', '2091', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33330, to_date('02-04-2091', 'dd-mm-yyyy'), '1', '02', '092', '04', '2091', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33331, to_date('03-04-2091', 'dd-mm-yyyy'), '2', '03', '093', '04', '2091', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33332, to_date('04-04-2091', 'dd-mm-yyyy'), '3', '04', '094', '04', '2091', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33333, to_date('05-04-2091', 'dd-mm-yyyy'), '4', '05', '095', '04', '2091', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33334, to_date('06-04-2091', 'dd-mm-yyyy'), '5', '06', '096', '04', '2091', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33335, to_date('07-04-2091', 'dd-mm-yyyy'), '6', '07', '097', '04', '2091', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33336, to_date('08-04-2091', 'dd-mm-yyyy'), '7', '08', '098', '04', '2091', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33337, to_date('09-04-2091', 'dd-mm-yyyy'), '1', '09', '099', '04', '2091', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33338, to_date('10-04-2091', 'dd-mm-yyyy'), '2', '10', '100', '04', '2091', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33339, to_date('11-04-2091', 'dd-mm-yyyy'), '3', '11', '101', '04', '2091', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33340, to_date('12-04-2091', 'dd-mm-yyyy'), '4', '12', '102', '04', '2091', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33341, to_date('13-04-2091', 'dd-mm-yyyy'), '5', '13', '103', '04', '2091', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33342, to_date('14-04-2091', 'dd-mm-yyyy'), '6', '14', '104', '04', '2091', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33343, to_date('15-04-2091', 'dd-mm-yyyy'), '7', '15', '105', '04', '2091', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33344, to_date('16-04-2091', 'dd-mm-yyyy'), '1', '16', '106', '04', '2091', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33345, to_date('17-04-2091', 'dd-mm-yyyy'), '2', '17', '107', '04', '2091', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33346, to_date('18-04-2091', 'dd-mm-yyyy'), '3', '18', '108', '04', '2091', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33347, to_date('19-04-2091', 'dd-mm-yyyy'), '4', '19', '109', '04', '2091', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33348, to_date('20-04-2091', 'dd-mm-yyyy'), '5', '20', '110', '04', '2091', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33349, to_date('21-04-2091', 'dd-mm-yyyy'), '6', '21', '111', '04', '2091', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33350, to_date('22-04-2091', 'dd-mm-yyyy'), '7', '22', '112', '04', '2091', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33351, to_date('23-04-2091', 'dd-mm-yyyy'), '1', '23', '113', '04', '2091', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33352, to_date('24-04-2091', 'dd-mm-yyyy'), '2', '24', '114', '04', '2091', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33353, to_date('25-04-2091', 'dd-mm-yyyy'), '3', '25', '115', '04', '2091', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33354, to_date('26-04-2091', 'dd-mm-yyyy'), '4', '26', '116', '04', '2091', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33355, to_date('27-04-2091', 'dd-mm-yyyy'), '5', '27', '117', '04', '2091', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33356, to_date('28-04-2091', 'dd-mm-yyyy'), '6', '28', '118', '04', '2091', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33357, to_date('29-04-2091', 'dd-mm-yyyy'), '7', '29', '119', '04', '2091', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33358, to_date('30-04-2091', 'dd-mm-yyyy'), '1', '30', '120', '04', '2091', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33359, to_date('01-05-2091', 'dd-mm-yyyy'), '2', '01', '121', '05', '2091', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33360, to_date('02-05-2091', 'dd-mm-yyyy'), '3', '02', '122', '05', '2091', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33361, to_date('03-05-2091', 'dd-mm-yyyy'), '4', '03', '123', '05', '2091', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33362, to_date('04-05-2091', 'dd-mm-yyyy'), '5', '04', '124', '05', '2091', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33363, to_date('05-05-2091', 'dd-mm-yyyy'), '6', '05', '125', '05', '2091', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33364, to_date('06-05-2091', 'dd-mm-yyyy'), '7', '06', '126', '05', '2091', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34849, to_date('30-05-2095', 'dd-mm-yyyy'), '1', '30', '150', '05', '2095', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34850, to_date('31-05-2095', 'dd-mm-yyyy'), '2', '31', '151', '05', '2095', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34851, to_date('01-06-2095', 'dd-mm-yyyy'), '3', '01', '152', '06', '2095', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34852, to_date('02-06-2095', 'dd-mm-yyyy'), '4', '02', '153', '06', '2095', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34853, to_date('03-06-2095', 'dd-mm-yyyy'), '5', '03', '154', '06', '2095', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34854, to_date('04-06-2095', 'dd-mm-yyyy'), '6', '04', '155', '06', '2095', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34855, to_date('05-06-2095', 'dd-mm-yyyy'), '7', '05', '156', '06', '2095', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34856, to_date('06-06-2095', 'dd-mm-yyyy'), '1', '06', '157', '06', '2095', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34857, to_date('07-06-2095', 'dd-mm-yyyy'), '2', '07', '158', '06', '2095', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34858, to_date('08-06-2095', 'dd-mm-yyyy'), '3', '08', '159', '06', '2095', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34859, to_date('09-06-2095', 'dd-mm-yyyy'), '4', '09', '160', '06', '2095', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34860, to_date('10-06-2095', 'dd-mm-yyyy'), '5', '10', '161', '06', '2095', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34861, to_date('11-06-2095', 'dd-mm-yyyy'), '6', '11', '162', '06', '2095', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34862, to_date('12-06-2095', 'dd-mm-yyyy'), '7', '12', '163', '06', '2095', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34863, to_date('13-06-2095', 'dd-mm-yyyy'), '1', '13', '164', '06', '2095', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34864, to_date('14-06-2095', 'dd-mm-yyyy'), '2', '14', '165', '06', '2095', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34865, to_date('15-06-2095', 'dd-mm-yyyy'), '3', '15', '166', '06', '2095', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34866, to_date('16-06-2095', 'dd-mm-yyyy'), '4', '16', '167', '06', '2095', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34867, to_date('17-06-2095', 'dd-mm-yyyy'), '5', '17', '168', '06', '2095', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34868, to_date('18-06-2095', 'dd-mm-yyyy'), '6', '18', '169', '06', '2095', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34869, to_date('19-06-2095', 'dd-mm-yyyy'), '7', '19', '170', '06', '2095', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34870, to_date('20-06-2095', 'dd-mm-yyyy'), '1', '20', '171', '06', '2095', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34871, to_date('21-06-2095', 'dd-mm-yyyy'), '2', '21', '172', '06', '2095', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34872, to_date('22-06-2095', 'dd-mm-yyyy'), '3', '22', '173', '06', '2095', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34873, to_date('23-06-2095', 'dd-mm-yyyy'), '4', '23', '174', '06', '2095', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34874, to_date('24-06-2095', 'dd-mm-yyyy'), '5', '24', '175', '06', '2095', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34875, to_date('25-06-2095', 'dd-mm-yyyy'), '6', '25', '176', '06', '2095', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34876, to_date('26-06-2095', 'dd-mm-yyyy'), '7', '26', '177', '06', '2095', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34877, to_date('27-06-2095', 'dd-mm-yyyy'), '1', '27', '178', '06', '2095', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34878, to_date('28-06-2095', 'dd-mm-yyyy'), '2', '28', '179', '06', '2095', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34879, to_date('29-06-2095', 'dd-mm-yyyy'), '3', '29', '180', '06', '2095', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34880, to_date('30-06-2095', 'dd-mm-yyyy'), '4', '30', '181', '06', '2095', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34881, to_date('01-07-2095', 'dd-mm-yyyy'), '5', '01', '182', '07', '2095', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34882, to_date('02-07-2095', 'dd-mm-yyyy'), '6', '02', '183', '07', '2095', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34883, to_date('03-07-2095', 'dd-mm-yyyy'), '7', '03', '184', '07', '2095', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34884, to_date('04-07-2095', 'dd-mm-yyyy'), '1', '04', '185', '07', '2095', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34885, to_date('05-07-2095', 'dd-mm-yyyy'), '2', '05', '186', '07', '2095', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34886, to_date('06-07-2095', 'dd-mm-yyyy'), '3', '06', '187', '07', '2095', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34887, to_date('07-07-2095', 'dd-mm-yyyy'), '4', '07', '188', '07', '2095', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34888, to_date('08-07-2095', 'dd-mm-yyyy'), '5', '08', '189', '07', '2095', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34889, to_date('09-07-2095', 'dd-mm-yyyy'), '6', '09', '190', '07', '2095', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34890, to_date('10-07-2095', 'dd-mm-yyyy'), '7', '10', '191', '07', '2095', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34891, to_date('11-07-2095', 'dd-mm-yyyy'), '1', '11', '192', '07', '2095', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34892, to_date('12-07-2095', 'dd-mm-yyyy'), '2', '12', '193', '07', '2095', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34893, to_date('13-07-2095', 'dd-mm-yyyy'), '3', '13', '194', '07', '2095', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34894, to_date('14-07-2095', 'dd-mm-yyyy'), '4', '14', '195', '07', '2095', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34895, to_date('15-07-2095', 'dd-mm-yyyy'), '5', '15', '196', '07', '2095', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34896, to_date('16-07-2095', 'dd-mm-yyyy'), '6', '16', '197', '07', '2095', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34897, to_date('17-07-2095', 'dd-mm-yyyy'), '7', '17', '198', '07', '2095', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34898, to_date('18-07-2095', 'dd-mm-yyyy'), '1', '18', '199', '07', '2095', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34899, to_date('19-07-2095', 'dd-mm-yyyy'), '2', '19', '200', '07', '2095', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34900, to_date('20-07-2095', 'dd-mm-yyyy'), '3', '20', '201', '07', '2095', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34901, to_date('21-07-2095', 'dd-mm-yyyy'), '4', '21', '202', '07', '2095', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34902, to_date('22-07-2095', 'dd-mm-yyyy'), '5', '22', '203', '07', '2095', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34903, to_date('23-07-2095', 'dd-mm-yyyy'), '6', '23', '204', '07', '2095', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34904, to_date('24-07-2095', 'dd-mm-yyyy'), '7', '24', '205', '07', '2095', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34905, to_date('25-07-2095', 'dd-mm-yyyy'), '1', '25', '206', '07', '2095', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34906, to_date('26-07-2095', 'dd-mm-yyyy'), '2', '26', '207', '07', '2095', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34907, to_date('27-07-2095', 'dd-mm-yyyy'), '3', '27', '208', '07', '2095', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34908, to_date('28-07-2095', 'dd-mm-yyyy'), '4', '28', '209', '07', '2095', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34909, to_date('29-07-2095', 'dd-mm-yyyy'), '5', '29', '210', '07', '2095', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34910, to_date('30-07-2095', 'dd-mm-yyyy'), '6', '30', '211', '07', '2095', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34911, to_date('31-07-2095', 'dd-mm-yyyy'), '7', '31', '212', '07', '2095', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34912, to_date('01-08-2095', 'dd-mm-yyyy'), '1', '01', '213', '08', '2095', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34913, to_date('02-08-2095', 'dd-mm-yyyy'), '2', '02', '214', '08', '2095', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34914, to_date('03-08-2095', 'dd-mm-yyyy'), '3', '03', '215', '08', '2095', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34915, to_date('04-08-2095', 'dd-mm-yyyy'), '4', '04', '216', '08', '2095', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34916, to_date('05-08-2095', 'dd-mm-yyyy'), '5', '05', '217', '08', '2095', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34917, to_date('06-08-2095', 'dd-mm-yyyy'), '6', '06', '218', '08', '2095', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34918, to_date('07-08-2095', 'dd-mm-yyyy'), '7', '07', '219', '08', '2095', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34919, to_date('08-08-2095', 'dd-mm-yyyy'), '1', '08', '220', '08', '2095', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34920, to_date('09-08-2095', 'dd-mm-yyyy'), '2', '09', '221', '08', '2095', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34921, to_date('10-08-2095', 'dd-mm-yyyy'), '3', '10', '222', '08', '2095', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34922, to_date('11-08-2095', 'dd-mm-yyyy'), '4', '11', '223', '08', '2095', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34923, to_date('12-08-2095', 'dd-mm-yyyy'), '5', '12', '224', '08', '2095', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34924, to_date('13-08-2095', 'dd-mm-yyyy'), '6', '13', '225', '08', '2095', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34925, to_date('14-08-2095', 'dd-mm-yyyy'), '7', '14', '226', '08', '2095', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34926, to_date('15-08-2095', 'dd-mm-yyyy'), '1', '15', '227', '08', '2095', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34927, to_date('16-08-2095', 'dd-mm-yyyy'), '2', '16', '228', '08', '2095', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34928, to_date('17-08-2095', 'dd-mm-yyyy'), '3', '17', '229', '08', '2095', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34929, to_date('18-08-2095', 'dd-mm-yyyy'), '4', '18', '230', '08', '2095', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34930, to_date('19-08-2095', 'dd-mm-yyyy'), '5', '19', '231', '08', '2095', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34931, to_date('20-08-2095', 'dd-mm-yyyy'), '6', '20', '232', '08', '2095', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34932, to_date('21-08-2095', 'dd-mm-yyyy'), '7', '21', '233', '08', '2095', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34933, to_date('22-08-2095', 'dd-mm-yyyy'), '1', '22', '234', '08', '2095', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34934, to_date('23-08-2095', 'dd-mm-yyyy'), '2', '23', '235', '08', '2095', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34935, to_date('24-08-2095', 'dd-mm-yyyy'), '3', '24', '236', '08', '2095', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34936, to_date('25-08-2095', 'dd-mm-yyyy'), '4', '25', '237', '08', '2095', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34937, to_date('26-08-2095', 'dd-mm-yyyy'), '5', '26', '238', '08', '2095', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34938, to_date('27-08-2095', 'dd-mm-yyyy'), '6', '27', '239', '08', '2095', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34939, to_date('28-08-2095', 'dd-mm-yyyy'), '7', '28', '240', '08', '2095', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34940, to_date('29-08-2095', 'dd-mm-yyyy'), '1', '29', '241', '08', '2095', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34941, to_date('30-08-2095', 'dd-mm-yyyy'), '2', '30', '242', '08', '2095', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34942, to_date('31-08-2095', 'dd-mm-yyyy'), '3', '31', '243', '08', '2095', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34943, to_date('01-09-2095', 'dd-mm-yyyy'), '4', '01', '244', '09', '2095', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34944, to_date('02-09-2095', 'dd-mm-yyyy'), '5', '02', '245', '09', '2095', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34945, to_date('03-09-2095', 'dd-mm-yyyy'), '6', '03', '246', '09', '2095', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34946, to_date('04-09-2095', 'dd-mm-yyyy'), '7', '04', '247', '09', '2095', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34947, to_date('05-09-2095', 'dd-mm-yyyy'), '1', '05', '248', '09', '2095', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34948, to_date('06-09-2095', 'dd-mm-yyyy'), '2', '06', '249', '09', '2095', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34949, to_date('07-09-2095', 'dd-mm-yyyy'), '3', '07', '250', '09', '2095', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34950, to_date('08-09-2095', 'dd-mm-yyyy'), '4', '08', '251', '09', '2095', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34951, to_date('09-09-2095', 'dd-mm-yyyy'), '5', '09', '252', '09', '2095', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34952, to_date('10-09-2095', 'dd-mm-yyyy'), '6', '10', '253', '09', '2095', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34953, to_date('11-09-2095', 'dd-mm-yyyy'), '7', '11', '254', '09', '2095', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34954, to_date('12-09-2095', 'dd-mm-yyyy'), '1', '12', '255', '09', '2095', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36439, to_date('06-10-2099', 'dd-mm-yyyy'), '2', '06', '279', '10', '2099', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36440, to_date('07-10-2099', 'dd-mm-yyyy'), '3', '07', '280', '10', '2099', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36441, to_date('08-10-2099', 'dd-mm-yyyy'), '4', '08', '281', '10', '2099', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36442, to_date('09-10-2099', 'dd-mm-yyyy'), '5', '09', '282', '10', '2099', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36443, to_date('10-10-2099', 'dd-mm-yyyy'), '6', '10', '283', '10', '2099', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36444, to_date('11-10-2099', 'dd-mm-yyyy'), '7', '11', '284', '10', '2099', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36445, to_date('12-10-2099', 'dd-mm-yyyy'), '1', '12', '285', '10', '2099', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36446, to_date('13-10-2099', 'dd-mm-yyyy'), '2', '13', '286', '10', '2099', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36447, to_date('14-10-2099', 'dd-mm-yyyy'), '3', '14', '287', '10', '2099', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36448, to_date('15-10-2099', 'dd-mm-yyyy'), '4', '15', '288', '10', '2099', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36449, to_date('16-10-2099', 'dd-mm-yyyy'), '5', '16', '289', '10', '2099', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36450, to_date('17-10-2099', 'dd-mm-yyyy'), '6', '17', '290', '10', '2099', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36451, to_date('18-10-2099', 'dd-mm-yyyy'), '7', '18', '291', '10', '2099', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36452, to_date('19-10-2099', 'dd-mm-yyyy'), '1', '19', '292', '10', '2099', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36453, to_date('20-10-2099', 'dd-mm-yyyy'), '2', '20', '293', '10', '2099', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36454, to_date('21-10-2099', 'dd-mm-yyyy'), '3', '21', '294', '10', '2099', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36455, to_date('22-10-2099', 'dd-mm-yyyy'), '4', '22', '295', '10', '2099', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36456, to_date('23-10-2099', 'dd-mm-yyyy'), '5', '23', '296', '10', '2099', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36457, to_date('24-10-2099', 'dd-mm-yyyy'), '6', '24', '297', '10', '2099', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36458, to_date('25-10-2099', 'dd-mm-yyyy'), '7', '25', '298', '10', '2099', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36459, to_date('26-10-2099', 'dd-mm-yyyy'), '1', '26', '299', '10', '2099', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36460, to_date('27-10-2099', 'dd-mm-yyyy'), '2', '27', '300', '10', '2099', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36461, to_date('28-10-2099', 'dd-mm-yyyy'), '3', '28', '301', '10', '2099', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36462, to_date('29-10-2099', 'dd-mm-yyyy'), '4', '29', '302', '10', '2099', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36463, to_date('30-10-2099', 'dd-mm-yyyy'), '5', '30', '303', '10', '2099', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36464, to_date('31-10-2099', 'dd-mm-yyyy'), '6', '31', '304', '10', '2099', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36465, to_date('01-11-2099', 'dd-mm-yyyy'), '7', '01', '305', '11', '2099', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36466, to_date('02-11-2099', 'dd-mm-yyyy'), '1', '02', '306', '11', '2099', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36467, to_date('03-11-2099', 'dd-mm-yyyy'), '2', '03', '307', '11', '2099', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36468, to_date('04-11-2099', 'dd-mm-yyyy'), '3', '04', '308', '11', '2099', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36469, to_date('05-11-2099', 'dd-mm-yyyy'), '4', '05', '309', '11', '2099', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36470, to_date('06-11-2099', 'dd-mm-yyyy'), '5', '06', '310', '11', '2099', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36471, to_date('07-11-2099', 'dd-mm-yyyy'), '6', '07', '311', '11', '2099', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36472, to_date('08-11-2099', 'dd-mm-yyyy'), '7', '08', '312', '11', '2099', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36473, to_date('09-11-2099', 'dd-mm-yyyy'), '1', '09', '313', '11', '2099', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36474, to_date('10-11-2099', 'dd-mm-yyyy'), '2', '10', '314', '11', '2099', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36475, to_date('11-11-2099', 'dd-mm-yyyy'), '3', '11', '315', '11', '2099', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36476, to_date('12-11-2099', 'dd-mm-yyyy'), '4', '12', '316', '11', '2099', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36477, to_date('13-11-2099', 'dd-mm-yyyy'), '5', '13', '317', '11', '2099', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36478, to_date('14-11-2099', 'dd-mm-yyyy'), '6', '14', '318', '11', '2099', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36479, to_date('15-11-2099', 'dd-mm-yyyy'), '7', '15', '319', '11', '2099', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36480, to_date('16-11-2099', 'dd-mm-yyyy'), '1', '16', '320', '11', '2099', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36481, to_date('17-11-2099', 'dd-mm-yyyy'), '2', '17', '321', '11', '2099', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36482, to_date('18-11-2099', 'dd-mm-yyyy'), '3', '18', '322', '11', '2099', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36483, to_date('19-11-2099', 'dd-mm-yyyy'), '4', '19', '323', '11', '2099', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36484, to_date('20-11-2099', 'dd-mm-yyyy'), '5', '20', '324', '11', '2099', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36485, to_date('21-11-2099', 'dd-mm-yyyy'), '6', '21', '325', '11', '2099', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36486, to_date('22-11-2099', 'dd-mm-yyyy'), '7', '22', '326', '11', '2099', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36487, to_date('23-11-2099', 'dd-mm-yyyy'), '1', '23', '327', '11', '2099', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36488, to_date('24-11-2099', 'dd-mm-yyyy'), '2', '24', '328', '11', '2099', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36489, to_date('25-11-2099', 'dd-mm-yyyy'), '3', '25', '329', '11', '2099', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36490, to_date('26-11-2099', 'dd-mm-yyyy'), '4', '26', '330', '11', '2099', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36491, to_date('27-11-2099', 'dd-mm-yyyy'), '5', '27', '331', '11', '2099', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36492, to_date('28-11-2099', 'dd-mm-yyyy'), '6', '28', '332', '11', '2099', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36493, to_date('29-11-2099', 'dd-mm-yyyy'), '7', '29', '333', '11', '2099', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36494, to_date('30-11-2099', 'dd-mm-yyyy'), '1', '30', '334', '11', '2099', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36495, to_date('01-12-2099', 'dd-mm-yyyy'), '2', '01', '335', '12', '2099', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36496, to_date('02-12-2099', 'dd-mm-yyyy'), '3', '02', '336', '12', '2099', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36497, to_date('03-12-2099', 'dd-mm-yyyy'), '4', '03', '337', '12', '2099', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36498, to_date('04-12-2099', 'dd-mm-yyyy'), '5', '04', '338', '12', '2099', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36499, to_date('05-12-2099', 'dd-mm-yyyy'), '6', '05', '339', '12', '2099', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36500, to_date('06-12-2099', 'dd-mm-yyyy'), '7', '06', '340', '12', '2099', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36501, to_date('07-12-2099', 'dd-mm-yyyy'), '1', '07', '341', '12', '2099', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36502, to_date('08-12-2099', 'dd-mm-yyyy'), '2', '08', '342', '12', '2099', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36503, to_date('09-12-2099', 'dd-mm-yyyy'), '3', '09', '343', '12', '2099', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36504, to_date('10-12-2099', 'dd-mm-yyyy'), '4', '10', '344', '12', '2099', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36505, to_date('11-12-2099', 'dd-mm-yyyy'), '5', '11', '345', '12', '2099', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36506, to_date('12-12-2099', 'dd-mm-yyyy'), '6', '12', '346', '12', '2099', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36507, to_date('13-12-2099', 'dd-mm-yyyy'), '7', '13', '347', '12', '2099', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36508, to_date('14-12-2099', 'dd-mm-yyyy'), '1', '14', '348', '12', '2099', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36509, to_date('15-12-2099', 'dd-mm-yyyy'), '2', '15', '349', '12', '2099', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36510, to_date('16-12-2099', 'dd-mm-yyyy'), '3', '16', '350', '12', '2099', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36511, to_date('17-12-2099', 'dd-mm-yyyy'), '4', '17', '351', '12', '2099', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36512, to_date('18-12-2099', 'dd-mm-yyyy'), '5', '18', '352', '12', '2099', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36513, to_date('19-12-2099', 'dd-mm-yyyy'), '6', '19', '353', '12', '2099', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36514, to_date('20-12-2099', 'dd-mm-yyyy'), '7', '20', '354', '12', '2099', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36515, to_date('21-12-2099', 'dd-mm-yyyy'), '1', '21', '355', '12', '2099', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36516, to_date('22-12-2099', 'dd-mm-yyyy'), '2', '22', '356', '12', '2099', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36517, to_date('23-12-2099', 'dd-mm-yyyy'), '3', '23', '357', '12', '2099', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36518, to_date('24-12-2099', 'dd-mm-yyyy'), '4', '24', '358', '12', '2099', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36519, to_date('25-12-2099', 'dd-mm-yyyy'), '5', '25', '359', '12', '2099', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36520, to_date('26-12-2099', 'dd-mm-yyyy'), '6', '26', '360', '12', '2099', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36521, to_date('27-12-2099', 'dd-mm-yyyy'), '7', '27', '361', '12', '2099', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36522, to_date('28-12-2099', 'dd-mm-yyyy'), '1', '28', '362', '12', '2099', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36523, to_date('29-12-2099', 'dd-mm-yyyy'), '2', '29', '363', '12', '2099', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36524, to_date('30-12-2099', 'dd-mm-yyyy'), '3', '30', '364', '12', '2099', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (36525, to_date('31-12-2099', 'dd-mm-yyyy'), '4', '31', '365', '12', '2099', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33365, to_date('07-05-2091', 'dd-mm-yyyy'), '1', '07', '127', '05', '2091', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33366, to_date('08-05-2091', 'dd-mm-yyyy'), '2', '08', '128', '05', '2091', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33367, to_date('09-05-2091', 'dd-mm-yyyy'), '3', '09', '129', '05', '2091', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33368, to_date('10-05-2091', 'dd-mm-yyyy'), '4', '10', '130', '05', '2091', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33369, to_date('11-05-2091', 'dd-mm-yyyy'), '5', '11', '131', '05', '2091', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33370, to_date('12-05-2091', 'dd-mm-yyyy'), '6', '12', '132', '05', '2091', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33371, to_date('13-05-2091', 'dd-mm-yyyy'), '7', '13', '133', '05', '2091', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33372, to_date('14-05-2091', 'dd-mm-yyyy'), '1', '14', '134', '05', '2091', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33373, to_date('15-05-2091', 'dd-mm-yyyy'), '2', '15', '135', '05', '2091', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33374, to_date('16-05-2091', 'dd-mm-yyyy'), '3', '16', '136', '05', '2091', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33375, to_date('17-05-2091', 'dd-mm-yyyy'), '4', '17', '137', '05', '2091', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33376, to_date('18-05-2091', 'dd-mm-yyyy'), '5', '18', '138', '05', '2091', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33377, to_date('19-05-2091', 'dd-mm-yyyy'), '6', '19', '139', '05', '2091', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33378, to_date('20-05-2091', 'dd-mm-yyyy'), '7', '20', '140', '05', '2091', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33379, to_date('21-05-2091', 'dd-mm-yyyy'), '1', '21', '141', '05', '2091', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33380, to_date('22-05-2091', 'dd-mm-yyyy'), '2', '22', '142', '05', '2091', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33381, to_date('23-05-2091', 'dd-mm-yyyy'), '3', '23', '143', '05', '2091', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33382, to_date('24-05-2091', 'dd-mm-yyyy'), '4', '24', '144', '05', '2091', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33383, to_date('25-05-2091', 'dd-mm-yyyy'), '5', '25', '145', '05', '2091', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33384, to_date('26-05-2091', 'dd-mm-yyyy'), '6', '26', '146', '05', '2091', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33385, to_date('27-05-2091', 'dd-mm-yyyy'), '7', '27', '147', '05', '2091', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33386, to_date('28-05-2091', 'dd-mm-yyyy'), '1', '28', '148', '05', '2091', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33387, to_date('29-05-2091', 'dd-mm-yyyy'), '2', '29', '149', '05', '2091', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33388, to_date('30-05-2091', 'dd-mm-yyyy'), '3', '30', '150', '05', '2091', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33389, to_date('31-05-2091', 'dd-mm-yyyy'), '4', '31', '151', '05', '2091', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33390, to_date('01-06-2091', 'dd-mm-yyyy'), '5', '01', '152', '06', '2091', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33391, to_date('02-06-2091', 'dd-mm-yyyy'), '6', '02', '153', '06', '2091', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33392, to_date('03-06-2091', 'dd-mm-yyyy'), '7', '03', '154', '06', '2091', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33393, to_date('04-06-2091', 'dd-mm-yyyy'), '1', '04', '155', '06', '2091', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33394, to_date('05-06-2091', 'dd-mm-yyyy'), '2', '05', '156', '06', '2091', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33395, to_date('06-06-2091', 'dd-mm-yyyy'), '3', '06', '157', '06', '2091', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33396, to_date('07-06-2091', 'dd-mm-yyyy'), '4', '07', '158', '06', '2091', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33397, to_date('08-06-2091', 'dd-mm-yyyy'), '5', '08', '159', '06', '2091', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33398, to_date('09-06-2091', 'dd-mm-yyyy'), '6', '09', '160', '06', '2091', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33399, to_date('10-06-2091', 'dd-mm-yyyy'), '7', '10', '161', '06', '2091', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33400, to_date('11-06-2091', 'dd-mm-yyyy'), '1', '11', '162', '06', '2091', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33401, to_date('12-06-2091', 'dd-mm-yyyy'), '2', '12', '163', '06', '2091', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33402, to_date('13-06-2091', 'dd-mm-yyyy'), '3', '13', '164', '06', '2091', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33403, to_date('14-06-2091', 'dd-mm-yyyy'), '4', '14', '165', '06', '2091', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33404, to_date('15-06-2091', 'dd-mm-yyyy'), '5', '15', '166', '06', '2091', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33405, to_date('16-06-2091', 'dd-mm-yyyy'), '6', '16', '167', '06', '2091', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33406, to_date('17-06-2091', 'dd-mm-yyyy'), '7', '17', '168', '06', '2091', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33407, to_date('18-06-2091', 'dd-mm-yyyy'), '1', '18', '169', '06', '2091', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33408, to_date('19-06-2091', 'dd-mm-yyyy'), '2', '19', '170', '06', '2091', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33409, to_date('20-06-2091', 'dd-mm-yyyy'), '3', '20', '171', '06', '2091', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33410, to_date('21-06-2091', 'dd-mm-yyyy'), '4', '21', '172', '06', '2091', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33411, to_date('22-06-2091', 'dd-mm-yyyy'), '5', '22', '173', '06', '2091', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33412, to_date('23-06-2091', 'dd-mm-yyyy'), '6', '23', '174', '06', '2091', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33413, to_date('24-06-2091', 'dd-mm-yyyy'), '7', '24', '175', '06', '2091', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33414, to_date('25-06-2091', 'dd-mm-yyyy'), '1', '25', '176', '06', '2091', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33415, to_date('26-06-2091', 'dd-mm-yyyy'), '2', '26', '177', '06', '2091', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33416, to_date('27-06-2091', 'dd-mm-yyyy'), '3', '27', '178', '06', '2091', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33417, to_date('28-06-2091', 'dd-mm-yyyy'), '4', '28', '179', '06', '2091', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33418, to_date('29-06-2091', 'dd-mm-yyyy'), '5', '29', '180', '06', '2091', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33419, to_date('30-06-2091', 'dd-mm-yyyy'), '6', '30', '181', '06', '2091', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33420, to_date('01-07-2091', 'dd-mm-yyyy'), '7', '01', '182', '07', '2091', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33421, to_date('02-07-2091', 'dd-mm-yyyy'), '1', '02', '183', '07', '2091', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33422, to_date('03-07-2091', 'dd-mm-yyyy'), '2', '03', '184', '07', '2091', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33423, to_date('04-07-2091', 'dd-mm-yyyy'), '3', '04', '185', '07', '2091', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33424, to_date('05-07-2091', 'dd-mm-yyyy'), '4', '05', '186', '07', '2091', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33425, to_date('06-07-2091', 'dd-mm-yyyy'), '5', '06', '187', '07', '2091', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33426, to_date('07-07-2091', 'dd-mm-yyyy'), '6', '07', '188', '07', '2091', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33427, to_date('08-07-2091', 'dd-mm-yyyy'), '7', '08', '189', '07', '2091', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33428, to_date('09-07-2091', 'dd-mm-yyyy'), '1', '09', '190', '07', '2091', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33429, to_date('10-07-2091', 'dd-mm-yyyy'), '2', '10', '191', '07', '2091', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33430, to_date('11-07-2091', 'dd-mm-yyyy'), '3', '11', '192', '07', '2091', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33431, to_date('12-07-2091', 'dd-mm-yyyy'), '4', '12', '193', '07', '2091', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33432, to_date('13-07-2091', 'dd-mm-yyyy'), '5', '13', '194', '07', '2091', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33433, to_date('14-07-2091', 'dd-mm-yyyy'), '6', '14', '195', '07', '2091', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33434, to_date('15-07-2091', 'dd-mm-yyyy'), '7', '15', '196', '07', '2091', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33435, to_date('16-07-2091', 'dd-mm-yyyy'), '1', '16', '197', '07', '2091', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33436, to_date('17-07-2091', 'dd-mm-yyyy'), '2', '17', '198', '07', '2091', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33437, to_date('18-07-2091', 'dd-mm-yyyy'), '3', '18', '199', '07', '2091', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33438, to_date('19-07-2091', 'dd-mm-yyyy'), '4', '19', '200', '07', '2091', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33439, to_date('20-07-2091', 'dd-mm-yyyy'), '5', '20', '201', '07', '2091', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33440, to_date('21-07-2091', 'dd-mm-yyyy'), '6', '21', '202', '07', '2091', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33441, to_date('22-07-2091', 'dd-mm-yyyy'), '7', '22', '203', '07', '2091', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33442, to_date('23-07-2091', 'dd-mm-yyyy'), '1', '23', '204', '07', '2091', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33443, to_date('24-07-2091', 'dd-mm-yyyy'), '2', '24', '205', '07', '2091', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33444, to_date('25-07-2091', 'dd-mm-yyyy'), '3', '25', '206', '07', '2091', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33445, to_date('26-07-2091', 'dd-mm-yyyy'), '4', '26', '207', '07', '2091', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33446, to_date('27-07-2091', 'dd-mm-yyyy'), '5', '27', '208', '07', '2091', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33447, to_date('28-07-2091', 'dd-mm-yyyy'), '6', '28', '209', '07', '2091', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33448, to_date('29-07-2091', 'dd-mm-yyyy'), '7', '29', '210', '07', '2091', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33449, to_date('30-07-2091', 'dd-mm-yyyy'), '1', '30', '211', '07', '2091', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33450, to_date('31-07-2091', 'dd-mm-yyyy'), '2', '31', '212', '07', '2091', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33451, to_date('01-08-2091', 'dd-mm-yyyy'), '3', '01', '213', '08', '2091', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33452, to_date('02-08-2091', 'dd-mm-yyyy'), '4', '02', '214', '08', '2091', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33453, to_date('03-08-2091', 'dd-mm-yyyy'), '5', '03', '215', '08', '2091', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33454, to_date('04-08-2091', 'dd-mm-yyyy'), '6', '04', '216', '08', '2091', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33455, to_date('05-08-2091', 'dd-mm-yyyy'), '7', '05', '217', '08', '2091', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33456, to_date('06-08-2091', 'dd-mm-yyyy'), '1', '06', '218', '08', '2091', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33457, to_date('07-08-2091', 'dd-mm-yyyy'), '2', '07', '219', '08', '2091', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33458, to_date('08-08-2091', 'dd-mm-yyyy'), '3', '08', '220', '08', '2091', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33459, to_date('09-08-2091', 'dd-mm-yyyy'), '4', '09', '221', '08', '2091', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33460, to_date('10-08-2091', 'dd-mm-yyyy'), '5', '10', '222', '08', '2091', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33461, to_date('11-08-2091', 'dd-mm-yyyy'), '6', '11', '223', '08', '2091', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33462, to_date('12-08-2091', 'dd-mm-yyyy'), '7', '12', '224', '08', '2091', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33463, to_date('13-08-2091', 'dd-mm-yyyy'), '1', '13', '225', '08', '2091', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33464, to_date('14-08-2091', 'dd-mm-yyyy'), '2', '14', '226', '08', '2091', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33465, to_date('15-08-2091', 'dd-mm-yyyy'), '3', '15', '227', '08', '2091', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33466, to_date('16-08-2091', 'dd-mm-yyyy'), '4', '16', '228', '08', '2091', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33467, to_date('17-08-2091', 'dd-mm-yyyy'), '5', '17', '229', '08', '2091', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33468, to_date('18-08-2091', 'dd-mm-yyyy'), '6', '18', '230', '08', '2091', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33469, to_date('19-08-2091', 'dd-mm-yyyy'), '7', '19', '231', '08', '2091', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33470, to_date('20-08-2091', 'dd-mm-yyyy'), '1', '20', '232', '08', '2091', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34955, to_date('13-09-2095', 'dd-mm-yyyy'), '2', '13', '256', '09', '2095', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34956, to_date('14-09-2095', 'dd-mm-yyyy'), '3', '14', '257', '09', '2095', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34957, to_date('15-09-2095', 'dd-mm-yyyy'), '4', '15', '258', '09', '2095', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34958, to_date('16-09-2095', 'dd-mm-yyyy'), '5', '16', '259', '09', '2095', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34959, to_date('17-09-2095', 'dd-mm-yyyy'), '6', '17', '260', '09', '2095', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34960, to_date('18-09-2095', 'dd-mm-yyyy'), '7', '18', '261', '09', '2095', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34961, to_date('19-09-2095', 'dd-mm-yyyy'), '1', '19', '262', '09', '2095', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34962, to_date('20-09-2095', 'dd-mm-yyyy'), '2', '20', '263', '09', '2095', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34963, to_date('21-09-2095', 'dd-mm-yyyy'), '3', '21', '264', '09', '2095', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34964, to_date('22-09-2095', 'dd-mm-yyyy'), '4', '22', '265', '09', '2095', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34965, to_date('23-09-2095', 'dd-mm-yyyy'), '5', '23', '266', '09', '2095', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34966, to_date('24-09-2095', 'dd-mm-yyyy'), '6', '24', '267', '09', '2095', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34967, to_date('25-09-2095', 'dd-mm-yyyy'), '7', '25', '268', '09', '2095', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34968, to_date('26-09-2095', 'dd-mm-yyyy'), '1', '26', '269', '09', '2095', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34969, to_date('27-09-2095', 'dd-mm-yyyy'), '2', '27', '270', '09', '2095', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34970, to_date('28-09-2095', 'dd-mm-yyyy'), '3', '28', '271', '09', '2095', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34971, to_date('29-09-2095', 'dd-mm-yyyy'), '4', '29', '272', '09', '2095', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34972, to_date('30-09-2095', 'dd-mm-yyyy'), '5', '30', '273', '09', '2095', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34973, to_date('01-10-2095', 'dd-mm-yyyy'), '6', '01', '274', '10', '2095', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34974, to_date('02-10-2095', 'dd-mm-yyyy'), '7', '02', '275', '10', '2095', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34975, to_date('03-10-2095', 'dd-mm-yyyy'), '1', '03', '276', '10', '2095', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34976, to_date('04-10-2095', 'dd-mm-yyyy'), '2', '04', '277', '10', '2095', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34977, to_date('05-10-2095', 'dd-mm-yyyy'), '3', '05', '278', '10', '2095', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34978, to_date('06-10-2095', 'dd-mm-yyyy'), '4', '06', '279', '10', '2095', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34979, to_date('07-10-2095', 'dd-mm-yyyy'), '5', '07', '280', '10', '2095', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34980, to_date('08-10-2095', 'dd-mm-yyyy'), '6', '08', '281', '10', '2095', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34981, to_date('09-10-2095', 'dd-mm-yyyy'), '7', '09', '282', '10', '2095', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34982, to_date('10-10-2095', 'dd-mm-yyyy'), '1', '10', '283', '10', '2095', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34983, to_date('11-10-2095', 'dd-mm-yyyy'), '2', '11', '284', '10', '2095', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34984, to_date('12-10-2095', 'dd-mm-yyyy'), '3', '12', '285', '10', '2095', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34985, to_date('13-10-2095', 'dd-mm-yyyy'), '4', '13', '286', '10', '2095', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34986, to_date('14-10-2095', 'dd-mm-yyyy'), '5', '14', '287', '10', '2095', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34987, to_date('15-10-2095', 'dd-mm-yyyy'), '6', '15', '288', '10', '2095', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34988, to_date('16-10-2095', 'dd-mm-yyyy'), '7', '16', '289', '10', '2095', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34989, to_date('17-10-2095', 'dd-mm-yyyy'), '1', '17', '290', '10', '2095', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34990, to_date('18-10-2095', 'dd-mm-yyyy'), '2', '18', '291', '10', '2095', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34991, to_date('19-10-2095', 'dd-mm-yyyy'), '3', '19', '292', '10', '2095', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34992, to_date('20-10-2095', 'dd-mm-yyyy'), '4', '20', '293', '10', '2095', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34993, to_date('21-10-2095', 'dd-mm-yyyy'), '5', '21', '294', '10', '2095', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34994, to_date('22-10-2095', 'dd-mm-yyyy'), '6', '22', '295', '10', '2095', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34995, to_date('23-10-2095', 'dd-mm-yyyy'), '7', '23', '296', '10', '2095', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34996, to_date('24-10-2095', 'dd-mm-yyyy'), '1', '24', '297', '10', '2095', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34997, to_date('25-10-2095', 'dd-mm-yyyy'), '2', '25', '298', '10', '2095', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34998, to_date('26-10-2095', 'dd-mm-yyyy'), '3', '26', '299', '10', '2095', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34999, to_date('27-10-2095', 'dd-mm-yyyy'), '4', '27', '300', '10', '2095', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35000, to_date('28-10-2095', 'dd-mm-yyyy'), '5', '28', '301', '10', '2095', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35001, to_date('29-10-2095', 'dd-mm-yyyy'), '6', '29', '302', '10', '2095', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35002, to_date('30-10-2095', 'dd-mm-yyyy'), '7', '30', '303', '10', '2095', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35003, to_date('31-10-2095', 'dd-mm-yyyy'), '1', '31', '304', '10', '2095', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35004, to_date('01-11-2095', 'dd-mm-yyyy'), '2', '01', '305', '11', '2095', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35005, to_date('02-11-2095', 'dd-mm-yyyy'), '3', '02', '306', '11', '2095', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35006, to_date('03-11-2095', 'dd-mm-yyyy'), '4', '03', '307', '11', '2095', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35007, to_date('04-11-2095', 'dd-mm-yyyy'), '5', '04', '308', '11', '2095', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35008, to_date('05-11-2095', 'dd-mm-yyyy'), '6', '05', '309', '11', '2095', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35009, to_date('06-11-2095', 'dd-mm-yyyy'), '7', '06', '310', '11', '2095', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35010, to_date('07-11-2095', 'dd-mm-yyyy'), '1', '07', '311', '11', '2095', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35011, to_date('08-11-2095', 'dd-mm-yyyy'), '2', '08', '312', '11', '2095', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35012, to_date('09-11-2095', 'dd-mm-yyyy'), '3', '09', '313', '11', '2095', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35013, to_date('10-11-2095', 'dd-mm-yyyy'), '4', '10', '314', '11', '2095', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35014, to_date('11-11-2095', 'dd-mm-yyyy'), '5', '11', '315', '11', '2095', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35015, to_date('12-11-2095', 'dd-mm-yyyy'), '6', '12', '316', '11', '2095', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
commit;
prompt 28000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35016, to_date('13-11-2095', 'dd-mm-yyyy'), '7', '13', '317', '11', '2095', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35017, to_date('14-11-2095', 'dd-mm-yyyy'), '1', '14', '318', '11', '2095', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35018, to_date('15-11-2095', 'dd-mm-yyyy'), '2', '15', '319', '11', '2095', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35019, to_date('16-11-2095', 'dd-mm-yyyy'), '3', '16', '320', '11', '2095', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35020, to_date('17-11-2095', 'dd-mm-yyyy'), '4', '17', '321', '11', '2095', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35021, to_date('18-11-2095', 'dd-mm-yyyy'), '5', '18', '322', '11', '2095', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35022, to_date('19-11-2095', 'dd-mm-yyyy'), '6', '19', '323', '11', '2095', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35023, to_date('20-11-2095', 'dd-mm-yyyy'), '7', '20', '324', '11', '2095', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35024, to_date('21-11-2095', 'dd-mm-yyyy'), '1', '21', '325', '11', '2095', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35025, to_date('22-11-2095', 'dd-mm-yyyy'), '2', '22', '326', '11', '2095', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35026, to_date('23-11-2095', 'dd-mm-yyyy'), '3', '23', '327', '11', '2095', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35027, to_date('24-11-2095', 'dd-mm-yyyy'), '4', '24', '328', '11', '2095', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35028, to_date('25-11-2095', 'dd-mm-yyyy'), '5', '25', '329', '11', '2095', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35029, to_date('26-11-2095', 'dd-mm-yyyy'), '6', '26', '330', '11', '2095', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35030, to_date('27-11-2095', 'dd-mm-yyyy'), '7', '27', '331', '11', '2095', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35031, to_date('28-11-2095', 'dd-mm-yyyy'), '1', '28', '332', '11', '2095', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35032, to_date('29-11-2095', 'dd-mm-yyyy'), '2', '29', '333', '11', '2095', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35033, to_date('30-11-2095', 'dd-mm-yyyy'), '3', '30', '334', '11', '2095', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35034, to_date('01-12-2095', 'dd-mm-yyyy'), '4', '01', '335', '12', '2095', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35035, to_date('02-12-2095', 'dd-mm-yyyy'), '5', '02', '336', '12', '2095', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35036, to_date('03-12-2095', 'dd-mm-yyyy'), '6', '03', '337', '12', '2095', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35037, to_date('04-12-2095', 'dd-mm-yyyy'), '7', '04', '338', '12', '2095', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35038, to_date('05-12-2095', 'dd-mm-yyyy'), '1', '05', '339', '12', '2095', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35039, to_date('06-12-2095', 'dd-mm-yyyy'), '2', '06', '340', '12', '2095', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35040, to_date('07-12-2095', 'dd-mm-yyyy'), '3', '07', '341', '12', '2095', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35041, to_date('08-12-2095', 'dd-mm-yyyy'), '4', '08', '342', '12', '2095', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35042, to_date('09-12-2095', 'dd-mm-yyyy'), '5', '09', '343', '12', '2095', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35043, to_date('10-12-2095', 'dd-mm-yyyy'), '6', '10', '344', '12', '2095', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35044, to_date('11-12-2095', 'dd-mm-yyyy'), '7', '11', '345', '12', '2095', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35045, to_date('12-12-2095', 'dd-mm-yyyy'), '1', '12', '346', '12', '2095', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35046, to_date('13-12-2095', 'dd-mm-yyyy'), '2', '13', '347', '12', '2095', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35047, to_date('14-12-2095', 'dd-mm-yyyy'), '3', '14', '348', '12', '2095', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35048, to_date('15-12-2095', 'dd-mm-yyyy'), '4', '15', '349', '12', '2095', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35049, to_date('16-12-2095', 'dd-mm-yyyy'), '5', '16', '350', '12', '2095', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35050, to_date('17-12-2095', 'dd-mm-yyyy'), '6', '17', '351', '12', '2095', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35051, to_date('18-12-2095', 'dd-mm-yyyy'), '7', '18', '352', '12', '2095', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35052, to_date('19-12-2095', 'dd-mm-yyyy'), '1', '19', '353', '12', '2095', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35053, to_date('20-12-2095', 'dd-mm-yyyy'), '2', '20', '354', '12', '2095', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35054, to_date('21-12-2095', 'dd-mm-yyyy'), '3', '21', '355', '12', '2095', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35055, to_date('22-12-2095', 'dd-mm-yyyy'), '4', '22', '356', '12', '2095', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35056, to_date('23-12-2095', 'dd-mm-yyyy'), '5', '23', '357', '12', '2095', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35057, to_date('24-12-2095', 'dd-mm-yyyy'), '6', '24', '358', '12', '2095', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35058, to_date('25-12-2095', 'dd-mm-yyyy'), '7', '25', '359', '12', '2095', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35059, to_date('26-12-2095', 'dd-mm-yyyy'), '1', '26', '360', '12', '2095', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35060, to_date('27-12-2095', 'dd-mm-yyyy'), '2', '27', '361', '12', '2095', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33471, to_date('21-08-2091', 'dd-mm-yyyy'), '2', '21', '233', '08', '2091', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33472, to_date('22-08-2091', 'dd-mm-yyyy'), '3', '22', '234', '08', '2091', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33473, to_date('23-08-2091', 'dd-mm-yyyy'), '4', '23', '235', '08', '2091', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33474, to_date('24-08-2091', 'dd-mm-yyyy'), '5', '24', '236', '08', '2091', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33475, to_date('25-08-2091', 'dd-mm-yyyy'), '6', '25', '237', '08', '2091', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33476, to_date('26-08-2091', 'dd-mm-yyyy'), '7', '26', '238', '08', '2091', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33477, to_date('27-08-2091', 'dd-mm-yyyy'), '1', '27', '239', '08', '2091', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33478, to_date('28-08-2091', 'dd-mm-yyyy'), '2', '28', '240', '08', '2091', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33479, to_date('29-08-2091', 'dd-mm-yyyy'), '3', '29', '241', '08', '2091', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33480, to_date('30-08-2091', 'dd-mm-yyyy'), '4', '30', '242', '08', '2091', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33481, to_date('31-08-2091', 'dd-mm-yyyy'), '5', '31', '243', '08', '2091', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33482, to_date('01-09-2091', 'dd-mm-yyyy'), '6', '01', '244', '09', '2091', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33483, to_date('02-09-2091', 'dd-mm-yyyy'), '7', '02', '245', '09', '2091', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33484, to_date('03-09-2091', 'dd-mm-yyyy'), '1', '03', '246', '09', '2091', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33485, to_date('04-09-2091', 'dd-mm-yyyy'), '2', '04', '247', '09', '2091', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33486, to_date('05-09-2091', 'dd-mm-yyyy'), '3', '05', '248', '09', '2091', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33487, to_date('06-09-2091', 'dd-mm-yyyy'), '4', '06', '249', '09', '2091', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33488, to_date('07-09-2091', 'dd-mm-yyyy'), '5', '07', '250', '09', '2091', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33489, to_date('08-09-2091', 'dd-mm-yyyy'), '6', '08', '251', '09', '2091', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33490, to_date('09-09-2091', 'dd-mm-yyyy'), '7', '09', '252', '09', '2091', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33491, to_date('10-09-2091', 'dd-mm-yyyy'), '1', '10', '253', '09', '2091', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33492, to_date('11-09-2091', 'dd-mm-yyyy'), '2', '11', '254', '09', '2091', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33493, to_date('12-09-2091', 'dd-mm-yyyy'), '3', '12', '255', '09', '2091', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33494, to_date('13-09-2091', 'dd-mm-yyyy'), '4', '13', '256', '09', '2091', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33495, to_date('14-09-2091', 'dd-mm-yyyy'), '5', '14', '257', '09', '2091', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33496, to_date('15-09-2091', 'dd-mm-yyyy'), '6', '15', '258', '09', '2091', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33497, to_date('16-09-2091', 'dd-mm-yyyy'), '7', '16', '259', '09', '2091', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33498, to_date('17-09-2091', 'dd-mm-yyyy'), '1', '17', '260', '09', '2091', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33499, to_date('18-09-2091', 'dd-mm-yyyy'), '2', '18', '261', '09', '2091', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33500, to_date('19-09-2091', 'dd-mm-yyyy'), '3', '19', '262', '09', '2091', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33501, to_date('20-09-2091', 'dd-mm-yyyy'), '4', '20', '263', '09', '2091', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33502, to_date('21-09-2091', 'dd-mm-yyyy'), '5', '21', '264', '09', '2091', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33503, to_date('22-09-2091', 'dd-mm-yyyy'), '6', '22', '265', '09', '2091', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33504, to_date('23-09-2091', 'dd-mm-yyyy'), '7', '23', '266', '09', '2091', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33505, to_date('24-09-2091', 'dd-mm-yyyy'), '1', '24', '267', '09', '2091', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33506, to_date('25-09-2091', 'dd-mm-yyyy'), '2', '25', '268', '09', '2091', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33507, to_date('26-09-2091', 'dd-mm-yyyy'), '3', '26', '269', '09', '2091', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33508, to_date('27-09-2091', 'dd-mm-yyyy'), '4', '27', '270', '09', '2091', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33509, to_date('28-09-2091', 'dd-mm-yyyy'), '5', '28', '271', '09', '2091', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33510, to_date('29-09-2091', 'dd-mm-yyyy'), '6', '29', '272', '09', '2091', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33511, to_date('30-09-2091', 'dd-mm-yyyy'), '7', '30', '273', '09', '2091', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33512, to_date('01-10-2091', 'dd-mm-yyyy'), '1', '01', '274', '10', '2091', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33513, to_date('02-10-2091', 'dd-mm-yyyy'), '2', '02', '275', '10', '2091', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33514, to_date('03-10-2091', 'dd-mm-yyyy'), '3', '03', '276', '10', '2091', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33515, to_date('04-10-2091', 'dd-mm-yyyy'), '4', '04', '277', '10', '2091', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33516, to_date('05-10-2091', 'dd-mm-yyyy'), '5', '05', '278', '10', '2091', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33517, to_date('06-10-2091', 'dd-mm-yyyy'), '6', '06', '279', '10', '2091', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33518, to_date('07-10-2091', 'dd-mm-yyyy'), '7', '07', '280', '10', '2091', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33519, to_date('08-10-2091', 'dd-mm-yyyy'), '1', '08', '281', '10', '2091', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33520, to_date('09-10-2091', 'dd-mm-yyyy'), '2', '09', '282', '10', '2091', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33521, to_date('10-10-2091', 'dd-mm-yyyy'), '3', '10', '283', '10', '2091', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33522, to_date('11-10-2091', 'dd-mm-yyyy'), '4', '11', '284', '10', '2091', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33523, to_date('12-10-2091', 'dd-mm-yyyy'), '5', '12', '285', '10', '2091', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33524, to_date('13-10-2091', 'dd-mm-yyyy'), '6', '13', '286', '10', '2091', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33525, to_date('14-10-2091', 'dd-mm-yyyy'), '7', '14', '287', '10', '2091', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33526, to_date('15-10-2091', 'dd-mm-yyyy'), '1', '15', '288', '10', '2091', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33527, to_date('16-10-2091', 'dd-mm-yyyy'), '2', '16', '289', '10', '2091', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33528, to_date('17-10-2091', 'dd-mm-yyyy'), '3', '17', '290', '10', '2091', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33529, to_date('18-10-2091', 'dd-mm-yyyy'), '4', '18', '291', '10', '2091', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33530, to_date('19-10-2091', 'dd-mm-yyyy'), '5', '19', '292', '10', '2091', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33531, to_date('20-10-2091', 'dd-mm-yyyy'), '6', '20', '293', '10', '2091', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33532, to_date('21-10-2091', 'dd-mm-yyyy'), '7', '21', '294', '10', '2091', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33533, to_date('22-10-2091', 'dd-mm-yyyy'), '1', '22', '295', '10', '2091', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33534, to_date('23-10-2091', 'dd-mm-yyyy'), '2', '23', '296', '10', '2091', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33535, to_date('24-10-2091', 'dd-mm-yyyy'), '3', '24', '297', '10', '2091', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33536, to_date('25-10-2091', 'dd-mm-yyyy'), '4', '25', '298', '10', '2091', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33537, to_date('26-10-2091', 'dd-mm-yyyy'), '5', '26', '299', '10', '2091', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33538, to_date('27-10-2091', 'dd-mm-yyyy'), '6', '27', '300', '10', '2091', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33539, to_date('28-10-2091', 'dd-mm-yyyy'), '7', '28', '301', '10', '2091', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33540, to_date('29-10-2091', 'dd-mm-yyyy'), '1', '29', '302', '10', '2091', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33541, to_date('30-10-2091', 'dd-mm-yyyy'), '2', '30', '303', '10', '2091', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33542, to_date('31-10-2091', 'dd-mm-yyyy'), '3', '31', '304', '10', '2091', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33543, to_date('01-11-2091', 'dd-mm-yyyy'), '4', '01', '305', '11', '2091', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33544, to_date('02-11-2091', 'dd-mm-yyyy'), '5', '02', '306', '11', '2091', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33545, to_date('03-11-2091', 'dd-mm-yyyy'), '6', '03', '307', '11', '2091', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33546, to_date('04-11-2091', 'dd-mm-yyyy'), '7', '04', '308', '11', '2091', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33547, to_date('05-11-2091', 'dd-mm-yyyy'), '1', '05', '309', '11', '2091', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33548, to_date('06-11-2091', 'dd-mm-yyyy'), '2', '06', '310', '11', '2091', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33549, to_date('07-11-2091', 'dd-mm-yyyy'), '3', '07', '311', '11', '2091', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33550, to_date('08-11-2091', 'dd-mm-yyyy'), '4', '08', '312', '11', '2091', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33551, to_date('09-11-2091', 'dd-mm-yyyy'), '5', '09', '313', '11', '2091', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33552, to_date('10-11-2091', 'dd-mm-yyyy'), '6', '10', '314', '11', '2091', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33553, to_date('11-11-2091', 'dd-mm-yyyy'), '7', '11', '315', '11', '2091', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33554, to_date('12-11-2091', 'dd-mm-yyyy'), '1', '12', '316', '11', '2091', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33555, to_date('13-11-2091', 'dd-mm-yyyy'), '2', '13', '317', '11', '2091', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33556, to_date('14-11-2091', 'dd-mm-yyyy'), '3', '14', '318', '11', '2091', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33557, to_date('15-11-2091', 'dd-mm-yyyy'), '4', '15', '319', '11', '2091', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33558, to_date('16-11-2091', 'dd-mm-yyyy'), '5', '16', '320', '11', '2091', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33559, to_date('17-11-2091', 'dd-mm-yyyy'), '6', '17', '321', '11', '2091', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33560, to_date('18-11-2091', 'dd-mm-yyyy'), '7', '18', '322', '11', '2091', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33561, to_date('19-11-2091', 'dd-mm-yyyy'), '1', '19', '323', '11', '2091', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33562, to_date('20-11-2091', 'dd-mm-yyyy'), '2', '20', '324', '11', '2091', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33563, to_date('21-11-2091', 'dd-mm-yyyy'), '3', '21', '325', '11', '2091', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33564, to_date('22-11-2091', 'dd-mm-yyyy'), '4', '22', '326', '11', '2091', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33565, to_date('23-11-2091', 'dd-mm-yyyy'), '5', '23', '327', '11', '2091', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33566, to_date('24-11-2091', 'dd-mm-yyyy'), '6', '24', '328', '11', '2091', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33567, to_date('25-11-2091', 'dd-mm-yyyy'), '7', '25', '329', '11', '2091', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33568, to_date('26-11-2091', 'dd-mm-yyyy'), '1', '26', '330', '11', '2091', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33569, to_date('27-11-2091', 'dd-mm-yyyy'), '2', '27', '331', '11', '2091', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33570, to_date('28-11-2091', 'dd-mm-yyyy'), '3', '28', '332', '11', '2091', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33571, to_date('29-11-2091', 'dd-mm-yyyy'), '4', '29', '333', '11', '2091', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33572, to_date('30-11-2091', 'dd-mm-yyyy'), '5', '30', '334', '11', '2091', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33573, to_date('01-12-2091', 'dd-mm-yyyy'), '6', '01', '335', '12', '2091', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33574, to_date('02-12-2091', 'dd-mm-yyyy'), '7', '02', '336', '12', '2091', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33575, to_date('03-12-2091', 'dd-mm-yyyy'), '1', '03', '337', '12', '2091', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33576, to_date('04-12-2091', 'dd-mm-yyyy'), '2', '04', '338', '12', '2091', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35061, to_date('28-12-2095', 'dd-mm-yyyy'), '3', '28', '362', '12', '2095', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35062, to_date('29-12-2095', 'dd-mm-yyyy'), '4', '29', '363', '12', '2095', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35063, to_date('30-12-2095', 'dd-mm-yyyy'), '5', '30', '364', '12', '2095', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35064, to_date('31-12-2095', 'dd-mm-yyyy'), '6', '31', '365', '12', '2095', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35065, to_date('01-01-2096', 'dd-mm-yyyy'), '7', '01', '001', '01', '2096', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35066, to_date('02-01-2096', 'dd-mm-yyyy'), '1', '02', '002', '01', '2096', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35067, to_date('03-01-2096', 'dd-mm-yyyy'), '2', '03', '003', '01', '2096', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35068, to_date('04-01-2096', 'dd-mm-yyyy'), '3', '04', '004', '01', '2096', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35069, to_date('05-01-2096', 'dd-mm-yyyy'), '4', '05', '005', '01', '2096', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35070, to_date('06-01-2096', 'dd-mm-yyyy'), '5', '06', '006', '01', '2096', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35071, to_date('07-01-2096', 'dd-mm-yyyy'), '6', '07', '007', '01', '2096', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35072, to_date('08-01-2096', 'dd-mm-yyyy'), '7', '08', '008', '01', '2096', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35073, to_date('09-01-2096', 'dd-mm-yyyy'), '1', '09', '009', '01', '2096', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35074, to_date('10-01-2096', 'dd-mm-yyyy'), '2', '10', '010', '01', '2096', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35075, to_date('11-01-2096', 'dd-mm-yyyy'), '3', '11', '011', '01', '2096', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35076, to_date('12-01-2096', 'dd-mm-yyyy'), '4', '12', '012', '01', '2096', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35077, to_date('13-01-2096', 'dd-mm-yyyy'), '5', '13', '013', '01', '2096', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35078, to_date('14-01-2096', 'dd-mm-yyyy'), '6', '14', '014', '01', '2096', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35079, to_date('15-01-2096', 'dd-mm-yyyy'), '7', '15', '015', '01', '2096', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35080, to_date('16-01-2096', 'dd-mm-yyyy'), '1', '16', '016', '01', '2096', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35081, to_date('17-01-2096', 'dd-mm-yyyy'), '2', '17', '017', '01', '2096', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35082, to_date('18-01-2096', 'dd-mm-yyyy'), '3', '18', '018', '01', '2096', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35083, to_date('19-01-2096', 'dd-mm-yyyy'), '4', '19', '019', '01', '2096', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35084, to_date('20-01-2096', 'dd-mm-yyyy'), '5', '20', '020', '01', '2096', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35085, to_date('21-01-2096', 'dd-mm-yyyy'), '6', '21', '021', '01', '2096', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35086, to_date('22-01-2096', 'dd-mm-yyyy'), '7', '22', '022', '01', '2096', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35087, to_date('23-01-2096', 'dd-mm-yyyy'), '1', '23', '023', '01', '2096', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35088, to_date('24-01-2096', 'dd-mm-yyyy'), '2', '24', '024', '01', '2096', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35089, to_date('25-01-2096', 'dd-mm-yyyy'), '3', '25', '025', '01', '2096', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35090, to_date('26-01-2096', 'dd-mm-yyyy'), '4', '26', '026', '01', '2096', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35091, to_date('27-01-2096', 'dd-mm-yyyy'), '5', '27', '027', '01', '2096', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35092, to_date('28-01-2096', 'dd-mm-yyyy'), '6', '28', '028', '01', '2096', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35093, to_date('29-01-2096', 'dd-mm-yyyy'), '7', '29', '029', '01', '2096', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35094, to_date('30-01-2096', 'dd-mm-yyyy'), '1', '30', '030', '01', '2096', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35095, to_date('31-01-2096', 'dd-mm-yyyy'), '2', '31', '031', '01', '2096', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35096, to_date('01-02-2096', 'dd-mm-yyyy'), '3', '01', '032', '02', '2096', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35097, to_date('02-02-2096', 'dd-mm-yyyy'), '4', '02', '033', '02', '2096', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35098, to_date('03-02-2096', 'dd-mm-yyyy'), '5', '03', '034', '02', '2096', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35099, to_date('04-02-2096', 'dd-mm-yyyy'), '6', '04', '035', '02', '2096', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35100, to_date('05-02-2096', 'dd-mm-yyyy'), '7', '05', '036', '02', '2096', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35101, to_date('06-02-2096', 'dd-mm-yyyy'), '1', '06', '037', '02', '2096', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35102, to_date('07-02-2096', 'dd-mm-yyyy'), '2', '07', '038', '02', '2096', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35103, to_date('08-02-2096', 'dd-mm-yyyy'), '3', '08', '039', '02', '2096', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35104, to_date('09-02-2096', 'dd-mm-yyyy'), '4', '09', '040', '02', '2096', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35105, to_date('10-02-2096', 'dd-mm-yyyy'), '5', '10', '041', '02', '2096', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35106, to_date('11-02-2096', 'dd-mm-yyyy'), '6', '11', '042', '02', '2096', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35107, to_date('12-02-2096', 'dd-mm-yyyy'), '7', '12', '043', '02', '2096', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35108, to_date('13-02-2096', 'dd-mm-yyyy'), '1', '13', '044', '02', '2096', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35109, to_date('14-02-2096', 'dd-mm-yyyy'), '2', '14', '045', '02', '2096', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35110, to_date('15-02-2096', 'dd-mm-yyyy'), '3', '15', '046', '02', '2096', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35111, to_date('16-02-2096', 'dd-mm-yyyy'), '4', '16', '047', '02', '2096', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35112, to_date('17-02-2096', 'dd-mm-yyyy'), '5', '17', '048', '02', '2096', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35113, to_date('18-02-2096', 'dd-mm-yyyy'), '6', '18', '049', '02', '2096', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35114, to_date('19-02-2096', 'dd-mm-yyyy'), '7', '19', '050', '02', '2096', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35115, to_date('20-02-2096', 'dd-mm-yyyy'), '1', '20', '051', '02', '2096', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35116, to_date('21-02-2096', 'dd-mm-yyyy'), '2', '21', '052', '02', '2096', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35117, to_date('22-02-2096', 'dd-mm-yyyy'), '3', '22', '053', '02', '2096', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35118, to_date('23-02-2096', 'dd-mm-yyyy'), '4', '23', '054', '02', '2096', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35119, to_date('24-02-2096', 'dd-mm-yyyy'), '5', '24', '055', '02', '2096', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35120, to_date('25-02-2096', 'dd-mm-yyyy'), '6', '25', '056', '02', '2096', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35121, to_date('26-02-2096', 'dd-mm-yyyy'), '7', '26', '057', '02', '2096', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35122, to_date('27-02-2096', 'dd-mm-yyyy'), '1', '27', '058', '02', '2096', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35123, to_date('28-02-2096', 'dd-mm-yyyy'), '2', '28', '059', '02', '2096', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35124, to_date('29-02-2096', 'dd-mm-yyyy'), '3', '29', '060', '02', '2096', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35125, to_date('01-03-2096', 'dd-mm-yyyy'), '4', '01', '061', '03', '2096', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35126, to_date('02-03-2096', 'dd-mm-yyyy'), '5', '02', '062', '03', '2096', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35127, to_date('03-03-2096', 'dd-mm-yyyy'), '6', '03', '063', '03', '2096', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35128, to_date('04-03-2096', 'dd-mm-yyyy'), '7', '04', '064', '03', '2096', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35129, to_date('05-03-2096', 'dd-mm-yyyy'), '1', '05', '065', '03', '2096', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35130, to_date('06-03-2096', 'dd-mm-yyyy'), '2', '06', '066', '03', '2096', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35131, to_date('07-03-2096', 'dd-mm-yyyy'), '3', '07', '067', '03', '2096', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35132, to_date('08-03-2096', 'dd-mm-yyyy'), '4', '08', '068', '03', '2096', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35133, to_date('09-03-2096', 'dd-mm-yyyy'), '5', '09', '069', '03', '2096', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35134, to_date('10-03-2096', 'dd-mm-yyyy'), '6', '10', '070', '03', '2096', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35135, to_date('11-03-2096', 'dd-mm-yyyy'), '7', '11', '071', '03', '2096', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35136, to_date('12-03-2096', 'dd-mm-yyyy'), '1', '12', '072', '03', '2096', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35137, to_date('13-03-2096', 'dd-mm-yyyy'), '2', '13', '073', '03', '2096', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35138, to_date('14-03-2096', 'dd-mm-yyyy'), '3', '14', '074', '03', '2096', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35139, to_date('15-03-2096', 'dd-mm-yyyy'), '4', '15', '075', '03', '2096', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35140, to_date('16-03-2096', 'dd-mm-yyyy'), '5', '16', '076', '03', '2096', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35141, to_date('17-03-2096', 'dd-mm-yyyy'), '6', '17', '077', '03', '2096', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35142, to_date('18-03-2096', 'dd-mm-yyyy'), '7', '18', '078', '03', '2096', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35143, to_date('19-03-2096', 'dd-mm-yyyy'), '1', '19', '079', '03', '2096', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35144, to_date('20-03-2096', 'dd-mm-yyyy'), '2', '20', '080', '03', '2096', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35145, to_date('21-03-2096', 'dd-mm-yyyy'), '3', '21', '081', '03', '2096', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35146, to_date('22-03-2096', 'dd-mm-yyyy'), '4', '22', '082', '03', '2096', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35147, to_date('23-03-2096', 'dd-mm-yyyy'), '5', '23', '083', '03', '2096', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35148, to_date('24-03-2096', 'dd-mm-yyyy'), '6', '24', '084', '03', '2096', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35149, to_date('25-03-2096', 'dd-mm-yyyy'), '7', '25', '085', '03', '2096', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35150, to_date('26-03-2096', 'dd-mm-yyyy'), '1', '26', '086', '03', '2096', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35151, to_date('27-03-2096', 'dd-mm-yyyy'), '2', '27', '087', '03', '2096', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35152, to_date('28-03-2096', 'dd-mm-yyyy'), '3', '28', '088', '03', '2096', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35153, to_date('29-03-2096', 'dd-mm-yyyy'), '4', '29', '089', '03', '2096', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35154, to_date('30-03-2096', 'dd-mm-yyyy'), '5', '30', '090', '03', '2096', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35155, to_date('31-03-2096', 'dd-mm-yyyy'), '6', '31', '091', '03', '2096', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35156, to_date('01-04-2096', 'dd-mm-yyyy'), '7', '01', '092', '04', '2096', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35157, to_date('02-04-2096', 'dd-mm-yyyy'), '1', '02', '093', '04', '2096', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35158, to_date('03-04-2096', 'dd-mm-yyyy'), '2', '03', '094', '04', '2096', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35159, to_date('04-04-2096', 'dd-mm-yyyy'), '3', '04', '095', '04', '2096', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35160, to_date('05-04-2096', 'dd-mm-yyyy'), '4', '05', '096', '04', '2096', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35161, to_date('06-04-2096', 'dd-mm-yyyy'), '5', '06', '097', '04', '2096', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35162, to_date('07-04-2096', 'dd-mm-yyyy'), '6', '07', '098', '04', '2096', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35163, to_date('08-04-2096', 'dd-mm-yyyy'), '7', '08', '099', '04', '2096', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35164, to_date('09-04-2096', 'dd-mm-yyyy'), '1', '09', '100', '04', '2096', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35165, to_date('10-04-2096', 'dd-mm-yyyy'), '2', '10', '101', '04', '2096', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35166, to_date('11-04-2096', 'dd-mm-yyyy'), '3', '11', '102', '04', '2096', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33577, to_date('05-12-2091', 'dd-mm-yyyy'), '3', '05', '339', '12', '2091', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33578, to_date('06-12-2091', 'dd-mm-yyyy'), '4', '06', '340', '12', '2091', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33579, to_date('07-12-2091', 'dd-mm-yyyy'), '5', '07', '341', '12', '2091', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33580, to_date('08-12-2091', 'dd-mm-yyyy'), '6', '08', '342', '12', '2091', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33581, to_date('09-12-2091', 'dd-mm-yyyy'), '7', '09', '343', '12', '2091', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33582, to_date('10-12-2091', 'dd-mm-yyyy'), '1', '10', '344', '12', '2091', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33583, to_date('11-12-2091', 'dd-mm-yyyy'), '2', '11', '345', '12', '2091', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33584, to_date('12-12-2091', 'dd-mm-yyyy'), '3', '12', '346', '12', '2091', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33585, to_date('13-12-2091', 'dd-mm-yyyy'), '4', '13', '347', '12', '2091', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33586, to_date('14-12-2091', 'dd-mm-yyyy'), '5', '14', '348', '12', '2091', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33587, to_date('15-12-2091', 'dd-mm-yyyy'), '6', '15', '349', '12', '2091', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33588, to_date('16-12-2091', 'dd-mm-yyyy'), '7', '16', '350', '12', '2091', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33589, to_date('17-12-2091', 'dd-mm-yyyy'), '1', '17', '351', '12', '2091', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33590, to_date('18-12-2091', 'dd-mm-yyyy'), '2', '18', '352', '12', '2091', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33591, to_date('19-12-2091', 'dd-mm-yyyy'), '3', '19', '353', '12', '2091', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33592, to_date('20-12-2091', 'dd-mm-yyyy'), '4', '20', '354', '12', '2091', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33593, to_date('21-12-2091', 'dd-mm-yyyy'), '5', '21', '355', '12', '2091', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33594, to_date('22-12-2091', 'dd-mm-yyyy'), '6', '22', '356', '12', '2091', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33595, to_date('23-12-2091', 'dd-mm-yyyy'), '7', '23', '357', '12', '2091', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33596, to_date('24-12-2091', 'dd-mm-yyyy'), '1', '24', '358', '12', '2091', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33597, to_date('25-12-2091', 'dd-mm-yyyy'), '2', '25', '359', '12', '2091', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33598, to_date('26-12-2091', 'dd-mm-yyyy'), '3', '26', '360', '12', '2091', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33599, to_date('27-12-2091', 'dd-mm-yyyy'), '4', '27', '361', '12', '2091', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33600, to_date('28-12-2091', 'dd-mm-yyyy'), '5', '28', '362', '12', '2091', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33601, to_date('29-12-2091', 'dd-mm-yyyy'), '6', '29', '363', '12', '2091', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33602, to_date('30-12-2091', 'dd-mm-yyyy'), '7', '30', '364', '12', '2091', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33603, to_date('31-12-2091', 'dd-mm-yyyy'), '1', '31', '365', '12', '2091', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33604, to_date('01-01-2092', 'dd-mm-yyyy'), '2', '01', '001', '01', '2092', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33605, to_date('02-01-2092', 'dd-mm-yyyy'), '3', '02', '002', '01', '2092', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33606, to_date('03-01-2092', 'dd-mm-yyyy'), '4', '03', '003', '01', '2092', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33607, to_date('04-01-2092', 'dd-mm-yyyy'), '5', '04', '004', '01', '2092', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33608, to_date('05-01-2092', 'dd-mm-yyyy'), '6', '05', '005', '01', '2092', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33609, to_date('06-01-2092', 'dd-mm-yyyy'), '7', '06', '006', '01', '2092', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33610, to_date('07-01-2092', 'dd-mm-yyyy'), '1', '07', '007', '01', '2092', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33611, to_date('08-01-2092', 'dd-mm-yyyy'), '2', '08', '008', '01', '2092', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33612, to_date('09-01-2092', 'dd-mm-yyyy'), '3', '09', '009', '01', '2092', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33613, to_date('10-01-2092', 'dd-mm-yyyy'), '4', '10', '010', '01', '2092', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33614, to_date('11-01-2092', 'dd-mm-yyyy'), '5', '11', '011', '01', '2092', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33615, to_date('12-01-2092', 'dd-mm-yyyy'), '6', '12', '012', '01', '2092', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33616, to_date('13-01-2092', 'dd-mm-yyyy'), '7', '13', '013', '01', '2092', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33617, to_date('14-01-2092', 'dd-mm-yyyy'), '1', '14', '014', '01', '2092', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33618, to_date('15-01-2092', 'dd-mm-yyyy'), '2', '15', '015', '01', '2092', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33619, to_date('16-01-2092', 'dd-mm-yyyy'), '3', '16', '016', '01', '2092', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33620, to_date('17-01-2092', 'dd-mm-yyyy'), '4', '17', '017', '01', '2092', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33621, to_date('18-01-2092', 'dd-mm-yyyy'), '5', '18', '018', '01', '2092', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33622, to_date('19-01-2092', 'dd-mm-yyyy'), '6', '19', '019', '01', '2092', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33623, to_date('20-01-2092', 'dd-mm-yyyy'), '7', '20', '020', '01', '2092', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33624, to_date('21-01-2092', 'dd-mm-yyyy'), '1', '21', '021', '01', '2092', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33625, to_date('22-01-2092', 'dd-mm-yyyy'), '2', '22', '022', '01', '2092', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33626, to_date('23-01-2092', 'dd-mm-yyyy'), '3', '23', '023', '01', '2092', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33627, to_date('24-01-2092', 'dd-mm-yyyy'), '4', '24', '024', '01', '2092', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33628, to_date('25-01-2092', 'dd-mm-yyyy'), '5', '25', '025', '01', '2092', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33629, to_date('26-01-2092', 'dd-mm-yyyy'), '6', '26', '026', '01', '2092', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33630, to_date('27-01-2092', 'dd-mm-yyyy'), '7', '27', '027', '01', '2092', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33631, to_date('28-01-2092', 'dd-mm-yyyy'), '1', '28', '028', '01', '2092', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33632, to_date('29-01-2092', 'dd-mm-yyyy'), '2', '29', '029', '01', '2092', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33633, to_date('30-01-2092', 'dd-mm-yyyy'), '3', '30', '030', '01', '2092', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33634, to_date('31-01-2092', 'dd-mm-yyyy'), '4', '31', '031', '01', '2092', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33635, to_date('01-02-2092', 'dd-mm-yyyy'), '5', '01', '032', '02', '2092', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33636, to_date('02-02-2092', 'dd-mm-yyyy'), '6', '02', '033', '02', '2092', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33637, to_date('03-02-2092', 'dd-mm-yyyy'), '7', '03', '034', '02', '2092', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33638, to_date('04-02-2092', 'dd-mm-yyyy'), '1', '04', '035', '02', '2092', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33639, to_date('05-02-2092', 'dd-mm-yyyy'), '2', '05', '036', '02', '2092', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33640, to_date('06-02-2092', 'dd-mm-yyyy'), '3', '06', '037', '02', '2092', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33641, to_date('07-02-2092', 'dd-mm-yyyy'), '4', '07', '038', '02', '2092', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33642, to_date('08-02-2092', 'dd-mm-yyyy'), '5', '08', '039', '02', '2092', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33643, to_date('09-02-2092', 'dd-mm-yyyy'), '6', '09', '040', '02', '2092', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33644, to_date('10-02-2092', 'dd-mm-yyyy'), '7', '10', '041', '02', '2092', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33645, to_date('11-02-2092', 'dd-mm-yyyy'), '1', '11', '042', '02', '2092', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33646, to_date('12-02-2092', 'dd-mm-yyyy'), '2', '12', '043', '02', '2092', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33647, to_date('13-02-2092', 'dd-mm-yyyy'), '3', '13', '044', '02', '2092', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33648, to_date('14-02-2092', 'dd-mm-yyyy'), '4', '14', '045', '02', '2092', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33649, to_date('15-02-2092', 'dd-mm-yyyy'), '5', '15', '046', '02', '2092', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33650, to_date('16-02-2092', 'dd-mm-yyyy'), '6', '16', '047', '02', '2092', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33651, to_date('17-02-2092', 'dd-mm-yyyy'), '7', '17', '048', '02', '2092', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33652, to_date('18-02-2092', 'dd-mm-yyyy'), '1', '18', '049', '02', '2092', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33653, to_date('19-02-2092', 'dd-mm-yyyy'), '2', '19', '050', '02', '2092', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33654, to_date('20-02-2092', 'dd-mm-yyyy'), '3', '20', '051', '02', '2092', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33655, to_date('21-02-2092', 'dd-mm-yyyy'), '4', '21', '052', '02', '2092', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33656, to_date('22-02-2092', 'dd-mm-yyyy'), '5', '22', '053', '02', '2092', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33657, to_date('23-02-2092', 'dd-mm-yyyy'), '6', '23', '054', '02', '2092', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33658, to_date('24-02-2092', 'dd-mm-yyyy'), '7', '24', '055', '02', '2092', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33659, to_date('25-02-2092', 'dd-mm-yyyy'), '1', '25', '056', '02', '2092', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33660, to_date('26-02-2092', 'dd-mm-yyyy'), '2', '26', '057', '02', '2092', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33661, to_date('27-02-2092', 'dd-mm-yyyy'), '3', '27', '058', '02', '2092', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33662, to_date('28-02-2092', 'dd-mm-yyyy'), '4', '28', '059', '02', '2092', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33663, to_date('29-02-2092', 'dd-mm-yyyy'), '5', '29', '060', '02', '2092', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33664, to_date('01-03-2092', 'dd-mm-yyyy'), '6', '01', '061', '03', '2092', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33665, to_date('02-03-2092', 'dd-mm-yyyy'), '7', '02', '062', '03', '2092', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33666, to_date('03-03-2092', 'dd-mm-yyyy'), '1', '03', '063', '03', '2092', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33667, to_date('04-03-2092', 'dd-mm-yyyy'), '2', '04', '064', '03', '2092', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33668, to_date('05-03-2092', 'dd-mm-yyyy'), '3', '05', '065', '03', '2092', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33669, to_date('06-03-2092', 'dd-mm-yyyy'), '4', '06', '066', '03', '2092', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33670, to_date('07-03-2092', 'dd-mm-yyyy'), '5', '07', '067', '03', '2092', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33671, to_date('08-03-2092', 'dd-mm-yyyy'), '6', '08', '068', '03', '2092', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33672, to_date('09-03-2092', 'dd-mm-yyyy'), '7', '09', '069', '03', '2092', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33673, to_date('10-03-2092', 'dd-mm-yyyy'), '1', '10', '070', '03', '2092', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33674, to_date('11-03-2092', 'dd-mm-yyyy'), '2', '11', '071', '03', '2092', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33675, to_date('12-03-2092', 'dd-mm-yyyy'), '3', '12', '072', '03', '2092', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33676, to_date('13-03-2092', 'dd-mm-yyyy'), '4', '13', '073', '03', '2092', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33677, to_date('14-03-2092', 'dd-mm-yyyy'), '5', '14', '074', '03', '2092', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33678, to_date('15-03-2092', 'dd-mm-yyyy'), '6', '15', '075', '03', '2092', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33679, to_date('16-03-2092', 'dd-mm-yyyy'), '7', '16', '076', '03', '2092', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33680, to_date('17-03-2092', 'dd-mm-yyyy'), '1', '17', '077', '03', '2092', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33681, to_date('18-03-2092', 'dd-mm-yyyy'), '2', '18', '078', '03', '2092', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33682, to_date('19-03-2092', 'dd-mm-yyyy'), '3', '19', '079', '03', '2092', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35167, to_date('12-04-2096', 'dd-mm-yyyy'), '4', '12', '103', '04', '2096', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35168, to_date('13-04-2096', 'dd-mm-yyyy'), '5', '13', '104', '04', '2096', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35169, to_date('14-04-2096', 'dd-mm-yyyy'), '6', '14', '105', '04', '2096', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35170, to_date('15-04-2096', 'dd-mm-yyyy'), '7', '15', '106', '04', '2096', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35171, to_date('16-04-2096', 'dd-mm-yyyy'), '1', '16', '107', '04', '2096', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35172, to_date('17-04-2096', 'dd-mm-yyyy'), '2', '17', '108', '04', '2096', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35173, to_date('18-04-2096', 'dd-mm-yyyy'), '3', '18', '109', '04', '2096', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35174, to_date('19-04-2096', 'dd-mm-yyyy'), '4', '19', '110', '04', '2096', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35175, to_date('20-04-2096', 'dd-mm-yyyy'), '5', '20', '111', '04', '2096', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35176, to_date('21-04-2096', 'dd-mm-yyyy'), '6', '21', '112', '04', '2096', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35177, to_date('22-04-2096', 'dd-mm-yyyy'), '7', '22', '113', '04', '2096', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35178, to_date('23-04-2096', 'dd-mm-yyyy'), '1', '23', '114', '04', '2096', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35179, to_date('24-04-2096', 'dd-mm-yyyy'), '2', '24', '115', '04', '2096', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35180, to_date('25-04-2096', 'dd-mm-yyyy'), '3', '25', '116', '04', '2096', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35181, to_date('26-04-2096', 'dd-mm-yyyy'), '4', '26', '117', '04', '2096', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35182, to_date('27-04-2096', 'dd-mm-yyyy'), '5', '27', '118', '04', '2096', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35183, to_date('28-04-2096', 'dd-mm-yyyy'), '6', '28', '119', '04', '2096', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35184, to_date('29-04-2096', 'dd-mm-yyyy'), '7', '29', '120', '04', '2096', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35185, to_date('30-04-2096', 'dd-mm-yyyy'), '1', '30', '121', '04', '2096', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35186, to_date('01-05-2096', 'dd-mm-yyyy'), '2', '01', '122', '05', '2096', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35187, to_date('02-05-2096', 'dd-mm-yyyy'), '3', '02', '123', '05', '2096', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35188, to_date('03-05-2096', 'dd-mm-yyyy'), '4', '03', '124', '05', '2096', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35189, to_date('04-05-2096', 'dd-mm-yyyy'), '5', '04', '125', '05', '2096', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35190, to_date('05-05-2096', 'dd-mm-yyyy'), '6', '05', '126', '05', '2096', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35191, to_date('06-05-2096', 'dd-mm-yyyy'), '7', '06', '127', '05', '2096', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35192, to_date('07-05-2096', 'dd-mm-yyyy'), '1', '07', '128', '05', '2096', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35193, to_date('08-05-2096', 'dd-mm-yyyy'), '2', '08', '129', '05', '2096', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35194, to_date('09-05-2096', 'dd-mm-yyyy'), '3', '09', '130', '05', '2096', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35195, to_date('10-05-2096', 'dd-mm-yyyy'), '4', '10', '131', '05', '2096', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35196, to_date('11-05-2096', 'dd-mm-yyyy'), '5', '11', '132', '05', '2096', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35197, to_date('12-05-2096', 'dd-mm-yyyy'), '6', '12', '133', '05', '2096', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35198, to_date('13-05-2096', 'dd-mm-yyyy'), '7', '13', '134', '05', '2096', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35199, to_date('14-05-2096', 'dd-mm-yyyy'), '1', '14', '135', '05', '2096', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35200, to_date('15-05-2096', 'dd-mm-yyyy'), '2', '15', '136', '05', '2096', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35201, to_date('16-05-2096', 'dd-mm-yyyy'), '3', '16', '137', '05', '2096', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35202, to_date('17-05-2096', 'dd-mm-yyyy'), '4', '17', '138', '05', '2096', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35203, to_date('18-05-2096', 'dd-mm-yyyy'), '5', '18', '139', '05', '2096', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35204, to_date('19-05-2096', 'dd-mm-yyyy'), '6', '19', '140', '05', '2096', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35205, to_date('20-05-2096', 'dd-mm-yyyy'), '7', '20', '141', '05', '2096', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35206, to_date('21-05-2096', 'dd-mm-yyyy'), '1', '21', '142', '05', '2096', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35207, to_date('22-05-2096', 'dd-mm-yyyy'), '2', '22', '143', '05', '2096', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35208, to_date('23-05-2096', 'dd-mm-yyyy'), '3', '23', '144', '05', '2096', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35209, to_date('24-05-2096', 'dd-mm-yyyy'), '4', '24', '145', '05', '2096', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35210, to_date('25-05-2096', 'dd-mm-yyyy'), '5', '25', '146', '05', '2096', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35211, to_date('26-05-2096', 'dd-mm-yyyy'), '6', '26', '147', '05', '2096', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35212, to_date('27-05-2096', 'dd-mm-yyyy'), '7', '27', '148', '05', '2096', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35213, to_date('28-05-2096', 'dd-mm-yyyy'), '1', '28', '149', '05', '2096', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35214, to_date('29-05-2096', 'dd-mm-yyyy'), '2', '29', '150', '05', '2096', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35215, to_date('30-05-2096', 'dd-mm-yyyy'), '3', '30', '151', '05', '2096', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35216, to_date('31-05-2096', 'dd-mm-yyyy'), '4', '31', '152', '05', '2096', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35217, to_date('01-06-2096', 'dd-mm-yyyy'), '5', '01', '153', '06', '2096', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35218, to_date('02-06-2096', 'dd-mm-yyyy'), '6', '02', '154', '06', '2096', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35219, to_date('03-06-2096', 'dd-mm-yyyy'), '7', '03', '155', '06', '2096', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35220, to_date('04-06-2096', 'dd-mm-yyyy'), '1', '04', '156', '06', '2096', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35221, to_date('05-06-2096', 'dd-mm-yyyy'), '2', '05', '157', '06', '2096', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35222, to_date('06-06-2096', 'dd-mm-yyyy'), '3', '06', '158', '06', '2096', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35223, to_date('07-06-2096', 'dd-mm-yyyy'), '4', '07', '159', '06', '2096', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35224, to_date('08-06-2096', 'dd-mm-yyyy'), '5', '08', '160', '06', '2096', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35225, to_date('09-06-2096', 'dd-mm-yyyy'), '6', '09', '161', '06', '2096', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35226, to_date('10-06-2096', 'dd-mm-yyyy'), '7', '10', '162', '06', '2096', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35227, to_date('11-06-2096', 'dd-mm-yyyy'), '1', '11', '163', '06', '2096', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35228, to_date('12-06-2096', 'dd-mm-yyyy'), '2', '12', '164', '06', '2096', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35229, to_date('13-06-2096', 'dd-mm-yyyy'), '3', '13', '165', '06', '2096', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35230, to_date('14-06-2096', 'dd-mm-yyyy'), '4', '14', '166', '06', '2096', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35231, to_date('15-06-2096', 'dd-mm-yyyy'), '5', '15', '167', '06', '2096', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35232, to_date('16-06-2096', 'dd-mm-yyyy'), '6', '16', '168', '06', '2096', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35233, to_date('17-06-2096', 'dd-mm-yyyy'), '7', '17', '169', '06', '2096', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35234, to_date('18-06-2096', 'dd-mm-yyyy'), '1', '18', '170', '06', '2096', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35235, to_date('19-06-2096', 'dd-mm-yyyy'), '2', '19', '171', '06', '2096', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35236, to_date('20-06-2096', 'dd-mm-yyyy'), '3', '20', '172', '06', '2096', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35237, to_date('21-06-2096', 'dd-mm-yyyy'), '4', '21', '173', '06', '2096', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35238, to_date('22-06-2096', 'dd-mm-yyyy'), '5', '22', '174', '06', '2096', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35239, to_date('23-06-2096', 'dd-mm-yyyy'), '6', '23', '175', '06', '2096', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35240, to_date('24-06-2096', 'dd-mm-yyyy'), '7', '24', '176', '06', '2096', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35241, to_date('25-06-2096', 'dd-mm-yyyy'), '1', '25', '177', '06', '2096', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35242, to_date('26-06-2096', 'dd-mm-yyyy'), '2', '26', '178', '06', '2096', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35243, to_date('27-06-2096', 'dd-mm-yyyy'), '3', '27', '179', '06', '2096', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35244, to_date('28-06-2096', 'dd-mm-yyyy'), '4', '28', '180', '06', '2096', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35245, to_date('29-06-2096', 'dd-mm-yyyy'), '5', '29', '181', '06', '2096', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35246, to_date('30-06-2096', 'dd-mm-yyyy'), '6', '30', '182', '06', '2096', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35247, to_date('01-07-2096', 'dd-mm-yyyy'), '7', '01', '183', '07', '2096', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35248, to_date('02-07-2096', 'dd-mm-yyyy'), '1', '02', '184', '07', '2096', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35249, to_date('03-07-2096', 'dd-mm-yyyy'), '2', '03', '185', '07', '2096', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35250, to_date('04-07-2096', 'dd-mm-yyyy'), '3', '04', '186', '07', '2096', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35251, to_date('05-07-2096', 'dd-mm-yyyy'), '4', '05', '187', '07', '2096', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35252, to_date('06-07-2096', 'dd-mm-yyyy'), '5', '06', '188', '07', '2096', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35253, to_date('07-07-2096', 'dd-mm-yyyy'), '6', '07', '189', '07', '2096', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35254, to_date('08-07-2096', 'dd-mm-yyyy'), '7', '08', '190', '07', '2096', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35255, to_date('09-07-2096', 'dd-mm-yyyy'), '1', '09', '191', '07', '2096', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35256, to_date('10-07-2096', 'dd-mm-yyyy'), '2', '10', '192', '07', '2096', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35257, to_date('11-07-2096', 'dd-mm-yyyy'), '3', '11', '193', '07', '2096', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35258, to_date('12-07-2096', 'dd-mm-yyyy'), '4', '12', '194', '07', '2096', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35259, to_date('13-07-2096', 'dd-mm-yyyy'), '5', '13', '195', '07', '2096', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35260, to_date('14-07-2096', 'dd-mm-yyyy'), '6', '14', '196', '07', '2096', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35261, to_date('15-07-2096', 'dd-mm-yyyy'), '7', '15', '197', '07', '2096', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35262, to_date('16-07-2096', 'dd-mm-yyyy'), '1', '16', '198', '07', '2096', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35263, to_date('17-07-2096', 'dd-mm-yyyy'), '2', '17', '199', '07', '2096', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35264, to_date('18-07-2096', 'dd-mm-yyyy'), '3', '18', '200', '07', '2096', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35265, to_date('19-07-2096', 'dd-mm-yyyy'), '4', '19', '201', '07', '2096', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35266, to_date('20-07-2096', 'dd-mm-yyyy'), '5', '20', '202', '07', '2096', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35267, to_date('21-07-2096', 'dd-mm-yyyy'), '6', '21', '203', '07', '2096', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35268, to_date('22-07-2096', 'dd-mm-yyyy'), '7', '22', '204', '07', '2096', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35269, to_date('23-07-2096', 'dd-mm-yyyy'), '1', '23', '205', '07', '2096', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35270, to_date('24-07-2096', 'dd-mm-yyyy'), '2', '24', '206', '07', '2096', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35271, to_date('25-07-2096', 'dd-mm-yyyy'), '3', '25', '207', '07', '2096', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35272, to_date('26-07-2096', 'dd-mm-yyyy'), '4', '26', '208', '07', '2096', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33683, to_date('20-03-2092', 'dd-mm-yyyy'), '4', '20', '080', '03', '2092', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33684, to_date('21-03-2092', 'dd-mm-yyyy'), '5', '21', '081', '03', '2092', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33685, to_date('22-03-2092', 'dd-mm-yyyy'), '6', '22', '082', '03', '2092', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33686, to_date('23-03-2092', 'dd-mm-yyyy'), '7', '23', '083', '03', '2092', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33687, to_date('24-03-2092', 'dd-mm-yyyy'), '1', '24', '084', '03', '2092', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33688, to_date('25-03-2092', 'dd-mm-yyyy'), '2', '25', '085', '03', '2092', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33689, to_date('26-03-2092', 'dd-mm-yyyy'), '3', '26', '086', '03', '2092', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33690, to_date('27-03-2092', 'dd-mm-yyyy'), '4', '27', '087', '03', '2092', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33691, to_date('28-03-2092', 'dd-mm-yyyy'), '5', '28', '088', '03', '2092', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33692, to_date('29-03-2092', 'dd-mm-yyyy'), '6', '29', '089', '03', '2092', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33693, to_date('30-03-2092', 'dd-mm-yyyy'), '7', '30', '090', '03', '2092', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33694, to_date('31-03-2092', 'dd-mm-yyyy'), '1', '31', '091', '03', '2092', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33695, to_date('01-04-2092', 'dd-mm-yyyy'), '2', '01', '092', '04', '2092', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33696, to_date('02-04-2092', 'dd-mm-yyyy'), '3', '02', '093', '04', '2092', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33697, to_date('03-04-2092', 'dd-mm-yyyy'), '4', '03', '094', '04', '2092', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33698, to_date('04-04-2092', 'dd-mm-yyyy'), '5', '04', '095', '04', '2092', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33699, to_date('05-04-2092', 'dd-mm-yyyy'), '6', '05', '096', '04', '2092', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33700, to_date('06-04-2092', 'dd-mm-yyyy'), '7', '06', '097', '04', '2092', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33701, to_date('07-04-2092', 'dd-mm-yyyy'), '1', '07', '098', '04', '2092', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33702, to_date('08-04-2092', 'dd-mm-yyyy'), '2', '08', '099', '04', '2092', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33703, to_date('09-04-2092', 'dd-mm-yyyy'), '3', '09', '100', '04', '2092', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33704, to_date('10-04-2092', 'dd-mm-yyyy'), '4', '10', '101', '04', '2092', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33705, to_date('11-04-2092', 'dd-mm-yyyy'), '5', '11', '102', '04', '2092', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33706, to_date('12-04-2092', 'dd-mm-yyyy'), '6', '12', '103', '04', '2092', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33707, to_date('13-04-2092', 'dd-mm-yyyy'), '7', '13', '104', '04', '2092', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33708, to_date('14-04-2092', 'dd-mm-yyyy'), '1', '14', '105', '04', '2092', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33709, to_date('15-04-2092', 'dd-mm-yyyy'), '2', '15', '106', '04', '2092', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33710, to_date('16-04-2092', 'dd-mm-yyyy'), '3', '16', '107', '04', '2092', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33711, to_date('17-04-2092', 'dd-mm-yyyy'), '4', '17', '108', '04', '2092', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33712, to_date('18-04-2092', 'dd-mm-yyyy'), '5', '18', '109', '04', '2092', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33713, to_date('19-04-2092', 'dd-mm-yyyy'), '6', '19', '110', '04', '2092', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33714, to_date('20-04-2092', 'dd-mm-yyyy'), '7', '20', '111', '04', '2092', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33715, to_date('21-04-2092', 'dd-mm-yyyy'), '1', '21', '112', '04', '2092', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33716, to_date('22-04-2092', 'dd-mm-yyyy'), '2', '22', '113', '04', '2092', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33717, to_date('23-04-2092', 'dd-mm-yyyy'), '3', '23', '114', '04', '2092', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33718, to_date('24-04-2092', 'dd-mm-yyyy'), '4', '24', '115', '04', '2092', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33719, to_date('25-04-2092', 'dd-mm-yyyy'), '5', '25', '116', '04', '2092', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33720, to_date('26-04-2092', 'dd-mm-yyyy'), '6', '26', '117', '04', '2092', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33721, to_date('27-04-2092', 'dd-mm-yyyy'), '7', '27', '118', '04', '2092', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33722, to_date('28-04-2092', 'dd-mm-yyyy'), '1', '28', '119', '04', '2092', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33723, to_date('29-04-2092', 'dd-mm-yyyy'), '2', '29', '120', '04', '2092', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33724, to_date('30-04-2092', 'dd-mm-yyyy'), '3', '30', '121', '04', '2092', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33725, to_date('01-05-2092', 'dd-mm-yyyy'), '4', '01', '122', '05', '2092', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33726, to_date('02-05-2092', 'dd-mm-yyyy'), '5', '02', '123', '05', '2092', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33727, to_date('03-05-2092', 'dd-mm-yyyy'), '6', '03', '124', '05', '2092', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33728, to_date('04-05-2092', 'dd-mm-yyyy'), '7', '04', '125', '05', '2092', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33729, to_date('05-05-2092', 'dd-mm-yyyy'), '1', '05', '126', '05', '2092', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33730, to_date('06-05-2092', 'dd-mm-yyyy'), '2', '06', '127', '05', '2092', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33731, to_date('07-05-2092', 'dd-mm-yyyy'), '3', '07', '128', '05', '2092', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33732, to_date('08-05-2092', 'dd-mm-yyyy'), '4', '08', '129', '05', '2092', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33733, to_date('09-05-2092', 'dd-mm-yyyy'), '5', '09', '130', '05', '2092', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33734, to_date('10-05-2092', 'dd-mm-yyyy'), '6', '10', '131', '05', '2092', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33735, to_date('11-05-2092', 'dd-mm-yyyy'), '7', '11', '132', '05', '2092', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33736, to_date('12-05-2092', 'dd-mm-yyyy'), '1', '12', '133', '05', '2092', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33737, to_date('13-05-2092', 'dd-mm-yyyy'), '2', '13', '134', '05', '2092', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33738, to_date('14-05-2092', 'dd-mm-yyyy'), '3', '14', '135', '05', '2092', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33739, to_date('15-05-2092', 'dd-mm-yyyy'), '4', '15', '136', '05', '2092', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33740, to_date('16-05-2092', 'dd-mm-yyyy'), '5', '16', '137', '05', '2092', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33741, to_date('17-05-2092', 'dd-mm-yyyy'), '6', '17', '138', '05', '2092', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33742, to_date('18-05-2092', 'dd-mm-yyyy'), '7', '18', '139', '05', '2092', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33743, to_date('19-05-2092', 'dd-mm-yyyy'), '1', '19', '140', '05', '2092', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33744, to_date('20-05-2092', 'dd-mm-yyyy'), '2', '20', '141', '05', '2092', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33745, to_date('21-05-2092', 'dd-mm-yyyy'), '3', '21', '142', '05', '2092', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33746, to_date('22-05-2092', 'dd-mm-yyyy'), '4', '22', '143', '05', '2092', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33747, to_date('23-05-2092', 'dd-mm-yyyy'), '5', '23', '144', '05', '2092', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33748, to_date('24-05-2092', 'dd-mm-yyyy'), '6', '24', '145', '05', '2092', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33749, to_date('25-05-2092', 'dd-mm-yyyy'), '7', '25', '146', '05', '2092', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33750, to_date('26-05-2092', 'dd-mm-yyyy'), '1', '26', '147', '05', '2092', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33751, to_date('27-05-2092', 'dd-mm-yyyy'), '2', '27', '148', '05', '2092', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33752, to_date('28-05-2092', 'dd-mm-yyyy'), '3', '28', '149', '05', '2092', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33753, to_date('29-05-2092', 'dd-mm-yyyy'), '4', '29', '150', '05', '2092', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33754, to_date('30-05-2092', 'dd-mm-yyyy'), '5', '30', '151', '05', '2092', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33755, to_date('31-05-2092', 'dd-mm-yyyy'), '6', '31', '152', '05', '2092', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33756, to_date('01-06-2092', 'dd-mm-yyyy'), '7', '01', '153', '06', '2092', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33757, to_date('02-06-2092', 'dd-mm-yyyy'), '1', '02', '154', '06', '2092', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33758, to_date('03-06-2092', 'dd-mm-yyyy'), '2', '03', '155', '06', '2092', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33759, to_date('04-06-2092', 'dd-mm-yyyy'), '3', '04', '156', '06', '2092', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33760, to_date('05-06-2092', 'dd-mm-yyyy'), '4', '05', '157', '06', '2092', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33761, to_date('06-06-2092', 'dd-mm-yyyy'), '5', '06', '158', '06', '2092', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33762, to_date('07-06-2092', 'dd-mm-yyyy'), '6', '07', '159', '06', '2092', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33763, to_date('08-06-2092', 'dd-mm-yyyy'), '7', '08', '160', '06', '2092', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33764, to_date('09-06-2092', 'dd-mm-yyyy'), '1', '09', '161', '06', '2092', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33765, to_date('10-06-2092', 'dd-mm-yyyy'), '2', '10', '162', '06', '2092', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33766, to_date('11-06-2092', 'dd-mm-yyyy'), '3', '11', '163', '06', '2092', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33767, to_date('12-06-2092', 'dd-mm-yyyy'), '4', '12', '164', '06', '2092', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33768, to_date('13-06-2092', 'dd-mm-yyyy'), '5', '13', '165', '06', '2092', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33769, to_date('14-06-2092', 'dd-mm-yyyy'), '6', '14', '166', '06', '2092', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33770, to_date('15-06-2092', 'dd-mm-yyyy'), '7', '15', '167', '06', '2092', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33771, to_date('16-06-2092', 'dd-mm-yyyy'), '1', '16', '168', '06', '2092', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33772, to_date('17-06-2092', 'dd-mm-yyyy'), '2', '17', '169', '06', '2092', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33773, to_date('18-06-2092', 'dd-mm-yyyy'), '3', '18', '170', '06', '2092', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33774, to_date('19-06-2092', 'dd-mm-yyyy'), '4', '19', '171', '06', '2092', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33775, to_date('20-06-2092', 'dd-mm-yyyy'), '5', '20', '172', '06', '2092', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33776, to_date('21-06-2092', 'dd-mm-yyyy'), '6', '21', '173', '06', '2092', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33777, to_date('22-06-2092', 'dd-mm-yyyy'), '7', '22', '174', '06', '2092', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33778, to_date('23-06-2092', 'dd-mm-yyyy'), '1', '23', '175', '06', '2092', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33779, to_date('24-06-2092', 'dd-mm-yyyy'), '2', '24', '176', '06', '2092', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33780, to_date('25-06-2092', 'dd-mm-yyyy'), '3', '25', '177', '06', '2092', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33781, to_date('26-06-2092', 'dd-mm-yyyy'), '4', '26', '178', '06', '2092', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33782, to_date('27-06-2092', 'dd-mm-yyyy'), '5', '27', '179', '06', '2092', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33783, to_date('28-06-2092', 'dd-mm-yyyy'), '6', '28', '180', '06', '2092', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33784, to_date('29-06-2092', 'dd-mm-yyyy'), '7', '29', '181', '06', '2092', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33785, to_date('30-06-2092', 'dd-mm-yyyy'), '1', '30', '182', '06', '2092', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33786, to_date('01-07-2092', 'dd-mm-yyyy'), '2', '01', '183', '07', '2092', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33787, to_date('02-07-2092', 'dd-mm-yyyy'), '3', '02', '184', '07', '2092', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33788, to_date('03-07-2092', 'dd-mm-yyyy'), '4', '03', '185', '07', '2092', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35273, to_date('27-07-2096', 'dd-mm-yyyy'), '5', '27', '209', '07', '2096', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35274, to_date('28-07-2096', 'dd-mm-yyyy'), '6', '28', '210', '07', '2096', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35275, to_date('29-07-2096', 'dd-mm-yyyy'), '7', '29', '211', '07', '2096', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35276, to_date('30-07-2096', 'dd-mm-yyyy'), '1', '30', '212', '07', '2096', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35277, to_date('31-07-2096', 'dd-mm-yyyy'), '2', '31', '213', '07', '2096', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35278, to_date('01-08-2096', 'dd-mm-yyyy'), '3', '01', '214', '08', '2096', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35279, to_date('02-08-2096', 'dd-mm-yyyy'), '4', '02', '215', '08', '2096', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35280, to_date('03-08-2096', 'dd-mm-yyyy'), '5', '03', '216', '08', '2096', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35281, to_date('04-08-2096', 'dd-mm-yyyy'), '6', '04', '217', '08', '2096', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35282, to_date('05-08-2096', 'dd-mm-yyyy'), '7', '05', '218', '08', '2096', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35283, to_date('06-08-2096', 'dd-mm-yyyy'), '1', '06', '219', '08', '2096', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35284, to_date('07-08-2096', 'dd-mm-yyyy'), '2', '07', '220', '08', '2096', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35285, to_date('08-08-2096', 'dd-mm-yyyy'), '3', '08', '221', '08', '2096', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35286, to_date('09-08-2096', 'dd-mm-yyyy'), '4', '09', '222', '08', '2096', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35287, to_date('10-08-2096', 'dd-mm-yyyy'), '5', '10', '223', '08', '2096', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35288, to_date('11-08-2096', 'dd-mm-yyyy'), '6', '11', '224', '08', '2096', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35289, to_date('12-08-2096', 'dd-mm-yyyy'), '7', '12', '225', '08', '2096', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35290, to_date('13-08-2096', 'dd-mm-yyyy'), '1', '13', '226', '08', '2096', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35291, to_date('14-08-2096', 'dd-mm-yyyy'), '2', '14', '227', '08', '2096', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35292, to_date('15-08-2096', 'dd-mm-yyyy'), '3', '15', '228', '08', '2096', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35293, to_date('16-08-2096', 'dd-mm-yyyy'), '4', '16', '229', '08', '2096', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35294, to_date('17-08-2096', 'dd-mm-yyyy'), '5', '17', '230', '08', '2096', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35295, to_date('18-08-2096', 'dd-mm-yyyy'), '6', '18', '231', '08', '2096', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35296, to_date('19-08-2096', 'dd-mm-yyyy'), '7', '19', '232', '08', '2096', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35297, to_date('20-08-2096', 'dd-mm-yyyy'), '1', '20', '233', '08', '2096', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35298, to_date('21-08-2096', 'dd-mm-yyyy'), '2', '21', '234', '08', '2096', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35299, to_date('22-08-2096', 'dd-mm-yyyy'), '3', '22', '235', '08', '2096', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35300, to_date('23-08-2096', 'dd-mm-yyyy'), '4', '23', '236', '08', '2096', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35301, to_date('24-08-2096', 'dd-mm-yyyy'), '5', '24', '237', '08', '2096', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35302, to_date('25-08-2096', 'dd-mm-yyyy'), '6', '25', '238', '08', '2096', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35303, to_date('26-08-2096', 'dd-mm-yyyy'), '7', '26', '239', '08', '2096', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35304, to_date('27-08-2096', 'dd-mm-yyyy'), '1', '27', '240', '08', '2096', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35305, to_date('28-08-2096', 'dd-mm-yyyy'), '2', '28', '241', '08', '2096', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35306, to_date('29-08-2096', 'dd-mm-yyyy'), '3', '29', '242', '08', '2096', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35307, to_date('30-08-2096', 'dd-mm-yyyy'), '4', '30', '243', '08', '2096', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35308, to_date('31-08-2096', 'dd-mm-yyyy'), '5', '31', '244', '08', '2096', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35309, to_date('01-09-2096', 'dd-mm-yyyy'), '6', '01', '245', '09', '2096', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35310, to_date('02-09-2096', 'dd-mm-yyyy'), '7', '02', '246', '09', '2096', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35311, to_date('03-09-2096', 'dd-mm-yyyy'), '1', '03', '247', '09', '2096', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35312, to_date('04-09-2096', 'dd-mm-yyyy'), '2', '04', '248', '09', '2096', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35313, to_date('05-09-2096', 'dd-mm-yyyy'), '3', '05', '249', '09', '2096', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35314, to_date('06-09-2096', 'dd-mm-yyyy'), '4', '06', '250', '09', '2096', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35315, to_date('07-09-2096', 'dd-mm-yyyy'), '5', '07', '251', '09', '2096', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35316, to_date('08-09-2096', 'dd-mm-yyyy'), '6', '08', '252', '09', '2096', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35317, to_date('09-09-2096', 'dd-mm-yyyy'), '7', '09', '253', '09', '2096', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35318, to_date('10-09-2096', 'dd-mm-yyyy'), '1', '10', '254', '09', '2096', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35319, to_date('11-09-2096', 'dd-mm-yyyy'), '2', '11', '255', '09', '2096', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35320, to_date('12-09-2096', 'dd-mm-yyyy'), '3', '12', '256', '09', '2096', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35321, to_date('13-09-2096', 'dd-mm-yyyy'), '4', '13', '257', '09', '2096', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35322, to_date('14-09-2096', 'dd-mm-yyyy'), '5', '14', '258', '09', '2096', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35323, to_date('15-09-2096', 'dd-mm-yyyy'), '6', '15', '259', '09', '2096', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35324, to_date('16-09-2096', 'dd-mm-yyyy'), '7', '16', '260', '09', '2096', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35325, to_date('17-09-2096', 'dd-mm-yyyy'), '1', '17', '261', '09', '2096', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35326, to_date('18-09-2096', 'dd-mm-yyyy'), '2', '18', '262', '09', '2096', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35327, to_date('19-09-2096', 'dd-mm-yyyy'), '3', '19', '263', '09', '2096', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35328, to_date('20-09-2096', 'dd-mm-yyyy'), '4', '20', '264', '09', '2096', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35329, to_date('21-09-2096', 'dd-mm-yyyy'), '5', '21', '265', '09', '2096', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35330, to_date('22-09-2096', 'dd-mm-yyyy'), '6', '22', '266', '09', '2096', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35331, to_date('23-09-2096', 'dd-mm-yyyy'), '7', '23', '267', '09', '2096', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35332, to_date('24-09-2096', 'dd-mm-yyyy'), '1', '24', '268', '09', '2096', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35333, to_date('25-09-2096', 'dd-mm-yyyy'), '2', '25', '269', '09', '2096', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35334, to_date('26-09-2096', 'dd-mm-yyyy'), '3', '26', '270', '09', '2096', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35335, to_date('27-09-2096', 'dd-mm-yyyy'), '4', '27', '271', '09', '2096', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35336, to_date('28-09-2096', 'dd-mm-yyyy'), '5', '28', '272', '09', '2096', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35337, to_date('29-09-2096', 'dd-mm-yyyy'), '6', '29', '273', '09', '2096', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35338, to_date('30-09-2096', 'dd-mm-yyyy'), '7', '30', '274', '09', '2096', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35339, to_date('01-10-2096', 'dd-mm-yyyy'), '1', '01', '275', '10', '2096', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35340, to_date('02-10-2096', 'dd-mm-yyyy'), '2', '02', '276', '10', '2096', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35341, to_date('03-10-2096', 'dd-mm-yyyy'), '3', '03', '277', '10', '2096', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35342, to_date('04-10-2096', 'dd-mm-yyyy'), '4', '04', '278', '10', '2096', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35343, to_date('05-10-2096', 'dd-mm-yyyy'), '5', '05', '279', '10', '2096', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35344, to_date('06-10-2096', 'dd-mm-yyyy'), '6', '06', '280', '10', '2096', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35345, to_date('07-10-2096', 'dd-mm-yyyy'), '7', '07', '281', '10', '2096', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35346, to_date('08-10-2096', 'dd-mm-yyyy'), '1', '08', '282', '10', '2096', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35347, to_date('09-10-2096', 'dd-mm-yyyy'), '2', '09', '283', '10', '2096', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35348, to_date('10-10-2096', 'dd-mm-yyyy'), '3', '10', '284', '10', '2096', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35349, to_date('11-10-2096', 'dd-mm-yyyy'), '4', '11', '285', '10', '2096', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35350, to_date('12-10-2096', 'dd-mm-yyyy'), '5', '12', '286', '10', '2096', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35351, to_date('13-10-2096', 'dd-mm-yyyy'), '6', '13', '287', '10', '2096', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35352, to_date('14-10-2096', 'dd-mm-yyyy'), '7', '14', '288', '10', '2096', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35353, to_date('15-10-2096', 'dd-mm-yyyy'), '1', '15', '289', '10', '2096', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35354, to_date('16-10-2096', 'dd-mm-yyyy'), '2', '16', '290', '10', '2096', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35355, to_date('17-10-2096', 'dd-mm-yyyy'), '3', '17', '291', '10', '2096', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35356, to_date('18-10-2096', 'dd-mm-yyyy'), '4', '18', '292', '10', '2096', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35357, to_date('19-10-2096', 'dd-mm-yyyy'), '5', '19', '293', '10', '2096', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35358, to_date('20-10-2096', 'dd-mm-yyyy'), '6', '20', '294', '10', '2096', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35359, to_date('21-10-2096', 'dd-mm-yyyy'), '7', '21', '295', '10', '2096', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35360, to_date('22-10-2096', 'dd-mm-yyyy'), '1', '22', '296', '10', '2096', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35361, to_date('23-10-2096', 'dd-mm-yyyy'), '2', '23', '297', '10', '2096', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35362, to_date('24-10-2096', 'dd-mm-yyyy'), '3', '24', '298', '10', '2096', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35363, to_date('25-10-2096', 'dd-mm-yyyy'), '4', '25', '299', '10', '2096', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35364, to_date('26-10-2096', 'dd-mm-yyyy'), '5', '26', '300', '10', '2096', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35365, to_date('27-10-2096', 'dd-mm-yyyy'), '6', '27', '301', '10', '2096', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35366, to_date('28-10-2096', 'dd-mm-yyyy'), '7', '28', '302', '10', '2096', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35367, to_date('29-10-2096', 'dd-mm-yyyy'), '1', '29', '303', '10', '2096', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35368, to_date('30-10-2096', 'dd-mm-yyyy'), '2', '30', '304', '10', '2096', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35369, to_date('31-10-2096', 'dd-mm-yyyy'), '3', '31', '305', '10', '2096', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35370, to_date('01-11-2096', 'dd-mm-yyyy'), '4', '01', '306', '11', '2096', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35371, to_date('02-11-2096', 'dd-mm-yyyy'), '5', '02', '307', '11', '2096', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35372, to_date('03-11-2096', 'dd-mm-yyyy'), '6', '03', '308', '11', '2096', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35373, to_date('04-11-2096', 'dd-mm-yyyy'), '7', '04', '309', '11', '2096', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35374, to_date('05-11-2096', 'dd-mm-yyyy'), '1', '05', '310', '11', '2096', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35375, to_date('06-11-2096', 'dd-mm-yyyy'), '2', '06', '311', '11', '2096', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35376, to_date('07-11-2096', 'dd-mm-yyyy'), '3', '07', '312', '11', '2096', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35377, to_date('08-11-2096', 'dd-mm-yyyy'), '4', '08', '313', '11', '2096', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35378, to_date('09-11-2096', 'dd-mm-yyyy'), '5', '09', '314', '11', '2096', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33789, to_date('04-07-2092', 'dd-mm-yyyy'), '5', '04', '186', '07', '2092', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33790, to_date('05-07-2092', 'dd-mm-yyyy'), '6', '05', '187', '07', '2092', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33791, to_date('06-07-2092', 'dd-mm-yyyy'), '7', '06', '188', '07', '2092', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33792, to_date('07-07-2092', 'dd-mm-yyyy'), '1', '07', '189', '07', '2092', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33793, to_date('08-07-2092', 'dd-mm-yyyy'), '2', '08', '190', '07', '2092', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33794, to_date('09-07-2092', 'dd-mm-yyyy'), '3', '09', '191', '07', '2092', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33795, to_date('10-07-2092', 'dd-mm-yyyy'), '4', '10', '192', '07', '2092', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33796, to_date('11-07-2092', 'dd-mm-yyyy'), '5', '11', '193', '07', '2092', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33797, to_date('12-07-2092', 'dd-mm-yyyy'), '6', '12', '194', '07', '2092', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33798, to_date('13-07-2092', 'dd-mm-yyyy'), '7', '13', '195', '07', '2092', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33799, to_date('14-07-2092', 'dd-mm-yyyy'), '1', '14', '196', '07', '2092', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33800, to_date('15-07-2092', 'dd-mm-yyyy'), '2', '15', '197', '07', '2092', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33801, to_date('16-07-2092', 'dd-mm-yyyy'), '3', '16', '198', '07', '2092', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33802, to_date('17-07-2092', 'dd-mm-yyyy'), '4', '17', '199', '07', '2092', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33803, to_date('18-07-2092', 'dd-mm-yyyy'), '5', '18', '200', '07', '2092', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33804, to_date('19-07-2092', 'dd-mm-yyyy'), '6', '19', '201', '07', '2092', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33805, to_date('20-07-2092', 'dd-mm-yyyy'), '7', '20', '202', '07', '2092', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33806, to_date('21-07-2092', 'dd-mm-yyyy'), '1', '21', '203', '07', '2092', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33807, to_date('22-07-2092', 'dd-mm-yyyy'), '2', '22', '204', '07', '2092', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33808, to_date('23-07-2092', 'dd-mm-yyyy'), '3', '23', '205', '07', '2092', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33809, to_date('24-07-2092', 'dd-mm-yyyy'), '4', '24', '206', '07', '2092', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33810, to_date('25-07-2092', 'dd-mm-yyyy'), '5', '25', '207', '07', '2092', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33811, to_date('26-07-2092', 'dd-mm-yyyy'), '6', '26', '208', '07', '2092', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33812, to_date('27-07-2092', 'dd-mm-yyyy'), '7', '27', '209', '07', '2092', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33813, to_date('28-07-2092', 'dd-mm-yyyy'), '1', '28', '210', '07', '2092', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33814, to_date('29-07-2092', 'dd-mm-yyyy'), '2', '29', '211', '07', '2092', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33815, to_date('30-07-2092', 'dd-mm-yyyy'), '3', '30', '212', '07', '2092', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33816, to_date('31-07-2092', 'dd-mm-yyyy'), '4', '31', '213', '07', '2092', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33817, to_date('01-08-2092', 'dd-mm-yyyy'), '5', '01', '214', '08', '2092', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33818, to_date('02-08-2092', 'dd-mm-yyyy'), '6', '02', '215', '08', '2092', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33819, to_date('03-08-2092', 'dd-mm-yyyy'), '7', '03', '216', '08', '2092', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33820, to_date('04-08-2092', 'dd-mm-yyyy'), '1', '04', '217', '08', '2092', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33821, to_date('05-08-2092', 'dd-mm-yyyy'), '2', '05', '218', '08', '2092', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33822, to_date('06-08-2092', 'dd-mm-yyyy'), '3', '06', '219', '08', '2092', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33823, to_date('07-08-2092', 'dd-mm-yyyy'), '4', '07', '220', '08', '2092', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33824, to_date('08-08-2092', 'dd-mm-yyyy'), '5', '08', '221', '08', '2092', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33825, to_date('09-08-2092', 'dd-mm-yyyy'), '6', '09', '222', '08', '2092', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33826, to_date('10-08-2092', 'dd-mm-yyyy'), '7', '10', '223', '08', '2092', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33827, to_date('11-08-2092', 'dd-mm-yyyy'), '1', '11', '224', '08', '2092', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33828, to_date('12-08-2092', 'dd-mm-yyyy'), '2', '12', '225', '08', '2092', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33829, to_date('13-08-2092', 'dd-mm-yyyy'), '3', '13', '226', '08', '2092', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33830, to_date('14-08-2092', 'dd-mm-yyyy'), '4', '14', '227', '08', '2092', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33831, to_date('15-08-2092', 'dd-mm-yyyy'), '5', '15', '228', '08', '2092', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33832, to_date('16-08-2092', 'dd-mm-yyyy'), '6', '16', '229', '08', '2092', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33833, to_date('17-08-2092', 'dd-mm-yyyy'), '7', '17', '230', '08', '2092', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33834, to_date('18-08-2092', 'dd-mm-yyyy'), '1', '18', '231', '08', '2092', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33835, to_date('19-08-2092', 'dd-mm-yyyy'), '2', '19', '232', '08', '2092', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33836, to_date('20-08-2092', 'dd-mm-yyyy'), '3', '20', '233', '08', '2092', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33837, to_date('21-08-2092', 'dd-mm-yyyy'), '4', '21', '234', '08', '2092', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33838, to_date('22-08-2092', 'dd-mm-yyyy'), '5', '22', '235', '08', '2092', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33839, to_date('23-08-2092', 'dd-mm-yyyy'), '6', '23', '236', '08', '2092', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33840, to_date('24-08-2092', 'dd-mm-yyyy'), '7', '24', '237', '08', '2092', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33841, to_date('25-08-2092', 'dd-mm-yyyy'), '1', '25', '238', '08', '2092', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33842, to_date('26-08-2092', 'dd-mm-yyyy'), '2', '26', '239', '08', '2092', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33843, to_date('27-08-2092', 'dd-mm-yyyy'), '3', '27', '240', '08', '2092', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33844, to_date('28-08-2092', 'dd-mm-yyyy'), '4', '28', '241', '08', '2092', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33845, to_date('29-08-2092', 'dd-mm-yyyy'), '5', '29', '242', '08', '2092', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33846, to_date('30-08-2092', 'dd-mm-yyyy'), '6', '30', '243', '08', '2092', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33847, to_date('31-08-2092', 'dd-mm-yyyy'), '7', '31', '244', '08', '2092', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33848, to_date('01-09-2092', 'dd-mm-yyyy'), '1', '01', '245', '09', '2092', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33849, to_date('02-09-2092', 'dd-mm-yyyy'), '2', '02', '246', '09', '2092', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33850, to_date('03-09-2092', 'dd-mm-yyyy'), '3', '03', '247', '09', '2092', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33851, to_date('04-09-2092', 'dd-mm-yyyy'), '4', '04', '248', '09', '2092', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33852, to_date('05-09-2092', 'dd-mm-yyyy'), '5', '05', '249', '09', '2092', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33853, to_date('06-09-2092', 'dd-mm-yyyy'), '6', '06', '250', '09', '2092', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33854, to_date('07-09-2092', 'dd-mm-yyyy'), '7', '07', '251', '09', '2092', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33855, to_date('08-09-2092', 'dd-mm-yyyy'), '1', '08', '252', '09', '2092', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33856, to_date('09-09-2092', 'dd-mm-yyyy'), '2', '09', '253', '09', '2092', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33857, to_date('10-09-2092', 'dd-mm-yyyy'), '3', '10', '254', '09', '2092', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33858, to_date('11-09-2092', 'dd-mm-yyyy'), '4', '11', '255', '09', '2092', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33859, to_date('12-09-2092', 'dd-mm-yyyy'), '5', '12', '256', '09', '2092', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33860, to_date('13-09-2092', 'dd-mm-yyyy'), '6', '13', '257', '09', '2092', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33861, to_date('14-09-2092', 'dd-mm-yyyy'), '7', '14', '258', '09', '2092', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33862, to_date('15-09-2092', 'dd-mm-yyyy'), '1', '15', '259', '09', '2092', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33863, to_date('16-09-2092', 'dd-mm-yyyy'), '2', '16', '260', '09', '2092', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33864, to_date('17-09-2092', 'dd-mm-yyyy'), '3', '17', '261', '09', '2092', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33865, to_date('18-09-2092', 'dd-mm-yyyy'), '4', '18', '262', '09', '2092', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33866, to_date('19-09-2092', 'dd-mm-yyyy'), '5', '19', '263', '09', '2092', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33867, to_date('20-09-2092', 'dd-mm-yyyy'), '6', '20', '264', '09', '2092', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33868, to_date('21-09-2092', 'dd-mm-yyyy'), '7', '21', '265', '09', '2092', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33869, to_date('22-09-2092', 'dd-mm-yyyy'), '1', '22', '266', '09', '2092', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33870, to_date('23-09-2092', 'dd-mm-yyyy'), '2', '23', '267', '09', '2092', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33871, to_date('24-09-2092', 'dd-mm-yyyy'), '3', '24', '268', '09', '2092', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33872, to_date('25-09-2092', 'dd-mm-yyyy'), '4', '25', '269', '09', '2092', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33873, to_date('26-09-2092', 'dd-mm-yyyy'), '5', '26', '270', '09', '2092', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33874, to_date('27-09-2092', 'dd-mm-yyyy'), '6', '27', '271', '09', '2092', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33875, to_date('28-09-2092', 'dd-mm-yyyy'), '7', '28', '272', '09', '2092', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33876, to_date('29-09-2092', 'dd-mm-yyyy'), '1', '29', '273', '09', '2092', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33877, to_date('30-09-2092', 'dd-mm-yyyy'), '2', '30', '274', '09', '2092', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33878, to_date('01-10-2092', 'dd-mm-yyyy'), '3', '01', '275', '10', '2092', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33879, to_date('02-10-2092', 'dd-mm-yyyy'), '4', '02', '276', '10', '2092', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33880, to_date('03-10-2092', 'dd-mm-yyyy'), '5', '03', '277', '10', '2092', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33881, to_date('04-10-2092', 'dd-mm-yyyy'), '6', '04', '278', '10', '2092', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33882, to_date('05-10-2092', 'dd-mm-yyyy'), '7', '05', '279', '10', '2092', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33883, to_date('06-10-2092', 'dd-mm-yyyy'), '1', '06', '280', '10', '2092', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33884, to_date('07-10-2092', 'dd-mm-yyyy'), '2', '07', '281', '10', '2092', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33885, to_date('08-10-2092', 'dd-mm-yyyy'), '3', '08', '282', '10', '2092', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33886, to_date('09-10-2092', 'dd-mm-yyyy'), '4', '09', '283', '10', '2092', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33887, to_date('10-10-2092', 'dd-mm-yyyy'), '5', '10', '284', '10', '2092', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33888, to_date('11-10-2092', 'dd-mm-yyyy'), '6', '11', '285', '10', '2092', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33889, to_date('12-10-2092', 'dd-mm-yyyy'), '7', '12', '286', '10', '2092', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33890, to_date('13-10-2092', 'dd-mm-yyyy'), '1', '13', '287', '10', '2092', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33891, to_date('14-10-2092', 'dd-mm-yyyy'), '2', '14', '288', '10', '2092', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33892, to_date('15-10-2092', 'dd-mm-yyyy'), '3', '15', '289', '10', '2092', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33893, to_date('16-10-2092', 'dd-mm-yyyy'), '4', '16', '290', '10', '2092', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33894, to_date('17-10-2092', 'dd-mm-yyyy'), '5', '17', '291', '10', '2092', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35379, to_date('10-11-2096', 'dd-mm-yyyy'), '6', '10', '315', '11', '2096', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35380, to_date('11-11-2096', 'dd-mm-yyyy'), '7', '11', '316', '11', '2096', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35381, to_date('12-11-2096', 'dd-mm-yyyy'), '1', '12', '317', '11', '2096', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35382, to_date('13-11-2096', 'dd-mm-yyyy'), '2', '13', '318', '11', '2096', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35383, to_date('14-11-2096', 'dd-mm-yyyy'), '3', '14', '319', '11', '2096', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35384, to_date('15-11-2096', 'dd-mm-yyyy'), '4', '15', '320', '11', '2096', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35385, to_date('16-11-2096', 'dd-mm-yyyy'), '5', '16', '321', '11', '2096', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35386, to_date('17-11-2096', 'dd-mm-yyyy'), '6', '17', '322', '11', '2096', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35387, to_date('18-11-2096', 'dd-mm-yyyy'), '7', '18', '323', '11', '2096', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35388, to_date('19-11-2096', 'dd-mm-yyyy'), '1', '19', '324', '11', '2096', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35389, to_date('20-11-2096', 'dd-mm-yyyy'), '2', '20', '325', '11', '2096', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35390, to_date('21-11-2096', 'dd-mm-yyyy'), '3', '21', '326', '11', '2096', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35391, to_date('22-11-2096', 'dd-mm-yyyy'), '4', '22', '327', '11', '2096', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35392, to_date('23-11-2096', 'dd-mm-yyyy'), '5', '23', '328', '11', '2096', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35393, to_date('24-11-2096', 'dd-mm-yyyy'), '6', '24', '329', '11', '2096', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35394, to_date('25-11-2096', 'dd-mm-yyyy'), '7', '25', '330', '11', '2096', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35395, to_date('26-11-2096', 'dd-mm-yyyy'), '1', '26', '331', '11', '2096', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35396, to_date('27-11-2096', 'dd-mm-yyyy'), '2', '27', '332', '11', '2096', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35397, to_date('28-11-2096', 'dd-mm-yyyy'), '3', '28', '333', '11', '2096', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35398, to_date('29-11-2096', 'dd-mm-yyyy'), '4', '29', '334', '11', '2096', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35399, to_date('30-11-2096', 'dd-mm-yyyy'), '5', '30', '335', '11', '2096', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35400, to_date('01-12-2096', 'dd-mm-yyyy'), '6', '01', '336', '12', '2096', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35401, to_date('02-12-2096', 'dd-mm-yyyy'), '7', '02', '337', '12', '2096', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35402, to_date('03-12-2096', 'dd-mm-yyyy'), '1', '03', '338', '12', '2096', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35403, to_date('04-12-2096', 'dd-mm-yyyy'), '2', '04', '339', '12', '2096', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35404, to_date('05-12-2096', 'dd-mm-yyyy'), '3', '05', '340', '12', '2096', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35405, to_date('06-12-2096', 'dd-mm-yyyy'), '4', '06', '341', '12', '2096', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35406, to_date('07-12-2096', 'dd-mm-yyyy'), '5', '07', '342', '12', '2096', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35407, to_date('08-12-2096', 'dd-mm-yyyy'), '6', '08', '343', '12', '2096', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35408, to_date('09-12-2096', 'dd-mm-yyyy'), '7', '09', '344', '12', '2096', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35409, to_date('10-12-2096', 'dd-mm-yyyy'), '1', '10', '345', '12', '2096', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35410, to_date('11-12-2096', 'dd-mm-yyyy'), '2', '11', '346', '12', '2096', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35411, to_date('12-12-2096', 'dd-mm-yyyy'), '3', '12', '347', '12', '2096', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35412, to_date('13-12-2096', 'dd-mm-yyyy'), '4', '13', '348', '12', '2096', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35413, to_date('14-12-2096', 'dd-mm-yyyy'), '5', '14', '349', '12', '2096', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35414, to_date('15-12-2096', 'dd-mm-yyyy'), '6', '15', '350', '12', '2096', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35415, to_date('16-12-2096', 'dd-mm-yyyy'), '7', '16', '351', '12', '2096', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35416, to_date('17-12-2096', 'dd-mm-yyyy'), '1', '17', '352', '12', '2096', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35417, to_date('18-12-2096', 'dd-mm-yyyy'), '2', '18', '353', '12', '2096', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35418, to_date('19-12-2096', 'dd-mm-yyyy'), '3', '19', '354', '12', '2096', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35419, to_date('20-12-2096', 'dd-mm-yyyy'), '4', '20', '355', '12', '2096', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35420, to_date('21-12-2096', 'dd-mm-yyyy'), '5', '21', '356', '12', '2096', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35421, to_date('22-12-2096', 'dd-mm-yyyy'), '6', '22', '357', '12', '2096', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35422, to_date('23-12-2096', 'dd-mm-yyyy'), '7', '23', '358', '12', '2096', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35423, to_date('24-12-2096', 'dd-mm-yyyy'), '1', '24', '359', '12', '2096', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35424, to_date('25-12-2096', 'dd-mm-yyyy'), '2', '25', '360', '12', '2096', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35425, to_date('26-12-2096', 'dd-mm-yyyy'), '3', '26', '361', '12', '2096', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35426, to_date('27-12-2096', 'dd-mm-yyyy'), '4', '27', '362', '12', '2096', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35427, to_date('28-12-2096', 'dd-mm-yyyy'), '5', '28', '363', '12', '2096', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35428, to_date('29-12-2096', 'dd-mm-yyyy'), '6', '29', '364', '12', '2096', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35429, to_date('30-12-2096', 'dd-mm-yyyy'), '7', '30', '365', '12', '2096', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35430, to_date('31-12-2096', 'dd-mm-yyyy'), '1', '31', '366', '12', '2096', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35431, to_date('01-01-2097', 'dd-mm-yyyy'), '2', '01', '001', '01', '2097', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35432, to_date('02-01-2097', 'dd-mm-yyyy'), '3', '02', '002', '01', '2097', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35433, to_date('03-01-2097', 'dd-mm-yyyy'), '4', '03', '003', '01', '2097', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35434, to_date('04-01-2097', 'dd-mm-yyyy'), '5', '04', '004', '01', '2097', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35435, to_date('05-01-2097', 'dd-mm-yyyy'), '6', '05', '005', '01', '2097', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35436, to_date('06-01-2097', 'dd-mm-yyyy'), '7', '06', '006', '01', '2097', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35437, to_date('07-01-2097', 'dd-mm-yyyy'), '1', '07', '007', '01', '2097', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35438, to_date('08-01-2097', 'dd-mm-yyyy'), '2', '08', '008', '01', '2097', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35439, to_date('09-01-2097', 'dd-mm-yyyy'), '3', '09', '009', '01', '2097', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35440, to_date('10-01-2097', 'dd-mm-yyyy'), '4', '10', '010', '01', '2097', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35441, to_date('11-01-2097', 'dd-mm-yyyy'), '5', '11', '011', '01', '2097', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35442, to_date('12-01-2097', 'dd-mm-yyyy'), '6', '12', '012', '01', '2097', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35443, to_date('13-01-2097', 'dd-mm-yyyy'), '7', '13', '013', '01', '2097', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35444, to_date('14-01-2097', 'dd-mm-yyyy'), '1', '14', '014', '01', '2097', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35445, to_date('15-01-2097', 'dd-mm-yyyy'), '2', '15', '015', '01', '2097', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35446, to_date('16-01-2097', 'dd-mm-yyyy'), '3', '16', '016', '01', '2097', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35447, to_date('17-01-2097', 'dd-mm-yyyy'), '4', '17', '017', '01', '2097', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35448, to_date('18-01-2097', 'dd-mm-yyyy'), '5', '18', '018', '01', '2097', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35449, to_date('19-01-2097', 'dd-mm-yyyy'), '6', '19', '019', '01', '2097', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35450, to_date('20-01-2097', 'dd-mm-yyyy'), '7', '20', '020', '01', '2097', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35451, to_date('21-01-2097', 'dd-mm-yyyy'), '1', '21', '021', '01', '2097', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35452, to_date('22-01-2097', 'dd-mm-yyyy'), '2', '22', '022', '01', '2097', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35453, to_date('23-01-2097', 'dd-mm-yyyy'), '3', '23', '023', '01', '2097', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35454, to_date('24-01-2097', 'dd-mm-yyyy'), '4', '24', '024', '01', '2097', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35455, to_date('25-01-2097', 'dd-mm-yyyy'), '5', '25', '025', '01', '2097', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35456, to_date('26-01-2097', 'dd-mm-yyyy'), '6', '26', '026', '01', '2097', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35457, to_date('27-01-2097', 'dd-mm-yyyy'), '7', '27', '027', '01', '2097', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35458, to_date('28-01-2097', 'dd-mm-yyyy'), '1', '28', '028', '01', '2097', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35459, to_date('29-01-2097', 'dd-mm-yyyy'), '2', '29', '029', '01', '2097', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35460, to_date('30-01-2097', 'dd-mm-yyyy'), '3', '30', '030', '01', '2097', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35461, to_date('31-01-2097', 'dd-mm-yyyy'), '4', '31', '031', '01', '2097', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35462, to_date('01-02-2097', 'dd-mm-yyyy'), '5', '01', '032', '02', '2097', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35463, to_date('02-02-2097', 'dd-mm-yyyy'), '6', '02', '033', '02', '2097', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35464, to_date('03-02-2097', 'dd-mm-yyyy'), '7', '03', '034', '02', '2097', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35465, to_date('04-02-2097', 'dd-mm-yyyy'), '1', '04', '035', '02', '2097', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35466, to_date('05-02-2097', 'dd-mm-yyyy'), '2', '05', '036', '02', '2097', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35467, to_date('06-02-2097', 'dd-mm-yyyy'), '3', '06', '037', '02', '2097', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35468, to_date('07-02-2097', 'dd-mm-yyyy'), '4', '07', '038', '02', '2097', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35469, to_date('08-02-2097', 'dd-mm-yyyy'), '5', '08', '039', '02', '2097', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35470, to_date('09-02-2097', 'dd-mm-yyyy'), '6', '09', '040', '02', '2097', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35471, to_date('10-02-2097', 'dd-mm-yyyy'), '7', '10', '041', '02', '2097', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35472, to_date('11-02-2097', 'dd-mm-yyyy'), '1', '11', '042', '02', '2097', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35473, to_date('12-02-2097', 'dd-mm-yyyy'), '2', '12', '043', '02', '2097', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35474, to_date('13-02-2097', 'dd-mm-yyyy'), '3', '13', '044', '02', '2097', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35475, to_date('14-02-2097', 'dd-mm-yyyy'), '4', '14', '045', '02', '2097', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35476, to_date('15-02-2097', 'dd-mm-yyyy'), '5', '15', '046', '02', '2097', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35477, to_date('16-02-2097', 'dd-mm-yyyy'), '6', '16', '047', '02', '2097', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35478, to_date('17-02-2097', 'dd-mm-yyyy'), '7', '17', '048', '02', '2097', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35479, to_date('18-02-2097', 'dd-mm-yyyy'), '1', '18', '049', '02', '2097', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35480, to_date('19-02-2097', 'dd-mm-yyyy'), '2', '19', '050', '02', '2097', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35481, to_date('20-02-2097', 'dd-mm-yyyy'), '3', '20', '051', '02', '2097', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35482, to_date('21-02-2097', 'dd-mm-yyyy'), '4', '21', '052', '02', '2097', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35483, to_date('22-02-2097', 'dd-mm-yyyy'), '5', '22', '053', '02', '2097', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35484, to_date('23-02-2097', 'dd-mm-yyyy'), '6', '23', '054', '02', '2097', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33895, to_date('18-10-2092', 'dd-mm-yyyy'), '6', '18', '292', '10', '2092', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33896, to_date('19-10-2092', 'dd-mm-yyyy'), '7', '19', '293', '10', '2092', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33897, to_date('20-10-2092', 'dd-mm-yyyy'), '1', '20', '294', '10', '2092', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33898, to_date('21-10-2092', 'dd-mm-yyyy'), '2', '21', '295', '10', '2092', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33899, to_date('22-10-2092', 'dd-mm-yyyy'), '3', '22', '296', '10', '2092', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33900, to_date('23-10-2092', 'dd-mm-yyyy'), '4', '23', '297', '10', '2092', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33901, to_date('24-10-2092', 'dd-mm-yyyy'), '5', '24', '298', '10', '2092', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33902, to_date('25-10-2092', 'dd-mm-yyyy'), '6', '25', '299', '10', '2092', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33903, to_date('26-10-2092', 'dd-mm-yyyy'), '7', '26', '300', '10', '2092', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33904, to_date('27-10-2092', 'dd-mm-yyyy'), '1', '27', '301', '10', '2092', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33905, to_date('28-10-2092', 'dd-mm-yyyy'), '2', '28', '302', '10', '2092', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33906, to_date('29-10-2092', 'dd-mm-yyyy'), '3', '29', '303', '10', '2092', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33907, to_date('30-10-2092', 'dd-mm-yyyy'), '4', '30', '304', '10', '2092', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33908, to_date('31-10-2092', 'dd-mm-yyyy'), '5', '31', '305', '10', '2092', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33909, to_date('01-11-2092', 'dd-mm-yyyy'), '6', '01', '306', '11', '2092', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33910, to_date('02-11-2092', 'dd-mm-yyyy'), '7', '02', '307', '11', '2092', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33911, to_date('03-11-2092', 'dd-mm-yyyy'), '1', '03', '308', '11', '2092', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33912, to_date('04-11-2092', 'dd-mm-yyyy'), '2', '04', '309', '11', '2092', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33913, to_date('05-11-2092', 'dd-mm-yyyy'), '3', '05', '310', '11', '2092', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33914, to_date('06-11-2092', 'dd-mm-yyyy'), '4', '06', '311', '11', '2092', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33915, to_date('07-11-2092', 'dd-mm-yyyy'), '5', '07', '312', '11', '2092', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33916, to_date('08-11-2092', 'dd-mm-yyyy'), '6', '08', '313', '11', '2092', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33917, to_date('09-11-2092', 'dd-mm-yyyy'), '7', '09', '314', '11', '2092', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33918, to_date('10-11-2092', 'dd-mm-yyyy'), '1', '10', '315', '11', '2092', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33919, to_date('11-11-2092', 'dd-mm-yyyy'), '2', '11', '316', '11', '2092', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33920, to_date('12-11-2092', 'dd-mm-yyyy'), '3', '12', '317', '11', '2092', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33921, to_date('13-11-2092', 'dd-mm-yyyy'), '4', '13', '318', '11', '2092', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33922, to_date('14-11-2092', 'dd-mm-yyyy'), '5', '14', '319', '11', '2092', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33923, to_date('15-11-2092', 'dd-mm-yyyy'), '6', '15', '320', '11', '2092', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33924, to_date('16-11-2092', 'dd-mm-yyyy'), '7', '16', '321', '11', '2092', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33925, to_date('17-11-2092', 'dd-mm-yyyy'), '1', '17', '322', '11', '2092', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33926, to_date('18-11-2092', 'dd-mm-yyyy'), '2', '18', '323', '11', '2092', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33927, to_date('19-11-2092', 'dd-mm-yyyy'), '3', '19', '324', '11', '2092', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33928, to_date('20-11-2092', 'dd-mm-yyyy'), '4', '20', '325', '11', '2092', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33929, to_date('21-11-2092', 'dd-mm-yyyy'), '5', '21', '326', '11', '2092', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33930, to_date('22-11-2092', 'dd-mm-yyyy'), '6', '22', '327', '11', '2092', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33931, to_date('23-11-2092', 'dd-mm-yyyy'), '7', '23', '328', '11', '2092', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33932, to_date('24-11-2092', 'dd-mm-yyyy'), '1', '24', '329', '11', '2092', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33933, to_date('25-11-2092', 'dd-mm-yyyy'), '2', '25', '330', '11', '2092', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33934, to_date('26-11-2092', 'dd-mm-yyyy'), '3', '26', '331', '11', '2092', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33935, to_date('27-11-2092', 'dd-mm-yyyy'), '4', '27', '332', '11', '2092', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33936, to_date('28-11-2092', 'dd-mm-yyyy'), '5', '28', '333', '11', '2092', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33937, to_date('29-11-2092', 'dd-mm-yyyy'), '6', '29', '334', '11', '2092', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33938, to_date('30-11-2092', 'dd-mm-yyyy'), '7', '30', '335', '11', '2092', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33939, to_date('01-12-2092', 'dd-mm-yyyy'), '1', '01', '336', '12', '2092', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33940, to_date('02-12-2092', 'dd-mm-yyyy'), '2', '02', '337', '12', '2092', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33941, to_date('03-12-2092', 'dd-mm-yyyy'), '3', '03', '338', '12', '2092', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33942, to_date('04-12-2092', 'dd-mm-yyyy'), '4', '04', '339', '12', '2092', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33943, to_date('05-12-2092', 'dd-mm-yyyy'), '5', '05', '340', '12', '2092', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33944, to_date('06-12-2092', 'dd-mm-yyyy'), '6', '06', '341', '12', '2092', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33945, to_date('07-12-2092', 'dd-mm-yyyy'), '7', '07', '342', '12', '2092', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33946, to_date('08-12-2092', 'dd-mm-yyyy'), '1', '08', '343', '12', '2092', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33947, to_date('09-12-2092', 'dd-mm-yyyy'), '2', '09', '344', '12', '2092', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33948, to_date('10-12-2092', 'dd-mm-yyyy'), '3', '10', '345', '12', '2092', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33949, to_date('11-12-2092', 'dd-mm-yyyy'), '4', '11', '346', '12', '2092', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33950, to_date('12-12-2092', 'dd-mm-yyyy'), '5', '12', '347', '12', '2092', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33951, to_date('13-12-2092', 'dd-mm-yyyy'), '6', '13', '348', '12', '2092', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33952, to_date('14-12-2092', 'dd-mm-yyyy'), '7', '14', '349', '12', '2092', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33953, to_date('15-12-2092', 'dd-mm-yyyy'), '1', '15', '350', '12', '2092', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33954, to_date('16-12-2092', 'dd-mm-yyyy'), '2', '16', '351', '12', '2092', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33955, to_date('17-12-2092', 'dd-mm-yyyy'), '3', '17', '352', '12', '2092', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33956, to_date('18-12-2092', 'dd-mm-yyyy'), '4', '18', '353', '12', '2092', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33957, to_date('19-12-2092', 'dd-mm-yyyy'), '5', '19', '354', '12', '2092', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33958, to_date('20-12-2092', 'dd-mm-yyyy'), '6', '20', '355', '12', '2092', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33959, to_date('21-12-2092', 'dd-mm-yyyy'), '7', '21', '356', '12', '2092', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33960, to_date('22-12-2092', 'dd-mm-yyyy'), '1', '22', '357', '12', '2092', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33961, to_date('23-12-2092', 'dd-mm-yyyy'), '2', '23', '358', '12', '2092', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33962, to_date('24-12-2092', 'dd-mm-yyyy'), '3', '24', '359', '12', '2092', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33963, to_date('25-12-2092', 'dd-mm-yyyy'), '4', '25', '360', '12', '2092', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33964, to_date('26-12-2092', 'dd-mm-yyyy'), '5', '26', '361', '12', '2092', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33965, to_date('27-12-2092', 'dd-mm-yyyy'), '6', '27', '362', '12', '2092', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33966, to_date('28-12-2092', 'dd-mm-yyyy'), '7', '28', '363', '12', '2092', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33967, to_date('29-12-2092', 'dd-mm-yyyy'), '1', '29', '364', '12', '2092', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33968, to_date('30-12-2092', 'dd-mm-yyyy'), '2', '30', '365', '12', '2092', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33969, to_date('31-12-2092', 'dd-mm-yyyy'), '3', '31', '366', '12', '2092', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33970, to_date('01-01-2093', 'dd-mm-yyyy'), '4', '01', '001', '01', '2093', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33971, to_date('02-01-2093', 'dd-mm-yyyy'), '5', '02', '002', '01', '2093', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33972, to_date('03-01-2093', 'dd-mm-yyyy'), '6', '03', '003', '01', '2093', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33973, to_date('04-01-2093', 'dd-mm-yyyy'), '7', '04', '004', '01', '2093', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33974, to_date('05-01-2093', 'dd-mm-yyyy'), '1', '05', '005', '01', '2093', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33975, to_date('06-01-2093', 'dd-mm-yyyy'), '2', '06', '006', '01', '2093', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33976, to_date('07-01-2093', 'dd-mm-yyyy'), '3', '07', '007', '01', '2093', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33977, to_date('08-01-2093', 'dd-mm-yyyy'), '4', '08', '008', '01', '2093', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33978, to_date('09-01-2093', 'dd-mm-yyyy'), '5', '09', '009', '01', '2093', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33979, to_date('10-01-2093', 'dd-mm-yyyy'), '6', '10', '010', '01', '2093', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33980, to_date('11-01-2093', 'dd-mm-yyyy'), '7', '11', '011', '01', '2093', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33981, to_date('12-01-2093', 'dd-mm-yyyy'), '1', '12', '012', '01', '2093', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33982, to_date('13-01-2093', 'dd-mm-yyyy'), '2', '13', '013', '01', '2093', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33983, to_date('14-01-2093', 'dd-mm-yyyy'), '3', '14', '014', '01', '2093', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33984, to_date('15-01-2093', 'dd-mm-yyyy'), '4', '15', '015', '01', '2093', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33985, to_date('16-01-2093', 'dd-mm-yyyy'), '5', '16', '016', '01', '2093', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33986, to_date('17-01-2093', 'dd-mm-yyyy'), '6', '17', '017', '01', '2093', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33987, to_date('18-01-2093', 'dd-mm-yyyy'), '7', '18', '018', '01', '2093', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33988, to_date('19-01-2093', 'dd-mm-yyyy'), '1', '19', '019', '01', '2093', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33989, to_date('20-01-2093', 'dd-mm-yyyy'), '2', '20', '020', '01', '2093', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33990, to_date('21-01-2093', 'dd-mm-yyyy'), '3', '21', '021', '01', '2093', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33991, to_date('22-01-2093', 'dd-mm-yyyy'), '4', '22', '022', '01', '2093', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33992, to_date('23-01-2093', 'dd-mm-yyyy'), '5', '23', '023', '01', '2093', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33993, to_date('24-01-2093', 'dd-mm-yyyy'), '6', '24', '024', '01', '2093', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33994, to_date('25-01-2093', 'dd-mm-yyyy'), '7', '25', '025', '01', '2093', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33995, to_date('26-01-2093', 'dd-mm-yyyy'), '1', '26', '026', '01', '2093', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33996, to_date('27-01-2093', 'dd-mm-yyyy'), '2', '27', '027', '01', '2093', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33997, to_date('28-01-2093', 'dd-mm-yyyy'), '3', '28', '028', '01', '2093', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33998, to_date('29-01-2093', 'dd-mm-yyyy'), '4', '29', '029', '01', '2093', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (33999, to_date('30-01-2093', 'dd-mm-yyyy'), '5', '30', '030', '01', '2093', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34000, to_date('31-01-2093', 'dd-mm-yyyy'), '6', '31', '031', '01', '2093', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35485, to_date('24-02-2097', 'dd-mm-yyyy'), '7', '24', '055', '02', '2097', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
commit;
prompt 29000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35486, to_date('25-02-2097', 'dd-mm-yyyy'), '1', '25', '056', '02', '2097', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35487, to_date('26-02-2097', 'dd-mm-yyyy'), '2', '26', '057', '02', '2097', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35488, to_date('27-02-2097', 'dd-mm-yyyy'), '3', '27', '058', '02', '2097', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35489, to_date('28-02-2097', 'dd-mm-yyyy'), '4', '28', '059', '02', '2097', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35490, to_date('01-03-2097', 'dd-mm-yyyy'), '5', '01', '060', '03', '2097', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35491, to_date('02-03-2097', 'dd-mm-yyyy'), '6', '02', '061', '03', '2097', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35492, to_date('03-03-2097', 'dd-mm-yyyy'), '7', '03', '062', '03', '2097', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35493, to_date('04-03-2097', 'dd-mm-yyyy'), '1', '04', '063', '03', '2097', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35494, to_date('05-03-2097', 'dd-mm-yyyy'), '2', '05', '064', '03', '2097', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35495, to_date('06-03-2097', 'dd-mm-yyyy'), '3', '06', '065', '03', '2097', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35496, to_date('07-03-2097', 'dd-mm-yyyy'), '4', '07', '066', '03', '2097', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35497, to_date('08-03-2097', 'dd-mm-yyyy'), '5', '08', '067', '03', '2097', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35498, to_date('09-03-2097', 'dd-mm-yyyy'), '6', '09', '068', '03', '2097', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35499, to_date('10-03-2097', 'dd-mm-yyyy'), '7', '10', '069', '03', '2097', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35500, to_date('11-03-2097', 'dd-mm-yyyy'), '1', '11', '070', '03', '2097', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35501, to_date('12-03-2097', 'dd-mm-yyyy'), '2', '12', '071', '03', '2097', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35502, to_date('13-03-2097', 'dd-mm-yyyy'), '3', '13', '072', '03', '2097', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35503, to_date('14-03-2097', 'dd-mm-yyyy'), '4', '14', '073', '03', '2097', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35504, to_date('15-03-2097', 'dd-mm-yyyy'), '5', '15', '074', '03', '2097', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35505, to_date('16-03-2097', 'dd-mm-yyyy'), '6', '16', '075', '03', '2097', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35506, to_date('17-03-2097', 'dd-mm-yyyy'), '7', '17', '076', '03', '2097', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35507, to_date('18-03-2097', 'dd-mm-yyyy'), '1', '18', '077', '03', '2097', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35508, to_date('19-03-2097', 'dd-mm-yyyy'), '2', '19', '078', '03', '2097', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35509, to_date('20-03-2097', 'dd-mm-yyyy'), '3', '20', '079', '03', '2097', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35510, to_date('21-03-2097', 'dd-mm-yyyy'), '4', '21', '080', '03', '2097', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35511, to_date('22-03-2097', 'dd-mm-yyyy'), '5', '22', '081', '03', '2097', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35512, to_date('23-03-2097', 'dd-mm-yyyy'), '6', '23', '082', '03', '2097', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35513, to_date('24-03-2097', 'dd-mm-yyyy'), '7', '24', '083', '03', '2097', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35514, to_date('25-03-2097', 'dd-mm-yyyy'), '1', '25', '084', '03', '2097', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35515, to_date('26-03-2097', 'dd-mm-yyyy'), '2', '26', '085', '03', '2097', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35516, to_date('27-03-2097', 'dd-mm-yyyy'), '3', '27', '086', '03', '2097', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35517, to_date('28-03-2097', 'dd-mm-yyyy'), '4', '28', '087', '03', '2097', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35518, to_date('29-03-2097', 'dd-mm-yyyy'), '5', '29', '088', '03', '2097', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35519, to_date('30-03-2097', 'dd-mm-yyyy'), '6', '30', '089', '03', '2097', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35520, to_date('31-03-2097', 'dd-mm-yyyy'), '7', '31', '090', '03', '2097', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35521, to_date('01-04-2097', 'dd-mm-yyyy'), '1', '01', '091', '04', '2097', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35522, to_date('02-04-2097', 'dd-mm-yyyy'), '2', '02', '092', '04', '2097', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35523, to_date('03-04-2097', 'dd-mm-yyyy'), '3', '03', '093', '04', '2097', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35524, to_date('04-04-2097', 'dd-mm-yyyy'), '4', '04', '094', '04', '2097', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35525, to_date('05-04-2097', 'dd-mm-yyyy'), '5', '05', '095', '04', '2097', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35526, to_date('06-04-2097', 'dd-mm-yyyy'), '6', '06', '096', '04', '2097', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35527, to_date('07-04-2097', 'dd-mm-yyyy'), '7', '07', '097', '04', '2097', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35528, to_date('08-04-2097', 'dd-mm-yyyy'), '1', '08', '098', '04', '2097', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35529, to_date('09-04-2097', 'dd-mm-yyyy'), '2', '09', '099', '04', '2097', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35530, to_date('10-04-2097', 'dd-mm-yyyy'), '3', '10', '100', '04', '2097', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35531, to_date('11-04-2097', 'dd-mm-yyyy'), '4', '11', '101', '04', '2097', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35532, to_date('12-04-2097', 'dd-mm-yyyy'), '5', '12', '102', '04', '2097', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35533, to_date('13-04-2097', 'dd-mm-yyyy'), '6', '13', '103', '04', '2097', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35534, to_date('14-04-2097', 'dd-mm-yyyy'), '7', '14', '104', '04', '2097', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35535, to_date('15-04-2097', 'dd-mm-yyyy'), '1', '15', '105', '04', '2097', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35536, to_date('16-04-2097', 'dd-mm-yyyy'), '2', '16', '106', '04', '2097', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35537, to_date('17-04-2097', 'dd-mm-yyyy'), '3', '17', '107', '04', '2097', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35538, to_date('18-04-2097', 'dd-mm-yyyy'), '4', '18', '108', '04', '2097', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35539, to_date('19-04-2097', 'dd-mm-yyyy'), '5', '19', '109', '04', '2097', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35540, to_date('20-04-2097', 'dd-mm-yyyy'), '6', '20', '110', '04', '2097', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35541, to_date('21-04-2097', 'dd-mm-yyyy'), '7', '21', '111', '04', '2097', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35542, to_date('22-04-2097', 'dd-mm-yyyy'), '1', '22', '112', '04', '2097', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35543, to_date('23-04-2097', 'dd-mm-yyyy'), '2', '23', '113', '04', '2097', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35544, to_date('24-04-2097', 'dd-mm-yyyy'), '3', '24', '114', '04', '2097', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35545, to_date('25-04-2097', 'dd-mm-yyyy'), '4', '25', '115', '04', '2097', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35546, to_date('26-04-2097', 'dd-mm-yyyy'), '5', '26', '116', '04', '2097', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35547, to_date('27-04-2097', 'dd-mm-yyyy'), '6', '27', '117', '04', '2097', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35548, to_date('28-04-2097', 'dd-mm-yyyy'), '7', '28', '118', '04', '2097', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35549, to_date('29-04-2097', 'dd-mm-yyyy'), '1', '29', '119', '04', '2097', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35550, to_date('30-04-2097', 'dd-mm-yyyy'), '2', '30', '120', '04', '2097', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35551, to_date('01-05-2097', 'dd-mm-yyyy'), '3', '01', '121', '05', '2097', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35552, to_date('02-05-2097', 'dd-mm-yyyy'), '4', '02', '122', '05', '2097', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35553, to_date('03-05-2097', 'dd-mm-yyyy'), '5', '03', '123', '05', '2097', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35554, to_date('04-05-2097', 'dd-mm-yyyy'), '6', '04', '124', '05', '2097', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35555, to_date('05-05-2097', 'dd-mm-yyyy'), '7', '05', '125', '05', '2097', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35556, to_date('06-05-2097', 'dd-mm-yyyy'), '1', '06', '126', '05', '2097', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35557, to_date('07-05-2097', 'dd-mm-yyyy'), '2', '07', '127', '05', '2097', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35558, to_date('08-05-2097', 'dd-mm-yyyy'), '3', '08', '128', '05', '2097', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35559, to_date('09-05-2097', 'dd-mm-yyyy'), '4', '09', '129', '05', '2097', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35560, to_date('10-05-2097', 'dd-mm-yyyy'), '5', '10', '130', '05', '2097', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35561, to_date('11-05-2097', 'dd-mm-yyyy'), '6', '11', '131', '05', '2097', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35562, to_date('12-05-2097', 'dd-mm-yyyy'), '7', '12', '132', '05', '2097', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35563, to_date('13-05-2097', 'dd-mm-yyyy'), '1', '13', '133', '05', '2097', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35564, to_date('14-05-2097', 'dd-mm-yyyy'), '2', '14', '134', '05', '2097', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35565, to_date('15-05-2097', 'dd-mm-yyyy'), '3', '15', '135', '05', '2097', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35566, to_date('16-05-2097', 'dd-mm-yyyy'), '4', '16', '136', '05', '2097', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35567, to_date('17-05-2097', 'dd-mm-yyyy'), '5', '17', '137', '05', '2097', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35568, to_date('18-05-2097', 'dd-mm-yyyy'), '6', '18', '138', '05', '2097', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35569, to_date('19-05-2097', 'dd-mm-yyyy'), '7', '19', '139', '05', '2097', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35570, to_date('20-05-2097', 'dd-mm-yyyy'), '1', '20', '140', '05', '2097', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35571, to_date('21-05-2097', 'dd-mm-yyyy'), '2', '21', '141', '05', '2097', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35572, to_date('22-05-2097', 'dd-mm-yyyy'), '3', '22', '142', '05', '2097', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35573, to_date('23-05-2097', 'dd-mm-yyyy'), '4', '23', '143', '05', '2097', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35574, to_date('24-05-2097', 'dd-mm-yyyy'), '5', '24', '144', '05', '2097', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35575, to_date('25-05-2097', 'dd-mm-yyyy'), '6', '25', '145', '05', '2097', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35576, to_date('26-05-2097', 'dd-mm-yyyy'), '7', '26', '146', '05', '2097', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35577, to_date('27-05-2097', 'dd-mm-yyyy'), '1', '27', '147', '05', '2097', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35578, to_date('28-05-2097', 'dd-mm-yyyy'), '2', '28', '148', '05', '2097', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35579, to_date('29-05-2097', 'dd-mm-yyyy'), '3', '29', '149', '05', '2097', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35580, to_date('30-05-2097', 'dd-mm-yyyy'), '4', '30', '150', '05', '2097', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35581, to_date('31-05-2097', 'dd-mm-yyyy'), '5', '31', '151', '05', '2097', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35582, to_date('01-06-2097', 'dd-mm-yyyy'), '6', '01', '152', '06', '2097', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35583, to_date('02-06-2097', 'dd-mm-yyyy'), '7', '02', '153', '06', '2097', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35584, to_date('03-06-2097', 'dd-mm-yyyy'), '1', '03', '154', '06', '2097', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35585, to_date('04-06-2097', 'dd-mm-yyyy'), '2', '04', '155', '06', '2097', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35586, to_date('05-06-2097', 'dd-mm-yyyy'), '3', '05', '156', '06', '2097', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35587, to_date('06-06-2097', 'dd-mm-yyyy'), '4', '06', '157', '06', '2097', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35588, to_date('07-06-2097', 'dd-mm-yyyy'), '5', '07', '158', '06', '2097', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35589, to_date('08-06-2097', 'dd-mm-yyyy'), '6', '08', '159', '06', '2097', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35590, to_date('09-06-2097', 'dd-mm-yyyy'), '7', '09', '160', '06', '2097', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34001, to_date('01-02-2093', 'dd-mm-yyyy'), '7', '01', '032', '02', '2093', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34002, to_date('02-02-2093', 'dd-mm-yyyy'), '1', '02', '033', '02', '2093', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34003, to_date('03-02-2093', 'dd-mm-yyyy'), '2', '03', '034', '02', '2093', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34004, to_date('04-02-2093', 'dd-mm-yyyy'), '3', '04', '035', '02', '2093', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34005, to_date('05-02-2093', 'dd-mm-yyyy'), '4', '05', '036', '02', '2093', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34006, to_date('06-02-2093', 'dd-mm-yyyy'), '5', '06', '037', '02', '2093', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34007, to_date('07-02-2093', 'dd-mm-yyyy'), '6', '07', '038', '02', '2093', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34008, to_date('08-02-2093', 'dd-mm-yyyy'), '7', '08', '039', '02', '2093', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34009, to_date('09-02-2093', 'dd-mm-yyyy'), '1', '09', '040', '02', '2093', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34010, to_date('10-02-2093', 'dd-mm-yyyy'), '2', '10', '041', '02', '2093', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34011, to_date('11-02-2093', 'dd-mm-yyyy'), '3', '11', '042', '02', '2093', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34012, to_date('12-02-2093', 'dd-mm-yyyy'), '4', '12', '043', '02', '2093', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34013, to_date('13-02-2093', 'dd-mm-yyyy'), '5', '13', '044', '02', '2093', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34014, to_date('14-02-2093', 'dd-mm-yyyy'), '6', '14', '045', '02', '2093', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34015, to_date('15-02-2093', 'dd-mm-yyyy'), '7', '15', '046', '02', '2093', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34016, to_date('16-02-2093', 'dd-mm-yyyy'), '1', '16', '047', '02', '2093', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34017, to_date('17-02-2093', 'dd-mm-yyyy'), '2', '17', '048', '02', '2093', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34018, to_date('18-02-2093', 'dd-mm-yyyy'), '3', '18', '049', '02', '2093', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34019, to_date('19-02-2093', 'dd-mm-yyyy'), '4', '19', '050', '02', '2093', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34020, to_date('20-02-2093', 'dd-mm-yyyy'), '5', '20', '051', '02', '2093', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34021, to_date('21-02-2093', 'dd-mm-yyyy'), '6', '21', '052', '02', '2093', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34022, to_date('22-02-2093', 'dd-mm-yyyy'), '7', '22', '053', '02', '2093', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34023, to_date('23-02-2093', 'dd-mm-yyyy'), '1', '23', '054', '02', '2093', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34024, to_date('24-02-2093', 'dd-mm-yyyy'), '2', '24', '055', '02', '2093', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34025, to_date('25-02-2093', 'dd-mm-yyyy'), '3', '25', '056', '02', '2093', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34026, to_date('26-02-2093', 'dd-mm-yyyy'), '4', '26', '057', '02', '2093', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34027, to_date('27-02-2093', 'dd-mm-yyyy'), '5', '27', '058', '02', '2093', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34028, to_date('28-02-2093', 'dd-mm-yyyy'), '6', '28', '059', '02', '2093', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34029, to_date('01-03-2093', 'dd-mm-yyyy'), '7', '01', '060', '03', '2093', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34030, to_date('02-03-2093', 'dd-mm-yyyy'), '1', '02', '061', '03', '2093', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34031, to_date('03-03-2093', 'dd-mm-yyyy'), '2', '03', '062', '03', '2093', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34032, to_date('04-03-2093', 'dd-mm-yyyy'), '3', '04', '063', '03', '2093', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34033, to_date('05-03-2093', 'dd-mm-yyyy'), '4', '05', '064', '03', '2093', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34034, to_date('06-03-2093', 'dd-mm-yyyy'), '5', '06', '065', '03', '2093', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34035, to_date('07-03-2093', 'dd-mm-yyyy'), '6', '07', '066', '03', '2093', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34036, to_date('08-03-2093', 'dd-mm-yyyy'), '7', '08', '067', '03', '2093', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34037, to_date('09-03-2093', 'dd-mm-yyyy'), '1', '09', '068', '03', '2093', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34038, to_date('10-03-2093', 'dd-mm-yyyy'), '2', '10', '069', '03', '2093', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34039, to_date('11-03-2093', 'dd-mm-yyyy'), '3', '11', '070', '03', '2093', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34040, to_date('12-03-2093', 'dd-mm-yyyy'), '4', '12', '071', '03', '2093', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34041, to_date('13-03-2093', 'dd-mm-yyyy'), '5', '13', '072', '03', '2093', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34042, to_date('14-03-2093', 'dd-mm-yyyy'), '6', '14', '073', '03', '2093', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34043, to_date('15-03-2093', 'dd-mm-yyyy'), '7', '15', '074', '03', '2093', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34044, to_date('16-03-2093', 'dd-mm-yyyy'), '1', '16', '075', '03', '2093', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34045, to_date('17-03-2093', 'dd-mm-yyyy'), '2', '17', '076', '03', '2093', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34046, to_date('18-03-2093', 'dd-mm-yyyy'), '3', '18', '077', '03', '2093', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34047, to_date('19-03-2093', 'dd-mm-yyyy'), '4', '19', '078', '03', '2093', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34048, to_date('20-03-2093', 'dd-mm-yyyy'), '5', '20', '079', '03', '2093', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34049, to_date('21-03-2093', 'dd-mm-yyyy'), '6', '21', '080', '03', '2093', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34050, to_date('22-03-2093', 'dd-mm-yyyy'), '7', '22', '081', '03', '2093', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34051, to_date('23-03-2093', 'dd-mm-yyyy'), '1', '23', '082', '03', '2093', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34052, to_date('24-03-2093', 'dd-mm-yyyy'), '2', '24', '083', '03', '2093', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34053, to_date('25-03-2093', 'dd-mm-yyyy'), '3', '25', '084', '03', '2093', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34054, to_date('26-03-2093', 'dd-mm-yyyy'), '4', '26', '085', '03', '2093', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34055, to_date('27-03-2093', 'dd-mm-yyyy'), '5', '27', '086', '03', '2093', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34056, to_date('28-03-2093', 'dd-mm-yyyy'), '6', '28', '087', '03', '2093', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34057, to_date('29-03-2093', 'dd-mm-yyyy'), '7', '29', '088', '03', '2093', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34058, to_date('30-03-2093', 'dd-mm-yyyy'), '1', '30', '089', '03', '2093', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34059, to_date('31-03-2093', 'dd-mm-yyyy'), '2', '31', '090', '03', '2093', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34060, to_date('01-04-2093', 'dd-mm-yyyy'), '3', '01', '091', '04', '2093', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34061, to_date('02-04-2093', 'dd-mm-yyyy'), '4', '02', '092', '04', '2093', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34062, to_date('03-04-2093', 'dd-mm-yyyy'), '5', '03', '093', '04', '2093', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34063, to_date('04-04-2093', 'dd-mm-yyyy'), '6', '04', '094', '04', '2093', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34064, to_date('05-04-2093', 'dd-mm-yyyy'), '7', '05', '095', '04', '2093', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34065, to_date('06-04-2093', 'dd-mm-yyyy'), '1', '06', '096', '04', '2093', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34066, to_date('07-04-2093', 'dd-mm-yyyy'), '2', '07', '097', '04', '2093', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34067, to_date('08-04-2093', 'dd-mm-yyyy'), '3', '08', '098', '04', '2093', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34068, to_date('09-04-2093', 'dd-mm-yyyy'), '4', '09', '099', '04', '2093', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34069, to_date('10-04-2093', 'dd-mm-yyyy'), '5', '10', '100', '04', '2093', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34070, to_date('11-04-2093', 'dd-mm-yyyy'), '6', '11', '101', '04', '2093', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34071, to_date('12-04-2093', 'dd-mm-yyyy'), '7', '12', '102', '04', '2093', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34072, to_date('13-04-2093', 'dd-mm-yyyy'), '1', '13', '103', '04', '2093', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34073, to_date('14-04-2093', 'dd-mm-yyyy'), '2', '14', '104', '04', '2093', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34074, to_date('15-04-2093', 'dd-mm-yyyy'), '3', '15', '105', '04', '2093', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34075, to_date('16-04-2093', 'dd-mm-yyyy'), '4', '16', '106', '04', '2093', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34076, to_date('17-04-2093', 'dd-mm-yyyy'), '5', '17', '107', '04', '2093', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34077, to_date('18-04-2093', 'dd-mm-yyyy'), '6', '18', '108', '04', '2093', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34078, to_date('19-04-2093', 'dd-mm-yyyy'), '7', '19', '109', '04', '2093', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34079, to_date('20-04-2093', 'dd-mm-yyyy'), '1', '20', '110', '04', '2093', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34080, to_date('21-04-2093', 'dd-mm-yyyy'), '2', '21', '111', '04', '2093', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34081, to_date('22-04-2093', 'dd-mm-yyyy'), '3', '22', '112', '04', '2093', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34082, to_date('23-04-2093', 'dd-mm-yyyy'), '4', '23', '113', '04', '2093', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34083, to_date('24-04-2093', 'dd-mm-yyyy'), '5', '24', '114', '04', '2093', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34084, to_date('25-04-2093', 'dd-mm-yyyy'), '6', '25', '115', '04', '2093', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34085, to_date('26-04-2093', 'dd-mm-yyyy'), '7', '26', '116', '04', '2093', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34086, to_date('27-04-2093', 'dd-mm-yyyy'), '1', '27', '117', '04', '2093', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34087, to_date('28-04-2093', 'dd-mm-yyyy'), '2', '28', '118', '04', '2093', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34088, to_date('29-04-2093', 'dd-mm-yyyy'), '3', '29', '119', '04', '2093', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34089, to_date('30-04-2093', 'dd-mm-yyyy'), '4', '30', '120', '04', '2093', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34090, to_date('01-05-2093', 'dd-mm-yyyy'), '5', '01', '121', '05', '2093', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34091, to_date('02-05-2093', 'dd-mm-yyyy'), '6', '02', '122', '05', '2093', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34092, to_date('03-05-2093', 'dd-mm-yyyy'), '7', '03', '123', '05', '2093', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34093, to_date('04-05-2093', 'dd-mm-yyyy'), '1', '04', '124', '05', '2093', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34094, to_date('05-05-2093', 'dd-mm-yyyy'), '2', '05', '125', '05', '2093', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34095, to_date('06-05-2093', 'dd-mm-yyyy'), '3', '06', '126', '05', '2093', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34096, to_date('07-05-2093', 'dd-mm-yyyy'), '4', '07', '127', '05', '2093', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34097, to_date('08-05-2093', 'dd-mm-yyyy'), '5', '08', '128', '05', '2093', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34098, to_date('09-05-2093', 'dd-mm-yyyy'), '6', '09', '129', '05', '2093', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34099, to_date('10-05-2093', 'dd-mm-yyyy'), '7', '10', '130', '05', '2093', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34100, to_date('11-05-2093', 'dd-mm-yyyy'), '1', '11', '131', '05', '2093', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34101, to_date('12-05-2093', 'dd-mm-yyyy'), '2', '12', '132', '05', '2093', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34102, to_date('13-05-2093', 'dd-mm-yyyy'), '3', '13', '133', '05', '2093', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34103, to_date('14-05-2093', 'dd-mm-yyyy'), '4', '14', '134', '05', '2093', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34104, to_date('15-05-2093', 'dd-mm-yyyy'), '5', '15', '135', '05', '2093', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34105, to_date('16-05-2093', 'dd-mm-yyyy'), '6', '16', '136', '05', '2093', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34106, to_date('17-05-2093', 'dd-mm-yyyy'), '7', '17', '137', '05', '2093', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35591, to_date('10-06-2097', 'dd-mm-yyyy'), '1', '10', '161', '06', '2097', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35592, to_date('11-06-2097', 'dd-mm-yyyy'), '2', '11', '162', '06', '2097', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35593, to_date('12-06-2097', 'dd-mm-yyyy'), '3', '12', '163', '06', '2097', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35594, to_date('13-06-2097', 'dd-mm-yyyy'), '4', '13', '164', '06', '2097', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35595, to_date('14-06-2097', 'dd-mm-yyyy'), '5', '14', '165', '06', '2097', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35596, to_date('15-06-2097', 'dd-mm-yyyy'), '6', '15', '166', '06', '2097', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35597, to_date('16-06-2097', 'dd-mm-yyyy'), '7', '16', '167', '06', '2097', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35598, to_date('17-06-2097', 'dd-mm-yyyy'), '1', '17', '168', '06', '2097', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35599, to_date('18-06-2097', 'dd-mm-yyyy'), '2', '18', '169', '06', '2097', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35600, to_date('19-06-2097', 'dd-mm-yyyy'), '3', '19', '170', '06', '2097', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35601, to_date('20-06-2097', 'dd-mm-yyyy'), '4', '20', '171', '06', '2097', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35602, to_date('21-06-2097', 'dd-mm-yyyy'), '5', '21', '172', '06', '2097', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35603, to_date('22-06-2097', 'dd-mm-yyyy'), '6', '22', '173', '06', '2097', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35604, to_date('23-06-2097', 'dd-mm-yyyy'), '7', '23', '174', '06', '2097', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35605, to_date('24-06-2097', 'dd-mm-yyyy'), '1', '24', '175', '06', '2097', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35606, to_date('25-06-2097', 'dd-mm-yyyy'), '2', '25', '176', '06', '2097', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35607, to_date('26-06-2097', 'dd-mm-yyyy'), '3', '26', '177', '06', '2097', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35608, to_date('27-06-2097', 'dd-mm-yyyy'), '4', '27', '178', '06', '2097', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35609, to_date('28-06-2097', 'dd-mm-yyyy'), '5', '28', '179', '06', '2097', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35610, to_date('29-06-2097', 'dd-mm-yyyy'), '6', '29', '180', '06', '2097', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35611, to_date('30-06-2097', 'dd-mm-yyyy'), '7', '30', '181', '06', '2097', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35612, to_date('01-07-2097', 'dd-mm-yyyy'), '1', '01', '182', '07', '2097', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35613, to_date('02-07-2097', 'dd-mm-yyyy'), '2', '02', '183', '07', '2097', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35614, to_date('03-07-2097', 'dd-mm-yyyy'), '3', '03', '184', '07', '2097', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35615, to_date('04-07-2097', 'dd-mm-yyyy'), '4', '04', '185', '07', '2097', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35616, to_date('05-07-2097', 'dd-mm-yyyy'), '5', '05', '186', '07', '2097', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35617, to_date('06-07-2097', 'dd-mm-yyyy'), '6', '06', '187', '07', '2097', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35618, to_date('07-07-2097', 'dd-mm-yyyy'), '7', '07', '188', '07', '2097', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35619, to_date('08-07-2097', 'dd-mm-yyyy'), '1', '08', '189', '07', '2097', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35620, to_date('09-07-2097', 'dd-mm-yyyy'), '2', '09', '190', '07', '2097', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35621, to_date('10-07-2097', 'dd-mm-yyyy'), '3', '10', '191', '07', '2097', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35622, to_date('11-07-2097', 'dd-mm-yyyy'), '4', '11', '192', '07', '2097', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35623, to_date('12-07-2097', 'dd-mm-yyyy'), '5', '12', '193', '07', '2097', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35624, to_date('13-07-2097', 'dd-mm-yyyy'), '6', '13', '194', '07', '2097', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35625, to_date('14-07-2097', 'dd-mm-yyyy'), '7', '14', '195', '07', '2097', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35626, to_date('15-07-2097', 'dd-mm-yyyy'), '1', '15', '196', '07', '2097', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35627, to_date('16-07-2097', 'dd-mm-yyyy'), '2', '16', '197', '07', '2097', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35628, to_date('17-07-2097', 'dd-mm-yyyy'), '3', '17', '198', '07', '2097', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35629, to_date('18-07-2097', 'dd-mm-yyyy'), '4', '18', '199', '07', '2097', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35630, to_date('19-07-2097', 'dd-mm-yyyy'), '5', '19', '200', '07', '2097', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35631, to_date('20-07-2097', 'dd-mm-yyyy'), '6', '20', '201', '07', '2097', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35632, to_date('21-07-2097', 'dd-mm-yyyy'), '7', '21', '202', '07', '2097', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35633, to_date('22-07-2097', 'dd-mm-yyyy'), '1', '22', '203', '07', '2097', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35634, to_date('23-07-2097', 'dd-mm-yyyy'), '2', '23', '204', '07', '2097', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35635, to_date('24-07-2097', 'dd-mm-yyyy'), '3', '24', '205', '07', '2097', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35636, to_date('25-07-2097', 'dd-mm-yyyy'), '4', '25', '206', '07', '2097', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35637, to_date('26-07-2097', 'dd-mm-yyyy'), '5', '26', '207', '07', '2097', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35638, to_date('27-07-2097', 'dd-mm-yyyy'), '6', '27', '208', '07', '2097', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35639, to_date('28-07-2097', 'dd-mm-yyyy'), '7', '28', '209', '07', '2097', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35640, to_date('29-07-2097', 'dd-mm-yyyy'), '1', '29', '210', '07', '2097', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35641, to_date('30-07-2097', 'dd-mm-yyyy'), '2', '30', '211', '07', '2097', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35642, to_date('31-07-2097', 'dd-mm-yyyy'), '3', '31', '212', '07', '2097', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35643, to_date('01-08-2097', 'dd-mm-yyyy'), '4', '01', '213', '08', '2097', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35644, to_date('02-08-2097', 'dd-mm-yyyy'), '5', '02', '214', '08', '2097', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35645, to_date('03-08-2097', 'dd-mm-yyyy'), '6', '03', '215', '08', '2097', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35646, to_date('04-08-2097', 'dd-mm-yyyy'), '7', '04', '216', '08', '2097', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35647, to_date('05-08-2097', 'dd-mm-yyyy'), '1', '05', '217', '08', '2097', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35648, to_date('06-08-2097', 'dd-mm-yyyy'), '2', '06', '218', '08', '2097', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35649, to_date('07-08-2097', 'dd-mm-yyyy'), '3', '07', '219', '08', '2097', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35650, to_date('08-08-2097', 'dd-mm-yyyy'), '4', '08', '220', '08', '2097', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35651, to_date('09-08-2097', 'dd-mm-yyyy'), '5', '09', '221', '08', '2097', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35652, to_date('10-08-2097', 'dd-mm-yyyy'), '6', '10', '222', '08', '2097', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35653, to_date('11-08-2097', 'dd-mm-yyyy'), '7', '11', '223', '08', '2097', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35654, to_date('12-08-2097', 'dd-mm-yyyy'), '1', '12', '224', '08', '2097', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35655, to_date('13-08-2097', 'dd-mm-yyyy'), '2', '13', '225', '08', '2097', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35656, to_date('14-08-2097', 'dd-mm-yyyy'), '3', '14', '226', '08', '2097', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35657, to_date('15-08-2097', 'dd-mm-yyyy'), '4', '15', '227', '08', '2097', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35658, to_date('16-08-2097', 'dd-mm-yyyy'), '5', '16', '228', '08', '2097', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35659, to_date('17-08-2097', 'dd-mm-yyyy'), '6', '17', '229', '08', '2097', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35660, to_date('18-08-2097', 'dd-mm-yyyy'), '7', '18', '230', '08', '2097', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35661, to_date('19-08-2097', 'dd-mm-yyyy'), '1', '19', '231', '08', '2097', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35662, to_date('20-08-2097', 'dd-mm-yyyy'), '2', '20', '232', '08', '2097', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35663, to_date('21-08-2097', 'dd-mm-yyyy'), '3', '21', '233', '08', '2097', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35664, to_date('22-08-2097', 'dd-mm-yyyy'), '4', '22', '234', '08', '2097', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35665, to_date('23-08-2097', 'dd-mm-yyyy'), '5', '23', '235', '08', '2097', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35666, to_date('24-08-2097', 'dd-mm-yyyy'), '6', '24', '236', '08', '2097', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35667, to_date('25-08-2097', 'dd-mm-yyyy'), '7', '25', '237', '08', '2097', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35668, to_date('26-08-2097', 'dd-mm-yyyy'), '1', '26', '238', '08', '2097', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35669, to_date('27-08-2097', 'dd-mm-yyyy'), '2', '27', '239', '08', '2097', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35670, to_date('28-08-2097', 'dd-mm-yyyy'), '3', '28', '240', '08', '2097', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35671, to_date('29-08-2097', 'dd-mm-yyyy'), '4', '29', '241', '08', '2097', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35672, to_date('30-08-2097', 'dd-mm-yyyy'), '5', '30', '242', '08', '2097', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35673, to_date('31-08-2097', 'dd-mm-yyyy'), '6', '31', '243', '08', '2097', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35674, to_date('01-09-2097', 'dd-mm-yyyy'), '7', '01', '244', '09', '2097', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35675, to_date('02-09-2097', 'dd-mm-yyyy'), '1', '02', '245', '09', '2097', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35676, to_date('03-09-2097', 'dd-mm-yyyy'), '2', '03', '246', '09', '2097', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35677, to_date('04-09-2097', 'dd-mm-yyyy'), '3', '04', '247', '09', '2097', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35678, to_date('05-09-2097', 'dd-mm-yyyy'), '4', '05', '248', '09', '2097', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35679, to_date('06-09-2097', 'dd-mm-yyyy'), '5', '06', '249', '09', '2097', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35680, to_date('07-09-2097', 'dd-mm-yyyy'), '6', '07', '250', '09', '2097', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35681, to_date('08-09-2097', 'dd-mm-yyyy'), '7', '08', '251', '09', '2097', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35682, to_date('09-09-2097', 'dd-mm-yyyy'), '1', '09', '252', '09', '2097', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35683, to_date('10-09-2097', 'dd-mm-yyyy'), '2', '10', '253', '09', '2097', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35684, to_date('11-09-2097', 'dd-mm-yyyy'), '3', '11', '254', '09', '2097', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35685, to_date('12-09-2097', 'dd-mm-yyyy'), '4', '12', '255', '09', '2097', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35686, to_date('13-09-2097', 'dd-mm-yyyy'), '5', '13', '256', '09', '2097', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35687, to_date('14-09-2097', 'dd-mm-yyyy'), '6', '14', '257', '09', '2097', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35688, to_date('15-09-2097', 'dd-mm-yyyy'), '7', '15', '258', '09', '2097', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35689, to_date('16-09-2097', 'dd-mm-yyyy'), '1', '16', '259', '09', '2097', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35690, to_date('17-09-2097', 'dd-mm-yyyy'), '2', '17', '260', '09', '2097', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35691, to_date('18-09-2097', 'dd-mm-yyyy'), '3', '18', '261', '09', '2097', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35692, to_date('19-09-2097', 'dd-mm-yyyy'), '4', '19', '262', '09', '2097', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35693, to_date('20-09-2097', 'dd-mm-yyyy'), '5', '20', '263', '09', '2097', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35694, to_date('21-09-2097', 'dd-mm-yyyy'), '6', '21', '264', '09', '2097', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35695, to_date('22-09-2097', 'dd-mm-yyyy'), '7', '22', '265', '09', '2097', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35696, to_date('23-09-2097', 'dd-mm-yyyy'), '1', '23', '266', '09', '2097', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34107, to_date('18-05-2093', 'dd-mm-yyyy'), '1', '18', '138', '05', '2093', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34108, to_date('19-05-2093', 'dd-mm-yyyy'), '2', '19', '139', '05', '2093', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34109, to_date('20-05-2093', 'dd-mm-yyyy'), '3', '20', '140', '05', '2093', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34110, to_date('21-05-2093', 'dd-mm-yyyy'), '4', '21', '141', '05', '2093', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34111, to_date('22-05-2093', 'dd-mm-yyyy'), '5', '22', '142', '05', '2093', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34112, to_date('23-05-2093', 'dd-mm-yyyy'), '6', '23', '143', '05', '2093', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34113, to_date('24-05-2093', 'dd-mm-yyyy'), '7', '24', '144', '05', '2093', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34114, to_date('25-05-2093', 'dd-mm-yyyy'), '1', '25', '145', '05', '2093', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34115, to_date('26-05-2093', 'dd-mm-yyyy'), '2', '26', '146', '05', '2093', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34116, to_date('27-05-2093', 'dd-mm-yyyy'), '3', '27', '147', '05', '2093', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34117, to_date('28-05-2093', 'dd-mm-yyyy'), '4', '28', '148', '05', '2093', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34118, to_date('29-05-2093', 'dd-mm-yyyy'), '5', '29', '149', '05', '2093', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34119, to_date('30-05-2093', 'dd-mm-yyyy'), '6', '30', '150', '05', '2093', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34120, to_date('31-05-2093', 'dd-mm-yyyy'), '7', '31', '151', '05', '2093', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34121, to_date('01-06-2093', 'dd-mm-yyyy'), '1', '01', '152', '06', '2093', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34122, to_date('02-06-2093', 'dd-mm-yyyy'), '2', '02', '153', '06', '2093', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34123, to_date('03-06-2093', 'dd-mm-yyyy'), '3', '03', '154', '06', '2093', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34124, to_date('04-06-2093', 'dd-mm-yyyy'), '4', '04', '155', '06', '2093', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34125, to_date('05-06-2093', 'dd-mm-yyyy'), '5', '05', '156', '06', '2093', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34126, to_date('06-06-2093', 'dd-mm-yyyy'), '6', '06', '157', '06', '2093', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34127, to_date('07-06-2093', 'dd-mm-yyyy'), '7', '07', '158', '06', '2093', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34128, to_date('08-06-2093', 'dd-mm-yyyy'), '1', '08', '159', '06', '2093', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34129, to_date('09-06-2093', 'dd-mm-yyyy'), '2', '09', '160', '06', '2093', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34130, to_date('10-06-2093', 'dd-mm-yyyy'), '3', '10', '161', '06', '2093', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34131, to_date('11-06-2093', 'dd-mm-yyyy'), '4', '11', '162', '06', '2093', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34132, to_date('12-06-2093', 'dd-mm-yyyy'), '5', '12', '163', '06', '2093', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34133, to_date('13-06-2093', 'dd-mm-yyyy'), '6', '13', '164', '06', '2093', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34134, to_date('14-06-2093', 'dd-mm-yyyy'), '7', '14', '165', '06', '2093', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34135, to_date('15-06-2093', 'dd-mm-yyyy'), '1', '15', '166', '06', '2093', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34136, to_date('16-06-2093', 'dd-mm-yyyy'), '2', '16', '167', '06', '2093', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34137, to_date('17-06-2093', 'dd-mm-yyyy'), '3', '17', '168', '06', '2093', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34138, to_date('18-06-2093', 'dd-mm-yyyy'), '4', '18', '169', '06', '2093', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34139, to_date('19-06-2093', 'dd-mm-yyyy'), '5', '19', '170', '06', '2093', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34140, to_date('20-06-2093', 'dd-mm-yyyy'), '6', '20', '171', '06', '2093', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34141, to_date('21-06-2093', 'dd-mm-yyyy'), '7', '21', '172', '06', '2093', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34142, to_date('22-06-2093', 'dd-mm-yyyy'), '1', '22', '173', '06', '2093', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34143, to_date('23-06-2093', 'dd-mm-yyyy'), '2', '23', '174', '06', '2093', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34144, to_date('24-06-2093', 'dd-mm-yyyy'), '3', '24', '175', '06', '2093', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34145, to_date('25-06-2093', 'dd-mm-yyyy'), '4', '25', '176', '06', '2093', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34146, to_date('26-06-2093', 'dd-mm-yyyy'), '5', '26', '177', '06', '2093', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34147, to_date('27-06-2093', 'dd-mm-yyyy'), '6', '27', '178', '06', '2093', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34148, to_date('28-06-2093', 'dd-mm-yyyy'), '7', '28', '179', '06', '2093', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34149, to_date('29-06-2093', 'dd-mm-yyyy'), '1', '29', '180', '06', '2093', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34150, to_date('30-06-2093', 'dd-mm-yyyy'), '2', '30', '181', '06', '2093', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34151, to_date('01-07-2093', 'dd-mm-yyyy'), '3', '01', '182', '07', '2093', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34152, to_date('02-07-2093', 'dd-mm-yyyy'), '4', '02', '183', '07', '2093', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34153, to_date('03-07-2093', 'dd-mm-yyyy'), '5', '03', '184', '07', '2093', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34154, to_date('04-07-2093', 'dd-mm-yyyy'), '6', '04', '185', '07', '2093', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34155, to_date('05-07-2093', 'dd-mm-yyyy'), '7', '05', '186', '07', '2093', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34156, to_date('06-07-2093', 'dd-mm-yyyy'), '1', '06', '187', '07', '2093', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34157, to_date('07-07-2093', 'dd-mm-yyyy'), '2', '07', '188', '07', '2093', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34158, to_date('08-07-2093', 'dd-mm-yyyy'), '3', '08', '189', '07', '2093', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34159, to_date('09-07-2093', 'dd-mm-yyyy'), '4', '09', '190', '07', '2093', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34160, to_date('10-07-2093', 'dd-mm-yyyy'), '5', '10', '191', '07', '2093', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34161, to_date('11-07-2093', 'dd-mm-yyyy'), '6', '11', '192', '07', '2093', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34162, to_date('12-07-2093', 'dd-mm-yyyy'), '7', '12', '193', '07', '2093', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34163, to_date('13-07-2093', 'dd-mm-yyyy'), '1', '13', '194', '07', '2093', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34164, to_date('14-07-2093', 'dd-mm-yyyy'), '2', '14', '195', '07', '2093', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34165, to_date('15-07-2093', 'dd-mm-yyyy'), '3', '15', '196', '07', '2093', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34166, to_date('16-07-2093', 'dd-mm-yyyy'), '4', '16', '197', '07', '2093', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34167, to_date('17-07-2093', 'dd-mm-yyyy'), '5', '17', '198', '07', '2093', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34168, to_date('18-07-2093', 'dd-mm-yyyy'), '6', '18', '199', '07', '2093', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34169, to_date('19-07-2093', 'dd-mm-yyyy'), '7', '19', '200', '07', '2093', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34170, to_date('20-07-2093', 'dd-mm-yyyy'), '1', '20', '201', '07', '2093', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34171, to_date('21-07-2093', 'dd-mm-yyyy'), '2', '21', '202', '07', '2093', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34172, to_date('22-07-2093', 'dd-mm-yyyy'), '3', '22', '203', '07', '2093', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34173, to_date('23-07-2093', 'dd-mm-yyyy'), '4', '23', '204', '07', '2093', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34174, to_date('24-07-2093', 'dd-mm-yyyy'), '5', '24', '205', '07', '2093', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34175, to_date('25-07-2093', 'dd-mm-yyyy'), '6', '25', '206', '07', '2093', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34176, to_date('26-07-2093', 'dd-mm-yyyy'), '7', '26', '207', '07', '2093', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34177, to_date('27-07-2093', 'dd-mm-yyyy'), '1', '27', '208', '07', '2093', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34178, to_date('28-07-2093', 'dd-mm-yyyy'), '2', '28', '209', '07', '2093', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34179, to_date('29-07-2093', 'dd-mm-yyyy'), '3', '29', '210', '07', '2093', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34180, to_date('30-07-2093', 'dd-mm-yyyy'), '4', '30', '211', '07', '2093', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34181, to_date('31-07-2093', 'dd-mm-yyyy'), '5', '31', '212', '07', '2093', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34182, to_date('01-08-2093', 'dd-mm-yyyy'), '6', '01', '213', '08', '2093', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34183, to_date('02-08-2093', 'dd-mm-yyyy'), '7', '02', '214', '08', '2093', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34184, to_date('03-08-2093', 'dd-mm-yyyy'), '1', '03', '215', '08', '2093', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34185, to_date('04-08-2093', 'dd-mm-yyyy'), '2', '04', '216', '08', '2093', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34186, to_date('05-08-2093', 'dd-mm-yyyy'), '3', '05', '217', '08', '2093', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34187, to_date('06-08-2093', 'dd-mm-yyyy'), '4', '06', '218', '08', '2093', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34188, to_date('07-08-2093', 'dd-mm-yyyy'), '5', '07', '219', '08', '2093', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34189, to_date('08-08-2093', 'dd-mm-yyyy'), '6', '08', '220', '08', '2093', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34190, to_date('09-08-2093', 'dd-mm-yyyy'), '7', '09', '221', '08', '2093', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34191, to_date('10-08-2093', 'dd-mm-yyyy'), '1', '10', '222', '08', '2093', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34192, to_date('11-08-2093', 'dd-mm-yyyy'), '2', '11', '223', '08', '2093', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34193, to_date('12-08-2093', 'dd-mm-yyyy'), '3', '12', '224', '08', '2093', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34194, to_date('13-08-2093', 'dd-mm-yyyy'), '4', '13', '225', '08', '2093', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34195, to_date('14-08-2093', 'dd-mm-yyyy'), '5', '14', '226', '08', '2093', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34196, to_date('15-08-2093', 'dd-mm-yyyy'), '6', '15', '227', '08', '2093', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34197, to_date('16-08-2093', 'dd-mm-yyyy'), '7', '16', '228', '08', '2093', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34198, to_date('17-08-2093', 'dd-mm-yyyy'), '1', '17', '229', '08', '2093', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34199, to_date('18-08-2093', 'dd-mm-yyyy'), '2', '18', '230', '08', '2093', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34200, to_date('19-08-2093', 'dd-mm-yyyy'), '3', '19', '231', '08', '2093', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34201, to_date('20-08-2093', 'dd-mm-yyyy'), '4', '20', '232', '08', '2093', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34202, to_date('21-08-2093', 'dd-mm-yyyy'), '5', '21', '233', '08', '2093', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34203, to_date('22-08-2093', 'dd-mm-yyyy'), '6', '22', '234', '08', '2093', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34204, to_date('23-08-2093', 'dd-mm-yyyy'), '7', '23', '235', '08', '2093', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34205, to_date('24-08-2093', 'dd-mm-yyyy'), '1', '24', '236', '08', '2093', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34206, to_date('25-08-2093', 'dd-mm-yyyy'), '2', '25', '237', '08', '2093', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34207, to_date('26-08-2093', 'dd-mm-yyyy'), '3', '26', '238', '08', '2093', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34208, to_date('27-08-2093', 'dd-mm-yyyy'), '4', '27', '239', '08', '2093', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34209, to_date('28-08-2093', 'dd-mm-yyyy'), '5', '28', '240', '08', '2093', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34210, to_date('29-08-2093', 'dd-mm-yyyy'), '6', '29', '241', '08', '2093', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34211, to_date('30-08-2093', 'dd-mm-yyyy'), '7', '30', '242', '08', '2093', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34212, to_date('31-08-2093', 'dd-mm-yyyy'), '1', '31', '243', '08', '2093', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35697, to_date('24-09-2097', 'dd-mm-yyyy'), '2', '24', '267', '09', '2097', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35698, to_date('25-09-2097', 'dd-mm-yyyy'), '3', '25', '268', '09', '2097', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35699, to_date('26-09-2097', 'dd-mm-yyyy'), '4', '26', '269', '09', '2097', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35700, to_date('27-09-2097', 'dd-mm-yyyy'), '5', '27', '270', '09', '2097', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35701, to_date('28-09-2097', 'dd-mm-yyyy'), '6', '28', '271', '09', '2097', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35702, to_date('29-09-2097', 'dd-mm-yyyy'), '7', '29', '272', '09', '2097', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35703, to_date('30-09-2097', 'dd-mm-yyyy'), '1', '30', '273', '09', '2097', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35704, to_date('01-10-2097', 'dd-mm-yyyy'), '2', '01', '274', '10', '2097', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35705, to_date('02-10-2097', 'dd-mm-yyyy'), '3', '02', '275', '10', '2097', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35706, to_date('03-10-2097', 'dd-mm-yyyy'), '4', '03', '276', '10', '2097', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35707, to_date('04-10-2097', 'dd-mm-yyyy'), '5', '04', '277', '10', '2097', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35708, to_date('05-10-2097', 'dd-mm-yyyy'), '6', '05', '278', '10', '2097', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35709, to_date('06-10-2097', 'dd-mm-yyyy'), '7', '06', '279', '10', '2097', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35710, to_date('07-10-2097', 'dd-mm-yyyy'), '1', '07', '280', '10', '2097', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35711, to_date('08-10-2097', 'dd-mm-yyyy'), '2', '08', '281', '10', '2097', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35712, to_date('09-10-2097', 'dd-mm-yyyy'), '3', '09', '282', '10', '2097', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35713, to_date('10-10-2097', 'dd-mm-yyyy'), '4', '10', '283', '10', '2097', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35714, to_date('11-10-2097', 'dd-mm-yyyy'), '5', '11', '284', '10', '2097', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35715, to_date('12-10-2097', 'dd-mm-yyyy'), '6', '12', '285', '10', '2097', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35716, to_date('13-10-2097', 'dd-mm-yyyy'), '7', '13', '286', '10', '2097', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35717, to_date('14-10-2097', 'dd-mm-yyyy'), '1', '14', '287', '10', '2097', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35718, to_date('15-10-2097', 'dd-mm-yyyy'), '2', '15', '288', '10', '2097', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35719, to_date('16-10-2097', 'dd-mm-yyyy'), '3', '16', '289', '10', '2097', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35720, to_date('17-10-2097', 'dd-mm-yyyy'), '4', '17', '290', '10', '2097', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35721, to_date('18-10-2097', 'dd-mm-yyyy'), '5', '18', '291', '10', '2097', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35722, to_date('19-10-2097', 'dd-mm-yyyy'), '6', '19', '292', '10', '2097', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35723, to_date('20-10-2097', 'dd-mm-yyyy'), '7', '20', '293', '10', '2097', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35724, to_date('21-10-2097', 'dd-mm-yyyy'), '1', '21', '294', '10', '2097', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35725, to_date('22-10-2097', 'dd-mm-yyyy'), '2', '22', '295', '10', '2097', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35726, to_date('23-10-2097', 'dd-mm-yyyy'), '3', '23', '296', '10', '2097', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35727, to_date('24-10-2097', 'dd-mm-yyyy'), '4', '24', '297', '10', '2097', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35728, to_date('25-10-2097', 'dd-mm-yyyy'), '5', '25', '298', '10', '2097', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35729, to_date('26-10-2097', 'dd-mm-yyyy'), '6', '26', '299', '10', '2097', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35730, to_date('27-10-2097', 'dd-mm-yyyy'), '7', '27', '300', '10', '2097', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35731, to_date('28-10-2097', 'dd-mm-yyyy'), '1', '28', '301', '10', '2097', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35732, to_date('29-10-2097', 'dd-mm-yyyy'), '2', '29', '302', '10', '2097', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35733, to_date('30-10-2097', 'dd-mm-yyyy'), '3', '30', '303', '10', '2097', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35734, to_date('31-10-2097', 'dd-mm-yyyy'), '4', '31', '304', '10', '2097', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35735, to_date('01-11-2097', 'dd-mm-yyyy'), '5', '01', '305', '11', '2097', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35736, to_date('02-11-2097', 'dd-mm-yyyy'), '6', '02', '306', '11', '2097', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35737, to_date('03-11-2097', 'dd-mm-yyyy'), '7', '03', '307', '11', '2097', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35738, to_date('04-11-2097', 'dd-mm-yyyy'), '1', '04', '308', '11', '2097', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35739, to_date('05-11-2097', 'dd-mm-yyyy'), '2', '05', '309', '11', '2097', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35740, to_date('06-11-2097', 'dd-mm-yyyy'), '3', '06', '310', '11', '2097', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35741, to_date('07-11-2097', 'dd-mm-yyyy'), '4', '07', '311', '11', '2097', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35742, to_date('08-11-2097', 'dd-mm-yyyy'), '5', '08', '312', '11', '2097', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35743, to_date('09-11-2097', 'dd-mm-yyyy'), '6', '09', '313', '11', '2097', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35744, to_date('10-11-2097', 'dd-mm-yyyy'), '7', '10', '314', '11', '2097', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35745, to_date('11-11-2097', 'dd-mm-yyyy'), '1', '11', '315', '11', '2097', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35746, to_date('12-11-2097', 'dd-mm-yyyy'), '2', '12', '316', '11', '2097', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35747, to_date('13-11-2097', 'dd-mm-yyyy'), '3', '13', '317', '11', '2097', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35748, to_date('14-11-2097', 'dd-mm-yyyy'), '4', '14', '318', '11', '2097', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35749, to_date('15-11-2097', 'dd-mm-yyyy'), '5', '15', '319', '11', '2097', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35750, to_date('16-11-2097', 'dd-mm-yyyy'), '6', '16', '320', '11', '2097', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35751, to_date('17-11-2097', 'dd-mm-yyyy'), '7', '17', '321', '11', '2097', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35752, to_date('18-11-2097', 'dd-mm-yyyy'), '1', '18', '322', '11', '2097', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35753, to_date('19-11-2097', 'dd-mm-yyyy'), '2', '19', '323', '11', '2097', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35754, to_date('20-11-2097', 'dd-mm-yyyy'), '3', '20', '324', '11', '2097', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35755, to_date('21-11-2097', 'dd-mm-yyyy'), '4', '21', '325', '11', '2097', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35756, to_date('22-11-2097', 'dd-mm-yyyy'), '5', '22', '326', '11', '2097', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35757, to_date('23-11-2097', 'dd-mm-yyyy'), '6', '23', '327', '11', '2097', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35758, to_date('24-11-2097', 'dd-mm-yyyy'), '7', '24', '328', '11', '2097', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35759, to_date('25-11-2097', 'dd-mm-yyyy'), '1', '25', '329', '11', '2097', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35760, to_date('26-11-2097', 'dd-mm-yyyy'), '2', '26', '330', '11', '2097', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35761, to_date('27-11-2097', 'dd-mm-yyyy'), '3', '27', '331', '11', '2097', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35762, to_date('28-11-2097', 'dd-mm-yyyy'), '4', '28', '332', '11', '2097', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35763, to_date('29-11-2097', 'dd-mm-yyyy'), '5', '29', '333', '11', '2097', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35764, to_date('30-11-2097', 'dd-mm-yyyy'), '6', '30', '334', '11', '2097', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35765, to_date('01-12-2097', 'dd-mm-yyyy'), '7', '01', '335', '12', '2097', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35766, to_date('02-12-2097', 'dd-mm-yyyy'), '1', '02', '336', '12', '2097', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35767, to_date('03-12-2097', 'dd-mm-yyyy'), '2', '03', '337', '12', '2097', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35768, to_date('04-12-2097', 'dd-mm-yyyy'), '3', '04', '338', '12', '2097', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35769, to_date('05-12-2097', 'dd-mm-yyyy'), '4', '05', '339', '12', '2097', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35770, to_date('06-12-2097', 'dd-mm-yyyy'), '5', '06', '340', '12', '2097', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35771, to_date('07-12-2097', 'dd-mm-yyyy'), '6', '07', '341', '12', '2097', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35772, to_date('08-12-2097', 'dd-mm-yyyy'), '7', '08', '342', '12', '2097', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35773, to_date('09-12-2097', 'dd-mm-yyyy'), '1', '09', '343', '12', '2097', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35774, to_date('10-12-2097', 'dd-mm-yyyy'), '2', '10', '344', '12', '2097', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35775, to_date('11-12-2097', 'dd-mm-yyyy'), '3', '11', '345', '12', '2097', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35776, to_date('12-12-2097', 'dd-mm-yyyy'), '4', '12', '346', '12', '2097', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35777, to_date('13-12-2097', 'dd-mm-yyyy'), '5', '13', '347', '12', '2097', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35778, to_date('14-12-2097', 'dd-mm-yyyy'), '6', '14', '348', '12', '2097', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35779, to_date('15-12-2097', 'dd-mm-yyyy'), '7', '15', '349', '12', '2097', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35780, to_date('16-12-2097', 'dd-mm-yyyy'), '1', '16', '350', '12', '2097', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35781, to_date('17-12-2097', 'dd-mm-yyyy'), '2', '17', '351', '12', '2097', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35782, to_date('18-12-2097', 'dd-mm-yyyy'), '3', '18', '352', '12', '2097', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35783, to_date('19-12-2097', 'dd-mm-yyyy'), '4', '19', '353', '12', '2097', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35784, to_date('20-12-2097', 'dd-mm-yyyy'), '5', '20', '354', '12', '2097', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35785, to_date('21-12-2097', 'dd-mm-yyyy'), '6', '21', '355', '12', '2097', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35786, to_date('22-12-2097', 'dd-mm-yyyy'), '7', '22', '356', '12', '2097', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35787, to_date('23-12-2097', 'dd-mm-yyyy'), '1', '23', '357', '12', '2097', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35788, to_date('24-12-2097', 'dd-mm-yyyy'), '2', '24', '358', '12', '2097', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35789, to_date('25-12-2097', 'dd-mm-yyyy'), '3', '25', '359', '12', '2097', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35790, to_date('26-12-2097', 'dd-mm-yyyy'), '4', '26', '360', '12', '2097', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35791, to_date('27-12-2097', 'dd-mm-yyyy'), '5', '27', '361', '12', '2097', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35792, to_date('28-12-2097', 'dd-mm-yyyy'), '6', '28', '362', '12', '2097', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35793, to_date('29-12-2097', 'dd-mm-yyyy'), '7', '29', '363', '12', '2097', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35794, to_date('30-12-2097', 'dd-mm-yyyy'), '1', '30', '364', '12', '2097', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35795, to_date('31-12-2097', 'dd-mm-yyyy'), '2', '31', '365', '12', '2097', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35796, to_date('01-01-2098', 'dd-mm-yyyy'), '3', '01', '001', '01', '2098', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35797, to_date('02-01-2098', 'dd-mm-yyyy'), '4', '02', '002', '01', '2098', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35798, to_date('03-01-2098', 'dd-mm-yyyy'), '5', '03', '003', '01', '2098', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35799, to_date('04-01-2098', 'dd-mm-yyyy'), '6', '04', '004', '01', '2098', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35800, to_date('05-01-2098', 'dd-mm-yyyy'), '7', '05', '005', '01', '2098', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35801, to_date('06-01-2098', 'dd-mm-yyyy'), '1', '06', '006', '01', '2098', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35802, to_date('07-01-2098', 'dd-mm-yyyy'), '2', '07', '007', '01', '2098', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34213, to_date('01-09-2093', 'dd-mm-yyyy'), '2', '01', '244', '09', '2093', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34214, to_date('02-09-2093', 'dd-mm-yyyy'), '3', '02', '245', '09', '2093', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34215, to_date('03-09-2093', 'dd-mm-yyyy'), '4', '03', '246', '09', '2093', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34216, to_date('04-09-2093', 'dd-mm-yyyy'), '5', '04', '247', '09', '2093', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34217, to_date('05-09-2093', 'dd-mm-yyyy'), '6', '05', '248', '09', '2093', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34218, to_date('06-09-2093', 'dd-mm-yyyy'), '7', '06', '249', '09', '2093', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34219, to_date('07-09-2093', 'dd-mm-yyyy'), '1', '07', '250', '09', '2093', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34220, to_date('08-09-2093', 'dd-mm-yyyy'), '2', '08', '251', '09', '2093', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34221, to_date('09-09-2093', 'dd-mm-yyyy'), '3', '09', '252', '09', '2093', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34222, to_date('10-09-2093', 'dd-mm-yyyy'), '4', '10', '253', '09', '2093', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34223, to_date('11-09-2093', 'dd-mm-yyyy'), '5', '11', '254', '09', '2093', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34224, to_date('12-09-2093', 'dd-mm-yyyy'), '6', '12', '255', '09', '2093', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34225, to_date('13-09-2093', 'dd-mm-yyyy'), '7', '13', '256', '09', '2093', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34226, to_date('14-09-2093', 'dd-mm-yyyy'), '1', '14', '257', '09', '2093', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34227, to_date('15-09-2093', 'dd-mm-yyyy'), '2', '15', '258', '09', '2093', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34228, to_date('16-09-2093', 'dd-mm-yyyy'), '3', '16', '259', '09', '2093', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34229, to_date('17-09-2093', 'dd-mm-yyyy'), '4', '17', '260', '09', '2093', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34230, to_date('18-09-2093', 'dd-mm-yyyy'), '5', '18', '261', '09', '2093', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34231, to_date('19-09-2093', 'dd-mm-yyyy'), '6', '19', '262', '09', '2093', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34232, to_date('20-09-2093', 'dd-mm-yyyy'), '7', '20', '263', '09', '2093', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34233, to_date('21-09-2093', 'dd-mm-yyyy'), '1', '21', '264', '09', '2093', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34234, to_date('22-09-2093', 'dd-mm-yyyy'), '2', '22', '265', '09', '2093', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34235, to_date('23-09-2093', 'dd-mm-yyyy'), '3', '23', '266', '09', '2093', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34236, to_date('24-09-2093', 'dd-mm-yyyy'), '4', '24', '267', '09', '2093', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34237, to_date('25-09-2093', 'dd-mm-yyyy'), '5', '25', '268', '09', '2093', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34238, to_date('26-09-2093', 'dd-mm-yyyy'), '6', '26', '269', '09', '2093', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34239, to_date('27-09-2093', 'dd-mm-yyyy'), '7', '27', '270', '09', '2093', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34240, to_date('28-09-2093', 'dd-mm-yyyy'), '1', '28', '271', '09', '2093', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34241, to_date('29-09-2093', 'dd-mm-yyyy'), '2', '29', '272', '09', '2093', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34242, to_date('30-09-2093', 'dd-mm-yyyy'), '3', '30', '273', '09', '2093', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34243, to_date('01-10-2093', 'dd-mm-yyyy'), '4', '01', '274', '10', '2093', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34244, to_date('02-10-2093', 'dd-mm-yyyy'), '5', '02', '275', '10', '2093', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34245, to_date('03-10-2093', 'dd-mm-yyyy'), '6', '03', '276', '10', '2093', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34246, to_date('04-10-2093', 'dd-mm-yyyy'), '7', '04', '277', '10', '2093', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34247, to_date('05-10-2093', 'dd-mm-yyyy'), '1', '05', '278', '10', '2093', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34248, to_date('06-10-2093', 'dd-mm-yyyy'), '2', '06', '279', '10', '2093', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34249, to_date('07-10-2093', 'dd-mm-yyyy'), '3', '07', '280', '10', '2093', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34250, to_date('08-10-2093', 'dd-mm-yyyy'), '4', '08', '281', '10', '2093', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34251, to_date('09-10-2093', 'dd-mm-yyyy'), '5', '09', '282', '10', '2093', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34252, to_date('10-10-2093', 'dd-mm-yyyy'), '6', '10', '283', '10', '2093', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34253, to_date('11-10-2093', 'dd-mm-yyyy'), '7', '11', '284', '10', '2093', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34254, to_date('12-10-2093', 'dd-mm-yyyy'), '1', '12', '285', '10', '2093', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34255, to_date('13-10-2093', 'dd-mm-yyyy'), '2', '13', '286', '10', '2093', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34256, to_date('14-10-2093', 'dd-mm-yyyy'), '3', '14', '287', '10', '2093', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34257, to_date('15-10-2093', 'dd-mm-yyyy'), '4', '15', '288', '10', '2093', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34258, to_date('16-10-2093', 'dd-mm-yyyy'), '5', '16', '289', '10', '2093', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34259, to_date('17-10-2093', 'dd-mm-yyyy'), '6', '17', '290', '10', '2093', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34260, to_date('18-10-2093', 'dd-mm-yyyy'), '7', '18', '291', '10', '2093', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34261, to_date('19-10-2093', 'dd-mm-yyyy'), '1', '19', '292', '10', '2093', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34262, to_date('20-10-2093', 'dd-mm-yyyy'), '2', '20', '293', '10', '2093', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34263, to_date('21-10-2093', 'dd-mm-yyyy'), '3', '21', '294', '10', '2093', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34264, to_date('22-10-2093', 'dd-mm-yyyy'), '4', '22', '295', '10', '2093', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34265, to_date('23-10-2093', 'dd-mm-yyyy'), '5', '23', '296', '10', '2093', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34266, to_date('24-10-2093', 'dd-mm-yyyy'), '6', '24', '297', '10', '2093', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34267, to_date('25-10-2093', 'dd-mm-yyyy'), '7', '25', '298', '10', '2093', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34268, to_date('26-10-2093', 'dd-mm-yyyy'), '1', '26', '299', '10', '2093', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34269, to_date('27-10-2093', 'dd-mm-yyyy'), '2', '27', '300', '10', '2093', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34270, to_date('28-10-2093', 'dd-mm-yyyy'), '3', '28', '301', '10', '2093', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34271, to_date('29-10-2093', 'dd-mm-yyyy'), '4', '29', '302', '10', '2093', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34272, to_date('30-10-2093', 'dd-mm-yyyy'), '5', '30', '303', '10', '2093', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34273, to_date('31-10-2093', 'dd-mm-yyyy'), '6', '31', '304', '10', '2093', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34274, to_date('01-11-2093', 'dd-mm-yyyy'), '7', '01', '305', '11', '2093', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34275, to_date('02-11-2093', 'dd-mm-yyyy'), '1', '02', '306', '11', '2093', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34276, to_date('03-11-2093', 'dd-mm-yyyy'), '2', '03', '307', '11', '2093', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34277, to_date('04-11-2093', 'dd-mm-yyyy'), '3', '04', '308', '11', '2093', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34278, to_date('05-11-2093', 'dd-mm-yyyy'), '4', '05', '309', '11', '2093', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34279, to_date('06-11-2093', 'dd-mm-yyyy'), '5', '06', '310', '11', '2093', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34280, to_date('07-11-2093', 'dd-mm-yyyy'), '6', '07', '311', '11', '2093', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34281, to_date('08-11-2093', 'dd-mm-yyyy'), '7', '08', '312', '11', '2093', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34282, to_date('09-11-2093', 'dd-mm-yyyy'), '1', '09', '313', '11', '2093', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34283, to_date('10-11-2093', 'dd-mm-yyyy'), '2', '10', '314', '11', '2093', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34284, to_date('11-11-2093', 'dd-mm-yyyy'), '3', '11', '315', '11', '2093', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34285, to_date('12-11-2093', 'dd-mm-yyyy'), '4', '12', '316', '11', '2093', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34286, to_date('13-11-2093', 'dd-mm-yyyy'), '5', '13', '317', '11', '2093', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34287, to_date('14-11-2093', 'dd-mm-yyyy'), '6', '14', '318', '11', '2093', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34288, to_date('15-11-2093', 'dd-mm-yyyy'), '7', '15', '319', '11', '2093', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34289, to_date('16-11-2093', 'dd-mm-yyyy'), '1', '16', '320', '11', '2093', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34290, to_date('17-11-2093', 'dd-mm-yyyy'), '2', '17', '321', '11', '2093', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34291, to_date('18-11-2093', 'dd-mm-yyyy'), '3', '18', '322', '11', '2093', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34292, to_date('19-11-2093', 'dd-mm-yyyy'), '4', '19', '323', '11', '2093', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34293, to_date('20-11-2093', 'dd-mm-yyyy'), '5', '20', '324', '11', '2093', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34294, to_date('21-11-2093', 'dd-mm-yyyy'), '6', '21', '325', '11', '2093', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34295, to_date('22-11-2093', 'dd-mm-yyyy'), '7', '22', '326', '11', '2093', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34296, to_date('23-11-2093', 'dd-mm-yyyy'), '1', '23', '327', '11', '2093', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34297, to_date('24-11-2093', 'dd-mm-yyyy'), '2', '24', '328', '11', '2093', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34298, to_date('25-11-2093', 'dd-mm-yyyy'), '3', '25', '329', '11', '2093', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34299, to_date('26-11-2093', 'dd-mm-yyyy'), '4', '26', '330', '11', '2093', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34300, to_date('27-11-2093', 'dd-mm-yyyy'), '5', '27', '331', '11', '2093', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34301, to_date('28-11-2093', 'dd-mm-yyyy'), '6', '28', '332', '11', '2093', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34302, to_date('29-11-2093', 'dd-mm-yyyy'), '7', '29', '333', '11', '2093', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34303, to_date('30-11-2093', 'dd-mm-yyyy'), '1', '30', '334', '11', '2093', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34304, to_date('01-12-2093', 'dd-mm-yyyy'), '2', '01', '335', '12', '2093', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34305, to_date('02-12-2093', 'dd-mm-yyyy'), '3', '02', '336', '12', '2093', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34306, to_date('03-12-2093', 'dd-mm-yyyy'), '4', '03', '337', '12', '2093', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34307, to_date('04-12-2093', 'dd-mm-yyyy'), '5', '04', '338', '12', '2093', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34308, to_date('05-12-2093', 'dd-mm-yyyy'), '6', '05', '339', '12', '2093', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34309, to_date('06-12-2093', 'dd-mm-yyyy'), '7', '06', '340', '12', '2093', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34310, to_date('07-12-2093', 'dd-mm-yyyy'), '1', '07', '341', '12', '2093', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34311, to_date('08-12-2093', 'dd-mm-yyyy'), '2', '08', '342', '12', '2093', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34312, to_date('09-12-2093', 'dd-mm-yyyy'), '3', '09', '343', '12', '2093', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34313, to_date('10-12-2093', 'dd-mm-yyyy'), '4', '10', '344', '12', '2093', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34314, to_date('11-12-2093', 'dd-mm-yyyy'), '5', '11', '345', '12', '2093', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34315, to_date('12-12-2093', 'dd-mm-yyyy'), '6', '12', '346', '12', '2093', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34316, to_date('13-12-2093', 'dd-mm-yyyy'), '7', '13', '347', '12', '2093', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34317, to_date('14-12-2093', 'dd-mm-yyyy'), '1', '14', '348', '12', '2093', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (34318, to_date('15-12-2093', 'dd-mm-yyyy'), '2', '15', '349', '12', '2093', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35803, to_date('08-01-2098', 'dd-mm-yyyy'), '3', '08', '008', '01', '2098', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35804, to_date('09-01-2098', 'dd-mm-yyyy'), '4', '09', '009', '01', '2098', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35805, to_date('10-01-2098', 'dd-mm-yyyy'), '5', '10', '010', '01', '2098', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35806, to_date('11-01-2098', 'dd-mm-yyyy'), '6', '11', '011', '01', '2098', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35807, to_date('12-01-2098', 'dd-mm-yyyy'), '7', '12', '012', '01', '2098', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35808, to_date('13-01-2098', 'dd-mm-yyyy'), '1', '13', '013', '01', '2098', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35809, to_date('14-01-2098', 'dd-mm-yyyy'), '2', '14', '014', '01', '2098', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35810, to_date('15-01-2098', 'dd-mm-yyyy'), '3', '15', '015', '01', '2098', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35811, to_date('16-01-2098', 'dd-mm-yyyy'), '4', '16', '016', '01', '2098', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35812, to_date('17-01-2098', 'dd-mm-yyyy'), '5', '17', '017', '01', '2098', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35813, to_date('18-01-2098', 'dd-mm-yyyy'), '6', '18', '018', '01', '2098', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35814, to_date('19-01-2098', 'dd-mm-yyyy'), '7', '19', '019', '01', '2098', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35815, to_date('20-01-2098', 'dd-mm-yyyy'), '1', '20', '020', '01', '2098', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35816, to_date('21-01-2098', 'dd-mm-yyyy'), '2', '21', '021', '01', '2098', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35817, to_date('22-01-2098', 'dd-mm-yyyy'), '3', '22', '022', '01', '2098', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35818, to_date('23-01-2098', 'dd-mm-yyyy'), '4', '23', '023', '01', '2098', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35819, to_date('24-01-2098', 'dd-mm-yyyy'), '5', '24', '024', '01', '2098', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35820, to_date('25-01-2098', 'dd-mm-yyyy'), '6', '25', '025', '01', '2098', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35821, to_date('26-01-2098', 'dd-mm-yyyy'), '7', '26', '026', '01', '2098', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35822, to_date('27-01-2098', 'dd-mm-yyyy'), '1', '27', '027', '01', '2098', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35823, to_date('28-01-2098', 'dd-mm-yyyy'), '2', '28', '028', '01', '2098', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35824, to_date('29-01-2098', 'dd-mm-yyyy'), '3', '29', '029', '01', '2098', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35825, to_date('30-01-2098', 'dd-mm-yyyy'), '4', '30', '030', '01', '2098', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35826, to_date('31-01-2098', 'dd-mm-yyyy'), '5', '31', '031', '01', '2098', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35827, to_date('01-02-2098', 'dd-mm-yyyy'), '6', '01', '032', '02', '2098', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35828, to_date('02-02-2098', 'dd-mm-yyyy'), '7', '02', '033', '02', '2098', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35829, to_date('03-02-2098', 'dd-mm-yyyy'), '1', '03', '034', '02', '2098', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35830, to_date('04-02-2098', 'dd-mm-yyyy'), '2', '04', '035', '02', '2098', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35831, to_date('05-02-2098', 'dd-mm-yyyy'), '3', '05', '036', '02', '2098', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35832, to_date('06-02-2098', 'dd-mm-yyyy'), '4', '06', '037', '02', '2098', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35833, to_date('07-02-2098', 'dd-mm-yyyy'), '5', '07', '038', '02', '2098', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35834, to_date('08-02-2098', 'dd-mm-yyyy'), '6', '08', '039', '02', '2098', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35835, to_date('09-02-2098', 'dd-mm-yyyy'), '7', '09', '040', '02', '2098', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35836, to_date('10-02-2098', 'dd-mm-yyyy'), '1', '10', '041', '02', '2098', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35837, to_date('11-02-2098', 'dd-mm-yyyy'), '2', '11', '042', '02', '2098', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35838, to_date('12-02-2098', 'dd-mm-yyyy'), '3', '12', '043', '02', '2098', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35839, to_date('13-02-2098', 'dd-mm-yyyy'), '4', '13', '044', '02', '2098', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35840, to_date('14-02-2098', 'dd-mm-yyyy'), '5', '14', '045', '02', '2098', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35841, to_date('15-02-2098', 'dd-mm-yyyy'), '6', '15', '046', '02', '2098', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35842, to_date('16-02-2098', 'dd-mm-yyyy'), '7', '16', '047', '02', '2098', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35843, to_date('17-02-2098', 'dd-mm-yyyy'), '1', '17', '048', '02', '2098', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35844, to_date('18-02-2098', 'dd-mm-yyyy'), '2', '18', '049', '02', '2098', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35845, to_date('19-02-2098', 'dd-mm-yyyy'), '3', '19', '050', '02', '2098', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35846, to_date('20-02-2098', 'dd-mm-yyyy'), '4', '20', '051', '02', '2098', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35847, to_date('21-02-2098', 'dd-mm-yyyy'), '5', '21', '052', '02', '2098', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35848, to_date('22-02-2098', 'dd-mm-yyyy'), '6', '22', '053', '02', '2098', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35849, to_date('23-02-2098', 'dd-mm-yyyy'), '7', '23', '054', '02', '2098', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35850, to_date('24-02-2098', 'dd-mm-yyyy'), '1', '24', '055', '02', '2098', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35851, to_date('25-02-2098', 'dd-mm-yyyy'), '2', '25', '056', '02', '2098', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35852, to_date('26-02-2098', 'dd-mm-yyyy'), '3', '26', '057', '02', '2098', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35853, to_date('27-02-2098', 'dd-mm-yyyy'), '4', '27', '058', '02', '2098', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35854, to_date('28-02-2098', 'dd-mm-yyyy'), '5', '28', '059', '02', '2098', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35855, to_date('01-03-2098', 'dd-mm-yyyy'), '6', '01', '060', '03', '2098', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35856, to_date('02-03-2098', 'dd-mm-yyyy'), '7', '02', '061', '03', '2098', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35857, to_date('03-03-2098', 'dd-mm-yyyy'), '1', '03', '062', '03', '2098', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35858, to_date('04-03-2098', 'dd-mm-yyyy'), '2', '04', '063', '03', '2098', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35859, to_date('05-03-2098', 'dd-mm-yyyy'), '3', '05', '064', '03', '2098', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35860, to_date('06-03-2098', 'dd-mm-yyyy'), '4', '06', '065', '03', '2098', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35861, to_date('07-03-2098', 'dd-mm-yyyy'), '5', '07', '066', '03', '2098', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35862, to_date('08-03-2098', 'dd-mm-yyyy'), '6', '08', '067', '03', '2098', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35863, to_date('09-03-2098', 'dd-mm-yyyy'), '7', '09', '068', '03', '2098', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35864, to_date('10-03-2098', 'dd-mm-yyyy'), '1', '10', '069', '03', '2098', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35865, to_date('11-03-2098', 'dd-mm-yyyy'), '2', '11', '070', '03', '2098', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35866, to_date('12-03-2098', 'dd-mm-yyyy'), '3', '12', '071', '03', '2098', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35867, to_date('13-03-2098', 'dd-mm-yyyy'), '4', '13', '072', '03', '2098', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35868, to_date('14-03-2098', 'dd-mm-yyyy'), '5', '14', '073', '03', '2098', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35869, to_date('15-03-2098', 'dd-mm-yyyy'), '6', '15', '074', '03', '2098', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35870, to_date('16-03-2098', 'dd-mm-yyyy'), '7', '16', '075', '03', '2098', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35871, to_date('17-03-2098', 'dd-mm-yyyy'), '1', '17', '076', '03', '2098', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35872, to_date('18-03-2098', 'dd-mm-yyyy'), '2', '18', '077', '03', '2098', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35873, to_date('19-03-2098', 'dd-mm-yyyy'), '3', '19', '078', '03', '2098', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35874, to_date('20-03-2098', 'dd-mm-yyyy'), '4', '20', '079', '03', '2098', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35875, to_date('21-03-2098', 'dd-mm-yyyy'), '5', '21', '080', '03', '2098', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35876, to_date('22-03-2098', 'dd-mm-yyyy'), '6', '22', '081', '03', '2098', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35877, to_date('23-03-2098', 'dd-mm-yyyy'), '7', '23', '082', '03', '2098', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35878, to_date('24-03-2098', 'dd-mm-yyyy'), '1', '24', '083', '03', '2098', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35879, to_date('25-03-2098', 'dd-mm-yyyy'), '2', '25', '084', '03', '2098', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35880, to_date('26-03-2098', 'dd-mm-yyyy'), '3', '26', '085', '03', '2098', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35881, to_date('27-03-2098', 'dd-mm-yyyy'), '4', '27', '086', '03', '2098', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35882, to_date('28-03-2098', 'dd-mm-yyyy'), '5', '28', '087', '03', '2098', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35883, to_date('29-03-2098', 'dd-mm-yyyy'), '6', '29', '088', '03', '2098', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35884, to_date('30-03-2098', 'dd-mm-yyyy'), '7', '30', '089', '03', '2098', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35885, to_date('31-03-2098', 'dd-mm-yyyy'), '1', '31', '090', '03', '2098', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35886, to_date('01-04-2098', 'dd-mm-yyyy'), '2', '01', '091', '04', '2098', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35887, to_date('02-04-2098', 'dd-mm-yyyy'), '3', '02', '092', '04', '2098', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35888, to_date('03-04-2098', 'dd-mm-yyyy'), '4', '03', '093', '04', '2098', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35889, to_date('04-04-2098', 'dd-mm-yyyy'), '5', '04', '094', '04', '2098', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35890, to_date('05-04-2098', 'dd-mm-yyyy'), '6', '05', '095', '04', '2098', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35891, to_date('06-04-2098', 'dd-mm-yyyy'), '7', '06', '096', '04', '2098', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35892, to_date('07-04-2098', 'dd-mm-yyyy'), '1', '07', '097', '04', '2098', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35893, to_date('08-04-2098', 'dd-mm-yyyy'), '2', '08', '098', '04', '2098', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35894, to_date('09-04-2098', 'dd-mm-yyyy'), '3', '09', '099', '04', '2098', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35895, to_date('10-04-2098', 'dd-mm-yyyy'), '4', '10', '100', '04', '2098', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35896, to_date('11-04-2098', 'dd-mm-yyyy'), '5', '11', '101', '04', '2098', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35897, to_date('12-04-2098', 'dd-mm-yyyy'), '6', '12', '102', '04', '2098', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35898, to_date('13-04-2098', 'dd-mm-yyyy'), '7', '13', '103', '04', '2098', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35899, to_date('14-04-2098', 'dd-mm-yyyy'), '1', '14', '104', '04', '2098', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35900, to_date('15-04-2098', 'dd-mm-yyyy'), '2', '15', '105', '04', '2098', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35901, to_date('16-04-2098', 'dd-mm-yyyy'), '3', '16', '106', '04', '2098', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35902, to_date('17-04-2098', 'dd-mm-yyyy'), '4', '17', '107', '04', '2098', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35903, to_date('18-04-2098', 'dd-mm-yyyy'), '5', '18', '108', '04', '2098', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35904, to_date('19-04-2098', 'dd-mm-yyyy'), '6', '19', '109', '04', '2098', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35905, to_date('20-04-2098', 'dd-mm-yyyy'), '7', '20', '110', '04', '2098', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35906, to_date('21-04-2098', 'dd-mm-yyyy'), '1', '21', '111', '04', '2098', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35907, to_date('22-04-2098', 'dd-mm-yyyy'), '2', '22', '112', '04', '2098', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (35908, to_date('23-04-2098', 'dd-mm-yyyy'), '3', '23', '113', '04', '2098', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27641, to_date('04-09-2075', 'dd-mm-yyyy'), '3', '04', '247', '09', '2075', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27642, to_date('05-09-2075', 'dd-mm-yyyy'), '4', '05', '248', '09', '2075', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27643, to_date('06-09-2075', 'dd-mm-yyyy'), '5', '06', '249', '09', '2075', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27644, to_date('07-09-2075', 'dd-mm-yyyy'), '6', '07', '250', '09', '2075', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27645, to_date('08-09-2075', 'dd-mm-yyyy'), '7', '08', '251', '09', '2075', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27646, to_date('09-09-2075', 'dd-mm-yyyy'), '1', '09', '252', '09', '2075', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27647, to_date('10-09-2075', 'dd-mm-yyyy'), '2', '10', '253', '09', '2075', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27648, to_date('11-09-2075', 'dd-mm-yyyy'), '3', '11', '254', '09', '2075', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27649, to_date('12-09-2075', 'dd-mm-yyyy'), '4', '12', '255', '09', '2075', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27650, to_date('13-09-2075', 'dd-mm-yyyy'), '5', '13', '256', '09', '2075', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27651, to_date('14-09-2075', 'dd-mm-yyyy'), '6', '14', '257', '09', '2075', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27652, to_date('15-09-2075', 'dd-mm-yyyy'), '7', '15', '258', '09', '2075', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27653, to_date('16-09-2075', 'dd-mm-yyyy'), '1', '16', '259', '09', '2075', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27654, to_date('17-09-2075', 'dd-mm-yyyy'), '2', '17', '260', '09', '2075', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27655, to_date('18-09-2075', 'dd-mm-yyyy'), '3', '18', '261', '09', '2075', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27656, to_date('19-09-2075', 'dd-mm-yyyy'), '4', '19', '262', '09', '2075', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27657, to_date('20-09-2075', 'dd-mm-yyyy'), '5', '20', '263', '09', '2075', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27658, to_date('21-09-2075', 'dd-mm-yyyy'), '6', '21', '264', '09', '2075', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27659, to_date('22-09-2075', 'dd-mm-yyyy'), '7', '22', '265', '09', '2075', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27660, to_date('23-09-2075', 'dd-mm-yyyy'), '1', '23', '266', '09', '2075', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27661, to_date('24-09-2075', 'dd-mm-yyyy'), '2', '24', '267', '09', '2075', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27662, to_date('25-09-2075', 'dd-mm-yyyy'), '3', '25', '268', '09', '2075', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27663, to_date('26-09-2075', 'dd-mm-yyyy'), '4', '26', '269', '09', '2075', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27664, to_date('27-09-2075', 'dd-mm-yyyy'), '5', '27', '270', '09', '2075', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27665, to_date('28-09-2075', 'dd-mm-yyyy'), '6', '28', '271', '09', '2075', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27666, to_date('29-09-2075', 'dd-mm-yyyy'), '7', '29', '272', '09', '2075', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27667, to_date('30-09-2075', 'dd-mm-yyyy'), '1', '30', '273', '09', '2075', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27668, to_date('01-10-2075', 'dd-mm-yyyy'), '2', '01', '274', '10', '2075', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27669, to_date('02-10-2075', 'dd-mm-yyyy'), '3', '02', '275', '10', '2075', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27670, to_date('03-10-2075', 'dd-mm-yyyy'), '4', '03', '276', '10', '2075', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27671, to_date('04-10-2075', 'dd-mm-yyyy'), '5', '04', '277', '10', '2075', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27672, to_date('05-10-2075', 'dd-mm-yyyy'), '6', '05', '278', '10', '2075', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27673, to_date('06-10-2075', 'dd-mm-yyyy'), '7', '06', '279', '10', '2075', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27674, to_date('07-10-2075', 'dd-mm-yyyy'), '1', '07', '280', '10', '2075', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27675, to_date('08-10-2075', 'dd-mm-yyyy'), '2', '08', '281', '10', '2075', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27676, to_date('09-10-2075', 'dd-mm-yyyy'), '3', '09', '282', '10', '2075', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27677, to_date('10-10-2075', 'dd-mm-yyyy'), '4', '10', '283', '10', '2075', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27678, to_date('11-10-2075', 'dd-mm-yyyy'), '5', '11', '284', '10', '2075', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27679, to_date('12-10-2075', 'dd-mm-yyyy'), '6', '12', '285', '10', '2075', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27680, to_date('13-10-2075', 'dd-mm-yyyy'), '7', '13', '286', '10', '2075', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27681, to_date('14-10-2075', 'dd-mm-yyyy'), '1', '14', '287', '10', '2075', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27682, to_date('15-10-2075', 'dd-mm-yyyy'), '2', '15', '288', '10', '2075', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27683, to_date('16-10-2075', 'dd-mm-yyyy'), '3', '16', '289', '10', '2075', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27684, to_date('17-10-2075', 'dd-mm-yyyy'), '4', '17', '290', '10', '2075', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27685, to_date('18-10-2075', 'dd-mm-yyyy'), '5', '18', '291', '10', '2075', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27686, to_date('19-10-2075', 'dd-mm-yyyy'), '6', '19', '292', '10', '2075', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27687, to_date('20-10-2075', 'dd-mm-yyyy'), '7', '20', '293', '10', '2075', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27688, to_date('21-10-2075', 'dd-mm-yyyy'), '1', '21', '294', '10', '2075', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27689, to_date('22-10-2075', 'dd-mm-yyyy'), '2', '22', '295', '10', '2075', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27690, to_date('23-10-2075', 'dd-mm-yyyy'), '3', '23', '296', '10', '2075', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27691, to_date('24-10-2075', 'dd-mm-yyyy'), '4', '24', '297', '10', '2075', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27692, to_date('25-10-2075', 'dd-mm-yyyy'), '5', '25', '298', '10', '2075', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27693, to_date('26-10-2075', 'dd-mm-yyyy'), '6', '26', '299', '10', '2075', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27694, to_date('27-10-2075', 'dd-mm-yyyy'), '7', '27', '300', '10', '2075', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27695, to_date('28-10-2075', 'dd-mm-yyyy'), '1', '28', '301', '10', '2075', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27696, to_date('29-10-2075', 'dd-mm-yyyy'), '2', '29', '302', '10', '2075', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27697, to_date('30-10-2075', 'dd-mm-yyyy'), '3', '30', '303', '10', '2075', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27698, to_date('31-10-2075', 'dd-mm-yyyy'), '4', '31', '304', '10', '2075', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27699, to_date('01-11-2075', 'dd-mm-yyyy'), '5', '01', '305', '11', '2075', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27700, to_date('02-11-2075', 'dd-mm-yyyy'), '6', '02', '306', '11', '2075', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27701, to_date('03-11-2075', 'dd-mm-yyyy'), '7', '03', '307', '11', '2075', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27702, to_date('04-11-2075', 'dd-mm-yyyy'), '1', '04', '308', '11', '2075', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27703, to_date('05-11-2075', 'dd-mm-yyyy'), '2', '05', '309', '11', '2075', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27704, to_date('06-11-2075', 'dd-mm-yyyy'), '3', '06', '310', '11', '2075', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27705, to_date('07-11-2075', 'dd-mm-yyyy'), '4', '07', '311', '11', '2075', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27706, to_date('08-11-2075', 'dd-mm-yyyy'), '5', '08', '312', '11', '2075', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27707, to_date('09-11-2075', 'dd-mm-yyyy'), '6', '09', '313', '11', '2075', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27708, to_date('10-11-2075', 'dd-mm-yyyy'), '7', '10', '314', '11', '2075', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27709, to_date('11-11-2075', 'dd-mm-yyyy'), '1', '11', '315', '11', '2075', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27710, to_date('12-11-2075', 'dd-mm-yyyy'), '2', '12', '316', '11', '2075', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27711, to_date('13-11-2075', 'dd-mm-yyyy'), '3', '13', '317', '11', '2075', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27712, to_date('14-11-2075', 'dd-mm-yyyy'), '4', '14', '318', '11', '2075', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27713, to_date('15-11-2075', 'dd-mm-yyyy'), '5', '15', '319', '11', '2075', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27714, to_date('16-11-2075', 'dd-mm-yyyy'), '6', '16', '320', '11', '2075', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27715, to_date('17-11-2075', 'dd-mm-yyyy'), '7', '17', '321', '11', '2075', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27716, to_date('18-11-2075', 'dd-mm-yyyy'), '1', '18', '322', '11', '2075', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27717, to_date('19-11-2075', 'dd-mm-yyyy'), '2', '19', '323', '11', '2075', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27718, to_date('20-11-2075', 'dd-mm-yyyy'), '3', '20', '324', '11', '2075', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27719, to_date('21-11-2075', 'dd-mm-yyyy'), '4', '21', '325', '11', '2075', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27720, to_date('22-11-2075', 'dd-mm-yyyy'), '5', '22', '326', '11', '2075', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27721, to_date('23-11-2075', 'dd-mm-yyyy'), '6', '23', '327', '11', '2075', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27722, to_date('24-11-2075', 'dd-mm-yyyy'), '7', '24', '328', '11', '2075', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27723, to_date('25-11-2075', 'dd-mm-yyyy'), '1', '25', '329', '11', '2075', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27724, to_date('26-11-2075', 'dd-mm-yyyy'), '2', '26', '330', '11', '2075', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27725, to_date('27-11-2075', 'dd-mm-yyyy'), '3', '27', '331', '11', '2075', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27726, to_date('28-11-2075', 'dd-mm-yyyy'), '4', '28', '332', '11', '2075', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27727, to_date('29-11-2075', 'dd-mm-yyyy'), '5', '29', '333', '11', '2075', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27728, to_date('30-11-2075', 'dd-mm-yyyy'), '6', '30', '334', '11', '2075', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27729, to_date('01-12-2075', 'dd-mm-yyyy'), '7', '01', '335', '12', '2075', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27730, to_date('02-12-2075', 'dd-mm-yyyy'), '1', '02', '336', '12', '2075', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27731, to_date('03-12-2075', 'dd-mm-yyyy'), '2', '03', '337', '12', '2075', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27732, to_date('04-12-2075', 'dd-mm-yyyy'), '3', '04', '338', '12', '2075', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27733, to_date('05-12-2075', 'dd-mm-yyyy'), '4', '05', '339', '12', '2075', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27734, to_date('06-12-2075', 'dd-mm-yyyy'), '5', '06', '340', '12', '2075', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27735, to_date('07-12-2075', 'dd-mm-yyyy'), '6', '07', '341', '12', '2075', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27736, to_date('08-12-2075', 'dd-mm-yyyy'), '7', '08', '342', '12', '2075', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27737, to_date('09-12-2075', 'dd-mm-yyyy'), '1', '09', '343', '12', '2075', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27738, to_date('10-12-2075', 'dd-mm-yyyy'), '2', '10', '344', '12', '2075', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27739, to_date('11-12-2075', 'dd-mm-yyyy'), '3', '11', '345', '12', '2075', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27740, to_date('12-12-2075', 'dd-mm-yyyy'), '4', '12', '346', '12', '2075', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27741, to_date('13-12-2075', 'dd-mm-yyyy'), '5', '13', '347', '12', '2075', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27742, to_date('14-12-2075', 'dd-mm-yyyy'), '6', '14', '348', '12', '2075', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27743, to_date('15-12-2075', 'dd-mm-yyyy'), '7', '15', '349', '12', '2075', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27744, to_date('16-12-2075', 'dd-mm-yyyy'), '1', '16', '350', '12', '2075', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27745, to_date('17-12-2075', 'dd-mm-yyyy'), '2', '17', '351', '12', '2075', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27746, to_date('18-12-2075', 'dd-mm-yyyy'), '3', '18', '352', '12', '2075', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29231, to_date('11-01-2080', 'dd-mm-yyyy'), '4', '11', '011', '01', '2080', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29232, to_date('12-01-2080', 'dd-mm-yyyy'), '5', '12', '012', '01', '2080', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29233, to_date('13-01-2080', 'dd-mm-yyyy'), '6', '13', '013', '01', '2080', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29234, to_date('14-01-2080', 'dd-mm-yyyy'), '7', '14', '014', '01', '2080', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29235, to_date('15-01-2080', 'dd-mm-yyyy'), '1', '15', '015', '01', '2080', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29236, to_date('16-01-2080', 'dd-mm-yyyy'), '2', '16', '016', '01', '2080', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29237, to_date('17-01-2080', 'dd-mm-yyyy'), '3', '17', '017', '01', '2080', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29238, to_date('18-01-2080', 'dd-mm-yyyy'), '4', '18', '018', '01', '2080', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29239, to_date('19-01-2080', 'dd-mm-yyyy'), '5', '19', '019', '01', '2080', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29240, to_date('20-01-2080', 'dd-mm-yyyy'), '6', '20', '020', '01', '2080', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29241, to_date('21-01-2080', 'dd-mm-yyyy'), '7', '21', '021', '01', '2080', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29242, to_date('22-01-2080', 'dd-mm-yyyy'), '1', '22', '022', '01', '2080', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29243, to_date('23-01-2080', 'dd-mm-yyyy'), '2', '23', '023', '01', '2080', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29244, to_date('24-01-2080', 'dd-mm-yyyy'), '3', '24', '024', '01', '2080', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29245, to_date('25-01-2080', 'dd-mm-yyyy'), '4', '25', '025', '01', '2080', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29246, to_date('26-01-2080', 'dd-mm-yyyy'), '5', '26', '026', '01', '2080', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29247, to_date('27-01-2080', 'dd-mm-yyyy'), '6', '27', '027', '01', '2080', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29248, to_date('28-01-2080', 'dd-mm-yyyy'), '7', '28', '028', '01', '2080', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29249, to_date('29-01-2080', 'dd-mm-yyyy'), '1', '29', '029', '01', '2080', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29250, to_date('30-01-2080', 'dd-mm-yyyy'), '2', '30', '030', '01', '2080', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29251, to_date('31-01-2080', 'dd-mm-yyyy'), '3', '31', '031', '01', '2080', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29252, to_date('01-02-2080', 'dd-mm-yyyy'), '4', '01', '032', '02', '2080', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29253, to_date('02-02-2080', 'dd-mm-yyyy'), '5', '02', '033', '02', '2080', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29254, to_date('03-02-2080', 'dd-mm-yyyy'), '6', '03', '034', '02', '2080', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29255, to_date('04-02-2080', 'dd-mm-yyyy'), '7', '04', '035', '02', '2080', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29256, to_date('05-02-2080', 'dd-mm-yyyy'), '1', '05', '036', '02', '2080', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29257, to_date('06-02-2080', 'dd-mm-yyyy'), '2', '06', '037', '02', '2080', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29258, to_date('07-02-2080', 'dd-mm-yyyy'), '3', '07', '038', '02', '2080', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29259, to_date('08-02-2080', 'dd-mm-yyyy'), '4', '08', '039', '02', '2080', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29260, to_date('09-02-2080', 'dd-mm-yyyy'), '5', '09', '040', '02', '2080', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29261, to_date('10-02-2080', 'dd-mm-yyyy'), '6', '10', '041', '02', '2080', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29262, to_date('11-02-2080', 'dd-mm-yyyy'), '7', '11', '042', '02', '2080', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29263, to_date('12-02-2080', 'dd-mm-yyyy'), '1', '12', '043', '02', '2080', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29264, to_date('13-02-2080', 'dd-mm-yyyy'), '2', '13', '044', '02', '2080', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29265, to_date('14-02-2080', 'dd-mm-yyyy'), '3', '14', '045', '02', '2080', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29266, to_date('15-02-2080', 'dd-mm-yyyy'), '4', '15', '046', '02', '2080', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29267, to_date('16-02-2080', 'dd-mm-yyyy'), '5', '16', '047', '02', '2080', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29268, to_date('17-02-2080', 'dd-mm-yyyy'), '6', '17', '048', '02', '2080', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29269, to_date('18-02-2080', 'dd-mm-yyyy'), '7', '18', '049', '02', '2080', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29270, to_date('19-02-2080', 'dd-mm-yyyy'), '1', '19', '050', '02', '2080', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29271, to_date('20-02-2080', 'dd-mm-yyyy'), '2', '20', '051', '02', '2080', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29272, to_date('21-02-2080', 'dd-mm-yyyy'), '3', '21', '052', '02', '2080', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29273, to_date('22-02-2080', 'dd-mm-yyyy'), '4', '22', '053', '02', '2080', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29274, to_date('23-02-2080', 'dd-mm-yyyy'), '5', '23', '054', '02', '2080', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29275, to_date('24-02-2080', 'dd-mm-yyyy'), '6', '24', '055', '02', '2080', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29276, to_date('25-02-2080', 'dd-mm-yyyy'), '7', '25', '056', '02', '2080', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29277, to_date('26-02-2080', 'dd-mm-yyyy'), '1', '26', '057', '02', '2080', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29278, to_date('27-02-2080', 'dd-mm-yyyy'), '2', '27', '058', '02', '2080', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29279, to_date('28-02-2080', 'dd-mm-yyyy'), '3', '28', '059', '02', '2080', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29280, to_date('29-02-2080', 'dd-mm-yyyy'), '4', '29', '060', '02', '2080', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29281, to_date('01-03-2080', 'dd-mm-yyyy'), '5', '01', '061', '03', '2080', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29282, to_date('02-03-2080', 'dd-mm-yyyy'), '6', '02', '062', '03', '2080', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29283, to_date('03-03-2080', 'dd-mm-yyyy'), '7', '03', '063', '03', '2080', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29284, to_date('04-03-2080', 'dd-mm-yyyy'), '1', '04', '064', '03', '2080', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29285, to_date('05-03-2080', 'dd-mm-yyyy'), '2', '05', '065', '03', '2080', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29286, to_date('06-03-2080', 'dd-mm-yyyy'), '3', '06', '066', '03', '2080', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29287, to_date('07-03-2080', 'dd-mm-yyyy'), '4', '07', '067', '03', '2080', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29288, to_date('08-03-2080', 'dd-mm-yyyy'), '5', '08', '068', '03', '2080', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29289, to_date('09-03-2080', 'dd-mm-yyyy'), '6', '09', '069', '03', '2080', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29290, to_date('10-03-2080', 'dd-mm-yyyy'), '7', '10', '070', '03', '2080', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29291, to_date('11-03-2080', 'dd-mm-yyyy'), '1', '11', '071', '03', '2080', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29292, to_date('12-03-2080', 'dd-mm-yyyy'), '2', '12', '072', '03', '2080', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29293, to_date('13-03-2080', 'dd-mm-yyyy'), '3', '13', '073', '03', '2080', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29294, to_date('14-03-2080', 'dd-mm-yyyy'), '4', '14', '074', '03', '2080', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29295, to_date('15-03-2080', 'dd-mm-yyyy'), '5', '15', '075', '03', '2080', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29296, to_date('16-03-2080', 'dd-mm-yyyy'), '6', '16', '076', '03', '2080', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29297, to_date('17-03-2080', 'dd-mm-yyyy'), '7', '17', '077', '03', '2080', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29298, to_date('18-03-2080', 'dd-mm-yyyy'), '1', '18', '078', '03', '2080', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29299, to_date('19-03-2080', 'dd-mm-yyyy'), '2', '19', '079', '03', '2080', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29300, to_date('20-03-2080', 'dd-mm-yyyy'), '3', '20', '080', '03', '2080', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29301, to_date('21-03-2080', 'dd-mm-yyyy'), '4', '21', '081', '03', '2080', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29302, to_date('22-03-2080', 'dd-mm-yyyy'), '5', '22', '082', '03', '2080', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29303, to_date('23-03-2080', 'dd-mm-yyyy'), '6', '23', '083', '03', '2080', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29304, to_date('24-03-2080', 'dd-mm-yyyy'), '7', '24', '084', '03', '2080', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29305, to_date('25-03-2080', 'dd-mm-yyyy'), '1', '25', '085', '03', '2080', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29306, to_date('26-03-2080', 'dd-mm-yyyy'), '2', '26', '086', '03', '2080', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29307, to_date('27-03-2080', 'dd-mm-yyyy'), '3', '27', '087', '03', '2080', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29308, to_date('28-03-2080', 'dd-mm-yyyy'), '4', '28', '088', '03', '2080', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29309, to_date('29-03-2080', 'dd-mm-yyyy'), '5', '29', '089', '03', '2080', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29310, to_date('30-03-2080', 'dd-mm-yyyy'), '6', '30', '090', '03', '2080', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29311, to_date('31-03-2080', 'dd-mm-yyyy'), '7', '31', '091', '03', '2080', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29312, to_date('01-04-2080', 'dd-mm-yyyy'), '1', '01', '092', '04', '2080', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29313, to_date('02-04-2080', 'dd-mm-yyyy'), '2', '02', '093', '04', '2080', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29314, to_date('03-04-2080', 'dd-mm-yyyy'), '3', '03', '094', '04', '2080', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29315, to_date('04-04-2080', 'dd-mm-yyyy'), '4', '04', '095', '04', '2080', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29316, to_date('05-04-2080', 'dd-mm-yyyy'), '5', '05', '096', '04', '2080', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29317, to_date('06-04-2080', 'dd-mm-yyyy'), '6', '06', '097', '04', '2080', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29318, to_date('07-04-2080', 'dd-mm-yyyy'), '7', '07', '098', '04', '2080', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29319, to_date('08-04-2080', 'dd-mm-yyyy'), '1', '08', '099', '04', '2080', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29320, to_date('09-04-2080', 'dd-mm-yyyy'), '2', '09', '100', '04', '2080', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29321, to_date('10-04-2080', 'dd-mm-yyyy'), '3', '10', '101', '04', '2080', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29322, to_date('11-04-2080', 'dd-mm-yyyy'), '4', '11', '102', '04', '2080', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29323, to_date('12-04-2080', 'dd-mm-yyyy'), '5', '12', '103', '04', '2080', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29324, to_date('13-04-2080', 'dd-mm-yyyy'), '6', '13', '104', '04', '2080', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29325, to_date('14-04-2080', 'dd-mm-yyyy'), '7', '14', '105', '04', '2080', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29326, to_date('15-04-2080', 'dd-mm-yyyy'), '1', '15', '106', '04', '2080', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29327, to_date('16-04-2080', 'dd-mm-yyyy'), '2', '16', '107', '04', '2080', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29328, to_date('17-04-2080', 'dd-mm-yyyy'), '3', '17', '108', '04', '2080', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29329, to_date('18-04-2080', 'dd-mm-yyyy'), '4', '18', '109', '04', '2080', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29330, to_date('19-04-2080', 'dd-mm-yyyy'), '5', '19', '110', '04', '2080', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29331, to_date('20-04-2080', 'dd-mm-yyyy'), '6', '20', '111', '04', '2080', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29332, to_date('21-04-2080', 'dd-mm-yyyy'), '7', '21', '112', '04', '2080', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29333, to_date('22-04-2080', 'dd-mm-yyyy'), '1', '22', '113', '04', '2080', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29334, to_date('23-04-2080', 'dd-mm-yyyy'), '2', '23', '114', '04', '2080', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29335, to_date('24-04-2080', 'dd-mm-yyyy'), '3', '24', '115', '04', '2080', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29336, to_date('25-04-2080', 'dd-mm-yyyy'), '4', '25', '116', '04', '2080', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30821, to_date('19-05-2084', 'dd-mm-yyyy'), '5', '19', '140', '05', '2084', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30822, to_date('20-05-2084', 'dd-mm-yyyy'), '6', '20', '141', '05', '2084', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30823, to_date('21-05-2084', 'dd-mm-yyyy'), '7', '21', '142', '05', '2084', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30824, to_date('22-05-2084', 'dd-mm-yyyy'), '1', '22', '143', '05', '2084', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30825, to_date('23-05-2084', 'dd-mm-yyyy'), '2', '23', '144', '05', '2084', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30826, to_date('24-05-2084', 'dd-mm-yyyy'), '3', '24', '145', '05', '2084', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30827, to_date('25-05-2084', 'dd-mm-yyyy'), '4', '25', '146', '05', '2084', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30828, to_date('26-05-2084', 'dd-mm-yyyy'), '5', '26', '147', '05', '2084', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30829, to_date('27-05-2084', 'dd-mm-yyyy'), '6', '27', '148', '05', '2084', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30830, to_date('28-05-2084', 'dd-mm-yyyy'), '7', '28', '149', '05', '2084', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30831, to_date('29-05-2084', 'dd-mm-yyyy'), '1', '29', '150', '05', '2084', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30832, to_date('30-05-2084', 'dd-mm-yyyy'), '2', '30', '151', '05', '2084', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30833, to_date('31-05-2084', 'dd-mm-yyyy'), '3', '31', '152', '05', '2084', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30834, to_date('01-06-2084', 'dd-mm-yyyy'), '4', '01', '153', '06', '2084', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30835, to_date('02-06-2084', 'dd-mm-yyyy'), '5', '02', '154', '06', '2084', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30836, to_date('03-06-2084', 'dd-mm-yyyy'), '6', '03', '155', '06', '2084', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30837, to_date('04-06-2084', 'dd-mm-yyyy'), '7', '04', '156', '06', '2084', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30838, to_date('05-06-2084', 'dd-mm-yyyy'), '1', '05', '157', '06', '2084', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30839, to_date('06-06-2084', 'dd-mm-yyyy'), '2', '06', '158', '06', '2084', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30840, to_date('07-06-2084', 'dd-mm-yyyy'), '3', '07', '159', '06', '2084', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30841, to_date('08-06-2084', 'dd-mm-yyyy'), '4', '08', '160', '06', '2084', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30842, to_date('09-06-2084', 'dd-mm-yyyy'), '5', '09', '161', '06', '2084', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30843, to_date('10-06-2084', 'dd-mm-yyyy'), '6', '10', '162', '06', '2084', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30844, to_date('11-06-2084', 'dd-mm-yyyy'), '7', '11', '163', '06', '2084', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30845, to_date('12-06-2084', 'dd-mm-yyyy'), '1', '12', '164', '06', '2084', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30846, to_date('13-06-2084', 'dd-mm-yyyy'), '2', '13', '165', '06', '2084', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30847, to_date('14-06-2084', 'dd-mm-yyyy'), '3', '14', '166', '06', '2084', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30848, to_date('15-06-2084', 'dd-mm-yyyy'), '4', '15', '167', '06', '2084', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30849, to_date('16-06-2084', 'dd-mm-yyyy'), '5', '16', '168', '06', '2084', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30850, to_date('17-06-2084', 'dd-mm-yyyy'), '6', '17', '169', '06', '2084', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30851, to_date('18-06-2084', 'dd-mm-yyyy'), '7', '18', '170', '06', '2084', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30852, to_date('19-06-2084', 'dd-mm-yyyy'), '1', '19', '171', '06', '2084', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30853, to_date('20-06-2084', 'dd-mm-yyyy'), '2', '20', '172', '06', '2084', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30854, to_date('21-06-2084', 'dd-mm-yyyy'), '3', '21', '173', '06', '2084', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30855, to_date('22-06-2084', 'dd-mm-yyyy'), '4', '22', '174', '06', '2084', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30856, to_date('23-06-2084', 'dd-mm-yyyy'), '5', '23', '175', '06', '2084', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30857, to_date('24-06-2084', 'dd-mm-yyyy'), '6', '24', '176', '06', '2084', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30858, to_date('25-06-2084', 'dd-mm-yyyy'), '7', '25', '177', '06', '2084', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30859, to_date('26-06-2084', 'dd-mm-yyyy'), '1', '26', '178', '06', '2084', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30860, to_date('27-06-2084', 'dd-mm-yyyy'), '2', '27', '179', '06', '2084', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30861, to_date('28-06-2084', 'dd-mm-yyyy'), '3', '28', '180', '06', '2084', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30862, to_date('29-06-2084', 'dd-mm-yyyy'), '4', '29', '181', '06', '2084', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30863, to_date('30-06-2084', 'dd-mm-yyyy'), '5', '30', '182', '06', '2084', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30864, to_date('01-07-2084', 'dd-mm-yyyy'), '6', '01', '183', '07', '2084', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30865, to_date('02-07-2084', 'dd-mm-yyyy'), '7', '02', '184', '07', '2084', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30866, to_date('03-07-2084', 'dd-mm-yyyy'), '1', '03', '185', '07', '2084', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30867, to_date('04-07-2084', 'dd-mm-yyyy'), '2', '04', '186', '07', '2084', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
commit;
prompt 30000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30868, to_date('05-07-2084', 'dd-mm-yyyy'), '3', '05', '187', '07', '2084', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30869, to_date('06-07-2084', 'dd-mm-yyyy'), '4', '06', '188', '07', '2084', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30870, to_date('07-07-2084', 'dd-mm-yyyy'), '5', '07', '189', '07', '2084', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30871, to_date('08-07-2084', 'dd-mm-yyyy'), '6', '08', '190', '07', '2084', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30872, to_date('09-07-2084', 'dd-mm-yyyy'), '7', '09', '191', '07', '2084', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30873, to_date('10-07-2084', 'dd-mm-yyyy'), '1', '10', '192', '07', '2084', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30874, to_date('11-07-2084', 'dd-mm-yyyy'), '2', '11', '193', '07', '2084', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30875, to_date('12-07-2084', 'dd-mm-yyyy'), '3', '12', '194', '07', '2084', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30876, to_date('13-07-2084', 'dd-mm-yyyy'), '4', '13', '195', '07', '2084', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30877, to_date('14-07-2084', 'dd-mm-yyyy'), '5', '14', '196', '07', '2084', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30878, to_date('15-07-2084', 'dd-mm-yyyy'), '6', '15', '197', '07', '2084', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30879, to_date('16-07-2084', 'dd-mm-yyyy'), '7', '16', '198', '07', '2084', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30880, to_date('17-07-2084', 'dd-mm-yyyy'), '1', '17', '199', '07', '2084', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30881, to_date('18-07-2084', 'dd-mm-yyyy'), '2', '18', '200', '07', '2084', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30882, to_date('19-07-2084', 'dd-mm-yyyy'), '3', '19', '201', '07', '2084', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30883, to_date('20-07-2084', 'dd-mm-yyyy'), '4', '20', '202', '07', '2084', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30884, to_date('21-07-2084', 'dd-mm-yyyy'), '5', '21', '203', '07', '2084', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30885, to_date('22-07-2084', 'dd-mm-yyyy'), '6', '22', '204', '07', '2084', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30886, to_date('23-07-2084', 'dd-mm-yyyy'), '7', '23', '205', '07', '2084', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30887, to_date('24-07-2084', 'dd-mm-yyyy'), '1', '24', '206', '07', '2084', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30888, to_date('25-07-2084', 'dd-mm-yyyy'), '2', '25', '207', '07', '2084', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30889, to_date('26-07-2084', 'dd-mm-yyyy'), '3', '26', '208', '07', '2084', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30890, to_date('27-07-2084', 'dd-mm-yyyy'), '4', '27', '209', '07', '2084', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30891, to_date('28-07-2084', 'dd-mm-yyyy'), '5', '28', '210', '07', '2084', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30892, to_date('29-07-2084', 'dd-mm-yyyy'), '6', '29', '211', '07', '2084', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30893, to_date('30-07-2084', 'dd-mm-yyyy'), '7', '30', '212', '07', '2084', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30894, to_date('31-07-2084', 'dd-mm-yyyy'), '1', '31', '213', '07', '2084', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30895, to_date('01-08-2084', 'dd-mm-yyyy'), '2', '01', '214', '08', '2084', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30896, to_date('02-08-2084', 'dd-mm-yyyy'), '3', '02', '215', '08', '2084', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30897, to_date('03-08-2084', 'dd-mm-yyyy'), '4', '03', '216', '08', '2084', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30898, to_date('04-08-2084', 'dd-mm-yyyy'), '5', '04', '217', '08', '2084', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30899, to_date('05-08-2084', 'dd-mm-yyyy'), '6', '05', '218', '08', '2084', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30900, to_date('06-08-2084', 'dd-mm-yyyy'), '7', '06', '219', '08', '2084', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30901, to_date('07-08-2084', 'dd-mm-yyyy'), '1', '07', '220', '08', '2084', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30902, to_date('08-08-2084', 'dd-mm-yyyy'), '2', '08', '221', '08', '2084', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30903, to_date('09-08-2084', 'dd-mm-yyyy'), '3', '09', '222', '08', '2084', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30904, to_date('10-08-2084', 'dd-mm-yyyy'), '4', '10', '223', '08', '2084', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30905, to_date('11-08-2084', 'dd-mm-yyyy'), '5', '11', '224', '08', '2084', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30906, to_date('12-08-2084', 'dd-mm-yyyy'), '6', '12', '225', '08', '2084', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30907, to_date('13-08-2084', 'dd-mm-yyyy'), '7', '13', '226', '08', '2084', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30908, to_date('14-08-2084', 'dd-mm-yyyy'), '1', '14', '227', '08', '2084', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30909, to_date('15-08-2084', 'dd-mm-yyyy'), '2', '15', '228', '08', '2084', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30910, to_date('16-08-2084', 'dd-mm-yyyy'), '3', '16', '229', '08', '2084', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30911, to_date('17-08-2084', 'dd-mm-yyyy'), '4', '17', '230', '08', '2084', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30912, to_date('18-08-2084', 'dd-mm-yyyy'), '5', '18', '231', '08', '2084', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30913, to_date('19-08-2084', 'dd-mm-yyyy'), '6', '19', '232', '08', '2084', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30914, to_date('20-08-2084', 'dd-mm-yyyy'), '7', '20', '233', '08', '2084', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30915, to_date('21-08-2084', 'dd-mm-yyyy'), '1', '21', '234', '08', '2084', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30916, to_date('22-08-2084', 'dd-mm-yyyy'), '2', '22', '235', '08', '2084', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30917, to_date('23-08-2084', 'dd-mm-yyyy'), '3', '23', '236', '08', '2084', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30918, to_date('24-08-2084', 'dd-mm-yyyy'), '4', '24', '237', '08', '2084', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30919, to_date('25-08-2084', 'dd-mm-yyyy'), '5', '25', '238', '08', '2084', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30920, to_date('26-08-2084', 'dd-mm-yyyy'), '6', '26', '239', '08', '2084', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30921, to_date('27-08-2084', 'dd-mm-yyyy'), '7', '27', '240', '08', '2084', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30922, to_date('28-08-2084', 'dd-mm-yyyy'), '1', '28', '241', '08', '2084', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30923, to_date('29-08-2084', 'dd-mm-yyyy'), '2', '29', '242', '08', '2084', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30924, to_date('30-08-2084', 'dd-mm-yyyy'), '3', '30', '243', '08', '2084', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30925, to_date('31-08-2084', 'dd-mm-yyyy'), '4', '31', '244', '08', '2084', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30926, to_date('01-09-2084', 'dd-mm-yyyy'), '5', '01', '245', '09', '2084', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32411, to_date('25-09-2088', 'dd-mm-yyyy'), '6', '25', '269', '09', '2088', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32412, to_date('26-09-2088', 'dd-mm-yyyy'), '7', '26', '270', '09', '2088', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32413, to_date('27-09-2088', 'dd-mm-yyyy'), '1', '27', '271', '09', '2088', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32414, to_date('28-09-2088', 'dd-mm-yyyy'), '2', '28', '272', '09', '2088', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32415, to_date('29-09-2088', 'dd-mm-yyyy'), '3', '29', '273', '09', '2088', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32416, to_date('30-09-2088', 'dd-mm-yyyy'), '4', '30', '274', '09', '2088', '40', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32417, to_date('01-10-2088', 'dd-mm-yyyy'), '5', '01', '275', '10', '2088', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32418, to_date('02-10-2088', 'dd-mm-yyyy'), '6', '02', '276', '10', '2088', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32419, to_date('03-10-2088', 'dd-mm-yyyy'), '7', '03', '277', '10', '2088', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32420, to_date('04-10-2088', 'dd-mm-yyyy'), '1', '04', '278', '10', '2088', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32421, to_date('05-10-2088', 'dd-mm-yyyy'), '2', '05', '279', '10', '2088', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32422, to_date('06-10-2088', 'dd-mm-yyyy'), '3', '06', '280', '10', '2088', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32423, to_date('07-10-2088', 'dd-mm-yyyy'), '4', '07', '281', '10', '2088', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32424, to_date('08-10-2088', 'dd-mm-yyyy'), '5', '08', '282', '10', '2088', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32425, to_date('09-10-2088', 'dd-mm-yyyy'), '6', '09', '283', '10', '2088', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32426, to_date('10-10-2088', 'dd-mm-yyyy'), '7', '10', '284', '10', '2088', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32427, to_date('11-10-2088', 'dd-mm-yyyy'), '1', '11', '285', '10', '2088', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32428, to_date('12-10-2088', 'dd-mm-yyyy'), '2', '12', '286', '10', '2088', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32429, to_date('13-10-2088', 'dd-mm-yyyy'), '3', '13', '287', '10', '2088', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32430, to_date('14-10-2088', 'dd-mm-yyyy'), '4', '14', '288', '10', '2088', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32431, to_date('15-10-2088', 'dd-mm-yyyy'), '5', '15', '289', '10', '2088', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32432, to_date('16-10-2088', 'dd-mm-yyyy'), '6', '16', '290', '10', '2088', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32433, to_date('17-10-2088', 'dd-mm-yyyy'), '7', '17', '291', '10', '2088', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32434, to_date('18-10-2088', 'dd-mm-yyyy'), '1', '18', '292', '10', '2088', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32435, to_date('19-10-2088', 'dd-mm-yyyy'), '2', '19', '293', '10', '2088', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32436, to_date('20-10-2088', 'dd-mm-yyyy'), '3', '20', '294', '10', '2088', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32437, to_date('21-10-2088', 'dd-mm-yyyy'), '4', '21', '295', '10', '2088', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32438, to_date('22-10-2088', 'dd-mm-yyyy'), '5', '22', '296', '10', '2088', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32439, to_date('23-10-2088', 'dd-mm-yyyy'), '6', '23', '297', '10', '2088', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32440, to_date('24-10-2088', 'dd-mm-yyyy'), '7', '24', '298', '10', '2088', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32441, to_date('25-10-2088', 'dd-mm-yyyy'), '1', '25', '299', '10', '2088', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32442, to_date('26-10-2088', 'dd-mm-yyyy'), '2', '26', '300', '10', '2088', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32443, to_date('27-10-2088', 'dd-mm-yyyy'), '3', '27', '301', '10', '2088', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32444, to_date('28-10-2088', 'dd-mm-yyyy'), '4', '28', '302', '10', '2088', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32445, to_date('29-10-2088', 'dd-mm-yyyy'), '5', '29', '303', '10', '2088', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32446, to_date('30-10-2088', 'dd-mm-yyyy'), '6', '30', '304', '10', '2088', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32447, to_date('31-10-2088', 'dd-mm-yyyy'), '7', '31', '305', '10', '2088', '44', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32448, to_date('01-11-2088', 'dd-mm-yyyy'), '1', '01', '306', '11', '2088', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32449, to_date('02-11-2088', 'dd-mm-yyyy'), '2', '02', '307', '11', '2088', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32450, to_date('03-11-2088', 'dd-mm-yyyy'), '3', '03', '308', '11', '2088', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32451, to_date('04-11-2088', 'dd-mm-yyyy'), '4', '04', '309', '11', '2088', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32452, to_date('05-11-2088', 'dd-mm-yyyy'), '5', '05', '310', '11', '2088', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32453, to_date('06-11-2088', 'dd-mm-yyyy'), '6', '06', '311', '11', '2088', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32454, to_date('07-11-2088', 'dd-mm-yyyy'), '7', '07', '312', '11', '2088', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32455, to_date('08-11-2088', 'dd-mm-yyyy'), '1', '08', '313', '11', '2088', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32456, to_date('09-11-2088', 'dd-mm-yyyy'), '2', '09', '314', '11', '2088', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32457, to_date('10-11-2088', 'dd-mm-yyyy'), '3', '10', '315', '11', '2088', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32458, to_date('11-11-2088', 'dd-mm-yyyy'), '4', '11', '316', '11', '2088', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32459, to_date('12-11-2088', 'dd-mm-yyyy'), '5', '12', '317', '11', '2088', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32460, to_date('13-11-2088', 'dd-mm-yyyy'), '6', '13', '318', '11', '2088', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32461, to_date('14-11-2088', 'dd-mm-yyyy'), '7', '14', '319', '11', '2088', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32462, to_date('15-11-2088', 'dd-mm-yyyy'), '1', '15', '320', '11', '2088', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32463, to_date('16-11-2088', 'dd-mm-yyyy'), '2', '16', '321', '11', '2088', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32464, to_date('17-11-2088', 'dd-mm-yyyy'), '3', '17', '322', '11', '2088', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32465, to_date('18-11-2088', 'dd-mm-yyyy'), '4', '18', '323', '11', '2088', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32466, to_date('19-11-2088', 'dd-mm-yyyy'), '5', '19', '324', '11', '2088', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32467, to_date('20-11-2088', 'dd-mm-yyyy'), '6', '20', '325', '11', '2088', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32468, to_date('21-11-2088', 'dd-mm-yyyy'), '7', '21', '326', '11', '2088', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32469, to_date('22-11-2088', 'dd-mm-yyyy'), '1', '22', '327', '11', '2088', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32470, to_date('23-11-2088', 'dd-mm-yyyy'), '2', '23', '328', '11', '2088', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32471, to_date('24-11-2088', 'dd-mm-yyyy'), '3', '24', '329', '11', '2088', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32472, to_date('25-11-2088', 'dd-mm-yyyy'), '4', '25', '330', '11', '2088', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32473, to_date('26-11-2088', 'dd-mm-yyyy'), '5', '26', '331', '11', '2088', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32474, to_date('27-11-2088', 'dd-mm-yyyy'), '6', '27', '332', '11', '2088', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32475, to_date('28-11-2088', 'dd-mm-yyyy'), '7', '28', '333', '11', '2088', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32476, to_date('29-11-2088', 'dd-mm-yyyy'), '1', '29', '334', '11', '2088', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32477, to_date('30-11-2088', 'dd-mm-yyyy'), '2', '30', '335', '11', '2088', '49', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32478, to_date('01-12-2088', 'dd-mm-yyyy'), '3', '01', '336', '12', '2088', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32479, to_date('02-12-2088', 'dd-mm-yyyy'), '4', '02', '337', '12', '2088', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32480, to_date('03-12-2088', 'dd-mm-yyyy'), '5', '03', '338', '12', '2088', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32481, to_date('04-12-2088', 'dd-mm-yyyy'), '6', '04', '339', '12', '2088', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32482, to_date('05-12-2088', 'dd-mm-yyyy'), '7', '05', '340', '12', '2088', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32483, to_date('06-12-2088', 'dd-mm-yyyy'), '1', '06', '341', '12', '2088', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32484, to_date('07-12-2088', 'dd-mm-yyyy'), '2', '07', '342', '12', '2088', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32485, to_date('08-12-2088', 'dd-mm-yyyy'), '3', '08', '343', '12', '2088', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32486, to_date('09-12-2088', 'dd-mm-yyyy'), '4', '09', '344', '12', '2088', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32487, to_date('10-12-2088', 'dd-mm-yyyy'), '5', '10', '345', '12', '2088', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32488, to_date('11-12-2088', 'dd-mm-yyyy'), '6', '11', '346', '12', '2088', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32489, to_date('12-12-2088', 'dd-mm-yyyy'), '7', '12', '347', '12', '2088', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32490, to_date('13-12-2088', 'dd-mm-yyyy'), '1', '13', '348', '12', '2088', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32491, to_date('14-12-2088', 'dd-mm-yyyy'), '2', '14', '349', '12', '2088', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32492, to_date('15-12-2088', 'dd-mm-yyyy'), '3', '15', '350', '12', '2088', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32493, to_date('16-12-2088', 'dd-mm-yyyy'), '4', '16', '351', '12', '2088', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32494, to_date('17-12-2088', 'dd-mm-yyyy'), '5', '17', '352', '12', '2088', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32495, to_date('18-12-2088', 'dd-mm-yyyy'), '6', '18', '353', '12', '2088', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32496, to_date('19-12-2088', 'dd-mm-yyyy'), '7', '19', '354', '12', '2088', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32497, to_date('20-12-2088', 'dd-mm-yyyy'), '1', '20', '355', '12', '2088', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32498, to_date('21-12-2088', 'dd-mm-yyyy'), '2', '21', '356', '12', '2088', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32499, to_date('22-12-2088', 'dd-mm-yyyy'), '3', '22', '357', '12', '2088', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32500, to_date('23-12-2088', 'dd-mm-yyyy'), '4', '23', '358', '12', '2088', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32501, to_date('24-12-2088', 'dd-mm-yyyy'), '5', '24', '359', '12', '2088', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32502, to_date('25-12-2088', 'dd-mm-yyyy'), '6', '25', '360', '12', '2088', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32503, to_date('26-12-2088', 'dd-mm-yyyy'), '7', '26', '361', '12', '2088', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32504, to_date('27-12-2088', 'dd-mm-yyyy'), '1', '27', '362', '12', '2088', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32505, to_date('28-12-2088', 'dd-mm-yyyy'), '2', '28', '363', '12', '2088', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32506, to_date('29-12-2088', 'dd-mm-yyyy'), '3', '29', '364', '12', '2088', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32507, to_date('30-12-2088', 'dd-mm-yyyy'), '4', '30', '365', '12', '2088', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32508, to_date('31-12-2088', 'dd-mm-yyyy'), '5', '31', '366', '12', '2088', '53', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32509, to_date('01-01-2089', 'dd-mm-yyyy'), '6', '01', '001', '01', '2089', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32510, to_date('02-01-2089', 'dd-mm-yyyy'), '7', '02', '002', '01', '2089', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32511, to_date('03-01-2089', 'dd-mm-yyyy'), '1', '03', '003', '01', '2089', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32512, to_date('04-01-2089', 'dd-mm-yyyy'), '2', '04', '004', '01', '2089', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32513, to_date('05-01-2089', 'dd-mm-yyyy'), '3', '05', '005', '01', '2089', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32514, to_date('06-01-2089', 'dd-mm-yyyy'), '4', '06', '006', '01', '2089', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32515, to_date('07-01-2089', 'dd-mm-yyyy'), '5', '07', '007', '01', '2089', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32516, to_date('08-01-2089', 'dd-mm-yyyy'), '6', '08', '008', '01', '2089', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32517, to_date('09-01-2089', 'dd-mm-yyyy'), '7', '09', '009', '01', '2089', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32518, to_date('10-01-2089', 'dd-mm-yyyy'), '1', '10', '010', '01', '2089', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32519, to_date('11-01-2089', 'dd-mm-yyyy'), '2', '11', '011', '01', '2089', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32520, to_date('12-01-2089', 'dd-mm-yyyy'), '3', '12', '012', '01', '2089', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32521, to_date('13-01-2089', 'dd-mm-yyyy'), '4', '13', '013', '01', '2089', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32522, to_date('14-01-2089', 'dd-mm-yyyy'), '5', '14', '014', '01', '2089', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32523, to_date('15-01-2089', 'dd-mm-yyyy'), '6', '15', '015', '01', '2089', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32524, to_date('16-01-2089', 'dd-mm-yyyy'), '7', '16', '016', '01', '2089', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32525, to_date('17-01-2089', 'dd-mm-yyyy'), '1', '17', '017', '01', '2089', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32526, to_date('18-01-2089', 'dd-mm-yyyy'), '2', '18', '018', '01', '2089', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32527, to_date('19-01-2089', 'dd-mm-yyyy'), '3', '19', '019', '01', '2089', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32528, to_date('20-01-2089', 'dd-mm-yyyy'), '4', '20', '020', '01', '2089', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32529, to_date('21-01-2089', 'dd-mm-yyyy'), '5', '21', '021', '01', '2089', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32530, to_date('22-01-2089', 'dd-mm-yyyy'), '6', '22', '022', '01', '2089', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32531, to_date('23-01-2089', 'dd-mm-yyyy'), '7', '23', '023', '01', '2089', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32532, to_date('24-01-2089', 'dd-mm-yyyy'), '1', '24', '024', '01', '2089', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32533, to_date('25-01-2089', 'dd-mm-yyyy'), '2', '25', '025', '01', '2089', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32534, to_date('26-01-2089', 'dd-mm-yyyy'), '3', '26', '026', '01', '2089', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32535, to_date('27-01-2089', 'dd-mm-yyyy'), '4', '27', '027', '01', '2089', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32536, to_date('28-01-2089', 'dd-mm-yyyy'), '5', '28', '028', '01', '2089', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32537, to_date('29-01-2089', 'dd-mm-yyyy'), '6', '29', '029', '01', '2089', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32538, to_date('30-01-2089', 'dd-mm-yyyy'), '7', '30', '030', '01', '2089', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32539, to_date('31-01-2089', 'dd-mm-yyyy'), '1', '31', '031', '01', '2089', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32540, to_date('01-02-2089', 'dd-mm-yyyy'), '2', '01', '032', '02', '2089', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32541, to_date('02-02-2089', 'dd-mm-yyyy'), '3', '02', '033', '02', '2089', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32542, to_date('03-02-2089', 'dd-mm-yyyy'), '4', '03', '034', '02', '2089', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32543, to_date('04-02-2089', 'dd-mm-yyyy'), '5', '04', '035', '02', '2089', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32544, to_date('05-02-2089', 'dd-mm-yyyy'), '6', '05', '036', '02', '2089', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32545, to_date('06-02-2089', 'dd-mm-yyyy'), '7', '06', '037', '02', '2089', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32546, to_date('07-02-2089', 'dd-mm-yyyy'), '1', '07', '038', '02', '2089', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32547, to_date('08-02-2089', 'dd-mm-yyyy'), '2', '08', '039', '02', '2089', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32548, to_date('09-02-2089', 'dd-mm-yyyy'), '3', '09', '040', '02', '2089', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32549, to_date('10-02-2089', 'dd-mm-yyyy'), '4', '10', '041', '02', '2089', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32550, to_date('11-02-2089', 'dd-mm-yyyy'), '5', '11', '042', '02', '2089', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32551, to_date('12-02-2089', 'dd-mm-yyyy'), '6', '12', '043', '02', '2089', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32552, to_date('13-02-2089', 'dd-mm-yyyy'), '7', '13', '044', '02', '2089', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32553, to_date('14-02-2089', 'dd-mm-yyyy'), '1', '14', '045', '02', '2089', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32554, to_date('15-02-2089', 'dd-mm-yyyy'), '2', '15', '046', '02', '2089', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32555, to_date('16-02-2089', 'dd-mm-yyyy'), '3', '16', '047', '02', '2089', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32556, to_date('17-02-2089', 'dd-mm-yyyy'), '4', '17', '048', '02', '2089', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32557, to_date('18-02-2089', 'dd-mm-yyyy'), '5', '18', '049', '02', '2089', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32558, to_date('19-02-2089', 'dd-mm-yyyy'), '6', '19', '050', '02', '2089', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32559, to_date('20-02-2089', 'dd-mm-yyyy'), '7', '20', '051', '02', '2089', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32560, to_date('21-02-2089', 'dd-mm-yyyy'), '1', '21', '052', '02', '2089', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32561, to_date('22-02-2089', 'dd-mm-yyyy'), '2', '22', '053', '02', '2089', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32562, to_date('23-02-2089', 'dd-mm-yyyy'), '3', '23', '054', '02', '2089', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32563, to_date('24-02-2089', 'dd-mm-yyyy'), '4', '24', '055', '02', '2089', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32564, to_date('25-02-2089', 'dd-mm-yyyy'), '5', '25', '056', '02', '2089', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32565, to_date('26-02-2089', 'dd-mm-yyyy'), '6', '26', '057', '02', '2089', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32566, to_date('27-02-2089', 'dd-mm-yyyy'), '7', '27', '058', '02', '2089', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32567, to_date('28-02-2089', 'dd-mm-yyyy'), '1', '28', '059', '02', '2089', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32568, to_date('01-03-2089', 'dd-mm-yyyy'), '2', '01', '060', '03', '2089', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32569, to_date('02-03-2089', 'dd-mm-yyyy'), '3', '02', '061', '03', '2089', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32570, to_date('03-03-2089', 'dd-mm-yyyy'), '4', '03', '062', '03', '2089', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32571, to_date('04-03-2089', 'dd-mm-yyyy'), '5', '04', '063', '03', '2089', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32572, to_date('05-03-2089', 'dd-mm-yyyy'), '6', '05', '064', '03', '2089', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32573, to_date('06-03-2089', 'dd-mm-yyyy'), '7', '06', '065', '03', '2089', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32574, to_date('07-03-2089', 'dd-mm-yyyy'), '1', '07', '066', '03', '2089', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32575, to_date('08-03-2089', 'dd-mm-yyyy'), '2', '08', '067', '03', '2089', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32576, to_date('09-03-2089', 'dd-mm-yyyy'), '3', '09', '068', '03', '2089', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32577, to_date('10-03-2089', 'dd-mm-yyyy'), '4', '10', '069', '03', '2089', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32578, to_date('11-03-2089', 'dd-mm-yyyy'), '5', '11', '070', '03', '2089', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32579, to_date('12-03-2089', 'dd-mm-yyyy'), '6', '12', '071', '03', '2089', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32580, to_date('13-03-2089', 'dd-mm-yyyy'), '7', '13', '072', '03', '2089', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32581, to_date('14-03-2089', 'dd-mm-yyyy'), '1', '14', '073', '03', '2089', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32582, to_date('15-03-2089', 'dd-mm-yyyy'), '2', '15', '074', '03', '2089', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32583, to_date('16-03-2089', 'dd-mm-yyyy'), '3', '16', '075', '03', '2089', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32584, to_date('17-03-2089', 'dd-mm-yyyy'), '4', '17', '076', '03', '2089', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32585, to_date('18-03-2089', 'dd-mm-yyyy'), '5', '18', '077', '03', '2089', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32586, to_date('19-03-2089', 'dd-mm-yyyy'), '6', '19', '078', '03', '2089', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32587, to_date('20-03-2089', 'dd-mm-yyyy'), '7', '20', '079', '03', '2089', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32588, to_date('21-03-2089', 'dd-mm-yyyy'), '1', '21', '080', '03', '2089', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32589, to_date('22-03-2089', 'dd-mm-yyyy'), '2', '22', '081', '03', '2089', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32590, to_date('23-03-2089', 'dd-mm-yyyy'), '3', '23', '082', '03', '2089', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32591, to_date('24-03-2089', 'dd-mm-yyyy'), '4', '24', '083', '03', '2089', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32592, to_date('25-03-2089', 'dd-mm-yyyy'), '5', '25', '084', '03', '2089', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32593, to_date('26-03-2089', 'dd-mm-yyyy'), '6', '26', '085', '03', '2089', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32594, to_date('27-03-2089', 'dd-mm-yyyy'), '7', '27', '086', '03', '2089', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32595, to_date('28-03-2089', 'dd-mm-yyyy'), '1', '28', '087', '03', '2089', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32596, to_date('29-03-2089', 'dd-mm-yyyy'), '2', '29', '088', '03', '2089', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32597, to_date('30-03-2089', 'dd-mm-yyyy'), '3', '30', '089', '03', '2089', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32598, to_date('31-03-2089', 'dd-mm-yyyy'), '4', '31', '090', '03', '2089', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32599, to_date('01-04-2089', 'dd-mm-yyyy'), '5', '01', '091', '04', '2089', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32600, to_date('02-04-2089', 'dd-mm-yyyy'), '6', '02', '092', '04', '2089', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32601, to_date('03-04-2089', 'dd-mm-yyyy'), '7', '03', '093', '04', '2089', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32602, to_date('04-04-2089', 'dd-mm-yyyy'), '1', '04', '094', '04', '2089', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32603, to_date('05-04-2089', 'dd-mm-yyyy'), '2', '05', '095', '04', '2089', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32604, to_date('06-04-2089', 'dd-mm-yyyy'), '3', '06', '096', '04', '2089', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32605, to_date('07-04-2089', 'dd-mm-yyyy'), '4', '07', '097', '04', '2089', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32606, to_date('08-04-2089', 'dd-mm-yyyy'), '5', '08', '098', '04', '2089', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32607, to_date('09-04-2089', 'dd-mm-yyyy'), '6', '09', '099', '04', '2089', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32608, to_date('10-04-2089', 'dd-mm-yyyy'), '7', '10', '100', '04', '2089', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32609, to_date('11-04-2089', 'dd-mm-yyyy'), '1', '11', '101', '04', '2089', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32610, to_date('12-04-2089', 'dd-mm-yyyy'), '2', '12', '102', '04', '2089', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32611, to_date('13-04-2089', 'dd-mm-yyyy'), '3', '13', '103', '04', '2089', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32612, to_date('14-04-2089', 'dd-mm-yyyy'), '4', '14', '104', '04', '2089', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32613, to_date('15-04-2089', 'dd-mm-yyyy'), '5', '15', '105', '04', '2089', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32614, to_date('16-04-2089', 'dd-mm-yyyy'), '6', '16', '106', '04', '2089', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32615, to_date('17-04-2089', 'dd-mm-yyyy'), '7', '17', '107', '04', '2089', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32616, to_date('18-04-2089', 'dd-mm-yyyy'), '1', '18', '108', '04', '2089', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32617, to_date('19-04-2089', 'dd-mm-yyyy'), '2', '19', '109', '04', '2089', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32618, to_date('20-04-2089', 'dd-mm-yyyy'), '3', '20', '110', '04', '2089', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32619, to_date('21-04-2089', 'dd-mm-yyyy'), '4', '21', '111', '04', '2089', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32620, to_date('22-04-2089', 'dd-mm-yyyy'), '5', '22', '112', '04', '2089', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32621, to_date('23-04-2089', 'dd-mm-yyyy'), '6', '23', '113', '04', '2089', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32622, to_date('24-04-2089', 'dd-mm-yyyy'), '7', '24', '114', '04', '2089', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32623, to_date('25-04-2089', 'dd-mm-yyyy'), '1', '25', '115', '04', '2089', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32624, to_date('26-04-2089', 'dd-mm-yyyy'), '2', '26', '116', '04', '2089', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32625, to_date('27-04-2089', 'dd-mm-yyyy'), '3', '27', '117', '04', '2089', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32626, to_date('28-04-2089', 'dd-mm-yyyy'), '4', '28', '118', '04', '2089', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32627, to_date('29-04-2089', 'dd-mm-yyyy'), '5', '29', '119', '04', '2089', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32628, to_date('30-04-2089', 'dd-mm-yyyy'), '6', '30', '120', '04', '2089', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32629, to_date('01-05-2089', 'dd-mm-yyyy'), '7', '01', '121', '05', '2089', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32630, to_date('02-05-2089', 'dd-mm-yyyy'), '1', '02', '122', '05', '2089', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32631, to_date('03-05-2089', 'dd-mm-yyyy'), '2', '03', '123', '05', '2089', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32632, to_date('04-05-2089', 'dd-mm-yyyy'), '3', '04', '124', '05', '2089', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32633, to_date('05-05-2089', 'dd-mm-yyyy'), '4', '05', '125', '05', '2089', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32634, to_date('06-05-2089', 'dd-mm-yyyy'), '5', '06', '126', '05', '2089', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32635, to_date('07-05-2089', 'dd-mm-yyyy'), '6', '07', '127', '05', '2089', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32636, to_date('08-05-2089', 'dd-mm-yyyy'), '7', '08', '128', '05', '2089', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32637, to_date('09-05-2089', 'dd-mm-yyyy'), '1', '09', '129', '05', '2089', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32638, to_date('10-05-2089', 'dd-mm-yyyy'), '2', '10', '130', '05', '2089', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32639, to_date('11-05-2089', 'dd-mm-yyyy'), '3', '11', '131', '05', '2089', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32640, to_date('12-05-2089', 'dd-mm-yyyy'), '4', '12', '132', '05', '2089', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32641, to_date('13-05-2089', 'dd-mm-yyyy'), '5', '13', '133', '05', '2089', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32642, to_date('14-05-2089', 'dd-mm-yyyy'), '6', '14', '134', '05', '2089', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32643, to_date('15-05-2089', 'dd-mm-yyyy'), '7', '15', '135', '05', '2089', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32644, to_date('16-05-2089', 'dd-mm-yyyy'), '1', '16', '136', '05', '2089', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32645, to_date('17-05-2089', 'dd-mm-yyyy'), '2', '17', '137', '05', '2089', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32646, to_date('18-05-2089', 'dd-mm-yyyy'), '3', '18', '138', '05', '2089', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32647, to_date('19-05-2089', 'dd-mm-yyyy'), '4', '19', '139', '05', '2089', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32648, to_date('20-05-2089', 'dd-mm-yyyy'), '5', '20', '140', '05', '2089', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32649, to_date('21-05-2089', 'dd-mm-yyyy'), '6', '21', '141', '05', '2089', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32650, to_date('22-05-2089', 'dd-mm-yyyy'), '7', '22', '142', '05', '2089', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32651, to_date('23-05-2089', 'dd-mm-yyyy'), '1', '23', '143', '05', '2089', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32652, to_date('24-05-2089', 'dd-mm-yyyy'), '2', '24', '144', '05', '2089', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32653, to_date('25-05-2089', 'dd-mm-yyyy'), '3', '25', '145', '05', '2089', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32654, to_date('26-05-2089', 'dd-mm-yyyy'), '4', '26', '146', '05', '2089', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32655, to_date('27-05-2089', 'dd-mm-yyyy'), '5', '27', '147', '05', '2089', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32656, to_date('28-05-2089', 'dd-mm-yyyy'), '6', '28', '148', '05', '2089', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32657, to_date('29-05-2089', 'dd-mm-yyyy'), '7', '29', '149', '05', '2089', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32658, to_date('30-05-2089', 'dd-mm-yyyy'), '1', '30', '150', '05', '2089', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32659, to_date('31-05-2089', 'dd-mm-yyyy'), '2', '31', '151', '05', '2089', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32660, to_date('01-06-2089', 'dd-mm-yyyy'), '3', '01', '152', '06', '2089', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32661, to_date('02-06-2089', 'dd-mm-yyyy'), '4', '02', '153', '06', '2089', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32662, to_date('03-06-2089', 'dd-mm-yyyy'), '5', '03', '154', '06', '2089', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32663, to_date('04-06-2089', 'dd-mm-yyyy'), '6', '04', '155', '06', '2089', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32664, to_date('05-06-2089', 'dd-mm-yyyy'), '7', '05', '156', '06', '2089', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32665, to_date('06-06-2089', 'dd-mm-yyyy'), '1', '06', '157', '06', '2089', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32666, to_date('07-06-2089', 'dd-mm-yyyy'), '2', '07', '158', '06', '2089', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32667, to_date('08-06-2089', 'dd-mm-yyyy'), '3', '08', '159', '06', '2089', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32668, to_date('09-06-2089', 'dd-mm-yyyy'), '4', '09', '160', '06', '2089', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32669, to_date('10-06-2089', 'dd-mm-yyyy'), '5', '10', '161', '06', '2089', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32670, to_date('11-06-2089', 'dd-mm-yyyy'), '6', '11', '162', '06', '2089', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32671, to_date('12-06-2089', 'dd-mm-yyyy'), '7', '12', '163', '06', '2089', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32672, to_date('13-06-2089', 'dd-mm-yyyy'), '1', '13', '164', '06', '2089', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32673, to_date('14-06-2089', 'dd-mm-yyyy'), '2', '14', '165', '06', '2089', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32674, to_date('15-06-2089', 'dd-mm-yyyy'), '3', '15', '166', '06', '2089', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32675, to_date('16-06-2089', 'dd-mm-yyyy'), '4', '16', '167', '06', '2089', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32676, to_date('17-06-2089', 'dd-mm-yyyy'), '5', '17', '168', '06', '2089', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32677, to_date('18-06-2089', 'dd-mm-yyyy'), '6', '18', '169', '06', '2089', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32678, to_date('19-06-2089', 'dd-mm-yyyy'), '7', '19', '170', '06', '2089', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32679, to_date('20-06-2089', 'dd-mm-yyyy'), '1', '20', '171', '06', '2089', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32680, to_date('21-06-2089', 'dd-mm-yyyy'), '2', '21', '172', '06', '2089', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32681, to_date('22-06-2089', 'dd-mm-yyyy'), '3', '22', '173', '06', '2089', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32682, to_date('23-06-2089', 'dd-mm-yyyy'), '4', '23', '174', '06', '2089', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32683, to_date('24-06-2089', 'dd-mm-yyyy'), '5', '24', '175', '06', '2089', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32684, to_date('25-06-2089', 'dd-mm-yyyy'), '6', '25', '176', '06', '2089', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32685, to_date('26-06-2089', 'dd-mm-yyyy'), '7', '26', '177', '06', '2089', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32686, to_date('27-06-2089', 'dd-mm-yyyy'), '1', '27', '178', '06', '2089', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32687, to_date('28-06-2089', 'dd-mm-yyyy'), '2', '28', '179', '06', '2089', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32688, to_date('29-06-2089', 'dd-mm-yyyy'), '3', '29', '180', '06', '2089', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32689, to_date('30-06-2089', 'dd-mm-yyyy'), '4', '30', '181', '06', '2089', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32690, to_date('01-07-2089', 'dd-mm-yyyy'), '5', '01', '182', '07', '2089', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32691, to_date('02-07-2089', 'dd-mm-yyyy'), '6', '02', '183', '07', '2089', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32692, to_date('03-07-2089', 'dd-mm-yyyy'), '7', '03', '184', '07', '2089', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32693, to_date('04-07-2089', 'dd-mm-yyyy'), '1', '04', '185', '07', '2089', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32694, to_date('05-07-2089', 'dd-mm-yyyy'), '2', '05', '186', '07', '2089', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32695, to_date('06-07-2089', 'dd-mm-yyyy'), '3', '06', '187', '07', '2089', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32696, to_date('07-07-2089', 'dd-mm-yyyy'), '4', '07', '188', '07', '2089', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32697, to_date('08-07-2089', 'dd-mm-yyyy'), '5', '08', '189', '07', '2089', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32698, to_date('09-07-2089', 'dd-mm-yyyy'), '6', '09', '190', '07', '2089', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32699, to_date('10-07-2089', 'dd-mm-yyyy'), '7', '10', '191', '07', '2089', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32700, to_date('11-07-2089', 'dd-mm-yyyy'), '1', '11', '192', '07', '2089', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32701, to_date('12-07-2089', 'dd-mm-yyyy'), '2', '12', '193', '07', '2089', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32702, to_date('13-07-2089', 'dd-mm-yyyy'), '3', '13', '194', '07', '2089', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32703, to_date('14-07-2089', 'dd-mm-yyyy'), '4', '14', '195', '07', '2089', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32704, to_date('15-07-2089', 'dd-mm-yyyy'), '5', '15', '196', '07', '2089', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32705, to_date('16-07-2089', 'dd-mm-yyyy'), '6', '16', '197', '07', '2089', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32706, to_date('17-07-2089', 'dd-mm-yyyy'), '7', '17', '198', '07', '2089', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32707, to_date('18-07-2089', 'dd-mm-yyyy'), '1', '18', '199', '07', '2089', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32708, to_date('19-07-2089', 'dd-mm-yyyy'), '2', '19', '200', '07', '2089', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32709, to_date('20-07-2089', 'dd-mm-yyyy'), '3', '20', '201', '07', '2089', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32710, to_date('21-07-2089', 'dd-mm-yyyy'), '4', '21', '202', '07', '2089', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32711, to_date('22-07-2089', 'dd-mm-yyyy'), '5', '22', '203', '07', '2089', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32712, to_date('23-07-2089', 'dd-mm-yyyy'), '6', '23', '204', '07', '2089', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32713, to_date('24-07-2089', 'dd-mm-yyyy'), '7', '24', '205', '07', '2089', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32714, to_date('25-07-2089', 'dd-mm-yyyy'), '1', '25', '206', '07', '2089', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32715, to_date('26-07-2089', 'dd-mm-yyyy'), '2', '26', '207', '07', '2089', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32716, to_date('27-07-2089', 'dd-mm-yyyy'), '3', '27', '208', '07', '2089', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32717, to_date('28-07-2089', 'dd-mm-yyyy'), '4', '28', '209', '07', '2089', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32718, to_date('29-07-2089', 'dd-mm-yyyy'), '5', '29', '210', '07', '2089', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32719, to_date('30-07-2089', 'dd-mm-yyyy'), '6', '30', '211', '07', '2089', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32720, to_date('31-07-2089', 'dd-mm-yyyy'), '7', '31', '212', '07', '2089', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32721, to_date('01-08-2089', 'dd-mm-yyyy'), '1', '01', '213', '08', '2089', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32722, to_date('02-08-2089', 'dd-mm-yyyy'), '2', '02', '214', '08', '2089', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32723, to_date('03-08-2089', 'dd-mm-yyyy'), '3', '03', '215', '08', '2089', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32724, to_date('04-08-2089', 'dd-mm-yyyy'), '4', '04', '216', '08', '2089', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32725, to_date('05-08-2089', 'dd-mm-yyyy'), '5', '05', '217', '08', '2089', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32726, to_date('06-08-2089', 'dd-mm-yyyy'), '6', '06', '218', '08', '2089', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32727, to_date('07-08-2089', 'dd-mm-yyyy'), '7', '07', '219', '08', '2089', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32728, to_date('08-08-2089', 'dd-mm-yyyy'), '1', '08', '220', '08', '2089', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32729, to_date('09-08-2089', 'dd-mm-yyyy'), '2', '09', '221', '08', '2089', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32730, to_date('10-08-2089', 'dd-mm-yyyy'), '3', '10', '222', '08', '2089', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32731, to_date('11-08-2089', 'dd-mm-yyyy'), '4', '11', '223', '08', '2089', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32732, to_date('12-08-2089', 'dd-mm-yyyy'), '5', '12', '224', '08', '2089', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32733, to_date('13-08-2089', 'dd-mm-yyyy'), '6', '13', '225', '08', '2089', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32734, to_date('14-08-2089', 'dd-mm-yyyy'), '7', '14', '226', '08', '2089', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32735, to_date('15-08-2089', 'dd-mm-yyyy'), '1', '15', '227', '08', '2089', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32736, to_date('16-08-2089', 'dd-mm-yyyy'), '2', '16', '228', '08', '2089', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32737, to_date('17-08-2089', 'dd-mm-yyyy'), '3', '17', '229', '08', '2089', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32738, to_date('18-08-2089', 'dd-mm-yyyy'), '4', '18', '230', '08', '2089', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32739, to_date('19-08-2089', 'dd-mm-yyyy'), '5', '19', '231', '08', '2089', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32740, to_date('20-08-2089', 'dd-mm-yyyy'), '6', '20', '232', '08', '2089', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32741, to_date('21-08-2089', 'dd-mm-yyyy'), '7', '21', '233', '08', '2089', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32742, to_date('22-08-2089', 'dd-mm-yyyy'), '1', '22', '234', '08', '2089', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32743, to_date('23-08-2089', 'dd-mm-yyyy'), '2', '23', '235', '08', '2089', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32744, to_date('24-08-2089', 'dd-mm-yyyy'), '3', '24', '236', '08', '2089', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32745, to_date('25-08-2089', 'dd-mm-yyyy'), '4', '25', '237', '08', '2089', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32746, to_date('26-08-2089', 'dd-mm-yyyy'), '5', '26', '238', '08', '2089', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32747, to_date('27-08-2089', 'dd-mm-yyyy'), '6', '27', '239', '08', '2089', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32748, to_date('28-08-2089', 'dd-mm-yyyy'), '7', '28', '240', '08', '2089', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32749, to_date('29-08-2089', 'dd-mm-yyyy'), '1', '29', '241', '08', '2089', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32750, to_date('30-08-2089', 'dd-mm-yyyy'), '2', '30', '242', '08', '2089', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32751, to_date('31-08-2089', 'dd-mm-yyyy'), '3', '31', '243', '08', '2089', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32752, to_date('01-09-2089', 'dd-mm-yyyy'), '4', '01', '244', '09', '2089', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32753, to_date('02-09-2089', 'dd-mm-yyyy'), '5', '02', '245', '09', '2089', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32754, to_date('03-09-2089', 'dd-mm-yyyy'), '6', '03', '246', '09', '2089', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32755, to_date('04-09-2089', 'dd-mm-yyyy'), '7', '04', '247', '09', '2089', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32756, to_date('05-09-2089', 'dd-mm-yyyy'), '1', '05', '248', '09', '2089', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32757, to_date('06-09-2089', 'dd-mm-yyyy'), '2', '06', '249', '09', '2089', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32758, to_date('07-09-2089', 'dd-mm-yyyy'), '3', '07', '250', '09', '2089', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32759, to_date('08-09-2089', 'dd-mm-yyyy'), '4', '08', '251', '09', '2089', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32760, to_date('09-09-2089', 'dd-mm-yyyy'), '5', '09', '252', '09', '2089', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32761, to_date('10-09-2089', 'dd-mm-yyyy'), '6', '10', '253', '09', '2089', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32762, to_date('11-09-2089', 'dd-mm-yyyy'), '7', '11', '254', '09', '2089', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32763, to_date('12-09-2089', 'dd-mm-yyyy'), '1', '12', '255', '09', '2089', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32764, to_date('13-09-2089', 'dd-mm-yyyy'), '2', '13', '256', '09', '2089', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32765, to_date('14-09-2089', 'dd-mm-yyyy'), '3', '14', '257', '09', '2089', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32766, to_date('15-09-2089', 'dd-mm-yyyy'), '4', '15', '258', '09', '2089', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32767, to_date('16-09-2089', 'dd-mm-yyyy'), '5', '16', '259', '09', '2089', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32768, to_date('17-09-2089', 'dd-mm-yyyy'), '6', '17', '260', '09', '2089', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32769, to_date('18-09-2089', 'dd-mm-yyyy'), '7', '18', '261', '09', '2089', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32770, to_date('19-09-2089', 'dd-mm-yyyy'), '1', '19', '262', '09', '2089', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32771, to_date('20-09-2089', 'dd-mm-yyyy'), '2', '20', '263', '09', '2089', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32772, to_date('21-09-2089', 'dd-mm-yyyy'), '3', '21', '264', '09', '2089', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32773, to_date('22-09-2089', 'dd-mm-yyyy'), '4', '22', '265', '09', '2089', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32774, to_date('23-09-2089', 'dd-mm-yyyy'), '5', '23', '266', '09', '2089', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32775, to_date('24-09-2089', 'dd-mm-yyyy'), '6', '24', '267', '09', '2089', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32776, to_date('25-09-2089', 'dd-mm-yyyy'), '7', '25', '268', '09', '2089', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32777, to_date('26-09-2089', 'dd-mm-yyyy'), '1', '26', '269', '09', '2089', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32778, to_date('27-09-2089', 'dd-mm-yyyy'), '2', '27', '270', '09', '2089', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32779, to_date('28-09-2089', 'dd-mm-yyyy'), '3', '28', '271', '09', '2089', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32780, to_date('29-09-2089', 'dd-mm-yyyy'), '4', '29', '272', '09', '2089', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32781, to_date('30-09-2089', 'dd-mm-yyyy'), '5', '30', '273', '09', '2089', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32782, to_date('01-10-2089', 'dd-mm-yyyy'), '6', '01', '274', '10', '2089', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32783, to_date('02-10-2089', 'dd-mm-yyyy'), '7', '02', '275', '10', '2089', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32784, to_date('03-10-2089', 'dd-mm-yyyy'), '1', '03', '276', '10', '2089', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32785, to_date('04-10-2089', 'dd-mm-yyyy'), '2', '04', '277', '10', '2089', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32786, to_date('05-10-2089', 'dd-mm-yyyy'), '3', '05', '278', '10', '2089', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32787, to_date('06-10-2089', 'dd-mm-yyyy'), '4', '06', '279', '10', '2089', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32788, to_date('07-10-2089', 'dd-mm-yyyy'), '5', '07', '280', '10', '2089', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32789, to_date('08-10-2089', 'dd-mm-yyyy'), '6', '08', '281', '10', '2089', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32790, to_date('09-10-2089', 'dd-mm-yyyy'), '7', '09', '282', '10', '2089', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32791, to_date('10-10-2089', 'dd-mm-yyyy'), '1', '10', '283', '10', '2089', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32792, to_date('11-10-2089', 'dd-mm-yyyy'), '2', '11', '284', '10', '2089', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32793, to_date('12-10-2089', 'dd-mm-yyyy'), '3', '12', '285', '10', '2089', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32794, to_date('13-10-2089', 'dd-mm-yyyy'), '4', '13', '286', '10', '2089', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32795, to_date('14-10-2089', 'dd-mm-yyyy'), '5', '14', '287', '10', '2089', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32796, to_date('15-10-2089', 'dd-mm-yyyy'), '6', '15', '288', '10', '2089', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32797, to_date('16-10-2089', 'dd-mm-yyyy'), '7', '16', '289', '10', '2089', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32798, to_date('17-10-2089', 'dd-mm-yyyy'), '1', '17', '290', '10', '2089', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32799, to_date('18-10-2089', 'dd-mm-yyyy'), '2', '18', '291', '10', '2089', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32800, to_date('19-10-2089', 'dd-mm-yyyy'), '3', '19', '292', '10', '2089', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32801, to_date('20-10-2089', 'dd-mm-yyyy'), '4', '20', '293', '10', '2089', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32802, to_date('21-10-2089', 'dd-mm-yyyy'), '5', '21', '294', '10', '2089', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32803, to_date('22-10-2089', 'dd-mm-yyyy'), '6', '22', '295', '10', '2089', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32804, to_date('23-10-2089', 'dd-mm-yyyy'), '7', '23', '296', '10', '2089', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32805, to_date('24-10-2089', 'dd-mm-yyyy'), '1', '24', '297', '10', '2089', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32806, to_date('25-10-2089', 'dd-mm-yyyy'), '2', '25', '298', '10', '2089', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32807, to_date('26-10-2089', 'dd-mm-yyyy'), '3', '26', '299', '10', '2089', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32808, to_date('27-10-2089', 'dd-mm-yyyy'), '4', '27', '300', '10', '2089', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32809, to_date('28-10-2089', 'dd-mm-yyyy'), '5', '28', '301', '10', '2089', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32810, to_date('29-10-2089', 'dd-mm-yyyy'), '6', '29', '302', '10', '2089', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32811, to_date('30-10-2089', 'dd-mm-yyyy'), '7', '30', '303', '10', '2089', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32812, to_date('31-10-2089', 'dd-mm-yyyy'), '1', '31', '304', '10', '2089', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32813, to_date('01-11-2089', 'dd-mm-yyyy'), '2', '01', '305', '11', '2089', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32814, to_date('02-11-2089', 'dd-mm-yyyy'), '3', '02', '306', '11', '2089', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32815, to_date('03-11-2089', 'dd-mm-yyyy'), '4', '03', '307', '11', '2089', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32816, to_date('04-11-2089', 'dd-mm-yyyy'), '5', '04', '308', '11', '2089', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32817, to_date('05-11-2089', 'dd-mm-yyyy'), '6', '05', '309', '11', '2089', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32818, to_date('06-11-2089', 'dd-mm-yyyy'), '7', '06', '310', '11', '2089', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32819, to_date('07-11-2089', 'dd-mm-yyyy'), '1', '07', '311', '11', '2089', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32820, to_date('08-11-2089', 'dd-mm-yyyy'), '2', '08', '312', '11', '2089', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32821, to_date('09-11-2089', 'dd-mm-yyyy'), '3', '09', '313', '11', '2089', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32822, to_date('10-11-2089', 'dd-mm-yyyy'), '4', '10', '314', '11', '2089', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32823, to_date('11-11-2089', 'dd-mm-yyyy'), '5', '11', '315', '11', '2089', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32824, to_date('12-11-2089', 'dd-mm-yyyy'), '6', '12', '316', '11', '2089', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32825, to_date('13-11-2089', 'dd-mm-yyyy'), '7', '13', '317', '11', '2089', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32826, to_date('14-11-2089', 'dd-mm-yyyy'), '1', '14', '318', '11', '2089', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32827, to_date('15-11-2089', 'dd-mm-yyyy'), '2', '15', '319', '11', '2089', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32828, to_date('16-11-2089', 'dd-mm-yyyy'), '3', '16', '320', '11', '2089', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32829, to_date('17-11-2089', 'dd-mm-yyyy'), '4', '17', '321', '11', '2089', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32830, to_date('18-11-2089', 'dd-mm-yyyy'), '5', '18', '322', '11', '2089', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32831, to_date('19-11-2089', 'dd-mm-yyyy'), '6', '19', '323', '11', '2089', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32832, to_date('20-11-2089', 'dd-mm-yyyy'), '7', '20', '324', '11', '2089', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32833, to_date('21-11-2089', 'dd-mm-yyyy'), '1', '21', '325', '11', '2089', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32834, to_date('22-11-2089', 'dd-mm-yyyy'), '2', '22', '326', '11', '2089', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26051, to_date('28-04-2071', 'dd-mm-yyyy'), '2', '28', '118', '04', '2071', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26052, to_date('29-04-2071', 'dd-mm-yyyy'), '3', '29', '119', '04', '2071', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26053, to_date('30-04-2071', 'dd-mm-yyyy'), '4', '30', '120', '04', '2071', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26054, to_date('01-05-2071', 'dd-mm-yyyy'), '5', '01', '121', '05', '2071', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26055, to_date('02-05-2071', 'dd-mm-yyyy'), '6', '02', '122', '05', '2071', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26056, to_date('03-05-2071', 'dd-mm-yyyy'), '7', '03', '123', '05', '2071', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26057, to_date('04-05-2071', 'dd-mm-yyyy'), '1', '04', '124', '05', '2071', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26058, to_date('05-05-2071', 'dd-mm-yyyy'), '2', '05', '125', '05', '2071', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26059, to_date('06-05-2071', 'dd-mm-yyyy'), '3', '06', '126', '05', '2071', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26060, to_date('07-05-2071', 'dd-mm-yyyy'), '4', '07', '127', '05', '2071', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26061, to_date('08-05-2071', 'dd-mm-yyyy'), '5', '08', '128', '05', '2071', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26062, to_date('09-05-2071', 'dd-mm-yyyy'), '6', '09', '129', '05', '2071', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26063, to_date('10-05-2071', 'dd-mm-yyyy'), '7', '10', '130', '05', '2071', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26064, to_date('11-05-2071', 'dd-mm-yyyy'), '1', '11', '131', '05', '2071', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26065, to_date('12-05-2071', 'dd-mm-yyyy'), '2', '12', '132', '05', '2071', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26066, to_date('13-05-2071', 'dd-mm-yyyy'), '3', '13', '133', '05', '2071', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26067, to_date('14-05-2071', 'dd-mm-yyyy'), '4', '14', '134', '05', '2071', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26068, to_date('15-05-2071', 'dd-mm-yyyy'), '5', '15', '135', '05', '2071', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26069, to_date('16-05-2071', 'dd-mm-yyyy'), '6', '16', '136', '05', '2071', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26070, to_date('17-05-2071', 'dd-mm-yyyy'), '7', '17', '137', '05', '2071', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26071, to_date('18-05-2071', 'dd-mm-yyyy'), '1', '18', '138', '05', '2071', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26072, to_date('19-05-2071', 'dd-mm-yyyy'), '2', '19', '139', '05', '2071', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26073, to_date('20-05-2071', 'dd-mm-yyyy'), '3', '20', '140', '05', '2071', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26074, to_date('21-05-2071', 'dd-mm-yyyy'), '4', '21', '141', '05', '2071', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26075, to_date('22-05-2071', 'dd-mm-yyyy'), '5', '22', '142', '05', '2071', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26076, to_date('23-05-2071', 'dd-mm-yyyy'), '6', '23', '143', '05', '2071', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26077, to_date('24-05-2071', 'dd-mm-yyyy'), '7', '24', '144', '05', '2071', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26078, to_date('25-05-2071', 'dd-mm-yyyy'), '1', '25', '145', '05', '2071', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26079, to_date('26-05-2071', 'dd-mm-yyyy'), '2', '26', '146', '05', '2071', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26080, to_date('27-05-2071', 'dd-mm-yyyy'), '3', '27', '147', '05', '2071', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26081, to_date('28-05-2071', 'dd-mm-yyyy'), '4', '28', '148', '05', '2071', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26082, to_date('29-05-2071', 'dd-mm-yyyy'), '5', '29', '149', '05', '2071', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26083, to_date('30-05-2071', 'dd-mm-yyyy'), '6', '30', '150', '05', '2071', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26084, to_date('31-05-2071', 'dd-mm-yyyy'), '7', '31', '151', '05', '2071', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26085, to_date('01-06-2071', 'dd-mm-yyyy'), '1', '01', '152', '06', '2071', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26086, to_date('02-06-2071', 'dd-mm-yyyy'), '2', '02', '153', '06', '2071', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26087, to_date('03-06-2071', 'dd-mm-yyyy'), '3', '03', '154', '06', '2071', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26088, to_date('04-06-2071', 'dd-mm-yyyy'), '4', '04', '155', '06', '2071', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26089, to_date('05-06-2071', 'dd-mm-yyyy'), '5', '05', '156', '06', '2071', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26090, to_date('06-06-2071', 'dd-mm-yyyy'), '6', '06', '157', '06', '2071', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26091, to_date('07-06-2071', 'dd-mm-yyyy'), '7', '07', '158', '06', '2071', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26092, to_date('08-06-2071', 'dd-mm-yyyy'), '1', '08', '159', '06', '2071', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26093, to_date('09-06-2071', 'dd-mm-yyyy'), '2', '09', '160', '06', '2071', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26094, to_date('10-06-2071', 'dd-mm-yyyy'), '3', '10', '161', '06', '2071', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26095, to_date('11-06-2071', 'dd-mm-yyyy'), '4', '11', '162', '06', '2071', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26096, to_date('12-06-2071', 'dd-mm-yyyy'), '5', '12', '163', '06', '2071', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26097, to_date('13-06-2071', 'dd-mm-yyyy'), '6', '13', '164', '06', '2071', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26098, to_date('14-06-2071', 'dd-mm-yyyy'), '7', '14', '165', '06', '2071', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26099, to_date('15-06-2071', 'dd-mm-yyyy'), '1', '15', '166', '06', '2071', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26100, to_date('16-06-2071', 'dd-mm-yyyy'), '2', '16', '167', '06', '2071', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26101, to_date('17-06-2071', 'dd-mm-yyyy'), '3', '17', '168', '06', '2071', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26102, to_date('18-06-2071', 'dd-mm-yyyy'), '4', '18', '169', '06', '2071', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26103, to_date('19-06-2071', 'dd-mm-yyyy'), '5', '19', '170', '06', '2071', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26104, to_date('20-06-2071', 'dd-mm-yyyy'), '6', '20', '171', '06', '2071', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26105, to_date('21-06-2071', 'dd-mm-yyyy'), '7', '21', '172', '06', '2071', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26106, to_date('22-06-2071', 'dd-mm-yyyy'), '1', '22', '173', '06', '2071', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26107, to_date('23-06-2071', 'dd-mm-yyyy'), '2', '23', '174', '06', '2071', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26108, to_date('24-06-2071', 'dd-mm-yyyy'), '3', '24', '175', '06', '2071', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26109, to_date('25-06-2071', 'dd-mm-yyyy'), '4', '25', '176', '06', '2071', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26110, to_date('26-06-2071', 'dd-mm-yyyy'), '5', '26', '177', '06', '2071', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26111, to_date('27-06-2071', 'dd-mm-yyyy'), '6', '27', '178', '06', '2071', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26112, to_date('28-06-2071', 'dd-mm-yyyy'), '7', '28', '179', '06', '2071', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26113, to_date('29-06-2071', 'dd-mm-yyyy'), '1', '29', '180', '06', '2071', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26114, to_date('30-06-2071', 'dd-mm-yyyy'), '2', '30', '181', '06', '2071', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26115, to_date('01-07-2071', 'dd-mm-yyyy'), '3', '01', '182', '07', '2071', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26116, to_date('02-07-2071', 'dd-mm-yyyy'), '4', '02', '183', '07', '2071', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26117, to_date('03-07-2071', 'dd-mm-yyyy'), '5', '03', '184', '07', '2071', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26118, to_date('04-07-2071', 'dd-mm-yyyy'), '6', '04', '185', '07', '2071', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26119, to_date('05-07-2071', 'dd-mm-yyyy'), '7', '05', '186', '07', '2071', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26120, to_date('06-07-2071', 'dd-mm-yyyy'), '1', '06', '187', '07', '2071', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26121, to_date('07-07-2071', 'dd-mm-yyyy'), '2', '07', '188', '07', '2071', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26122, to_date('08-07-2071', 'dd-mm-yyyy'), '3', '08', '189', '07', '2071', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26123, to_date('09-07-2071', 'dd-mm-yyyy'), '4', '09', '190', '07', '2071', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26124, to_date('10-07-2071', 'dd-mm-yyyy'), '5', '10', '191', '07', '2071', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26125, to_date('11-07-2071', 'dd-mm-yyyy'), '6', '11', '192', '07', '2071', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26126, to_date('12-07-2071', 'dd-mm-yyyy'), '7', '12', '193', '07', '2071', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26127, to_date('13-07-2071', 'dd-mm-yyyy'), '1', '13', '194', '07', '2071', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26128, to_date('14-07-2071', 'dd-mm-yyyy'), '2', '14', '195', '07', '2071', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26129, to_date('15-07-2071', 'dd-mm-yyyy'), '3', '15', '196', '07', '2071', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26130, to_date('16-07-2071', 'dd-mm-yyyy'), '4', '16', '197', '07', '2071', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26131, to_date('17-07-2071', 'dd-mm-yyyy'), '5', '17', '198', '07', '2071', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26132, to_date('18-07-2071', 'dd-mm-yyyy'), '6', '18', '199', '07', '2071', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26133, to_date('19-07-2071', 'dd-mm-yyyy'), '7', '19', '200', '07', '2071', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26134, to_date('20-07-2071', 'dd-mm-yyyy'), '1', '20', '201', '07', '2071', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26135, to_date('21-07-2071', 'dd-mm-yyyy'), '2', '21', '202', '07', '2071', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26136, to_date('22-07-2071', 'dd-mm-yyyy'), '3', '22', '203', '07', '2071', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26137, to_date('23-07-2071', 'dd-mm-yyyy'), '4', '23', '204', '07', '2071', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26138, to_date('24-07-2071', 'dd-mm-yyyy'), '5', '24', '205', '07', '2071', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26139, to_date('25-07-2071', 'dd-mm-yyyy'), '6', '25', '206', '07', '2071', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26140, to_date('26-07-2071', 'dd-mm-yyyy'), '7', '26', '207', '07', '2071', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26141, to_date('27-07-2071', 'dd-mm-yyyy'), '1', '27', '208', '07', '2071', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26142, to_date('28-07-2071', 'dd-mm-yyyy'), '2', '28', '209', '07', '2071', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26143, to_date('29-07-2071', 'dd-mm-yyyy'), '3', '29', '210', '07', '2071', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26144, to_date('30-07-2071', 'dd-mm-yyyy'), '4', '30', '211', '07', '2071', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26145, to_date('31-07-2071', 'dd-mm-yyyy'), '5', '31', '212', '07', '2071', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26146, to_date('01-08-2071', 'dd-mm-yyyy'), '6', '01', '213', '08', '2071', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26147, to_date('02-08-2071', 'dd-mm-yyyy'), '7', '02', '214', '08', '2071', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26148, to_date('03-08-2071', 'dd-mm-yyyy'), '1', '03', '215', '08', '2071', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26149, to_date('04-08-2071', 'dd-mm-yyyy'), '2', '04', '216', '08', '2071', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26150, to_date('05-08-2071', 'dd-mm-yyyy'), '3', '05', '217', '08', '2071', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26151, to_date('06-08-2071', 'dd-mm-yyyy'), '4', '06', '218', '08', '2071', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26152, to_date('07-08-2071', 'dd-mm-yyyy'), '5', '07', '219', '08', '2071', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26153, to_date('08-08-2071', 'dd-mm-yyyy'), '6', '08', '220', '08', '2071', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26154, to_date('09-08-2071', 'dd-mm-yyyy'), '7', '09', '221', '08', '2071', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26155, to_date('10-08-2071', 'dd-mm-yyyy'), '1', '10', '222', '08', '2071', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26156, to_date('11-08-2071', 'dd-mm-yyyy'), '2', '11', '223', '08', '2071', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27747, to_date('19-12-2075', 'dd-mm-yyyy'), '4', '19', '353', '12', '2075', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27748, to_date('20-12-2075', 'dd-mm-yyyy'), '5', '20', '354', '12', '2075', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27749, to_date('21-12-2075', 'dd-mm-yyyy'), '6', '21', '355', '12', '2075', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27750, to_date('22-12-2075', 'dd-mm-yyyy'), '7', '22', '356', '12', '2075', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27751, to_date('23-12-2075', 'dd-mm-yyyy'), '1', '23', '357', '12', '2075', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27752, to_date('24-12-2075', 'dd-mm-yyyy'), '2', '24', '358', '12', '2075', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27753, to_date('25-12-2075', 'dd-mm-yyyy'), '3', '25', '359', '12', '2075', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27754, to_date('26-12-2075', 'dd-mm-yyyy'), '4', '26', '360', '12', '2075', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27755, to_date('27-12-2075', 'dd-mm-yyyy'), '5', '27', '361', '12', '2075', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27756, to_date('28-12-2075', 'dd-mm-yyyy'), '6', '28', '362', '12', '2075', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27757, to_date('29-12-2075', 'dd-mm-yyyy'), '7', '29', '363', '12', '2075', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27758, to_date('30-12-2075', 'dd-mm-yyyy'), '1', '30', '364', '12', '2075', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27759, to_date('31-12-2075', 'dd-mm-yyyy'), '2', '31', '365', '12', '2075', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27760, to_date('01-01-2076', 'dd-mm-yyyy'), '3', '01', '001', '01', '2076', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27761, to_date('02-01-2076', 'dd-mm-yyyy'), '4', '02', '002', '01', '2076', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27762, to_date('03-01-2076', 'dd-mm-yyyy'), '5', '03', '003', '01', '2076', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27763, to_date('04-01-2076', 'dd-mm-yyyy'), '6', '04', '004', '01', '2076', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27764, to_date('05-01-2076', 'dd-mm-yyyy'), '7', '05', '005', '01', '2076', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27765, to_date('06-01-2076', 'dd-mm-yyyy'), '1', '06', '006', '01', '2076', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27766, to_date('07-01-2076', 'dd-mm-yyyy'), '2', '07', '007', '01', '2076', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27767, to_date('08-01-2076', 'dd-mm-yyyy'), '3', '08', '008', '01', '2076', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27768, to_date('09-01-2076', 'dd-mm-yyyy'), '4', '09', '009', '01', '2076', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27769, to_date('10-01-2076', 'dd-mm-yyyy'), '5', '10', '010', '01', '2076', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27770, to_date('11-01-2076', 'dd-mm-yyyy'), '6', '11', '011', '01', '2076', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27771, to_date('12-01-2076', 'dd-mm-yyyy'), '7', '12', '012', '01', '2076', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27772, to_date('13-01-2076', 'dd-mm-yyyy'), '1', '13', '013', '01', '2076', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27773, to_date('14-01-2076', 'dd-mm-yyyy'), '2', '14', '014', '01', '2076', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27774, to_date('15-01-2076', 'dd-mm-yyyy'), '3', '15', '015', '01', '2076', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27775, to_date('16-01-2076', 'dd-mm-yyyy'), '4', '16', '016', '01', '2076', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27776, to_date('17-01-2076', 'dd-mm-yyyy'), '5', '17', '017', '01', '2076', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27777, to_date('18-01-2076', 'dd-mm-yyyy'), '6', '18', '018', '01', '2076', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27778, to_date('19-01-2076', 'dd-mm-yyyy'), '7', '19', '019', '01', '2076', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27779, to_date('20-01-2076', 'dd-mm-yyyy'), '1', '20', '020', '01', '2076', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27780, to_date('21-01-2076', 'dd-mm-yyyy'), '2', '21', '021', '01', '2076', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27781, to_date('22-01-2076', 'dd-mm-yyyy'), '3', '22', '022', '01', '2076', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27782, to_date('23-01-2076', 'dd-mm-yyyy'), '4', '23', '023', '01', '2076', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27783, to_date('24-01-2076', 'dd-mm-yyyy'), '5', '24', '024', '01', '2076', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27784, to_date('25-01-2076', 'dd-mm-yyyy'), '6', '25', '025', '01', '2076', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27785, to_date('26-01-2076', 'dd-mm-yyyy'), '7', '26', '026', '01', '2076', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27786, to_date('27-01-2076', 'dd-mm-yyyy'), '1', '27', '027', '01', '2076', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27787, to_date('28-01-2076', 'dd-mm-yyyy'), '2', '28', '028', '01', '2076', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27788, to_date('29-01-2076', 'dd-mm-yyyy'), '3', '29', '029', '01', '2076', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27789, to_date('30-01-2076', 'dd-mm-yyyy'), '4', '30', '030', '01', '2076', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27790, to_date('31-01-2076', 'dd-mm-yyyy'), '5', '31', '031', '01', '2076', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27791, to_date('01-02-2076', 'dd-mm-yyyy'), '6', '01', '032', '02', '2076', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27792, to_date('02-02-2076', 'dd-mm-yyyy'), '7', '02', '033', '02', '2076', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27793, to_date('03-02-2076', 'dd-mm-yyyy'), '1', '03', '034', '02', '2076', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27794, to_date('04-02-2076', 'dd-mm-yyyy'), '2', '04', '035', '02', '2076', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27795, to_date('05-02-2076', 'dd-mm-yyyy'), '3', '05', '036', '02', '2076', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27796, to_date('06-02-2076', 'dd-mm-yyyy'), '4', '06', '037', '02', '2076', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27797, to_date('07-02-2076', 'dd-mm-yyyy'), '5', '07', '038', '02', '2076', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27798, to_date('08-02-2076', 'dd-mm-yyyy'), '6', '08', '039', '02', '2076', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27799, to_date('09-02-2076', 'dd-mm-yyyy'), '7', '09', '040', '02', '2076', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27800, to_date('10-02-2076', 'dd-mm-yyyy'), '1', '10', '041', '02', '2076', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27801, to_date('11-02-2076', 'dd-mm-yyyy'), '2', '11', '042', '02', '2076', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27802, to_date('12-02-2076', 'dd-mm-yyyy'), '3', '12', '043', '02', '2076', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27803, to_date('13-02-2076', 'dd-mm-yyyy'), '4', '13', '044', '02', '2076', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27804, to_date('14-02-2076', 'dd-mm-yyyy'), '5', '14', '045', '02', '2076', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27805, to_date('15-02-2076', 'dd-mm-yyyy'), '6', '15', '046', '02', '2076', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27806, to_date('16-02-2076', 'dd-mm-yyyy'), '7', '16', '047', '02', '2076', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27807, to_date('17-02-2076', 'dd-mm-yyyy'), '1', '17', '048', '02', '2076', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27808, to_date('18-02-2076', 'dd-mm-yyyy'), '2', '18', '049', '02', '2076', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27809, to_date('19-02-2076', 'dd-mm-yyyy'), '3', '19', '050', '02', '2076', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27810, to_date('20-02-2076', 'dd-mm-yyyy'), '4', '20', '051', '02', '2076', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27811, to_date('21-02-2076', 'dd-mm-yyyy'), '5', '21', '052', '02', '2076', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27812, to_date('22-02-2076', 'dd-mm-yyyy'), '6', '22', '053', '02', '2076', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27813, to_date('23-02-2076', 'dd-mm-yyyy'), '7', '23', '054', '02', '2076', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27814, to_date('24-02-2076', 'dd-mm-yyyy'), '1', '24', '055', '02', '2076', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27815, to_date('25-02-2076', 'dd-mm-yyyy'), '2', '25', '056', '02', '2076', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27816, to_date('26-02-2076', 'dd-mm-yyyy'), '3', '26', '057', '02', '2076', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27817, to_date('27-02-2076', 'dd-mm-yyyy'), '4', '27', '058', '02', '2076', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27818, to_date('28-02-2076', 'dd-mm-yyyy'), '5', '28', '059', '02', '2076', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27819, to_date('29-02-2076', 'dd-mm-yyyy'), '6', '29', '060', '02', '2076', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27820, to_date('01-03-2076', 'dd-mm-yyyy'), '7', '01', '061', '03', '2076', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27821, to_date('02-03-2076', 'dd-mm-yyyy'), '1', '02', '062', '03', '2076', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27822, to_date('03-03-2076', 'dd-mm-yyyy'), '2', '03', '063', '03', '2076', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27823, to_date('04-03-2076', 'dd-mm-yyyy'), '3', '04', '064', '03', '2076', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27824, to_date('05-03-2076', 'dd-mm-yyyy'), '4', '05', '065', '03', '2076', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27825, to_date('06-03-2076', 'dd-mm-yyyy'), '5', '06', '066', '03', '2076', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27826, to_date('07-03-2076', 'dd-mm-yyyy'), '6', '07', '067', '03', '2076', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27827, to_date('08-03-2076', 'dd-mm-yyyy'), '7', '08', '068', '03', '2076', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27828, to_date('09-03-2076', 'dd-mm-yyyy'), '1', '09', '069', '03', '2076', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27829, to_date('10-03-2076', 'dd-mm-yyyy'), '2', '10', '070', '03', '2076', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27830, to_date('11-03-2076', 'dd-mm-yyyy'), '3', '11', '071', '03', '2076', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27831, to_date('12-03-2076', 'dd-mm-yyyy'), '4', '12', '072', '03', '2076', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27832, to_date('13-03-2076', 'dd-mm-yyyy'), '5', '13', '073', '03', '2076', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27833, to_date('14-03-2076', 'dd-mm-yyyy'), '6', '14', '074', '03', '2076', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27834, to_date('15-03-2076', 'dd-mm-yyyy'), '7', '15', '075', '03', '2076', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27835, to_date('16-03-2076', 'dd-mm-yyyy'), '1', '16', '076', '03', '2076', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27836, to_date('17-03-2076', 'dd-mm-yyyy'), '2', '17', '077', '03', '2076', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27837, to_date('18-03-2076', 'dd-mm-yyyy'), '3', '18', '078', '03', '2076', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27838, to_date('19-03-2076', 'dd-mm-yyyy'), '4', '19', '079', '03', '2076', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27839, to_date('20-03-2076', 'dd-mm-yyyy'), '5', '20', '080', '03', '2076', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27840, to_date('21-03-2076', 'dd-mm-yyyy'), '6', '21', '081', '03', '2076', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27841, to_date('22-03-2076', 'dd-mm-yyyy'), '7', '22', '082', '03', '2076', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27842, to_date('23-03-2076', 'dd-mm-yyyy'), '1', '23', '083', '03', '2076', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27843, to_date('24-03-2076', 'dd-mm-yyyy'), '2', '24', '084', '03', '2076', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27844, to_date('25-03-2076', 'dd-mm-yyyy'), '3', '25', '085', '03', '2076', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27845, to_date('26-03-2076', 'dd-mm-yyyy'), '4', '26', '086', '03', '2076', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27846, to_date('27-03-2076', 'dd-mm-yyyy'), '5', '27', '087', '03', '2076', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27847, to_date('28-03-2076', 'dd-mm-yyyy'), '6', '28', '088', '03', '2076', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27848, to_date('29-03-2076', 'dd-mm-yyyy'), '7', '29', '089', '03', '2076', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27849, to_date('30-03-2076', 'dd-mm-yyyy'), '1', '30', '090', '03', '2076', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27850, to_date('31-03-2076', 'dd-mm-yyyy'), '2', '31', '091', '03', '2076', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27851, to_date('01-04-2076', 'dd-mm-yyyy'), '3', '01', '092', '04', '2076', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27852, to_date('02-04-2076', 'dd-mm-yyyy'), '4', '02', '093', '04', '2076', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29337, to_date('26-04-2080', 'dd-mm-yyyy'), '5', '26', '117', '04', '2080', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29338, to_date('27-04-2080', 'dd-mm-yyyy'), '6', '27', '118', '04', '2080', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29339, to_date('28-04-2080', 'dd-mm-yyyy'), '7', '28', '119', '04', '2080', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29340, to_date('29-04-2080', 'dd-mm-yyyy'), '1', '29', '120', '04', '2080', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29341, to_date('30-04-2080', 'dd-mm-yyyy'), '2', '30', '121', '04', '2080', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29342, to_date('01-05-2080', 'dd-mm-yyyy'), '3', '01', '122', '05', '2080', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29343, to_date('02-05-2080', 'dd-mm-yyyy'), '4', '02', '123', '05', '2080', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29344, to_date('03-05-2080', 'dd-mm-yyyy'), '5', '03', '124', '05', '2080', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29345, to_date('04-05-2080', 'dd-mm-yyyy'), '6', '04', '125', '05', '2080', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29346, to_date('05-05-2080', 'dd-mm-yyyy'), '7', '05', '126', '05', '2080', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29347, to_date('06-05-2080', 'dd-mm-yyyy'), '1', '06', '127', '05', '2080', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29348, to_date('07-05-2080', 'dd-mm-yyyy'), '2', '07', '128', '05', '2080', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29349, to_date('08-05-2080', 'dd-mm-yyyy'), '3', '08', '129', '05', '2080', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29350, to_date('09-05-2080', 'dd-mm-yyyy'), '4', '09', '130', '05', '2080', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29351, to_date('10-05-2080', 'dd-mm-yyyy'), '5', '10', '131', '05', '2080', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29352, to_date('11-05-2080', 'dd-mm-yyyy'), '6', '11', '132', '05', '2080', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29353, to_date('12-05-2080', 'dd-mm-yyyy'), '7', '12', '133', '05', '2080', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29354, to_date('13-05-2080', 'dd-mm-yyyy'), '1', '13', '134', '05', '2080', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29355, to_date('14-05-2080', 'dd-mm-yyyy'), '2', '14', '135', '05', '2080', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29356, to_date('15-05-2080', 'dd-mm-yyyy'), '3', '15', '136', '05', '2080', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29357, to_date('16-05-2080', 'dd-mm-yyyy'), '4', '16', '137', '05', '2080', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29358, to_date('17-05-2080', 'dd-mm-yyyy'), '5', '17', '138', '05', '2080', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29359, to_date('18-05-2080', 'dd-mm-yyyy'), '6', '18', '139', '05', '2080', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29360, to_date('19-05-2080', 'dd-mm-yyyy'), '7', '19', '140', '05', '2080', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29361, to_date('20-05-2080', 'dd-mm-yyyy'), '1', '20', '141', '05', '2080', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29362, to_date('21-05-2080', 'dd-mm-yyyy'), '2', '21', '142', '05', '2080', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29363, to_date('22-05-2080', 'dd-mm-yyyy'), '3', '22', '143', '05', '2080', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29364, to_date('23-05-2080', 'dd-mm-yyyy'), '4', '23', '144', '05', '2080', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29365, to_date('24-05-2080', 'dd-mm-yyyy'), '5', '24', '145', '05', '2080', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29366, to_date('25-05-2080', 'dd-mm-yyyy'), '6', '25', '146', '05', '2080', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29367, to_date('26-05-2080', 'dd-mm-yyyy'), '7', '26', '147', '05', '2080', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29368, to_date('27-05-2080', 'dd-mm-yyyy'), '1', '27', '148', '05', '2080', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29369, to_date('28-05-2080', 'dd-mm-yyyy'), '2', '28', '149', '05', '2080', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29370, to_date('29-05-2080', 'dd-mm-yyyy'), '3', '29', '150', '05', '2080', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29371, to_date('30-05-2080', 'dd-mm-yyyy'), '4', '30', '151', '05', '2080', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29372, to_date('31-05-2080', 'dd-mm-yyyy'), '5', '31', '152', '05', '2080', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29373, to_date('01-06-2080', 'dd-mm-yyyy'), '6', '01', '153', '06', '2080', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29374, to_date('02-06-2080', 'dd-mm-yyyy'), '7', '02', '154', '06', '2080', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29375, to_date('03-06-2080', 'dd-mm-yyyy'), '1', '03', '155', '06', '2080', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29376, to_date('04-06-2080', 'dd-mm-yyyy'), '2', '04', '156', '06', '2080', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29377, to_date('05-06-2080', 'dd-mm-yyyy'), '3', '05', '157', '06', '2080', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29378, to_date('06-06-2080', 'dd-mm-yyyy'), '4', '06', '158', '06', '2080', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29379, to_date('07-06-2080', 'dd-mm-yyyy'), '5', '07', '159', '06', '2080', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29380, to_date('08-06-2080', 'dd-mm-yyyy'), '6', '08', '160', '06', '2080', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29381, to_date('09-06-2080', 'dd-mm-yyyy'), '7', '09', '161', '06', '2080', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29382, to_date('10-06-2080', 'dd-mm-yyyy'), '1', '10', '162', '06', '2080', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29383, to_date('11-06-2080', 'dd-mm-yyyy'), '2', '11', '163', '06', '2080', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29384, to_date('12-06-2080', 'dd-mm-yyyy'), '3', '12', '164', '06', '2080', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29385, to_date('13-06-2080', 'dd-mm-yyyy'), '4', '13', '165', '06', '2080', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29386, to_date('14-06-2080', 'dd-mm-yyyy'), '5', '14', '166', '06', '2080', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29387, to_date('15-06-2080', 'dd-mm-yyyy'), '6', '15', '167', '06', '2080', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29388, to_date('16-06-2080', 'dd-mm-yyyy'), '7', '16', '168', '06', '2080', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29389, to_date('17-06-2080', 'dd-mm-yyyy'), '1', '17', '169', '06', '2080', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29390, to_date('18-06-2080', 'dd-mm-yyyy'), '2', '18', '170', '06', '2080', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29391, to_date('19-06-2080', 'dd-mm-yyyy'), '3', '19', '171', '06', '2080', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29392, to_date('20-06-2080', 'dd-mm-yyyy'), '4', '20', '172', '06', '2080', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29393, to_date('21-06-2080', 'dd-mm-yyyy'), '5', '21', '173', '06', '2080', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29394, to_date('22-06-2080', 'dd-mm-yyyy'), '6', '22', '174', '06', '2080', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29395, to_date('23-06-2080', 'dd-mm-yyyy'), '7', '23', '175', '06', '2080', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29396, to_date('24-06-2080', 'dd-mm-yyyy'), '1', '24', '176', '06', '2080', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29397, to_date('25-06-2080', 'dd-mm-yyyy'), '2', '25', '177', '06', '2080', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29398, to_date('26-06-2080', 'dd-mm-yyyy'), '3', '26', '178', '06', '2080', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29399, to_date('27-06-2080', 'dd-mm-yyyy'), '4', '27', '179', '06', '2080', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29400, to_date('28-06-2080', 'dd-mm-yyyy'), '5', '28', '180', '06', '2080', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29401, to_date('29-06-2080', 'dd-mm-yyyy'), '6', '29', '181', '06', '2080', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29402, to_date('30-06-2080', 'dd-mm-yyyy'), '7', '30', '182', '06', '2080', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29403, to_date('01-07-2080', 'dd-mm-yyyy'), '1', '01', '183', '07', '2080', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29404, to_date('02-07-2080', 'dd-mm-yyyy'), '2', '02', '184', '07', '2080', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29405, to_date('03-07-2080', 'dd-mm-yyyy'), '3', '03', '185', '07', '2080', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29406, to_date('04-07-2080', 'dd-mm-yyyy'), '4', '04', '186', '07', '2080', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29407, to_date('05-07-2080', 'dd-mm-yyyy'), '5', '05', '187', '07', '2080', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29408, to_date('06-07-2080', 'dd-mm-yyyy'), '6', '06', '188', '07', '2080', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29409, to_date('07-07-2080', 'dd-mm-yyyy'), '7', '07', '189', '07', '2080', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29410, to_date('08-07-2080', 'dd-mm-yyyy'), '1', '08', '190', '07', '2080', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29411, to_date('09-07-2080', 'dd-mm-yyyy'), '2', '09', '191', '07', '2080', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29412, to_date('10-07-2080', 'dd-mm-yyyy'), '3', '10', '192', '07', '2080', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29413, to_date('11-07-2080', 'dd-mm-yyyy'), '4', '11', '193', '07', '2080', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29414, to_date('12-07-2080', 'dd-mm-yyyy'), '5', '12', '194', '07', '2080', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29415, to_date('13-07-2080', 'dd-mm-yyyy'), '6', '13', '195', '07', '2080', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29416, to_date('14-07-2080', 'dd-mm-yyyy'), '7', '14', '196', '07', '2080', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29417, to_date('15-07-2080', 'dd-mm-yyyy'), '1', '15', '197', '07', '2080', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29418, to_date('16-07-2080', 'dd-mm-yyyy'), '2', '16', '198', '07', '2080', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29419, to_date('17-07-2080', 'dd-mm-yyyy'), '3', '17', '199', '07', '2080', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29420, to_date('18-07-2080', 'dd-mm-yyyy'), '4', '18', '200', '07', '2080', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29421, to_date('19-07-2080', 'dd-mm-yyyy'), '5', '19', '201', '07', '2080', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29422, to_date('20-07-2080', 'dd-mm-yyyy'), '6', '20', '202', '07', '2080', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29423, to_date('21-07-2080', 'dd-mm-yyyy'), '7', '21', '203', '07', '2080', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29424, to_date('22-07-2080', 'dd-mm-yyyy'), '1', '22', '204', '07', '2080', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29425, to_date('23-07-2080', 'dd-mm-yyyy'), '2', '23', '205', '07', '2080', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29426, to_date('24-07-2080', 'dd-mm-yyyy'), '3', '24', '206', '07', '2080', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29427, to_date('25-07-2080', 'dd-mm-yyyy'), '4', '25', '207', '07', '2080', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29428, to_date('26-07-2080', 'dd-mm-yyyy'), '5', '26', '208', '07', '2080', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29429, to_date('27-07-2080', 'dd-mm-yyyy'), '6', '27', '209', '07', '2080', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29430, to_date('28-07-2080', 'dd-mm-yyyy'), '7', '28', '210', '07', '2080', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29431, to_date('29-07-2080', 'dd-mm-yyyy'), '1', '29', '211', '07', '2080', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29432, to_date('30-07-2080', 'dd-mm-yyyy'), '2', '30', '212', '07', '2080', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29433, to_date('31-07-2080', 'dd-mm-yyyy'), '3', '31', '213', '07', '2080', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29434, to_date('01-08-2080', 'dd-mm-yyyy'), '4', '01', '214', '08', '2080', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29435, to_date('02-08-2080', 'dd-mm-yyyy'), '5', '02', '215', '08', '2080', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29436, to_date('03-08-2080', 'dd-mm-yyyy'), '6', '03', '216', '08', '2080', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29437, to_date('04-08-2080', 'dd-mm-yyyy'), '7', '04', '217', '08', '2080', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29438, to_date('05-08-2080', 'dd-mm-yyyy'), '1', '05', '218', '08', '2080', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29439, to_date('06-08-2080', 'dd-mm-yyyy'), '2', '06', '219', '08', '2080', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29440, to_date('07-08-2080', 'dd-mm-yyyy'), '3', '07', '220', '08', '2080', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29441, to_date('08-08-2080', 'dd-mm-yyyy'), '4', '08', '221', '08', '2080', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29442, to_date('09-08-2080', 'dd-mm-yyyy'), '5', '09', '222', '08', '2080', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30927, to_date('02-09-2084', 'dd-mm-yyyy'), '6', '02', '246', '09', '2084', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30928, to_date('03-09-2084', 'dd-mm-yyyy'), '7', '03', '247', '09', '2084', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30929, to_date('04-09-2084', 'dd-mm-yyyy'), '1', '04', '248', '09', '2084', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30930, to_date('05-09-2084', 'dd-mm-yyyy'), '2', '05', '249', '09', '2084', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30931, to_date('06-09-2084', 'dd-mm-yyyy'), '3', '06', '250', '09', '2084', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30932, to_date('07-09-2084', 'dd-mm-yyyy'), '4', '07', '251', '09', '2084', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30933, to_date('08-09-2084', 'dd-mm-yyyy'), '5', '08', '252', '09', '2084', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30934, to_date('09-09-2084', 'dd-mm-yyyy'), '6', '09', '253', '09', '2084', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30935, to_date('10-09-2084', 'dd-mm-yyyy'), '7', '10', '254', '09', '2084', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30936, to_date('11-09-2084', 'dd-mm-yyyy'), '1', '11', '255', '09', '2084', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30937, to_date('12-09-2084', 'dd-mm-yyyy'), '2', '12', '256', '09', '2084', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30938, to_date('13-09-2084', 'dd-mm-yyyy'), '3', '13', '257', '09', '2084', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30939, to_date('14-09-2084', 'dd-mm-yyyy'), '4', '14', '258', '09', '2084', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30940, to_date('15-09-2084', 'dd-mm-yyyy'), '5', '15', '259', '09', '2084', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30941, to_date('16-09-2084', 'dd-mm-yyyy'), '6', '16', '260', '09', '2084', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30942, to_date('17-09-2084', 'dd-mm-yyyy'), '7', '17', '261', '09', '2084', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30943, to_date('18-09-2084', 'dd-mm-yyyy'), '1', '18', '262', '09', '2084', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30944, to_date('19-09-2084', 'dd-mm-yyyy'), '2', '19', '263', '09', '2084', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30945, to_date('20-09-2084', 'dd-mm-yyyy'), '3', '20', '264', '09', '2084', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30946, to_date('21-09-2084', 'dd-mm-yyyy'), '4', '21', '265', '09', '2084', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30947, to_date('22-09-2084', 'dd-mm-yyyy'), '5', '22', '266', '09', '2084', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30948, to_date('23-09-2084', 'dd-mm-yyyy'), '6', '23', '267', '09', '2084', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30949, to_date('24-09-2084', 'dd-mm-yyyy'), '7', '24', '268', '09', '2084', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30950, to_date('25-09-2084', 'dd-mm-yyyy'), '1', '25', '269', '09', '2084', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30951, to_date('26-09-2084', 'dd-mm-yyyy'), '2', '26', '270', '09', '2084', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30952, to_date('27-09-2084', 'dd-mm-yyyy'), '3', '27', '271', '09', '2084', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30953, to_date('28-09-2084', 'dd-mm-yyyy'), '4', '28', '272', '09', '2084', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30954, to_date('29-09-2084', 'dd-mm-yyyy'), '5', '29', '273', '09', '2084', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30955, to_date('30-09-2084', 'dd-mm-yyyy'), '6', '30', '274', '09', '2084', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30956, to_date('01-10-2084', 'dd-mm-yyyy'), '7', '01', '275', '10', '2084', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30957, to_date('02-10-2084', 'dd-mm-yyyy'), '1', '02', '276', '10', '2084', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30958, to_date('03-10-2084', 'dd-mm-yyyy'), '2', '03', '277', '10', '2084', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30959, to_date('04-10-2084', 'dd-mm-yyyy'), '3', '04', '278', '10', '2084', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30960, to_date('05-10-2084', 'dd-mm-yyyy'), '4', '05', '279', '10', '2084', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30961, to_date('06-10-2084', 'dd-mm-yyyy'), '5', '06', '280', '10', '2084', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30962, to_date('07-10-2084', 'dd-mm-yyyy'), '6', '07', '281', '10', '2084', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30963, to_date('08-10-2084', 'dd-mm-yyyy'), '7', '08', '282', '10', '2084', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30964, to_date('09-10-2084', 'dd-mm-yyyy'), '1', '09', '283', '10', '2084', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30965, to_date('10-10-2084', 'dd-mm-yyyy'), '2', '10', '284', '10', '2084', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30966, to_date('11-10-2084', 'dd-mm-yyyy'), '3', '11', '285', '10', '2084', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30967, to_date('12-10-2084', 'dd-mm-yyyy'), '4', '12', '286', '10', '2084', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30968, to_date('13-10-2084', 'dd-mm-yyyy'), '5', '13', '287', '10', '2084', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30969, to_date('14-10-2084', 'dd-mm-yyyy'), '6', '14', '288', '10', '2084', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30970, to_date('15-10-2084', 'dd-mm-yyyy'), '7', '15', '289', '10', '2084', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30971, to_date('16-10-2084', 'dd-mm-yyyy'), '1', '16', '290', '10', '2084', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30972, to_date('17-10-2084', 'dd-mm-yyyy'), '2', '17', '291', '10', '2084', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30973, to_date('18-10-2084', 'dd-mm-yyyy'), '3', '18', '292', '10', '2084', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30974, to_date('19-10-2084', 'dd-mm-yyyy'), '4', '19', '293', '10', '2084', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30975, to_date('20-10-2084', 'dd-mm-yyyy'), '5', '20', '294', '10', '2084', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30976, to_date('21-10-2084', 'dd-mm-yyyy'), '6', '21', '295', '10', '2084', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30977, to_date('22-10-2084', 'dd-mm-yyyy'), '7', '22', '296', '10', '2084', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30978, to_date('23-10-2084', 'dd-mm-yyyy'), '1', '23', '297', '10', '2084', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30979, to_date('24-10-2084', 'dd-mm-yyyy'), '2', '24', '298', '10', '2084', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30980, to_date('25-10-2084', 'dd-mm-yyyy'), '3', '25', '299', '10', '2084', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30981, to_date('26-10-2084', 'dd-mm-yyyy'), '4', '26', '300', '10', '2084', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30982, to_date('27-10-2084', 'dd-mm-yyyy'), '5', '27', '301', '10', '2084', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30983, to_date('28-10-2084', 'dd-mm-yyyy'), '6', '28', '302', '10', '2084', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30984, to_date('29-10-2084', 'dd-mm-yyyy'), '7', '29', '303', '10', '2084', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30985, to_date('30-10-2084', 'dd-mm-yyyy'), '1', '30', '304', '10', '2084', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30986, to_date('31-10-2084', 'dd-mm-yyyy'), '2', '31', '305', '10', '2084', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30987, to_date('01-11-2084', 'dd-mm-yyyy'), '3', '01', '306', '11', '2084', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30988, to_date('02-11-2084', 'dd-mm-yyyy'), '4', '02', '307', '11', '2084', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30989, to_date('03-11-2084', 'dd-mm-yyyy'), '5', '03', '308', '11', '2084', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30990, to_date('04-11-2084', 'dd-mm-yyyy'), '6', '04', '309', '11', '2084', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30991, to_date('05-11-2084', 'dd-mm-yyyy'), '7', '05', '310', '11', '2084', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30992, to_date('06-11-2084', 'dd-mm-yyyy'), '1', '06', '311', '11', '2084', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30993, to_date('07-11-2084', 'dd-mm-yyyy'), '2', '07', '312', '11', '2084', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30994, to_date('08-11-2084', 'dd-mm-yyyy'), '3', '08', '313', '11', '2084', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30995, to_date('09-11-2084', 'dd-mm-yyyy'), '4', '09', '314', '11', '2084', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30996, to_date('10-11-2084', 'dd-mm-yyyy'), '5', '10', '315', '11', '2084', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30997, to_date('11-11-2084', 'dd-mm-yyyy'), '6', '11', '316', '11', '2084', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30998, to_date('12-11-2084', 'dd-mm-yyyy'), '7', '12', '317', '11', '2084', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30999, to_date('13-11-2084', 'dd-mm-yyyy'), '1', '13', '318', '11', '2084', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31000, to_date('14-11-2084', 'dd-mm-yyyy'), '2', '14', '319', '11', '2084', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31001, to_date('15-11-2084', 'dd-mm-yyyy'), '3', '15', '320', '11', '2084', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31002, to_date('16-11-2084', 'dd-mm-yyyy'), '4', '16', '321', '11', '2084', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31003, to_date('17-11-2084', 'dd-mm-yyyy'), '5', '17', '322', '11', '2084', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31004, to_date('18-11-2084', 'dd-mm-yyyy'), '6', '18', '323', '11', '2084', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31005, to_date('19-11-2084', 'dd-mm-yyyy'), '7', '19', '324', '11', '2084', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31006, to_date('20-11-2084', 'dd-mm-yyyy'), '1', '20', '325', '11', '2084', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31007, to_date('21-11-2084', 'dd-mm-yyyy'), '2', '21', '326', '11', '2084', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31008, to_date('22-11-2084', 'dd-mm-yyyy'), '3', '22', '327', '11', '2084', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31009, to_date('23-11-2084', 'dd-mm-yyyy'), '4', '23', '328', '11', '2084', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31010, to_date('24-11-2084', 'dd-mm-yyyy'), '5', '24', '329', '11', '2084', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31011, to_date('25-11-2084', 'dd-mm-yyyy'), '6', '25', '330', '11', '2084', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31012, to_date('26-11-2084', 'dd-mm-yyyy'), '7', '26', '331', '11', '2084', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31013, to_date('27-11-2084', 'dd-mm-yyyy'), '1', '27', '332', '11', '2084', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31014, to_date('28-11-2084', 'dd-mm-yyyy'), '2', '28', '333', '11', '2084', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31015, to_date('29-11-2084', 'dd-mm-yyyy'), '3', '29', '334', '11', '2084', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31016, to_date('30-11-2084', 'dd-mm-yyyy'), '4', '30', '335', '11', '2084', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31017, to_date('01-12-2084', 'dd-mm-yyyy'), '5', '01', '336', '12', '2084', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31018, to_date('02-12-2084', 'dd-mm-yyyy'), '6', '02', '337', '12', '2084', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31019, to_date('03-12-2084', 'dd-mm-yyyy'), '7', '03', '338', '12', '2084', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31020, to_date('04-12-2084', 'dd-mm-yyyy'), '1', '04', '339', '12', '2084', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31021, to_date('05-12-2084', 'dd-mm-yyyy'), '2', '05', '340', '12', '2084', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31022, to_date('06-12-2084', 'dd-mm-yyyy'), '3', '06', '341', '12', '2084', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31023, to_date('07-12-2084', 'dd-mm-yyyy'), '4', '07', '342', '12', '2084', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31024, to_date('08-12-2084', 'dd-mm-yyyy'), '5', '08', '343', '12', '2084', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31025, to_date('09-12-2084', 'dd-mm-yyyy'), '6', '09', '344', '12', '2084', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31026, to_date('10-12-2084', 'dd-mm-yyyy'), '7', '10', '345', '12', '2084', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31027, to_date('11-12-2084', 'dd-mm-yyyy'), '1', '11', '346', '12', '2084', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31028, to_date('12-12-2084', 'dd-mm-yyyy'), '2', '12', '347', '12', '2084', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31029, to_date('13-12-2084', 'dd-mm-yyyy'), '3', '13', '348', '12', '2084', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31030, to_date('14-12-2084', 'dd-mm-yyyy'), '4', '14', '349', '12', '2084', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31031, to_date('15-12-2084', 'dd-mm-yyyy'), '5', '15', '350', '12', '2084', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31032, to_date('16-12-2084', 'dd-mm-yyyy'), '6', '16', '351', '12', '2084', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26157, to_date('12-08-2071', 'dd-mm-yyyy'), '3', '12', '224', '08', '2071', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26158, to_date('13-08-2071', 'dd-mm-yyyy'), '4', '13', '225', '08', '2071', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26159, to_date('14-08-2071', 'dd-mm-yyyy'), '5', '14', '226', '08', '2071', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26160, to_date('15-08-2071', 'dd-mm-yyyy'), '6', '15', '227', '08', '2071', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26161, to_date('16-08-2071', 'dd-mm-yyyy'), '7', '16', '228', '08', '2071', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26162, to_date('17-08-2071', 'dd-mm-yyyy'), '1', '17', '229', '08', '2071', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26163, to_date('18-08-2071', 'dd-mm-yyyy'), '2', '18', '230', '08', '2071', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26164, to_date('19-08-2071', 'dd-mm-yyyy'), '3', '19', '231', '08', '2071', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26165, to_date('20-08-2071', 'dd-mm-yyyy'), '4', '20', '232', '08', '2071', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26166, to_date('21-08-2071', 'dd-mm-yyyy'), '5', '21', '233', '08', '2071', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26167, to_date('22-08-2071', 'dd-mm-yyyy'), '6', '22', '234', '08', '2071', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26168, to_date('23-08-2071', 'dd-mm-yyyy'), '7', '23', '235', '08', '2071', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26169, to_date('24-08-2071', 'dd-mm-yyyy'), '1', '24', '236', '08', '2071', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26170, to_date('25-08-2071', 'dd-mm-yyyy'), '2', '25', '237', '08', '2071', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26171, to_date('26-08-2071', 'dd-mm-yyyy'), '3', '26', '238', '08', '2071', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26172, to_date('27-08-2071', 'dd-mm-yyyy'), '4', '27', '239', '08', '2071', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26173, to_date('28-08-2071', 'dd-mm-yyyy'), '5', '28', '240', '08', '2071', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26174, to_date('29-08-2071', 'dd-mm-yyyy'), '6', '29', '241', '08', '2071', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26175, to_date('30-08-2071', 'dd-mm-yyyy'), '7', '30', '242', '08', '2071', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26176, to_date('31-08-2071', 'dd-mm-yyyy'), '1', '31', '243', '08', '2071', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26177, to_date('01-09-2071', 'dd-mm-yyyy'), '2', '01', '244', '09', '2071', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26178, to_date('02-09-2071', 'dd-mm-yyyy'), '3', '02', '245', '09', '2071', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26179, to_date('03-09-2071', 'dd-mm-yyyy'), '4', '03', '246', '09', '2071', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26180, to_date('04-09-2071', 'dd-mm-yyyy'), '5', '04', '247', '09', '2071', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26181, to_date('05-09-2071', 'dd-mm-yyyy'), '6', '05', '248', '09', '2071', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26182, to_date('06-09-2071', 'dd-mm-yyyy'), '7', '06', '249', '09', '2071', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26183, to_date('07-09-2071', 'dd-mm-yyyy'), '1', '07', '250', '09', '2071', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26184, to_date('08-09-2071', 'dd-mm-yyyy'), '2', '08', '251', '09', '2071', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26185, to_date('09-09-2071', 'dd-mm-yyyy'), '3', '09', '252', '09', '2071', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26186, to_date('10-09-2071', 'dd-mm-yyyy'), '4', '10', '253', '09', '2071', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26187, to_date('11-09-2071', 'dd-mm-yyyy'), '5', '11', '254', '09', '2071', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26188, to_date('12-09-2071', 'dd-mm-yyyy'), '6', '12', '255', '09', '2071', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26189, to_date('13-09-2071', 'dd-mm-yyyy'), '7', '13', '256', '09', '2071', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26190, to_date('14-09-2071', 'dd-mm-yyyy'), '1', '14', '257', '09', '2071', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26191, to_date('15-09-2071', 'dd-mm-yyyy'), '2', '15', '258', '09', '2071', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26192, to_date('16-09-2071', 'dd-mm-yyyy'), '3', '16', '259', '09', '2071', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26193, to_date('17-09-2071', 'dd-mm-yyyy'), '4', '17', '260', '09', '2071', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26194, to_date('18-09-2071', 'dd-mm-yyyy'), '5', '18', '261', '09', '2071', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26195, to_date('19-09-2071', 'dd-mm-yyyy'), '6', '19', '262', '09', '2071', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26196, to_date('20-09-2071', 'dd-mm-yyyy'), '7', '20', '263', '09', '2071', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26197, to_date('21-09-2071', 'dd-mm-yyyy'), '1', '21', '264', '09', '2071', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26198, to_date('22-09-2071', 'dd-mm-yyyy'), '2', '22', '265', '09', '2071', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26199, to_date('23-09-2071', 'dd-mm-yyyy'), '3', '23', '266', '09', '2071', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26200, to_date('24-09-2071', 'dd-mm-yyyy'), '4', '24', '267', '09', '2071', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26201, to_date('25-09-2071', 'dd-mm-yyyy'), '5', '25', '268', '09', '2071', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26202, to_date('26-09-2071', 'dd-mm-yyyy'), '6', '26', '269', '09', '2071', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26203, to_date('27-09-2071', 'dd-mm-yyyy'), '7', '27', '270', '09', '2071', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26204, to_date('28-09-2071', 'dd-mm-yyyy'), '1', '28', '271', '09', '2071', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26205, to_date('29-09-2071', 'dd-mm-yyyy'), '2', '29', '272', '09', '2071', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26206, to_date('30-09-2071', 'dd-mm-yyyy'), '3', '30', '273', '09', '2071', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26207, to_date('01-10-2071', 'dd-mm-yyyy'), '4', '01', '274', '10', '2071', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26208, to_date('02-10-2071', 'dd-mm-yyyy'), '5', '02', '275', '10', '2071', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26209, to_date('03-10-2071', 'dd-mm-yyyy'), '6', '03', '276', '10', '2071', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26210, to_date('04-10-2071', 'dd-mm-yyyy'), '7', '04', '277', '10', '2071', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26211, to_date('05-10-2071', 'dd-mm-yyyy'), '1', '05', '278', '10', '2071', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26212, to_date('06-10-2071', 'dd-mm-yyyy'), '2', '06', '279', '10', '2071', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26213, to_date('07-10-2071', 'dd-mm-yyyy'), '3', '07', '280', '10', '2071', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26214, to_date('08-10-2071', 'dd-mm-yyyy'), '4', '08', '281', '10', '2071', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26215, to_date('09-10-2071', 'dd-mm-yyyy'), '5', '09', '282', '10', '2071', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26216, to_date('10-10-2071', 'dd-mm-yyyy'), '6', '10', '283', '10', '2071', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26217, to_date('11-10-2071', 'dd-mm-yyyy'), '7', '11', '284', '10', '2071', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26218, to_date('12-10-2071', 'dd-mm-yyyy'), '1', '12', '285', '10', '2071', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26219, to_date('13-10-2071', 'dd-mm-yyyy'), '2', '13', '286', '10', '2071', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26220, to_date('14-10-2071', 'dd-mm-yyyy'), '3', '14', '287', '10', '2071', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26221, to_date('15-10-2071', 'dd-mm-yyyy'), '4', '15', '288', '10', '2071', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26222, to_date('16-10-2071', 'dd-mm-yyyy'), '5', '16', '289', '10', '2071', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26223, to_date('17-10-2071', 'dd-mm-yyyy'), '6', '17', '290', '10', '2071', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26224, to_date('18-10-2071', 'dd-mm-yyyy'), '7', '18', '291', '10', '2071', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26225, to_date('19-10-2071', 'dd-mm-yyyy'), '1', '19', '292', '10', '2071', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26226, to_date('20-10-2071', 'dd-mm-yyyy'), '2', '20', '293', '10', '2071', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26227, to_date('21-10-2071', 'dd-mm-yyyy'), '3', '21', '294', '10', '2071', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26228, to_date('22-10-2071', 'dd-mm-yyyy'), '4', '22', '295', '10', '2071', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26229, to_date('23-10-2071', 'dd-mm-yyyy'), '5', '23', '296', '10', '2071', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26230, to_date('24-10-2071', 'dd-mm-yyyy'), '6', '24', '297', '10', '2071', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26231, to_date('25-10-2071', 'dd-mm-yyyy'), '7', '25', '298', '10', '2071', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26232, to_date('26-10-2071', 'dd-mm-yyyy'), '1', '26', '299', '10', '2071', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26233, to_date('27-10-2071', 'dd-mm-yyyy'), '2', '27', '300', '10', '2071', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26234, to_date('28-10-2071', 'dd-mm-yyyy'), '3', '28', '301', '10', '2071', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26235, to_date('29-10-2071', 'dd-mm-yyyy'), '4', '29', '302', '10', '2071', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26236, to_date('30-10-2071', 'dd-mm-yyyy'), '5', '30', '303', '10', '2071', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26237, to_date('31-10-2071', 'dd-mm-yyyy'), '6', '31', '304', '10', '2071', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26238, to_date('01-11-2071', 'dd-mm-yyyy'), '7', '01', '305', '11', '2071', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26239, to_date('02-11-2071', 'dd-mm-yyyy'), '1', '02', '306', '11', '2071', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26240, to_date('03-11-2071', 'dd-mm-yyyy'), '2', '03', '307', '11', '2071', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26241, to_date('04-11-2071', 'dd-mm-yyyy'), '3', '04', '308', '11', '2071', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26242, to_date('05-11-2071', 'dd-mm-yyyy'), '4', '05', '309', '11', '2071', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26243, to_date('06-11-2071', 'dd-mm-yyyy'), '5', '06', '310', '11', '2071', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26244, to_date('07-11-2071', 'dd-mm-yyyy'), '6', '07', '311', '11', '2071', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26245, to_date('08-11-2071', 'dd-mm-yyyy'), '7', '08', '312', '11', '2071', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26246, to_date('09-11-2071', 'dd-mm-yyyy'), '1', '09', '313', '11', '2071', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26247, to_date('10-11-2071', 'dd-mm-yyyy'), '2', '10', '314', '11', '2071', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26248, to_date('11-11-2071', 'dd-mm-yyyy'), '3', '11', '315', '11', '2071', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26249, to_date('12-11-2071', 'dd-mm-yyyy'), '4', '12', '316', '11', '2071', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
commit;
prompt 31000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26250, to_date('13-11-2071', 'dd-mm-yyyy'), '5', '13', '317', '11', '2071', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26251, to_date('14-11-2071', 'dd-mm-yyyy'), '6', '14', '318', '11', '2071', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26252, to_date('15-11-2071', 'dd-mm-yyyy'), '7', '15', '319', '11', '2071', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26253, to_date('16-11-2071', 'dd-mm-yyyy'), '1', '16', '320', '11', '2071', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26254, to_date('17-11-2071', 'dd-mm-yyyy'), '2', '17', '321', '11', '2071', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26255, to_date('18-11-2071', 'dd-mm-yyyy'), '3', '18', '322', '11', '2071', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26256, to_date('19-11-2071', 'dd-mm-yyyy'), '4', '19', '323', '11', '2071', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26257, to_date('20-11-2071', 'dd-mm-yyyy'), '5', '20', '324', '11', '2071', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26258, to_date('21-11-2071', 'dd-mm-yyyy'), '6', '21', '325', '11', '2071', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26259, to_date('22-11-2071', 'dd-mm-yyyy'), '7', '22', '326', '11', '2071', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26260, to_date('23-11-2071', 'dd-mm-yyyy'), '1', '23', '327', '11', '2071', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26261, to_date('24-11-2071', 'dd-mm-yyyy'), '2', '24', '328', '11', '2071', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26262, to_date('25-11-2071', 'dd-mm-yyyy'), '3', '25', '329', '11', '2071', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27853, to_date('03-04-2076', 'dd-mm-yyyy'), '5', '03', '094', '04', '2076', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27854, to_date('04-04-2076', 'dd-mm-yyyy'), '6', '04', '095', '04', '2076', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27855, to_date('05-04-2076', 'dd-mm-yyyy'), '7', '05', '096', '04', '2076', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27856, to_date('06-04-2076', 'dd-mm-yyyy'), '1', '06', '097', '04', '2076', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27857, to_date('07-04-2076', 'dd-mm-yyyy'), '2', '07', '098', '04', '2076', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27858, to_date('08-04-2076', 'dd-mm-yyyy'), '3', '08', '099', '04', '2076', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27859, to_date('09-04-2076', 'dd-mm-yyyy'), '4', '09', '100', '04', '2076', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27860, to_date('10-04-2076', 'dd-mm-yyyy'), '5', '10', '101', '04', '2076', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27861, to_date('11-04-2076', 'dd-mm-yyyy'), '6', '11', '102', '04', '2076', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27862, to_date('12-04-2076', 'dd-mm-yyyy'), '7', '12', '103', '04', '2076', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27863, to_date('13-04-2076', 'dd-mm-yyyy'), '1', '13', '104', '04', '2076', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27864, to_date('14-04-2076', 'dd-mm-yyyy'), '2', '14', '105', '04', '2076', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27865, to_date('15-04-2076', 'dd-mm-yyyy'), '3', '15', '106', '04', '2076', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27866, to_date('16-04-2076', 'dd-mm-yyyy'), '4', '16', '107', '04', '2076', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27867, to_date('17-04-2076', 'dd-mm-yyyy'), '5', '17', '108', '04', '2076', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27868, to_date('18-04-2076', 'dd-mm-yyyy'), '6', '18', '109', '04', '2076', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27869, to_date('19-04-2076', 'dd-mm-yyyy'), '7', '19', '110', '04', '2076', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27870, to_date('20-04-2076', 'dd-mm-yyyy'), '1', '20', '111', '04', '2076', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27871, to_date('21-04-2076', 'dd-mm-yyyy'), '2', '21', '112', '04', '2076', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27872, to_date('22-04-2076', 'dd-mm-yyyy'), '3', '22', '113', '04', '2076', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27873, to_date('23-04-2076', 'dd-mm-yyyy'), '4', '23', '114', '04', '2076', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27874, to_date('24-04-2076', 'dd-mm-yyyy'), '5', '24', '115', '04', '2076', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27875, to_date('25-04-2076', 'dd-mm-yyyy'), '6', '25', '116', '04', '2076', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27876, to_date('26-04-2076', 'dd-mm-yyyy'), '7', '26', '117', '04', '2076', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27877, to_date('27-04-2076', 'dd-mm-yyyy'), '1', '27', '118', '04', '2076', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27878, to_date('28-04-2076', 'dd-mm-yyyy'), '2', '28', '119', '04', '2076', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27879, to_date('29-04-2076', 'dd-mm-yyyy'), '3', '29', '120', '04', '2076', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27880, to_date('30-04-2076', 'dd-mm-yyyy'), '4', '30', '121', '04', '2076', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27881, to_date('01-05-2076', 'dd-mm-yyyy'), '5', '01', '122', '05', '2076', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27882, to_date('02-05-2076', 'dd-mm-yyyy'), '6', '02', '123', '05', '2076', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27883, to_date('03-05-2076', 'dd-mm-yyyy'), '7', '03', '124', '05', '2076', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27884, to_date('04-05-2076', 'dd-mm-yyyy'), '1', '04', '125', '05', '2076', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27885, to_date('05-05-2076', 'dd-mm-yyyy'), '2', '05', '126', '05', '2076', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27886, to_date('06-05-2076', 'dd-mm-yyyy'), '3', '06', '127', '05', '2076', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27887, to_date('07-05-2076', 'dd-mm-yyyy'), '4', '07', '128', '05', '2076', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27888, to_date('08-05-2076', 'dd-mm-yyyy'), '5', '08', '129', '05', '2076', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27889, to_date('09-05-2076', 'dd-mm-yyyy'), '6', '09', '130', '05', '2076', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27890, to_date('10-05-2076', 'dd-mm-yyyy'), '7', '10', '131', '05', '2076', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27891, to_date('11-05-2076', 'dd-mm-yyyy'), '1', '11', '132', '05', '2076', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27892, to_date('12-05-2076', 'dd-mm-yyyy'), '2', '12', '133', '05', '2076', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27893, to_date('13-05-2076', 'dd-mm-yyyy'), '3', '13', '134', '05', '2076', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27894, to_date('14-05-2076', 'dd-mm-yyyy'), '4', '14', '135', '05', '2076', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27895, to_date('15-05-2076', 'dd-mm-yyyy'), '5', '15', '136', '05', '2076', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27896, to_date('16-05-2076', 'dd-mm-yyyy'), '6', '16', '137', '05', '2076', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27897, to_date('17-05-2076', 'dd-mm-yyyy'), '7', '17', '138', '05', '2076', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27898, to_date('18-05-2076', 'dd-mm-yyyy'), '1', '18', '139', '05', '2076', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27899, to_date('19-05-2076', 'dd-mm-yyyy'), '2', '19', '140', '05', '2076', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27900, to_date('20-05-2076', 'dd-mm-yyyy'), '3', '20', '141', '05', '2076', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27901, to_date('21-05-2076', 'dd-mm-yyyy'), '4', '21', '142', '05', '2076', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27902, to_date('22-05-2076', 'dd-mm-yyyy'), '5', '22', '143', '05', '2076', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27903, to_date('23-05-2076', 'dd-mm-yyyy'), '6', '23', '144', '05', '2076', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27904, to_date('24-05-2076', 'dd-mm-yyyy'), '7', '24', '145', '05', '2076', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27905, to_date('25-05-2076', 'dd-mm-yyyy'), '1', '25', '146', '05', '2076', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27906, to_date('26-05-2076', 'dd-mm-yyyy'), '2', '26', '147', '05', '2076', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27907, to_date('27-05-2076', 'dd-mm-yyyy'), '3', '27', '148', '05', '2076', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27908, to_date('28-05-2076', 'dd-mm-yyyy'), '4', '28', '149', '05', '2076', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27909, to_date('29-05-2076', 'dd-mm-yyyy'), '5', '29', '150', '05', '2076', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27910, to_date('30-05-2076', 'dd-mm-yyyy'), '6', '30', '151', '05', '2076', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27911, to_date('31-05-2076', 'dd-mm-yyyy'), '7', '31', '152', '05', '2076', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27912, to_date('01-06-2076', 'dd-mm-yyyy'), '1', '01', '153', '06', '2076', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27913, to_date('02-06-2076', 'dd-mm-yyyy'), '2', '02', '154', '06', '2076', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27914, to_date('03-06-2076', 'dd-mm-yyyy'), '3', '03', '155', '06', '2076', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27915, to_date('04-06-2076', 'dd-mm-yyyy'), '4', '04', '156', '06', '2076', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27916, to_date('05-06-2076', 'dd-mm-yyyy'), '5', '05', '157', '06', '2076', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27917, to_date('06-06-2076', 'dd-mm-yyyy'), '6', '06', '158', '06', '2076', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27918, to_date('07-06-2076', 'dd-mm-yyyy'), '7', '07', '159', '06', '2076', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27919, to_date('08-06-2076', 'dd-mm-yyyy'), '1', '08', '160', '06', '2076', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27920, to_date('09-06-2076', 'dd-mm-yyyy'), '2', '09', '161', '06', '2076', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27921, to_date('10-06-2076', 'dd-mm-yyyy'), '3', '10', '162', '06', '2076', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27922, to_date('11-06-2076', 'dd-mm-yyyy'), '4', '11', '163', '06', '2076', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27923, to_date('12-06-2076', 'dd-mm-yyyy'), '5', '12', '164', '06', '2076', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27924, to_date('13-06-2076', 'dd-mm-yyyy'), '6', '13', '165', '06', '2076', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27925, to_date('14-06-2076', 'dd-mm-yyyy'), '7', '14', '166', '06', '2076', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27926, to_date('15-06-2076', 'dd-mm-yyyy'), '1', '15', '167', '06', '2076', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27927, to_date('16-06-2076', 'dd-mm-yyyy'), '2', '16', '168', '06', '2076', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27928, to_date('17-06-2076', 'dd-mm-yyyy'), '3', '17', '169', '06', '2076', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27929, to_date('18-06-2076', 'dd-mm-yyyy'), '4', '18', '170', '06', '2076', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27930, to_date('19-06-2076', 'dd-mm-yyyy'), '5', '19', '171', '06', '2076', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27931, to_date('20-06-2076', 'dd-mm-yyyy'), '6', '20', '172', '06', '2076', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27932, to_date('21-06-2076', 'dd-mm-yyyy'), '7', '21', '173', '06', '2076', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27933, to_date('22-06-2076', 'dd-mm-yyyy'), '1', '22', '174', '06', '2076', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27934, to_date('23-06-2076', 'dd-mm-yyyy'), '2', '23', '175', '06', '2076', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27935, to_date('24-06-2076', 'dd-mm-yyyy'), '3', '24', '176', '06', '2076', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27936, to_date('25-06-2076', 'dd-mm-yyyy'), '4', '25', '177', '06', '2076', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27937, to_date('26-06-2076', 'dd-mm-yyyy'), '5', '26', '178', '06', '2076', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27938, to_date('27-06-2076', 'dd-mm-yyyy'), '6', '27', '179', '06', '2076', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27939, to_date('28-06-2076', 'dd-mm-yyyy'), '7', '28', '180', '06', '2076', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27940, to_date('29-06-2076', 'dd-mm-yyyy'), '1', '29', '181', '06', '2076', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27941, to_date('30-06-2076', 'dd-mm-yyyy'), '2', '30', '182', '06', '2076', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27942, to_date('01-07-2076', 'dd-mm-yyyy'), '3', '01', '183', '07', '2076', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27943, to_date('02-07-2076', 'dd-mm-yyyy'), '4', '02', '184', '07', '2076', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27944, to_date('03-07-2076', 'dd-mm-yyyy'), '5', '03', '185', '07', '2076', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27945, to_date('04-07-2076', 'dd-mm-yyyy'), '6', '04', '186', '07', '2076', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27946, to_date('05-07-2076', 'dd-mm-yyyy'), '7', '05', '187', '07', '2076', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27947, to_date('06-07-2076', 'dd-mm-yyyy'), '1', '06', '188', '07', '2076', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27948, to_date('07-07-2076', 'dd-mm-yyyy'), '2', '07', '189', '07', '2076', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27949, to_date('08-07-2076', 'dd-mm-yyyy'), '3', '08', '190', '07', '2076', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27950, to_date('09-07-2076', 'dd-mm-yyyy'), '4', '09', '191', '07', '2076', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27951, to_date('10-07-2076', 'dd-mm-yyyy'), '5', '10', '192', '07', '2076', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27952, to_date('11-07-2076', 'dd-mm-yyyy'), '6', '11', '193', '07', '2076', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27953, to_date('12-07-2076', 'dd-mm-yyyy'), '7', '12', '194', '07', '2076', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27954, to_date('13-07-2076', 'dd-mm-yyyy'), '1', '13', '195', '07', '2076', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27955, to_date('14-07-2076', 'dd-mm-yyyy'), '2', '14', '196', '07', '2076', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27956, to_date('15-07-2076', 'dd-mm-yyyy'), '3', '15', '197', '07', '2076', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27957, to_date('16-07-2076', 'dd-mm-yyyy'), '4', '16', '198', '07', '2076', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27958, to_date('17-07-2076', 'dd-mm-yyyy'), '5', '17', '199', '07', '2076', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29443, to_date('10-08-2080', 'dd-mm-yyyy'), '6', '10', '223', '08', '2080', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29444, to_date('11-08-2080', 'dd-mm-yyyy'), '7', '11', '224', '08', '2080', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29445, to_date('12-08-2080', 'dd-mm-yyyy'), '1', '12', '225', '08', '2080', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29446, to_date('13-08-2080', 'dd-mm-yyyy'), '2', '13', '226', '08', '2080', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29447, to_date('14-08-2080', 'dd-mm-yyyy'), '3', '14', '227', '08', '2080', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29448, to_date('15-08-2080', 'dd-mm-yyyy'), '4', '15', '228', '08', '2080', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29449, to_date('16-08-2080', 'dd-mm-yyyy'), '5', '16', '229', '08', '2080', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29450, to_date('17-08-2080', 'dd-mm-yyyy'), '6', '17', '230', '08', '2080', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29451, to_date('18-08-2080', 'dd-mm-yyyy'), '7', '18', '231', '08', '2080', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29452, to_date('19-08-2080', 'dd-mm-yyyy'), '1', '19', '232', '08', '2080', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29453, to_date('20-08-2080', 'dd-mm-yyyy'), '2', '20', '233', '08', '2080', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29454, to_date('21-08-2080', 'dd-mm-yyyy'), '3', '21', '234', '08', '2080', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29455, to_date('22-08-2080', 'dd-mm-yyyy'), '4', '22', '235', '08', '2080', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29456, to_date('23-08-2080', 'dd-mm-yyyy'), '5', '23', '236', '08', '2080', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29457, to_date('24-08-2080', 'dd-mm-yyyy'), '6', '24', '237', '08', '2080', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29458, to_date('25-08-2080', 'dd-mm-yyyy'), '7', '25', '238', '08', '2080', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29459, to_date('26-08-2080', 'dd-mm-yyyy'), '1', '26', '239', '08', '2080', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29460, to_date('27-08-2080', 'dd-mm-yyyy'), '2', '27', '240', '08', '2080', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29461, to_date('28-08-2080', 'dd-mm-yyyy'), '3', '28', '241', '08', '2080', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29462, to_date('29-08-2080', 'dd-mm-yyyy'), '4', '29', '242', '08', '2080', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29463, to_date('30-08-2080', 'dd-mm-yyyy'), '5', '30', '243', '08', '2080', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29464, to_date('31-08-2080', 'dd-mm-yyyy'), '6', '31', '244', '08', '2080', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29465, to_date('01-09-2080', 'dd-mm-yyyy'), '7', '01', '245', '09', '2080', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29466, to_date('02-09-2080', 'dd-mm-yyyy'), '1', '02', '246', '09', '2080', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29467, to_date('03-09-2080', 'dd-mm-yyyy'), '2', '03', '247', '09', '2080', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29468, to_date('04-09-2080', 'dd-mm-yyyy'), '3', '04', '248', '09', '2080', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29469, to_date('05-09-2080', 'dd-mm-yyyy'), '4', '05', '249', '09', '2080', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29470, to_date('06-09-2080', 'dd-mm-yyyy'), '5', '06', '250', '09', '2080', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29471, to_date('07-09-2080', 'dd-mm-yyyy'), '6', '07', '251', '09', '2080', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29472, to_date('08-09-2080', 'dd-mm-yyyy'), '7', '08', '252', '09', '2080', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29473, to_date('09-09-2080', 'dd-mm-yyyy'), '1', '09', '253', '09', '2080', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29474, to_date('10-09-2080', 'dd-mm-yyyy'), '2', '10', '254', '09', '2080', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29475, to_date('11-09-2080', 'dd-mm-yyyy'), '3', '11', '255', '09', '2080', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29476, to_date('12-09-2080', 'dd-mm-yyyy'), '4', '12', '256', '09', '2080', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29477, to_date('13-09-2080', 'dd-mm-yyyy'), '5', '13', '257', '09', '2080', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29478, to_date('14-09-2080', 'dd-mm-yyyy'), '6', '14', '258', '09', '2080', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29479, to_date('15-09-2080', 'dd-mm-yyyy'), '7', '15', '259', '09', '2080', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29480, to_date('16-09-2080', 'dd-mm-yyyy'), '1', '16', '260', '09', '2080', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29481, to_date('17-09-2080', 'dd-mm-yyyy'), '2', '17', '261', '09', '2080', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29482, to_date('18-09-2080', 'dd-mm-yyyy'), '3', '18', '262', '09', '2080', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29483, to_date('19-09-2080', 'dd-mm-yyyy'), '4', '19', '263', '09', '2080', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29484, to_date('20-09-2080', 'dd-mm-yyyy'), '5', '20', '264', '09', '2080', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29485, to_date('21-09-2080', 'dd-mm-yyyy'), '6', '21', '265', '09', '2080', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29486, to_date('22-09-2080', 'dd-mm-yyyy'), '7', '22', '266', '09', '2080', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29487, to_date('23-09-2080', 'dd-mm-yyyy'), '1', '23', '267', '09', '2080', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29488, to_date('24-09-2080', 'dd-mm-yyyy'), '2', '24', '268', '09', '2080', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29489, to_date('25-09-2080', 'dd-mm-yyyy'), '3', '25', '269', '09', '2080', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29490, to_date('26-09-2080', 'dd-mm-yyyy'), '4', '26', '270', '09', '2080', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29491, to_date('27-09-2080', 'dd-mm-yyyy'), '5', '27', '271', '09', '2080', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29492, to_date('28-09-2080', 'dd-mm-yyyy'), '6', '28', '272', '09', '2080', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29493, to_date('29-09-2080', 'dd-mm-yyyy'), '7', '29', '273', '09', '2080', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29494, to_date('30-09-2080', 'dd-mm-yyyy'), '1', '30', '274', '09', '2080', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29495, to_date('01-10-2080', 'dd-mm-yyyy'), '2', '01', '275', '10', '2080', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29496, to_date('02-10-2080', 'dd-mm-yyyy'), '3', '02', '276', '10', '2080', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29497, to_date('03-10-2080', 'dd-mm-yyyy'), '4', '03', '277', '10', '2080', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29498, to_date('04-10-2080', 'dd-mm-yyyy'), '5', '04', '278', '10', '2080', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29499, to_date('05-10-2080', 'dd-mm-yyyy'), '6', '05', '279', '10', '2080', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29500, to_date('06-10-2080', 'dd-mm-yyyy'), '7', '06', '280', '10', '2080', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29501, to_date('07-10-2080', 'dd-mm-yyyy'), '1', '07', '281', '10', '2080', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29502, to_date('08-10-2080', 'dd-mm-yyyy'), '2', '08', '282', '10', '2080', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29503, to_date('09-10-2080', 'dd-mm-yyyy'), '3', '09', '283', '10', '2080', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29504, to_date('10-10-2080', 'dd-mm-yyyy'), '4', '10', '284', '10', '2080', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29505, to_date('11-10-2080', 'dd-mm-yyyy'), '5', '11', '285', '10', '2080', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29506, to_date('12-10-2080', 'dd-mm-yyyy'), '6', '12', '286', '10', '2080', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29507, to_date('13-10-2080', 'dd-mm-yyyy'), '7', '13', '287', '10', '2080', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29508, to_date('14-10-2080', 'dd-mm-yyyy'), '1', '14', '288', '10', '2080', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29509, to_date('15-10-2080', 'dd-mm-yyyy'), '2', '15', '289', '10', '2080', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29510, to_date('16-10-2080', 'dd-mm-yyyy'), '3', '16', '290', '10', '2080', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29511, to_date('17-10-2080', 'dd-mm-yyyy'), '4', '17', '291', '10', '2080', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29512, to_date('18-10-2080', 'dd-mm-yyyy'), '5', '18', '292', '10', '2080', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29513, to_date('19-10-2080', 'dd-mm-yyyy'), '6', '19', '293', '10', '2080', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29514, to_date('20-10-2080', 'dd-mm-yyyy'), '7', '20', '294', '10', '2080', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29515, to_date('21-10-2080', 'dd-mm-yyyy'), '1', '21', '295', '10', '2080', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29516, to_date('22-10-2080', 'dd-mm-yyyy'), '2', '22', '296', '10', '2080', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29517, to_date('23-10-2080', 'dd-mm-yyyy'), '3', '23', '297', '10', '2080', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29518, to_date('24-10-2080', 'dd-mm-yyyy'), '4', '24', '298', '10', '2080', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29519, to_date('25-10-2080', 'dd-mm-yyyy'), '5', '25', '299', '10', '2080', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29520, to_date('26-10-2080', 'dd-mm-yyyy'), '6', '26', '300', '10', '2080', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29521, to_date('27-10-2080', 'dd-mm-yyyy'), '7', '27', '301', '10', '2080', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29522, to_date('28-10-2080', 'dd-mm-yyyy'), '1', '28', '302', '10', '2080', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29523, to_date('29-10-2080', 'dd-mm-yyyy'), '2', '29', '303', '10', '2080', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29524, to_date('30-10-2080', 'dd-mm-yyyy'), '3', '30', '304', '10', '2080', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29525, to_date('31-10-2080', 'dd-mm-yyyy'), '4', '31', '305', '10', '2080', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29526, to_date('01-11-2080', 'dd-mm-yyyy'), '5', '01', '306', '11', '2080', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29527, to_date('02-11-2080', 'dd-mm-yyyy'), '6', '02', '307', '11', '2080', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29528, to_date('03-11-2080', 'dd-mm-yyyy'), '7', '03', '308', '11', '2080', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29529, to_date('04-11-2080', 'dd-mm-yyyy'), '1', '04', '309', '11', '2080', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29530, to_date('05-11-2080', 'dd-mm-yyyy'), '2', '05', '310', '11', '2080', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29531, to_date('06-11-2080', 'dd-mm-yyyy'), '3', '06', '311', '11', '2080', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29532, to_date('07-11-2080', 'dd-mm-yyyy'), '4', '07', '312', '11', '2080', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29533, to_date('08-11-2080', 'dd-mm-yyyy'), '5', '08', '313', '11', '2080', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29534, to_date('09-11-2080', 'dd-mm-yyyy'), '6', '09', '314', '11', '2080', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29535, to_date('10-11-2080', 'dd-mm-yyyy'), '7', '10', '315', '11', '2080', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29536, to_date('11-11-2080', 'dd-mm-yyyy'), '1', '11', '316', '11', '2080', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29537, to_date('12-11-2080', 'dd-mm-yyyy'), '2', '12', '317', '11', '2080', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29538, to_date('13-11-2080', 'dd-mm-yyyy'), '3', '13', '318', '11', '2080', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29539, to_date('14-11-2080', 'dd-mm-yyyy'), '4', '14', '319', '11', '2080', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29540, to_date('15-11-2080', 'dd-mm-yyyy'), '5', '15', '320', '11', '2080', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29541, to_date('16-11-2080', 'dd-mm-yyyy'), '6', '16', '321', '11', '2080', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29542, to_date('17-11-2080', 'dd-mm-yyyy'), '7', '17', '322', '11', '2080', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29543, to_date('18-11-2080', 'dd-mm-yyyy'), '1', '18', '323', '11', '2080', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29544, to_date('19-11-2080', 'dd-mm-yyyy'), '2', '19', '324', '11', '2080', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29545, to_date('20-11-2080', 'dd-mm-yyyy'), '3', '20', '325', '11', '2080', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29546, to_date('21-11-2080', 'dd-mm-yyyy'), '4', '21', '326', '11', '2080', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29547, to_date('22-11-2080', 'dd-mm-yyyy'), '5', '22', '327', '11', '2080', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29548, to_date('23-11-2080', 'dd-mm-yyyy'), '6', '23', '328', '11', '2080', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31033, to_date('17-12-2084', 'dd-mm-yyyy'), '7', '17', '352', '12', '2084', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31034, to_date('18-12-2084', 'dd-mm-yyyy'), '1', '18', '353', '12', '2084', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31035, to_date('19-12-2084', 'dd-mm-yyyy'), '2', '19', '354', '12', '2084', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31036, to_date('20-12-2084', 'dd-mm-yyyy'), '3', '20', '355', '12', '2084', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31037, to_date('21-12-2084', 'dd-mm-yyyy'), '4', '21', '356', '12', '2084', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31038, to_date('22-12-2084', 'dd-mm-yyyy'), '5', '22', '357', '12', '2084', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31039, to_date('23-12-2084', 'dd-mm-yyyy'), '6', '23', '358', '12', '2084', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31040, to_date('24-12-2084', 'dd-mm-yyyy'), '7', '24', '359', '12', '2084', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31041, to_date('25-12-2084', 'dd-mm-yyyy'), '1', '25', '360', '12', '2084', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31042, to_date('26-12-2084', 'dd-mm-yyyy'), '2', '26', '361', '12', '2084', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31043, to_date('27-12-2084', 'dd-mm-yyyy'), '3', '27', '362', '12', '2084', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31044, to_date('28-12-2084', 'dd-mm-yyyy'), '4', '28', '363', '12', '2084', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31045, to_date('29-12-2084', 'dd-mm-yyyy'), '5', '29', '364', '12', '2084', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31046, to_date('30-12-2084', 'dd-mm-yyyy'), '6', '30', '365', '12', '2084', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31047, to_date('31-12-2084', 'dd-mm-yyyy'), '7', '31', '366', '12', '2084', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31048, to_date('01-01-2085', 'dd-mm-yyyy'), '1', '01', '001', '01', '2085', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31049, to_date('02-01-2085', 'dd-mm-yyyy'), '2', '02', '002', '01', '2085', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31050, to_date('03-01-2085', 'dd-mm-yyyy'), '3', '03', '003', '01', '2085', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31051, to_date('04-01-2085', 'dd-mm-yyyy'), '4', '04', '004', '01', '2085', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31052, to_date('05-01-2085', 'dd-mm-yyyy'), '5', '05', '005', '01', '2085', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31053, to_date('06-01-2085', 'dd-mm-yyyy'), '6', '06', '006', '01', '2085', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31054, to_date('07-01-2085', 'dd-mm-yyyy'), '7', '07', '007', '01', '2085', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31055, to_date('08-01-2085', 'dd-mm-yyyy'), '1', '08', '008', '01', '2085', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31056, to_date('09-01-2085', 'dd-mm-yyyy'), '2', '09', '009', '01', '2085', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31057, to_date('10-01-2085', 'dd-mm-yyyy'), '3', '10', '010', '01', '2085', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31058, to_date('11-01-2085', 'dd-mm-yyyy'), '4', '11', '011', '01', '2085', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31059, to_date('12-01-2085', 'dd-mm-yyyy'), '5', '12', '012', '01', '2085', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31060, to_date('13-01-2085', 'dd-mm-yyyy'), '6', '13', '013', '01', '2085', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31061, to_date('14-01-2085', 'dd-mm-yyyy'), '7', '14', '014', '01', '2085', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31062, to_date('15-01-2085', 'dd-mm-yyyy'), '1', '15', '015', '01', '2085', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31063, to_date('16-01-2085', 'dd-mm-yyyy'), '2', '16', '016', '01', '2085', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31064, to_date('17-01-2085', 'dd-mm-yyyy'), '3', '17', '017', '01', '2085', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31065, to_date('18-01-2085', 'dd-mm-yyyy'), '4', '18', '018', '01', '2085', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31066, to_date('19-01-2085', 'dd-mm-yyyy'), '5', '19', '019', '01', '2085', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31067, to_date('20-01-2085', 'dd-mm-yyyy'), '6', '20', '020', '01', '2085', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31068, to_date('21-01-2085', 'dd-mm-yyyy'), '7', '21', '021', '01', '2085', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31069, to_date('22-01-2085', 'dd-mm-yyyy'), '1', '22', '022', '01', '2085', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31070, to_date('23-01-2085', 'dd-mm-yyyy'), '2', '23', '023', '01', '2085', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31071, to_date('24-01-2085', 'dd-mm-yyyy'), '3', '24', '024', '01', '2085', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31072, to_date('25-01-2085', 'dd-mm-yyyy'), '4', '25', '025', '01', '2085', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31073, to_date('26-01-2085', 'dd-mm-yyyy'), '5', '26', '026', '01', '2085', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31074, to_date('27-01-2085', 'dd-mm-yyyy'), '6', '27', '027', '01', '2085', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31075, to_date('28-01-2085', 'dd-mm-yyyy'), '7', '28', '028', '01', '2085', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31076, to_date('29-01-2085', 'dd-mm-yyyy'), '1', '29', '029', '01', '2085', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31077, to_date('30-01-2085', 'dd-mm-yyyy'), '2', '30', '030', '01', '2085', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31078, to_date('31-01-2085', 'dd-mm-yyyy'), '3', '31', '031', '01', '2085', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31079, to_date('01-02-2085', 'dd-mm-yyyy'), '4', '01', '032', '02', '2085', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31080, to_date('02-02-2085', 'dd-mm-yyyy'), '5', '02', '033', '02', '2085', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31081, to_date('03-02-2085', 'dd-mm-yyyy'), '6', '03', '034', '02', '2085', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31082, to_date('04-02-2085', 'dd-mm-yyyy'), '7', '04', '035', '02', '2085', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31083, to_date('05-02-2085', 'dd-mm-yyyy'), '1', '05', '036', '02', '2085', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31084, to_date('06-02-2085', 'dd-mm-yyyy'), '2', '06', '037', '02', '2085', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31085, to_date('07-02-2085', 'dd-mm-yyyy'), '3', '07', '038', '02', '2085', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31086, to_date('08-02-2085', 'dd-mm-yyyy'), '4', '08', '039', '02', '2085', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31087, to_date('09-02-2085', 'dd-mm-yyyy'), '5', '09', '040', '02', '2085', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31088, to_date('10-02-2085', 'dd-mm-yyyy'), '6', '10', '041', '02', '2085', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31089, to_date('11-02-2085', 'dd-mm-yyyy'), '7', '11', '042', '02', '2085', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31090, to_date('12-02-2085', 'dd-mm-yyyy'), '1', '12', '043', '02', '2085', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31091, to_date('13-02-2085', 'dd-mm-yyyy'), '2', '13', '044', '02', '2085', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31092, to_date('14-02-2085', 'dd-mm-yyyy'), '3', '14', '045', '02', '2085', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31093, to_date('15-02-2085', 'dd-mm-yyyy'), '4', '15', '046', '02', '2085', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31094, to_date('16-02-2085', 'dd-mm-yyyy'), '5', '16', '047', '02', '2085', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31095, to_date('17-02-2085', 'dd-mm-yyyy'), '6', '17', '048', '02', '2085', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31096, to_date('18-02-2085', 'dd-mm-yyyy'), '7', '18', '049', '02', '2085', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31097, to_date('19-02-2085', 'dd-mm-yyyy'), '1', '19', '050', '02', '2085', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31098, to_date('20-02-2085', 'dd-mm-yyyy'), '2', '20', '051', '02', '2085', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31099, to_date('21-02-2085', 'dd-mm-yyyy'), '3', '21', '052', '02', '2085', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31100, to_date('22-02-2085', 'dd-mm-yyyy'), '4', '22', '053', '02', '2085', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31101, to_date('23-02-2085', 'dd-mm-yyyy'), '5', '23', '054', '02', '2085', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31102, to_date('24-02-2085', 'dd-mm-yyyy'), '6', '24', '055', '02', '2085', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31103, to_date('25-02-2085', 'dd-mm-yyyy'), '7', '25', '056', '02', '2085', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31104, to_date('26-02-2085', 'dd-mm-yyyy'), '1', '26', '057', '02', '2085', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31105, to_date('27-02-2085', 'dd-mm-yyyy'), '2', '27', '058', '02', '2085', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31106, to_date('28-02-2085', 'dd-mm-yyyy'), '3', '28', '059', '02', '2085', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31107, to_date('01-03-2085', 'dd-mm-yyyy'), '4', '01', '060', '03', '2085', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31108, to_date('02-03-2085', 'dd-mm-yyyy'), '5', '02', '061', '03', '2085', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31109, to_date('03-03-2085', 'dd-mm-yyyy'), '6', '03', '062', '03', '2085', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31110, to_date('04-03-2085', 'dd-mm-yyyy'), '7', '04', '063', '03', '2085', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31111, to_date('05-03-2085', 'dd-mm-yyyy'), '1', '05', '064', '03', '2085', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31112, to_date('06-03-2085', 'dd-mm-yyyy'), '2', '06', '065', '03', '2085', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31113, to_date('07-03-2085', 'dd-mm-yyyy'), '3', '07', '066', '03', '2085', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31114, to_date('08-03-2085', 'dd-mm-yyyy'), '4', '08', '067', '03', '2085', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31115, to_date('09-03-2085', 'dd-mm-yyyy'), '5', '09', '068', '03', '2085', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31116, to_date('10-03-2085', 'dd-mm-yyyy'), '6', '10', '069', '03', '2085', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31117, to_date('11-03-2085', 'dd-mm-yyyy'), '7', '11', '070', '03', '2085', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31118, to_date('12-03-2085', 'dd-mm-yyyy'), '1', '12', '071', '03', '2085', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31119, to_date('13-03-2085', 'dd-mm-yyyy'), '2', '13', '072', '03', '2085', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31120, to_date('14-03-2085', 'dd-mm-yyyy'), '3', '14', '073', '03', '2085', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31121, to_date('15-03-2085', 'dd-mm-yyyy'), '4', '15', '074', '03', '2085', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31122, to_date('16-03-2085', 'dd-mm-yyyy'), '5', '16', '075', '03', '2085', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31123, to_date('17-03-2085', 'dd-mm-yyyy'), '6', '17', '076', '03', '2085', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31124, to_date('18-03-2085', 'dd-mm-yyyy'), '7', '18', '077', '03', '2085', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31125, to_date('19-03-2085', 'dd-mm-yyyy'), '1', '19', '078', '03', '2085', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31126, to_date('20-03-2085', 'dd-mm-yyyy'), '2', '20', '079', '03', '2085', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31127, to_date('21-03-2085', 'dd-mm-yyyy'), '3', '21', '080', '03', '2085', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31128, to_date('22-03-2085', 'dd-mm-yyyy'), '4', '22', '081', '03', '2085', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31129, to_date('23-03-2085', 'dd-mm-yyyy'), '5', '23', '082', '03', '2085', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31130, to_date('24-03-2085', 'dd-mm-yyyy'), '6', '24', '083', '03', '2085', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31131, to_date('25-03-2085', 'dd-mm-yyyy'), '7', '25', '084', '03', '2085', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31132, to_date('26-03-2085', 'dd-mm-yyyy'), '1', '26', '085', '03', '2085', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31133, to_date('27-03-2085', 'dd-mm-yyyy'), '2', '27', '086', '03', '2085', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31134, to_date('28-03-2085', 'dd-mm-yyyy'), '3', '28', '087', '03', '2085', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31135, to_date('29-03-2085', 'dd-mm-yyyy'), '4', '29', '088', '03', '2085', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31136, to_date('30-03-2085', 'dd-mm-yyyy'), '5', '30', '089', '03', '2085', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31137, to_date('31-03-2085', 'dd-mm-yyyy'), '6', '31', '090', '03', '2085', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31138, to_date('01-04-2085', 'dd-mm-yyyy'), '7', '01', '091', '04', '2085', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26263, to_date('26-11-2071', 'dd-mm-yyyy'), '4', '26', '330', '11', '2071', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26264, to_date('27-11-2071', 'dd-mm-yyyy'), '5', '27', '331', '11', '2071', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26265, to_date('28-11-2071', 'dd-mm-yyyy'), '6', '28', '332', '11', '2071', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26266, to_date('29-11-2071', 'dd-mm-yyyy'), '7', '29', '333', '11', '2071', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26267, to_date('30-11-2071', 'dd-mm-yyyy'), '1', '30', '334', '11', '2071', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26268, to_date('01-12-2071', 'dd-mm-yyyy'), '2', '01', '335', '12', '2071', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26269, to_date('02-12-2071', 'dd-mm-yyyy'), '3', '02', '336', '12', '2071', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26270, to_date('03-12-2071', 'dd-mm-yyyy'), '4', '03', '337', '12', '2071', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26271, to_date('04-12-2071', 'dd-mm-yyyy'), '5', '04', '338', '12', '2071', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26272, to_date('05-12-2071', 'dd-mm-yyyy'), '6', '05', '339', '12', '2071', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26273, to_date('06-12-2071', 'dd-mm-yyyy'), '7', '06', '340', '12', '2071', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26274, to_date('07-12-2071', 'dd-mm-yyyy'), '1', '07', '341', '12', '2071', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26275, to_date('08-12-2071', 'dd-mm-yyyy'), '2', '08', '342', '12', '2071', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26276, to_date('09-12-2071', 'dd-mm-yyyy'), '3', '09', '343', '12', '2071', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26277, to_date('10-12-2071', 'dd-mm-yyyy'), '4', '10', '344', '12', '2071', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26278, to_date('11-12-2071', 'dd-mm-yyyy'), '5', '11', '345', '12', '2071', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26279, to_date('12-12-2071', 'dd-mm-yyyy'), '6', '12', '346', '12', '2071', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26280, to_date('13-12-2071', 'dd-mm-yyyy'), '7', '13', '347', '12', '2071', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26281, to_date('14-12-2071', 'dd-mm-yyyy'), '1', '14', '348', '12', '2071', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26282, to_date('15-12-2071', 'dd-mm-yyyy'), '2', '15', '349', '12', '2071', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26283, to_date('16-12-2071', 'dd-mm-yyyy'), '3', '16', '350', '12', '2071', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26284, to_date('17-12-2071', 'dd-mm-yyyy'), '4', '17', '351', '12', '2071', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26285, to_date('18-12-2071', 'dd-mm-yyyy'), '5', '18', '352', '12', '2071', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26286, to_date('19-12-2071', 'dd-mm-yyyy'), '6', '19', '353', '12', '2071', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26287, to_date('20-12-2071', 'dd-mm-yyyy'), '7', '20', '354', '12', '2071', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26288, to_date('21-12-2071', 'dd-mm-yyyy'), '1', '21', '355', '12', '2071', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26289, to_date('22-12-2071', 'dd-mm-yyyy'), '2', '22', '356', '12', '2071', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26290, to_date('23-12-2071', 'dd-mm-yyyy'), '3', '23', '357', '12', '2071', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26291, to_date('24-12-2071', 'dd-mm-yyyy'), '4', '24', '358', '12', '2071', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26292, to_date('25-12-2071', 'dd-mm-yyyy'), '5', '25', '359', '12', '2071', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26293, to_date('26-12-2071', 'dd-mm-yyyy'), '6', '26', '360', '12', '2071', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26294, to_date('27-12-2071', 'dd-mm-yyyy'), '7', '27', '361', '12', '2071', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26295, to_date('28-12-2071', 'dd-mm-yyyy'), '1', '28', '362', '12', '2071', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26296, to_date('29-12-2071', 'dd-mm-yyyy'), '2', '29', '363', '12', '2071', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26297, to_date('30-12-2071', 'dd-mm-yyyy'), '3', '30', '364', '12', '2071', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26298, to_date('31-12-2071', 'dd-mm-yyyy'), '4', '31', '365', '12', '2071', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26299, to_date('01-01-2072', 'dd-mm-yyyy'), '5', '01', '001', '01', '2072', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26300, to_date('02-01-2072', 'dd-mm-yyyy'), '6', '02', '002', '01', '2072', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26301, to_date('03-01-2072', 'dd-mm-yyyy'), '7', '03', '003', '01', '2072', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26302, to_date('04-01-2072', 'dd-mm-yyyy'), '1', '04', '004', '01', '2072', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26303, to_date('05-01-2072', 'dd-mm-yyyy'), '2', '05', '005', '01', '2072', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26304, to_date('06-01-2072', 'dd-mm-yyyy'), '3', '06', '006', '01', '2072', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26305, to_date('07-01-2072', 'dd-mm-yyyy'), '4', '07', '007', '01', '2072', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26306, to_date('08-01-2072', 'dd-mm-yyyy'), '5', '08', '008', '01', '2072', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26307, to_date('09-01-2072', 'dd-mm-yyyy'), '6', '09', '009', '01', '2072', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26308, to_date('10-01-2072', 'dd-mm-yyyy'), '7', '10', '010', '01', '2072', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26309, to_date('11-01-2072', 'dd-mm-yyyy'), '1', '11', '011', '01', '2072', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26310, to_date('12-01-2072', 'dd-mm-yyyy'), '2', '12', '012', '01', '2072', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26311, to_date('13-01-2072', 'dd-mm-yyyy'), '3', '13', '013', '01', '2072', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26312, to_date('14-01-2072', 'dd-mm-yyyy'), '4', '14', '014', '01', '2072', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26313, to_date('15-01-2072', 'dd-mm-yyyy'), '5', '15', '015', '01', '2072', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26314, to_date('16-01-2072', 'dd-mm-yyyy'), '6', '16', '016', '01', '2072', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26315, to_date('17-01-2072', 'dd-mm-yyyy'), '7', '17', '017', '01', '2072', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26316, to_date('18-01-2072', 'dd-mm-yyyy'), '1', '18', '018', '01', '2072', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26317, to_date('19-01-2072', 'dd-mm-yyyy'), '2', '19', '019', '01', '2072', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26318, to_date('20-01-2072', 'dd-mm-yyyy'), '3', '20', '020', '01', '2072', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26319, to_date('21-01-2072', 'dd-mm-yyyy'), '4', '21', '021', '01', '2072', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26320, to_date('22-01-2072', 'dd-mm-yyyy'), '5', '22', '022', '01', '2072', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26321, to_date('23-01-2072', 'dd-mm-yyyy'), '6', '23', '023', '01', '2072', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26322, to_date('24-01-2072', 'dd-mm-yyyy'), '7', '24', '024', '01', '2072', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26323, to_date('25-01-2072', 'dd-mm-yyyy'), '1', '25', '025', '01', '2072', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26324, to_date('26-01-2072', 'dd-mm-yyyy'), '2', '26', '026', '01', '2072', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26325, to_date('27-01-2072', 'dd-mm-yyyy'), '3', '27', '027', '01', '2072', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26326, to_date('28-01-2072', 'dd-mm-yyyy'), '4', '28', '028', '01', '2072', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26327, to_date('29-01-2072', 'dd-mm-yyyy'), '5', '29', '029', '01', '2072', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26328, to_date('30-01-2072', 'dd-mm-yyyy'), '6', '30', '030', '01', '2072', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26329, to_date('31-01-2072', 'dd-mm-yyyy'), '7', '31', '031', '01', '2072', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26330, to_date('01-02-2072', 'dd-mm-yyyy'), '1', '01', '032', '02', '2072', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26331, to_date('02-02-2072', 'dd-mm-yyyy'), '2', '02', '033', '02', '2072', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26332, to_date('03-02-2072', 'dd-mm-yyyy'), '3', '03', '034', '02', '2072', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26333, to_date('04-02-2072', 'dd-mm-yyyy'), '4', '04', '035', '02', '2072', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26334, to_date('05-02-2072', 'dd-mm-yyyy'), '5', '05', '036', '02', '2072', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26335, to_date('06-02-2072', 'dd-mm-yyyy'), '6', '06', '037', '02', '2072', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26336, to_date('07-02-2072', 'dd-mm-yyyy'), '7', '07', '038', '02', '2072', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26337, to_date('08-02-2072', 'dd-mm-yyyy'), '1', '08', '039', '02', '2072', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26338, to_date('09-02-2072', 'dd-mm-yyyy'), '2', '09', '040', '02', '2072', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26339, to_date('10-02-2072', 'dd-mm-yyyy'), '3', '10', '041', '02', '2072', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26340, to_date('11-02-2072', 'dd-mm-yyyy'), '4', '11', '042', '02', '2072', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26341, to_date('12-02-2072', 'dd-mm-yyyy'), '5', '12', '043', '02', '2072', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26342, to_date('13-02-2072', 'dd-mm-yyyy'), '6', '13', '044', '02', '2072', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26343, to_date('14-02-2072', 'dd-mm-yyyy'), '7', '14', '045', '02', '2072', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26344, to_date('15-02-2072', 'dd-mm-yyyy'), '1', '15', '046', '02', '2072', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26345, to_date('16-02-2072', 'dd-mm-yyyy'), '2', '16', '047', '02', '2072', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26346, to_date('17-02-2072', 'dd-mm-yyyy'), '3', '17', '048', '02', '2072', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26347, to_date('18-02-2072', 'dd-mm-yyyy'), '4', '18', '049', '02', '2072', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26348, to_date('19-02-2072', 'dd-mm-yyyy'), '5', '19', '050', '02', '2072', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26349, to_date('20-02-2072', 'dd-mm-yyyy'), '6', '20', '051', '02', '2072', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26350, to_date('21-02-2072', 'dd-mm-yyyy'), '7', '21', '052', '02', '2072', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26351, to_date('22-02-2072', 'dd-mm-yyyy'), '1', '22', '053', '02', '2072', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26352, to_date('23-02-2072', 'dd-mm-yyyy'), '2', '23', '054', '02', '2072', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26353, to_date('24-02-2072', 'dd-mm-yyyy'), '3', '24', '055', '02', '2072', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26354, to_date('25-02-2072', 'dd-mm-yyyy'), '4', '25', '056', '02', '2072', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26355, to_date('26-02-2072', 'dd-mm-yyyy'), '5', '26', '057', '02', '2072', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26356, to_date('27-02-2072', 'dd-mm-yyyy'), '6', '27', '058', '02', '2072', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26357, to_date('28-02-2072', 'dd-mm-yyyy'), '7', '28', '059', '02', '2072', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26358, to_date('29-02-2072', 'dd-mm-yyyy'), '1', '29', '060', '02', '2072', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26359, to_date('01-03-2072', 'dd-mm-yyyy'), '2', '01', '061', '03', '2072', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26360, to_date('02-03-2072', 'dd-mm-yyyy'), '3', '02', '062', '03', '2072', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26361, to_date('03-03-2072', 'dd-mm-yyyy'), '4', '03', '063', '03', '2072', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26362, to_date('04-03-2072', 'dd-mm-yyyy'), '5', '04', '064', '03', '2072', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26363, to_date('05-03-2072', 'dd-mm-yyyy'), '6', '05', '065', '03', '2072', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26364, to_date('06-03-2072', 'dd-mm-yyyy'), '7', '06', '066', '03', '2072', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26365, to_date('07-03-2072', 'dd-mm-yyyy'), '1', '07', '067', '03', '2072', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26366, to_date('08-03-2072', 'dd-mm-yyyy'), '2', '08', '068', '03', '2072', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26367, to_date('09-03-2072', 'dd-mm-yyyy'), '3', '09', '069', '03', '2072', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26368, to_date('10-03-2072', 'dd-mm-yyyy'), '4', '10', '070', '03', '2072', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27959, to_date('18-07-2076', 'dd-mm-yyyy'), '6', '18', '200', '07', '2076', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27960, to_date('19-07-2076', 'dd-mm-yyyy'), '7', '19', '201', '07', '2076', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27961, to_date('20-07-2076', 'dd-mm-yyyy'), '1', '20', '202', '07', '2076', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27962, to_date('21-07-2076', 'dd-mm-yyyy'), '2', '21', '203', '07', '2076', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27963, to_date('22-07-2076', 'dd-mm-yyyy'), '3', '22', '204', '07', '2076', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27964, to_date('23-07-2076', 'dd-mm-yyyy'), '4', '23', '205', '07', '2076', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27965, to_date('24-07-2076', 'dd-mm-yyyy'), '5', '24', '206', '07', '2076', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27966, to_date('25-07-2076', 'dd-mm-yyyy'), '6', '25', '207', '07', '2076', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27967, to_date('26-07-2076', 'dd-mm-yyyy'), '7', '26', '208', '07', '2076', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27968, to_date('27-07-2076', 'dd-mm-yyyy'), '1', '27', '209', '07', '2076', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27969, to_date('28-07-2076', 'dd-mm-yyyy'), '2', '28', '210', '07', '2076', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27970, to_date('29-07-2076', 'dd-mm-yyyy'), '3', '29', '211', '07', '2076', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27971, to_date('30-07-2076', 'dd-mm-yyyy'), '4', '30', '212', '07', '2076', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27972, to_date('31-07-2076', 'dd-mm-yyyy'), '5', '31', '213', '07', '2076', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27973, to_date('01-08-2076', 'dd-mm-yyyy'), '6', '01', '214', '08', '2076', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27974, to_date('02-08-2076', 'dd-mm-yyyy'), '7', '02', '215', '08', '2076', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27975, to_date('03-08-2076', 'dd-mm-yyyy'), '1', '03', '216', '08', '2076', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27976, to_date('04-08-2076', 'dd-mm-yyyy'), '2', '04', '217', '08', '2076', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27977, to_date('05-08-2076', 'dd-mm-yyyy'), '3', '05', '218', '08', '2076', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27978, to_date('06-08-2076', 'dd-mm-yyyy'), '4', '06', '219', '08', '2076', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27979, to_date('07-08-2076', 'dd-mm-yyyy'), '5', '07', '220', '08', '2076', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27980, to_date('08-08-2076', 'dd-mm-yyyy'), '6', '08', '221', '08', '2076', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27981, to_date('09-08-2076', 'dd-mm-yyyy'), '7', '09', '222', '08', '2076', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27982, to_date('10-08-2076', 'dd-mm-yyyy'), '1', '10', '223', '08', '2076', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27983, to_date('11-08-2076', 'dd-mm-yyyy'), '2', '11', '224', '08', '2076', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27984, to_date('12-08-2076', 'dd-mm-yyyy'), '3', '12', '225', '08', '2076', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27985, to_date('13-08-2076', 'dd-mm-yyyy'), '4', '13', '226', '08', '2076', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27986, to_date('14-08-2076', 'dd-mm-yyyy'), '5', '14', '227', '08', '2076', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27987, to_date('15-08-2076', 'dd-mm-yyyy'), '6', '15', '228', '08', '2076', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27988, to_date('16-08-2076', 'dd-mm-yyyy'), '7', '16', '229', '08', '2076', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27989, to_date('17-08-2076', 'dd-mm-yyyy'), '1', '17', '230', '08', '2076', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27990, to_date('18-08-2076', 'dd-mm-yyyy'), '2', '18', '231', '08', '2076', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27991, to_date('19-08-2076', 'dd-mm-yyyy'), '3', '19', '232', '08', '2076', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27992, to_date('20-08-2076', 'dd-mm-yyyy'), '4', '20', '233', '08', '2076', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27993, to_date('21-08-2076', 'dd-mm-yyyy'), '5', '21', '234', '08', '2076', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27994, to_date('22-08-2076', 'dd-mm-yyyy'), '6', '22', '235', '08', '2076', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27995, to_date('23-08-2076', 'dd-mm-yyyy'), '7', '23', '236', '08', '2076', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27996, to_date('24-08-2076', 'dd-mm-yyyy'), '1', '24', '237', '08', '2076', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27997, to_date('25-08-2076', 'dd-mm-yyyy'), '2', '25', '238', '08', '2076', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27998, to_date('26-08-2076', 'dd-mm-yyyy'), '3', '26', '239', '08', '2076', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27999, to_date('27-08-2076', 'dd-mm-yyyy'), '4', '27', '240', '08', '2076', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28000, to_date('28-08-2076', 'dd-mm-yyyy'), '5', '28', '241', '08', '2076', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28001, to_date('29-08-2076', 'dd-mm-yyyy'), '6', '29', '242', '08', '2076', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28002, to_date('30-08-2076', 'dd-mm-yyyy'), '7', '30', '243', '08', '2076', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28003, to_date('31-08-2076', 'dd-mm-yyyy'), '1', '31', '244', '08', '2076', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28004, to_date('01-09-2076', 'dd-mm-yyyy'), '2', '01', '245', '09', '2076', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28005, to_date('02-09-2076', 'dd-mm-yyyy'), '3', '02', '246', '09', '2076', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28006, to_date('03-09-2076', 'dd-mm-yyyy'), '4', '03', '247', '09', '2076', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28007, to_date('04-09-2076', 'dd-mm-yyyy'), '5', '04', '248', '09', '2076', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28008, to_date('05-09-2076', 'dd-mm-yyyy'), '6', '05', '249', '09', '2076', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28009, to_date('06-09-2076', 'dd-mm-yyyy'), '7', '06', '250', '09', '2076', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28010, to_date('07-09-2076', 'dd-mm-yyyy'), '1', '07', '251', '09', '2076', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28011, to_date('08-09-2076', 'dd-mm-yyyy'), '2', '08', '252', '09', '2076', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28012, to_date('09-09-2076', 'dd-mm-yyyy'), '3', '09', '253', '09', '2076', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28013, to_date('10-09-2076', 'dd-mm-yyyy'), '4', '10', '254', '09', '2076', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28014, to_date('11-09-2076', 'dd-mm-yyyy'), '5', '11', '255', '09', '2076', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28015, to_date('12-09-2076', 'dd-mm-yyyy'), '6', '12', '256', '09', '2076', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28016, to_date('13-09-2076', 'dd-mm-yyyy'), '7', '13', '257', '09', '2076', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28017, to_date('14-09-2076', 'dd-mm-yyyy'), '1', '14', '258', '09', '2076', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28018, to_date('15-09-2076', 'dd-mm-yyyy'), '2', '15', '259', '09', '2076', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28019, to_date('16-09-2076', 'dd-mm-yyyy'), '3', '16', '260', '09', '2076', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28020, to_date('17-09-2076', 'dd-mm-yyyy'), '4', '17', '261', '09', '2076', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28021, to_date('18-09-2076', 'dd-mm-yyyy'), '5', '18', '262', '09', '2076', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28022, to_date('19-09-2076', 'dd-mm-yyyy'), '6', '19', '263', '09', '2076', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28023, to_date('20-09-2076', 'dd-mm-yyyy'), '7', '20', '264', '09', '2076', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28024, to_date('21-09-2076', 'dd-mm-yyyy'), '1', '21', '265', '09', '2076', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28025, to_date('22-09-2076', 'dd-mm-yyyy'), '2', '22', '266', '09', '2076', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28026, to_date('23-09-2076', 'dd-mm-yyyy'), '3', '23', '267', '09', '2076', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28027, to_date('24-09-2076', 'dd-mm-yyyy'), '4', '24', '268', '09', '2076', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28028, to_date('25-09-2076', 'dd-mm-yyyy'), '5', '25', '269', '09', '2076', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28029, to_date('26-09-2076', 'dd-mm-yyyy'), '6', '26', '270', '09', '2076', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28030, to_date('27-09-2076', 'dd-mm-yyyy'), '7', '27', '271', '09', '2076', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28031, to_date('28-09-2076', 'dd-mm-yyyy'), '1', '28', '272', '09', '2076', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28032, to_date('29-09-2076', 'dd-mm-yyyy'), '2', '29', '273', '09', '2076', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28033, to_date('30-09-2076', 'dd-mm-yyyy'), '3', '30', '274', '09', '2076', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28034, to_date('01-10-2076', 'dd-mm-yyyy'), '4', '01', '275', '10', '2076', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28035, to_date('02-10-2076', 'dd-mm-yyyy'), '5', '02', '276', '10', '2076', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28036, to_date('03-10-2076', 'dd-mm-yyyy'), '6', '03', '277', '10', '2076', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28037, to_date('04-10-2076', 'dd-mm-yyyy'), '7', '04', '278', '10', '2076', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28038, to_date('05-10-2076', 'dd-mm-yyyy'), '1', '05', '279', '10', '2076', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28039, to_date('06-10-2076', 'dd-mm-yyyy'), '2', '06', '280', '10', '2076', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28040, to_date('07-10-2076', 'dd-mm-yyyy'), '3', '07', '281', '10', '2076', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28041, to_date('08-10-2076', 'dd-mm-yyyy'), '4', '08', '282', '10', '2076', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28042, to_date('09-10-2076', 'dd-mm-yyyy'), '5', '09', '283', '10', '2076', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28043, to_date('10-10-2076', 'dd-mm-yyyy'), '6', '10', '284', '10', '2076', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28044, to_date('11-10-2076', 'dd-mm-yyyy'), '7', '11', '285', '10', '2076', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28045, to_date('12-10-2076', 'dd-mm-yyyy'), '1', '12', '286', '10', '2076', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28046, to_date('13-10-2076', 'dd-mm-yyyy'), '2', '13', '287', '10', '2076', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28047, to_date('14-10-2076', 'dd-mm-yyyy'), '3', '14', '288', '10', '2076', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28048, to_date('15-10-2076', 'dd-mm-yyyy'), '4', '15', '289', '10', '2076', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28049, to_date('16-10-2076', 'dd-mm-yyyy'), '5', '16', '290', '10', '2076', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28050, to_date('17-10-2076', 'dd-mm-yyyy'), '6', '17', '291', '10', '2076', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28051, to_date('18-10-2076', 'dd-mm-yyyy'), '7', '18', '292', '10', '2076', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28052, to_date('19-10-2076', 'dd-mm-yyyy'), '1', '19', '293', '10', '2076', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28053, to_date('20-10-2076', 'dd-mm-yyyy'), '2', '20', '294', '10', '2076', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28054, to_date('21-10-2076', 'dd-mm-yyyy'), '3', '21', '295', '10', '2076', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28055, to_date('22-10-2076', 'dd-mm-yyyy'), '4', '22', '296', '10', '2076', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28056, to_date('23-10-2076', 'dd-mm-yyyy'), '5', '23', '297', '10', '2076', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28057, to_date('24-10-2076', 'dd-mm-yyyy'), '6', '24', '298', '10', '2076', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28058, to_date('25-10-2076', 'dd-mm-yyyy'), '7', '25', '299', '10', '2076', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28059, to_date('26-10-2076', 'dd-mm-yyyy'), '1', '26', '300', '10', '2076', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28060, to_date('27-10-2076', 'dd-mm-yyyy'), '2', '27', '301', '10', '2076', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28061, to_date('28-10-2076', 'dd-mm-yyyy'), '3', '28', '302', '10', '2076', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28062, to_date('29-10-2076', 'dd-mm-yyyy'), '4', '29', '303', '10', '2076', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28063, to_date('30-10-2076', 'dd-mm-yyyy'), '5', '30', '304', '10', '2076', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28064, to_date('31-10-2076', 'dd-mm-yyyy'), '6', '31', '305', '10', '2076', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29549, to_date('24-11-2080', 'dd-mm-yyyy'), '7', '24', '329', '11', '2080', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29550, to_date('25-11-2080', 'dd-mm-yyyy'), '1', '25', '330', '11', '2080', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29551, to_date('26-11-2080', 'dd-mm-yyyy'), '2', '26', '331', '11', '2080', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29552, to_date('27-11-2080', 'dd-mm-yyyy'), '3', '27', '332', '11', '2080', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29553, to_date('28-11-2080', 'dd-mm-yyyy'), '4', '28', '333', '11', '2080', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29554, to_date('29-11-2080', 'dd-mm-yyyy'), '5', '29', '334', '11', '2080', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29555, to_date('30-11-2080', 'dd-mm-yyyy'), '6', '30', '335', '11', '2080', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29556, to_date('01-12-2080', 'dd-mm-yyyy'), '7', '01', '336', '12', '2080', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29557, to_date('02-12-2080', 'dd-mm-yyyy'), '1', '02', '337', '12', '2080', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29558, to_date('03-12-2080', 'dd-mm-yyyy'), '2', '03', '338', '12', '2080', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29559, to_date('04-12-2080', 'dd-mm-yyyy'), '3', '04', '339', '12', '2080', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29560, to_date('05-12-2080', 'dd-mm-yyyy'), '4', '05', '340', '12', '2080', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29561, to_date('06-12-2080', 'dd-mm-yyyy'), '5', '06', '341', '12', '2080', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29562, to_date('07-12-2080', 'dd-mm-yyyy'), '6', '07', '342', '12', '2080', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29563, to_date('08-12-2080', 'dd-mm-yyyy'), '7', '08', '343', '12', '2080', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29564, to_date('09-12-2080', 'dd-mm-yyyy'), '1', '09', '344', '12', '2080', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29565, to_date('10-12-2080', 'dd-mm-yyyy'), '2', '10', '345', '12', '2080', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29566, to_date('11-12-2080', 'dd-mm-yyyy'), '3', '11', '346', '12', '2080', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29567, to_date('12-12-2080', 'dd-mm-yyyy'), '4', '12', '347', '12', '2080', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29568, to_date('13-12-2080', 'dd-mm-yyyy'), '5', '13', '348', '12', '2080', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29569, to_date('14-12-2080', 'dd-mm-yyyy'), '6', '14', '349', '12', '2080', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29570, to_date('15-12-2080', 'dd-mm-yyyy'), '7', '15', '350', '12', '2080', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29571, to_date('16-12-2080', 'dd-mm-yyyy'), '1', '16', '351', '12', '2080', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29572, to_date('17-12-2080', 'dd-mm-yyyy'), '2', '17', '352', '12', '2080', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29573, to_date('18-12-2080', 'dd-mm-yyyy'), '3', '18', '353', '12', '2080', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29574, to_date('19-12-2080', 'dd-mm-yyyy'), '4', '19', '354', '12', '2080', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29575, to_date('20-12-2080', 'dd-mm-yyyy'), '5', '20', '355', '12', '2080', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29576, to_date('21-12-2080', 'dd-mm-yyyy'), '6', '21', '356', '12', '2080', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29577, to_date('22-12-2080', 'dd-mm-yyyy'), '7', '22', '357', '12', '2080', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29578, to_date('23-12-2080', 'dd-mm-yyyy'), '1', '23', '358', '12', '2080', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29579, to_date('24-12-2080', 'dd-mm-yyyy'), '2', '24', '359', '12', '2080', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29580, to_date('25-12-2080', 'dd-mm-yyyy'), '3', '25', '360', '12', '2080', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29581, to_date('26-12-2080', 'dd-mm-yyyy'), '4', '26', '361', '12', '2080', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29582, to_date('27-12-2080', 'dd-mm-yyyy'), '5', '27', '362', '12', '2080', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29583, to_date('28-12-2080', 'dd-mm-yyyy'), '6', '28', '363', '12', '2080', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29584, to_date('29-12-2080', 'dd-mm-yyyy'), '7', '29', '364', '12', '2080', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29585, to_date('30-12-2080', 'dd-mm-yyyy'), '1', '30', '365', '12', '2080', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29586, to_date('31-12-2080', 'dd-mm-yyyy'), '2', '31', '366', '12', '2080', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29587, to_date('01-01-2081', 'dd-mm-yyyy'), '3', '01', '001', '01', '2081', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29588, to_date('02-01-2081', 'dd-mm-yyyy'), '4', '02', '002', '01', '2081', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29589, to_date('03-01-2081', 'dd-mm-yyyy'), '5', '03', '003', '01', '2081', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29590, to_date('04-01-2081', 'dd-mm-yyyy'), '6', '04', '004', '01', '2081', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29591, to_date('05-01-2081', 'dd-mm-yyyy'), '7', '05', '005', '01', '2081', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29592, to_date('06-01-2081', 'dd-mm-yyyy'), '1', '06', '006', '01', '2081', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29593, to_date('07-01-2081', 'dd-mm-yyyy'), '2', '07', '007', '01', '2081', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29594, to_date('08-01-2081', 'dd-mm-yyyy'), '3', '08', '008', '01', '2081', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29595, to_date('09-01-2081', 'dd-mm-yyyy'), '4', '09', '009', '01', '2081', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29596, to_date('10-01-2081', 'dd-mm-yyyy'), '5', '10', '010', '01', '2081', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29597, to_date('11-01-2081', 'dd-mm-yyyy'), '6', '11', '011', '01', '2081', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29598, to_date('12-01-2081', 'dd-mm-yyyy'), '7', '12', '012', '01', '2081', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29599, to_date('13-01-2081', 'dd-mm-yyyy'), '1', '13', '013', '01', '2081', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29600, to_date('14-01-2081', 'dd-mm-yyyy'), '2', '14', '014', '01', '2081', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29601, to_date('15-01-2081', 'dd-mm-yyyy'), '3', '15', '015', '01', '2081', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29602, to_date('16-01-2081', 'dd-mm-yyyy'), '4', '16', '016', '01', '2081', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29603, to_date('17-01-2081', 'dd-mm-yyyy'), '5', '17', '017', '01', '2081', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29604, to_date('18-01-2081', 'dd-mm-yyyy'), '6', '18', '018', '01', '2081', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29605, to_date('19-01-2081', 'dd-mm-yyyy'), '7', '19', '019', '01', '2081', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29606, to_date('20-01-2081', 'dd-mm-yyyy'), '1', '20', '020', '01', '2081', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29607, to_date('21-01-2081', 'dd-mm-yyyy'), '2', '21', '021', '01', '2081', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29608, to_date('22-01-2081', 'dd-mm-yyyy'), '3', '22', '022', '01', '2081', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29609, to_date('23-01-2081', 'dd-mm-yyyy'), '4', '23', '023', '01', '2081', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29610, to_date('24-01-2081', 'dd-mm-yyyy'), '5', '24', '024', '01', '2081', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29611, to_date('25-01-2081', 'dd-mm-yyyy'), '6', '25', '025', '01', '2081', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29612, to_date('26-01-2081', 'dd-mm-yyyy'), '7', '26', '026', '01', '2081', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29613, to_date('27-01-2081', 'dd-mm-yyyy'), '1', '27', '027', '01', '2081', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29614, to_date('28-01-2081', 'dd-mm-yyyy'), '2', '28', '028', '01', '2081', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29615, to_date('29-01-2081', 'dd-mm-yyyy'), '3', '29', '029', '01', '2081', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29616, to_date('30-01-2081', 'dd-mm-yyyy'), '4', '30', '030', '01', '2081', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29617, to_date('31-01-2081', 'dd-mm-yyyy'), '5', '31', '031', '01', '2081', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29618, to_date('01-02-2081', 'dd-mm-yyyy'), '6', '01', '032', '02', '2081', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29619, to_date('02-02-2081', 'dd-mm-yyyy'), '7', '02', '033', '02', '2081', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29620, to_date('03-02-2081', 'dd-mm-yyyy'), '1', '03', '034', '02', '2081', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29621, to_date('04-02-2081', 'dd-mm-yyyy'), '2', '04', '035', '02', '2081', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29622, to_date('05-02-2081', 'dd-mm-yyyy'), '3', '05', '036', '02', '2081', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29623, to_date('06-02-2081', 'dd-mm-yyyy'), '4', '06', '037', '02', '2081', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29624, to_date('07-02-2081', 'dd-mm-yyyy'), '5', '07', '038', '02', '2081', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29625, to_date('08-02-2081', 'dd-mm-yyyy'), '6', '08', '039', '02', '2081', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29626, to_date('09-02-2081', 'dd-mm-yyyy'), '7', '09', '040', '02', '2081', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29627, to_date('10-02-2081', 'dd-mm-yyyy'), '1', '10', '041', '02', '2081', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29628, to_date('11-02-2081', 'dd-mm-yyyy'), '2', '11', '042', '02', '2081', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29629, to_date('12-02-2081', 'dd-mm-yyyy'), '3', '12', '043', '02', '2081', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29630, to_date('13-02-2081', 'dd-mm-yyyy'), '4', '13', '044', '02', '2081', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29631, to_date('14-02-2081', 'dd-mm-yyyy'), '5', '14', '045', '02', '2081', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29632, to_date('15-02-2081', 'dd-mm-yyyy'), '6', '15', '046', '02', '2081', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29633, to_date('16-02-2081', 'dd-mm-yyyy'), '7', '16', '047', '02', '2081', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29634, to_date('17-02-2081', 'dd-mm-yyyy'), '1', '17', '048', '02', '2081', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29635, to_date('18-02-2081', 'dd-mm-yyyy'), '2', '18', '049', '02', '2081', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29636, to_date('19-02-2081', 'dd-mm-yyyy'), '3', '19', '050', '02', '2081', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29637, to_date('20-02-2081', 'dd-mm-yyyy'), '4', '20', '051', '02', '2081', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29638, to_date('21-02-2081', 'dd-mm-yyyy'), '5', '21', '052', '02', '2081', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29639, to_date('22-02-2081', 'dd-mm-yyyy'), '6', '22', '053', '02', '2081', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29640, to_date('23-02-2081', 'dd-mm-yyyy'), '7', '23', '054', '02', '2081', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29641, to_date('24-02-2081', 'dd-mm-yyyy'), '1', '24', '055', '02', '2081', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29642, to_date('25-02-2081', 'dd-mm-yyyy'), '2', '25', '056', '02', '2081', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29643, to_date('26-02-2081', 'dd-mm-yyyy'), '3', '26', '057', '02', '2081', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29644, to_date('27-02-2081', 'dd-mm-yyyy'), '4', '27', '058', '02', '2081', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29645, to_date('28-02-2081', 'dd-mm-yyyy'), '5', '28', '059', '02', '2081', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29646, to_date('01-03-2081', 'dd-mm-yyyy'), '6', '01', '060', '03', '2081', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29647, to_date('02-03-2081', 'dd-mm-yyyy'), '7', '02', '061', '03', '2081', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29648, to_date('03-03-2081', 'dd-mm-yyyy'), '1', '03', '062', '03', '2081', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29649, to_date('04-03-2081', 'dd-mm-yyyy'), '2', '04', '063', '03', '2081', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29650, to_date('05-03-2081', 'dd-mm-yyyy'), '3', '05', '064', '03', '2081', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29651, to_date('06-03-2081', 'dd-mm-yyyy'), '4', '06', '065', '03', '2081', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29652, to_date('07-03-2081', 'dd-mm-yyyy'), '5', '07', '066', '03', '2081', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29653, to_date('08-03-2081', 'dd-mm-yyyy'), '6', '08', '067', '03', '2081', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29654, to_date('09-03-2081', 'dd-mm-yyyy'), '7', '09', '068', '03', '2081', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31139, to_date('02-04-2085', 'dd-mm-yyyy'), '1', '02', '092', '04', '2085', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31140, to_date('03-04-2085', 'dd-mm-yyyy'), '2', '03', '093', '04', '2085', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31141, to_date('04-04-2085', 'dd-mm-yyyy'), '3', '04', '094', '04', '2085', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31142, to_date('05-04-2085', 'dd-mm-yyyy'), '4', '05', '095', '04', '2085', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31143, to_date('06-04-2085', 'dd-mm-yyyy'), '5', '06', '096', '04', '2085', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31144, to_date('07-04-2085', 'dd-mm-yyyy'), '6', '07', '097', '04', '2085', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31145, to_date('08-04-2085', 'dd-mm-yyyy'), '7', '08', '098', '04', '2085', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31146, to_date('09-04-2085', 'dd-mm-yyyy'), '1', '09', '099', '04', '2085', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31147, to_date('10-04-2085', 'dd-mm-yyyy'), '2', '10', '100', '04', '2085', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31148, to_date('11-04-2085', 'dd-mm-yyyy'), '3', '11', '101', '04', '2085', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31149, to_date('12-04-2085', 'dd-mm-yyyy'), '4', '12', '102', '04', '2085', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31150, to_date('13-04-2085', 'dd-mm-yyyy'), '5', '13', '103', '04', '2085', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31151, to_date('14-04-2085', 'dd-mm-yyyy'), '6', '14', '104', '04', '2085', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31152, to_date('15-04-2085', 'dd-mm-yyyy'), '7', '15', '105', '04', '2085', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31153, to_date('16-04-2085', 'dd-mm-yyyy'), '1', '16', '106', '04', '2085', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31154, to_date('17-04-2085', 'dd-mm-yyyy'), '2', '17', '107', '04', '2085', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31155, to_date('18-04-2085', 'dd-mm-yyyy'), '3', '18', '108', '04', '2085', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31156, to_date('19-04-2085', 'dd-mm-yyyy'), '4', '19', '109', '04', '2085', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31157, to_date('20-04-2085', 'dd-mm-yyyy'), '5', '20', '110', '04', '2085', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31158, to_date('21-04-2085', 'dd-mm-yyyy'), '6', '21', '111', '04', '2085', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31159, to_date('22-04-2085', 'dd-mm-yyyy'), '7', '22', '112', '04', '2085', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31160, to_date('23-04-2085', 'dd-mm-yyyy'), '1', '23', '113', '04', '2085', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31161, to_date('24-04-2085', 'dd-mm-yyyy'), '2', '24', '114', '04', '2085', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31162, to_date('25-04-2085', 'dd-mm-yyyy'), '3', '25', '115', '04', '2085', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31163, to_date('26-04-2085', 'dd-mm-yyyy'), '4', '26', '116', '04', '2085', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31164, to_date('27-04-2085', 'dd-mm-yyyy'), '5', '27', '117', '04', '2085', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31165, to_date('28-04-2085', 'dd-mm-yyyy'), '6', '28', '118', '04', '2085', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31166, to_date('29-04-2085', 'dd-mm-yyyy'), '7', '29', '119', '04', '2085', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31167, to_date('30-04-2085', 'dd-mm-yyyy'), '1', '30', '120', '04', '2085', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31168, to_date('01-05-2085', 'dd-mm-yyyy'), '2', '01', '121', '05', '2085', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31169, to_date('02-05-2085', 'dd-mm-yyyy'), '3', '02', '122', '05', '2085', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31170, to_date('03-05-2085', 'dd-mm-yyyy'), '4', '03', '123', '05', '2085', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31171, to_date('04-05-2085', 'dd-mm-yyyy'), '5', '04', '124', '05', '2085', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31172, to_date('05-05-2085', 'dd-mm-yyyy'), '6', '05', '125', '05', '2085', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31173, to_date('06-05-2085', 'dd-mm-yyyy'), '7', '06', '126', '05', '2085', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31174, to_date('07-05-2085', 'dd-mm-yyyy'), '1', '07', '127', '05', '2085', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31175, to_date('08-05-2085', 'dd-mm-yyyy'), '2', '08', '128', '05', '2085', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31176, to_date('09-05-2085', 'dd-mm-yyyy'), '3', '09', '129', '05', '2085', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31177, to_date('10-05-2085', 'dd-mm-yyyy'), '4', '10', '130', '05', '2085', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31178, to_date('11-05-2085', 'dd-mm-yyyy'), '5', '11', '131', '05', '2085', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31179, to_date('12-05-2085', 'dd-mm-yyyy'), '6', '12', '132', '05', '2085', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31180, to_date('13-05-2085', 'dd-mm-yyyy'), '7', '13', '133', '05', '2085', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31181, to_date('14-05-2085', 'dd-mm-yyyy'), '1', '14', '134', '05', '2085', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31182, to_date('15-05-2085', 'dd-mm-yyyy'), '2', '15', '135', '05', '2085', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31183, to_date('16-05-2085', 'dd-mm-yyyy'), '3', '16', '136', '05', '2085', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31184, to_date('17-05-2085', 'dd-mm-yyyy'), '4', '17', '137', '05', '2085', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31185, to_date('18-05-2085', 'dd-mm-yyyy'), '5', '18', '138', '05', '2085', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31186, to_date('19-05-2085', 'dd-mm-yyyy'), '6', '19', '139', '05', '2085', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31187, to_date('20-05-2085', 'dd-mm-yyyy'), '7', '20', '140', '05', '2085', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31188, to_date('21-05-2085', 'dd-mm-yyyy'), '1', '21', '141', '05', '2085', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31189, to_date('22-05-2085', 'dd-mm-yyyy'), '2', '22', '142', '05', '2085', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31190, to_date('23-05-2085', 'dd-mm-yyyy'), '3', '23', '143', '05', '2085', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31191, to_date('24-05-2085', 'dd-mm-yyyy'), '4', '24', '144', '05', '2085', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31192, to_date('25-05-2085', 'dd-mm-yyyy'), '5', '25', '145', '05', '2085', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31193, to_date('26-05-2085', 'dd-mm-yyyy'), '6', '26', '146', '05', '2085', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31194, to_date('27-05-2085', 'dd-mm-yyyy'), '7', '27', '147', '05', '2085', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31195, to_date('28-05-2085', 'dd-mm-yyyy'), '1', '28', '148', '05', '2085', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31196, to_date('29-05-2085', 'dd-mm-yyyy'), '2', '29', '149', '05', '2085', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31197, to_date('30-05-2085', 'dd-mm-yyyy'), '3', '30', '150', '05', '2085', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31198, to_date('31-05-2085', 'dd-mm-yyyy'), '4', '31', '151', '05', '2085', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31199, to_date('01-06-2085', 'dd-mm-yyyy'), '5', '01', '152', '06', '2085', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31200, to_date('02-06-2085', 'dd-mm-yyyy'), '6', '02', '153', '06', '2085', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31201, to_date('03-06-2085', 'dd-mm-yyyy'), '7', '03', '154', '06', '2085', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31202, to_date('04-06-2085', 'dd-mm-yyyy'), '1', '04', '155', '06', '2085', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31203, to_date('05-06-2085', 'dd-mm-yyyy'), '2', '05', '156', '06', '2085', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31204, to_date('06-06-2085', 'dd-mm-yyyy'), '3', '06', '157', '06', '2085', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31205, to_date('07-06-2085', 'dd-mm-yyyy'), '4', '07', '158', '06', '2085', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31206, to_date('08-06-2085', 'dd-mm-yyyy'), '5', '08', '159', '06', '2085', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31207, to_date('09-06-2085', 'dd-mm-yyyy'), '6', '09', '160', '06', '2085', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31208, to_date('10-06-2085', 'dd-mm-yyyy'), '7', '10', '161', '06', '2085', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31209, to_date('11-06-2085', 'dd-mm-yyyy'), '1', '11', '162', '06', '2085', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31210, to_date('12-06-2085', 'dd-mm-yyyy'), '2', '12', '163', '06', '2085', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31211, to_date('13-06-2085', 'dd-mm-yyyy'), '3', '13', '164', '06', '2085', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31212, to_date('14-06-2085', 'dd-mm-yyyy'), '4', '14', '165', '06', '2085', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31213, to_date('15-06-2085', 'dd-mm-yyyy'), '5', '15', '166', '06', '2085', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31214, to_date('16-06-2085', 'dd-mm-yyyy'), '6', '16', '167', '06', '2085', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31215, to_date('17-06-2085', 'dd-mm-yyyy'), '7', '17', '168', '06', '2085', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31216, to_date('18-06-2085', 'dd-mm-yyyy'), '1', '18', '169', '06', '2085', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31217, to_date('19-06-2085', 'dd-mm-yyyy'), '2', '19', '170', '06', '2085', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31218, to_date('20-06-2085', 'dd-mm-yyyy'), '3', '20', '171', '06', '2085', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31219, to_date('21-06-2085', 'dd-mm-yyyy'), '4', '21', '172', '06', '2085', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31220, to_date('22-06-2085', 'dd-mm-yyyy'), '5', '22', '173', '06', '2085', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31221, to_date('23-06-2085', 'dd-mm-yyyy'), '6', '23', '174', '06', '2085', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31222, to_date('24-06-2085', 'dd-mm-yyyy'), '7', '24', '175', '06', '2085', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31223, to_date('25-06-2085', 'dd-mm-yyyy'), '1', '25', '176', '06', '2085', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31224, to_date('26-06-2085', 'dd-mm-yyyy'), '2', '26', '177', '06', '2085', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31225, to_date('27-06-2085', 'dd-mm-yyyy'), '3', '27', '178', '06', '2085', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31226, to_date('28-06-2085', 'dd-mm-yyyy'), '4', '28', '179', '06', '2085', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31227, to_date('29-06-2085', 'dd-mm-yyyy'), '5', '29', '180', '06', '2085', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31228, to_date('30-06-2085', 'dd-mm-yyyy'), '6', '30', '181', '06', '2085', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31229, to_date('01-07-2085', 'dd-mm-yyyy'), '7', '01', '182', '07', '2085', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31230, to_date('02-07-2085', 'dd-mm-yyyy'), '1', '02', '183', '07', '2085', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31231, to_date('03-07-2085', 'dd-mm-yyyy'), '2', '03', '184', '07', '2085', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31232, to_date('04-07-2085', 'dd-mm-yyyy'), '3', '04', '185', '07', '2085', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31233, to_date('05-07-2085', 'dd-mm-yyyy'), '4', '05', '186', '07', '2085', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31234, to_date('06-07-2085', 'dd-mm-yyyy'), '5', '06', '187', '07', '2085', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31235, to_date('07-07-2085', 'dd-mm-yyyy'), '6', '07', '188', '07', '2085', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31236, to_date('08-07-2085', 'dd-mm-yyyy'), '7', '08', '189', '07', '2085', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31237, to_date('09-07-2085', 'dd-mm-yyyy'), '1', '09', '190', '07', '2085', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31238, to_date('10-07-2085', 'dd-mm-yyyy'), '2', '10', '191', '07', '2085', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31239, to_date('11-07-2085', 'dd-mm-yyyy'), '3', '11', '192', '07', '2085', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31240, to_date('12-07-2085', 'dd-mm-yyyy'), '4', '12', '193', '07', '2085', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31241, to_date('13-07-2085', 'dd-mm-yyyy'), '5', '13', '194', '07', '2085', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31242, to_date('14-07-2085', 'dd-mm-yyyy'), '6', '14', '195', '07', '2085', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31243, to_date('15-07-2085', 'dd-mm-yyyy'), '7', '15', '196', '07', '2085', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31244, to_date('16-07-2085', 'dd-mm-yyyy'), '1', '16', '197', '07', '2085', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26369, to_date('11-03-2072', 'dd-mm-yyyy'), '5', '11', '071', '03', '2072', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26370, to_date('12-03-2072', 'dd-mm-yyyy'), '6', '12', '072', '03', '2072', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26371, to_date('13-03-2072', 'dd-mm-yyyy'), '7', '13', '073', '03', '2072', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26372, to_date('14-03-2072', 'dd-mm-yyyy'), '1', '14', '074', '03', '2072', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26373, to_date('15-03-2072', 'dd-mm-yyyy'), '2', '15', '075', '03', '2072', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26374, to_date('16-03-2072', 'dd-mm-yyyy'), '3', '16', '076', '03', '2072', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26375, to_date('17-03-2072', 'dd-mm-yyyy'), '4', '17', '077', '03', '2072', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26376, to_date('18-03-2072', 'dd-mm-yyyy'), '5', '18', '078', '03', '2072', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26377, to_date('19-03-2072', 'dd-mm-yyyy'), '6', '19', '079', '03', '2072', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26378, to_date('20-03-2072', 'dd-mm-yyyy'), '7', '20', '080', '03', '2072', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26379, to_date('21-03-2072', 'dd-mm-yyyy'), '1', '21', '081', '03', '2072', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26380, to_date('22-03-2072', 'dd-mm-yyyy'), '2', '22', '082', '03', '2072', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26381, to_date('23-03-2072', 'dd-mm-yyyy'), '3', '23', '083', '03', '2072', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26382, to_date('24-03-2072', 'dd-mm-yyyy'), '4', '24', '084', '03', '2072', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26383, to_date('25-03-2072', 'dd-mm-yyyy'), '5', '25', '085', '03', '2072', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26384, to_date('26-03-2072', 'dd-mm-yyyy'), '6', '26', '086', '03', '2072', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26385, to_date('27-03-2072', 'dd-mm-yyyy'), '7', '27', '087', '03', '2072', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26386, to_date('28-03-2072', 'dd-mm-yyyy'), '1', '28', '088', '03', '2072', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26387, to_date('29-03-2072', 'dd-mm-yyyy'), '2', '29', '089', '03', '2072', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26388, to_date('30-03-2072', 'dd-mm-yyyy'), '3', '30', '090', '03', '2072', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26389, to_date('31-03-2072', 'dd-mm-yyyy'), '4', '31', '091', '03', '2072', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26390, to_date('01-04-2072', 'dd-mm-yyyy'), '5', '01', '092', '04', '2072', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26391, to_date('02-04-2072', 'dd-mm-yyyy'), '6', '02', '093', '04', '2072', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26392, to_date('03-04-2072', 'dd-mm-yyyy'), '7', '03', '094', '04', '2072', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26393, to_date('04-04-2072', 'dd-mm-yyyy'), '1', '04', '095', '04', '2072', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26394, to_date('05-04-2072', 'dd-mm-yyyy'), '2', '05', '096', '04', '2072', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26395, to_date('06-04-2072', 'dd-mm-yyyy'), '3', '06', '097', '04', '2072', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26396, to_date('07-04-2072', 'dd-mm-yyyy'), '4', '07', '098', '04', '2072', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26397, to_date('08-04-2072', 'dd-mm-yyyy'), '5', '08', '099', '04', '2072', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26398, to_date('09-04-2072', 'dd-mm-yyyy'), '6', '09', '100', '04', '2072', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26399, to_date('10-04-2072', 'dd-mm-yyyy'), '7', '10', '101', '04', '2072', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26400, to_date('11-04-2072', 'dd-mm-yyyy'), '1', '11', '102', '04', '2072', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26401, to_date('12-04-2072', 'dd-mm-yyyy'), '2', '12', '103', '04', '2072', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26402, to_date('13-04-2072', 'dd-mm-yyyy'), '3', '13', '104', '04', '2072', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26403, to_date('14-04-2072', 'dd-mm-yyyy'), '4', '14', '105', '04', '2072', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26404, to_date('15-04-2072', 'dd-mm-yyyy'), '5', '15', '106', '04', '2072', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26405, to_date('16-04-2072', 'dd-mm-yyyy'), '6', '16', '107', '04', '2072', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26406, to_date('17-04-2072', 'dd-mm-yyyy'), '7', '17', '108', '04', '2072', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26407, to_date('18-04-2072', 'dd-mm-yyyy'), '1', '18', '109', '04', '2072', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26408, to_date('19-04-2072', 'dd-mm-yyyy'), '2', '19', '110', '04', '2072', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26409, to_date('20-04-2072', 'dd-mm-yyyy'), '3', '20', '111', '04', '2072', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26410, to_date('21-04-2072', 'dd-mm-yyyy'), '4', '21', '112', '04', '2072', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26411, to_date('22-04-2072', 'dd-mm-yyyy'), '5', '22', '113', '04', '2072', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26412, to_date('23-04-2072', 'dd-mm-yyyy'), '6', '23', '114', '04', '2072', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26413, to_date('24-04-2072', 'dd-mm-yyyy'), '7', '24', '115', '04', '2072', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26414, to_date('25-04-2072', 'dd-mm-yyyy'), '1', '25', '116', '04', '2072', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26415, to_date('26-04-2072', 'dd-mm-yyyy'), '2', '26', '117', '04', '2072', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26416, to_date('27-04-2072', 'dd-mm-yyyy'), '3', '27', '118', '04', '2072', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26417, to_date('28-04-2072', 'dd-mm-yyyy'), '4', '28', '119', '04', '2072', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26418, to_date('29-04-2072', 'dd-mm-yyyy'), '5', '29', '120', '04', '2072', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26419, to_date('30-04-2072', 'dd-mm-yyyy'), '6', '30', '121', '04', '2072', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26420, to_date('01-05-2072', 'dd-mm-yyyy'), '7', '01', '122', '05', '2072', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26421, to_date('02-05-2072', 'dd-mm-yyyy'), '1', '02', '123', '05', '2072', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26422, to_date('03-05-2072', 'dd-mm-yyyy'), '2', '03', '124', '05', '2072', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26423, to_date('04-05-2072', 'dd-mm-yyyy'), '3', '04', '125', '05', '2072', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26424, to_date('05-05-2072', 'dd-mm-yyyy'), '4', '05', '126', '05', '2072', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26425, to_date('06-05-2072', 'dd-mm-yyyy'), '5', '06', '127', '05', '2072', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26426, to_date('07-05-2072', 'dd-mm-yyyy'), '6', '07', '128', '05', '2072', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26427, to_date('08-05-2072', 'dd-mm-yyyy'), '7', '08', '129', '05', '2072', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26428, to_date('09-05-2072', 'dd-mm-yyyy'), '1', '09', '130', '05', '2072', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26429, to_date('10-05-2072', 'dd-mm-yyyy'), '2', '10', '131', '05', '2072', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26430, to_date('11-05-2072', 'dd-mm-yyyy'), '3', '11', '132', '05', '2072', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26431, to_date('12-05-2072', 'dd-mm-yyyy'), '4', '12', '133', '05', '2072', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26432, to_date('13-05-2072', 'dd-mm-yyyy'), '5', '13', '134', '05', '2072', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26433, to_date('14-05-2072', 'dd-mm-yyyy'), '6', '14', '135', '05', '2072', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26434, to_date('15-05-2072', 'dd-mm-yyyy'), '7', '15', '136', '05', '2072', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26435, to_date('16-05-2072', 'dd-mm-yyyy'), '1', '16', '137', '05', '2072', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26436, to_date('17-05-2072', 'dd-mm-yyyy'), '2', '17', '138', '05', '2072', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26437, to_date('18-05-2072', 'dd-mm-yyyy'), '3', '18', '139', '05', '2072', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26438, to_date('19-05-2072', 'dd-mm-yyyy'), '4', '19', '140', '05', '2072', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26439, to_date('20-05-2072', 'dd-mm-yyyy'), '5', '20', '141', '05', '2072', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26440, to_date('21-05-2072', 'dd-mm-yyyy'), '6', '21', '142', '05', '2072', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26441, to_date('22-05-2072', 'dd-mm-yyyy'), '7', '22', '143', '05', '2072', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26442, to_date('23-05-2072', 'dd-mm-yyyy'), '1', '23', '144', '05', '2072', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26443, to_date('24-05-2072', 'dd-mm-yyyy'), '2', '24', '145', '05', '2072', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26444, to_date('25-05-2072', 'dd-mm-yyyy'), '3', '25', '146', '05', '2072', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26445, to_date('26-05-2072', 'dd-mm-yyyy'), '4', '26', '147', '05', '2072', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26446, to_date('27-05-2072', 'dd-mm-yyyy'), '5', '27', '148', '05', '2072', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26447, to_date('28-05-2072', 'dd-mm-yyyy'), '6', '28', '149', '05', '2072', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26448, to_date('29-05-2072', 'dd-mm-yyyy'), '7', '29', '150', '05', '2072', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26449, to_date('30-05-2072', 'dd-mm-yyyy'), '1', '30', '151', '05', '2072', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26450, to_date('31-05-2072', 'dd-mm-yyyy'), '2', '31', '152', '05', '2072', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26451, to_date('01-06-2072', 'dd-mm-yyyy'), '3', '01', '153', '06', '2072', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26452, to_date('02-06-2072', 'dd-mm-yyyy'), '4', '02', '154', '06', '2072', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26453, to_date('03-06-2072', 'dd-mm-yyyy'), '5', '03', '155', '06', '2072', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26454, to_date('04-06-2072', 'dd-mm-yyyy'), '6', '04', '156', '06', '2072', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26455, to_date('05-06-2072', 'dd-mm-yyyy'), '7', '05', '157', '06', '2072', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26456, to_date('06-06-2072', 'dd-mm-yyyy'), '1', '06', '158', '06', '2072', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26457, to_date('07-06-2072', 'dd-mm-yyyy'), '2', '07', '159', '06', '2072', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26458, to_date('08-06-2072', 'dd-mm-yyyy'), '3', '08', '160', '06', '2072', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26459, to_date('09-06-2072', 'dd-mm-yyyy'), '4', '09', '161', '06', '2072', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26460, to_date('10-06-2072', 'dd-mm-yyyy'), '5', '10', '162', '06', '2072', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26461, to_date('11-06-2072', 'dd-mm-yyyy'), '6', '11', '163', '06', '2072', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26462, to_date('12-06-2072', 'dd-mm-yyyy'), '7', '12', '164', '06', '2072', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26463, to_date('13-06-2072', 'dd-mm-yyyy'), '1', '13', '165', '06', '2072', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26464, to_date('14-06-2072', 'dd-mm-yyyy'), '2', '14', '166', '06', '2072', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26465, to_date('15-06-2072', 'dd-mm-yyyy'), '3', '15', '167', '06', '2072', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26466, to_date('16-06-2072', 'dd-mm-yyyy'), '4', '16', '168', '06', '2072', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26467, to_date('17-06-2072', 'dd-mm-yyyy'), '5', '17', '169', '06', '2072', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26468, to_date('18-06-2072', 'dd-mm-yyyy'), '6', '18', '170', '06', '2072', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26469, to_date('19-06-2072', 'dd-mm-yyyy'), '7', '19', '171', '06', '2072', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26470, to_date('20-06-2072', 'dd-mm-yyyy'), '1', '20', '172', '06', '2072', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26471, to_date('21-06-2072', 'dd-mm-yyyy'), '2', '21', '173', '06', '2072', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26472, to_date('22-06-2072', 'dd-mm-yyyy'), '3', '22', '174', '06', '2072', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26473, to_date('23-06-2072', 'dd-mm-yyyy'), '4', '23', '175', '06', '2072', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26474, to_date('24-06-2072', 'dd-mm-yyyy'), '5', '24', '176', '06', '2072', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28065, to_date('01-11-2076', 'dd-mm-yyyy'), '7', '01', '306', '11', '2076', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28066, to_date('02-11-2076', 'dd-mm-yyyy'), '1', '02', '307', '11', '2076', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28067, to_date('03-11-2076', 'dd-mm-yyyy'), '2', '03', '308', '11', '2076', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28068, to_date('04-11-2076', 'dd-mm-yyyy'), '3', '04', '309', '11', '2076', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28069, to_date('05-11-2076', 'dd-mm-yyyy'), '4', '05', '310', '11', '2076', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28070, to_date('06-11-2076', 'dd-mm-yyyy'), '5', '06', '311', '11', '2076', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28071, to_date('07-11-2076', 'dd-mm-yyyy'), '6', '07', '312', '11', '2076', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28072, to_date('08-11-2076', 'dd-mm-yyyy'), '7', '08', '313', '11', '2076', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28073, to_date('09-11-2076', 'dd-mm-yyyy'), '1', '09', '314', '11', '2076', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28074, to_date('10-11-2076', 'dd-mm-yyyy'), '2', '10', '315', '11', '2076', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28075, to_date('11-11-2076', 'dd-mm-yyyy'), '3', '11', '316', '11', '2076', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28076, to_date('12-11-2076', 'dd-mm-yyyy'), '4', '12', '317', '11', '2076', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28077, to_date('13-11-2076', 'dd-mm-yyyy'), '5', '13', '318', '11', '2076', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28078, to_date('14-11-2076', 'dd-mm-yyyy'), '6', '14', '319', '11', '2076', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28079, to_date('15-11-2076', 'dd-mm-yyyy'), '7', '15', '320', '11', '2076', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28080, to_date('16-11-2076', 'dd-mm-yyyy'), '1', '16', '321', '11', '2076', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28081, to_date('17-11-2076', 'dd-mm-yyyy'), '2', '17', '322', '11', '2076', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28082, to_date('18-11-2076', 'dd-mm-yyyy'), '3', '18', '323', '11', '2076', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28083, to_date('19-11-2076', 'dd-mm-yyyy'), '4', '19', '324', '11', '2076', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28084, to_date('20-11-2076', 'dd-mm-yyyy'), '5', '20', '325', '11', '2076', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28085, to_date('21-11-2076', 'dd-mm-yyyy'), '6', '21', '326', '11', '2076', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28086, to_date('22-11-2076', 'dd-mm-yyyy'), '7', '22', '327', '11', '2076', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28087, to_date('23-11-2076', 'dd-mm-yyyy'), '1', '23', '328', '11', '2076', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28088, to_date('24-11-2076', 'dd-mm-yyyy'), '2', '24', '329', '11', '2076', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28089, to_date('25-11-2076', 'dd-mm-yyyy'), '3', '25', '330', '11', '2076', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28090, to_date('26-11-2076', 'dd-mm-yyyy'), '4', '26', '331', '11', '2076', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28091, to_date('27-11-2076', 'dd-mm-yyyy'), '5', '27', '332', '11', '2076', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28092, to_date('28-11-2076', 'dd-mm-yyyy'), '6', '28', '333', '11', '2076', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28093, to_date('29-11-2076', 'dd-mm-yyyy'), '7', '29', '334', '11', '2076', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28094, to_date('30-11-2076', 'dd-mm-yyyy'), '1', '30', '335', '11', '2076', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28095, to_date('01-12-2076', 'dd-mm-yyyy'), '2', '01', '336', '12', '2076', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28096, to_date('02-12-2076', 'dd-mm-yyyy'), '3', '02', '337', '12', '2076', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28097, to_date('03-12-2076', 'dd-mm-yyyy'), '4', '03', '338', '12', '2076', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28098, to_date('04-12-2076', 'dd-mm-yyyy'), '5', '04', '339', '12', '2076', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28099, to_date('05-12-2076', 'dd-mm-yyyy'), '6', '05', '340', '12', '2076', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28100, to_date('06-12-2076', 'dd-mm-yyyy'), '7', '06', '341', '12', '2076', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28101, to_date('07-12-2076', 'dd-mm-yyyy'), '1', '07', '342', '12', '2076', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28102, to_date('08-12-2076', 'dd-mm-yyyy'), '2', '08', '343', '12', '2076', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28103, to_date('09-12-2076', 'dd-mm-yyyy'), '3', '09', '344', '12', '2076', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28104, to_date('10-12-2076', 'dd-mm-yyyy'), '4', '10', '345', '12', '2076', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28105, to_date('11-12-2076', 'dd-mm-yyyy'), '5', '11', '346', '12', '2076', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28106, to_date('12-12-2076', 'dd-mm-yyyy'), '6', '12', '347', '12', '2076', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28107, to_date('13-12-2076', 'dd-mm-yyyy'), '7', '13', '348', '12', '2076', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28108, to_date('14-12-2076', 'dd-mm-yyyy'), '1', '14', '349', '12', '2076', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28109, to_date('15-12-2076', 'dd-mm-yyyy'), '2', '15', '350', '12', '2076', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28110, to_date('16-12-2076', 'dd-mm-yyyy'), '3', '16', '351', '12', '2076', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28111, to_date('17-12-2076', 'dd-mm-yyyy'), '4', '17', '352', '12', '2076', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28112, to_date('18-12-2076', 'dd-mm-yyyy'), '5', '18', '353', '12', '2076', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28113, to_date('19-12-2076', 'dd-mm-yyyy'), '6', '19', '354', '12', '2076', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28114, to_date('20-12-2076', 'dd-mm-yyyy'), '7', '20', '355', '12', '2076', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28115, to_date('21-12-2076', 'dd-mm-yyyy'), '1', '21', '356', '12', '2076', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28116, to_date('22-12-2076', 'dd-mm-yyyy'), '2', '22', '357', '12', '2076', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28117, to_date('23-12-2076', 'dd-mm-yyyy'), '3', '23', '358', '12', '2076', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28118, to_date('24-12-2076', 'dd-mm-yyyy'), '4', '24', '359', '12', '2076', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28119, to_date('25-12-2076', 'dd-mm-yyyy'), '5', '25', '360', '12', '2076', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28120, to_date('26-12-2076', 'dd-mm-yyyy'), '6', '26', '361', '12', '2076', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28121, to_date('27-12-2076', 'dd-mm-yyyy'), '7', '27', '362', '12', '2076', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28122, to_date('28-12-2076', 'dd-mm-yyyy'), '1', '28', '363', '12', '2076', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28123, to_date('29-12-2076', 'dd-mm-yyyy'), '2', '29', '364', '12', '2076', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28124, to_date('30-12-2076', 'dd-mm-yyyy'), '3', '30', '365', '12', '2076', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28125, to_date('31-12-2076', 'dd-mm-yyyy'), '4', '31', '366', '12', '2076', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28126, to_date('01-01-2077', 'dd-mm-yyyy'), '5', '01', '001', '01', '2077', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28127, to_date('02-01-2077', 'dd-mm-yyyy'), '6', '02', '002', '01', '2077', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28128, to_date('03-01-2077', 'dd-mm-yyyy'), '7', '03', '003', '01', '2077', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28129, to_date('04-01-2077', 'dd-mm-yyyy'), '1', '04', '004', '01', '2077', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28130, to_date('05-01-2077', 'dd-mm-yyyy'), '2', '05', '005', '01', '2077', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28131, to_date('06-01-2077', 'dd-mm-yyyy'), '3', '06', '006', '01', '2077', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28132, to_date('07-01-2077', 'dd-mm-yyyy'), '4', '07', '007', '01', '2077', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28133, to_date('08-01-2077', 'dd-mm-yyyy'), '5', '08', '008', '01', '2077', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28134, to_date('09-01-2077', 'dd-mm-yyyy'), '6', '09', '009', '01', '2077', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28135, to_date('10-01-2077', 'dd-mm-yyyy'), '7', '10', '010', '01', '2077', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28136, to_date('11-01-2077', 'dd-mm-yyyy'), '1', '11', '011', '01', '2077', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28137, to_date('12-01-2077', 'dd-mm-yyyy'), '2', '12', '012', '01', '2077', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28138, to_date('13-01-2077', 'dd-mm-yyyy'), '3', '13', '013', '01', '2077', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28139, to_date('14-01-2077', 'dd-mm-yyyy'), '4', '14', '014', '01', '2077', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28140, to_date('15-01-2077', 'dd-mm-yyyy'), '5', '15', '015', '01', '2077', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28141, to_date('16-01-2077', 'dd-mm-yyyy'), '6', '16', '016', '01', '2077', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28142, to_date('17-01-2077', 'dd-mm-yyyy'), '7', '17', '017', '01', '2077', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28143, to_date('18-01-2077', 'dd-mm-yyyy'), '1', '18', '018', '01', '2077', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28144, to_date('19-01-2077', 'dd-mm-yyyy'), '2', '19', '019', '01', '2077', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28145, to_date('20-01-2077', 'dd-mm-yyyy'), '3', '20', '020', '01', '2077', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28146, to_date('21-01-2077', 'dd-mm-yyyy'), '4', '21', '021', '01', '2077', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28147, to_date('22-01-2077', 'dd-mm-yyyy'), '5', '22', '022', '01', '2077', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28148, to_date('23-01-2077', 'dd-mm-yyyy'), '6', '23', '023', '01', '2077', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28149, to_date('24-01-2077', 'dd-mm-yyyy'), '7', '24', '024', '01', '2077', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28150, to_date('25-01-2077', 'dd-mm-yyyy'), '1', '25', '025', '01', '2077', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28151, to_date('26-01-2077', 'dd-mm-yyyy'), '2', '26', '026', '01', '2077', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28152, to_date('27-01-2077', 'dd-mm-yyyy'), '3', '27', '027', '01', '2077', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28153, to_date('28-01-2077', 'dd-mm-yyyy'), '4', '28', '028', '01', '2077', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28154, to_date('29-01-2077', 'dd-mm-yyyy'), '5', '29', '029', '01', '2077', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28155, to_date('30-01-2077', 'dd-mm-yyyy'), '6', '30', '030', '01', '2077', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28156, to_date('31-01-2077', 'dd-mm-yyyy'), '7', '31', '031', '01', '2077', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28157, to_date('01-02-2077', 'dd-mm-yyyy'), '1', '01', '032', '02', '2077', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28158, to_date('02-02-2077', 'dd-mm-yyyy'), '2', '02', '033', '02', '2077', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28159, to_date('03-02-2077', 'dd-mm-yyyy'), '3', '03', '034', '02', '2077', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28160, to_date('04-02-2077', 'dd-mm-yyyy'), '4', '04', '035', '02', '2077', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28161, to_date('05-02-2077', 'dd-mm-yyyy'), '5', '05', '036', '02', '2077', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28162, to_date('06-02-2077', 'dd-mm-yyyy'), '6', '06', '037', '02', '2077', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28163, to_date('07-02-2077', 'dd-mm-yyyy'), '7', '07', '038', '02', '2077', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28164, to_date('08-02-2077', 'dd-mm-yyyy'), '1', '08', '039', '02', '2077', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28165, to_date('09-02-2077', 'dd-mm-yyyy'), '2', '09', '040', '02', '2077', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28166, to_date('10-02-2077', 'dd-mm-yyyy'), '3', '10', '041', '02', '2077', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28167, to_date('11-02-2077', 'dd-mm-yyyy'), '4', '11', '042', '02', '2077', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28168, to_date('12-02-2077', 'dd-mm-yyyy'), '5', '12', '043', '02', '2077', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28169, to_date('13-02-2077', 'dd-mm-yyyy'), '6', '13', '044', '02', '2077', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28170, to_date('14-02-2077', 'dd-mm-yyyy'), '7', '14', '045', '02', '2077', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29655, to_date('10-03-2081', 'dd-mm-yyyy'), '1', '10', '069', '03', '2081', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29656, to_date('11-03-2081', 'dd-mm-yyyy'), '2', '11', '070', '03', '2081', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29657, to_date('12-03-2081', 'dd-mm-yyyy'), '3', '12', '071', '03', '2081', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29658, to_date('13-03-2081', 'dd-mm-yyyy'), '4', '13', '072', '03', '2081', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29659, to_date('14-03-2081', 'dd-mm-yyyy'), '5', '14', '073', '03', '2081', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29660, to_date('15-03-2081', 'dd-mm-yyyy'), '6', '15', '074', '03', '2081', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29661, to_date('16-03-2081', 'dd-mm-yyyy'), '7', '16', '075', '03', '2081', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29662, to_date('17-03-2081', 'dd-mm-yyyy'), '1', '17', '076', '03', '2081', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29663, to_date('18-03-2081', 'dd-mm-yyyy'), '2', '18', '077', '03', '2081', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29664, to_date('19-03-2081', 'dd-mm-yyyy'), '3', '19', '078', '03', '2081', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29665, to_date('20-03-2081', 'dd-mm-yyyy'), '4', '20', '079', '03', '2081', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29666, to_date('21-03-2081', 'dd-mm-yyyy'), '5', '21', '080', '03', '2081', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29667, to_date('22-03-2081', 'dd-mm-yyyy'), '6', '22', '081', '03', '2081', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29668, to_date('23-03-2081', 'dd-mm-yyyy'), '7', '23', '082', '03', '2081', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29669, to_date('24-03-2081', 'dd-mm-yyyy'), '1', '24', '083', '03', '2081', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29670, to_date('25-03-2081', 'dd-mm-yyyy'), '2', '25', '084', '03', '2081', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29671, to_date('26-03-2081', 'dd-mm-yyyy'), '3', '26', '085', '03', '2081', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29672, to_date('27-03-2081', 'dd-mm-yyyy'), '4', '27', '086', '03', '2081', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29673, to_date('28-03-2081', 'dd-mm-yyyy'), '5', '28', '087', '03', '2081', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29674, to_date('29-03-2081', 'dd-mm-yyyy'), '6', '29', '088', '03', '2081', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29675, to_date('30-03-2081', 'dd-mm-yyyy'), '7', '30', '089', '03', '2081', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29676, to_date('31-03-2081', 'dd-mm-yyyy'), '1', '31', '090', '03', '2081', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29677, to_date('01-04-2081', 'dd-mm-yyyy'), '2', '01', '091', '04', '2081', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29678, to_date('02-04-2081', 'dd-mm-yyyy'), '3', '02', '092', '04', '2081', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29679, to_date('03-04-2081', 'dd-mm-yyyy'), '4', '03', '093', '04', '2081', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29680, to_date('04-04-2081', 'dd-mm-yyyy'), '5', '04', '094', '04', '2081', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29681, to_date('05-04-2081', 'dd-mm-yyyy'), '6', '05', '095', '04', '2081', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29682, to_date('06-04-2081', 'dd-mm-yyyy'), '7', '06', '096', '04', '2081', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29683, to_date('07-04-2081', 'dd-mm-yyyy'), '1', '07', '097', '04', '2081', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29684, to_date('08-04-2081', 'dd-mm-yyyy'), '2', '08', '098', '04', '2081', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29685, to_date('09-04-2081', 'dd-mm-yyyy'), '3', '09', '099', '04', '2081', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29686, to_date('10-04-2081', 'dd-mm-yyyy'), '4', '10', '100', '04', '2081', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29687, to_date('11-04-2081', 'dd-mm-yyyy'), '5', '11', '101', '04', '2081', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
commit;
prompt 32000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29688, to_date('12-04-2081', 'dd-mm-yyyy'), '6', '12', '102', '04', '2081', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29689, to_date('13-04-2081', 'dd-mm-yyyy'), '7', '13', '103', '04', '2081', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29690, to_date('14-04-2081', 'dd-mm-yyyy'), '1', '14', '104', '04', '2081', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29691, to_date('15-04-2081', 'dd-mm-yyyy'), '2', '15', '105', '04', '2081', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29692, to_date('16-04-2081', 'dd-mm-yyyy'), '3', '16', '106', '04', '2081', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29693, to_date('17-04-2081', 'dd-mm-yyyy'), '4', '17', '107', '04', '2081', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29694, to_date('18-04-2081', 'dd-mm-yyyy'), '5', '18', '108', '04', '2081', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29695, to_date('19-04-2081', 'dd-mm-yyyy'), '6', '19', '109', '04', '2081', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29696, to_date('20-04-2081', 'dd-mm-yyyy'), '7', '20', '110', '04', '2081', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29697, to_date('21-04-2081', 'dd-mm-yyyy'), '1', '21', '111', '04', '2081', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29698, to_date('22-04-2081', 'dd-mm-yyyy'), '2', '22', '112', '04', '2081', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29699, to_date('23-04-2081', 'dd-mm-yyyy'), '3', '23', '113', '04', '2081', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29700, to_date('24-04-2081', 'dd-mm-yyyy'), '4', '24', '114', '04', '2081', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29701, to_date('25-04-2081', 'dd-mm-yyyy'), '5', '25', '115', '04', '2081', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29702, to_date('26-04-2081', 'dd-mm-yyyy'), '6', '26', '116', '04', '2081', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29703, to_date('27-04-2081', 'dd-mm-yyyy'), '7', '27', '117', '04', '2081', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29704, to_date('28-04-2081', 'dd-mm-yyyy'), '1', '28', '118', '04', '2081', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29705, to_date('29-04-2081', 'dd-mm-yyyy'), '2', '29', '119', '04', '2081', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29706, to_date('30-04-2081', 'dd-mm-yyyy'), '3', '30', '120', '04', '2081', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29707, to_date('01-05-2081', 'dd-mm-yyyy'), '4', '01', '121', '05', '2081', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29708, to_date('02-05-2081', 'dd-mm-yyyy'), '5', '02', '122', '05', '2081', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29709, to_date('03-05-2081', 'dd-mm-yyyy'), '6', '03', '123', '05', '2081', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29710, to_date('04-05-2081', 'dd-mm-yyyy'), '7', '04', '124', '05', '2081', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29711, to_date('05-05-2081', 'dd-mm-yyyy'), '1', '05', '125', '05', '2081', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29712, to_date('06-05-2081', 'dd-mm-yyyy'), '2', '06', '126', '05', '2081', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29713, to_date('07-05-2081', 'dd-mm-yyyy'), '3', '07', '127', '05', '2081', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29714, to_date('08-05-2081', 'dd-mm-yyyy'), '4', '08', '128', '05', '2081', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29715, to_date('09-05-2081', 'dd-mm-yyyy'), '5', '09', '129', '05', '2081', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29716, to_date('10-05-2081', 'dd-mm-yyyy'), '6', '10', '130', '05', '2081', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29717, to_date('11-05-2081', 'dd-mm-yyyy'), '7', '11', '131', '05', '2081', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29718, to_date('12-05-2081', 'dd-mm-yyyy'), '1', '12', '132', '05', '2081', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29719, to_date('13-05-2081', 'dd-mm-yyyy'), '2', '13', '133', '05', '2081', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29720, to_date('14-05-2081', 'dd-mm-yyyy'), '3', '14', '134', '05', '2081', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29721, to_date('15-05-2081', 'dd-mm-yyyy'), '4', '15', '135', '05', '2081', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29722, to_date('16-05-2081', 'dd-mm-yyyy'), '5', '16', '136', '05', '2081', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29723, to_date('17-05-2081', 'dd-mm-yyyy'), '6', '17', '137', '05', '2081', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29724, to_date('18-05-2081', 'dd-mm-yyyy'), '7', '18', '138', '05', '2081', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29725, to_date('19-05-2081', 'dd-mm-yyyy'), '1', '19', '139', '05', '2081', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29726, to_date('20-05-2081', 'dd-mm-yyyy'), '2', '20', '140', '05', '2081', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29727, to_date('21-05-2081', 'dd-mm-yyyy'), '3', '21', '141', '05', '2081', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29728, to_date('22-05-2081', 'dd-mm-yyyy'), '4', '22', '142', '05', '2081', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29729, to_date('23-05-2081', 'dd-mm-yyyy'), '5', '23', '143', '05', '2081', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29730, to_date('24-05-2081', 'dd-mm-yyyy'), '6', '24', '144', '05', '2081', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29731, to_date('25-05-2081', 'dd-mm-yyyy'), '7', '25', '145', '05', '2081', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29732, to_date('26-05-2081', 'dd-mm-yyyy'), '1', '26', '146', '05', '2081', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29733, to_date('27-05-2081', 'dd-mm-yyyy'), '2', '27', '147', '05', '2081', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29734, to_date('28-05-2081', 'dd-mm-yyyy'), '3', '28', '148', '05', '2081', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29735, to_date('29-05-2081', 'dd-mm-yyyy'), '4', '29', '149', '05', '2081', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29736, to_date('30-05-2081', 'dd-mm-yyyy'), '5', '30', '150', '05', '2081', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29737, to_date('31-05-2081', 'dd-mm-yyyy'), '6', '31', '151', '05', '2081', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29738, to_date('01-06-2081', 'dd-mm-yyyy'), '7', '01', '152', '06', '2081', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29739, to_date('02-06-2081', 'dd-mm-yyyy'), '1', '02', '153', '06', '2081', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29740, to_date('03-06-2081', 'dd-mm-yyyy'), '2', '03', '154', '06', '2081', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29741, to_date('04-06-2081', 'dd-mm-yyyy'), '3', '04', '155', '06', '2081', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29742, to_date('05-06-2081', 'dd-mm-yyyy'), '4', '05', '156', '06', '2081', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29743, to_date('06-06-2081', 'dd-mm-yyyy'), '5', '06', '157', '06', '2081', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29744, to_date('07-06-2081', 'dd-mm-yyyy'), '6', '07', '158', '06', '2081', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29745, to_date('08-06-2081', 'dd-mm-yyyy'), '7', '08', '159', '06', '2081', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29746, to_date('09-06-2081', 'dd-mm-yyyy'), '1', '09', '160', '06', '2081', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29747, to_date('10-06-2081', 'dd-mm-yyyy'), '2', '10', '161', '06', '2081', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29748, to_date('11-06-2081', 'dd-mm-yyyy'), '3', '11', '162', '06', '2081', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29749, to_date('12-06-2081', 'dd-mm-yyyy'), '4', '12', '163', '06', '2081', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29750, to_date('13-06-2081', 'dd-mm-yyyy'), '5', '13', '164', '06', '2081', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29751, to_date('14-06-2081', 'dd-mm-yyyy'), '6', '14', '165', '06', '2081', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29752, to_date('15-06-2081', 'dd-mm-yyyy'), '7', '15', '166', '06', '2081', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29753, to_date('16-06-2081', 'dd-mm-yyyy'), '1', '16', '167', '06', '2081', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29754, to_date('17-06-2081', 'dd-mm-yyyy'), '2', '17', '168', '06', '2081', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29755, to_date('18-06-2081', 'dd-mm-yyyy'), '3', '18', '169', '06', '2081', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29756, to_date('19-06-2081', 'dd-mm-yyyy'), '4', '19', '170', '06', '2081', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29757, to_date('20-06-2081', 'dd-mm-yyyy'), '5', '20', '171', '06', '2081', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29758, to_date('21-06-2081', 'dd-mm-yyyy'), '6', '21', '172', '06', '2081', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29759, to_date('22-06-2081', 'dd-mm-yyyy'), '7', '22', '173', '06', '2081', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29760, to_date('23-06-2081', 'dd-mm-yyyy'), '1', '23', '174', '06', '2081', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31245, to_date('17-07-2085', 'dd-mm-yyyy'), '2', '17', '198', '07', '2085', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31246, to_date('18-07-2085', 'dd-mm-yyyy'), '3', '18', '199', '07', '2085', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31247, to_date('19-07-2085', 'dd-mm-yyyy'), '4', '19', '200', '07', '2085', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31248, to_date('20-07-2085', 'dd-mm-yyyy'), '5', '20', '201', '07', '2085', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31249, to_date('21-07-2085', 'dd-mm-yyyy'), '6', '21', '202', '07', '2085', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31250, to_date('22-07-2085', 'dd-mm-yyyy'), '7', '22', '203', '07', '2085', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31251, to_date('23-07-2085', 'dd-mm-yyyy'), '1', '23', '204', '07', '2085', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31252, to_date('24-07-2085', 'dd-mm-yyyy'), '2', '24', '205', '07', '2085', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31253, to_date('25-07-2085', 'dd-mm-yyyy'), '3', '25', '206', '07', '2085', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31254, to_date('26-07-2085', 'dd-mm-yyyy'), '4', '26', '207', '07', '2085', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31255, to_date('27-07-2085', 'dd-mm-yyyy'), '5', '27', '208', '07', '2085', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31256, to_date('28-07-2085', 'dd-mm-yyyy'), '6', '28', '209', '07', '2085', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31257, to_date('29-07-2085', 'dd-mm-yyyy'), '7', '29', '210', '07', '2085', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31258, to_date('30-07-2085', 'dd-mm-yyyy'), '1', '30', '211', '07', '2085', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31259, to_date('31-07-2085', 'dd-mm-yyyy'), '2', '31', '212', '07', '2085', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31260, to_date('01-08-2085', 'dd-mm-yyyy'), '3', '01', '213', '08', '2085', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31261, to_date('02-08-2085', 'dd-mm-yyyy'), '4', '02', '214', '08', '2085', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31262, to_date('03-08-2085', 'dd-mm-yyyy'), '5', '03', '215', '08', '2085', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31263, to_date('04-08-2085', 'dd-mm-yyyy'), '6', '04', '216', '08', '2085', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31264, to_date('05-08-2085', 'dd-mm-yyyy'), '7', '05', '217', '08', '2085', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31265, to_date('06-08-2085', 'dd-mm-yyyy'), '1', '06', '218', '08', '2085', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31266, to_date('07-08-2085', 'dd-mm-yyyy'), '2', '07', '219', '08', '2085', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31267, to_date('08-08-2085', 'dd-mm-yyyy'), '3', '08', '220', '08', '2085', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31268, to_date('09-08-2085', 'dd-mm-yyyy'), '4', '09', '221', '08', '2085', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31269, to_date('10-08-2085', 'dd-mm-yyyy'), '5', '10', '222', '08', '2085', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31270, to_date('11-08-2085', 'dd-mm-yyyy'), '6', '11', '223', '08', '2085', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31271, to_date('12-08-2085', 'dd-mm-yyyy'), '7', '12', '224', '08', '2085', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31272, to_date('13-08-2085', 'dd-mm-yyyy'), '1', '13', '225', '08', '2085', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31273, to_date('14-08-2085', 'dd-mm-yyyy'), '2', '14', '226', '08', '2085', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31274, to_date('15-08-2085', 'dd-mm-yyyy'), '3', '15', '227', '08', '2085', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31275, to_date('16-08-2085', 'dd-mm-yyyy'), '4', '16', '228', '08', '2085', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31276, to_date('17-08-2085', 'dd-mm-yyyy'), '5', '17', '229', '08', '2085', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31277, to_date('18-08-2085', 'dd-mm-yyyy'), '6', '18', '230', '08', '2085', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31278, to_date('19-08-2085', 'dd-mm-yyyy'), '7', '19', '231', '08', '2085', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31279, to_date('20-08-2085', 'dd-mm-yyyy'), '1', '20', '232', '08', '2085', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31280, to_date('21-08-2085', 'dd-mm-yyyy'), '2', '21', '233', '08', '2085', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31281, to_date('22-08-2085', 'dd-mm-yyyy'), '3', '22', '234', '08', '2085', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31282, to_date('23-08-2085', 'dd-mm-yyyy'), '4', '23', '235', '08', '2085', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31283, to_date('24-08-2085', 'dd-mm-yyyy'), '5', '24', '236', '08', '2085', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31284, to_date('25-08-2085', 'dd-mm-yyyy'), '6', '25', '237', '08', '2085', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31285, to_date('26-08-2085', 'dd-mm-yyyy'), '7', '26', '238', '08', '2085', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31286, to_date('27-08-2085', 'dd-mm-yyyy'), '1', '27', '239', '08', '2085', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31287, to_date('28-08-2085', 'dd-mm-yyyy'), '2', '28', '240', '08', '2085', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31288, to_date('29-08-2085', 'dd-mm-yyyy'), '3', '29', '241', '08', '2085', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31289, to_date('30-08-2085', 'dd-mm-yyyy'), '4', '30', '242', '08', '2085', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31290, to_date('31-08-2085', 'dd-mm-yyyy'), '5', '31', '243', '08', '2085', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31291, to_date('01-09-2085', 'dd-mm-yyyy'), '6', '01', '244', '09', '2085', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31292, to_date('02-09-2085', 'dd-mm-yyyy'), '7', '02', '245', '09', '2085', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31293, to_date('03-09-2085', 'dd-mm-yyyy'), '1', '03', '246', '09', '2085', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31294, to_date('04-09-2085', 'dd-mm-yyyy'), '2', '04', '247', '09', '2085', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31295, to_date('05-09-2085', 'dd-mm-yyyy'), '3', '05', '248', '09', '2085', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31296, to_date('06-09-2085', 'dd-mm-yyyy'), '4', '06', '249', '09', '2085', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31297, to_date('07-09-2085', 'dd-mm-yyyy'), '5', '07', '250', '09', '2085', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31298, to_date('08-09-2085', 'dd-mm-yyyy'), '6', '08', '251', '09', '2085', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31299, to_date('09-09-2085', 'dd-mm-yyyy'), '7', '09', '252', '09', '2085', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31300, to_date('10-09-2085', 'dd-mm-yyyy'), '1', '10', '253', '09', '2085', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31301, to_date('11-09-2085', 'dd-mm-yyyy'), '2', '11', '254', '09', '2085', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31302, to_date('12-09-2085', 'dd-mm-yyyy'), '3', '12', '255', '09', '2085', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31303, to_date('13-09-2085', 'dd-mm-yyyy'), '4', '13', '256', '09', '2085', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31304, to_date('14-09-2085', 'dd-mm-yyyy'), '5', '14', '257', '09', '2085', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31305, to_date('15-09-2085', 'dd-mm-yyyy'), '6', '15', '258', '09', '2085', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31306, to_date('16-09-2085', 'dd-mm-yyyy'), '7', '16', '259', '09', '2085', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31307, to_date('17-09-2085', 'dd-mm-yyyy'), '1', '17', '260', '09', '2085', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31308, to_date('18-09-2085', 'dd-mm-yyyy'), '2', '18', '261', '09', '2085', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31309, to_date('19-09-2085', 'dd-mm-yyyy'), '3', '19', '262', '09', '2085', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31310, to_date('20-09-2085', 'dd-mm-yyyy'), '4', '20', '263', '09', '2085', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31311, to_date('21-09-2085', 'dd-mm-yyyy'), '5', '21', '264', '09', '2085', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31312, to_date('22-09-2085', 'dd-mm-yyyy'), '6', '22', '265', '09', '2085', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31313, to_date('23-09-2085', 'dd-mm-yyyy'), '7', '23', '266', '09', '2085', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31314, to_date('24-09-2085', 'dd-mm-yyyy'), '1', '24', '267', '09', '2085', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31315, to_date('25-09-2085', 'dd-mm-yyyy'), '2', '25', '268', '09', '2085', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31316, to_date('26-09-2085', 'dd-mm-yyyy'), '3', '26', '269', '09', '2085', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31317, to_date('27-09-2085', 'dd-mm-yyyy'), '4', '27', '270', '09', '2085', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31318, to_date('28-09-2085', 'dd-mm-yyyy'), '5', '28', '271', '09', '2085', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31319, to_date('29-09-2085', 'dd-mm-yyyy'), '6', '29', '272', '09', '2085', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31320, to_date('30-09-2085', 'dd-mm-yyyy'), '7', '30', '273', '09', '2085', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31321, to_date('01-10-2085', 'dd-mm-yyyy'), '1', '01', '274', '10', '2085', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31322, to_date('02-10-2085', 'dd-mm-yyyy'), '2', '02', '275', '10', '2085', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31323, to_date('03-10-2085', 'dd-mm-yyyy'), '3', '03', '276', '10', '2085', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31324, to_date('04-10-2085', 'dd-mm-yyyy'), '4', '04', '277', '10', '2085', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31325, to_date('05-10-2085', 'dd-mm-yyyy'), '5', '05', '278', '10', '2085', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31326, to_date('06-10-2085', 'dd-mm-yyyy'), '6', '06', '279', '10', '2085', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31327, to_date('07-10-2085', 'dd-mm-yyyy'), '7', '07', '280', '10', '2085', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31328, to_date('08-10-2085', 'dd-mm-yyyy'), '1', '08', '281', '10', '2085', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31329, to_date('09-10-2085', 'dd-mm-yyyy'), '2', '09', '282', '10', '2085', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31330, to_date('10-10-2085', 'dd-mm-yyyy'), '3', '10', '283', '10', '2085', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31331, to_date('11-10-2085', 'dd-mm-yyyy'), '4', '11', '284', '10', '2085', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31332, to_date('12-10-2085', 'dd-mm-yyyy'), '5', '12', '285', '10', '2085', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31333, to_date('13-10-2085', 'dd-mm-yyyy'), '6', '13', '286', '10', '2085', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31334, to_date('14-10-2085', 'dd-mm-yyyy'), '7', '14', '287', '10', '2085', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31335, to_date('15-10-2085', 'dd-mm-yyyy'), '1', '15', '288', '10', '2085', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31336, to_date('16-10-2085', 'dd-mm-yyyy'), '2', '16', '289', '10', '2085', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31337, to_date('17-10-2085', 'dd-mm-yyyy'), '3', '17', '290', '10', '2085', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31338, to_date('18-10-2085', 'dd-mm-yyyy'), '4', '18', '291', '10', '2085', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31339, to_date('19-10-2085', 'dd-mm-yyyy'), '5', '19', '292', '10', '2085', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31340, to_date('20-10-2085', 'dd-mm-yyyy'), '6', '20', '293', '10', '2085', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31341, to_date('21-10-2085', 'dd-mm-yyyy'), '7', '21', '294', '10', '2085', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31342, to_date('22-10-2085', 'dd-mm-yyyy'), '1', '22', '295', '10', '2085', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31343, to_date('23-10-2085', 'dd-mm-yyyy'), '2', '23', '296', '10', '2085', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31344, to_date('24-10-2085', 'dd-mm-yyyy'), '3', '24', '297', '10', '2085', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31345, to_date('25-10-2085', 'dd-mm-yyyy'), '4', '25', '298', '10', '2085', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31346, to_date('26-10-2085', 'dd-mm-yyyy'), '5', '26', '299', '10', '2085', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31347, to_date('27-10-2085', 'dd-mm-yyyy'), '6', '27', '300', '10', '2085', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31348, to_date('28-10-2085', 'dd-mm-yyyy'), '7', '28', '301', '10', '2085', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31349, to_date('29-10-2085', 'dd-mm-yyyy'), '1', '29', '302', '10', '2085', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31350, to_date('30-10-2085', 'dd-mm-yyyy'), '2', '30', '303', '10', '2085', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26475, to_date('25-06-2072', 'dd-mm-yyyy'), '6', '25', '177', '06', '2072', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26476, to_date('26-06-2072', 'dd-mm-yyyy'), '7', '26', '178', '06', '2072', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26477, to_date('27-06-2072', 'dd-mm-yyyy'), '1', '27', '179', '06', '2072', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26478, to_date('28-06-2072', 'dd-mm-yyyy'), '2', '28', '180', '06', '2072', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26479, to_date('29-06-2072', 'dd-mm-yyyy'), '3', '29', '181', '06', '2072', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26480, to_date('30-06-2072', 'dd-mm-yyyy'), '4', '30', '182', '06', '2072', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26481, to_date('01-07-2072', 'dd-mm-yyyy'), '5', '01', '183', '07', '2072', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26482, to_date('02-07-2072', 'dd-mm-yyyy'), '6', '02', '184', '07', '2072', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26483, to_date('03-07-2072', 'dd-mm-yyyy'), '7', '03', '185', '07', '2072', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26484, to_date('04-07-2072', 'dd-mm-yyyy'), '1', '04', '186', '07', '2072', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26485, to_date('05-07-2072', 'dd-mm-yyyy'), '2', '05', '187', '07', '2072', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26486, to_date('06-07-2072', 'dd-mm-yyyy'), '3', '06', '188', '07', '2072', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26487, to_date('07-07-2072', 'dd-mm-yyyy'), '4', '07', '189', '07', '2072', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26488, to_date('08-07-2072', 'dd-mm-yyyy'), '5', '08', '190', '07', '2072', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26489, to_date('09-07-2072', 'dd-mm-yyyy'), '6', '09', '191', '07', '2072', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26490, to_date('10-07-2072', 'dd-mm-yyyy'), '7', '10', '192', '07', '2072', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26491, to_date('11-07-2072', 'dd-mm-yyyy'), '1', '11', '193', '07', '2072', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26492, to_date('12-07-2072', 'dd-mm-yyyy'), '2', '12', '194', '07', '2072', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26493, to_date('13-07-2072', 'dd-mm-yyyy'), '3', '13', '195', '07', '2072', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26494, to_date('14-07-2072', 'dd-mm-yyyy'), '4', '14', '196', '07', '2072', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26495, to_date('15-07-2072', 'dd-mm-yyyy'), '5', '15', '197', '07', '2072', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26496, to_date('16-07-2072', 'dd-mm-yyyy'), '6', '16', '198', '07', '2072', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26497, to_date('17-07-2072', 'dd-mm-yyyy'), '7', '17', '199', '07', '2072', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26498, to_date('18-07-2072', 'dd-mm-yyyy'), '1', '18', '200', '07', '2072', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26499, to_date('19-07-2072', 'dd-mm-yyyy'), '2', '19', '201', '07', '2072', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26500, to_date('20-07-2072', 'dd-mm-yyyy'), '3', '20', '202', '07', '2072', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26501, to_date('21-07-2072', 'dd-mm-yyyy'), '4', '21', '203', '07', '2072', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26502, to_date('22-07-2072', 'dd-mm-yyyy'), '5', '22', '204', '07', '2072', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26503, to_date('23-07-2072', 'dd-mm-yyyy'), '6', '23', '205', '07', '2072', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26504, to_date('24-07-2072', 'dd-mm-yyyy'), '7', '24', '206', '07', '2072', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26505, to_date('25-07-2072', 'dd-mm-yyyy'), '1', '25', '207', '07', '2072', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26506, to_date('26-07-2072', 'dd-mm-yyyy'), '2', '26', '208', '07', '2072', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26507, to_date('27-07-2072', 'dd-mm-yyyy'), '3', '27', '209', '07', '2072', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26508, to_date('28-07-2072', 'dd-mm-yyyy'), '4', '28', '210', '07', '2072', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26509, to_date('29-07-2072', 'dd-mm-yyyy'), '5', '29', '211', '07', '2072', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26510, to_date('30-07-2072', 'dd-mm-yyyy'), '6', '30', '212', '07', '2072', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26511, to_date('31-07-2072', 'dd-mm-yyyy'), '7', '31', '213', '07', '2072', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26512, to_date('01-08-2072', 'dd-mm-yyyy'), '1', '01', '214', '08', '2072', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26513, to_date('02-08-2072', 'dd-mm-yyyy'), '2', '02', '215', '08', '2072', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26514, to_date('03-08-2072', 'dd-mm-yyyy'), '3', '03', '216', '08', '2072', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26515, to_date('04-08-2072', 'dd-mm-yyyy'), '4', '04', '217', '08', '2072', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26516, to_date('05-08-2072', 'dd-mm-yyyy'), '5', '05', '218', '08', '2072', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26517, to_date('06-08-2072', 'dd-mm-yyyy'), '6', '06', '219', '08', '2072', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26518, to_date('07-08-2072', 'dd-mm-yyyy'), '7', '07', '220', '08', '2072', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26519, to_date('08-08-2072', 'dd-mm-yyyy'), '1', '08', '221', '08', '2072', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26520, to_date('09-08-2072', 'dd-mm-yyyy'), '2', '09', '222', '08', '2072', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26521, to_date('10-08-2072', 'dd-mm-yyyy'), '3', '10', '223', '08', '2072', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26522, to_date('11-08-2072', 'dd-mm-yyyy'), '4', '11', '224', '08', '2072', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26523, to_date('12-08-2072', 'dd-mm-yyyy'), '5', '12', '225', '08', '2072', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26524, to_date('13-08-2072', 'dd-mm-yyyy'), '6', '13', '226', '08', '2072', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26525, to_date('14-08-2072', 'dd-mm-yyyy'), '7', '14', '227', '08', '2072', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26526, to_date('15-08-2072', 'dd-mm-yyyy'), '1', '15', '228', '08', '2072', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26527, to_date('16-08-2072', 'dd-mm-yyyy'), '2', '16', '229', '08', '2072', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26528, to_date('17-08-2072', 'dd-mm-yyyy'), '3', '17', '230', '08', '2072', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26529, to_date('18-08-2072', 'dd-mm-yyyy'), '4', '18', '231', '08', '2072', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26530, to_date('19-08-2072', 'dd-mm-yyyy'), '5', '19', '232', '08', '2072', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26531, to_date('20-08-2072', 'dd-mm-yyyy'), '6', '20', '233', '08', '2072', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26532, to_date('21-08-2072', 'dd-mm-yyyy'), '7', '21', '234', '08', '2072', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26533, to_date('22-08-2072', 'dd-mm-yyyy'), '1', '22', '235', '08', '2072', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26534, to_date('23-08-2072', 'dd-mm-yyyy'), '2', '23', '236', '08', '2072', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26535, to_date('24-08-2072', 'dd-mm-yyyy'), '3', '24', '237', '08', '2072', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26536, to_date('25-08-2072', 'dd-mm-yyyy'), '4', '25', '238', '08', '2072', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26537, to_date('26-08-2072', 'dd-mm-yyyy'), '5', '26', '239', '08', '2072', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26538, to_date('27-08-2072', 'dd-mm-yyyy'), '6', '27', '240', '08', '2072', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26539, to_date('28-08-2072', 'dd-mm-yyyy'), '7', '28', '241', '08', '2072', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26540, to_date('29-08-2072', 'dd-mm-yyyy'), '1', '29', '242', '08', '2072', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26541, to_date('30-08-2072', 'dd-mm-yyyy'), '2', '30', '243', '08', '2072', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26542, to_date('31-08-2072', 'dd-mm-yyyy'), '3', '31', '244', '08', '2072', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26543, to_date('01-09-2072', 'dd-mm-yyyy'), '4', '01', '245', '09', '2072', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26544, to_date('02-09-2072', 'dd-mm-yyyy'), '5', '02', '246', '09', '2072', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26545, to_date('03-09-2072', 'dd-mm-yyyy'), '6', '03', '247', '09', '2072', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26546, to_date('04-09-2072', 'dd-mm-yyyy'), '7', '04', '248', '09', '2072', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26547, to_date('05-09-2072', 'dd-mm-yyyy'), '1', '05', '249', '09', '2072', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26548, to_date('06-09-2072', 'dd-mm-yyyy'), '2', '06', '250', '09', '2072', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26549, to_date('07-09-2072', 'dd-mm-yyyy'), '3', '07', '251', '09', '2072', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26550, to_date('08-09-2072', 'dd-mm-yyyy'), '4', '08', '252', '09', '2072', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26551, to_date('09-09-2072', 'dd-mm-yyyy'), '5', '09', '253', '09', '2072', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26552, to_date('10-09-2072', 'dd-mm-yyyy'), '6', '10', '254', '09', '2072', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26553, to_date('11-09-2072', 'dd-mm-yyyy'), '7', '11', '255', '09', '2072', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26554, to_date('12-09-2072', 'dd-mm-yyyy'), '1', '12', '256', '09', '2072', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26555, to_date('13-09-2072', 'dd-mm-yyyy'), '2', '13', '257', '09', '2072', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26556, to_date('14-09-2072', 'dd-mm-yyyy'), '3', '14', '258', '09', '2072', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26557, to_date('15-09-2072', 'dd-mm-yyyy'), '4', '15', '259', '09', '2072', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26558, to_date('16-09-2072', 'dd-mm-yyyy'), '5', '16', '260', '09', '2072', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26559, to_date('17-09-2072', 'dd-mm-yyyy'), '6', '17', '261', '09', '2072', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26560, to_date('18-09-2072', 'dd-mm-yyyy'), '7', '18', '262', '09', '2072', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26561, to_date('19-09-2072', 'dd-mm-yyyy'), '1', '19', '263', '09', '2072', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26562, to_date('20-09-2072', 'dd-mm-yyyy'), '2', '20', '264', '09', '2072', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26563, to_date('21-09-2072', 'dd-mm-yyyy'), '3', '21', '265', '09', '2072', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26564, to_date('22-09-2072', 'dd-mm-yyyy'), '4', '22', '266', '09', '2072', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26565, to_date('23-09-2072', 'dd-mm-yyyy'), '5', '23', '267', '09', '2072', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26566, to_date('24-09-2072', 'dd-mm-yyyy'), '6', '24', '268', '09', '2072', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26567, to_date('25-09-2072', 'dd-mm-yyyy'), '7', '25', '269', '09', '2072', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26568, to_date('26-09-2072', 'dd-mm-yyyy'), '1', '26', '270', '09', '2072', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26569, to_date('27-09-2072', 'dd-mm-yyyy'), '2', '27', '271', '09', '2072', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26570, to_date('28-09-2072', 'dd-mm-yyyy'), '3', '28', '272', '09', '2072', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26571, to_date('29-09-2072', 'dd-mm-yyyy'), '4', '29', '273', '09', '2072', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26572, to_date('30-09-2072', 'dd-mm-yyyy'), '5', '30', '274', '09', '2072', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26573, to_date('01-10-2072', 'dd-mm-yyyy'), '6', '01', '275', '10', '2072', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26574, to_date('02-10-2072', 'dd-mm-yyyy'), '7', '02', '276', '10', '2072', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26575, to_date('03-10-2072', 'dd-mm-yyyy'), '1', '03', '277', '10', '2072', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26576, to_date('04-10-2072', 'dd-mm-yyyy'), '2', '04', '278', '10', '2072', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26577, to_date('05-10-2072', 'dd-mm-yyyy'), '3', '05', '279', '10', '2072', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26578, to_date('06-10-2072', 'dd-mm-yyyy'), '4', '06', '280', '10', '2072', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26579, to_date('07-10-2072', 'dd-mm-yyyy'), '5', '07', '281', '10', '2072', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26580, to_date('08-10-2072', 'dd-mm-yyyy'), '6', '08', '282', '10', '2072', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28171, to_date('15-02-2077', 'dd-mm-yyyy'), '1', '15', '046', '02', '2077', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28172, to_date('16-02-2077', 'dd-mm-yyyy'), '2', '16', '047', '02', '2077', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28173, to_date('17-02-2077', 'dd-mm-yyyy'), '3', '17', '048', '02', '2077', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28174, to_date('18-02-2077', 'dd-mm-yyyy'), '4', '18', '049', '02', '2077', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28175, to_date('19-02-2077', 'dd-mm-yyyy'), '5', '19', '050', '02', '2077', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28176, to_date('20-02-2077', 'dd-mm-yyyy'), '6', '20', '051', '02', '2077', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28177, to_date('21-02-2077', 'dd-mm-yyyy'), '7', '21', '052', '02', '2077', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28178, to_date('22-02-2077', 'dd-mm-yyyy'), '1', '22', '053', '02', '2077', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28179, to_date('23-02-2077', 'dd-mm-yyyy'), '2', '23', '054', '02', '2077', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28180, to_date('24-02-2077', 'dd-mm-yyyy'), '3', '24', '055', '02', '2077', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28181, to_date('25-02-2077', 'dd-mm-yyyy'), '4', '25', '056', '02', '2077', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28182, to_date('26-02-2077', 'dd-mm-yyyy'), '5', '26', '057', '02', '2077', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28183, to_date('27-02-2077', 'dd-mm-yyyy'), '6', '27', '058', '02', '2077', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28184, to_date('28-02-2077', 'dd-mm-yyyy'), '7', '28', '059', '02', '2077', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28185, to_date('01-03-2077', 'dd-mm-yyyy'), '1', '01', '060', '03', '2077', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28186, to_date('02-03-2077', 'dd-mm-yyyy'), '2', '02', '061', '03', '2077', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28187, to_date('03-03-2077', 'dd-mm-yyyy'), '3', '03', '062', '03', '2077', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28188, to_date('04-03-2077', 'dd-mm-yyyy'), '4', '04', '063', '03', '2077', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28189, to_date('05-03-2077', 'dd-mm-yyyy'), '5', '05', '064', '03', '2077', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28190, to_date('06-03-2077', 'dd-mm-yyyy'), '6', '06', '065', '03', '2077', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28191, to_date('07-03-2077', 'dd-mm-yyyy'), '7', '07', '066', '03', '2077', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28192, to_date('08-03-2077', 'dd-mm-yyyy'), '1', '08', '067', '03', '2077', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28193, to_date('09-03-2077', 'dd-mm-yyyy'), '2', '09', '068', '03', '2077', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28194, to_date('10-03-2077', 'dd-mm-yyyy'), '3', '10', '069', '03', '2077', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28195, to_date('11-03-2077', 'dd-mm-yyyy'), '4', '11', '070', '03', '2077', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28196, to_date('12-03-2077', 'dd-mm-yyyy'), '5', '12', '071', '03', '2077', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28197, to_date('13-03-2077', 'dd-mm-yyyy'), '6', '13', '072', '03', '2077', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28198, to_date('14-03-2077', 'dd-mm-yyyy'), '7', '14', '073', '03', '2077', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28199, to_date('15-03-2077', 'dd-mm-yyyy'), '1', '15', '074', '03', '2077', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28200, to_date('16-03-2077', 'dd-mm-yyyy'), '2', '16', '075', '03', '2077', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28201, to_date('17-03-2077', 'dd-mm-yyyy'), '3', '17', '076', '03', '2077', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28202, to_date('18-03-2077', 'dd-mm-yyyy'), '4', '18', '077', '03', '2077', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28203, to_date('19-03-2077', 'dd-mm-yyyy'), '5', '19', '078', '03', '2077', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28204, to_date('20-03-2077', 'dd-mm-yyyy'), '6', '20', '079', '03', '2077', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28205, to_date('21-03-2077', 'dd-mm-yyyy'), '7', '21', '080', '03', '2077', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28206, to_date('22-03-2077', 'dd-mm-yyyy'), '1', '22', '081', '03', '2077', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28207, to_date('23-03-2077', 'dd-mm-yyyy'), '2', '23', '082', '03', '2077', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28208, to_date('24-03-2077', 'dd-mm-yyyy'), '3', '24', '083', '03', '2077', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28209, to_date('25-03-2077', 'dd-mm-yyyy'), '4', '25', '084', '03', '2077', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28210, to_date('26-03-2077', 'dd-mm-yyyy'), '5', '26', '085', '03', '2077', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28211, to_date('27-03-2077', 'dd-mm-yyyy'), '6', '27', '086', '03', '2077', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28212, to_date('28-03-2077', 'dd-mm-yyyy'), '7', '28', '087', '03', '2077', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28213, to_date('29-03-2077', 'dd-mm-yyyy'), '1', '29', '088', '03', '2077', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28214, to_date('30-03-2077', 'dd-mm-yyyy'), '2', '30', '089', '03', '2077', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28215, to_date('31-03-2077', 'dd-mm-yyyy'), '3', '31', '090', '03', '2077', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28216, to_date('01-04-2077', 'dd-mm-yyyy'), '4', '01', '091', '04', '2077', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28217, to_date('02-04-2077', 'dd-mm-yyyy'), '5', '02', '092', '04', '2077', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28218, to_date('03-04-2077', 'dd-mm-yyyy'), '6', '03', '093', '04', '2077', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28219, to_date('04-04-2077', 'dd-mm-yyyy'), '7', '04', '094', '04', '2077', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28220, to_date('05-04-2077', 'dd-mm-yyyy'), '1', '05', '095', '04', '2077', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28221, to_date('06-04-2077', 'dd-mm-yyyy'), '2', '06', '096', '04', '2077', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28222, to_date('07-04-2077', 'dd-mm-yyyy'), '3', '07', '097', '04', '2077', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28223, to_date('08-04-2077', 'dd-mm-yyyy'), '4', '08', '098', '04', '2077', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28224, to_date('09-04-2077', 'dd-mm-yyyy'), '5', '09', '099', '04', '2077', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28225, to_date('10-04-2077', 'dd-mm-yyyy'), '6', '10', '100', '04', '2077', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28226, to_date('11-04-2077', 'dd-mm-yyyy'), '7', '11', '101', '04', '2077', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28227, to_date('12-04-2077', 'dd-mm-yyyy'), '1', '12', '102', '04', '2077', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28228, to_date('13-04-2077', 'dd-mm-yyyy'), '2', '13', '103', '04', '2077', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28229, to_date('14-04-2077', 'dd-mm-yyyy'), '3', '14', '104', '04', '2077', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28230, to_date('15-04-2077', 'dd-mm-yyyy'), '4', '15', '105', '04', '2077', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28231, to_date('16-04-2077', 'dd-mm-yyyy'), '5', '16', '106', '04', '2077', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28232, to_date('17-04-2077', 'dd-mm-yyyy'), '6', '17', '107', '04', '2077', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28233, to_date('18-04-2077', 'dd-mm-yyyy'), '7', '18', '108', '04', '2077', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28234, to_date('19-04-2077', 'dd-mm-yyyy'), '1', '19', '109', '04', '2077', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28235, to_date('20-04-2077', 'dd-mm-yyyy'), '2', '20', '110', '04', '2077', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28236, to_date('21-04-2077', 'dd-mm-yyyy'), '3', '21', '111', '04', '2077', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28237, to_date('22-04-2077', 'dd-mm-yyyy'), '4', '22', '112', '04', '2077', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28238, to_date('23-04-2077', 'dd-mm-yyyy'), '5', '23', '113', '04', '2077', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28239, to_date('24-04-2077', 'dd-mm-yyyy'), '6', '24', '114', '04', '2077', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28240, to_date('25-04-2077', 'dd-mm-yyyy'), '7', '25', '115', '04', '2077', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28241, to_date('26-04-2077', 'dd-mm-yyyy'), '1', '26', '116', '04', '2077', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28242, to_date('27-04-2077', 'dd-mm-yyyy'), '2', '27', '117', '04', '2077', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28243, to_date('28-04-2077', 'dd-mm-yyyy'), '3', '28', '118', '04', '2077', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28244, to_date('29-04-2077', 'dd-mm-yyyy'), '4', '29', '119', '04', '2077', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28245, to_date('30-04-2077', 'dd-mm-yyyy'), '5', '30', '120', '04', '2077', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28246, to_date('01-05-2077', 'dd-mm-yyyy'), '6', '01', '121', '05', '2077', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28247, to_date('02-05-2077', 'dd-mm-yyyy'), '7', '02', '122', '05', '2077', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28248, to_date('03-05-2077', 'dd-mm-yyyy'), '1', '03', '123', '05', '2077', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28249, to_date('04-05-2077', 'dd-mm-yyyy'), '2', '04', '124', '05', '2077', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28250, to_date('05-05-2077', 'dd-mm-yyyy'), '3', '05', '125', '05', '2077', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28251, to_date('06-05-2077', 'dd-mm-yyyy'), '4', '06', '126', '05', '2077', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28252, to_date('07-05-2077', 'dd-mm-yyyy'), '5', '07', '127', '05', '2077', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28253, to_date('08-05-2077', 'dd-mm-yyyy'), '6', '08', '128', '05', '2077', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28254, to_date('09-05-2077', 'dd-mm-yyyy'), '7', '09', '129', '05', '2077', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28255, to_date('10-05-2077', 'dd-mm-yyyy'), '1', '10', '130', '05', '2077', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28256, to_date('11-05-2077', 'dd-mm-yyyy'), '2', '11', '131', '05', '2077', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28257, to_date('12-05-2077', 'dd-mm-yyyy'), '3', '12', '132', '05', '2077', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28258, to_date('13-05-2077', 'dd-mm-yyyy'), '4', '13', '133', '05', '2077', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28259, to_date('14-05-2077', 'dd-mm-yyyy'), '5', '14', '134', '05', '2077', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28260, to_date('15-05-2077', 'dd-mm-yyyy'), '6', '15', '135', '05', '2077', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28261, to_date('16-05-2077', 'dd-mm-yyyy'), '7', '16', '136', '05', '2077', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28262, to_date('17-05-2077', 'dd-mm-yyyy'), '1', '17', '137', '05', '2077', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28263, to_date('18-05-2077', 'dd-mm-yyyy'), '2', '18', '138', '05', '2077', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28264, to_date('19-05-2077', 'dd-mm-yyyy'), '3', '19', '139', '05', '2077', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28265, to_date('20-05-2077', 'dd-mm-yyyy'), '4', '20', '140', '05', '2077', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28266, to_date('21-05-2077', 'dd-mm-yyyy'), '5', '21', '141', '05', '2077', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28267, to_date('22-05-2077', 'dd-mm-yyyy'), '6', '22', '142', '05', '2077', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28268, to_date('23-05-2077', 'dd-mm-yyyy'), '7', '23', '143', '05', '2077', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28269, to_date('24-05-2077', 'dd-mm-yyyy'), '1', '24', '144', '05', '2077', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28270, to_date('25-05-2077', 'dd-mm-yyyy'), '2', '25', '145', '05', '2077', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28271, to_date('26-05-2077', 'dd-mm-yyyy'), '3', '26', '146', '05', '2077', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28272, to_date('27-05-2077', 'dd-mm-yyyy'), '4', '27', '147', '05', '2077', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28273, to_date('28-05-2077', 'dd-mm-yyyy'), '5', '28', '148', '05', '2077', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28274, to_date('29-05-2077', 'dd-mm-yyyy'), '6', '29', '149', '05', '2077', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28275, to_date('30-05-2077', 'dd-mm-yyyy'), '7', '30', '150', '05', '2077', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28276, to_date('31-05-2077', 'dd-mm-yyyy'), '1', '31', '151', '05', '2077', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29761, to_date('24-06-2081', 'dd-mm-yyyy'), '2', '24', '175', '06', '2081', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29762, to_date('25-06-2081', 'dd-mm-yyyy'), '3', '25', '176', '06', '2081', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29763, to_date('26-06-2081', 'dd-mm-yyyy'), '4', '26', '177', '06', '2081', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29764, to_date('27-06-2081', 'dd-mm-yyyy'), '5', '27', '178', '06', '2081', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29765, to_date('28-06-2081', 'dd-mm-yyyy'), '6', '28', '179', '06', '2081', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29766, to_date('29-06-2081', 'dd-mm-yyyy'), '7', '29', '180', '06', '2081', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29767, to_date('30-06-2081', 'dd-mm-yyyy'), '1', '30', '181', '06', '2081', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29768, to_date('01-07-2081', 'dd-mm-yyyy'), '2', '01', '182', '07', '2081', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29769, to_date('02-07-2081', 'dd-mm-yyyy'), '3', '02', '183', '07', '2081', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29770, to_date('03-07-2081', 'dd-mm-yyyy'), '4', '03', '184', '07', '2081', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29771, to_date('04-07-2081', 'dd-mm-yyyy'), '5', '04', '185', '07', '2081', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29772, to_date('05-07-2081', 'dd-mm-yyyy'), '6', '05', '186', '07', '2081', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29773, to_date('06-07-2081', 'dd-mm-yyyy'), '7', '06', '187', '07', '2081', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29774, to_date('07-07-2081', 'dd-mm-yyyy'), '1', '07', '188', '07', '2081', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29775, to_date('08-07-2081', 'dd-mm-yyyy'), '2', '08', '189', '07', '2081', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29776, to_date('09-07-2081', 'dd-mm-yyyy'), '3', '09', '190', '07', '2081', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29777, to_date('10-07-2081', 'dd-mm-yyyy'), '4', '10', '191', '07', '2081', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29778, to_date('11-07-2081', 'dd-mm-yyyy'), '5', '11', '192', '07', '2081', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29779, to_date('12-07-2081', 'dd-mm-yyyy'), '6', '12', '193', '07', '2081', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29780, to_date('13-07-2081', 'dd-mm-yyyy'), '7', '13', '194', '07', '2081', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29781, to_date('14-07-2081', 'dd-mm-yyyy'), '1', '14', '195', '07', '2081', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29782, to_date('15-07-2081', 'dd-mm-yyyy'), '2', '15', '196', '07', '2081', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29783, to_date('16-07-2081', 'dd-mm-yyyy'), '3', '16', '197', '07', '2081', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29784, to_date('17-07-2081', 'dd-mm-yyyy'), '4', '17', '198', '07', '2081', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29785, to_date('18-07-2081', 'dd-mm-yyyy'), '5', '18', '199', '07', '2081', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29786, to_date('19-07-2081', 'dd-mm-yyyy'), '6', '19', '200', '07', '2081', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29787, to_date('20-07-2081', 'dd-mm-yyyy'), '7', '20', '201', '07', '2081', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29788, to_date('21-07-2081', 'dd-mm-yyyy'), '1', '21', '202', '07', '2081', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29789, to_date('22-07-2081', 'dd-mm-yyyy'), '2', '22', '203', '07', '2081', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29790, to_date('23-07-2081', 'dd-mm-yyyy'), '3', '23', '204', '07', '2081', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29791, to_date('24-07-2081', 'dd-mm-yyyy'), '4', '24', '205', '07', '2081', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29792, to_date('25-07-2081', 'dd-mm-yyyy'), '5', '25', '206', '07', '2081', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29793, to_date('26-07-2081', 'dd-mm-yyyy'), '6', '26', '207', '07', '2081', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29794, to_date('27-07-2081', 'dd-mm-yyyy'), '7', '27', '208', '07', '2081', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29795, to_date('28-07-2081', 'dd-mm-yyyy'), '1', '28', '209', '07', '2081', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29796, to_date('29-07-2081', 'dd-mm-yyyy'), '2', '29', '210', '07', '2081', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29797, to_date('30-07-2081', 'dd-mm-yyyy'), '3', '30', '211', '07', '2081', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29798, to_date('31-07-2081', 'dd-mm-yyyy'), '4', '31', '212', '07', '2081', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29799, to_date('01-08-2081', 'dd-mm-yyyy'), '5', '01', '213', '08', '2081', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29800, to_date('02-08-2081', 'dd-mm-yyyy'), '6', '02', '214', '08', '2081', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29801, to_date('03-08-2081', 'dd-mm-yyyy'), '7', '03', '215', '08', '2081', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29802, to_date('04-08-2081', 'dd-mm-yyyy'), '1', '04', '216', '08', '2081', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29803, to_date('05-08-2081', 'dd-mm-yyyy'), '2', '05', '217', '08', '2081', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29804, to_date('06-08-2081', 'dd-mm-yyyy'), '3', '06', '218', '08', '2081', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29805, to_date('07-08-2081', 'dd-mm-yyyy'), '4', '07', '219', '08', '2081', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29806, to_date('08-08-2081', 'dd-mm-yyyy'), '5', '08', '220', '08', '2081', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29807, to_date('09-08-2081', 'dd-mm-yyyy'), '6', '09', '221', '08', '2081', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29808, to_date('10-08-2081', 'dd-mm-yyyy'), '7', '10', '222', '08', '2081', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29809, to_date('11-08-2081', 'dd-mm-yyyy'), '1', '11', '223', '08', '2081', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29810, to_date('12-08-2081', 'dd-mm-yyyy'), '2', '12', '224', '08', '2081', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29811, to_date('13-08-2081', 'dd-mm-yyyy'), '3', '13', '225', '08', '2081', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29812, to_date('14-08-2081', 'dd-mm-yyyy'), '4', '14', '226', '08', '2081', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29813, to_date('15-08-2081', 'dd-mm-yyyy'), '5', '15', '227', '08', '2081', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29814, to_date('16-08-2081', 'dd-mm-yyyy'), '6', '16', '228', '08', '2081', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29815, to_date('17-08-2081', 'dd-mm-yyyy'), '7', '17', '229', '08', '2081', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29816, to_date('18-08-2081', 'dd-mm-yyyy'), '1', '18', '230', '08', '2081', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29817, to_date('19-08-2081', 'dd-mm-yyyy'), '2', '19', '231', '08', '2081', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29818, to_date('20-08-2081', 'dd-mm-yyyy'), '3', '20', '232', '08', '2081', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29819, to_date('21-08-2081', 'dd-mm-yyyy'), '4', '21', '233', '08', '2081', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29820, to_date('22-08-2081', 'dd-mm-yyyy'), '5', '22', '234', '08', '2081', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29821, to_date('23-08-2081', 'dd-mm-yyyy'), '6', '23', '235', '08', '2081', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29822, to_date('24-08-2081', 'dd-mm-yyyy'), '7', '24', '236', '08', '2081', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29823, to_date('25-08-2081', 'dd-mm-yyyy'), '1', '25', '237', '08', '2081', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29824, to_date('26-08-2081', 'dd-mm-yyyy'), '2', '26', '238', '08', '2081', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29825, to_date('27-08-2081', 'dd-mm-yyyy'), '3', '27', '239', '08', '2081', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29826, to_date('28-08-2081', 'dd-mm-yyyy'), '4', '28', '240', '08', '2081', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29827, to_date('29-08-2081', 'dd-mm-yyyy'), '5', '29', '241', '08', '2081', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29828, to_date('30-08-2081', 'dd-mm-yyyy'), '6', '30', '242', '08', '2081', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29829, to_date('31-08-2081', 'dd-mm-yyyy'), '7', '31', '243', '08', '2081', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29830, to_date('01-09-2081', 'dd-mm-yyyy'), '1', '01', '244', '09', '2081', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29831, to_date('02-09-2081', 'dd-mm-yyyy'), '2', '02', '245', '09', '2081', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29832, to_date('03-09-2081', 'dd-mm-yyyy'), '3', '03', '246', '09', '2081', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29833, to_date('04-09-2081', 'dd-mm-yyyy'), '4', '04', '247', '09', '2081', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29834, to_date('05-09-2081', 'dd-mm-yyyy'), '5', '05', '248', '09', '2081', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29835, to_date('06-09-2081', 'dd-mm-yyyy'), '6', '06', '249', '09', '2081', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29836, to_date('07-09-2081', 'dd-mm-yyyy'), '7', '07', '250', '09', '2081', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29837, to_date('08-09-2081', 'dd-mm-yyyy'), '1', '08', '251', '09', '2081', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29838, to_date('09-09-2081', 'dd-mm-yyyy'), '2', '09', '252', '09', '2081', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29839, to_date('10-09-2081', 'dd-mm-yyyy'), '3', '10', '253', '09', '2081', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29840, to_date('11-09-2081', 'dd-mm-yyyy'), '4', '11', '254', '09', '2081', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29841, to_date('12-09-2081', 'dd-mm-yyyy'), '5', '12', '255', '09', '2081', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29842, to_date('13-09-2081', 'dd-mm-yyyy'), '6', '13', '256', '09', '2081', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29843, to_date('14-09-2081', 'dd-mm-yyyy'), '7', '14', '257', '09', '2081', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29844, to_date('15-09-2081', 'dd-mm-yyyy'), '1', '15', '258', '09', '2081', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29845, to_date('16-09-2081', 'dd-mm-yyyy'), '2', '16', '259', '09', '2081', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29846, to_date('17-09-2081', 'dd-mm-yyyy'), '3', '17', '260', '09', '2081', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29847, to_date('18-09-2081', 'dd-mm-yyyy'), '4', '18', '261', '09', '2081', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29848, to_date('19-09-2081', 'dd-mm-yyyy'), '5', '19', '262', '09', '2081', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29849, to_date('20-09-2081', 'dd-mm-yyyy'), '6', '20', '263', '09', '2081', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29850, to_date('21-09-2081', 'dd-mm-yyyy'), '7', '21', '264', '09', '2081', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29851, to_date('22-09-2081', 'dd-mm-yyyy'), '1', '22', '265', '09', '2081', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29852, to_date('23-09-2081', 'dd-mm-yyyy'), '2', '23', '266', '09', '2081', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29853, to_date('24-09-2081', 'dd-mm-yyyy'), '3', '24', '267', '09', '2081', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29854, to_date('25-09-2081', 'dd-mm-yyyy'), '4', '25', '268', '09', '2081', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29855, to_date('26-09-2081', 'dd-mm-yyyy'), '5', '26', '269', '09', '2081', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29856, to_date('27-09-2081', 'dd-mm-yyyy'), '6', '27', '270', '09', '2081', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29857, to_date('28-09-2081', 'dd-mm-yyyy'), '7', '28', '271', '09', '2081', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29858, to_date('29-09-2081', 'dd-mm-yyyy'), '1', '29', '272', '09', '2081', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29859, to_date('30-09-2081', 'dd-mm-yyyy'), '2', '30', '273', '09', '2081', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29860, to_date('01-10-2081', 'dd-mm-yyyy'), '3', '01', '274', '10', '2081', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29861, to_date('02-10-2081', 'dd-mm-yyyy'), '4', '02', '275', '10', '2081', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29862, to_date('03-10-2081', 'dd-mm-yyyy'), '5', '03', '276', '10', '2081', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29863, to_date('04-10-2081', 'dd-mm-yyyy'), '6', '04', '277', '10', '2081', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29864, to_date('05-10-2081', 'dd-mm-yyyy'), '7', '05', '278', '10', '2081', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29865, to_date('06-10-2081', 'dd-mm-yyyy'), '1', '06', '279', '10', '2081', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29866, to_date('07-10-2081', 'dd-mm-yyyy'), '2', '07', '280', '10', '2081', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31351, to_date('31-10-2085', 'dd-mm-yyyy'), '3', '31', '304', '10', '2085', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31352, to_date('01-11-2085', 'dd-mm-yyyy'), '4', '01', '305', '11', '2085', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31353, to_date('02-11-2085', 'dd-mm-yyyy'), '5', '02', '306', '11', '2085', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31354, to_date('03-11-2085', 'dd-mm-yyyy'), '6', '03', '307', '11', '2085', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31355, to_date('04-11-2085', 'dd-mm-yyyy'), '7', '04', '308', '11', '2085', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31356, to_date('05-11-2085', 'dd-mm-yyyy'), '1', '05', '309', '11', '2085', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31357, to_date('06-11-2085', 'dd-mm-yyyy'), '2', '06', '310', '11', '2085', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31358, to_date('07-11-2085', 'dd-mm-yyyy'), '3', '07', '311', '11', '2085', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31359, to_date('08-11-2085', 'dd-mm-yyyy'), '4', '08', '312', '11', '2085', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31360, to_date('09-11-2085', 'dd-mm-yyyy'), '5', '09', '313', '11', '2085', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31361, to_date('10-11-2085', 'dd-mm-yyyy'), '6', '10', '314', '11', '2085', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31362, to_date('11-11-2085', 'dd-mm-yyyy'), '7', '11', '315', '11', '2085', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31363, to_date('12-11-2085', 'dd-mm-yyyy'), '1', '12', '316', '11', '2085', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31364, to_date('13-11-2085', 'dd-mm-yyyy'), '2', '13', '317', '11', '2085', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31365, to_date('14-11-2085', 'dd-mm-yyyy'), '3', '14', '318', '11', '2085', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31366, to_date('15-11-2085', 'dd-mm-yyyy'), '4', '15', '319', '11', '2085', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31367, to_date('16-11-2085', 'dd-mm-yyyy'), '5', '16', '320', '11', '2085', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31368, to_date('17-11-2085', 'dd-mm-yyyy'), '6', '17', '321', '11', '2085', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31369, to_date('18-11-2085', 'dd-mm-yyyy'), '7', '18', '322', '11', '2085', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31370, to_date('19-11-2085', 'dd-mm-yyyy'), '1', '19', '323', '11', '2085', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31371, to_date('20-11-2085', 'dd-mm-yyyy'), '2', '20', '324', '11', '2085', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31372, to_date('21-11-2085', 'dd-mm-yyyy'), '3', '21', '325', '11', '2085', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31373, to_date('22-11-2085', 'dd-mm-yyyy'), '4', '22', '326', '11', '2085', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31374, to_date('23-11-2085', 'dd-mm-yyyy'), '5', '23', '327', '11', '2085', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31375, to_date('24-11-2085', 'dd-mm-yyyy'), '6', '24', '328', '11', '2085', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31376, to_date('25-11-2085', 'dd-mm-yyyy'), '7', '25', '329', '11', '2085', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31377, to_date('26-11-2085', 'dd-mm-yyyy'), '1', '26', '330', '11', '2085', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31378, to_date('27-11-2085', 'dd-mm-yyyy'), '2', '27', '331', '11', '2085', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31379, to_date('28-11-2085', 'dd-mm-yyyy'), '3', '28', '332', '11', '2085', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31380, to_date('29-11-2085', 'dd-mm-yyyy'), '4', '29', '333', '11', '2085', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31381, to_date('30-11-2085', 'dd-mm-yyyy'), '5', '30', '334', '11', '2085', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31382, to_date('01-12-2085', 'dd-mm-yyyy'), '6', '01', '335', '12', '2085', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31383, to_date('02-12-2085', 'dd-mm-yyyy'), '7', '02', '336', '12', '2085', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31384, to_date('03-12-2085', 'dd-mm-yyyy'), '1', '03', '337', '12', '2085', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31385, to_date('04-12-2085', 'dd-mm-yyyy'), '2', '04', '338', '12', '2085', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31386, to_date('05-12-2085', 'dd-mm-yyyy'), '3', '05', '339', '12', '2085', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31387, to_date('06-12-2085', 'dd-mm-yyyy'), '4', '06', '340', '12', '2085', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31388, to_date('07-12-2085', 'dd-mm-yyyy'), '5', '07', '341', '12', '2085', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31389, to_date('08-12-2085', 'dd-mm-yyyy'), '6', '08', '342', '12', '2085', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31390, to_date('09-12-2085', 'dd-mm-yyyy'), '7', '09', '343', '12', '2085', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31391, to_date('10-12-2085', 'dd-mm-yyyy'), '1', '10', '344', '12', '2085', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31392, to_date('11-12-2085', 'dd-mm-yyyy'), '2', '11', '345', '12', '2085', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31393, to_date('12-12-2085', 'dd-mm-yyyy'), '3', '12', '346', '12', '2085', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31394, to_date('13-12-2085', 'dd-mm-yyyy'), '4', '13', '347', '12', '2085', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31395, to_date('14-12-2085', 'dd-mm-yyyy'), '5', '14', '348', '12', '2085', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31396, to_date('15-12-2085', 'dd-mm-yyyy'), '6', '15', '349', '12', '2085', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31397, to_date('16-12-2085', 'dd-mm-yyyy'), '7', '16', '350', '12', '2085', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31398, to_date('17-12-2085', 'dd-mm-yyyy'), '1', '17', '351', '12', '2085', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31399, to_date('18-12-2085', 'dd-mm-yyyy'), '2', '18', '352', '12', '2085', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31400, to_date('19-12-2085', 'dd-mm-yyyy'), '3', '19', '353', '12', '2085', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31401, to_date('20-12-2085', 'dd-mm-yyyy'), '4', '20', '354', '12', '2085', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31402, to_date('21-12-2085', 'dd-mm-yyyy'), '5', '21', '355', '12', '2085', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31403, to_date('22-12-2085', 'dd-mm-yyyy'), '6', '22', '356', '12', '2085', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31404, to_date('23-12-2085', 'dd-mm-yyyy'), '7', '23', '357', '12', '2085', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31405, to_date('24-12-2085', 'dd-mm-yyyy'), '1', '24', '358', '12', '2085', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31406, to_date('25-12-2085', 'dd-mm-yyyy'), '2', '25', '359', '12', '2085', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31407, to_date('26-12-2085', 'dd-mm-yyyy'), '3', '26', '360', '12', '2085', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31408, to_date('27-12-2085', 'dd-mm-yyyy'), '4', '27', '361', '12', '2085', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31409, to_date('28-12-2085', 'dd-mm-yyyy'), '5', '28', '362', '12', '2085', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31410, to_date('29-12-2085', 'dd-mm-yyyy'), '6', '29', '363', '12', '2085', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31411, to_date('30-12-2085', 'dd-mm-yyyy'), '7', '30', '364', '12', '2085', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31412, to_date('31-12-2085', 'dd-mm-yyyy'), '1', '31', '365', '12', '2085', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31413, to_date('01-01-2086', 'dd-mm-yyyy'), '2', '01', '001', '01', '2086', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31414, to_date('02-01-2086', 'dd-mm-yyyy'), '3', '02', '002', '01', '2086', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31415, to_date('03-01-2086', 'dd-mm-yyyy'), '4', '03', '003', '01', '2086', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31416, to_date('04-01-2086', 'dd-mm-yyyy'), '5', '04', '004', '01', '2086', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31417, to_date('05-01-2086', 'dd-mm-yyyy'), '6', '05', '005', '01', '2086', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31418, to_date('06-01-2086', 'dd-mm-yyyy'), '7', '06', '006', '01', '2086', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31419, to_date('07-01-2086', 'dd-mm-yyyy'), '1', '07', '007', '01', '2086', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31420, to_date('08-01-2086', 'dd-mm-yyyy'), '2', '08', '008', '01', '2086', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31421, to_date('09-01-2086', 'dd-mm-yyyy'), '3', '09', '009', '01', '2086', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31422, to_date('10-01-2086', 'dd-mm-yyyy'), '4', '10', '010', '01', '2086', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31423, to_date('11-01-2086', 'dd-mm-yyyy'), '5', '11', '011', '01', '2086', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31424, to_date('12-01-2086', 'dd-mm-yyyy'), '6', '12', '012', '01', '2086', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31425, to_date('13-01-2086', 'dd-mm-yyyy'), '7', '13', '013', '01', '2086', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31426, to_date('14-01-2086', 'dd-mm-yyyy'), '1', '14', '014', '01', '2086', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31427, to_date('15-01-2086', 'dd-mm-yyyy'), '2', '15', '015', '01', '2086', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31428, to_date('16-01-2086', 'dd-mm-yyyy'), '3', '16', '016', '01', '2086', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31429, to_date('17-01-2086', 'dd-mm-yyyy'), '4', '17', '017', '01', '2086', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31430, to_date('18-01-2086', 'dd-mm-yyyy'), '5', '18', '018', '01', '2086', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31431, to_date('19-01-2086', 'dd-mm-yyyy'), '6', '19', '019', '01', '2086', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31432, to_date('20-01-2086', 'dd-mm-yyyy'), '7', '20', '020', '01', '2086', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31433, to_date('21-01-2086', 'dd-mm-yyyy'), '1', '21', '021', '01', '2086', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31434, to_date('22-01-2086', 'dd-mm-yyyy'), '2', '22', '022', '01', '2086', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31435, to_date('23-01-2086', 'dd-mm-yyyy'), '3', '23', '023', '01', '2086', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31436, to_date('24-01-2086', 'dd-mm-yyyy'), '4', '24', '024', '01', '2086', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31437, to_date('25-01-2086', 'dd-mm-yyyy'), '5', '25', '025', '01', '2086', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31438, to_date('26-01-2086', 'dd-mm-yyyy'), '6', '26', '026', '01', '2086', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31439, to_date('27-01-2086', 'dd-mm-yyyy'), '7', '27', '027', '01', '2086', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31440, to_date('28-01-2086', 'dd-mm-yyyy'), '1', '28', '028', '01', '2086', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31441, to_date('29-01-2086', 'dd-mm-yyyy'), '2', '29', '029', '01', '2086', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31442, to_date('30-01-2086', 'dd-mm-yyyy'), '3', '30', '030', '01', '2086', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31443, to_date('31-01-2086', 'dd-mm-yyyy'), '4', '31', '031', '01', '2086', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31444, to_date('01-02-2086', 'dd-mm-yyyy'), '5', '01', '032', '02', '2086', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31445, to_date('02-02-2086', 'dd-mm-yyyy'), '6', '02', '033', '02', '2086', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31446, to_date('03-02-2086', 'dd-mm-yyyy'), '7', '03', '034', '02', '2086', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31447, to_date('04-02-2086', 'dd-mm-yyyy'), '1', '04', '035', '02', '2086', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31448, to_date('05-02-2086', 'dd-mm-yyyy'), '2', '05', '036', '02', '2086', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31449, to_date('06-02-2086', 'dd-mm-yyyy'), '3', '06', '037', '02', '2086', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31450, to_date('07-02-2086', 'dd-mm-yyyy'), '4', '07', '038', '02', '2086', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31451, to_date('08-02-2086', 'dd-mm-yyyy'), '5', '08', '039', '02', '2086', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31452, to_date('09-02-2086', 'dd-mm-yyyy'), '6', '09', '040', '02', '2086', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31453, to_date('10-02-2086', 'dd-mm-yyyy'), '7', '10', '041', '02', '2086', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31454, to_date('11-02-2086', 'dd-mm-yyyy'), '1', '11', '042', '02', '2086', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31455, to_date('12-02-2086', 'dd-mm-yyyy'), '2', '12', '043', '02', '2086', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31456, to_date('13-02-2086', 'dd-mm-yyyy'), '3', '13', '044', '02', '2086', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26581, to_date('09-10-2072', 'dd-mm-yyyy'), '7', '09', '283', '10', '2072', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26582, to_date('10-10-2072', 'dd-mm-yyyy'), '1', '10', '284', '10', '2072', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26583, to_date('11-10-2072', 'dd-mm-yyyy'), '2', '11', '285', '10', '2072', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26584, to_date('12-10-2072', 'dd-mm-yyyy'), '3', '12', '286', '10', '2072', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26585, to_date('13-10-2072', 'dd-mm-yyyy'), '4', '13', '287', '10', '2072', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26586, to_date('14-10-2072', 'dd-mm-yyyy'), '5', '14', '288', '10', '2072', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26587, to_date('15-10-2072', 'dd-mm-yyyy'), '6', '15', '289', '10', '2072', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26588, to_date('16-10-2072', 'dd-mm-yyyy'), '7', '16', '290', '10', '2072', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26589, to_date('17-10-2072', 'dd-mm-yyyy'), '1', '17', '291', '10', '2072', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26590, to_date('18-10-2072', 'dd-mm-yyyy'), '2', '18', '292', '10', '2072', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26591, to_date('19-10-2072', 'dd-mm-yyyy'), '3', '19', '293', '10', '2072', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26592, to_date('20-10-2072', 'dd-mm-yyyy'), '4', '20', '294', '10', '2072', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26593, to_date('21-10-2072', 'dd-mm-yyyy'), '5', '21', '295', '10', '2072', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26594, to_date('22-10-2072', 'dd-mm-yyyy'), '6', '22', '296', '10', '2072', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26595, to_date('23-10-2072', 'dd-mm-yyyy'), '7', '23', '297', '10', '2072', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26596, to_date('24-10-2072', 'dd-mm-yyyy'), '1', '24', '298', '10', '2072', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26597, to_date('25-10-2072', 'dd-mm-yyyy'), '2', '25', '299', '10', '2072', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26598, to_date('26-10-2072', 'dd-mm-yyyy'), '3', '26', '300', '10', '2072', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26599, to_date('27-10-2072', 'dd-mm-yyyy'), '4', '27', '301', '10', '2072', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26600, to_date('28-10-2072', 'dd-mm-yyyy'), '5', '28', '302', '10', '2072', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26601, to_date('29-10-2072', 'dd-mm-yyyy'), '6', '29', '303', '10', '2072', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26602, to_date('30-10-2072', 'dd-mm-yyyy'), '7', '30', '304', '10', '2072', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26603, to_date('31-10-2072', 'dd-mm-yyyy'), '1', '31', '305', '10', '2072', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26604, to_date('01-11-2072', 'dd-mm-yyyy'), '2', '01', '306', '11', '2072', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26605, to_date('02-11-2072', 'dd-mm-yyyy'), '3', '02', '307', '11', '2072', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26606, to_date('03-11-2072', 'dd-mm-yyyy'), '4', '03', '308', '11', '2072', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26607, to_date('04-11-2072', 'dd-mm-yyyy'), '5', '04', '309', '11', '2072', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26608, to_date('05-11-2072', 'dd-mm-yyyy'), '6', '05', '310', '11', '2072', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26609, to_date('06-11-2072', 'dd-mm-yyyy'), '7', '06', '311', '11', '2072', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26610, to_date('07-11-2072', 'dd-mm-yyyy'), '1', '07', '312', '11', '2072', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26611, to_date('08-11-2072', 'dd-mm-yyyy'), '2', '08', '313', '11', '2072', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26612, to_date('09-11-2072', 'dd-mm-yyyy'), '3', '09', '314', '11', '2072', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26613, to_date('10-11-2072', 'dd-mm-yyyy'), '4', '10', '315', '11', '2072', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26614, to_date('11-11-2072', 'dd-mm-yyyy'), '5', '11', '316', '11', '2072', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26615, to_date('12-11-2072', 'dd-mm-yyyy'), '6', '12', '317', '11', '2072', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26616, to_date('13-11-2072', 'dd-mm-yyyy'), '7', '13', '318', '11', '2072', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26617, to_date('14-11-2072', 'dd-mm-yyyy'), '1', '14', '319', '11', '2072', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26618, to_date('15-11-2072', 'dd-mm-yyyy'), '2', '15', '320', '11', '2072', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26619, to_date('16-11-2072', 'dd-mm-yyyy'), '3', '16', '321', '11', '2072', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26620, to_date('17-11-2072', 'dd-mm-yyyy'), '4', '17', '322', '11', '2072', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26621, to_date('18-11-2072', 'dd-mm-yyyy'), '5', '18', '323', '11', '2072', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26622, to_date('19-11-2072', 'dd-mm-yyyy'), '6', '19', '324', '11', '2072', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26623, to_date('20-11-2072', 'dd-mm-yyyy'), '7', '20', '325', '11', '2072', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26624, to_date('21-11-2072', 'dd-mm-yyyy'), '1', '21', '326', '11', '2072', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26625, to_date('22-11-2072', 'dd-mm-yyyy'), '2', '22', '327', '11', '2072', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26626, to_date('23-11-2072', 'dd-mm-yyyy'), '3', '23', '328', '11', '2072', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26627, to_date('24-11-2072', 'dd-mm-yyyy'), '4', '24', '329', '11', '2072', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26628, to_date('25-11-2072', 'dd-mm-yyyy'), '5', '25', '330', '11', '2072', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26629, to_date('26-11-2072', 'dd-mm-yyyy'), '6', '26', '331', '11', '2072', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26630, to_date('27-11-2072', 'dd-mm-yyyy'), '7', '27', '332', '11', '2072', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26631, to_date('28-11-2072', 'dd-mm-yyyy'), '1', '28', '333', '11', '2072', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26632, to_date('29-11-2072', 'dd-mm-yyyy'), '2', '29', '334', '11', '2072', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26633, to_date('30-11-2072', 'dd-mm-yyyy'), '3', '30', '335', '11', '2072', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26634, to_date('01-12-2072', 'dd-mm-yyyy'), '4', '01', '336', '12', '2072', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26635, to_date('02-12-2072', 'dd-mm-yyyy'), '5', '02', '337', '12', '2072', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26636, to_date('03-12-2072', 'dd-mm-yyyy'), '6', '03', '338', '12', '2072', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26637, to_date('04-12-2072', 'dd-mm-yyyy'), '7', '04', '339', '12', '2072', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26638, to_date('05-12-2072', 'dd-mm-yyyy'), '1', '05', '340', '12', '2072', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26639, to_date('06-12-2072', 'dd-mm-yyyy'), '2', '06', '341', '12', '2072', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26640, to_date('07-12-2072', 'dd-mm-yyyy'), '3', '07', '342', '12', '2072', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26641, to_date('08-12-2072', 'dd-mm-yyyy'), '4', '08', '343', '12', '2072', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26642, to_date('09-12-2072', 'dd-mm-yyyy'), '5', '09', '344', '12', '2072', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26643, to_date('10-12-2072', 'dd-mm-yyyy'), '6', '10', '345', '12', '2072', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26644, to_date('11-12-2072', 'dd-mm-yyyy'), '7', '11', '346', '12', '2072', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26645, to_date('12-12-2072', 'dd-mm-yyyy'), '1', '12', '347', '12', '2072', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26646, to_date('13-12-2072', 'dd-mm-yyyy'), '2', '13', '348', '12', '2072', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26647, to_date('14-12-2072', 'dd-mm-yyyy'), '3', '14', '349', '12', '2072', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26648, to_date('15-12-2072', 'dd-mm-yyyy'), '4', '15', '350', '12', '2072', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26649, to_date('16-12-2072', 'dd-mm-yyyy'), '5', '16', '351', '12', '2072', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26650, to_date('17-12-2072', 'dd-mm-yyyy'), '6', '17', '352', '12', '2072', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26651, to_date('18-12-2072', 'dd-mm-yyyy'), '7', '18', '353', '12', '2072', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26652, to_date('19-12-2072', 'dd-mm-yyyy'), '1', '19', '354', '12', '2072', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26653, to_date('20-12-2072', 'dd-mm-yyyy'), '2', '20', '355', '12', '2072', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26654, to_date('21-12-2072', 'dd-mm-yyyy'), '3', '21', '356', '12', '2072', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26655, to_date('22-12-2072', 'dd-mm-yyyy'), '4', '22', '357', '12', '2072', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26656, to_date('23-12-2072', 'dd-mm-yyyy'), '5', '23', '358', '12', '2072', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26657, to_date('24-12-2072', 'dd-mm-yyyy'), '6', '24', '359', '12', '2072', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26658, to_date('25-12-2072', 'dd-mm-yyyy'), '7', '25', '360', '12', '2072', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26659, to_date('26-12-2072', 'dd-mm-yyyy'), '1', '26', '361', '12', '2072', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26660, to_date('27-12-2072', 'dd-mm-yyyy'), '2', '27', '362', '12', '2072', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26661, to_date('28-12-2072', 'dd-mm-yyyy'), '3', '28', '363', '12', '2072', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26662, to_date('29-12-2072', 'dd-mm-yyyy'), '4', '29', '364', '12', '2072', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26663, to_date('30-12-2072', 'dd-mm-yyyy'), '5', '30', '365', '12', '2072', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26664, to_date('31-12-2072', 'dd-mm-yyyy'), '6', '31', '366', '12', '2072', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26665, to_date('01-01-2073', 'dd-mm-yyyy'), '7', '01', '001', '01', '2073', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26666, to_date('02-01-2073', 'dd-mm-yyyy'), '1', '02', '002', '01', '2073', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26667, to_date('03-01-2073', 'dd-mm-yyyy'), '2', '03', '003', '01', '2073', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26668, to_date('04-01-2073', 'dd-mm-yyyy'), '3', '04', '004', '01', '2073', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26669, to_date('05-01-2073', 'dd-mm-yyyy'), '4', '05', '005', '01', '2073', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26670, to_date('06-01-2073', 'dd-mm-yyyy'), '5', '06', '006', '01', '2073', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26671, to_date('07-01-2073', 'dd-mm-yyyy'), '6', '07', '007', '01', '2073', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26672, to_date('08-01-2073', 'dd-mm-yyyy'), '7', '08', '008', '01', '2073', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26673, to_date('09-01-2073', 'dd-mm-yyyy'), '1', '09', '009', '01', '2073', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26674, to_date('10-01-2073', 'dd-mm-yyyy'), '2', '10', '010', '01', '2073', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26675, to_date('11-01-2073', 'dd-mm-yyyy'), '3', '11', '011', '01', '2073', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26676, to_date('12-01-2073', 'dd-mm-yyyy'), '4', '12', '012', '01', '2073', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26677, to_date('13-01-2073', 'dd-mm-yyyy'), '5', '13', '013', '01', '2073', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26678, to_date('14-01-2073', 'dd-mm-yyyy'), '6', '14', '014', '01', '2073', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26679, to_date('15-01-2073', 'dd-mm-yyyy'), '7', '15', '015', '01', '2073', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26680, to_date('16-01-2073', 'dd-mm-yyyy'), '1', '16', '016', '01', '2073', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26681, to_date('17-01-2073', 'dd-mm-yyyy'), '2', '17', '017', '01', '2073', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26682, to_date('18-01-2073', 'dd-mm-yyyy'), '3', '18', '018', '01', '2073', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26683, to_date('19-01-2073', 'dd-mm-yyyy'), '4', '19', '019', '01', '2073', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26684, to_date('20-01-2073', 'dd-mm-yyyy'), '5', '20', '020', '01', '2073', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26685, to_date('21-01-2073', 'dd-mm-yyyy'), '6', '21', '021', '01', '2073', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26686, to_date('22-01-2073', 'dd-mm-yyyy'), '7', '22', '022', '01', '2073', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28277, to_date('01-06-2077', 'dd-mm-yyyy'), '2', '01', '152', '06', '2077', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28278, to_date('02-06-2077', 'dd-mm-yyyy'), '3', '02', '153', '06', '2077', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28279, to_date('03-06-2077', 'dd-mm-yyyy'), '4', '03', '154', '06', '2077', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28280, to_date('04-06-2077', 'dd-mm-yyyy'), '5', '04', '155', '06', '2077', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28281, to_date('05-06-2077', 'dd-mm-yyyy'), '6', '05', '156', '06', '2077', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28282, to_date('06-06-2077', 'dd-mm-yyyy'), '7', '06', '157', '06', '2077', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28283, to_date('07-06-2077', 'dd-mm-yyyy'), '1', '07', '158', '06', '2077', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28284, to_date('08-06-2077', 'dd-mm-yyyy'), '2', '08', '159', '06', '2077', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28285, to_date('09-06-2077', 'dd-mm-yyyy'), '3', '09', '160', '06', '2077', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28286, to_date('10-06-2077', 'dd-mm-yyyy'), '4', '10', '161', '06', '2077', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28287, to_date('11-06-2077', 'dd-mm-yyyy'), '5', '11', '162', '06', '2077', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28288, to_date('12-06-2077', 'dd-mm-yyyy'), '6', '12', '163', '06', '2077', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28289, to_date('13-06-2077', 'dd-mm-yyyy'), '7', '13', '164', '06', '2077', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28290, to_date('14-06-2077', 'dd-mm-yyyy'), '1', '14', '165', '06', '2077', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28291, to_date('15-06-2077', 'dd-mm-yyyy'), '2', '15', '166', '06', '2077', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28292, to_date('16-06-2077', 'dd-mm-yyyy'), '3', '16', '167', '06', '2077', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28293, to_date('17-06-2077', 'dd-mm-yyyy'), '4', '17', '168', '06', '2077', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28294, to_date('18-06-2077', 'dd-mm-yyyy'), '5', '18', '169', '06', '2077', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28295, to_date('19-06-2077', 'dd-mm-yyyy'), '6', '19', '170', '06', '2077', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28296, to_date('20-06-2077', 'dd-mm-yyyy'), '7', '20', '171', '06', '2077', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28297, to_date('21-06-2077', 'dd-mm-yyyy'), '1', '21', '172', '06', '2077', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28298, to_date('22-06-2077', 'dd-mm-yyyy'), '2', '22', '173', '06', '2077', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28299, to_date('23-06-2077', 'dd-mm-yyyy'), '3', '23', '174', '06', '2077', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28300, to_date('24-06-2077', 'dd-mm-yyyy'), '4', '24', '175', '06', '2077', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28301, to_date('25-06-2077', 'dd-mm-yyyy'), '5', '25', '176', '06', '2077', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28302, to_date('26-06-2077', 'dd-mm-yyyy'), '6', '26', '177', '06', '2077', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28303, to_date('27-06-2077', 'dd-mm-yyyy'), '7', '27', '178', '06', '2077', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28304, to_date('28-06-2077', 'dd-mm-yyyy'), '1', '28', '179', '06', '2077', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28305, to_date('29-06-2077', 'dd-mm-yyyy'), '2', '29', '180', '06', '2077', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28306, to_date('30-06-2077', 'dd-mm-yyyy'), '3', '30', '181', '06', '2077', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28307, to_date('01-07-2077', 'dd-mm-yyyy'), '4', '01', '182', '07', '2077', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28308, to_date('02-07-2077', 'dd-mm-yyyy'), '5', '02', '183', '07', '2077', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28309, to_date('03-07-2077', 'dd-mm-yyyy'), '6', '03', '184', '07', '2077', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28310, to_date('04-07-2077', 'dd-mm-yyyy'), '7', '04', '185', '07', '2077', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28311, to_date('05-07-2077', 'dd-mm-yyyy'), '1', '05', '186', '07', '2077', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28312, to_date('06-07-2077', 'dd-mm-yyyy'), '2', '06', '187', '07', '2077', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28313, to_date('07-07-2077', 'dd-mm-yyyy'), '3', '07', '188', '07', '2077', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28314, to_date('08-07-2077', 'dd-mm-yyyy'), '4', '08', '189', '07', '2077', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28315, to_date('09-07-2077', 'dd-mm-yyyy'), '5', '09', '190', '07', '2077', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28316, to_date('10-07-2077', 'dd-mm-yyyy'), '6', '10', '191', '07', '2077', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28317, to_date('11-07-2077', 'dd-mm-yyyy'), '7', '11', '192', '07', '2077', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28318, to_date('12-07-2077', 'dd-mm-yyyy'), '1', '12', '193', '07', '2077', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28319, to_date('13-07-2077', 'dd-mm-yyyy'), '2', '13', '194', '07', '2077', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28320, to_date('14-07-2077', 'dd-mm-yyyy'), '3', '14', '195', '07', '2077', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28321, to_date('15-07-2077', 'dd-mm-yyyy'), '4', '15', '196', '07', '2077', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28322, to_date('16-07-2077', 'dd-mm-yyyy'), '5', '16', '197', '07', '2077', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28323, to_date('17-07-2077', 'dd-mm-yyyy'), '6', '17', '198', '07', '2077', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28324, to_date('18-07-2077', 'dd-mm-yyyy'), '7', '18', '199', '07', '2077', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28325, to_date('19-07-2077', 'dd-mm-yyyy'), '1', '19', '200', '07', '2077', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28326, to_date('20-07-2077', 'dd-mm-yyyy'), '2', '20', '201', '07', '2077', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28327, to_date('21-07-2077', 'dd-mm-yyyy'), '3', '21', '202', '07', '2077', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28328, to_date('22-07-2077', 'dd-mm-yyyy'), '4', '22', '203', '07', '2077', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28329, to_date('23-07-2077', 'dd-mm-yyyy'), '5', '23', '204', '07', '2077', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28330, to_date('24-07-2077', 'dd-mm-yyyy'), '6', '24', '205', '07', '2077', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28331, to_date('25-07-2077', 'dd-mm-yyyy'), '7', '25', '206', '07', '2077', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28332, to_date('26-07-2077', 'dd-mm-yyyy'), '1', '26', '207', '07', '2077', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28333, to_date('27-07-2077', 'dd-mm-yyyy'), '2', '27', '208', '07', '2077', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28334, to_date('28-07-2077', 'dd-mm-yyyy'), '3', '28', '209', '07', '2077', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28335, to_date('29-07-2077', 'dd-mm-yyyy'), '4', '29', '210', '07', '2077', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28336, to_date('30-07-2077', 'dd-mm-yyyy'), '5', '30', '211', '07', '2077', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28337, to_date('31-07-2077', 'dd-mm-yyyy'), '6', '31', '212', '07', '2077', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28338, to_date('01-08-2077', 'dd-mm-yyyy'), '7', '01', '213', '08', '2077', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28339, to_date('02-08-2077', 'dd-mm-yyyy'), '1', '02', '214', '08', '2077', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28340, to_date('03-08-2077', 'dd-mm-yyyy'), '2', '03', '215', '08', '2077', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28341, to_date('04-08-2077', 'dd-mm-yyyy'), '3', '04', '216', '08', '2077', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28342, to_date('05-08-2077', 'dd-mm-yyyy'), '4', '05', '217', '08', '2077', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28343, to_date('06-08-2077', 'dd-mm-yyyy'), '5', '06', '218', '08', '2077', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28344, to_date('07-08-2077', 'dd-mm-yyyy'), '6', '07', '219', '08', '2077', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28345, to_date('08-08-2077', 'dd-mm-yyyy'), '7', '08', '220', '08', '2077', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28346, to_date('09-08-2077', 'dd-mm-yyyy'), '1', '09', '221', '08', '2077', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28347, to_date('10-08-2077', 'dd-mm-yyyy'), '2', '10', '222', '08', '2077', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28348, to_date('11-08-2077', 'dd-mm-yyyy'), '3', '11', '223', '08', '2077', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28349, to_date('12-08-2077', 'dd-mm-yyyy'), '4', '12', '224', '08', '2077', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28350, to_date('13-08-2077', 'dd-mm-yyyy'), '5', '13', '225', '08', '2077', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28351, to_date('14-08-2077', 'dd-mm-yyyy'), '6', '14', '226', '08', '2077', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28352, to_date('15-08-2077', 'dd-mm-yyyy'), '7', '15', '227', '08', '2077', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28353, to_date('16-08-2077', 'dd-mm-yyyy'), '1', '16', '228', '08', '2077', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28354, to_date('17-08-2077', 'dd-mm-yyyy'), '2', '17', '229', '08', '2077', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28355, to_date('18-08-2077', 'dd-mm-yyyy'), '3', '18', '230', '08', '2077', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28356, to_date('19-08-2077', 'dd-mm-yyyy'), '4', '19', '231', '08', '2077', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28357, to_date('20-08-2077', 'dd-mm-yyyy'), '5', '20', '232', '08', '2077', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28358, to_date('21-08-2077', 'dd-mm-yyyy'), '6', '21', '233', '08', '2077', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28359, to_date('22-08-2077', 'dd-mm-yyyy'), '7', '22', '234', '08', '2077', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28360, to_date('23-08-2077', 'dd-mm-yyyy'), '1', '23', '235', '08', '2077', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28361, to_date('24-08-2077', 'dd-mm-yyyy'), '2', '24', '236', '08', '2077', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28362, to_date('25-08-2077', 'dd-mm-yyyy'), '3', '25', '237', '08', '2077', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28363, to_date('26-08-2077', 'dd-mm-yyyy'), '4', '26', '238', '08', '2077', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28364, to_date('27-08-2077', 'dd-mm-yyyy'), '5', '27', '239', '08', '2077', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28365, to_date('28-08-2077', 'dd-mm-yyyy'), '6', '28', '240', '08', '2077', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28366, to_date('29-08-2077', 'dd-mm-yyyy'), '7', '29', '241', '08', '2077', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28367, to_date('30-08-2077', 'dd-mm-yyyy'), '1', '30', '242', '08', '2077', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28368, to_date('31-08-2077', 'dd-mm-yyyy'), '2', '31', '243', '08', '2077', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28369, to_date('01-09-2077', 'dd-mm-yyyy'), '3', '01', '244', '09', '2077', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28370, to_date('02-09-2077', 'dd-mm-yyyy'), '4', '02', '245', '09', '2077', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28371, to_date('03-09-2077', 'dd-mm-yyyy'), '5', '03', '246', '09', '2077', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28372, to_date('04-09-2077', 'dd-mm-yyyy'), '6', '04', '247', '09', '2077', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28373, to_date('05-09-2077', 'dd-mm-yyyy'), '7', '05', '248', '09', '2077', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28374, to_date('06-09-2077', 'dd-mm-yyyy'), '1', '06', '249', '09', '2077', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28375, to_date('07-09-2077', 'dd-mm-yyyy'), '2', '07', '250', '09', '2077', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28376, to_date('08-09-2077', 'dd-mm-yyyy'), '3', '08', '251', '09', '2077', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28377, to_date('09-09-2077', 'dd-mm-yyyy'), '4', '09', '252', '09', '2077', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28378, to_date('10-09-2077', 'dd-mm-yyyy'), '5', '10', '253', '09', '2077', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28379, to_date('11-09-2077', 'dd-mm-yyyy'), '6', '11', '254', '09', '2077', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28380, to_date('12-09-2077', 'dd-mm-yyyy'), '7', '12', '255', '09', '2077', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28381, to_date('13-09-2077', 'dd-mm-yyyy'), '1', '13', '256', '09', '2077', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28382, to_date('14-09-2077', 'dd-mm-yyyy'), '2', '14', '257', '09', '2077', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29867, to_date('08-10-2081', 'dd-mm-yyyy'), '3', '08', '281', '10', '2081', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29868, to_date('09-10-2081', 'dd-mm-yyyy'), '4', '09', '282', '10', '2081', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29869, to_date('10-10-2081', 'dd-mm-yyyy'), '5', '10', '283', '10', '2081', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29870, to_date('11-10-2081', 'dd-mm-yyyy'), '6', '11', '284', '10', '2081', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29871, to_date('12-10-2081', 'dd-mm-yyyy'), '7', '12', '285', '10', '2081', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29872, to_date('13-10-2081', 'dd-mm-yyyy'), '1', '13', '286', '10', '2081', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29873, to_date('14-10-2081', 'dd-mm-yyyy'), '2', '14', '287', '10', '2081', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29874, to_date('15-10-2081', 'dd-mm-yyyy'), '3', '15', '288', '10', '2081', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29875, to_date('16-10-2081', 'dd-mm-yyyy'), '4', '16', '289', '10', '2081', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29876, to_date('17-10-2081', 'dd-mm-yyyy'), '5', '17', '290', '10', '2081', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29877, to_date('18-10-2081', 'dd-mm-yyyy'), '6', '18', '291', '10', '2081', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29878, to_date('19-10-2081', 'dd-mm-yyyy'), '7', '19', '292', '10', '2081', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29879, to_date('20-10-2081', 'dd-mm-yyyy'), '1', '20', '293', '10', '2081', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29880, to_date('21-10-2081', 'dd-mm-yyyy'), '2', '21', '294', '10', '2081', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29881, to_date('22-10-2081', 'dd-mm-yyyy'), '3', '22', '295', '10', '2081', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29882, to_date('23-10-2081', 'dd-mm-yyyy'), '4', '23', '296', '10', '2081', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29883, to_date('24-10-2081', 'dd-mm-yyyy'), '5', '24', '297', '10', '2081', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29884, to_date('25-10-2081', 'dd-mm-yyyy'), '6', '25', '298', '10', '2081', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29885, to_date('26-10-2081', 'dd-mm-yyyy'), '7', '26', '299', '10', '2081', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29886, to_date('27-10-2081', 'dd-mm-yyyy'), '1', '27', '300', '10', '2081', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29887, to_date('28-10-2081', 'dd-mm-yyyy'), '2', '28', '301', '10', '2081', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29888, to_date('29-10-2081', 'dd-mm-yyyy'), '3', '29', '302', '10', '2081', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29889, to_date('30-10-2081', 'dd-mm-yyyy'), '4', '30', '303', '10', '2081', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29890, to_date('31-10-2081', 'dd-mm-yyyy'), '5', '31', '304', '10', '2081', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29891, to_date('01-11-2081', 'dd-mm-yyyy'), '6', '01', '305', '11', '2081', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29892, to_date('02-11-2081', 'dd-mm-yyyy'), '7', '02', '306', '11', '2081', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29893, to_date('03-11-2081', 'dd-mm-yyyy'), '1', '03', '307', '11', '2081', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29894, to_date('04-11-2081', 'dd-mm-yyyy'), '2', '04', '308', '11', '2081', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29895, to_date('05-11-2081', 'dd-mm-yyyy'), '3', '05', '309', '11', '2081', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29896, to_date('06-11-2081', 'dd-mm-yyyy'), '4', '06', '310', '11', '2081', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29897, to_date('07-11-2081', 'dd-mm-yyyy'), '5', '07', '311', '11', '2081', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29898, to_date('08-11-2081', 'dd-mm-yyyy'), '6', '08', '312', '11', '2081', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29899, to_date('09-11-2081', 'dd-mm-yyyy'), '7', '09', '313', '11', '2081', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29900, to_date('10-11-2081', 'dd-mm-yyyy'), '1', '10', '314', '11', '2081', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29901, to_date('11-11-2081', 'dd-mm-yyyy'), '2', '11', '315', '11', '2081', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29902, to_date('12-11-2081', 'dd-mm-yyyy'), '3', '12', '316', '11', '2081', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29903, to_date('13-11-2081', 'dd-mm-yyyy'), '4', '13', '317', '11', '2081', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29904, to_date('14-11-2081', 'dd-mm-yyyy'), '5', '14', '318', '11', '2081', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29905, to_date('15-11-2081', 'dd-mm-yyyy'), '6', '15', '319', '11', '2081', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29906, to_date('16-11-2081', 'dd-mm-yyyy'), '7', '16', '320', '11', '2081', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29907, to_date('17-11-2081', 'dd-mm-yyyy'), '1', '17', '321', '11', '2081', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29908, to_date('18-11-2081', 'dd-mm-yyyy'), '2', '18', '322', '11', '2081', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29909, to_date('19-11-2081', 'dd-mm-yyyy'), '3', '19', '323', '11', '2081', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29910, to_date('20-11-2081', 'dd-mm-yyyy'), '4', '20', '324', '11', '2081', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29911, to_date('21-11-2081', 'dd-mm-yyyy'), '5', '21', '325', '11', '2081', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29912, to_date('22-11-2081', 'dd-mm-yyyy'), '6', '22', '326', '11', '2081', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29913, to_date('23-11-2081', 'dd-mm-yyyy'), '7', '23', '327', '11', '2081', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29914, to_date('24-11-2081', 'dd-mm-yyyy'), '1', '24', '328', '11', '2081', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29915, to_date('25-11-2081', 'dd-mm-yyyy'), '2', '25', '329', '11', '2081', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29916, to_date('26-11-2081', 'dd-mm-yyyy'), '3', '26', '330', '11', '2081', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29917, to_date('27-11-2081', 'dd-mm-yyyy'), '4', '27', '331', '11', '2081', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29918, to_date('28-11-2081', 'dd-mm-yyyy'), '5', '28', '332', '11', '2081', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29919, to_date('29-11-2081', 'dd-mm-yyyy'), '6', '29', '333', '11', '2081', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29920, to_date('30-11-2081', 'dd-mm-yyyy'), '7', '30', '334', '11', '2081', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29921, to_date('01-12-2081', 'dd-mm-yyyy'), '1', '01', '335', '12', '2081', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29922, to_date('02-12-2081', 'dd-mm-yyyy'), '2', '02', '336', '12', '2081', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29923, to_date('03-12-2081', 'dd-mm-yyyy'), '3', '03', '337', '12', '2081', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29924, to_date('04-12-2081', 'dd-mm-yyyy'), '4', '04', '338', '12', '2081', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29925, to_date('05-12-2081', 'dd-mm-yyyy'), '5', '05', '339', '12', '2081', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29926, to_date('06-12-2081', 'dd-mm-yyyy'), '6', '06', '340', '12', '2081', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29927, to_date('07-12-2081', 'dd-mm-yyyy'), '7', '07', '341', '12', '2081', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29928, to_date('08-12-2081', 'dd-mm-yyyy'), '1', '08', '342', '12', '2081', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29929, to_date('09-12-2081', 'dd-mm-yyyy'), '2', '09', '343', '12', '2081', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29930, to_date('10-12-2081', 'dd-mm-yyyy'), '3', '10', '344', '12', '2081', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29931, to_date('11-12-2081', 'dd-mm-yyyy'), '4', '11', '345', '12', '2081', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29932, to_date('12-12-2081', 'dd-mm-yyyy'), '5', '12', '346', '12', '2081', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29933, to_date('13-12-2081', 'dd-mm-yyyy'), '6', '13', '347', '12', '2081', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29934, to_date('14-12-2081', 'dd-mm-yyyy'), '7', '14', '348', '12', '2081', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29935, to_date('15-12-2081', 'dd-mm-yyyy'), '1', '15', '349', '12', '2081', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29936, to_date('16-12-2081', 'dd-mm-yyyy'), '2', '16', '350', '12', '2081', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29937, to_date('17-12-2081', 'dd-mm-yyyy'), '3', '17', '351', '12', '2081', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29938, to_date('18-12-2081', 'dd-mm-yyyy'), '4', '18', '352', '12', '2081', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29939, to_date('19-12-2081', 'dd-mm-yyyy'), '5', '19', '353', '12', '2081', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29940, to_date('20-12-2081', 'dd-mm-yyyy'), '6', '20', '354', '12', '2081', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29941, to_date('21-12-2081', 'dd-mm-yyyy'), '7', '21', '355', '12', '2081', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29942, to_date('22-12-2081', 'dd-mm-yyyy'), '1', '22', '356', '12', '2081', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29943, to_date('23-12-2081', 'dd-mm-yyyy'), '2', '23', '357', '12', '2081', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29944, to_date('24-12-2081', 'dd-mm-yyyy'), '3', '24', '358', '12', '2081', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29945, to_date('25-12-2081', 'dd-mm-yyyy'), '4', '25', '359', '12', '2081', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29946, to_date('26-12-2081', 'dd-mm-yyyy'), '5', '26', '360', '12', '2081', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29947, to_date('27-12-2081', 'dd-mm-yyyy'), '6', '27', '361', '12', '2081', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29948, to_date('28-12-2081', 'dd-mm-yyyy'), '7', '28', '362', '12', '2081', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29949, to_date('29-12-2081', 'dd-mm-yyyy'), '1', '29', '363', '12', '2081', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29950, to_date('30-12-2081', 'dd-mm-yyyy'), '2', '30', '364', '12', '2081', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29951, to_date('31-12-2081', 'dd-mm-yyyy'), '3', '31', '365', '12', '2081', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29952, to_date('01-01-2082', 'dd-mm-yyyy'), '4', '01', '001', '01', '2082', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29953, to_date('02-01-2082', 'dd-mm-yyyy'), '5', '02', '002', '01', '2082', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29954, to_date('03-01-2082', 'dd-mm-yyyy'), '6', '03', '003', '01', '2082', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29955, to_date('04-01-2082', 'dd-mm-yyyy'), '7', '04', '004', '01', '2082', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29956, to_date('05-01-2082', 'dd-mm-yyyy'), '1', '05', '005', '01', '2082', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29957, to_date('06-01-2082', 'dd-mm-yyyy'), '2', '06', '006', '01', '2082', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29958, to_date('07-01-2082', 'dd-mm-yyyy'), '3', '07', '007', '01', '2082', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29959, to_date('08-01-2082', 'dd-mm-yyyy'), '4', '08', '008', '01', '2082', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29960, to_date('09-01-2082', 'dd-mm-yyyy'), '5', '09', '009', '01', '2082', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29961, to_date('10-01-2082', 'dd-mm-yyyy'), '6', '10', '010', '01', '2082', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29962, to_date('11-01-2082', 'dd-mm-yyyy'), '7', '11', '011', '01', '2082', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29963, to_date('12-01-2082', 'dd-mm-yyyy'), '1', '12', '012', '01', '2082', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29964, to_date('13-01-2082', 'dd-mm-yyyy'), '2', '13', '013', '01', '2082', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29965, to_date('14-01-2082', 'dd-mm-yyyy'), '3', '14', '014', '01', '2082', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29966, to_date('15-01-2082', 'dd-mm-yyyy'), '4', '15', '015', '01', '2082', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29967, to_date('16-01-2082', 'dd-mm-yyyy'), '5', '16', '016', '01', '2082', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29968, to_date('17-01-2082', 'dd-mm-yyyy'), '6', '17', '017', '01', '2082', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29969, to_date('18-01-2082', 'dd-mm-yyyy'), '7', '18', '018', '01', '2082', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29970, to_date('19-01-2082', 'dd-mm-yyyy'), '1', '19', '019', '01', '2082', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29971, to_date('20-01-2082', 'dd-mm-yyyy'), '2', '20', '020', '01', '2082', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29972, to_date('21-01-2082', 'dd-mm-yyyy'), '3', '21', '021', '01', '2082', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31457, to_date('14-02-2086', 'dd-mm-yyyy'), '4', '14', '045', '02', '2086', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31458, to_date('15-02-2086', 'dd-mm-yyyy'), '5', '15', '046', '02', '2086', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31459, to_date('16-02-2086', 'dd-mm-yyyy'), '6', '16', '047', '02', '2086', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31460, to_date('17-02-2086', 'dd-mm-yyyy'), '7', '17', '048', '02', '2086', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31461, to_date('18-02-2086', 'dd-mm-yyyy'), '1', '18', '049', '02', '2086', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31462, to_date('19-02-2086', 'dd-mm-yyyy'), '2', '19', '050', '02', '2086', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31463, to_date('20-02-2086', 'dd-mm-yyyy'), '3', '20', '051', '02', '2086', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31464, to_date('21-02-2086', 'dd-mm-yyyy'), '4', '21', '052', '02', '2086', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31465, to_date('22-02-2086', 'dd-mm-yyyy'), '5', '22', '053', '02', '2086', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31466, to_date('23-02-2086', 'dd-mm-yyyy'), '6', '23', '054', '02', '2086', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31467, to_date('24-02-2086', 'dd-mm-yyyy'), '7', '24', '055', '02', '2086', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31468, to_date('25-02-2086', 'dd-mm-yyyy'), '1', '25', '056', '02', '2086', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31469, to_date('26-02-2086', 'dd-mm-yyyy'), '2', '26', '057', '02', '2086', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31470, to_date('27-02-2086', 'dd-mm-yyyy'), '3', '27', '058', '02', '2086', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31471, to_date('28-02-2086', 'dd-mm-yyyy'), '4', '28', '059', '02', '2086', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31472, to_date('01-03-2086', 'dd-mm-yyyy'), '5', '01', '060', '03', '2086', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31473, to_date('02-03-2086', 'dd-mm-yyyy'), '6', '02', '061', '03', '2086', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31474, to_date('03-03-2086', 'dd-mm-yyyy'), '7', '03', '062', '03', '2086', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31475, to_date('04-03-2086', 'dd-mm-yyyy'), '1', '04', '063', '03', '2086', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31476, to_date('05-03-2086', 'dd-mm-yyyy'), '2', '05', '064', '03', '2086', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31477, to_date('06-03-2086', 'dd-mm-yyyy'), '3', '06', '065', '03', '2086', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31478, to_date('07-03-2086', 'dd-mm-yyyy'), '4', '07', '066', '03', '2086', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31479, to_date('08-03-2086', 'dd-mm-yyyy'), '5', '08', '067', '03', '2086', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31480, to_date('09-03-2086', 'dd-mm-yyyy'), '6', '09', '068', '03', '2086', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31481, to_date('10-03-2086', 'dd-mm-yyyy'), '7', '10', '069', '03', '2086', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31482, to_date('11-03-2086', 'dd-mm-yyyy'), '1', '11', '070', '03', '2086', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31483, to_date('12-03-2086', 'dd-mm-yyyy'), '2', '12', '071', '03', '2086', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31484, to_date('13-03-2086', 'dd-mm-yyyy'), '3', '13', '072', '03', '2086', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31485, to_date('14-03-2086', 'dd-mm-yyyy'), '4', '14', '073', '03', '2086', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31486, to_date('15-03-2086', 'dd-mm-yyyy'), '5', '15', '074', '03', '2086', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31487, to_date('16-03-2086', 'dd-mm-yyyy'), '6', '16', '075', '03', '2086', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31488, to_date('17-03-2086', 'dd-mm-yyyy'), '7', '17', '076', '03', '2086', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31489, to_date('18-03-2086', 'dd-mm-yyyy'), '1', '18', '077', '03', '2086', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31490, to_date('19-03-2086', 'dd-mm-yyyy'), '2', '19', '078', '03', '2086', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31491, to_date('20-03-2086', 'dd-mm-yyyy'), '3', '20', '079', '03', '2086', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31492, to_date('21-03-2086', 'dd-mm-yyyy'), '4', '21', '080', '03', '2086', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31493, to_date('22-03-2086', 'dd-mm-yyyy'), '5', '22', '081', '03', '2086', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31494, to_date('23-03-2086', 'dd-mm-yyyy'), '6', '23', '082', '03', '2086', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31495, to_date('24-03-2086', 'dd-mm-yyyy'), '7', '24', '083', '03', '2086', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31496, to_date('25-03-2086', 'dd-mm-yyyy'), '1', '25', '084', '03', '2086', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31497, to_date('26-03-2086', 'dd-mm-yyyy'), '2', '26', '085', '03', '2086', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31498, to_date('27-03-2086', 'dd-mm-yyyy'), '3', '27', '086', '03', '2086', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31499, to_date('28-03-2086', 'dd-mm-yyyy'), '4', '28', '087', '03', '2086', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31500, to_date('29-03-2086', 'dd-mm-yyyy'), '5', '29', '088', '03', '2086', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31501, to_date('30-03-2086', 'dd-mm-yyyy'), '6', '30', '089', '03', '2086', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31502, to_date('31-03-2086', 'dd-mm-yyyy'), '7', '31', '090', '03', '2086', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31503, to_date('01-04-2086', 'dd-mm-yyyy'), '1', '01', '091', '04', '2086', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31504, to_date('02-04-2086', 'dd-mm-yyyy'), '2', '02', '092', '04', '2086', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31505, to_date('03-04-2086', 'dd-mm-yyyy'), '3', '03', '093', '04', '2086', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31506, to_date('04-04-2086', 'dd-mm-yyyy'), '4', '04', '094', '04', '2086', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31507, to_date('05-04-2086', 'dd-mm-yyyy'), '5', '05', '095', '04', '2086', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31508, to_date('06-04-2086', 'dd-mm-yyyy'), '6', '06', '096', '04', '2086', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31509, to_date('07-04-2086', 'dd-mm-yyyy'), '7', '07', '097', '04', '2086', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31510, to_date('08-04-2086', 'dd-mm-yyyy'), '1', '08', '098', '04', '2086', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31511, to_date('09-04-2086', 'dd-mm-yyyy'), '2', '09', '099', '04', '2086', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31512, to_date('10-04-2086', 'dd-mm-yyyy'), '3', '10', '100', '04', '2086', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31513, to_date('11-04-2086', 'dd-mm-yyyy'), '4', '11', '101', '04', '2086', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31514, to_date('12-04-2086', 'dd-mm-yyyy'), '5', '12', '102', '04', '2086', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31515, to_date('13-04-2086', 'dd-mm-yyyy'), '6', '13', '103', '04', '2086', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31516, to_date('14-04-2086', 'dd-mm-yyyy'), '7', '14', '104', '04', '2086', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31517, to_date('15-04-2086', 'dd-mm-yyyy'), '1', '15', '105', '04', '2086', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31518, to_date('16-04-2086', 'dd-mm-yyyy'), '2', '16', '106', '04', '2086', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31519, to_date('17-04-2086', 'dd-mm-yyyy'), '3', '17', '107', '04', '2086', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31520, to_date('18-04-2086', 'dd-mm-yyyy'), '4', '18', '108', '04', '2086', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31521, to_date('19-04-2086', 'dd-mm-yyyy'), '5', '19', '109', '04', '2086', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31522, to_date('20-04-2086', 'dd-mm-yyyy'), '6', '20', '110', '04', '2086', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31523, to_date('21-04-2086', 'dd-mm-yyyy'), '7', '21', '111', '04', '2086', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31524, to_date('22-04-2086', 'dd-mm-yyyy'), '1', '22', '112', '04', '2086', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31525, to_date('23-04-2086', 'dd-mm-yyyy'), '2', '23', '113', '04', '2086', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31526, to_date('24-04-2086', 'dd-mm-yyyy'), '3', '24', '114', '04', '2086', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31527, to_date('25-04-2086', 'dd-mm-yyyy'), '4', '25', '115', '04', '2086', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31528, to_date('26-04-2086', 'dd-mm-yyyy'), '5', '26', '116', '04', '2086', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31529, to_date('27-04-2086', 'dd-mm-yyyy'), '6', '27', '117', '04', '2086', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31530, to_date('28-04-2086', 'dd-mm-yyyy'), '7', '28', '118', '04', '2086', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31531, to_date('29-04-2086', 'dd-mm-yyyy'), '1', '29', '119', '04', '2086', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31532, to_date('30-04-2086', 'dd-mm-yyyy'), '2', '30', '120', '04', '2086', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31533, to_date('01-05-2086', 'dd-mm-yyyy'), '3', '01', '121', '05', '2086', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31534, to_date('02-05-2086', 'dd-mm-yyyy'), '4', '02', '122', '05', '2086', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31535, to_date('03-05-2086', 'dd-mm-yyyy'), '5', '03', '123', '05', '2086', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
commit;
prompt 33000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31536, to_date('04-05-2086', 'dd-mm-yyyy'), '6', '04', '124', '05', '2086', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31537, to_date('05-05-2086', 'dd-mm-yyyy'), '7', '05', '125', '05', '2086', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31538, to_date('06-05-2086', 'dd-mm-yyyy'), '1', '06', '126', '05', '2086', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31539, to_date('07-05-2086', 'dd-mm-yyyy'), '2', '07', '127', '05', '2086', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31540, to_date('08-05-2086', 'dd-mm-yyyy'), '3', '08', '128', '05', '2086', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31541, to_date('09-05-2086', 'dd-mm-yyyy'), '4', '09', '129', '05', '2086', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31542, to_date('10-05-2086', 'dd-mm-yyyy'), '5', '10', '130', '05', '2086', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31543, to_date('11-05-2086', 'dd-mm-yyyy'), '6', '11', '131', '05', '2086', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31544, to_date('12-05-2086', 'dd-mm-yyyy'), '7', '12', '132', '05', '2086', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31545, to_date('13-05-2086', 'dd-mm-yyyy'), '1', '13', '133', '05', '2086', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31546, to_date('14-05-2086', 'dd-mm-yyyy'), '2', '14', '134', '05', '2086', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31547, to_date('15-05-2086', 'dd-mm-yyyy'), '3', '15', '135', '05', '2086', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31548, to_date('16-05-2086', 'dd-mm-yyyy'), '4', '16', '136', '05', '2086', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31549, to_date('17-05-2086', 'dd-mm-yyyy'), '5', '17', '137', '05', '2086', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31550, to_date('18-05-2086', 'dd-mm-yyyy'), '6', '18', '138', '05', '2086', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31551, to_date('19-05-2086', 'dd-mm-yyyy'), '7', '19', '139', '05', '2086', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31552, to_date('20-05-2086', 'dd-mm-yyyy'), '1', '20', '140', '05', '2086', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31553, to_date('21-05-2086', 'dd-mm-yyyy'), '2', '21', '141', '05', '2086', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31554, to_date('22-05-2086', 'dd-mm-yyyy'), '3', '22', '142', '05', '2086', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31555, to_date('23-05-2086', 'dd-mm-yyyy'), '4', '23', '143', '05', '2086', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31556, to_date('24-05-2086', 'dd-mm-yyyy'), '5', '24', '144', '05', '2086', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31557, to_date('25-05-2086', 'dd-mm-yyyy'), '6', '25', '145', '05', '2086', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31558, to_date('26-05-2086', 'dd-mm-yyyy'), '7', '26', '146', '05', '2086', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31559, to_date('27-05-2086', 'dd-mm-yyyy'), '1', '27', '147', '05', '2086', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31560, to_date('28-05-2086', 'dd-mm-yyyy'), '2', '28', '148', '05', '2086', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31561, to_date('29-05-2086', 'dd-mm-yyyy'), '3', '29', '149', '05', '2086', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31562, to_date('30-05-2086', 'dd-mm-yyyy'), '4', '30', '150', '05', '2086', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26687, to_date('23-01-2073', 'dd-mm-yyyy'), '1', '23', '023', '01', '2073', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26688, to_date('24-01-2073', 'dd-mm-yyyy'), '2', '24', '024', '01', '2073', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26689, to_date('25-01-2073', 'dd-mm-yyyy'), '3', '25', '025', '01', '2073', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26690, to_date('26-01-2073', 'dd-mm-yyyy'), '4', '26', '026', '01', '2073', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26691, to_date('27-01-2073', 'dd-mm-yyyy'), '5', '27', '027', '01', '2073', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26692, to_date('28-01-2073', 'dd-mm-yyyy'), '6', '28', '028', '01', '2073', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26693, to_date('29-01-2073', 'dd-mm-yyyy'), '7', '29', '029', '01', '2073', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26694, to_date('30-01-2073', 'dd-mm-yyyy'), '1', '30', '030', '01', '2073', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26695, to_date('31-01-2073', 'dd-mm-yyyy'), '2', '31', '031', '01', '2073', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26696, to_date('01-02-2073', 'dd-mm-yyyy'), '3', '01', '032', '02', '2073', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26697, to_date('02-02-2073', 'dd-mm-yyyy'), '4', '02', '033', '02', '2073', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26698, to_date('03-02-2073', 'dd-mm-yyyy'), '5', '03', '034', '02', '2073', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26699, to_date('04-02-2073', 'dd-mm-yyyy'), '6', '04', '035', '02', '2073', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26700, to_date('05-02-2073', 'dd-mm-yyyy'), '7', '05', '036', '02', '2073', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26701, to_date('06-02-2073', 'dd-mm-yyyy'), '1', '06', '037', '02', '2073', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26702, to_date('07-02-2073', 'dd-mm-yyyy'), '2', '07', '038', '02', '2073', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26703, to_date('08-02-2073', 'dd-mm-yyyy'), '3', '08', '039', '02', '2073', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26704, to_date('09-02-2073', 'dd-mm-yyyy'), '4', '09', '040', '02', '2073', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26705, to_date('10-02-2073', 'dd-mm-yyyy'), '5', '10', '041', '02', '2073', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26706, to_date('11-02-2073', 'dd-mm-yyyy'), '6', '11', '042', '02', '2073', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26707, to_date('12-02-2073', 'dd-mm-yyyy'), '7', '12', '043', '02', '2073', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26708, to_date('13-02-2073', 'dd-mm-yyyy'), '1', '13', '044', '02', '2073', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26709, to_date('14-02-2073', 'dd-mm-yyyy'), '2', '14', '045', '02', '2073', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26710, to_date('15-02-2073', 'dd-mm-yyyy'), '3', '15', '046', '02', '2073', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26711, to_date('16-02-2073', 'dd-mm-yyyy'), '4', '16', '047', '02', '2073', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26712, to_date('17-02-2073', 'dd-mm-yyyy'), '5', '17', '048', '02', '2073', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26713, to_date('18-02-2073', 'dd-mm-yyyy'), '6', '18', '049', '02', '2073', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26714, to_date('19-02-2073', 'dd-mm-yyyy'), '7', '19', '050', '02', '2073', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26715, to_date('20-02-2073', 'dd-mm-yyyy'), '1', '20', '051', '02', '2073', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26716, to_date('21-02-2073', 'dd-mm-yyyy'), '2', '21', '052', '02', '2073', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26717, to_date('22-02-2073', 'dd-mm-yyyy'), '3', '22', '053', '02', '2073', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26718, to_date('23-02-2073', 'dd-mm-yyyy'), '4', '23', '054', '02', '2073', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26719, to_date('24-02-2073', 'dd-mm-yyyy'), '5', '24', '055', '02', '2073', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26720, to_date('25-02-2073', 'dd-mm-yyyy'), '6', '25', '056', '02', '2073', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26721, to_date('26-02-2073', 'dd-mm-yyyy'), '7', '26', '057', '02', '2073', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26722, to_date('27-02-2073', 'dd-mm-yyyy'), '1', '27', '058', '02', '2073', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26723, to_date('28-02-2073', 'dd-mm-yyyy'), '2', '28', '059', '02', '2073', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26724, to_date('01-03-2073', 'dd-mm-yyyy'), '3', '01', '060', '03', '2073', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26725, to_date('02-03-2073', 'dd-mm-yyyy'), '4', '02', '061', '03', '2073', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26726, to_date('03-03-2073', 'dd-mm-yyyy'), '5', '03', '062', '03', '2073', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26727, to_date('04-03-2073', 'dd-mm-yyyy'), '6', '04', '063', '03', '2073', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26728, to_date('05-03-2073', 'dd-mm-yyyy'), '7', '05', '064', '03', '2073', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26729, to_date('06-03-2073', 'dd-mm-yyyy'), '1', '06', '065', '03', '2073', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26730, to_date('07-03-2073', 'dd-mm-yyyy'), '2', '07', '066', '03', '2073', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26731, to_date('08-03-2073', 'dd-mm-yyyy'), '3', '08', '067', '03', '2073', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26732, to_date('09-03-2073', 'dd-mm-yyyy'), '4', '09', '068', '03', '2073', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26733, to_date('10-03-2073', 'dd-mm-yyyy'), '5', '10', '069', '03', '2073', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26734, to_date('11-03-2073', 'dd-mm-yyyy'), '6', '11', '070', '03', '2073', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26735, to_date('12-03-2073', 'dd-mm-yyyy'), '7', '12', '071', '03', '2073', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26736, to_date('13-03-2073', 'dd-mm-yyyy'), '1', '13', '072', '03', '2073', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26737, to_date('14-03-2073', 'dd-mm-yyyy'), '2', '14', '073', '03', '2073', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26738, to_date('15-03-2073', 'dd-mm-yyyy'), '3', '15', '074', '03', '2073', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26739, to_date('16-03-2073', 'dd-mm-yyyy'), '4', '16', '075', '03', '2073', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26740, to_date('17-03-2073', 'dd-mm-yyyy'), '5', '17', '076', '03', '2073', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26741, to_date('18-03-2073', 'dd-mm-yyyy'), '6', '18', '077', '03', '2073', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26742, to_date('19-03-2073', 'dd-mm-yyyy'), '7', '19', '078', '03', '2073', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26743, to_date('20-03-2073', 'dd-mm-yyyy'), '1', '20', '079', '03', '2073', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26744, to_date('21-03-2073', 'dd-mm-yyyy'), '2', '21', '080', '03', '2073', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26745, to_date('22-03-2073', 'dd-mm-yyyy'), '3', '22', '081', '03', '2073', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26746, to_date('23-03-2073', 'dd-mm-yyyy'), '4', '23', '082', '03', '2073', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26747, to_date('24-03-2073', 'dd-mm-yyyy'), '5', '24', '083', '03', '2073', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26748, to_date('25-03-2073', 'dd-mm-yyyy'), '6', '25', '084', '03', '2073', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26749, to_date('26-03-2073', 'dd-mm-yyyy'), '7', '26', '085', '03', '2073', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26750, to_date('27-03-2073', 'dd-mm-yyyy'), '1', '27', '086', '03', '2073', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26751, to_date('28-03-2073', 'dd-mm-yyyy'), '2', '28', '087', '03', '2073', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26752, to_date('29-03-2073', 'dd-mm-yyyy'), '3', '29', '088', '03', '2073', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26753, to_date('30-03-2073', 'dd-mm-yyyy'), '4', '30', '089', '03', '2073', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26754, to_date('31-03-2073', 'dd-mm-yyyy'), '5', '31', '090', '03', '2073', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26755, to_date('01-04-2073', 'dd-mm-yyyy'), '6', '01', '091', '04', '2073', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26756, to_date('02-04-2073', 'dd-mm-yyyy'), '7', '02', '092', '04', '2073', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26757, to_date('03-04-2073', 'dd-mm-yyyy'), '1', '03', '093', '04', '2073', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26758, to_date('04-04-2073', 'dd-mm-yyyy'), '2', '04', '094', '04', '2073', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26759, to_date('05-04-2073', 'dd-mm-yyyy'), '3', '05', '095', '04', '2073', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26760, to_date('06-04-2073', 'dd-mm-yyyy'), '4', '06', '096', '04', '2073', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26761, to_date('07-04-2073', 'dd-mm-yyyy'), '5', '07', '097', '04', '2073', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26762, to_date('08-04-2073', 'dd-mm-yyyy'), '6', '08', '098', '04', '2073', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26763, to_date('09-04-2073', 'dd-mm-yyyy'), '7', '09', '099', '04', '2073', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26764, to_date('10-04-2073', 'dd-mm-yyyy'), '1', '10', '100', '04', '2073', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26765, to_date('11-04-2073', 'dd-mm-yyyy'), '2', '11', '101', '04', '2073', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26766, to_date('12-04-2073', 'dd-mm-yyyy'), '3', '12', '102', '04', '2073', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26767, to_date('13-04-2073', 'dd-mm-yyyy'), '4', '13', '103', '04', '2073', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26768, to_date('14-04-2073', 'dd-mm-yyyy'), '5', '14', '104', '04', '2073', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26769, to_date('15-04-2073', 'dd-mm-yyyy'), '6', '15', '105', '04', '2073', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26770, to_date('16-04-2073', 'dd-mm-yyyy'), '7', '16', '106', '04', '2073', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26771, to_date('17-04-2073', 'dd-mm-yyyy'), '1', '17', '107', '04', '2073', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26772, to_date('18-04-2073', 'dd-mm-yyyy'), '2', '18', '108', '04', '2073', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26773, to_date('19-04-2073', 'dd-mm-yyyy'), '3', '19', '109', '04', '2073', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26774, to_date('20-04-2073', 'dd-mm-yyyy'), '4', '20', '110', '04', '2073', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26775, to_date('21-04-2073', 'dd-mm-yyyy'), '5', '21', '111', '04', '2073', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26776, to_date('22-04-2073', 'dd-mm-yyyy'), '6', '22', '112', '04', '2073', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26777, to_date('23-04-2073', 'dd-mm-yyyy'), '7', '23', '113', '04', '2073', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26778, to_date('24-04-2073', 'dd-mm-yyyy'), '1', '24', '114', '04', '2073', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26779, to_date('25-04-2073', 'dd-mm-yyyy'), '2', '25', '115', '04', '2073', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26780, to_date('26-04-2073', 'dd-mm-yyyy'), '3', '26', '116', '04', '2073', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26781, to_date('27-04-2073', 'dd-mm-yyyy'), '4', '27', '117', '04', '2073', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26782, to_date('28-04-2073', 'dd-mm-yyyy'), '5', '28', '118', '04', '2073', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26783, to_date('29-04-2073', 'dd-mm-yyyy'), '6', '29', '119', '04', '2073', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26784, to_date('30-04-2073', 'dd-mm-yyyy'), '7', '30', '120', '04', '2073', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26785, to_date('01-05-2073', 'dd-mm-yyyy'), '1', '01', '121', '05', '2073', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26786, to_date('02-05-2073', 'dd-mm-yyyy'), '2', '02', '122', '05', '2073', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26787, to_date('03-05-2073', 'dd-mm-yyyy'), '3', '03', '123', '05', '2073', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26788, to_date('04-05-2073', 'dd-mm-yyyy'), '4', '04', '124', '05', '2073', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26789, to_date('05-05-2073', 'dd-mm-yyyy'), '5', '05', '125', '05', '2073', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26790, to_date('06-05-2073', 'dd-mm-yyyy'), '6', '06', '126', '05', '2073', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26791, to_date('07-05-2073', 'dd-mm-yyyy'), '7', '07', '127', '05', '2073', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26792, to_date('08-05-2073', 'dd-mm-yyyy'), '1', '08', '128', '05', '2073', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28383, to_date('15-09-2077', 'dd-mm-yyyy'), '3', '15', '258', '09', '2077', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28384, to_date('16-09-2077', 'dd-mm-yyyy'), '4', '16', '259', '09', '2077', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28385, to_date('17-09-2077', 'dd-mm-yyyy'), '5', '17', '260', '09', '2077', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28386, to_date('18-09-2077', 'dd-mm-yyyy'), '6', '18', '261', '09', '2077', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28387, to_date('19-09-2077', 'dd-mm-yyyy'), '7', '19', '262', '09', '2077', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28388, to_date('20-09-2077', 'dd-mm-yyyy'), '1', '20', '263', '09', '2077', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28389, to_date('21-09-2077', 'dd-mm-yyyy'), '2', '21', '264', '09', '2077', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28390, to_date('22-09-2077', 'dd-mm-yyyy'), '3', '22', '265', '09', '2077', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28391, to_date('23-09-2077', 'dd-mm-yyyy'), '4', '23', '266', '09', '2077', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28392, to_date('24-09-2077', 'dd-mm-yyyy'), '5', '24', '267', '09', '2077', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28393, to_date('25-09-2077', 'dd-mm-yyyy'), '6', '25', '268', '09', '2077', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28394, to_date('26-09-2077', 'dd-mm-yyyy'), '7', '26', '269', '09', '2077', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28395, to_date('27-09-2077', 'dd-mm-yyyy'), '1', '27', '270', '09', '2077', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28396, to_date('28-09-2077', 'dd-mm-yyyy'), '2', '28', '271', '09', '2077', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28397, to_date('29-09-2077', 'dd-mm-yyyy'), '3', '29', '272', '09', '2077', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28398, to_date('30-09-2077', 'dd-mm-yyyy'), '4', '30', '273', '09', '2077', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28399, to_date('01-10-2077', 'dd-mm-yyyy'), '5', '01', '274', '10', '2077', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28400, to_date('02-10-2077', 'dd-mm-yyyy'), '6', '02', '275', '10', '2077', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28401, to_date('03-10-2077', 'dd-mm-yyyy'), '7', '03', '276', '10', '2077', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28402, to_date('04-10-2077', 'dd-mm-yyyy'), '1', '04', '277', '10', '2077', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28403, to_date('05-10-2077', 'dd-mm-yyyy'), '2', '05', '278', '10', '2077', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28404, to_date('06-10-2077', 'dd-mm-yyyy'), '3', '06', '279', '10', '2077', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28405, to_date('07-10-2077', 'dd-mm-yyyy'), '4', '07', '280', '10', '2077', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28406, to_date('08-10-2077', 'dd-mm-yyyy'), '5', '08', '281', '10', '2077', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28407, to_date('09-10-2077', 'dd-mm-yyyy'), '6', '09', '282', '10', '2077', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28408, to_date('10-10-2077', 'dd-mm-yyyy'), '7', '10', '283', '10', '2077', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28409, to_date('11-10-2077', 'dd-mm-yyyy'), '1', '11', '284', '10', '2077', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28410, to_date('12-10-2077', 'dd-mm-yyyy'), '2', '12', '285', '10', '2077', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28411, to_date('13-10-2077', 'dd-mm-yyyy'), '3', '13', '286', '10', '2077', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28412, to_date('14-10-2077', 'dd-mm-yyyy'), '4', '14', '287', '10', '2077', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28413, to_date('15-10-2077', 'dd-mm-yyyy'), '5', '15', '288', '10', '2077', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28414, to_date('16-10-2077', 'dd-mm-yyyy'), '6', '16', '289', '10', '2077', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28415, to_date('17-10-2077', 'dd-mm-yyyy'), '7', '17', '290', '10', '2077', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28416, to_date('18-10-2077', 'dd-mm-yyyy'), '1', '18', '291', '10', '2077', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28417, to_date('19-10-2077', 'dd-mm-yyyy'), '2', '19', '292', '10', '2077', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28418, to_date('20-10-2077', 'dd-mm-yyyy'), '3', '20', '293', '10', '2077', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28419, to_date('21-10-2077', 'dd-mm-yyyy'), '4', '21', '294', '10', '2077', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28420, to_date('22-10-2077', 'dd-mm-yyyy'), '5', '22', '295', '10', '2077', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28421, to_date('23-10-2077', 'dd-mm-yyyy'), '6', '23', '296', '10', '2077', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28422, to_date('24-10-2077', 'dd-mm-yyyy'), '7', '24', '297', '10', '2077', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28423, to_date('25-10-2077', 'dd-mm-yyyy'), '1', '25', '298', '10', '2077', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28424, to_date('26-10-2077', 'dd-mm-yyyy'), '2', '26', '299', '10', '2077', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28425, to_date('27-10-2077', 'dd-mm-yyyy'), '3', '27', '300', '10', '2077', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28426, to_date('28-10-2077', 'dd-mm-yyyy'), '4', '28', '301', '10', '2077', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28427, to_date('29-10-2077', 'dd-mm-yyyy'), '5', '29', '302', '10', '2077', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28428, to_date('30-10-2077', 'dd-mm-yyyy'), '6', '30', '303', '10', '2077', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28429, to_date('31-10-2077', 'dd-mm-yyyy'), '7', '31', '304', '10', '2077', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28430, to_date('01-11-2077', 'dd-mm-yyyy'), '1', '01', '305', '11', '2077', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28431, to_date('02-11-2077', 'dd-mm-yyyy'), '2', '02', '306', '11', '2077', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28432, to_date('03-11-2077', 'dd-mm-yyyy'), '3', '03', '307', '11', '2077', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28433, to_date('04-11-2077', 'dd-mm-yyyy'), '4', '04', '308', '11', '2077', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28434, to_date('05-11-2077', 'dd-mm-yyyy'), '5', '05', '309', '11', '2077', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28435, to_date('06-11-2077', 'dd-mm-yyyy'), '6', '06', '310', '11', '2077', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28436, to_date('07-11-2077', 'dd-mm-yyyy'), '7', '07', '311', '11', '2077', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28437, to_date('08-11-2077', 'dd-mm-yyyy'), '1', '08', '312', '11', '2077', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28438, to_date('09-11-2077', 'dd-mm-yyyy'), '2', '09', '313', '11', '2077', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28439, to_date('10-11-2077', 'dd-mm-yyyy'), '3', '10', '314', '11', '2077', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28440, to_date('11-11-2077', 'dd-mm-yyyy'), '4', '11', '315', '11', '2077', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28441, to_date('12-11-2077', 'dd-mm-yyyy'), '5', '12', '316', '11', '2077', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28442, to_date('13-11-2077', 'dd-mm-yyyy'), '6', '13', '317', '11', '2077', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28443, to_date('14-11-2077', 'dd-mm-yyyy'), '7', '14', '318', '11', '2077', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28444, to_date('15-11-2077', 'dd-mm-yyyy'), '1', '15', '319', '11', '2077', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28445, to_date('16-11-2077', 'dd-mm-yyyy'), '2', '16', '320', '11', '2077', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28446, to_date('17-11-2077', 'dd-mm-yyyy'), '3', '17', '321', '11', '2077', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28447, to_date('18-11-2077', 'dd-mm-yyyy'), '4', '18', '322', '11', '2077', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28448, to_date('19-11-2077', 'dd-mm-yyyy'), '5', '19', '323', '11', '2077', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28449, to_date('20-11-2077', 'dd-mm-yyyy'), '6', '20', '324', '11', '2077', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28450, to_date('21-11-2077', 'dd-mm-yyyy'), '7', '21', '325', '11', '2077', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28451, to_date('22-11-2077', 'dd-mm-yyyy'), '1', '22', '326', '11', '2077', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28452, to_date('23-11-2077', 'dd-mm-yyyy'), '2', '23', '327', '11', '2077', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28453, to_date('24-11-2077', 'dd-mm-yyyy'), '3', '24', '328', '11', '2077', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28454, to_date('25-11-2077', 'dd-mm-yyyy'), '4', '25', '329', '11', '2077', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28455, to_date('26-11-2077', 'dd-mm-yyyy'), '5', '26', '330', '11', '2077', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28456, to_date('27-11-2077', 'dd-mm-yyyy'), '6', '27', '331', '11', '2077', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28457, to_date('28-11-2077', 'dd-mm-yyyy'), '7', '28', '332', '11', '2077', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28458, to_date('29-11-2077', 'dd-mm-yyyy'), '1', '29', '333', '11', '2077', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28459, to_date('30-11-2077', 'dd-mm-yyyy'), '2', '30', '334', '11', '2077', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28460, to_date('01-12-2077', 'dd-mm-yyyy'), '3', '01', '335', '12', '2077', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28461, to_date('02-12-2077', 'dd-mm-yyyy'), '4', '02', '336', '12', '2077', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28462, to_date('03-12-2077', 'dd-mm-yyyy'), '5', '03', '337', '12', '2077', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28463, to_date('04-12-2077', 'dd-mm-yyyy'), '6', '04', '338', '12', '2077', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28464, to_date('05-12-2077', 'dd-mm-yyyy'), '7', '05', '339', '12', '2077', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28465, to_date('06-12-2077', 'dd-mm-yyyy'), '1', '06', '340', '12', '2077', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28466, to_date('07-12-2077', 'dd-mm-yyyy'), '2', '07', '341', '12', '2077', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28467, to_date('08-12-2077', 'dd-mm-yyyy'), '3', '08', '342', '12', '2077', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28468, to_date('09-12-2077', 'dd-mm-yyyy'), '4', '09', '343', '12', '2077', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28469, to_date('10-12-2077', 'dd-mm-yyyy'), '5', '10', '344', '12', '2077', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28470, to_date('11-12-2077', 'dd-mm-yyyy'), '6', '11', '345', '12', '2077', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28471, to_date('12-12-2077', 'dd-mm-yyyy'), '7', '12', '346', '12', '2077', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28472, to_date('13-12-2077', 'dd-mm-yyyy'), '1', '13', '347', '12', '2077', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28473, to_date('14-12-2077', 'dd-mm-yyyy'), '2', '14', '348', '12', '2077', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28474, to_date('15-12-2077', 'dd-mm-yyyy'), '3', '15', '349', '12', '2077', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28475, to_date('16-12-2077', 'dd-mm-yyyy'), '4', '16', '350', '12', '2077', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28476, to_date('17-12-2077', 'dd-mm-yyyy'), '5', '17', '351', '12', '2077', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28477, to_date('18-12-2077', 'dd-mm-yyyy'), '6', '18', '352', '12', '2077', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28478, to_date('19-12-2077', 'dd-mm-yyyy'), '7', '19', '353', '12', '2077', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28479, to_date('20-12-2077', 'dd-mm-yyyy'), '1', '20', '354', '12', '2077', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28480, to_date('21-12-2077', 'dd-mm-yyyy'), '2', '21', '355', '12', '2077', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28481, to_date('22-12-2077', 'dd-mm-yyyy'), '3', '22', '356', '12', '2077', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28482, to_date('23-12-2077', 'dd-mm-yyyy'), '4', '23', '357', '12', '2077', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28483, to_date('24-12-2077', 'dd-mm-yyyy'), '5', '24', '358', '12', '2077', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28484, to_date('25-12-2077', 'dd-mm-yyyy'), '6', '25', '359', '12', '2077', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28485, to_date('26-12-2077', 'dd-mm-yyyy'), '7', '26', '360', '12', '2077', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28486, to_date('27-12-2077', 'dd-mm-yyyy'), '1', '27', '361', '12', '2077', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28487, to_date('28-12-2077', 'dd-mm-yyyy'), '2', '28', '362', '12', '2077', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28488, to_date('29-12-2077', 'dd-mm-yyyy'), '3', '29', '363', '12', '2077', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29973, to_date('22-01-2082', 'dd-mm-yyyy'), '4', '22', '022', '01', '2082', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29974, to_date('23-01-2082', 'dd-mm-yyyy'), '5', '23', '023', '01', '2082', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29975, to_date('24-01-2082', 'dd-mm-yyyy'), '6', '24', '024', '01', '2082', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29976, to_date('25-01-2082', 'dd-mm-yyyy'), '7', '25', '025', '01', '2082', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29977, to_date('26-01-2082', 'dd-mm-yyyy'), '1', '26', '026', '01', '2082', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29978, to_date('27-01-2082', 'dd-mm-yyyy'), '2', '27', '027', '01', '2082', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29979, to_date('28-01-2082', 'dd-mm-yyyy'), '3', '28', '028', '01', '2082', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29980, to_date('29-01-2082', 'dd-mm-yyyy'), '4', '29', '029', '01', '2082', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29981, to_date('30-01-2082', 'dd-mm-yyyy'), '5', '30', '030', '01', '2082', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29982, to_date('31-01-2082', 'dd-mm-yyyy'), '6', '31', '031', '01', '2082', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29983, to_date('01-02-2082', 'dd-mm-yyyy'), '7', '01', '032', '02', '2082', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29984, to_date('02-02-2082', 'dd-mm-yyyy'), '1', '02', '033', '02', '2082', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29985, to_date('03-02-2082', 'dd-mm-yyyy'), '2', '03', '034', '02', '2082', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29986, to_date('04-02-2082', 'dd-mm-yyyy'), '3', '04', '035', '02', '2082', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29987, to_date('05-02-2082', 'dd-mm-yyyy'), '4', '05', '036', '02', '2082', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29988, to_date('06-02-2082', 'dd-mm-yyyy'), '5', '06', '037', '02', '2082', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29989, to_date('07-02-2082', 'dd-mm-yyyy'), '6', '07', '038', '02', '2082', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29990, to_date('08-02-2082', 'dd-mm-yyyy'), '7', '08', '039', '02', '2082', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29991, to_date('09-02-2082', 'dd-mm-yyyy'), '1', '09', '040', '02', '2082', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29992, to_date('10-02-2082', 'dd-mm-yyyy'), '2', '10', '041', '02', '2082', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29993, to_date('11-02-2082', 'dd-mm-yyyy'), '3', '11', '042', '02', '2082', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29994, to_date('12-02-2082', 'dd-mm-yyyy'), '4', '12', '043', '02', '2082', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29995, to_date('13-02-2082', 'dd-mm-yyyy'), '5', '13', '044', '02', '2082', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29996, to_date('14-02-2082', 'dd-mm-yyyy'), '6', '14', '045', '02', '2082', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29997, to_date('15-02-2082', 'dd-mm-yyyy'), '7', '15', '046', '02', '2082', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29998, to_date('16-02-2082', 'dd-mm-yyyy'), '1', '16', '047', '02', '2082', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29999, to_date('17-02-2082', 'dd-mm-yyyy'), '2', '17', '048', '02', '2082', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30000, to_date('18-02-2082', 'dd-mm-yyyy'), '3', '18', '049', '02', '2082', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30001, to_date('19-02-2082', 'dd-mm-yyyy'), '4', '19', '050', '02', '2082', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30002, to_date('20-02-2082', 'dd-mm-yyyy'), '5', '20', '051', '02', '2082', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30003, to_date('21-02-2082', 'dd-mm-yyyy'), '6', '21', '052', '02', '2082', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30004, to_date('22-02-2082', 'dd-mm-yyyy'), '7', '22', '053', '02', '2082', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30005, to_date('23-02-2082', 'dd-mm-yyyy'), '1', '23', '054', '02', '2082', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30006, to_date('24-02-2082', 'dd-mm-yyyy'), '2', '24', '055', '02', '2082', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30007, to_date('25-02-2082', 'dd-mm-yyyy'), '3', '25', '056', '02', '2082', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30008, to_date('26-02-2082', 'dd-mm-yyyy'), '4', '26', '057', '02', '2082', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30009, to_date('27-02-2082', 'dd-mm-yyyy'), '5', '27', '058', '02', '2082', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30010, to_date('28-02-2082', 'dd-mm-yyyy'), '6', '28', '059', '02', '2082', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30011, to_date('01-03-2082', 'dd-mm-yyyy'), '7', '01', '060', '03', '2082', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30012, to_date('02-03-2082', 'dd-mm-yyyy'), '1', '02', '061', '03', '2082', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30013, to_date('03-03-2082', 'dd-mm-yyyy'), '2', '03', '062', '03', '2082', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30014, to_date('04-03-2082', 'dd-mm-yyyy'), '3', '04', '063', '03', '2082', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30015, to_date('05-03-2082', 'dd-mm-yyyy'), '4', '05', '064', '03', '2082', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30016, to_date('06-03-2082', 'dd-mm-yyyy'), '5', '06', '065', '03', '2082', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30017, to_date('07-03-2082', 'dd-mm-yyyy'), '6', '07', '066', '03', '2082', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30018, to_date('08-03-2082', 'dd-mm-yyyy'), '7', '08', '067', '03', '2082', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30019, to_date('09-03-2082', 'dd-mm-yyyy'), '1', '09', '068', '03', '2082', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30020, to_date('10-03-2082', 'dd-mm-yyyy'), '2', '10', '069', '03', '2082', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30021, to_date('11-03-2082', 'dd-mm-yyyy'), '3', '11', '070', '03', '2082', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30022, to_date('12-03-2082', 'dd-mm-yyyy'), '4', '12', '071', '03', '2082', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30023, to_date('13-03-2082', 'dd-mm-yyyy'), '5', '13', '072', '03', '2082', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30024, to_date('14-03-2082', 'dd-mm-yyyy'), '6', '14', '073', '03', '2082', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30025, to_date('15-03-2082', 'dd-mm-yyyy'), '7', '15', '074', '03', '2082', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30026, to_date('16-03-2082', 'dd-mm-yyyy'), '1', '16', '075', '03', '2082', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30027, to_date('17-03-2082', 'dd-mm-yyyy'), '2', '17', '076', '03', '2082', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30028, to_date('18-03-2082', 'dd-mm-yyyy'), '3', '18', '077', '03', '2082', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30029, to_date('19-03-2082', 'dd-mm-yyyy'), '4', '19', '078', '03', '2082', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30030, to_date('20-03-2082', 'dd-mm-yyyy'), '5', '20', '079', '03', '2082', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30031, to_date('21-03-2082', 'dd-mm-yyyy'), '6', '21', '080', '03', '2082', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30032, to_date('22-03-2082', 'dd-mm-yyyy'), '7', '22', '081', '03', '2082', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30033, to_date('23-03-2082', 'dd-mm-yyyy'), '1', '23', '082', '03', '2082', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30034, to_date('24-03-2082', 'dd-mm-yyyy'), '2', '24', '083', '03', '2082', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30035, to_date('25-03-2082', 'dd-mm-yyyy'), '3', '25', '084', '03', '2082', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30036, to_date('26-03-2082', 'dd-mm-yyyy'), '4', '26', '085', '03', '2082', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30037, to_date('27-03-2082', 'dd-mm-yyyy'), '5', '27', '086', '03', '2082', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30038, to_date('28-03-2082', 'dd-mm-yyyy'), '6', '28', '087', '03', '2082', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30039, to_date('29-03-2082', 'dd-mm-yyyy'), '7', '29', '088', '03', '2082', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30040, to_date('30-03-2082', 'dd-mm-yyyy'), '1', '30', '089', '03', '2082', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30041, to_date('31-03-2082', 'dd-mm-yyyy'), '2', '31', '090', '03', '2082', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30042, to_date('01-04-2082', 'dd-mm-yyyy'), '3', '01', '091', '04', '2082', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30043, to_date('02-04-2082', 'dd-mm-yyyy'), '4', '02', '092', '04', '2082', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30044, to_date('03-04-2082', 'dd-mm-yyyy'), '5', '03', '093', '04', '2082', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30045, to_date('04-04-2082', 'dd-mm-yyyy'), '6', '04', '094', '04', '2082', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30046, to_date('05-04-2082', 'dd-mm-yyyy'), '7', '05', '095', '04', '2082', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30047, to_date('06-04-2082', 'dd-mm-yyyy'), '1', '06', '096', '04', '2082', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30048, to_date('07-04-2082', 'dd-mm-yyyy'), '2', '07', '097', '04', '2082', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30049, to_date('08-04-2082', 'dd-mm-yyyy'), '3', '08', '098', '04', '2082', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30050, to_date('09-04-2082', 'dd-mm-yyyy'), '4', '09', '099', '04', '2082', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30051, to_date('10-04-2082', 'dd-mm-yyyy'), '5', '10', '100', '04', '2082', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30052, to_date('11-04-2082', 'dd-mm-yyyy'), '6', '11', '101', '04', '2082', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30053, to_date('12-04-2082', 'dd-mm-yyyy'), '7', '12', '102', '04', '2082', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30054, to_date('13-04-2082', 'dd-mm-yyyy'), '1', '13', '103', '04', '2082', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30055, to_date('14-04-2082', 'dd-mm-yyyy'), '2', '14', '104', '04', '2082', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30056, to_date('15-04-2082', 'dd-mm-yyyy'), '3', '15', '105', '04', '2082', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30057, to_date('16-04-2082', 'dd-mm-yyyy'), '4', '16', '106', '04', '2082', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30058, to_date('17-04-2082', 'dd-mm-yyyy'), '5', '17', '107', '04', '2082', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30059, to_date('18-04-2082', 'dd-mm-yyyy'), '6', '18', '108', '04', '2082', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30060, to_date('19-04-2082', 'dd-mm-yyyy'), '7', '19', '109', '04', '2082', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30061, to_date('20-04-2082', 'dd-mm-yyyy'), '1', '20', '110', '04', '2082', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30062, to_date('21-04-2082', 'dd-mm-yyyy'), '2', '21', '111', '04', '2082', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30063, to_date('22-04-2082', 'dd-mm-yyyy'), '3', '22', '112', '04', '2082', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30064, to_date('23-04-2082', 'dd-mm-yyyy'), '4', '23', '113', '04', '2082', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30065, to_date('24-04-2082', 'dd-mm-yyyy'), '5', '24', '114', '04', '2082', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30066, to_date('25-04-2082', 'dd-mm-yyyy'), '6', '25', '115', '04', '2082', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30067, to_date('26-04-2082', 'dd-mm-yyyy'), '7', '26', '116', '04', '2082', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30068, to_date('27-04-2082', 'dd-mm-yyyy'), '1', '27', '117', '04', '2082', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30069, to_date('28-04-2082', 'dd-mm-yyyy'), '2', '28', '118', '04', '2082', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30070, to_date('29-04-2082', 'dd-mm-yyyy'), '3', '29', '119', '04', '2082', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30071, to_date('30-04-2082', 'dd-mm-yyyy'), '4', '30', '120', '04', '2082', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30072, to_date('01-05-2082', 'dd-mm-yyyy'), '5', '01', '121', '05', '2082', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30073, to_date('02-05-2082', 'dd-mm-yyyy'), '6', '02', '122', '05', '2082', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30074, to_date('03-05-2082', 'dd-mm-yyyy'), '7', '03', '123', '05', '2082', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30075, to_date('04-05-2082', 'dd-mm-yyyy'), '1', '04', '124', '05', '2082', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30076, to_date('05-05-2082', 'dd-mm-yyyy'), '2', '05', '125', '05', '2082', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30077, to_date('06-05-2082', 'dd-mm-yyyy'), '3', '06', '126', '05', '2082', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30078, to_date('07-05-2082', 'dd-mm-yyyy'), '4', '07', '127', '05', '2082', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31563, to_date('31-05-2086', 'dd-mm-yyyy'), '5', '31', '151', '05', '2086', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31564, to_date('01-06-2086', 'dd-mm-yyyy'), '6', '01', '152', '06', '2086', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31565, to_date('02-06-2086', 'dd-mm-yyyy'), '7', '02', '153', '06', '2086', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31566, to_date('03-06-2086', 'dd-mm-yyyy'), '1', '03', '154', '06', '2086', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31567, to_date('04-06-2086', 'dd-mm-yyyy'), '2', '04', '155', '06', '2086', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31568, to_date('05-06-2086', 'dd-mm-yyyy'), '3', '05', '156', '06', '2086', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31569, to_date('06-06-2086', 'dd-mm-yyyy'), '4', '06', '157', '06', '2086', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31570, to_date('07-06-2086', 'dd-mm-yyyy'), '5', '07', '158', '06', '2086', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31571, to_date('08-06-2086', 'dd-mm-yyyy'), '6', '08', '159', '06', '2086', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31572, to_date('09-06-2086', 'dd-mm-yyyy'), '7', '09', '160', '06', '2086', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31573, to_date('10-06-2086', 'dd-mm-yyyy'), '1', '10', '161', '06', '2086', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31574, to_date('11-06-2086', 'dd-mm-yyyy'), '2', '11', '162', '06', '2086', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31575, to_date('12-06-2086', 'dd-mm-yyyy'), '3', '12', '163', '06', '2086', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31576, to_date('13-06-2086', 'dd-mm-yyyy'), '4', '13', '164', '06', '2086', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31577, to_date('14-06-2086', 'dd-mm-yyyy'), '5', '14', '165', '06', '2086', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31578, to_date('15-06-2086', 'dd-mm-yyyy'), '6', '15', '166', '06', '2086', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31579, to_date('16-06-2086', 'dd-mm-yyyy'), '7', '16', '167', '06', '2086', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31580, to_date('17-06-2086', 'dd-mm-yyyy'), '1', '17', '168', '06', '2086', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31581, to_date('18-06-2086', 'dd-mm-yyyy'), '2', '18', '169', '06', '2086', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31582, to_date('19-06-2086', 'dd-mm-yyyy'), '3', '19', '170', '06', '2086', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31583, to_date('20-06-2086', 'dd-mm-yyyy'), '4', '20', '171', '06', '2086', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31584, to_date('21-06-2086', 'dd-mm-yyyy'), '5', '21', '172', '06', '2086', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31585, to_date('22-06-2086', 'dd-mm-yyyy'), '6', '22', '173', '06', '2086', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31586, to_date('23-06-2086', 'dd-mm-yyyy'), '7', '23', '174', '06', '2086', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31587, to_date('24-06-2086', 'dd-mm-yyyy'), '1', '24', '175', '06', '2086', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31588, to_date('25-06-2086', 'dd-mm-yyyy'), '2', '25', '176', '06', '2086', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31589, to_date('26-06-2086', 'dd-mm-yyyy'), '3', '26', '177', '06', '2086', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31590, to_date('27-06-2086', 'dd-mm-yyyy'), '4', '27', '178', '06', '2086', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31591, to_date('28-06-2086', 'dd-mm-yyyy'), '5', '28', '179', '06', '2086', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31592, to_date('29-06-2086', 'dd-mm-yyyy'), '6', '29', '180', '06', '2086', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31593, to_date('30-06-2086', 'dd-mm-yyyy'), '7', '30', '181', '06', '2086', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31594, to_date('01-07-2086', 'dd-mm-yyyy'), '1', '01', '182', '07', '2086', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31595, to_date('02-07-2086', 'dd-mm-yyyy'), '2', '02', '183', '07', '2086', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31596, to_date('03-07-2086', 'dd-mm-yyyy'), '3', '03', '184', '07', '2086', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31597, to_date('04-07-2086', 'dd-mm-yyyy'), '4', '04', '185', '07', '2086', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31598, to_date('05-07-2086', 'dd-mm-yyyy'), '5', '05', '186', '07', '2086', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31599, to_date('06-07-2086', 'dd-mm-yyyy'), '6', '06', '187', '07', '2086', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31600, to_date('07-07-2086', 'dd-mm-yyyy'), '7', '07', '188', '07', '2086', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31601, to_date('08-07-2086', 'dd-mm-yyyy'), '1', '08', '189', '07', '2086', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31602, to_date('09-07-2086', 'dd-mm-yyyy'), '2', '09', '190', '07', '2086', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31603, to_date('10-07-2086', 'dd-mm-yyyy'), '3', '10', '191', '07', '2086', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31604, to_date('11-07-2086', 'dd-mm-yyyy'), '4', '11', '192', '07', '2086', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31605, to_date('12-07-2086', 'dd-mm-yyyy'), '5', '12', '193', '07', '2086', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31606, to_date('13-07-2086', 'dd-mm-yyyy'), '6', '13', '194', '07', '2086', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31607, to_date('14-07-2086', 'dd-mm-yyyy'), '7', '14', '195', '07', '2086', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31608, to_date('15-07-2086', 'dd-mm-yyyy'), '1', '15', '196', '07', '2086', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31609, to_date('16-07-2086', 'dd-mm-yyyy'), '2', '16', '197', '07', '2086', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31610, to_date('17-07-2086', 'dd-mm-yyyy'), '3', '17', '198', '07', '2086', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31611, to_date('18-07-2086', 'dd-mm-yyyy'), '4', '18', '199', '07', '2086', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31612, to_date('19-07-2086', 'dd-mm-yyyy'), '5', '19', '200', '07', '2086', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31613, to_date('20-07-2086', 'dd-mm-yyyy'), '6', '20', '201', '07', '2086', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31614, to_date('21-07-2086', 'dd-mm-yyyy'), '7', '21', '202', '07', '2086', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31615, to_date('22-07-2086', 'dd-mm-yyyy'), '1', '22', '203', '07', '2086', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31616, to_date('23-07-2086', 'dd-mm-yyyy'), '2', '23', '204', '07', '2086', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31617, to_date('24-07-2086', 'dd-mm-yyyy'), '3', '24', '205', '07', '2086', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31618, to_date('25-07-2086', 'dd-mm-yyyy'), '4', '25', '206', '07', '2086', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31619, to_date('26-07-2086', 'dd-mm-yyyy'), '5', '26', '207', '07', '2086', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31620, to_date('27-07-2086', 'dd-mm-yyyy'), '6', '27', '208', '07', '2086', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31621, to_date('28-07-2086', 'dd-mm-yyyy'), '7', '28', '209', '07', '2086', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31622, to_date('29-07-2086', 'dd-mm-yyyy'), '1', '29', '210', '07', '2086', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31623, to_date('30-07-2086', 'dd-mm-yyyy'), '2', '30', '211', '07', '2086', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31624, to_date('31-07-2086', 'dd-mm-yyyy'), '3', '31', '212', '07', '2086', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31625, to_date('01-08-2086', 'dd-mm-yyyy'), '4', '01', '213', '08', '2086', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31626, to_date('02-08-2086', 'dd-mm-yyyy'), '5', '02', '214', '08', '2086', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31627, to_date('03-08-2086', 'dd-mm-yyyy'), '6', '03', '215', '08', '2086', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31628, to_date('04-08-2086', 'dd-mm-yyyy'), '7', '04', '216', '08', '2086', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31629, to_date('05-08-2086', 'dd-mm-yyyy'), '1', '05', '217', '08', '2086', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31630, to_date('06-08-2086', 'dd-mm-yyyy'), '2', '06', '218', '08', '2086', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31631, to_date('07-08-2086', 'dd-mm-yyyy'), '3', '07', '219', '08', '2086', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31632, to_date('08-08-2086', 'dd-mm-yyyy'), '4', '08', '220', '08', '2086', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31633, to_date('09-08-2086', 'dd-mm-yyyy'), '5', '09', '221', '08', '2086', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31634, to_date('10-08-2086', 'dd-mm-yyyy'), '6', '10', '222', '08', '2086', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31635, to_date('11-08-2086', 'dd-mm-yyyy'), '7', '11', '223', '08', '2086', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31636, to_date('12-08-2086', 'dd-mm-yyyy'), '1', '12', '224', '08', '2086', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31637, to_date('13-08-2086', 'dd-mm-yyyy'), '2', '13', '225', '08', '2086', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31638, to_date('14-08-2086', 'dd-mm-yyyy'), '3', '14', '226', '08', '2086', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31639, to_date('15-08-2086', 'dd-mm-yyyy'), '4', '15', '227', '08', '2086', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31640, to_date('16-08-2086', 'dd-mm-yyyy'), '5', '16', '228', '08', '2086', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31641, to_date('17-08-2086', 'dd-mm-yyyy'), '6', '17', '229', '08', '2086', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31642, to_date('18-08-2086', 'dd-mm-yyyy'), '7', '18', '230', '08', '2086', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31643, to_date('19-08-2086', 'dd-mm-yyyy'), '1', '19', '231', '08', '2086', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31644, to_date('20-08-2086', 'dd-mm-yyyy'), '2', '20', '232', '08', '2086', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31645, to_date('21-08-2086', 'dd-mm-yyyy'), '3', '21', '233', '08', '2086', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31646, to_date('22-08-2086', 'dd-mm-yyyy'), '4', '22', '234', '08', '2086', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31647, to_date('23-08-2086', 'dd-mm-yyyy'), '5', '23', '235', '08', '2086', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31648, to_date('24-08-2086', 'dd-mm-yyyy'), '6', '24', '236', '08', '2086', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31649, to_date('25-08-2086', 'dd-mm-yyyy'), '7', '25', '237', '08', '2086', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31650, to_date('26-08-2086', 'dd-mm-yyyy'), '1', '26', '238', '08', '2086', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31651, to_date('27-08-2086', 'dd-mm-yyyy'), '2', '27', '239', '08', '2086', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31652, to_date('28-08-2086', 'dd-mm-yyyy'), '3', '28', '240', '08', '2086', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31653, to_date('29-08-2086', 'dd-mm-yyyy'), '4', '29', '241', '08', '2086', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31654, to_date('30-08-2086', 'dd-mm-yyyy'), '5', '30', '242', '08', '2086', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31655, to_date('31-08-2086', 'dd-mm-yyyy'), '6', '31', '243', '08', '2086', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31656, to_date('01-09-2086', 'dd-mm-yyyy'), '7', '01', '244', '09', '2086', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31657, to_date('02-09-2086', 'dd-mm-yyyy'), '1', '02', '245', '09', '2086', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31658, to_date('03-09-2086', 'dd-mm-yyyy'), '2', '03', '246', '09', '2086', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31659, to_date('04-09-2086', 'dd-mm-yyyy'), '3', '04', '247', '09', '2086', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31660, to_date('05-09-2086', 'dd-mm-yyyy'), '4', '05', '248', '09', '2086', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31661, to_date('06-09-2086', 'dd-mm-yyyy'), '5', '06', '249', '09', '2086', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31662, to_date('07-09-2086', 'dd-mm-yyyy'), '6', '07', '250', '09', '2086', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31663, to_date('08-09-2086', 'dd-mm-yyyy'), '7', '08', '251', '09', '2086', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31664, to_date('09-09-2086', 'dd-mm-yyyy'), '1', '09', '252', '09', '2086', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31665, to_date('10-09-2086', 'dd-mm-yyyy'), '2', '10', '253', '09', '2086', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31666, to_date('11-09-2086', 'dd-mm-yyyy'), '3', '11', '254', '09', '2086', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31667, to_date('12-09-2086', 'dd-mm-yyyy'), '4', '12', '255', '09', '2086', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31668, to_date('13-09-2086', 'dd-mm-yyyy'), '5', '13', '256', '09', '2086', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26793, to_date('09-05-2073', 'dd-mm-yyyy'), '2', '09', '129', '05', '2073', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26794, to_date('10-05-2073', 'dd-mm-yyyy'), '3', '10', '130', '05', '2073', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26795, to_date('11-05-2073', 'dd-mm-yyyy'), '4', '11', '131', '05', '2073', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26796, to_date('12-05-2073', 'dd-mm-yyyy'), '5', '12', '132', '05', '2073', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26797, to_date('13-05-2073', 'dd-mm-yyyy'), '6', '13', '133', '05', '2073', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26798, to_date('14-05-2073', 'dd-mm-yyyy'), '7', '14', '134', '05', '2073', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26799, to_date('15-05-2073', 'dd-mm-yyyy'), '1', '15', '135', '05', '2073', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26800, to_date('16-05-2073', 'dd-mm-yyyy'), '2', '16', '136', '05', '2073', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26801, to_date('17-05-2073', 'dd-mm-yyyy'), '3', '17', '137', '05', '2073', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26802, to_date('18-05-2073', 'dd-mm-yyyy'), '4', '18', '138', '05', '2073', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26803, to_date('19-05-2073', 'dd-mm-yyyy'), '5', '19', '139', '05', '2073', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26804, to_date('20-05-2073', 'dd-mm-yyyy'), '6', '20', '140', '05', '2073', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26805, to_date('21-05-2073', 'dd-mm-yyyy'), '7', '21', '141', '05', '2073', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26806, to_date('22-05-2073', 'dd-mm-yyyy'), '1', '22', '142', '05', '2073', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26807, to_date('23-05-2073', 'dd-mm-yyyy'), '2', '23', '143', '05', '2073', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26808, to_date('24-05-2073', 'dd-mm-yyyy'), '3', '24', '144', '05', '2073', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26809, to_date('25-05-2073', 'dd-mm-yyyy'), '4', '25', '145', '05', '2073', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26810, to_date('26-05-2073', 'dd-mm-yyyy'), '5', '26', '146', '05', '2073', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26811, to_date('27-05-2073', 'dd-mm-yyyy'), '6', '27', '147', '05', '2073', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26812, to_date('28-05-2073', 'dd-mm-yyyy'), '7', '28', '148', '05', '2073', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26813, to_date('29-05-2073', 'dd-mm-yyyy'), '1', '29', '149', '05', '2073', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26814, to_date('30-05-2073', 'dd-mm-yyyy'), '2', '30', '150', '05', '2073', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26815, to_date('31-05-2073', 'dd-mm-yyyy'), '3', '31', '151', '05', '2073', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26816, to_date('01-06-2073', 'dd-mm-yyyy'), '4', '01', '152', '06', '2073', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26817, to_date('02-06-2073', 'dd-mm-yyyy'), '5', '02', '153', '06', '2073', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26818, to_date('03-06-2073', 'dd-mm-yyyy'), '6', '03', '154', '06', '2073', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26819, to_date('04-06-2073', 'dd-mm-yyyy'), '7', '04', '155', '06', '2073', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26820, to_date('05-06-2073', 'dd-mm-yyyy'), '1', '05', '156', '06', '2073', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26821, to_date('06-06-2073', 'dd-mm-yyyy'), '2', '06', '157', '06', '2073', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26822, to_date('07-06-2073', 'dd-mm-yyyy'), '3', '07', '158', '06', '2073', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26823, to_date('08-06-2073', 'dd-mm-yyyy'), '4', '08', '159', '06', '2073', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26824, to_date('09-06-2073', 'dd-mm-yyyy'), '5', '09', '160', '06', '2073', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26825, to_date('10-06-2073', 'dd-mm-yyyy'), '6', '10', '161', '06', '2073', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26826, to_date('11-06-2073', 'dd-mm-yyyy'), '7', '11', '162', '06', '2073', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26827, to_date('12-06-2073', 'dd-mm-yyyy'), '1', '12', '163', '06', '2073', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26828, to_date('13-06-2073', 'dd-mm-yyyy'), '2', '13', '164', '06', '2073', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26829, to_date('14-06-2073', 'dd-mm-yyyy'), '3', '14', '165', '06', '2073', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26830, to_date('15-06-2073', 'dd-mm-yyyy'), '4', '15', '166', '06', '2073', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26831, to_date('16-06-2073', 'dd-mm-yyyy'), '5', '16', '167', '06', '2073', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26832, to_date('17-06-2073', 'dd-mm-yyyy'), '6', '17', '168', '06', '2073', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26833, to_date('18-06-2073', 'dd-mm-yyyy'), '7', '18', '169', '06', '2073', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26834, to_date('19-06-2073', 'dd-mm-yyyy'), '1', '19', '170', '06', '2073', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26835, to_date('20-06-2073', 'dd-mm-yyyy'), '2', '20', '171', '06', '2073', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26836, to_date('21-06-2073', 'dd-mm-yyyy'), '3', '21', '172', '06', '2073', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26837, to_date('22-06-2073', 'dd-mm-yyyy'), '4', '22', '173', '06', '2073', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26838, to_date('23-06-2073', 'dd-mm-yyyy'), '5', '23', '174', '06', '2073', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26839, to_date('24-06-2073', 'dd-mm-yyyy'), '6', '24', '175', '06', '2073', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26840, to_date('25-06-2073', 'dd-mm-yyyy'), '7', '25', '176', '06', '2073', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26841, to_date('26-06-2073', 'dd-mm-yyyy'), '1', '26', '177', '06', '2073', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26842, to_date('27-06-2073', 'dd-mm-yyyy'), '2', '27', '178', '06', '2073', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26843, to_date('28-06-2073', 'dd-mm-yyyy'), '3', '28', '179', '06', '2073', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26844, to_date('29-06-2073', 'dd-mm-yyyy'), '4', '29', '180', '06', '2073', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26845, to_date('30-06-2073', 'dd-mm-yyyy'), '5', '30', '181', '06', '2073', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26846, to_date('01-07-2073', 'dd-mm-yyyy'), '6', '01', '182', '07', '2073', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26847, to_date('02-07-2073', 'dd-mm-yyyy'), '7', '02', '183', '07', '2073', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26848, to_date('03-07-2073', 'dd-mm-yyyy'), '1', '03', '184', '07', '2073', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26849, to_date('04-07-2073', 'dd-mm-yyyy'), '2', '04', '185', '07', '2073', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26850, to_date('05-07-2073', 'dd-mm-yyyy'), '3', '05', '186', '07', '2073', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26851, to_date('06-07-2073', 'dd-mm-yyyy'), '4', '06', '187', '07', '2073', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26852, to_date('07-07-2073', 'dd-mm-yyyy'), '5', '07', '188', '07', '2073', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26853, to_date('08-07-2073', 'dd-mm-yyyy'), '6', '08', '189', '07', '2073', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26854, to_date('09-07-2073', 'dd-mm-yyyy'), '7', '09', '190', '07', '2073', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26855, to_date('10-07-2073', 'dd-mm-yyyy'), '1', '10', '191', '07', '2073', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26856, to_date('11-07-2073', 'dd-mm-yyyy'), '2', '11', '192', '07', '2073', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26857, to_date('12-07-2073', 'dd-mm-yyyy'), '3', '12', '193', '07', '2073', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26858, to_date('13-07-2073', 'dd-mm-yyyy'), '4', '13', '194', '07', '2073', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26859, to_date('14-07-2073', 'dd-mm-yyyy'), '5', '14', '195', '07', '2073', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26860, to_date('15-07-2073', 'dd-mm-yyyy'), '6', '15', '196', '07', '2073', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26861, to_date('16-07-2073', 'dd-mm-yyyy'), '7', '16', '197', '07', '2073', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26862, to_date('17-07-2073', 'dd-mm-yyyy'), '1', '17', '198', '07', '2073', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26863, to_date('18-07-2073', 'dd-mm-yyyy'), '2', '18', '199', '07', '2073', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26864, to_date('19-07-2073', 'dd-mm-yyyy'), '3', '19', '200', '07', '2073', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26865, to_date('20-07-2073', 'dd-mm-yyyy'), '4', '20', '201', '07', '2073', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26866, to_date('21-07-2073', 'dd-mm-yyyy'), '5', '21', '202', '07', '2073', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26867, to_date('22-07-2073', 'dd-mm-yyyy'), '6', '22', '203', '07', '2073', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26868, to_date('23-07-2073', 'dd-mm-yyyy'), '7', '23', '204', '07', '2073', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26869, to_date('24-07-2073', 'dd-mm-yyyy'), '1', '24', '205', '07', '2073', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26870, to_date('25-07-2073', 'dd-mm-yyyy'), '2', '25', '206', '07', '2073', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26871, to_date('26-07-2073', 'dd-mm-yyyy'), '3', '26', '207', '07', '2073', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26872, to_date('27-07-2073', 'dd-mm-yyyy'), '4', '27', '208', '07', '2073', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26873, to_date('28-07-2073', 'dd-mm-yyyy'), '5', '28', '209', '07', '2073', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26874, to_date('29-07-2073', 'dd-mm-yyyy'), '6', '29', '210', '07', '2073', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26875, to_date('30-07-2073', 'dd-mm-yyyy'), '7', '30', '211', '07', '2073', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26876, to_date('31-07-2073', 'dd-mm-yyyy'), '1', '31', '212', '07', '2073', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26877, to_date('01-08-2073', 'dd-mm-yyyy'), '2', '01', '213', '08', '2073', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26878, to_date('02-08-2073', 'dd-mm-yyyy'), '3', '02', '214', '08', '2073', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26879, to_date('03-08-2073', 'dd-mm-yyyy'), '4', '03', '215', '08', '2073', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26880, to_date('04-08-2073', 'dd-mm-yyyy'), '5', '04', '216', '08', '2073', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26881, to_date('05-08-2073', 'dd-mm-yyyy'), '6', '05', '217', '08', '2073', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26882, to_date('06-08-2073', 'dd-mm-yyyy'), '7', '06', '218', '08', '2073', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26883, to_date('07-08-2073', 'dd-mm-yyyy'), '1', '07', '219', '08', '2073', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26884, to_date('08-08-2073', 'dd-mm-yyyy'), '2', '08', '220', '08', '2073', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26885, to_date('09-08-2073', 'dd-mm-yyyy'), '3', '09', '221', '08', '2073', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26886, to_date('10-08-2073', 'dd-mm-yyyy'), '4', '10', '222', '08', '2073', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26887, to_date('11-08-2073', 'dd-mm-yyyy'), '5', '11', '223', '08', '2073', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26888, to_date('12-08-2073', 'dd-mm-yyyy'), '6', '12', '224', '08', '2073', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26889, to_date('13-08-2073', 'dd-mm-yyyy'), '7', '13', '225', '08', '2073', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26890, to_date('14-08-2073', 'dd-mm-yyyy'), '1', '14', '226', '08', '2073', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26891, to_date('15-08-2073', 'dd-mm-yyyy'), '2', '15', '227', '08', '2073', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26892, to_date('16-08-2073', 'dd-mm-yyyy'), '3', '16', '228', '08', '2073', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26893, to_date('17-08-2073', 'dd-mm-yyyy'), '4', '17', '229', '08', '2073', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26894, to_date('18-08-2073', 'dd-mm-yyyy'), '5', '18', '230', '08', '2073', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26895, to_date('19-08-2073', 'dd-mm-yyyy'), '6', '19', '231', '08', '2073', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26896, to_date('20-08-2073', 'dd-mm-yyyy'), '7', '20', '232', '08', '2073', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26897, to_date('21-08-2073', 'dd-mm-yyyy'), '1', '21', '233', '08', '2073', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26898, to_date('22-08-2073', 'dd-mm-yyyy'), '2', '22', '234', '08', '2073', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28489, to_date('30-12-2077', 'dd-mm-yyyy'), '4', '30', '364', '12', '2077', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28490, to_date('31-12-2077', 'dd-mm-yyyy'), '5', '31', '365', '12', '2077', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28491, to_date('01-01-2078', 'dd-mm-yyyy'), '6', '01', '001', '01', '2078', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28492, to_date('02-01-2078', 'dd-mm-yyyy'), '7', '02', '002', '01', '2078', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28493, to_date('03-01-2078', 'dd-mm-yyyy'), '1', '03', '003', '01', '2078', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28494, to_date('04-01-2078', 'dd-mm-yyyy'), '2', '04', '004', '01', '2078', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28495, to_date('05-01-2078', 'dd-mm-yyyy'), '3', '05', '005', '01', '2078', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28496, to_date('06-01-2078', 'dd-mm-yyyy'), '4', '06', '006', '01', '2078', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28497, to_date('07-01-2078', 'dd-mm-yyyy'), '5', '07', '007', '01', '2078', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28498, to_date('08-01-2078', 'dd-mm-yyyy'), '6', '08', '008', '01', '2078', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28499, to_date('09-01-2078', 'dd-mm-yyyy'), '7', '09', '009', '01', '2078', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28500, to_date('10-01-2078', 'dd-mm-yyyy'), '1', '10', '010', '01', '2078', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28501, to_date('11-01-2078', 'dd-mm-yyyy'), '2', '11', '011', '01', '2078', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28502, to_date('12-01-2078', 'dd-mm-yyyy'), '3', '12', '012', '01', '2078', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28503, to_date('13-01-2078', 'dd-mm-yyyy'), '4', '13', '013', '01', '2078', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28504, to_date('14-01-2078', 'dd-mm-yyyy'), '5', '14', '014', '01', '2078', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28505, to_date('15-01-2078', 'dd-mm-yyyy'), '6', '15', '015', '01', '2078', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28506, to_date('16-01-2078', 'dd-mm-yyyy'), '7', '16', '016', '01', '2078', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28507, to_date('17-01-2078', 'dd-mm-yyyy'), '1', '17', '017', '01', '2078', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28508, to_date('18-01-2078', 'dd-mm-yyyy'), '2', '18', '018', '01', '2078', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28509, to_date('19-01-2078', 'dd-mm-yyyy'), '3', '19', '019', '01', '2078', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28510, to_date('20-01-2078', 'dd-mm-yyyy'), '4', '20', '020', '01', '2078', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28511, to_date('21-01-2078', 'dd-mm-yyyy'), '5', '21', '021', '01', '2078', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28512, to_date('22-01-2078', 'dd-mm-yyyy'), '6', '22', '022', '01', '2078', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28513, to_date('23-01-2078', 'dd-mm-yyyy'), '7', '23', '023', '01', '2078', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28514, to_date('24-01-2078', 'dd-mm-yyyy'), '1', '24', '024', '01', '2078', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28515, to_date('25-01-2078', 'dd-mm-yyyy'), '2', '25', '025', '01', '2078', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28516, to_date('26-01-2078', 'dd-mm-yyyy'), '3', '26', '026', '01', '2078', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28517, to_date('27-01-2078', 'dd-mm-yyyy'), '4', '27', '027', '01', '2078', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28518, to_date('28-01-2078', 'dd-mm-yyyy'), '5', '28', '028', '01', '2078', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28519, to_date('29-01-2078', 'dd-mm-yyyy'), '6', '29', '029', '01', '2078', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28520, to_date('30-01-2078', 'dd-mm-yyyy'), '7', '30', '030', '01', '2078', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28521, to_date('31-01-2078', 'dd-mm-yyyy'), '1', '31', '031', '01', '2078', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28522, to_date('01-02-2078', 'dd-mm-yyyy'), '2', '01', '032', '02', '2078', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28523, to_date('02-02-2078', 'dd-mm-yyyy'), '3', '02', '033', '02', '2078', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28524, to_date('03-02-2078', 'dd-mm-yyyy'), '4', '03', '034', '02', '2078', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28525, to_date('04-02-2078', 'dd-mm-yyyy'), '5', '04', '035', '02', '2078', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28526, to_date('05-02-2078', 'dd-mm-yyyy'), '6', '05', '036', '02', '2078', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28527, to_date('06-02-2078', 'dd-mm-yyyy'), '7', '06', '037', '02', '2078', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28528, to_date('07-02-2078', 'dd-mm-yyyy'), '1', '07', '038', '02', '2078', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28529, to_date('08-02-2078', 'dd-mm-yyyy'), '2', '08', '039', '02', '2078', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28530, to_date('09-02-2078', 'dd-mm-yyyy'), '3', '09', '040', '02', '2078', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28531, to_date('10-02-2078', 'dd-mm-yyyy'), '4', '10', '041', '02', '2078', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28532, to_date('11-02-2078', 'dd-mm-yyyy'), '5', '11', '042', '02', '2078', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28533, to_date('12-02-2078', 'dd-mm-yyyy'), '6', '12', '043', '02', '2078', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28534, to_date('13-02-2078', 'dd-mm-yyyy'), '7', '13', '044', '02', '2078', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28535, to_date('14-02-2078', 'dd-mm-yyyy'), '1', '14', '045', '02', '2078', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28536, to_date('15-02-2078', 'dd-mm-yyyy'), '2', '15', '046', '02', '2078', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28537, to_date('16-02-2078', 'dd-mm-yyyy'), '3', '16', '047', '02', '2078', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28538, to_date('17-02-2078', 'dd-mm-yyyy'), '4', '17', '048', '02', '2078', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28539, to_date('18-02-2078', 'dd-mm-yyyy'), '5', '18', '049', '02', '2078', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28540, to_date('19-02-2078', 'dd-mm-yyyy'), '6', '19', '050', '02', '2078', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28541, to_date('20-02-2078', 'dd-mm-yyyy'), '7', '20', '051', '02', '2078', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28542, to_date('21-02-2078', 'dd-mm-yyyy'), '1', '21', '052', '02', '2078', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28543, to_date('22-02-2078', 'dd-mm-yyyy'), '2', '22', '053', '02', '2078', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28544, to_date('23-02-2078', 'dd-mm-yyyy'), '3', '23', '054', '02', '2078', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28545, to_date('24-02-2078', 'dd-mm-yyyy'), '4', '24', '055', '02', '2078', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28546, to_date('25-02-2078', 'dd-mm-yyyy'), '5', '25', '056', '02', '2078', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28547, to_date('26-02-2078', 'dd-mm-yyyy'), '6', '26', '057', '02', '2078', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28548, to_date('27-02-2078', 'dd-mm-yyyy'), '7', '27', '058', '02', '2078', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28549, to_date('28-02-2078', 'dd-mm-yyyy'), '1', '28', '059', '02', '2078', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28550, to_date('01-03-2078', 'dd-mm-yyyy'), '2', '01', '060', '03', '2078', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28551, to_date('02-03-2078', 'dd-mm-yyyy'), '3', '02', '061', '03', '2078', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28552, to_date('03-03-2078', 'dd-mm-yyyy'), '4', '03', '062', '03', '2078', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28553, to_date('04-03-2078', 'dd-mm-yyyy'), '5', '04', '063', '03', '2078', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28554, to_date('05-03-2078', 'dd-mm-yyyy'), '6', '05', '064', '03', '2078', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28555, to_date('06-03-2078', 'dd-mm-yyyy'), '7', '06', '065', '03', '2078', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28556, to_date('07-03-2078', 'dd-mm-yyyy'), '1', '07', '066', '03', '2078', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28557, to_date('08-03-2078', 'dd-mm-yyyy'), '2', '08', '067', '03', '2078', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28558, to_date('09-03-2078', 'dd-mm-yyyy'), '3', '09', '068', '03', '2078', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28559, to_date('10-03-2078', 'dd-mm-yyyy'), '4', '10', '069', '03', '2078', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28560, to_date('11-03-2078', 'dd-mm-yyyy'), '5', '11', '070', '03', '2078', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28561, to_date('12-03-2078', 'dd-mm-yyyy'), '6', '12', '071', '03', '2078', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28562, to_date('13-03-2078', 'dd-mm-yyyy'), '7', '13', '072', '03', '2078', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28563, to_date('14-03-2078', 'dd-mm-yyyy'), '1', '14', '073', '03', '2078', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28564, to_date('15-03-2078', 'dd-mm-yyyy'), '2', '15', '074', '03', '2078', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28565, to_date('16-03-2078', 'dd-mm-yyyy'), '3', '16', '075', '03', '2078', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28566, to_date('17-03-2078', 'dd-mm-yyyy'), '4', '17', '076', '03', '2078', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28567, to_date('18-03-2078', 'dd-mm-yyyy'), '5', '18', '077', '03', '2078', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28568, to_date('19-03-2078', 'dd-mm-yyyy'), '6', '19', '078', '03', '2078', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28569, to_date('20-03-2078', 'dd-mm-yyyy'), '7', '20', '079', '03', '2078', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28570, to_date('21-03-2078', 'dd-mm-yyyy'), '1', '21', '080', '03', '2078', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28571, to_date('22-03-2078', 'dd-mm-yyyy'), '2', '22', '081', '03', '2078', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28572, to_date('23-03-2078', 'dd-mm-yyyy'), '3', '23', '082', '03', '2078', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28573, to_date('24-03-2078', 'dd-mm-yyyy'), '4', '24', '083', '03', '2078', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28574, to_date('25-03-2078', 'dd-mm-yyyy'), '5', '25', '084', '03', '2078', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28575, to_date('26-03-2078', 'dd-mm-yyyy'), '6', '26', '085', '03', '2078', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28576, to_date('27-03-2078', 'dd-mm-yyyy'), '7', '27', '086', '03', '2078', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28577, to_date('28-03-2078', 'dd-mm-yyyy'), '1', '28', '087', '03', '2078', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28578, to_date('29-03-2078', 'dd-mm-yyyy'), '2', '29', '088', '03', '2078', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28579, to_date('30-03-2078', 'dd-mm-yyyy'), '3', '30', '089', '03', '2078', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28580, to_date('31-03-2078', 'dd-mm-yyyy'), '4', '31', '090', '03', '2078', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28581, to_date('01-04-2078', 'dd-mm-yyyy'), '5', '01', '091', '04', '2078', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28582, to_date('02-04-2078', 'dd-mm-yyyy'), '6', '02', '092', '04', '2078', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28583, to_date('03-04-2078', 'dd-mm-yyyy'), '7', '03', '093', '04', '2078', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28584, to_date('04-04-2078', 'dd-mm-yyyy'), '1', '04', '094', '04', '2078', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28585, to_date('05-04-2078', 'dd-mm-yyyy'), '2', '05', '095', '04', '2078', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28586, to_date('06-04-2078', 'dd-mm-yyyy'), '3', '06', '096', '04', '2078', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28587, to_date('07-04-2078', 'dd-mm-yyyy'), '4', '07', '097', '04', '2078', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28588, to_date('08-04-2078', 'dd-mm-yyyy'), '5', '08', '098', '04', '2078', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28589, to_date('09-04-2078', 'dd-mm-yyyy'), '6', '09', '099', '04', '2078', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28590, to_date('10-04-2078', 'dd-mm-yyyy'), '7', '10', '100', '04', '2078', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28591, to_date('11-04-2078', 'dd-mm-yyyy'), '1', '11', '101', '04', '2078', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28592, to_date('12-04-2078', 'dd-mm-yyyy'), '2', '12', '102', '04', '2078', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28593, to_date('13-04-2078', 'dd-mm-yyyy'), '3', '13', '103', '04', '2078', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28594, to_date('14-04-2078', 'dd-mm-yyyy'), '4', '14', '104', '04', '2078', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30079, to_date('08-05-2082', 'dd-mm-yyyy'), '5', '08', '128', '05', '2082', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30080, to_date('09-05-2082', 'dd-mm-yyyy'), '6', '09', '129', '05', '2082', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30081, to_date('10-05-2082', 'dd-mm-yyyy'), '7', '10', '130', '05', '2082', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30082, to_date('11-05-2082', 'dd-mm-yyyy'), '1', '11', '131', '05', '2082', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30083, to_date('12-05-2082', 'dd-mm-yyyy'), '2', '12', '132', '05', '2082', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30084, to_date('13-05-2082', 'dd-mm-yyyy'), '3', '13', '133', '05', '2082', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30085, to_date('14-05-2082', 'dd-mm-yyyy'), '4', '14', '134', '05', '2082', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30086, to_date('15-05-2082', 'dd-mm-yyyy'), '5', '15', '135', '05', '2082', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30087, to_date('16-05-2082', 'dd-mm-yyyy'), '6', '16', '136', '05', '2082', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30088, to_date('17-05-2082', 'dd-mm-yyyy'), '7', '17', '137', '05', '2082', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30089, to_date('18-05-2082', 'dd-mm-yyyy'), '1', '18', '138', '05', '2082', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30090, to_date('19-05-2082', 'dd-mm-yyyy'), '2', '19', '139', '05', '2082', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30091, to_date('20-05-2082', 'dd-mm-yyyy'), '3', '20', '140', '05', '2082', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30092, to_date('21-05-2082', 'dd-mm-yyyy'), '4', '21', '141', '05', '2082', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30093, to_date('22-05-2082', 'dd-mm-yyyy'), '5', '22', '142', '05', '2082', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30094, to_date('23-05-2082', 'dd-mm-yyyy'), '6', '23', '143', '05', '2082', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30095, to_date('24-05-2082', 'dd-mm-yyyy'), '7', '24', '144', '05', '2082', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30096, to_date('25-05-2082', 'dd-mm-yyyy'), '1', '25', '145', '05', '2082', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30097, to_date('26-05-2082', 'dd-mm-yyyy'), '2', '26', '146', '05', '2082', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30098, to_date('27-05-2082', 'dd-mm-yyyy'), '3', '27', '147', '05', '2082', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30099, to_date('28-05-2082', 'dd-mm-yyyy'), '4', '28', '148', '05', '2082', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30100, to_date('29-05-2082', 'dd-mm-yyyy'), '5', '29', '149', '05', '2082', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30101, to_date('30-05-2082', 'dd-mm-yyyy'), '6', '30', '150', '05', '2082', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30102, to_date('31-05-2082', 'dd-mm-yyyy'), '7', '31', '151', '05', '2082', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30103, to_date('01-06-2082', 'dd-mm-yyyy'), '1', '01', '152', '06', '2082', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30104, to_date('02-06-2082', 'dd-mm-yyyy'), '2', '02', '153', '06', '2082', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30105, to_date('03-06-2082', 'dd-mm-yyyy'), '3', '03', '154', '06', '2082', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30106, to_date('04-06-2082', 'dd-mm-yyyy'), '4', '04', '155', '06', '2082', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30107, to_date('05-06-2082', 'dd-mm-yyyy'), '5', '05', '156', '06', '2082', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30108, to_date('06-06-2082', 'dd-mm-yyyy'), '6', '06', '157', '06', '2082', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30109, to_date('07-06-2082', 'dd-mm-yyyy'), '7', '07', '158', '06', '2082', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30110, to_date('08-06-2082', 'dd-mm-yyyy'), '1', '08', '159', '06', '2082', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30111, to_date('09-06-2082', 'dd-mm-yyyy'), '2', '09', '160', '06', '2082', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30112, to_date('10-06-2082', 'dd-mm-yyyy'), '3', '10', '161', '06', '2082', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30113, to_date('11-06-2082', 'dd-mm-yyyy'), '4', '11', '162', '06', '2082', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30114, to_date('12-06-2082', 'dd-mm-yyyy'), '5', '12', '163', '06', '2082', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30115, to_date('13-06-2082', 'dd-mm-yyyy'), '6', '13', '164', '06', '2082', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30116, to_date('14-06-2082', 'dd-mm-yyyy'), '7', '14', '165', '06', '2082', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30117, to_date('15-06-2082', 'dd-mm-yyyy'), '1', '15', '166', '06', '2082', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30118, to_date('16-06-2082', 'dd-mm-yyyy'), '2', '16', '167', '06', '2082', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30119, to_date('17-06-2082', 'dd-mm-yyyy'), '3', '17', '168', '06', '2082', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30120, to_date('18-06-2082', 'dd-mm-yyyy'), '4', '18', '169', '06', '2082', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30121, to_date('19-06-2082', 'dd-mm-yyyy'), '5', '19', '170', '06', '2082', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30122, to_date('20-06-2082', 'dd-mm-yyyy'), '6', '20', '171', '06', '2082', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30123, to_date('21-06-2082', 'dd-mm-yyyy'), '7', '21', '172', '06', '2082', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30124, to_date('22-06-2082', 'dd-mm-yyyy'), '1', '22', '173', '06', '2082', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30125, to_date('23-06-2082', 'dd-mm-yyyy'), '2', '23', '174', '06', '2082', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30126, to_date('24-06-2082', 'dd-mm-yyyy'), '3', '24', '175', '06', '2082', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30127, to_date('25-06-2082', 'dd-mm-yyyy'), '4', '25', '176', '06', '2082', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30128, to_date('26-06-2082', 'dd-mm-yyyy'), '5', '26', '177', '06', '2082', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30129, to_date('27-06-2082', 'dd-mm-yyyy'), '6', '27', '178', '06', '2082', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30130, to_date('28-06-2082', 'dd-mm-yyyy'), '7', '28', '179', '06', '2082', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30131, to_date('29-06-2082', 'dd-mm-yyyy'), '1', '29', '180', '06', '2082', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30132, to_date('30-06-2082', 'dd-mm-yyyy'), '2', '30', '181', '06', '2082', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30133, to_date('01-07-2082', 'dd-mm-yyyy'), '3', '01', '182', '07', '2082', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30134, to_date('02-07-2082', 'dd-mm-yyyy'), '4', '02', '183', '07', '2082', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30135, to_date('03-07-2082', 'dd-mm-yyyy'), '5', '03', '184', '07', '2082', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30136, to_date('04-07-2082', 'dd-mm-yyyy'), '6', '04', '185', '07', '2082', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30137, to_date('05-07-2082', 'dd-mm-yyyy'), '7', '05', '186', '07', '2082', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30138, to_date('06-07-2082', 'dd-mm-yyyy'), '1', '06', '187', '07', '2082', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30139, to_date('07-07-2082', 'dd-mm-yyyy'), '2', '07', '188', '07', '2082', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30140, to_date('08-07-2082', 'dd-mm-yyyy'), '3', '08', '189', '07', '2082', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30141, to_date('09-07-2082', 'dd-mm-yyyy'), '4', '09', '190', '07', '2082', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30142, to_date('10-07-2082', 'dd-mm-yyyy'), '5', '10', '191', '07', '2082', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30143, to_date('11-07-2082', 'dd-mm-yyyy'), '6', '11', '192', '07', '2082', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30144, to_date('12-07-2082', 'dd-mm-yyyy'), '7', '12', '193', '07', '2082', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30145, to_date('13-07-2082', 'dd-mm-yyyy'), '1', '13', '194', '07', '2082', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30146, to_date('14-07-2082', 'dd-mm-yyyy'), '2', '14', '195', '07', '2082', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30147, to_date('15-07-2082', 'dd-mm-yyyy'), '3', '15', '196', '07', '2082', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30148, to_date('16-07-2082', 'dd-mm-yyyy'), '4', '16', '197', '07', '2082', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30149, to_date('17-07-2082', 'dd-mm-yyyy'), '5', '17', '198', '07', '2082', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30150, to_date('18-07-2082', 'dd-mm-yyyy'), '6', '18', '199', '07', '2082', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30151, to_date('19-07-2082', 'dd-mm-yyyy'), '7', '19', '200', '07', '2082', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30152, to_date('20-07-2082', 'dd-mm-yyyy'), '1', '20', '201', '07', '2082', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30153, to_date('21-07-2082', 'dd-mm-yyyy'), '2', '21', '202', '07', '2082', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30154, to_date('22-07-2082', 'dd-mm-yyyy'), '3', '22', '203', '07', '2082', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30155, to_date('23-07-2082', 'dd-mm-yyyy'), '4', '23', '204', '07', '2082', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30156, to_date('24-07-2082', 'dd-mm-yyyy'), '5', '24', '205', '07', '2082', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30157, to_date('25-07-2082', 'dd-mm-yyyy'), '6', '25', '206', '07', '2082', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30158, to_date('26-07-2082', 'dd-mm-yyyy'), '7', '26', '207', '07', '2082', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30159, to_date('27-07-2082', 'dd-mm-yyyy'), '1', '27', '208', '07', '2082', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30160, to_date('28-07-2082', 'dd-mm-yyyy'), '2', '28', '209', '07', '2082', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30161, to_date('29-07-2082', 'dd-mm-yyyy'), '3', '29', '210', '07', '2082', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30162, to_date('30-07-2082', 'dd-mm-yyyy'), '4', '30', '211', '07', '2082', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30163, to_date('31-07-2082', 'dd-mm-yyyy'), '5', '31', '212', '07', '2082', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30164, to_date('01-08-2082', 'dd-mm-yyyy'), '6', '01', '213', '08', '2082', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30165, to_date('02-08-2082', 'dd-mm-yyyy'), '7', '02', '214', '08', '2082', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30166, to_date('03-08-2082', 'dd-mm-yyyy'), '1', '03', '215', '08', '2082', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30167, to_date('04-08-2082', 'dd-mm-yyyy'), '2', '04', '216', '08', '2082', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30168, to_date('05-08-2082', 'dd-mm-yyyy'), '3', '05', '217', '08', '2082', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30169, to_date('06-08-2082', 'dd-mm-yyyy'), '4', '06', '218', '08', '2082', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30170, to_date('07-08-2082', 'dd-mm-yyyy'), '5', '07', '219', '08', '2082', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30171, to_date('08-08-2082', 'dd-mm-yyyy'), '6', '08', '220', '08', '2082', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30172, to_date('09-08-2082', 'dd-mm-yyyy'), '7', '09', '221', '08', '2082', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30173, to_date('10-08-2082', 'dd-mm-yyyy'), '1', '10', '222', '08', '2082', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30174, to_date('11-08-2082', 'dd-mm-yyyy'), '2', '11', '223', '08', '2082', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30175, to_date('12-08-2082', 'dd-mm-yyyy'), '3', '12', '224', '08', '2082', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30176, to_date('13-08-2082', 'dd-mm-yyyy'), '4', '13', '225', '08', '2082', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30177, to_date('14-08-2082', 'dd-mm-yyyy'), '5', '14', '226', '08', '2082', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30178, to_date('15-08-2082', 'dd-mm-yyyy'), '6', '15', '227', '08', '2082', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30179, to_date('16-08-2082', 'dd-mm-yyyy'), '7', '16', '228', '08', '2082', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30180, to_date('17-08-2082', 'dd-mm-yyyy'), '1', '17', '229', '08', '2082', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30181, to_date('18-08-2082', 'dd-mm-yyyy'), '2', '18', '230', '08', '2082', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30182, to_date('19-08-2082', 'dd-mm-yyyy'), '3', '19', '231', '08', '2082', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30183, to_date('20-08-2082', 'dd-mm-yyyy'), '4', '20', '232', '08', '2082', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30184, to_date('21-08-2082', 'dd-mm-yyyy'), '5', '21', '233', '08', '2082', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31669, to_date('14-09-2086', 'dd-mm-yyyy'), '6', '14', '257', '09', '2086', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31670, to_date('15-09-2086', 'dd-mm-yyyy'), '7', '15', '258', '09', '2086', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31671, to_date('16-09-2086', 'dd-mm-yyyy'), '1', '16', '259', '09', '2086', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31672, to_date('17-09-2086', 'dd-mm-yyyy'), '2', '17', '260', '09', '2086', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31673, to_date('18-09-2086', 'dd-mm-yyyy'), '3', '18', '261', '09', '2086', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31674, to_date('19-09-2086', 'dd-mm-yyyy'), '4', '19', '262', '09', '2086', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31675, to_date('20-09-2086', 'dd-mm-yyyy'), '5', '20', '263', '09', '2086', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31676, to_date('21-09-2086', 'dd-mm-yyyy'), '6', '21', '264', '09', '2086', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31677, to_date('22-09-2086', 'dd-mm-yyyy'), '7', '22', '265', '09', '2086', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31678, to_date('23-09-2086', 'dd-mm-yyyy'), '1', '23', '266', '09', '2086', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31679, to_date('24-09-2086', 'dd-mm-yyyy'), '2', '24', '267', '09', '2086', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31680, to_date('25-09-2086', 'dd-mm-yyyy'), '3', '25', '268', '09', '2086', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31681, to_date('26-09-2086', 'dd-mm-yyyy'), '4', '26', '269', '09', '2086', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31682, to_date('27-09-2086', 'dd-mm-yyyy'), '5', '27', '270', '09', '2086', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31683, to_date('28-09-2086', 'dd-mm-yyyy'), '6', '28', '271', '09', '2086', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31684, to_date('29-09-2086', 'dd-mm-yyyy'), '7', '29', '272', '09', '2086', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31685, to_date('30-09-2086', 'dd-mm-yyyy'), '1', '30', '273', '09', '2086', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31686, to_date('01-10-2086', 'dd-mm-yyyy'), '2', '01', '274', '10', '2086', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31687, to_date('02-10-2086', 'dd-mm-yyyy'), '3', '02', '275', '10', '2086', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31688, to_date('03-10-2086', 'dd-mm-yyyy'), '4', '03', '276', '10', '2086', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31689, to_date('04-10-2086', 'dd-mm-yyyy'), '5', '04', '277', '10', '2086', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31690, to_date('05-10-2086', 'dd-mm-yyyy'), '6', '05', '278', '10', '2086', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31691, to_date('06-10-2086', 'dd-mm-yyyy'), '7', '06', '279', '10', '2086', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31692, to_date('07-10-2086', 'dd-mm-yyyy'), '1', '07', '280', '10', '2086', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31693, to_date('08-10-2086', 'dd-mm-yyyy'), '2', '08', '281', '10', '2086', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31694, to_date('09-10-2086', 'dd-mm-yyyy'), '3', '09', '282', '10', '2086', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31695, to_date('10-10-2086', 'dd-mm-yyyy'), '4', '10', '283', '10', '2086', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31696, to_date('11-10-2086', 'dd-mm-yyyy'), '5', '11', '284', '10', '2086', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31697, to_date('12-10-2086', 'dd-mm-yyyy'), '6', '12', '285', '10', '2086', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31698, to_date('13-10-2086', 'dd-mm-yyyy'), '7', '13', '286', '10', '2086', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31699, to_date('14-10-2086', 'dd-mm-yyyy'), '1', '14', '287', '10', '2086', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31700, to_date('15-10-2086', 'dd-mm-yyyy'), '2', '15', '288', '10', '2086', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31701, to_date('16-10-2086', 'dd-mm-yyyy'), '3', '16', '289', '10', '2086', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31702, to_date('17-10-2086', 'dd-mm-yyyy'), '4', '17', '290', '10', '2086', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31703, to_date('18-10-2086', 'dd-mm-yyyy'), '5', '18', '291', '10', '2086', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31704, to_date('19-10-2086', 'dd-mm-yyyy'), '6', '19', '292', '10', '2086', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31705, to_date('20-10-2086', 'dd-mm-yyyy'), '7', '20', '293', '10', '2086', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31706, to_date('21-10-2086', 'dd-mm-yyyy'), '1', '21', '294', '10', '2086', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31707, to_date('22-10-2086', 'dd-mm-yyyy'), '2', '22', '295', '10', '2086', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31708, to_date('23-10-2086', 'dd-mm-yyyy'), '3', '23', '296', '10', '2086', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31709, to_date('24-10-2086', 'dd-mm-yyyy'), '4', '24', '297', '10', '2086', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31710, to_date('25-10-2086', 'dd-mm-yyyy'), '5', '25', '298', '10', '2086', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31711, to_date('26-10-2086', 'dd-mm-yyyy'), '6', '26', '299', '10', '2086', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31712, to_date('27-10-2086', 'dd-mm-yyyy'), '7', '27', '300', '10', '2086', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31713, to_date('28-10-2086', 'dd-mm-yyyy'), '1', '28', '301', '10', '2086', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31714, to_date('29-10-2086', 'dd-mm-yyyy'), '2', '29', '302', '10', '2086', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31715, to_date('30-10-2086', 'dd-mm-yyyy'), '3', '30', '303', '10', '2086', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31716, to_date('31-10-2086', 'dd-mm-yyyy'), '4', '31', '304', '10', '2086', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31717, to_date('01-11-2086', 'dd-mm-yyyy'), '5', '01', '305', '11', '2086', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31718, to_date('02-11-2086', 'dd-mm-yyyy'), '6', '02', '306', '11', '2086', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31719, to_date('03-11-2086', 'dd-mm-yyyy'), '7', '03', '307', '11', '2086', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31720, to_date('04-11-2086', 'dd-mm-yyyy'), '1', '04', '308', '11', '2086', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31721, to_date('05-11-2086', 'dd-mm-yyyy'), '2', '05', '309', '11', '2086', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31722, to_date('06-11-2086', 'dd-mm-yyyy'), '3', '06', '310', '11', '2086', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31723, to_date('07-11-2086', 'dd-mm-yyyy'), '4', '07', '311', '11', '2086', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31724, to_date('08-11-2086', 'dd-mm-yyyy'), '5', '08', '312', '11', '2086', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31725, to_date('09-11-2086', 'dd-mm-yyyy'), '6', '09', '313', '11', '2086', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31726, to_date('10-11-2086', 'dd-mm-yyyy'), '7', '10', '314', '11', '2086', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31727, to_date('11-11-2086', 'dd-mm-yyyy'), '1', '11', '315', '11', '2086', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31728, to_date('12-11-2086', 'dd-mm-yyyy'), '2', '12', '316', '11', '2086', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31729, to_date('13-11-2086', 'dd-mm-yyyy'), '3', '13', '317', '11', '2086', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31730, to_date('14-11-2086', 'dd-mm-yyyy'), '4', '14', '318', '11', '2086', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31731, to_date('15-11-2086', 'dd-mm-yyyy'), '5', '15', '319', '11', '2086', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31732, to_date('16-11-2086', 'dd-mm-yyyy'), '6', '16', '320', '11', '2086', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31733, to_date('17-11-2086', 'dd-mm-yyyy'), '7', '17', '321', '11', '2086', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31734, to_date('18-11-2086', 'dd-mm-yyyy'), '1', '18', '322', '11', '2086', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31735, to_date('19-11-2086', 'dd-mm-yyyy'), '2', '19', '323', '11', '2086', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31736, to_date('20-11-2086', 'dd-mm-yyyy'), '3', '20', '324', '11', '2086', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31737, to_date('21-11-2086', 'dd-mm-yyyy'), '4', '21', '325', '11', '2086', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31738, to_date('22-11-2086', 'dd-mm-yyyy'), '5', '22', '326', '11', '2086', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31739, to_date('23-11-2086', 'dd-mm-yyyy'), '6', '23', '327', '11', '2086', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31740, to_date('24-11-2086', 'dd-mm-yyyy'), '7', '24', '328', '11', '2086', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31741, to_date('25-11-2086', 'dd-mm-yyyy'), '1', '25', '329', '11', '2086', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31742, to_date('26-11-2086', 'dd-mm-yyyy'), '2', '26', '330', '11', '2086', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31743, to_date('27-11-2086', 'dd-mm-yyyy'), '3', '27', '331', '11', '2086', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31744, to_date('28-11-2086', 'dd-mm-yyyy'), '4', '28', '332', '11', '2086', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31745, to_date('29-11-2086', 'dd-mm-yyyy'), '5', '29', '333', '11', '2086', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31746, to_date('30-11-2086', 'dd-mm-yyyy'), '6', '30', '334', '11', '2086', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31747, to_date('01-12-2086', 'dd-mm-yyyy'), '7', '01', '335', '12', '2086', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31748, to_date('02-12-2086', 'dd-mm-yyyy'), '1', '02', '336', '12', '2086', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31749, to_date('03-12-2086', 'dd-mm-yyyy'), '2', '03', '337', '12', '2086', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31750, to_date('04-12-2086', 'dd-mm-yyyy'), '3', '04', '338', '12', '2086', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31751, to_date('05-12-2086', 'dd-mm-yyyy'), '4', '05', '339', '12', '2086', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31752, to_date('06-12-2086', 'dd-mm-yyyy'), '5', '06', '340', '12', '2086', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31753, to_date('07-12-2086', 'dd-mm-yyyy'), '6', '07', '341', '12', '2086', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31754, to_date('08-12-2086', 'dd-mm-yyyy'), '7', '08', '342', '12', '2086', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31755, to_date('09-12-2086', 'dd-mm-yyyy'), '1', '09', '343', '12', '2086', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31756, to_date('10-12-2086', 'dd-mm-yyyy'), '2', '10', '344', '12', '2086', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31757, to_date('11-12-2086', 'dd-mm-yyyy'), '3', '11', '345', '12', '2086', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31758, to_date('12-12-2086', 'dd-mm-yyyy'), '4', '12', '346', '12', '2086', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31759, to_date('13-12-2086', 'dd-mm-yyyy'), '5', '13', '347', '12', '2086', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31760, to_date('14-12-2086', 'dd-mm-yyyy'), '6', '14', '348', '12', '2086', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31761, to_date('15-12-2086', 'dd-mm-yyyy'), '7', '15', '349', '12', '2086', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31762, to_date('16-12-2086', 'dd-mm-yyyy'), '1', '16', '350', '12', '2086', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31763, to_date('17-12-2086', 'dd-mm-yyyy'), '2', '17', '351', '12', '2086', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31764, to_date('18-12-2086', 'dd-mm-yyyy'), '3', '18', '352', '12', '2086', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31765, to_date('19-12-2086', 'dd-mm-yyyy'), '4', '19', '353', '12', '2086', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31766, to_date('20-12-2086', 'dd-mm-yyyy'), '5', '20', '354', '12', '2086', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31767, to_date('21-12-2086', 'dd-mm-yyyy'), '6', '21', '355', '12', '2086', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31768, to_date('22-12-2086', 'dd-mm-yyyy'), '7', '22', '356', '12', '2086', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31769, to_date('23-12-2086', 'dd-mm-yyyy'), '1', '23', '357', '12', '2086', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31770, to_date('24-12-2086', 'dd-mm-yyyy'), '2', '24', '358', '12', '2086', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31771, to_date('25-12-2086', 'dd-mm-yyyy'), '3', '25', '359', '12', '2086', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31772, to_date('26-12-2086', 'dd-mm-yyyy'), '4', '26', '360', '12', '2086', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31773, to_date('27-12-2086', 'dd-mm-yyyy'), '5', '27', '361', '12', '2086', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31774, to_date('28-12-2086', 'dd-mm-yyyy'), '6', '28', '362', '12', '2086', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26899, to_date('23-08-2073', 'dd-mm-yyyy'), '3', '23', '235', '08', '2073', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26900, to_date('24-08-2073', 'dd-mm-yyyy'), '4', '24', '236', '08', '2073', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26901, to_date('25-08-2073', 'dd-mm-yyyy'), '5', '25', '237', '08', '2073', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26902, to_date('26-08-2073', 'dd-mm-yyyy'), '6', '26', '238', '08', '2073', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26903, to_date('27-08-2073', 'dd-mm-yyyy'), '7', '27', '239', '08', '2073', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26904, to_date('28-08-2073', 'dd-mm-yyyy'), '1', '28', '240', '08', '2073', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26905, to_date('29-08-2073', 'dd-mm-yyyy'), '2', '29', '241', '08', '2073', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26906, to_date('30-08-2073', 'dd-mm-yyyy'), '3', '30', '242', '08', '2073', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26907, to_date('31-08-2073', 'dd-mm-yyyy'), '4', '31', '243', '08', '2073', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26908, to_date('01-09-2073', 'dd-mm-yyyy'), '5', '01', '244', '09', '2073', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26909, to_date('02-09-2073', 'dd-mm-yyyy'), '6', '02', '245', '09', '2073', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26910, to_date('03-09-2073', 'dd-mm-yyyy'), '7', '03', '246', '09', '2073', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26911, to_date('04-09-2073', 'dd-mm-yyyy'), '1', '04', '247', '09', '2073', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26912, to_date('05-09-2073', 'dd-mm-yyyy'), '2', '05', '248', '09', '2073', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26913, to_date('06-09-2073', 'dd-mm-yyyy'), '3', '06', '249', '09', '2073', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26914, to_date('07-09-2073', 'dd-mm-yyyy'), '4', '07', '250', '09', '2073', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26915, to_date('08-09-2073', 'dd-mm-yyyy'), '5', '08', '251', '09', '2073', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26916, to_date('09-09-2073', 'dd-mm-yyyy'), '6', '09', '252', '09', '2073', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26917, to_date('10-09-2073', 'dd-mm-yyyy'), '7', '10', '253', '09', '2073', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26918, to_date('11-09-2073', 'dd-mm-yyyy'), '1', '11', '254', '09', '2073', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26919, to_date('12-09-2073', 'dd-mm-yyyy'), '2', '12', '255', '09', '2073', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26920, to_date('13-09-2073', 'dd-mm-yyyy'), '3', '13', '256', '09', '2073', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26921, to_date('14-09-2073', 'dd-mm-yyyy'), '4', '14', '257', '09', '2073', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26922, to_date('15-09-2073', 'dd-mm-yyyy'), '5', '15', '258', '09', '2073', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26923, to_date('16-09-2073', 'dd-mm-yyyy'), '6', '16', '259', '09', '2073', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26924, to_date('17-09-2073', 'dd-mm-yyyy'), '7', '17', '260', '09', '2073', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26925, to_date('18-09-2073', 'dd-mm-yyyy'), '1', '18', '261', '09', '2073', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26926, to_date('19-09-2073', 'dd-mm-yyyy'), '2', '19', '262', '09', '2073', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26927, to_date('20-09-2073', 'dd-mm-yyyy'), '3', '20', '263', '09', '2073', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26928, to_date('21-09-2073', 'dd-mm-yyyy'), '4', '21', '264', '09', '2073', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26929, to_date('22-09-2073', 'dd-mm-yyyy'), '5', '22', '265', '09', '2073', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26930, to_date('23-09-2073', 'dd-mm-yyyy'), '6', '23', '266', '09', '2073', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26931, to_date('24-09-2073', 'dd-mm-yyyy'), '7', '24', '267', '09', '2073', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26932, to_date('25-09-2073', 'dd-mm-yyyy'), '1', '25', '268', '09', '2073', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26933, to_date('26-09-2073', 'dd-mm-yyyy'), '2', '26', '269', '09', '2073', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26934, to_date('27-09-2073', 'dd-mm-yyyy'), '3', '27', '270', '09', '2073', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26935, to_date('28-09-2073', 'dd-mm-yyyy'), '4', '28', '271', '09', '2073', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26936, to_date('29-09-2073', 'dd-mm-yyyy'), '5', '29', '272', '09', '2073', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26937, to_date('30-09-2073', 'dd-mm-yyyy'), '6', '30', '273', '09', '2073', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26938, to_date('01-10-2073', 'dd-mm-yyyy'), '7', '01', '274', '10', '2073', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26939, to_date('02-10-2073', 'dd-mm-yyyy'), '1', '02', '275', '10', '2073', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26940, to_date('03-10-2073', 'dd-mm-yyyy'), '2', '03', '276', '10', '2073', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26941, to_date('04-10-2073', 'dd-mm-yyyy'), '3', '04', '277', '10', '2073', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26942, to_date('05-10-2073', 'dd-mm-yyyy'), '4', '05', '278', '10', '2073', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26943, to_date('06-10-2073', 'dd-mm-yyyy'), '5', '06', '279', '10', '2073', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26944, to_date('07-10-2073', 'dd-mm-yyyy'), '6', '07', '280', '10', '2073', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26945, to_date('08-10-2073', 'dd-mm-yyyy'), '7', '08', '281', '10', '2073', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26946, to_date('09-10-2073', 'dd-mm-yyyy'), '1', '09', '282', '10', '2073', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26947, to_date('10-10-2073', 'dd-mm-yyyy'), '2', '10', '283', '10', '2073', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26948, to_date('11-10-2073', 'dd-mm-yyyy'), '3', '11', '284', '10', '2073', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26949, to_date('12-10-2073', 'dd-mm-yyyy'), '4', '12', '285', '10', '2073', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26950, to_date('13-10-2073', 'dd-mm-yyyy'), '5', '13', '286', '10', '2073', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26951, to_date('14-10-2073', 'dd-mm-yyyy'), '6', '14', '287', '10', '2073', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26952, to_date('15-10-2073', 'dd-mm-yyyy'), '7', '15', '288', '10', '2073', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26953, to_date('16-10-2073', 'dd-mm-yyyy'), '1', '16', '289', '10', '2073', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26954, to_date('17-10-2073', 'dd-mm-yyyy'), '2', '17', '290', '10', '2073', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26955, to_date('18-10-2073', 'dd-mm-yyyy'), '3', '18', '291', '10', '2073', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26956, to_date('19-10-2073', 'dd-mm-yyyy'), '4', '19', '292', '10', '2073', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26957, to_date('20-10-2073', 'dd-mm-yyyy'), '5', '20', '293', '10', '2073', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26958, to_date('21-10-2073', 'dd-mm-yyyy'), '6', '21', '294', '10', '2073', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26959, to_date('22-10-2073', 'dd-mm-yyyy'), '7', '22', '295', '10', '2073', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26960, to_date('23-10-2073', 'dd-mm-yyyy'), '1', '23', '296', '10', '2073', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26961, to_date('24-10-2073', 'dd-mm-yyyy'), '2', '24', '297', '10', '2073', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26962, to_date('25-10-2073', 'dd-mm-yyyy'), '3', '25', '298', '10', '2073', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26963, to_date('26-10-2073', 'dd-mm-yyyy'), '4', '26', '299', '10', '2073', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26964, to_date('27-10-2073', 'dd-mm-yyyy'), '5', '27', '300', '10', '2073', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26965, to_date('28-10-2073', 'dd-mm-yyyy'), '6', '28', '301', '10', '2073', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26966, to_date('29-10-2073', 'dd-mm-yyyy'), '7', '29', '302', '10', '2073', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26967, to_date('30-10-2073', 'dd-mm-yyyy'), '1', '30', '303', '10', '2073', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26968, to_date('31-10-2073', 'dd-mm-yyyy'), '2', '31', '304', '10', '2073', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26969, to_date('01-11-2073', 'dd-mm-yyyy'), '3', '01', '305', '11', '2073', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26970, to_date('02-11-2073', 'dd-mm-yyyy'), '4', '02', '306', '11', '2073', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26971, to_date('03-11-2073', 'dd-mm-yyyy'), '5', '03', '307', '11', '2073', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26972, to_date('04-11-2073', 'dd-mm-yyyy'), '6', '04', '308', '11', '2073', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26973, to_date('05-11-2073', 'dd-mm-yyyy'), '7', '05', '309', '11', '2073', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26974, to_date('06-11-2073', 'dd-mm-yyyy'), '1', '06', '310', '11', '2073', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26975, to_date('07-11-2073', 'dd-mm-yyyy'), '2', '07', '311', '11', '2073', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26976, to_date('08-11-2073', 'dd-mm-yyyy'), '3', '08', '312', '11', '2073', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26977, to_date('09-11-2073', 'dd-mm-yyyy'), '4', '09', '313', '11', '2073', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26978, to_date('10-11-2073', 'dd-mm-yyyy'), '5', '10', '314', '11', '2073', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26979, to_date('11-11-2073', 'dd-mm-yyyy'), '6', '11', '315', '11', '2073', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26980, to_date('12-11-2073', 'dd-mm-yyyy'), '7', '12', '316', '11', '2073', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26981, to_date('13-11-2073', 'dd-mm-yyyy'), '1', '13', '317', '11', '2073', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26982, to_date('14-11-2073', 'dd-mm-yyyy'), '2', '14', '318', '11', '2073', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26983, to_date('15-11-2073', 'dd-mm-yyyy'), '3', '15', '319', '11', '2073', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26984, to_date('16-11-2073', 'dd-mm-yyyy'), '4', '16', '320', '11', '2073', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26985, to_date('17-11-2073', 'dd-mm-yyyy'), '5', '17', '321', '11', '2073', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26986, to_date('18-11-2073', 'dd-mm-yyyy'), '6', '18', '322', '11', '2073', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26987, to_date('19-11-2073', 'dd-mm-yyyy'), '7', '19', '323', '11', '2073', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26988, to_date('20-11-2073', 'dd-mm-yyyy'), '1', '20', '324', '11', '2073', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26989, to_date('21-11-2073', 'dd-mm-yyyy'), '2', '21', '325', '11', '2073', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26990, to_date('22-11-2073', 'dd-mm-yyyy'), '3', '22', '326', '11', '2073', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26991, to_date('23-11-2073', 'dd-mm-yyyy'), '4', '23', '327', '11', '2073', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26992, to_date('24-11-2073', 'dd-mm-yyyy'), '5', '24', '328', '11', '2073', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26993, to_date('25-11-2073', 'dd-mm-yyyy'), '6', '25', '329', '11', '2073', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26994, to_date('26-11-2073', 'dd-mm-yyyy'), '7', '26', '330', '11', '2073', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26995, to_date('27-11-2073', 'dd-mm-yyyy'), '1', '27', '331', '11', '2073', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26996, to_date('28-11-2073', 'dd-mm-yyyy'), '2', '28', '332', '11', '2073', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26997, to_date('29-11-2073', 'dd-mm-yyyy'), '3', '29', '333', '11', '2073', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26998, to_date('30-11-2073', 'dd-mm-yyyy'), '4', '30', '334', '11', '2073', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (26999, to_date('01-12-2073', 'dd-mm-yyyy'), '5', '01', '335', '12', '2073', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27000, to_date('02-12-2073', 'dd-mm-yyyy'), '6', '02', '336', '12', '2073', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27001, to_date('03-12-2073', 'dd-mm-yyyy'), '7', '03', '337', '12', '2073', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27002, to_date('04-12-2073', 'dd-mm-yyyy'), '1', '04', '338', '12', '2073', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27003, to_date('05-12-2073', 'dd-mm-yyyy'), '2', '05', '339', '12', '2073', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27004, to_date('06-12-2073', 'dd-mm-yyyy'), '3', '06', '340', '12', '2073', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28595, to_date('15-04-2078', 'dd-mm-yyyy'), '5', '15', '105', '04', '2078', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28596, to_date('16-04-2078', 'dd-mm-yyyy'), '6', '16', '106', '04', '2078', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28597, to_date('17-04-2078', 'dd-mm-yyyy'), '7', '17', '107', '04', '2078', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28598, to_date('18-04-2078', 'dd-mm-yyyy'), '1', '18', '108', '04', '2078', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28599, to_date('19-04-2078', 'dd-mm-yyyy'), '2', '19', '109', '04', '2078', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28600, to_date('20-04-2078', 'dd-mm-yyyy'), '3', '20', '110', '04', '2078', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28601, to_date('21-04-2078', 'dd-mm-yyyy'), '4', '21', '111', '04', '2078', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28602, to_date('22-04-2078', 'dd-mm-yyyy'), '5', '22', '112', '04', '2078', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28603, to_date('23-04-2078', 'dd-mm-yyyy'), '6', '23', '113', '04', '2078', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28604, to_date('24-04-2078', 'dd-mm-yyyy'), '7', '24', '114', '04', '2078', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28605, to_date('25-04-2078', 'dd-mm-yyyy'), '1', '25', '115', '04', '2078', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28606, to_date('26-04-2078', 'dd-mm-yyyy'), '2', '26', '116', '04', '2078', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28607, to_date('27-04-2078', 'dd-mm-yyyy'), '3', '27', '117', '04', '2078', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28608, to_date('28-04-2078', 'dd-mm-yyyy'), '4', '28', '118', '04', '2078', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28609, to_date('29-04-2078', 'dd-mm-yyyy'), '5', '29', '119', '04', '2078', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28610, to_date('30-04-2078', 'dd-mm-yyyy'), '6', '30', '120', '04', '2078', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28611, to_date('01-05-2078', 'dd-mm-yyyy'), '7', '01', '121', '05', '2078', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28612, to_date('02-05-2078', 'dd-mm-yyyy'), '1', '02', '122', '05', '2078', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28613, to_date('03-05-2078', 'dd-mm-yyyy'), '2', '03', '123', '05', '2078', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
commit;
prompt 34000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28614, to_date('04-05-2078', 'dd-mm-yyyy'), '3', '04', '124', '05', '2078', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28615, to_date('05-05-2078', 'dd-mm-yyyy'), '4', '05', '125', '05', '2078', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28616, to_date('06-05-2078', 'dd-mm-yyyy'), '5', '06', '126', '05', '2078', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28617, to_date('07-05-2078', 'dd-mm-yyyy'), '6', '07', '127', '05', '2078', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28618, to_date('08-05-2078', 'dd-mm-yyyy'), '7', '08', '128', '05', '2078', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28619, to_date('09-05-2078', 'dd-mm-yyyy'), '1', '09', '129', '05', '2078', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28620, to_date('10-05-2078', 'dd-mm-yyyy'), '2', '10', '130', '05', '2078', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28621, to_date('11-05-2078', 'dd-mm-yyyy'), '3', '11', '131', '05', '2078', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28622, to_date('12-05-2078', 'dd-mm-yyyy'), '4', '12', '132', '05', '2078', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28623, to_date('13-05-2078', 'dd-mm-yyyy'), '5', '13', '133', '05', '2078', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28624, to_date('14-05-2078', 'dd-mm-yyyy'), '6', '14', '134', '05', '2078', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28625, to_date('15-05-2078', 'dd-mm-yyyy'), '7', '15', '135', '05', '2078', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28626, to_date('16-05-2078', 'dd-mm-yyyy'), '1', '16', '136', '05', '2078', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28627, to_date('17-05-2078', 'dd-mm-yyyy'), '2', '17', '137', '05', '2078', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28628, to_date('18-05-2078', 'dd-mm-yyyy'), '3', '18', '138', '05', '2078', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28629, to_date('19-05-2078', 'dd-mm-yyyy'), '4', '19', '139', '05', '2078', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28630, to_date('20-05-2078', 'dd-mm-yyyy'), '5', '20', '140', '05', '2078', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28631, to_date('21-05-2078', 'dd-mm-yyyy'), '6', '21', '141', '05', '2078', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28632, to_date('22-05-2078', 'dd-mm-yyyy'), '7', '22', '142', '05', '2078', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28633, to_date('23-05-2078', 'dd-mm-yyyy'), '1', '23', '143', '05', '2078', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28634, to_date('24-05-2078', 'dd-mm-yyyy'), '2', '24', '144', '05', '2078', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28635, to_date('25-05-2078', 'dd-mm-yyyy'), '3', '25', '145', '05', '2078', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28636, to_date('26-05-2078', 'dd-mm-yyyy'), '4', '26', '146', '05', '2078', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28637, to_date('27-05-2078', 'dd-mm-yyyy'), '5', '27', '147', '05', '2078', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28638, to_date('28-05-2078', 'dd-mm-yyyy'), '6', '28', '148', '05', '2078', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28639, to_date('29-05-2078', 'dd-mm-yyyy'), '7', '29', '149', '05', '2078', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28640, to_date('30-05-2078', 'dd-mm-yyyy'), '1', '30', '150', '05', '2078', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28641, to_date('31-05-2078', 'dd-mm-yyyy'), '2', '31', '151', '05', '2078', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28642, to_date('01-06-2078', 'dd-mm-yyyy'), '3', '01', '152', '06', '2078', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28643, to_date('02-06-2078', 'dd-mm-yyyy'), '4', '02', '153', '06', '2078', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28644, to_date('03-06-2078', 'dd-mm-yyyy'), '5', '03', '154', '06', '2078', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28645, to_date('04-06-2078', 'dd-mm-yyyy'), '6', '04', '155', '06', '2078', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28646, to_date('05-06-2078', 'dd-mm-yyyy'), '7', '05', '156', '06', '2078', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28647, to_date('06-06-2078', 'dd-mm-yyyy'), '1', '06', '157', '06', '2078', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28648, to_date('07-06-2078', 'dd-mm-yyyy'), '2', '07', '158', '06', '2078', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28649, to_date('08-06-2078', 'dd-mm-yyyy'), '3', '08', '159', '06', '2078', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28650, to_date('09-06-2078', 'dd-mm-yyyy'), '4', '09', '160', '06', '2078', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28651, to_date('10-06-2078', 'dd-mm-yyyy'), '5', '10', '161', '06', '2078', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28652, to_date('11-06-2078', 'dd-mm-yyyy'), '6', '11', '162', '06', '2078', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28653, to_date('12-06-2078', 'dd-mm-yyyy'), '7', '12', '163', '06', '2078', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28654, to_date('13-06-2078', 'dd-mm-yyyy'), '1', '13', '164', '06', '2078', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28655, to_date('14-06-2078', 'dd-mm-yyyy'), '2', '14', '165', '06', '2078', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28656, to_date('15-06-2078', 'dd-mm-yyyy'), '3', '15', '166', '06', '2078', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28657, to_date('16-06-2078', 'dd-mm-yyyy'), '4', '16', '167', '06', '2078', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28658, to_date('17-06-2078', 'dd-mm-yyyy'), '5', '17', '168', '06', '2078', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28659, to_date('18-06-2078', 'dd-mm-yyyy'), '6', '18', '169', '06', '2078', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28660, to_date('19-06-2078', 'dd-mm-yyyy'), '7', '19', '170', '06', '2078', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28661, to_date('20-06-2078', 'dd-mm-yyyy'), '1', '20', '171', '06', '2078', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28662, to_date('21-06-2078', 'dd-mm-yyyy'), '2', '21', '172', '06', '2078', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28663, to_date('22-06-2078', 'dd-mm-yyyy'), '3', '22', '173', '06', '2078', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28664, to_date('23-06-2078', 'dd-mm-yyyy'), '4', '23', '174', '06', '2078', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28665, to_date('24-06-2078', 'dd-mm-yyyy'), '5', '24', '175', '06', '2078', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28666, to_date('25-06-2078', 'dd-mm-yyyy'), '6', '25', '176', '06', '2078', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28667, to_date('26-06-2078', 'dd-mm-yyyy'), '7', '26', '177', '06', '2078', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28668, to_date('27-06-2078', 'dd-mm-yyyy'), '1', '27', '178', '06', '2078', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28669, to_date('28-06-2078', 'dd-mm-yyyy'), '2', '28', '179', '06', '2078', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28670, to_date('29-06-2078', 'dd-mm-yyyy'), '3', '29', '180', '06', '2078', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28671, to_date('30-06-2078', 'dd-mm-yyyy'), '4', '30', '181', '06', '2078', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28672, to_date('01-07-2078', 'dd-mm-yyyy'), '5', '01', '182', '07', '2078', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28673, to_date('02-07-2078', 'dd-mm-yyyy'), '6', '02', '183', '07', '2078', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28674, to_date('03-07-2078', 'dd-mm-yyyy'), '7', '03', '184', '07', '2078', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28675, to_date('04-07-2078', 'dd-mm-yyyy'), '1', '04', '185', '07', '2078', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28676, to_date('05-07-2078', 'dd-mm-yyyy'), '2', '05', '186', '07', '2078', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28677, to_date('06-07-2078', 'dd-mm-yyyy'), '3', '06', '187', '07', '2078', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28678, to_date('07-07-2078', 'dd-mm-yyyy'), '4', '07', '188', '07', '2078', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28679, to_date('08-07-2078', 'dd-mm-yyyy'), '5', '08', '189', '07', '2078', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28680, to_date('09-07-2078', 'dd-mm-yyyy'), '6', '09', '190', '07', '2078', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28681, to_date('10-07-2078', 'dd-mm-yyyy'), '7', '10', '191', '07', '2078', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28682, to_date('11-07-2078', 'dd-mm-yyyy'), '1', '11', '192', '07', '2078', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28683, to_date('12-07-2078', 'dd-mm-yyyy'), '2', '12', '193', '07', '2078', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28684, to_date('13-07-2078', 'dd-mm-yyyy'), '3', '13', '194', '07', '2078', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28685, to_date('14-07-2078', 'dd-mm-yyyy'), '4', '14', '195', '07', '2078', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28686, to_date('15-07-2078', 'dd-mm-yyyy'), '5', '15', '196', '07', '2078', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28687, to_date('16-07-2078', 'dd-mm-yyyy'), '6', '16', '197', '07', '2078', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28688, to_date('17-07-2078', 'dd-mm-yyyy'), '7', '17', '198', '07', '2078', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28689, to_date('18-07-2078', 'dd-mm-yyyy'), '1', '18', '199', '07', '2078', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28690, to_date('19-07-2078', 'dd-mm-yyyy'), '2', '19', '200', '07', '2078', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28691, to_date('20-07-2078', 'dd-mm-yyyy'), '3', '20', '201', '07', '2078', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28692, to_date('21-07-2078', 'dd-mm-yyyy'), '4', '21', '202', '07', '2078', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28693, to_date('22-07-2078', 'dd-mm-yyyy'), '5', '22', '203', '07', '2078', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28694, to_date('23-07-2078', 'dd-mm-yyyy'), '6', '23', '204', '07', '2078', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28695, to_date('24-07-2078', 'dd-mm-yyyy'), '7', '24', '205', '07', '2078', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28696, to_date('25-07-2078', 'dd-mm-yyyy'), '1', '25', '206', '07', '2078', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28697, to_date('26-07-2078', 'dd-mm-yyyy'), '2', '26', '207', '07', '2078', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28698, to_date('27-07-2078', 'dd-mm-yyyy'), '3', '27', '208', '07', '2078', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28699, to_date('28-07-2078', 'dd-mm-yyyy'), '4', '28', '209', '07', '2078', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28700, to_date('29-07-2078', 'dd-mm-yyyy'), '5', '29', '210', '07', '2078', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30185, to_date('22-08-2082', 'dd-mm-yyyy'), '6', '22', '234', '08', '2082', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30186, to_date('23-08-2082', 'dd-mm-yyyy'), '7', '23', '235', '08', '2082', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30187, to_date('24-08-2082', 'dd-mm-yyyy'), '1', '24', '236', '08', '2082', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30188, to_date('25-08-2082', 'dd-mm-yyyy'), '2', '25', '237', '08', '2082', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30189, to_date('26-08-2082', 'dd-mm-yyyy'), '3', '26', '238', '08', '2082', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30190, to_date('27-08-2082', 'dd-mm-yyyy'), '4', '27', '239', '08', '2082', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30191, to_date('28-08-2082', 'dd-mm-yyyy'), '5', '28', '240', '08', '2082', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30192, to_date('29-08-2082', 'dd-mm-yyyy'), '6', '29', '241', '08', '2082', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30193, to_date('30-08-2082', 'dd-mm-yyyy'), '7', '30', '242', '08', '2082', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30194, to_date('31-08-2082', 'dd-mm-yyyy'), '1', '31', '243', '08', '2082', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30195, to_date('01-09-2082', 'dd-mm-yyyy'), '2', '01', '244', '09', '2082', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30196, to_date('02-09-2082', 'dd-mm-yyyy'), '3', '02', '245', '09', '2082', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30197, to_date('03-09-2082', 'dd-mm-yyyy'), '4', '03', '246', '09', '2082', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30198, to_date('04-09-2082', 'dd-mm-yyyy'), '5', '04', '247', '09', '2082', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30199, to_date('05-09-2082', 'dd-mm-yyyy'), '6', '05', '248', '09', '2082', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30200, to_date('06-09-2082', 'dd-mm-yyyy'), '7', '06', '249', '09', '2082', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30201, to_date('07-09-2082', 'dd-mm-yyyy'), '1', '07', '250', '09', '2082', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30202, to_date('08-09-2082', 'dd-mm-yyyy'), '2', '08', '251', '09', '2082', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30203, to_date('09-09-2082', 'dd-mm-yyyy'), '3', '09', '252', '09', '2082', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30204, to_date('10-09-2082', 'dd-mm-yyyy'), '4', '10', '253', '09', '2082', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30205, to_date('11-09-2082', 'dd-mm-yyyy'), '5', '11', '254', '09', '2082', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30206, to_date('12-09-2082', 'dd-mm-yyyy'), '6', '12', '255', '09', '2082', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30207, to_date('13-09-2082', 'dd-mm-yyyy'), '7', '13', '256', '09', '2082', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30208, to_date('14-09-2082', 'dd-mm-yyyy'), '1', '14', '257', '09', '2082', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30209, to_date('15-09-2082', 'dd-mm-yyyy'), '2', '15', '258', '09', '2082', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30210, to_date('16-09-2082', 'dd-mm-yyyy'), '3', '16', '259', '09', '2082', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30211, to_date('17-09-2082', 'dd-mm-yyyy'), '4', '17', '260', '09', '2082', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30212, to_date('18-09-2082', 'dd-mm-yyyy'), '5', '18', '261', '09', '2082', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30213, to_date('19-09-2082', 'dd-mm-yyyy'), '6', '19', '262', '09', '2082', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30214, to_date('20-09-2082', 'dd-mm-yyyy'), '7', '20', '263', '09', '2082', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30215, to_date('21-09-2082', 'dd-mm-yyyy'), '1', '21', '264', '09', '2082', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30216, to_date('22-09-2082', 'dd-mm-yyyy'), '2', '22', '265', '09', '2082', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30217, to_date('23-09-2082', 'dd-mm-yyyy'), '3', '23', '266', '09', '2082', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30218, to_date('24-09-2082', 'dd-mm-yyyy'), '4', '24', '267', '09', '2082', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30219, to_date('25-09-2082', 'dd-mm-yyyy'), '5', '25', '268', '09', '2082', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30220, to_date('26-09-2082', 'dd-mm-yyyy'), '6', '26', '269', '09', '2082', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30221, to_date('27-09-2082', 'dd-mm-yyyy'), '7', '27', '270', '09', '2082', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30222, to_date('28-09-2082', 'dd-mm-yyyy'), '1', '28', '271', '09', '2082', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30223, to_date('29-09-2082', 'dd-mm-yyyy'), '2', '29', '272', '09', '2082', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30224, to_date('30-09-2082', 'dd-mm-yyyy'), '3', '30', '273', '09', '2082', '40', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30225, to_date('01-10-2082', 'dd-mm-yyyy'), '4', '01', '274', '10', '2082', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30226, to_date('02-10-2082', 'dd-mm-yyyy'), '5', '02', '275', '10', '2082', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30227, to_date('03-10-2082', 'dd-mm-yyyy'), '6', '03', '276', '10', '2082', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30228, to_date('04-10-2082', 'dd-mm-yyyy'), '7', '04', '277', '10', '2082', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30229, to_date('05-10-2082', 'dd-mm-yyyy'), '1', '05', '278', '10', '2082', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30230, to_date('06-10-2082', 'dd-mm-yyyy'), '2', '06', '279', '10', '2082', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30231, to_date('07-10-2082', 'dd-mm-yyyy'), '3', '07', '280', '10', '2082', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30232, to_date('08-10-2082', 'dd-mm-yyyy'), '4', '08', '281', '10', '2082', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30233, to_date('09-10-2082', 'dd-mm-yyyy'), '5', '09', '282', '10', '2082', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30234, to_date('10-10-2082', 'dd-mm-yyyy'), '6', '10', '283', '10', '2082', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30235, to_date('11-10-2082', 'dd-mm-yyyy'), '7', '11', '284', '10', '2082', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30236, to_date('12-10-2082', 'dd-mm-yyyy'), '1', '12', '285', '10', '2082', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30237, to_date('13-10-2082', 'dd-mm-yyyy'), '2', '13', '286', '10', '2082', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30238, to_date('14-10-2082', 'dd-mm-yyyy'), '3', '14', '287', '10', '2082', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30239, to_date('15-10-2082', 'dd-mm-yyyy'), '4', '15', '288', '10', '2082', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30240, to_date('16-10-2082', 'dd-mm-yyyy'), '5', '16', '289', '10', '2082', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30241, to_date('17-10-2082', 'dd-mm-yyyy'), '6', '17', '290', '10', '2082', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30242, to_date('18-10-2082', 'dd-mm-yyyy'), '7', '18', '291', '10', '2082', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30243, to_date('19-10-2082', 'dd-mm-yyyy'), '1', '19', '292', '10', '2082', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30244, to_date('20-10-2082', 'dd-mm-yyyy'), '2', '20', '293', '10', '2082', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30245, to_date('21-10-2082', 'dd-mm-yyyy'), '3', '21', '294', '10', '2082', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30246, to_date('22-10-2082', 'dd-mm-yyyy'), '4', '22', '295', '10', '2082', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30247, to_date('23-10-2082', 'dd-mm-yyyy'), '5', '23', '296', '10', '2082', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30248, to_date('24-10-2082', 'dd-mm-yyyy'), '6', '24', '297', '10', '2082', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30249, to_date('25-10-2082', 'dd-mm-yyyy'), '7', '25', '298', '10', '2082', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30250, to_date('26-10-2082', 'dd-mm-yyyy'), '1', '26', '299', '10', '2082', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30251, to_date('27-10-2082', 'dd-mm-yyyy'), '2', '27', '300', '10', '2082', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30252, to_date('28-10-2082', 'dd-mm-yyyy'), '3', '28', '301', '10', '2082', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30253, to_date('29-10-2082', 'dd-mm-yyyy'), '4', '29', '302', '10', '2082', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30254, to_date('30-10-2082', 'dd-mm-yyyy'), '5', '30', '303', '10', '2082', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30255, to_date('31-10-2082', 'dd-mm-yyyy'), '6', '31', '304', '10', '2082', '44', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30256, to_date('01-11-2082', 'dd-mm-yyyy'), '7', '01', '305', '11', '2082', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30257, to_date('02-11-2082', 'dd-mm-yyyy'), '1', '02', '306', '11', '2082', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30258, to_date('03-11-2082', 'dd-mm-yyyy'), '2', '03', '307', '11', '2082', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30259, to_date('04-11-2082', 'dd-mm-yyyy'), '3', '04', '308', '11', '2082', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30260, to_date('05-11-2082', 'dd-mm-yyyy'), '4', '05', '309', '11', '2082', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30261, to_date('06-11-2082', 'dd-mm-yyyy'), '5', '06', '310', '11', '2082', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30262, to_date('07-11-2082', 'dd-mm-yyyy'), '6', '07', '311', '11', '2082', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30263, to_date('08-11-2082', 'dd-mm-yyyy'), '7', '08', '312', '11', '2082', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30264, to_date('09-11-2082', 'dd-mm-yyyy'), '1', '09', '313', '11', '2082', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30265, to_date('10-11-2082', 'dd-mm-yyyy'), '2', '10', '314', '11', '2082', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30266, to_date('11-11-2082', 'dd-mm-yyyy'), '3', '11', '315', '11', '2082', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30267, to_date('12-11-2082', 'dd-mm-yyyy'), '4', '12', '316', '11', '2082', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30268, to_date('13-11-2082', 'dd-mm-yyyy'), '5', '13', '317', '11', '2082', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30269, to_date('14-11-2082', 'dd-mm-yyyy'), '6', '14', '318', '11', '2082', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30270, to_date('15-11-2082', 'dd-mm-yyyy'), '7', '15', '319', '11', '2082', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30271, to_date('16-11-2082', 'dd-mm-yyyy'), '1', '16', '320', '11', '2082', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30272, to_date('17-11-2082', 'dd-mm-yyyy'), '2', '17', '321', '11', '2082', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30273, to_date('18-11-2082', 'dd-mm-yyyy'), '3', '18', '322', '11', '2082', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30274, to_date('19-11-2082', 'dd-mm-yyyy'), '4', '19', '323', '11', '2082', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30275, to_date('20-11-2082', 'dd-mm-yyyy'), '5', '20', '324', '11', '2082', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30276, to_date('21-11-2082', 'dd-mm-yyyy'), '6', '21', '325', '11', '2082', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30277, to_date('22-11-2082', 'dd-mm-yyyy'), '7', '22', '326', '11', '2082', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30278, to_date('23-11-2082', 'dd-mm-yyyy'), '1', '23', '327', '11', '2082', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30279, to_date('24-11-2082', 'dd-mm-yyyy'), '2', '24', '328', '11', '2082', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30280, to_date('25-11-2082', 'dd-mm-yyyy'), '3', '25', '329', '11', '2082', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30281, to_date('26-11-2082', 'dd-mm-yyyy'), '4', '26', '330', '11', '2082', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30282, to_date('27-11-2082', 'dd-mm-yyyy'), '5', '27', '331', '11', '2082', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30283, to_date('28-11-2082', 'dd-mm-yyyy'), '6', '28', '332', '11', '2082', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30284, to_date('29-11-2082', 'dd-mm-yyyy'), '7', '29', '333', '11', '2082', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30285, to_date('30-11-2082', 'dd-mm-yyyy'), '1', '30', '334', '11', '2082', '49', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30286, to_date('01-12-2082', 'dd-mm-yyyy'), '2', '01', '335', '12', '2082', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30287, to_date('02-12-2082', 'dd-mm-yyyy'), '3', '02', '336', '12', '2082', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30288, to_date('03-12-2082', 'dd-mm-yyyy'), '4', '03', '337', '12', '2082', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30289, to_date('04-12-2082', 'dd-mm-yyyy'), '5', '04', '338', '12', '2082', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30290, to_date('05-12-2082', 'dd-mm-yyyy'), '6', '05', '339', '12', '2082', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31775, to_date('29-12-2086', 'dd-mm-yyyy'), '7', '29', '363', '12', '2086', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31776, to_date('30-12-2086', 'dd-mm-yyyy'), '1', '30', '364', '12', '2086', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31777, to_date('31-12-2086', 'dd-mm-yyyy'), '2', '31', '365', '12', '2086', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31778, to_date('01-01-2087', 'dd-mm-yyyy'), '3', '01', '001', '01', '2087', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31779, to_date('02-01-2087', 'dd-mm-yyyy'), '4', '02', '002', '01', '2087', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31780, to_date('03-01-2087', 'dd-mm-yyyy'), '5', '03', '003', '01', '2087', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31781, to_date('04-01-2087', 'dd-mm-yyyy'), '6', '04', '004', '01', '2087', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31782, to_date('05-01-2087', 'dd-mm-yyyy'), '7', '05', '005', '01', '2087', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31783, to_date('06-01-2087', 'dd-mm-yyyy'), '1', '06', '006', '01', '2087', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31784, to_date('07-01-2087', 'dd-mm-yyyy'), '2', '07', '007', '01', '2087', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31785, to_date('08-01-2087', 'dd-mm-yyyy'), '3', '08', '008', '01', '2087', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31786, to_date('09-01-2087', 'dd-mm-yyyy'), '4', '09', '009', '01', '2087', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31787, to_date('10-01-2087', 'dd-mm-yyyy'), '5', '10', '010', '01', '2087', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31788, to_date('11-01-2087', 'dd-mm-yyyy'), '6', '11', '011', '01', '2087', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31789, to_date('12-01-2087', 'dd-mm-yyyy'), '7', '12', '012', '01', '2087', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31790, to_date('13-01-2087', 'dd-mm-yyyy'), '1', '13', '013', '01', '2087', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31791, to_date('14-01-2087', 'dd-mm-yyyy'), '2', '14', '014', '01', '2087', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31792, to_date('15-01-2087', 'dd-mm-yyyy'), '3', '15', '015', '01', '2087', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31793, to_date('16-01-2087', 'dd-mm-yyyy'), '4', '16', '016', '01', '2087', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31794, to_date('17-01-2087', 'dd-mm-yyyy'), '5', '17', '017', '01', '2087', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31795, to_date('18-01-2087', 'dd-mm-yyyy'), '6', '18', '018', '01', '2087', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31796, to_date('19-01-2087', 'dd-mm-yyyy'), '7', '19', '019', '01', '2087', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31797, to_date('20-01-2087', 'dd-mm-yyyy'), '1', '20', '020', '01', '2087', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31798, to_date('21-01-2087', 'dd-mm-yyyy'), '2', '21', '021', '01', '2087', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31799, to_date('22-01-2087', 'dd-mm-yyyy'), '3', '22', '022', '01', '2087', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31800, to_date('23-01-2087', 'dd-mm-yyyy'), '4', '23', '023', '01', '2087', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31801, to_date('24-01-2087', 'dd-mm-yyyy'), '5', '24', '024', '01', '2087', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31802, to_date('25-01-2087', 'dd-mm-yyyy'), '6', '25', '025', '01', '2087', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31803, to_date('26-01-2087', 'dd-mm-yyyy'), '7', '26', '026', '01', '2087', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31804, to_date('27-01-2087', 'dd-mm-yyyy'), '1', '27', '027', '01', '2087', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31805, to_date('28-01-2087', 'dd-mm-yyyy'), '2', '28', '028', '01', '2087', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31806, to_date('29-01-2087', 'dd-mm-yyyy'), '3', '29', '029', '01', '2087', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31807, to_date('30-01-2087', 'dd-mm-yyyy'), '4', '30', '030', '01', '2087', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31808, to_date('31-01-2087', 'dd-mm-yyyy'), '5', '31', '031', '01', '2087', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31809, to_date('01-02-2087', 'dd-mm-yyyy'), '6', '01', '032', '02', '2087', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31810, to_date('02-02-2087', 'dd-mm-yyyy'), '7', '02', '033', '02', '2087', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31811, to_date('03-02-2087', 'dd-mm-yyyy'), '1', '03', '034', '02', '2087', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31812, to_date('04-02-2087', 'dd-mm-yyyy'), '2', '04', '035', '02', '2087', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31813, to_date('05-02-2087', 'dd-mm-yyyy'), '3', '05', '036', '02', '2087', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31814, to_date('06-02-2087', 'dd-mm-yyyy'), '4', '06', '037', '02', '2087', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31815, to_date('07-02-2087', 'dd-mm-yyyy'), '5', '07', '038', '02', '2087', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31816, to_date('08-02-2087', 'dd-mm-yyyy'), '6', '08', '039', '02', '2087', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31817, to_date('09-02-2087', 'dd-mm-yyyy'), '7', '09', '040', '02', '2087', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31818, to_date('10-02-2087', 'dd-mm-yyyy'), '1', '10', '041', '02', '2087', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31819, to_date('11-02-2087', 'dd-mm-yyyy'), '2', '11', '042', '02', '2087', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31820, to_date('12-02-2087', 'dd-mm-yyyy'), '3', '12', '043', '02', '2087', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31821, to_date('13-02-2087', 'dd-mm-yyyy'), '4', '13', '044', '02', '2087', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31822, to_date('14-02-2087', 'dd-mm-yyyy'), '5', '14', '045', '02', '2087', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31823, to_date('15-02-2087', 'dd-mm-yyyy'), '6', '15', '046', '02', '2087', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31824, to_date('16-02-2087', 'dd-mm-yyyy'), '7', '16', '047', '02', '2087', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31825, to_date('17-02-2087', 'dd-mm-yyyy'), '1', '17', '048', '02', '2087', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31826, to_date('18-02-2087', 'dd-mm-yyyy'), '2', '18', '049', '02', '2087', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31827, to_date('19-02-2087', 'dd-mm-yyyy'), '3', '19', '050', '02', '2087', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31828, to_date('20-02-2087', 'dd-mm-yyyy'), '4', '20', '051', '02', '2087', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31829, to_date('21-02-2087', 'dd-mm-yyyy'), '5', '21', '052', '02', '2087', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31830, to_date('22-02-2087', 'dd-mm-yyyy'), '6', '22', '053', '02', '2087', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31831, to_date('23-02-2087', 'dd-mm-yyyy'), '7', '23', '054', '02', '2087', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31832, to_date('24-02-2087', 'dd-mm-yyyy'), '1', '24', '055', '02', '2087', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31833, to_date('25-02-2087', 'dd-mm-yyyy'), '2', '25', '056', '02', '2087', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31834, to_date('26-02-2087', 'dd-mm-yyyy'), '3', '26', '057', '02', '2087', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31835, to_date('27-02-2087', 'dd-mm-yyyy'), '4', '27', '058', '02', '2087', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31836, to_date('28-02-2087', 'dd-mm-yyyy'), '5', '28', '059', '02', '2087', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31837, to_date('01-03-2087', 'dd-mm-yyyy'), '6', '01', '060', '03', '2087', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31838, to_date('02-03-2087', 'dd-mm-yyyy'), '7', '02', '061', '03', '2087', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31839, to_date('03-03-2087', 'dd-mm-yyyy'), '1', '03', '062', '03', '2087', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31840, to_date('04-03-2087', 'dd-mm-yyyy'), '2', '04', '063', '03', '2087', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31841, to_date('05-03-2087', 'dd-mm-yyyy'), '3', '05', '064', '03', '2087', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31842, to_date('06-03-2087', 'dd-mm-yyyy'), '4', '06', '065', '03', '2087', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31843, to_date('07-03-2087', 'dd-mm-yyyy'), '5', '07', '066', '03', '2087', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31844, to_date('08-03-2087', 'dd-mm-yyyy'), '6', '08', '067', '03', '2087', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31845, to_date('09-03-2087', 'dd-mm-yyyy'), '7', '09', '068', '03', '2087', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31846, to_date('10-03-2087', 'dd-mm-yyyy'), '1', '10', '069', '03', '2087', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31847, to_date('11-03-2087', 'dd-mm-yyyy'), '2', '11', '070', '03', '2087', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31848, to_date('12-03-2087', 'dd-mm-yyyy'), '3', '12', '071', '03', '2087', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31849, to_date('13-03-2087', 'dd-mm-yyyy'), '4', '13', '072', '03', '2087', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31850, to_date('14-03-2087', 'dd-mm-yyyy'), '5', '14', '073', '03', '2087', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31851, to_date('15-03-2087', 'dd-mm-yyyy'), '6', '15', '074', '03', '2087', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31852, to_date('16-03-2087', 'dd-mm-yyyy'), '7', '16', '075', '03', '2087', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31853, to_date('17-03-2087', 'dd-mm-yyyy'), '1', '17', '076', '03', '2087', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31854, to_date('18-03-2087', 'dd-mm-yyyy'), '2', '18', '077', '03', '2087', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31855, to_date('19-03-2087', 'dd-mm-yyyy'), '3', '19', '078', '03', '2087', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31856, to_date('20-03-2087', 'dd-mm-yyyy'), '4', '20', '079', '03', '2087', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31857, to_date('21-03-2087', 'dd-mm-yyyy'), '5', '21', '080', '03', '2087', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31858, to_date('22-03-2087', 'dd-mm-yyyy'), '6', '22', '081', '03', '2087', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31859, to_date('23-03-2087', 'dd-mm-yyyy'), '7', '23', '082', '03', '2087', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31860, to_date('24-03-2087', 'dd-mm-yyyy'), '1', '24', '083', '03', '2087', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31861, to_date('25-03-2087', 'dd-mm-yyyy'), '2', '25', '084', '03', '2087', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31862, to_date('26-03-2087', 'dd-mm-yyyy'), '3', '26', '085', '03', '2087', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31863, to_date('27-03-2087', 'dd-mm-yyyy'), '4', '27', '086', '03', '2087', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31864, to_date('28-03-2087', 'dd-mm-yyyy'), '5', '28', '087', '03', '2087', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31865, to_date('29-03-2087', 'dd-mm-yyyy'), '6', '29', '088', '03', '2087', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31866, to_date('30-03-2087', 'dd-mm-yyyy'), '7', '30', '089', '03', '2087', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31867, to_date('31-03-2087', 'dd-mm-yyyy'), '1', '31', '090', '03', '2087', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31868, to_date('01-04-2087', 'dd-mm-yyyy'), '2', '01', '091', '04', '2087', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31869, to_date('02-04-2087', 'dd-mm-yyyy'), '3', '02', '092', '04', '2087', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31870, to_date('03-04-2087', 'dd-mm-yyyy'), '4', '03', '093', '04', '2087', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31871, to_date('04-04-2087', 'dd-mm-yyyy'), '5', '04', '094', '04', '2087', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31872, to_date('05-04-2087', 'dd-mm-yyyy'), '6', '05', '095', '04', '2087', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31873, to_date('06-04-2087', 'dd-mm-yyyy'), '7', '06', '096', '04', '2087', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31874, to_date('07-04-2087', 'dd-mm-yyyy'), '1', '07', '097', '04', '2087', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31875, to_date('08-04-2087', 'dd-mm-yyyy'), '2', '08', '098', '04', '2087', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31876, to_date('09-04-2087', 'dd-mm-yyyy'), '3', '09', '099', '04', '2087', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31877, to_date('10-04-2087', 'dd-mm-yyyy'), '4', '10', '100', '04', '2087', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31878, to_date('11-04-2087', 'dd-mm-yyyy'), '5', '11', '101', '04', '2087', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31879, to_date('12-04-2087', 'dd-mm-yyyy'), '6', '12', '102', '04', '2087', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31880, to_date('13-04-2087', 'dd-mm-yyyy'), '7', '13', '103', '04', '2087', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27005, to_date('07-12-2073', 'dd-mm-yyyy'), '4', '07', '341', '12', '2073', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27006, to_date('08-12-2073', 'dd-mm-yyyy'), '5', '08', '342', '12', '2073', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27007, to_date('09-12-2073', 'dd-mm-yyyy'), '6', '09', '343', '12', '2073', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27008, to_date('10-12-2073', 'dd-mm-yyyy'), '7', '10', '344', '12', '2073', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27009, to_date('11-12-2073', 'dd-mm-yyyy'), '1', '11', '345', '12', '2073', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27010, to_date('12-12-2073', 'dd-mm-yyyy'), '2', '12', '346', '12', '2073', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27011, to_date('13-12-2073', 'dd-mm-yyyy'), '3', '13', '347', '12', '2073', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27012, to_date('14-12-2073', 'dd-mm-yyyy'), '4', '14', '348', '12', '2073', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27013, to_date('15-12-2073', 'dd-mm-yyyy'), '5', '15', '349', '12', '2073', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27014, to_date('16-12-2073', 'dd-mm-yyyy'), '6', '16', '350', '12', '2073', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27015, to_date('17-12-2073', 'dd-mm-yyyy'), '7', '17', '351', '12', '2073', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27016, to_date('18-12-2073', 'dd-mm-yyyy'), '1', '18', '352', '12', '2073', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27017, to_date('19-12-2073', 'dd-mm-yyyy'), '2', '19', '353', '12', '2073', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27018, to_date('20-12-2073', 'dd-mm-yyyy'), '3', '20', '354', '12', '2073', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27019, to_date('21-12-2073', 'dd-mm-yyyy'), '4', '21', '355', '12', '2073', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27020, to_date('22-12-2073', 'dd-mm-yyyy'), '5', '22', '356', '12', '2073', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27021, to_date('23-12-2073', 'dd-mm-yyyy'), '6', '23', '357', '12', '2073', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27022, to_date('24-12-2073', 'dd-mm-yyyy'), '7', '24', '358', '12', '2073', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27023, to_date('25-12-2073', 'dd-mm-yyyy'), '1', '25', '359', '12', '2073', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27024, to_date('26-12-2073', 'dd-mm-yyyy'), '2', '26', '360', '12', '2073', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27025, to_date('27-12-2073', 'dd-mm-yyyy'), '3', '27', '361', '12', '2073', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27026, to_date('28-12-2073', 'dd-mm-yyyy'), '4', '28', '362', '12', '2073', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27027, to_date('29-12-2073', 'dd-mm-yyyy'), '5', '29', '363', '12', '2073', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27028, to_date('30-12-2073', 'dd-mm-yyyy'), '6', '30', '364', '12', '2073', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27029, to_date('31-12-2073', 'dd-mm-yyyy'), '7', '31', '365', '12', '2073', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27030, to_date('01-01-2074', 'dd-mm-yyyy'), '1', '01', '001', '01', '2074', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27031, to_date('02-01-2074', 'dd-mm-yyyy'), '2', '02', '002', '01', '2074', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27032, to_date('03-01-2074', 'dd-mm-yyyy'), '3', '03', '003', '01', '2074', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27033, to_date('04-01-2074', 'dd-mm-yyyy'), '4', '04', '004', '01', '2074', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27034, to_date('05-01-2074', 'dd-mm-yyyy'), '5', '05', '005', '01', '2074', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27035, to_date('06-01-2074', 'dd-mm-yyyy'), '6', '06', '006', '01', '2074', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27036, to_date('07-01-2074', 'dd-mm-yyyy'), '7', '07', '007', '01', '2074', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27037, to_date('08-01-2074', 'dd-mm-yyyy'), '1', '08', '008', '01', '2074', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27038, to_date('09-01-2074', 'dd-mm-yyyy'), '2', '09', '009', '01', '2074', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27039, to_date('10-01-2074', 'dd-mm-yyyy'), '3', '10', '010', '01', '2074', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27040, to_date('11-01-2074', 'dd-mm-yyyy'), '4', '11', '011', '01', '2074', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27041, to_date('12-01-2074', 'dd-mm-yyyy'), '5', '12', '012', '01', '2074', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27042, to_date('13-01-2074', 'dd-mm-yyyy'), '6', '13', '013', '01', '2074', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27043, to_date('14-01-2074', 'dd-mm-yyyy'), '7', '14', '014', '01', '2074', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27044, to_date('15-01-2074', 'dd-mm-yyyy'), '1', '15', '015', '01', '2074', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27045, to_date('16-01-2074', 'dd-mm-yyyy'), '2', '16', '016', '01', '2074', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27046, to_date('17-01-2074', 'dd-mm-yyyy'), '3', '17', '017', '01', '2074', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27047, to_date('18-01-2074', 'dd-mm-yyyy'), '4', '18', '018', '01', '2074', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27048, to_date('19-01-2074', 'dd-mm-yyyy'), '5', '19', '019', '01', '2074', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27049, to_date('20-01-2074', 'dd-mm-yyyy'), '6', '20', '020', '01', '2074', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27050, to_date('21-01-2074', 'dd-mm-yyyy'), '7', '21', '021', '01', '2074', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27051, to_date('22-01-2074', 'dd-mm-yyyy'), '1', '22', '022', '01', '2074', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27052, to_date('23-01-2074', 'dd-mm-yyyy'), '2', '23', '023', '01', '2074', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27053, to_date('24-01-2074', 'dd-mm-yyyy'), '3', '24', '024', '01', '2074', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27054, to_date('25-01-2074', 'dd-mm-yyyy'), '4', '25', '025', '01', '2074', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27055, to_date('26-01-2074', 'dd-mm-yyyy'), '5', '26', '026', '01', '2074', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27056, to_date('27-01-2074', 'dd-mm-yyyy'), '6', '27', '027', '01', '2074', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27057, to_date('28-01-2074', 'dd-mm-yyyy'), '7', '28', '028', '01', '2074', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27058, to_date('29-01-2074', 'dd-mm-yyyy'), '1', '29', '029', '01', '2074', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27059, to_date('30-01-2074', 'dd-mm-yyyy'), '2', '30', '030', '01', '2074', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27060, to_date('31-01-2074', 'dd-mm-yyyy'), '3', '31', '031', '01', '2074', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27061, to_date('01-02-2074', 'dd-mm-yyyy'), '4', '01', '032', '02', '2074', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27062, to_date('02-02-2074', 'dd-mm-yyyy'), '5', '02', '033', '02', '2074', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27063, to_date('03-02-2074', 'dd-mm-yyyy'), '6', '03', '034', '02', '2074', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27064, to_date('04-02-2074', 'dd-mm-yyyy'), '7', '04', '035', '02', '2074', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27065, to_date('05-02-2074', 'dd-mm-yyyy'), '1', '05', '036', '02', '2074', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27066, to_date('06-02-2074', 'dd-mm-yyyy'), '2', '06', '037', '02', '2074', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27067, to_date('07-02-2074', 'dd-mm-yyyy'), '3', '07', '038', '02', '2074', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27068, to_date('08-02-2074', 'dd-mm-yyyy'), '4', '08', '039', '02', '2074', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27069, to_date('09-02-2074', 'dd-mm-yyyy'), '5', '09', '040', '02', '2074', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27070, to_date('10-02-2074', 'dd-mm-yyyy'), '6', '10', '041', '02', '2074', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27071, to_date('11-02-2074', 'dd-mm-yyyy'), '7', '11', '042', '02', '2074', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27072, to_date('12-02-2074', 'dd-mm-yyyy'), '1', '12', '043', '02', '2074', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27073, to_date('13-02-2074', 'dd-mm-yyyy'), '2', '13', '044', '02', '2074', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27074, to_date('14-02-2074', 'dd-mm-yyyy'), '3', '14', '045', '02', '2074', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27075, to_date('15-02-2074', 'dd-mm-yyyy'), '4', '15', '046', '02', '2074', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27076, to_date('16-02-2074', 'dd-mm-yyyy'), '5', '16', '047', '02', '2074', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27077, to_date('17-02-2074', 'dd-mm-yyyy'), '6', '17', '048', '02', '2074', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27078, to_date('18-02-2074', 'dd-mm-yyyy'), '7', '18', '049', '02', '2074', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27079, to_date('19-02-2074', 'dd-mm-yyyy'), '1', '19', '050', '02', '2074', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27080, to_date('20-02-2074', 'dd-mm-yyyy'), '2', '20', '051', '02', '2074', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27081, to_date('21-02-2074', 'dd-mm-yyyy'), '3', '21', '052', '02', '2074', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27082, to_date('22-02-2074', 'dd-mm-yyyy'), '4', '22', '053', '02', '2074', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27083, to_date('23-02-2074', 'dd-mm-yyyy'), '5', '23', '054', '02', '2074', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27084, to_date('24-02-2074', 'dd-mm-yyyy'), '6', '24', '055', '02', '2074', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27085, to_date('25-02-2074', 'dd-mm-yyyy'), '7', '25', '056', '02', '2074', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27086, to_date('26-02-2074', 'dd-mm-yyyy'), '1', '26', '057', '02', '2074', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27087, to_date('27-02-2074', 'dd-mm-yyyy'), '2', '27', '058', '02', '2074', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27088, to_date('28-02-2074', 'dd-mm-yyyy'), '3', '28', '059', '02', '2074', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27089, to_date('01-03-2074', 'dd-mm-yyyy'), '4', '01', '060', '03', '2074', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27090, to_date('02-03-2074', 'dd-mm-yyyy'), '5', '02', '061', '03', '2074', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27091, to_date('03-03-2074', 'dd-mm-yyyy'), '6', '03', '062', '03', '2074', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27092, to_date('04-03-2074', 'dd-mm-yyyy'), '7', '04', '063', '03', '2074', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27093, to_date('05-03-2074', 'dd-mm-yyyy'), '1', '05', '064', '03', '2074', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27094, to_date('06-03-2074', 'dd-mm-yyyy'), '2', '06', '065', '03', '2074', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27095, to_date('07-03-2074', 'dd-mm-yyyy'), '3', '07', '066', '03', '2074', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27096, to_date('08-03-2074', 'dd-mm-yyyy'), '4', '08', '067', '03', '2074', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27097, to_date('09-03-2074', 'dd-mm-yyyy'), '5', '09', '068', '03', '2074', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27098, to_date('10-03-2074', 'dd-mm-yyyy'), '6', '10', '069', '03', '2074', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27099, to_date('11-03-2074', 'dd-mm-yyyy'), '7', '11', '070', '03', '2074', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27100, to_date('12-03-2074', 'dd-mm-yyyy'), '1', '12', '071', '03', '2074', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27101, to_date('13-03-2074', 'dd-mm-yyyy'), '2', '13', '072', '03', '2074', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27102, to_date('14-03-2074', 'dd-mm-yyyy'), '3', '14', '073', '03', '2074', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27103, to_date('15-03-2074', 'dd-mm-yyyy'), '4', '15', '074', '03', '2074', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27104, to_date('16-03-2074', 'dd-mm-yyyy'), '5', '16', '075', '03', '2074', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27105, to_date('17-03-2074', 'dd-mm-yyyy'), '6', '17', '076', '03', '2074', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27106, to_date('18-03-2074', 'dd-mm-yyyy'), '7', '18', '077', '03', '2074', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27107, to_date('19-03-2074', 'dd-mm-yyyy'), '1', '19', '078', '03', '2074', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27108, to_date('20-03-2074', 'dd-mm-yyyy'), '2', '20', '079', '03', '2074', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27109, to_date('21-03-2074', 'dd-mm-yyyy'), '3', '21', '080', '03', '2074', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27110, to_date('22-03-2074', 'dd-mm-yyyy'), '4', '22', '081', '03', '2074', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28701, to_date('30-07-2078', 'dd-mm-yyyy'), '6', '30', '211', '07', '2078', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28702, to_date('31-07-2078', 'dd-mm-yyyy'), '7', '31', '212', '07', '2078', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28703, to_date('01-08-2078', 'dd-mm-yyyy'), '1', '01', '213', '08', '2078', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28704, to_date('02-08-2078', 'dd-mm-yyyy'), '2', '02', '214', '08', '2078', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28705, to_date('03-08-2078', 'dd-mm-yyyy'), '3', '03', '215', '08', '2078', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28706, to_date('04-08-2078', 'dd-mm-yyyy'), '4', '04', '216', '08', '2078', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28707, to_date('05-08-2078', 'dd-mm-yyyy'), '5', '05', '217', '08', '2078', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28708, to_date('06-08-2078', 'dd-mm-yyyy'), '6', '06', '218', '08', '2078', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28709, to_date('07-08-2078', 'dd-mm-yyyy'), '7', '07', '219', '08', '2078', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28710, to_date('08-08-2078', 'dd-mm-yyyy'), '1', '08', '220', '08', '2078', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28711, to_date('09-08-2078', 'dd-mm-yyyy'), '2', '09', '221', '08', '2078', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28712, to_date('10-08-2078', 'dd-mm-yyyy'), '3', '10', '222', '08', '2078', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28713, to_date('11-08-2078', 'dd-mm-yyyy'), '4', '11', '223', '08', '2078', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28714, to_date('12-08-2078', 'dd-mm-yyyy'), '5', '12', '224', '08', '2078', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28715, to_date('13-08-2078', 'dd-mm-yyyy'), '6', '13', '225', '08', '2078', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28716, to_date('14-08-2078', 'dd-mm-yyyy'), '7', '14', '226', '08', '2078', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28717, to_date('15-08-2078', 'dd-mm-yyyy'), '1', '15', '227', '08', '2078', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28718, to_date('16-08-2078', 'dd-mm-yyyy'), '2', '16', '228', '08', '2078', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28719, to_date('17-08-2078', 'dd-mm-yyyy'), '3', '17', '229', '08', '2078', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28720, to_date('18-08-2078', 'dd-mm-yyyy'), '4', '18', '230', '08', '2078', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28721, to_date('19-08-2078', 'dd-mm-yyyy'), '5', '19', '231', '08', '2078', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28722, to_date('20-08-2078', 'dd-mm-yyyy'), '6', '20', '232', '08', '2078', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28723, to_date('21-08-2078', 'dd-mm-yyyy'), '7', '21', '233', '08', '2078', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28724, to_date('22-08-2078', 'dd-mm-yyyy'), '1', '22', '234', '08', '2078', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28725, to_date('23-08-2078', 'dd-mm-yyyy'), '2', '23', '235', '08', '2078', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28726, to_date('24-08-2078', 'dd-mm-yyyy'), '3', '24', '236', '08', '2078', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28727, to_date('25-08-2078', 'dd-mm-yyyy'), '4', '25', '237', '08', '2078', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28728, to_date('26-08-2078', 'dd-mm-yyyy'), '5', '26', '238', '08', '2078', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28729, to_date('27-08-2078', 'dd-mm-yyyy'), '6', '27', '239', '08', '2078', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28730, to_date('28-08-2078', 'dd-mm-yyyy'), '7', '28', '240', '08', '2078', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28731, to_date('29-08-2078', 'dd-mm-yyyy'), '1', '29', '241', '08', '2078', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28732, to_date('30-08-2078', 'dd-mm-yyyy'), '2', '30', '242', '08', '2078', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28733, to_date('31-08-2078', 'dd-mm-yyyy'), '3', '31', '243', '08', '2078', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28734, to_date('01-09-2078', 'dd-mm-yyyy'), '4', '01', '244', '09', '2078', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28735, to_date('02-09-2078', 'dd-mm-yyyy'), '5', '02', '245', '09', '2078', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28736, to_date('03-09-2078', 'dd-mm-yyyy'), '6', '03', '246', '09', '2078', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28737, to_date('04-09-2078', 'dd-mm-yyyy'), '7', '04', '247', '09', '2078', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28738, to_date('05-09-2078', 'dd-mm-yyyy'), '1', '05', '248', '09', '2078', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28739, to_date('06-09-2078', 'dd-mm-yyyy'), '2', '06', '249', '09', '2078', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28740, to_date('07-09-2078', 'dd-mm-yyyy'), '3', '07', '250', '09', '2078', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28741, to_date('08-09-2078', 'dd-mm-yyyy'), '4', '08', '251', '09', '2078', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28742, to_date('09-09-2078', 'dd-mm-yyyy'), '5', '09', '252', '09', '2078', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28743, to_date('10-09-2078', 'dd-mm-yyyy'), '6', '10', '253', '09', '2078', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28744, to_date('11-09-2078', 'dd-mm-yyyy'), '7', '11', '254', '09', '2078', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28745, to_date('12-09-2078', 'dd-mm-yyyy'), '1', '12', '255', '09', '2078', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28746, to_date('13-09-2078', 'dd-mm-yyyy'), '2', '13', '256', '09', '2078', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28747, to_date('14-09-2078', 'dd-mm-yyyy'), '3', '14', '257', '09', '2078', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28748, to_date('15-09-2078', 'dd-mm-yyyy'), '4', '15', '258', '09', '2078', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28749, to_date('16-09-2078', 'dd-mm-yyyy'), '5', '16', '259', '09', '2078', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28750, to_date('17-09-2078', 'dd-mm-yyyy'), '6', '17', '260', '09', '2078', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28751, to_date('18-09-2078', 'dd-mm-yyyy'), '7', '18', '261', '09', '2078', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28752, to_date('19-09-2078', 'dd-mm-yyyy'), '1', '19', '262', '09', '2078', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28753, to_date('20-09-2078', 'dd-mm-yyyy'), '2', '20', '263', '09', '2078', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28754, to_date('21-09-2078', 'dd-mm-yyyy'), '3', '21', '264', '09', '2078', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28755, to_date('22-09-2078', 'dd-mm-yyyy'), '4', '22', '265', '09', '2078', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28756, to_date('23-09-2078', 'dd-mm-yyyy'), '5', '23', '266', '09', '2078', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28757, to_date('24-09-2078', 'dd-mm-yyyy'), '6', '24', '267', '09', '2078', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28758, to_date('25-09-2078', 'dd-mm-yyyy'), '7', '25', '268', '09', '2078', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28759, to_date('26-09-2078', 'dd-mm-yyyy'), '1', '26', '269', '09', '2078', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28760, to_date('27-09-2078', 'dd-mm-yyyy'), '2', '27', '270', '09', '2078', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28761, to_date('28-09-2078', 'dd-mm-yyyy'), '3', '28', '271', '09', '2078', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28762, to_date('29-09-2078', 'dd-mm-yyyy'), '4', '29', '272', '09', '2078', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28763, to_date('30-09-2078', 'dd-mm-yyyy'), '5', '30', '273', '09', '2078', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28764, to_date('01-10-2078', 'dd-mm-yyyy'), '6', '01', '274', '10', '2078', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28765, to_date('02-10-2078', 'dd-mm-yyyy'), '7', '02', '275', '10', '2078', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28766, to_date('03-10-2078', 'dd-mm-yyyy'), '1', '03', '276', '10', '2078', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28767, to_date('04-10-2078', 'dd-mm-yyyy'), '2', '04', '277', '10', '2078', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28768, to_date('05-10-2078', 'dd-mm-yyyy'), '3', '05', '278', '10', '2078', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28769, to_date('06-10-2078', 'dd-mm-yyyy'), '4', '06', '279', '10', '2078', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28770, to_date('07-10-2078', 'dd-mm-yyyy'), '5', '07', '280', '10', '2078', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28771, to_date('08-10-2078', 'dd-mm-yyyy'), '6', '08', '281', '10', '2078', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28772, to_date('09-10-2078', 'dd-mm-yyyy'), '7', '09', '282', '10', '2078', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28773, to_date('10-10-2078', 'dd-mm-yyyy'), '1', '10', '283', '10', '2078', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28774, to_date('11-10-2078', 'dd-mm-yyyy'), '2', '11', '284', '10', '2078', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28775, to_date('12-10-2078', 'dd-mm-yyyy'), '3', '12', '285', '10', '2078', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28776, to_date('13-10-2078', 'dd-mm-yyyy'), '4', '13', '286', '10', '2078', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28777, to_date('14-10-2078', 'dd-mm-yyyy'), '5', '14', '287', '10', '2078', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28778, to_date('15-10-2078', 'dd-mm-yyyy'), '6', '15', '288', '10', '2078', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28779, to_date('16-10-2078', 'dd-mm-yyyy'), '7', '16', '289', '10', '2078', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28780, to_date('17-10-2078', 'dd-mm-yyyy'), '1', '17', '290', '10', '2078', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28781, to_date('18-10-2078', 'dd-mm-yyyy'), '2', '18', '291', '10', '2078', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28782, to_date('19-10-2078', 'dd-mm-yyyy'), '3', '19', '292', '10', '2078', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28783, to_date('20-10-2078', 'dd-mm-yyyy'), '4', '20', '293', '10', '2078', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28784, to_date('21-10-2078', 'dd-mm-yyyy'), '5', '21', '294', '10', '2078', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28785, to_date('22-10-2078', 'dd-mm-yyyy'), '6', '22', '295', '10', '2078', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28786, to_date('23-10-2078', 'dd-mm-yyyy'), '7', '23', '296', '10', '2078', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28787, to_date('24-10-2078', 'dd-mm-yyyy'), '1', '24', '297', '10', '2078', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28788, to_date('25-10-2078', 'dd-mm-yyyy'), '2', '25', '298', '10', '2078', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28789, to_date('26-10-2078', 'dd-mm-yyyy'), '3', '26', '299', '10', '2078', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28790, to_date('27-10-2078', 'dd-mm-yyyy'), '4', '27', '300', '10', '2078', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28791, to_date('28-10-2078', 'dd-mm-yyyy'), '5', '28', '301', '10', '2078', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28792, to_date('29-10-2078', 'dd-mm-yyyy'), '6', '29', '302', '10', '2078', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28793, to_date('30-10-2078', 'dd-mm-yyyy'), '7', '30', '303', '10', '2078', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28794, to_date('31-10-2078', 'dd-mm-yyyy'), '1', '31', '304', '10', '2078', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28795, to_date('01-11-2078', 'dd-mm-yyyy'), '2', '01', '305', '11', '2078', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28796, to_date('02-11-2078', 'dd-mm-yyyy'), '3', '02', '306', '11', '2078', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28797, to_date('03-11-2078', 'dd-mm-yyyy'), '4', '03', '307', '11', '2078', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28798, to_date('04-11-2078', 'dd-mm-yyyy'), '5', '04', '308', '11', '2078', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28799, to_date('05-11-2078', 'dd-mm-yyyy'), '6', '05', '309', '11', '2078', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28800, to_date('06-11-2078', 'dd-mm-yyyy'), '7', '06', '310', '11', '2078', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28801, to_date('07-11-2078', 'dd-mm-yyyy'), '1', '07', '311', '11', '2078', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28802, to_date('08-11-2078', 'dd-mm-yyyy'), '2', '08', '312', '11', '2078', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28803, to_date('09-11-2078', 'dd-mm-yyyy'), '3', '09', '313', '11', '2078', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28804, to_date('10-11-2078', 'dd-mm-yyyy'), '4', '10', '314', '11', '2078', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28805, to_date('11-11-2078', 'dd-mm-yyyy'), '5', '11', '315', '11', '2078', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28806, to_date('12-11-2078', 'dd-mm-yyyy'), '6', '12', '316', '11', '2078', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30291, to_date('06-12-2082', 'dd-mm-yyyy'), '7', '06', '340', '12', '2082', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30292, to_date('07-12-2082', 'dd-mm-yyyy'), '1', '07', '341', '12', '2082', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30293, to_date('08-12-2082', 'dd-mm-yyyy'), '2', '08', '342', '12', '2082', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30294, to_date('09-12-2082', 'dd-mm-yyyy'), '3', '09', '343', '12', '2082', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30295, to_date('10-12-2082', 'dd-mm-yyyy'), '4', '10', '344', '12', '2082', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30296, to_date('11-12-2082', 'dd-mm-yyyy'), '5', '11', '345', '12', '2082', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30297, to_date('12-12-2082', 'dd-mm-yyyy'), '6', '12', '346', '12', '2082', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30298, to_date('13-12-2082', 'dd-mm-yyyy'), '7', '13', '347', '12', '2082', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30299, to_date('14-12-2082', 'dd-mm-yyyy'), '1', '14', '348', '12', '2082', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30300, to_date('15-12-2082', 'dd-mm-yyyy'), '2', '15', '349', '12', '2082', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30301, to_date('16-12-2082', 'dd-mm-yyyy'), '3', '16', '350', '12', '2082', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30302, to_date('17-12-2082', 'dd-mm-yyyy'), '4', '17', '351', '12', '2082', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30303, to_date('18-12-2082', 'dd-mm-yyyy'), '5', '18', '352', '12', '2082', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30304, to_date('19-12-2082', 'dd-mm-yyyy'), '6', '19', '353', '12', '2082', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30305, to_date('20-12-2082', 'dd-mm-yyyy'), '7', '20', '354', '12', '2082', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30306, to_date('21-12-2082', 'dd-mm-yyyy'), '1', '21', '355', '12', '2082', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30307, to_date('22-12-2082', 'dd-mm-yyyy'), '2', '22', '356', '12', '2082', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30308, to_date('23-12-2082', 'dd-mm-yyyy'), '3', '23', '357', '12', '2082', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30309, to_date('24-12-2082', 'dd-mm-yyyy'), '4', '24', '358', '12', '2082', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30310, to_date('25-12-2082', 'dd-mm-yyyy'), '5', '25', '359', '12', '2082', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30311, to_date('26-12-2082', 'dd-mm-yyyy'), '6', '26', '360', '12', '2082', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30312, to_date('27-12-2082', 'dd-mm-yyyy'), '7', '27', '361', '12', '2082', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30313, to_date('28-12-2082', 'dd-mm-yyyy'), '1', '28', '362', '12', '2082', '53', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30314, to_date('29-12-2082', 'dd-mm-yyyy'), '2', '29', '363', '12', '2082', '53', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30315, to_date('30-12-2082', 'dd-mm-yyyy'), '3', '30', '364', '12', '2082', '53', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30316, to_date('31-12-2082', 'dd-mm-yyyy'), '4', '31', '365', '12', '2082', '53', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30317, to_date('01-01-2083', 'dd-mm-yyyy'), '5', '01', '001', '01', '2083', '53', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30318, to_date('02-01-2083', 'dd-mm-yyyy'), '6', '02', '002', '01', '2083', '53', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30319, to_date('03-01-2083', 'dd-mm-yyyy'), '7', '03', '003', '01', '2083', '53', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30320, to_date('04-01-2083', 'dd-mm-yyyy'), '1', '04', '004', '01', '2083', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30321, to_date('05-01-2083', 'dd-mm-yyyy'), '2', '05', '005', '01', '2083', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30322, to_date('06-01-2083', 'dd-mm-yyyy'), '3', '06', '006', '01', '2083', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30323, to_date('07-01-2083', 'dd-mm-yyyy'), '4', '07', '007', '01', '2083', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30324, to_date('08-01-2083', 'dd-mm-yyyy'), '5', '08', '008', '01', '2083', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30325, to_date('09-01-2083', 'dd-mm-yyyy'), '6', '09', '009', '01', '2083', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30326, to_date('10-01-2083', 'dd-mm-yyyy'), '7', '10', '010', '01', '2083', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30327, to_date('11-01-2083', 'dd-mm-yyyy'), '1', '11', '011', '01', '2083', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30328, to_date('12-01-2083', 'dd-mm-yyyy'), '2', '12', '012', '01', '2083', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30329, to_date('13-01-2083', 'dd-mm-yyyy'), '3', '13', '013', '01', '2083', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30330, to_date('14-01-2083', 'dd-mm-yyyy'), '4', '14', '014', '01', '2083', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30331, to_date('15-01-2083', 'dd-mm-yyyy'), '5', '15', '015', '01', '2083', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30332, to_date('16-01-2083', 'dd-mm-yyyy'), '6', '16', '016', '01', '2083', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30333, to_date('17-01-2083', 'dd-mm-yyyy'), '7', '17', '017', '01', '2083', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30334, to_date('18-01-2083', 'dd-mm-yyyy'), '1', '18', '018', '01', '2083', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30335, to_date('19-01-2083', 'dd-mm-yyyy'), '2', '19', '019', '01', '2083', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30336, to_date('20-01-2083', 'dd-mm-yyyy'), '3', '20', '020', '01', '2083', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30337, to_date('21-01-2083', 'dd-mm-yyyy'), '4', '21', '021', '01', '2083', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30338, to_date('22-01-2083', 'dd-mm-yyyy'), '5', '22', '022', '01', '2083', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30339, to_date('23-01-2083', 'dd-mm-yyyy'), '6', '23', '023', '01', '2083', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30340, to_date('24-01-2083', 'dd-mm-yyyy'), '7', '24', '024', '01', '2083', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30341, to_date('25-01-2083', 'dd-mm-yyyy'), '1', '25', '025', '01', '2083', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30342, to_date('26-01-2083', 'dd-mm-yyyy'), '2', '26', '026', '01', '2083', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30343, to_date('27-01-2083', 'dd-mm-yyyy'), '3', '27', '027', '01', '2083', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30344, to_date('28-01-2083', 'dd-mm-yyyy'), '4', '28', '028', '01', '2083', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30345, to_date('29-01-2083', 'dd-mm-yyyy'), '5', '29', '029', '01', '2083', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30346, to_date('30-01-2083', 'dd-mm-yyyy'), '6', '30', '030', '01', '2083', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30347, to_date('31-01-2083', 'dd-mm-yyyy'), '7', '31', '031', '01', '2083', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30348, to_date('01-02-2083', 'dd-mm-yyyy'), '1', '01', '032', '02', '2083', '05', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30349, to_date('02-02-2083', 'dd-mm-yyyy'), '2', '02', '033', '02', '2083', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30350, to_date('03-02-2083', 'dd-mm-yyyy'), '3', '03', '034', '02', '2083', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30351, to_date('04-02-2083', 'dd-mm-yyyy'), '4', '04', '035', '02', '2083', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30352, to_date('05-02-2083', 'dd-mm-yyyy'), '5', '05', '036', '02', '2083', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30353, to_date('06-02-2083', 'dd-mm-yyyy'), '6', '06', '037', '02', '2083', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30354, to_date('07-02-2083', 'dd-mm-yyyy'), '7', '07', '038', '02', '2083', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30355, to_date('08-02-2083', 'dd-mm-yyyy'), '1', '08', '039', '02', '2083', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30356, to_date('09-02-2083', 'dd-mm-yyyy'), '2', '09', '040', '02', '2083', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30357, to_date('10-02-2083', 'dd-mm-yyyy'), '3', '10', '041', '02', '2083', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30358, to_date('11-02-2083', 'dd-mm-yyyy'), '4', '11', '042', '02', '2083', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30359, to_date('12-02-2083', 'dd-mm-yyyy'), '5', '12', '043', '02', '2083', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30360, to_date('13-02-2083', 'dd-mm-yyyy'), '6', '13', '044', '02', '2083', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30361, to_date('14-02-2083', 'dd-mm-yyyy'), '7', '14', '045', '02', '2083', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30362, to_date('15-02-2083', 'dd-mm-yyyy'), '1', '15', '046', '02', '2083', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30363, to_date('16-02-2083', 'dd-mm-yyyy'), '2', '16', '047', '02', '2083', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30364, to_date('17-02-2083', 'dd-mm-yyyy'), '3', '17', '048', '02', '2083', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30365, to_date('18-02-2083', 'dd-mm-yyyy'), '4', '18', '049', '02', '2083', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30366, to_date('19-02-2083', 'dd-mm-yyyy'), '5', '19', '050', '02', '2083', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30367, to_date('20-02-2083', 'dd-mm-yyyy'), '6', '20', '051', '02', '2083', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30368, to_date('21-02-2083', 'dd-mm-yyyy'), '7', '21', '052', '02', '2083', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30369, to_date('22-02-2083', 'dd-mm-yyyy'), '1', '22', '053', '02', '2083', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30370, to_date('23-02-2083', 'dd-mm-yyyy'), '2', '23', '054', '02', '2083', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30371, to_date('24-02-2083', 'dd-mm-yyyy'), '3', '24', '055', '02', '2083', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30372, to_date('25-02-2083', 'dd-mm-yyyy'), '4', '25', '056', '02', '2083', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30373, to_date('26-02-2083', 'dd-mm-yyyy'), '5', '26', '057', '02', '2083', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30374, to_date('27-02-2083', 'dd-mm-yyyy'), '6', '27', '058', '02', '2083', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30375, to_date('28-02-2083', 'dd-mm-yyyy'), '7', '28', '059', '02', '2083', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30376, to_date('01-03-2083', 'dd-mm-yyyy'), '1', '01', '060', '03', '2083', '09', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30377, to_date('02-03-2083', 'dd-mm-yyyy'), '2', '02', '061', '03', '2083', '09', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30378, to_date('03-03-2083', 'dd-mm-yyyy'), '3', '03', '062', '03', '2083', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30379, to_date('04-03-2083', 'dd-mm-yyyy'), '4', '04', '063', '03', '2083', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30380, to_date('05-03-2083', 'dd-mm-yyyy'), '5', '05', '064', '03', '2083', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30381, to_date('06-03-2083', 'dd-mm-yyyy'), '6', '06', '065', '03', '2083', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30382, to_date('07-03-2083', 'dd-mm-yyyy'), '7', '07', '066', '03', '2083', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30383, to_date('08-03-2083', 'dd-mm-yyyy'), '1', '08', '067', '03', '2083', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30384, to_date('09-03-2083', 'dd-mm-yyyy'), '2', '09', '068', '03', '2083', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30385, to_date('10-03-2083', 'dd-mm-yyyy'), '3', '10', '069', '03', '2083', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30386, to_date('11-03-2083', 'dd-mm-yyyy'), '4', '11', '070', '03', '2083', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30387, to_date('12-03-2083', 'dd-mm-yyyy'), '5', '12', '071', '03', '2083', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30388, to_date('13-03-2083', 'dd-mm-yyyy'), '6', '13', '072', '03', '2083', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30389, to_date('14-03-2083', 'dd-mm-yyyy'), '7', '14', '073', '03', '2083', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30390, to_date('15-03-2083', 'dd-mm-yyyy'), '1', '15', '074', '03', '2083', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30391, to_date('16-03-2083', 'dd-mm-yyyy'), '2', '16', '075', '03', '2083', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30392, to_date('17-03-2083', 'dd-mm-yyyy'), '3', '17', '076', '03', '2083', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30393, to_date('18-03-2083', 'dd-mm-yyyy'), '4', '18', '077', '03', '2083', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30394, to_date('19-03-2083', 'dd-mm-yyyy'), '5', '19', '078', '03', '2083', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30395, to_date('20-03-2083', 'dd-mm-yyyy'), '6', '20', '079', '03', '2083', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30396, to_date('21-03-2083', 'dd-mm-yyyy'), '7', '21', '080', '03', '2083', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31881, to_date('14-04-2087', 'dd-mm-yyyy'), '1', '14', '104', '04', '2087', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31882, to_date('15-04-2087', 'dd-mm-yyyy'), '2', '15', '105', '04', '2087', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31883, to_date('16-04-2087', 'dd-mm-yyyy'), '3', '16', '106', '04', '2087', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31884, to_date('17-04-2087', 'dd-mm-yyyy'), '4', '17', '107', '04', '2087', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31885, to_date('18-04-2087', 'dd-mm-yyyy'), '5', '18', '108', '04', '2087', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31886, to_date('19-04-2087', 'dd-mm-yyyy'), '6', '19', '109', '04', '2087', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31887, to_date('20-04-2087', 'dd-mm-yyyy'), '7', '20', '110', '04', '2087', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31888, to_date('21-04-2087', 'dd-mm-yyyy'), '1', '21', '111', '04', '2087', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31889, to_date('22-04-2087', 'dd-mm-yyyy'), '2', '22', '112', '04', '2087', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31890, to_date('23-04-2087', 'dd-mm-yyyy'), '3', '23', '113', '04', '2087', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31891, to_date('24-04-2087', 'dd-mm-yyyy'), '4', '24', '114', '04', '2087', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31892, to_date('25-04-2087', 'dd-mm-yyyy'), '5', '25', '115', '04', '2087', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31893, to_date('26-04-2087', 'dd-mm-yyyy'), '6', '26', '116', '04', '2087', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31894, to_date('27-04-2087', 'dd-mm-yyyy'), '7', '27', '117', '04', '2087', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31895, to_date('28-04-2087', 'dd-mm-yyyy'), '1', '28', '118', '04', '2087', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31896, to_date('29-04-2087', 'dd-mm-yyyy'), '2', '29', '119', '04', '2087', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31897, to_date('30-04-2087', 'dd-mm-yyyy'), '3', '30', '120', '04', '2087', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31898, to_date('01-05-2087', 'dd-mm-yyyy'), '4', '01', '121', '05', '2087', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31899, to_date('02-05-2087', 'dd-mm-yyyy'), '5', '02', '122', '05', '2087', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31900, to_date('03-05-2087', 'dd-mm-yyyy'), '6', '03', '123', '05', '2087', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31901, to_date('04-05-2087', 'dd-mm-yyyy'), '7', '04', '124', '05', '2087', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31902, to_date('05-05-2087', 'dd-mm-yyyy'), '1', '05', '125', '05', '2087', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31903, to_date('06-05-2087', 'dd-mm-yyyy'), '2', '06', '126', '05', '2087', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31904, to_date('07-05-2087', 'dd-mm-yyyy'), '3', '07', '127', '05', '2087', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31905, to_date('08-05-2087', 'dd-mm-yyyy'), '4', '08', '128', '05', '2087', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31906, to_date('09-05-2087', 'dd-mm-yyyy'), '5', '09', '129', '05', '2087', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31907, to_date('10-05-2087', 'dd-mm-yyyy'), '6', '10', '130', '05', '2087', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31908, to_date('11-05-2087', 'dd-mm-yyyy'), '7', '11', '131', '05', '2087', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31909, to_date('12-05-2087', 'dd-mm-yyyy'), '1', '12', '132', '05', '2087', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31910, to_date('13-05-2087', 'dd-mm-yyyy'), '2', '13', '133', '05', '2087', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31911, to_date('14-05-2087', 'dd-mm-yyyy'), '3', '14', '134', '05', '2087', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31912, to_date('15-05-2087', 'dd-mm-yyyy'), '4', '15', '135', '05', '2087', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31913, to_date('16-05-2087', 'dd-mm-yyyy'), '5', '16', '136', '05', '2087', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31914, to_date('17-05-2087', 'dd-mm-yyyy'), '6', '17', '137', '05', '2087', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31915, to_date('18-05-2087', 'dd-mm-yyyy'), '7', '18', '138', '05', '2087', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31916, to_date('19-05-2087', 'dd-mm-yyyy'), '1', '19', '139', '05', '2087', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31917, to_date('20-05-2087', 'dd-mm-yyyy'), '2', '20', '140', '05', '2087', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31918, to_date('21-05-2087', 'dd-mm-yyyy'), '3', '21', '141', '05', '2087', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31919, to_date('22-05-2087', 'dd-mm-yyyy'), '4', '22', '142', '05', '2087', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31920, to_date('23-05-2087', 'dd-mm-yyyy'), '5', '23', '143', '05', '2087', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31921, to_date('24-05-2087', 'dd-mm-yyyy'), '6', '24', '144', '05', '2087', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31922, to_date('25-05-2087', 'dd-mm-yyyy'), '7', '25', '145', '05', '2087', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31923, to_date('26-05-2087', 'dd-mm-yyyy'), '1', '26', '146', '05', '2087', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31924, to_date('27-05-2087', 'dd-mm-yyyy'), '2', '27', '147', '05', '2087', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31925, to_date('28-05-2087', 'dd-mm-yyyy'), '3', '28', '148', '05', '2087', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31926, to_date('29-05-2087', 'dd-mm-yyyy'), '4', '29', '149', '05', '2087', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31927, to_date('30-05-2087', 'dd-mm-yyyy'), '5', '30', '150', '05', '2087', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31928, to_date('31-05-2087', 'dd-mm-yyyy'), '6', '31', '151', '05', '2087', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31929, to_date('01-06-2087', 'dd-mm-yyyy'), '7', '01', '152', '06', '2087', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31930, to_date('02-06-2087', 'dd-mm-yyyy'), '1', '02', '153', '06', '2087', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31931, to_date('03-06-2087', 'dd-mm-yyyy'), '2', '03', '154', '06', '2087', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31932, to_date('04-06-2087', 'dd-mm-yyyy'), '3', '04', '155', '06', '2087', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31933, to_date('05-06-2087', 'dd-mm-yyyy'), '4', '05', '156', '06', '2087', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31934, to_date('06-06-2087', 'dd-mm-yyyy'), '5', '06', '157', '06', '2087', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31935, to_date('07-06-2087', 'dd-mm-yyyy'), '6', '07', '158', '06', '2087', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31936, to_date('08-06-2087', 'dd-mm-yyyy'), '7', '08', '159', '06', '2087', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31937, to_date('09-06-2087', 'dd-mm-yyyy'), '1', '09', '160', '06', '2087', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31938, to_date('10-06-2087', 'dd-mm-yyyy'), '2', '10', '161', '06', '2087', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31939, to_date('11-06-2087', 'dd-mm-yyyy'), '3', '11', '162', '06', '2087', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31940, to_date('12-06-2087', 'dd-mm-yyyy'), '4', '12', '163', '06', '2087', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31941, to_date('13-06-2087', 'dd-mm-yyyy'), '5', '13', '164', '06', '2087', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31942, to_date('14-06-2087', 'dd-mm-yyyy'), '6', '14', '165', '06', '2087', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31943, to_date('15-06-2087', 'dd-mm-yyyy'), '7', '15', '166', '06', '2087', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31944, to_date('16-06-2087', 'dd-mm-yyyy'), '1', '16', '167', '06', '2087', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31945, to_date('17-06-2087', 'dd-mm-yyyy'), '2', '17', '168', '06', '2087', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31946, to_date('18-06-2087', 'dd-mm-yyyy'), '3', '18', '169', '06', '2087', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31947, to_date('19-06-2087', 'dd-mm-yyyy'), '4', '19', '170', '06', '2087', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31948, to_date('20-06-2087', 'dd-mm-yyyy'), '5', '20', '171', '06', '2087', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31949, to_date('21-06-2087', 'dd-mm-yyyy'), '6', '21', '172', '06', '2087', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31950, to_date('22-06-2087', 'dd-mm-yyyy'), '7', '22', '173', '06', '2087', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31951, to_date('23-06-2087', 'dd-mm-yyyy'), '1', '23', '174', '06', '2087', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31952, to_date('24-06-2087', 'dd-mm-yyyy'), '2', '24', '175', '06', '2087', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31953, to_date('25-06-2087', 'dd-mm-yyyy'), '3', '25', '176', '06', '2087', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31954, to_date('26-06-2087', 'dd-mm-yyyy'), '4', '26', '177', '06', '2087', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31955, to_date('27-06-2087', 'dd-mm-yyyy'), '5', '27', '178', '06', '2087', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31956, to_date('28-06-2087', 'dd-mm-yyyy'), '6', '28', '179', '06', '2087', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31957, to_date('29-06-2087', 'dd-mm-yyyy'), '7', '29', '180', '06', '2087', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31958, to_date('30-06-2087', 'dd-mm-yyyy'), '1', '30', '181', '06', '2087', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31959, to_date('01-07-2087', 'dd-mm-yyyy'), '2', '01', '182', '07', '2087', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31960, to_date('02-07-2087', 'dd-mm-yyyy'), '3', '02', '183', '07', '2087', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31961, to_date('03-07-2087', 'dd-mm-yyyy'), '4', '03', '184', '07', '2087', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31962, to_date('04-07-2087', 'dd-mm-yyyy'), '5', '04', '185', '07', '2087', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31963, to_date('05-07-2087', 'dd-mm-yyyy'), '6', '05', '186', '07', '2087', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31964, to_date('06-07-2087', 'dd-mm-yyyy'), '7', '06', '187', '07', '2087', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31965, to_date('07-07-2087', 'dd-mm-yyyy'), '1', '07', '188', '07', '2087', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31966, to_date('08-07-2087', 'dd-mm-yyyy'), '2', '08', '189', '07', '2087', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31967, to_date('09-07-2087', 'dd-mm-yyyy'), '3', '09', '190', '07', '2087', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31968, to_date('10-07-2087', 'dd-mm-yyyy'), '4', '10', '191', '07', '2087', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31969, to_date('11-07-2087', 'dd-mm-yyyy'), '5', '11', '192', '07', '2087', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31970, to_date('12-07-2087', 'dd-mm-yyyy'), '6', '12', '193', '07', '2087', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31971, to_date('13-07-2087', 'dd-mm-yyyy'), '7', '13', '194', '07', '2087', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31972, to_date('14-07-2087', 'dd-mm-yyyy'), '1', '14', '195', '07', '2087', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31973, to_date('15-07-2087', 'dd-mm-yyyy'), '2', '15', '196', '07', '2087', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31974, to_date('16-07-2087', 'dd-mm-yyyy'), '3', '16', '197', '07', '2087', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31975, to_date('17-07-2087', 'dd-mm-yyyy'), '4', '17', '198', '07', '2087', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31976, to_date('18-07-2087', 'dd-mm-yyyy'), '5', '18', '199', '07', '2087', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31977, to_date('19-07-2087', 'dd-mm-yyyy'), '6', '19', '200', '07', '2087', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31978, to_date('20-07-2087', 'dd-mm-yyyy'), '7', '20', '201', '07', '2087', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31979, to_date('21-07-2087', 'dd-mm-yyyy'), '1', '21', '202', '07', '2087', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31980, to_date('22-07-2087', 'dd-mm-yyyy'), '2', '22', '203', '07', '2087', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31981, to_date('23-07-2087', 'dd-mm-yyyy'), '3', '23', '204', '07', '2087', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31982, to_date('24-07-2087', 'dd-mm-yyyy'), '4', '24', '205', '07', '2087', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31983, to_date('25-07-2087', 'dd-mm-yyyy'), '5', '25', '206', '07', '2087', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31984, to_date('26-07-2087', 'dd-mm-yyyy'), '6', '26', '207', '07', '2087', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31985, to_date('27-07-2087', 'dd-mm-yyyy'), '7', '27', '208', '07', '2087', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31986, to_date('28-07-2087', 'dd-mm-yyyy'), '1', '28', '209', '07', '2087', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27111, to_date('23-03-2074', 'dd-mm-yyyy'), '5', '23', '082', '03', '2074', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27112, to_date('24-03-2074', 'dd-mm-yyyy'), '6', '24', '083', '03', '2074', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27113, to_date('25-03-2074', 'dd-mm-yyyy'), '7', '25', '084', '03', '2074', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27114, to_date('26-03-2074', 'dd-mm-yyyy'), '1', '26', '085', '03', '2074', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27115, to_date('27-03-2074', 'dd-mm-yyyy'), '2', '27', '086', '03', '2074', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27116, to_date('28-03-2074', 'dd-mm-yyyy'), '3', '28', '087', '03', '2074', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27117, to_date('29-03-2074', 'dd-mm-yyyy'), '4', '29', '088', '03', '2074', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27118, to_date('30-03-2074', 'dd-mm-yyyy'), '5', '30', '089', '03', '2074', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27119, to_date('31-03-2074', 'dd-mm-yyyy'), '6', '31', '090', '03', '2074', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27120, to_date('01-04-2074', 'dd-mm-yyyy'), '7', '01', '091', '04', '2074', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27121, to_date('02-04-2074', 'dd-mm-yyyy'), '1', '02', '092', '04', '2074', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27122, to_date('03-04-2074', 'dd-mm-yyyy'), '2', '03', '093', '04', '2074', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27123, to_date('04-04-2074', 'dd-mm-yyyy'), '3', '04', '094', '04', '2074', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27124, to_date('05-04-2074', 'dd-mm-yyyy'), '4', '05', '095', '04', '2074', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27125, to_date('06-04-2074', 'dd-mm-yyyy'), '5', '06', '096', '04', '2074', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27126, to_date('07-04-2074', 'dd-mm-yyyy'), '6', '07', '097', '04', '2074', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27127, to_date('08-04-2074', 'dd-mm-yyyy'), '7', '08', '098', '04', '2074', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27128, to_date('09-04-2074', 'dd-mm-yyyy'), '1', '09', '099', '04', '2074', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27129, to_date('10-04-2074', 'dd-mm-yyyy'), '2', '10', '100', '04', '2074', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27130, to_date('11-04-2074', 'dd-mm-yyyy'), '3', '11', '101', '04', '2074', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27131, to_date('12-04-2074', 'dd-mm-yyyy'), '4', '12', '102', '04', '2074', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27132, to_date('13-04-2074', 'dd-mm-yyyy'), '5', '13', '103', '04', '2074', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27133, to_date('14-04-2074', 'dd-mm-yyyy'), '6', '14', '104', '04', '2074', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27134, to_date('15-04-2074', 'dd-mm-yyyy'), '7', '15', '105', '04', '2074', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27135, to_date('16-04-2074', 'dd-mm-yyyy'), '1', '16', '106', '04', '2074', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27136, to_date('17-04-2074', 'dd-mm-yyyy'), '2', '17', '107', '04', '2074', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27137, to_date('18-04-2074', 'dd-mm-yyyy'), '3', '18', '108', '04', '2074', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27138, to_date('19-04-2074', 'dd-mm-yyyy'), '4', '19', '109', '04', '2074', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27139, to_date('20-04-2074', 'dd-mm-yyyy'), '5', '20', '110', '04', '2074', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27140, to_date('21-04-2074', 'dd-mm-yyyy'), '6', '21', '111', '04', '2074', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27141, to_date('22-04-2074', 'dd-mm-yyyy'), '7', '22', '112', '04', '2074', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27142, to_date('23-04-2074', 'dd-mm-yyyy'), '1', '23', '113', '04', '2074', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27143, to_date('24-04-2074', 'dd-mm-yyyy'), '2', '24', '114', '04', '2074', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27144, to_date('25-04-2074', 'dd-mm-yyyy'), '3', '25', '115', '04', '2074', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27145, to_date('26-04-2074', 'dd-mm-yyyy'), '4', '26', '116', '04', '2074', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27146, to_date('27-04-2074', 'dd-mm-yyyy'), '5', '27', '117', '04', '2074', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27147, to_date('28-04-2074', 'dd-mm-yyyy'), '6', '28', '118', '04', '2074', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27148, to_date('29-04-2074', 'dd-mm-yyyy'), '7', '29', '119', '04', '2074', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27149, to_date('30-04-2074', 'dd-mm-yyyy'), '1', '30', '120', '04', '2074', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27150, to_date('01-05-2074', 'dd-mm-yyyy'), '2', '01', '121', '05', '2074', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27151, to_date('02-05-2074', 'dd-mm-yyyy'), '3', '02', '122', '05', '2074', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27152, to_date('03-05-2074', 'dd-mm-yyyy'), '4', '03', '123', '05', '2074', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27153, to_date('04-05-2074', 'dd-mm-yyyy'), '5', '04', '124', '05', '2074', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27154, to_date('05-05-2074', 'dd-mm-yyyy'), '6', '05', '125', '05', '2074', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27155, to_date('06-05-2074', 'dd-mm-yyyy'), '7', '06', '126', '05', '2074', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27156, to_date('07-05-2074', 'dd-mm-yyyy'), '1', '07', '127', '05', '2074', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27157, to_date('08-05-2074', 'dd-mm-yyyy'), '2', '08', '128', '05', '2074', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27158, to_date('09-05-2074', 'dd-mm-yyyy'), '3', '09', '129', '05', '2074', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27159, to_date('10-05-2074', 'dd-mm-yyyy'), '4', '10', '130', '05', '2074', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27160, to_date('11-05-2074', 'dd-mm-yyyy'), '5', '11', '131', '05', '2074', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27161, to_date('12-05-2074', 'dd-mm-yyyy'), '6', '12', '132', '05', '2074', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27162, to_date('13-05-2074', 'dd-mm-yyyy'), '7', '13', '133', '05', '2074', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27163, to_date('14-05-2074', 'dd-mm-yyyy'), '1', '14', '134', '05', '2074', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27164, to_date('15-05-2074', 'dd-mm-yyyy'), '2', '15', '135', '05', '2074', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27165, to_date('16-05-2074', 'dd-mm-yyyy'), '3', '16', '136', '05', '2074', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27166, to_date('17-05-2074', 'dd-mm-yyyy'), '4', '17', '137', '05', '2074', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27167, to_date('18-05-2074', 'dd-mm-yyyy'), '5', '18', '138', '05', '2074', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27168, to_date('19-05-2074', 'dd-mm-yyyy'), '6', '19', '139', '05', '2074', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27169, to_date('20-05-2074', 'dd-mm-yyyy'), '7', '20', '140', '05', '2074', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27170, to_date('21-05-2074', 'dd-mm-yyyy'), '1', '21', '141', '05', '2074', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27171, to_date('22-05-2074', 'dd-mm-yyyy'), '2', '22', '142', '05', '2074', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27172, to_date('23-05-2074', 'dd-mm-yyyy'), '3', '23', '143', '05', '2074', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27173, to_date('24-05-2074', 'dd-mm-yyyy'), '4', '24', '144', '05', '2074', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27174, to_date('25-05-2074', 'dd-mm-yyyy'), '5', '25', '145', '05', '2074', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27175, to_date('26-05-2074', 'dd-mm-yyyy'), '6', '26', '146', '05', '2074', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27176, to_date('27-05-2074', 'dd-mm-yyyy'), '7', '27', '147', '05', '2074', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27177, to_date('28-05-2074', 'dd-mm-yyyy'), '1', '28', '148', '05', '2074', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27178, to_date('29-05-2074', 'dd-mm-yyyy'), '2', '29', '149', '05', '2074', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27179, to_date('30-05-2074', 'dd-mm-yyyy'), '3', '30', '150', '05', '2074', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27180, to_date('31-05-2074', 'dd-mm-yyyy'), '4', '31', '151', '05', '2074', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27181, to_date('01-06-2074', 'dd-mm-yyyy'), '5', '01', '152', '06', '2074', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27182, to_date('02-06-2074', 'dd-mm-yyyy'), '6', '02', '153', '06', '2074', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27183, to_date('03-06-2074', 'dd-mm-yyyy'), '7', '03', '154', '06', '2074', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27184, to_date('04-06-2074', 'dd-mm-yyyy'), '1', '04', '155', '06', '2074', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27185, to_date('05-06-2074', 'dd-mm-yyyy'), '2', '05', '156', '06', '2074', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27186, to_date('06-06-2074', 'dd-mm-yyyy'), '3', '06', '157', '06', '2074', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27187, to_date('07-06-2074', 'dd-mm-yyyy'), '4', '07', '158', '06', '2074', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27188, to_date('08-06-2074', 'dd-mm-yyyy'), '5', '08', '159', '06', '2074', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27189, to_date('09-06-2074', 'dd-mm-yyyy'), '6', '09', '160', '06', '2074', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27190, to_date('10-06-2074', 'dd-mm-yyyy'), '7', '10', '161', '06', '2074', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27191, to_date('11-06-2074', 'dd-mm-yyyy'), '1', '11', '162', '06', '2074', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27192, to_date('12-06-2074', 'dd-mm-yyyy'), '2', '12', '163', '06', '2074', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27193, to_date('13-06-2074', 'dd-mm-yyyy'), '3', '13', '164', '06', '2074', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27194, to_date('14-06-2074', 'dd-mm-yyyy'), '4', '14', '165', '06', '2074', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27195, to_date('15-06-2074', 'dd-mm-yyyy'), '5', '15', '166', '06', '2074', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27196, to_date('16-06-2074', 'dd-mm-yyyy'), '6', '16', '167', '06', '2074', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27197, to_date('17-06-2074', 'dd-mm-yyyy'), '7', '17', '168', '06', '2074', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27198, to_date('18-06-2074', 'dd-mm-yyyy'), '1', '18', '169', '06', '2074', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27199, to_date('19-06-2074', 'dd-mm-yyyy'), '2', '19', '170', '06', '2074', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27200, to_date('20-06-2074', 'dd-mm-yyyy'), '3', '20', '171', '06', '2074', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27201, to_date('21-06-2074', 'dd-mm-yyyy'), '4', '21', '172', '06', '2074', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27202, to_date('22-06-2074', 'dd-mm-yyyy'), '5', '22', '173', '06', '2074', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27203, to_date('23-06-2074', 'dd-mm-yyyy'), '6', '23', '174', '06', '2074', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27204, to_date('24-06-2074', 'dd-mm-yyyy'), '7', '24', '175', '06', '2074', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27205, to_date('25-06-2074', 'dd-mm-yyyy'), '1', '25', '176', '06', '2074', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27206, to_date('26-06-2074', 'dd-mm-yyyy'), '2', '26', '177', '06', '2074', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27207, to_date('27-06-2074', 'dd-mm-yyyy'), '3', '27', '178', '06', '2074', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27208, to_date('28-06-2074', 'dd-mm-yyyy'), '4', '28', '179', '06', '2074', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27209, to_date('29-06-2074', 'dd-mm-yyyy'), '5', '29', '180', '06', '2074', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27210, to_date('30-06-2074', 'dd-mm-yyyy'), '6', '30', '181', '06', '2074', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27211, to_date('01-07-2074', 'dd-mm-yyyy'), '7', '01', '182', '07', '2074', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27212, to_date('02-07-2074', 'dd-mm-yyyy'), '1', '02', '183', '07', '2074', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27213, to_date('03-07-2074', 'dd-mm-yyyy'), '2', '03', '184', '07', '2074', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27214, to_date('04-07-2074', 'dd-mm-yyyy'), '3', '04', '185', '07', '2074', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27215, to_date('05-07-2074', 'dd-mm-yyyy'), '4', '05', '186', '07', '2074', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27216, to_date('06-07-2074', 'dd-mm-yyyy'), '5', '06', '187', '07', '2074', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28807, to_date('13-11-2078', 'dd-mm-yyyy'), '7', '13', '317', '11', '2078', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28808, to_date('14-11-2078', 'dd-mm-yyyy'), '1', '14', '318', '11', '2078', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28809, to_date('15-11-2078', 'dd-mm-yyyy'), '2', '15', '319', '11', '2078', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28810, to_date('16-11-2078', 'dd-mm-yyyy'), '3', '16', '320', '11', '2078', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28811, to_date('17-11-2078', 'dd-mm-yyyy'), '4', '17', '321', '11', '2078', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28812, to_date('18-11-2078', 'dd-mm-yyyy'), '5', '18', '322', '11', '2078', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28813, to_date('19-11-2078', 'dd-mm-yyyy'), '6', '19', '323', '11', '2078', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28814, to_date('20-11-2078', 'dd-mm-yyyy'), '7', '20', '324', '11', '2078', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28815, to_date('21-11-2078', 'dd-mm-yyyy'), '1', '21', '325', '11', '2078', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28816, to_date('22-11-2078', 'dd-mm-yyyy'), '2', '22', '326', '11', '2078', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28817, to_date('23-11-2078', 'dd-mm-yyyy'), '3', '23', '327', '11', '2078', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28818, to_date('24-11-2078', 'dd-mm-yyyy'), '4', '24', '328', '11', '2078', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28819, to_date('25-11-2078', 'dd-mm-yyyy'), '5', '25', '329', '11', '2078', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28820, to_date('26-11-2078', 'dd-mm-yyyy'), '6', '26', '330', '11', '2078', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28821, to_date('27-11-2078', 'dd-mm-yyyy'), '7', '27', '331', '11', '2078', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28822, to_date('28-11-2078', 'dd-mm-yyyy'), '1', '28', '332', '11', '2078', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28823, to_date('29-11-2078', 'dd-mm-yyyy'), '2', '29', '333', '11', '2078', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28824, to_date('30-11-2078', 'dd-mm-yyyy'), '3', '30', '334', '11', '2078', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28825, to_date('01-12-2078', 'dd-mm-yyyy'), '4', '01', '335', '12', '2078', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28826, to_date('02-12-2078', 'dd-mm-yyyy'), '5', '02', '336', '12', '2078', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28827, to_date('03-12-2078', 'dd-mm-yyyy'), '6', '03', '337', '12', '2078', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28828, to_date('04-12-2078', 'dd-mm-yyyy'), '7', '04', '338', '12', '2078', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28829, to_date('05-12-2078', 'dd-mm-yyyy'), '1', '05', '339', '12', '2078', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28830, to_date('06-12-2078', 'dd-mm-yyyy'), '2', '06', '340', '12', '2078', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28831, to_date('07-12-2078', 'dd-mm-yyyy'), '3', '07', '341', '12', '2078', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28832, to_date('08-12-2078', 'dd-mm-yyyy'), '4', '08', '342', '12', '2078', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28833, to_date('09-12-2078', 'dd-mm-yyyy'), '5', '09', '343', '12', '2078', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28834, to_date('10-12-2078', 'dd-mm-yyyy'), '6', '10', '344', '12', '2078', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28835, to_date('11-12-2078', 'dd-mm-yyyy'), '7', '11', '345', '12', '2078', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28836, to_date('12-12-2078', 'dd-mm-yyyy'), '1', '12', '346', '12', '2078', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28837, to_date('13-12-2078', 'dd-mm-yyyy'), '2', '13', '347', '12', '2078', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28838, to_date('14-12-2078', 'dd-mm-yyyy'), '3', '14', '348', '12', '2078', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28839, to_date('15-12-2078', 'dd-mm-yyyy'), '4', '15', '349', '12', '2078', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28840, to_date('16-12-2078', 'dd-mm-yyyy'), '5', '16', '350', '12', '2078', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28841, to_date('17-12-2078', 'dd-mm-yyyy'), '6', '17', '351', '12', '2078', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28842, to_date('18-12-2078', 'dd-mm-yyyy'), '7', '18', '352', '12', '2078', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28843, to_date('19-12-2078', 'dd-mm-yyyy'), '1', '19', '353', '12', '2078', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28844, to_date('20-12-2078', 'dd-mm-yyyy'), '2', '20', '354', '12', '2078', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28845, to_date('21-12-2078', 'dd-mm-yyyy'), '3', '21', '355', '12', '2078', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28846, to_date('22-12-2078', 'dd-mm-yyyy'), '4', '22', '356', '12', '2078', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28847, to_date('23-12-2078', 'dd-mm-yyyy'), '5', '23', '357', '12', '2078', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28848, to_date('24-12-2078', 'dd-mm-yyyy'), '6', '24', '358', '12', '2078', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28849, to_date('25-12-2078', 'dd-mm-yyyy'), '7', '25', '359', '12', '2078', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28850, to_date('26-12-2078', 'dd-mm-yyyy'), '1', '26', '360', '12', '2078', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28851, to_date('27-12-2078', 'dd-mm-yyyy'), '2', '27', '361', '12', '2078', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28852, to_date('28-12-2078', 'dd-mm-yyyy'), '3', '28', '362', '12', '2078', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28853, to_date('29-12-2078', 'dd-mm-yyyy'), '4', '29', '363', '12', '2078', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28854, to_date('30-12-2078', 'dd-mm-yyyy'), '5', '30', '364', '12', '2078', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28855, to_date('31-12-2078', 'dd-mm-yyyy'), '6', '31', '365', '12', '2078', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28856, to_date('01-01-2079', 'dd-mm-yyyy'), '7', '01', '001', '01', '2079', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28857, to_date('02-01-2079', 'dd-mm-yyyy'), '1', '02', '002', '01', '2079', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28858, to_date('03-01-2079', 'dd-mm-yyyy'), '2', '03', '003', '01', '2079', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28859, to_date('04-01-2079', 'dd-mm-yyyy'), '3', '04', '004', '01', '2079', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28860, to_date('05-01-2079', 'dd-mm-yyyy'), '4', '05', '005', '01', '2079', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28861, to_date('06-01-2079', 'dd-mm-yyyy'), '5', '06', '006', '01', '2079', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28862, to_date('07-01-2079', 'dd-mm-yyyy'), '6', '07', '007', '01', '2079', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28863, to_date('08-01-2079', 'dd-mm-yyyy'), '7', '08', '008', '01', '2079', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28864, to_date('09-01-2079', 'dd-mm-yyyy'), '1', '09', '009', '01', '2079', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28865, to_date('10-01-2079', 'dd-mm-yyyy'), '2', '10', '010', '01', '2079', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28866, to_date('11-01-2079', 'dd-mm-yyyy'), '3', '11', '011', '01', '2079', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28867, to_date('12-01-2079', 'dd-mm-yyyy'), '4', '12', '012', '01', '2079', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28868, to_date('13-01-2079', 'dd-mm-yyyy'), '5', '13', '013', '01', '2079', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28869, to_date('14-01-2079', 'dd-mm-yyyy'), '6', '14', '014', '01', '2079', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28870, to_date('15-01-2079', 'dd-mm-yyyy'), '7', '15', '015', '01', '2079', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28871, to_date('16-01-2079', 'dd-mm-yyyy'), '1', '16', '016', '01', '2079', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28872, to_date('17-01-2079', 'dd-mm-yyyy'), '2', '17', '017', '01', '2079', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28873, to_date('18-01-2079', 'dd-mm-yyyy'), '3', '18', '018', '01', '2079', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28874, to_date('19-01-2079', 'dd-mm-yyyy'), '4', '19', '019', '01', '2079', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28875, to_date('20-01-2079', 'dd-mm-yyyy'), '5', '20', '020', '01', '2079', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28876, to_date('21-01-2079', 'dd-mm-yyyy'), '6', '21', '021', '01', '2079', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28877, to_date('22-01-2079', 'dd-mm-yyyy'), '7', '22', '022', '01', '2079', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28878, to_date('23-01-2079', 'dd-mm-yyyy'), '1', '23', '023', '01', '2079', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28879, to_date('24-01-2079', 'dd-mm-yyyy'), '2', '24', '024', '01', '2079', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28880, to_date('25-01-2079', 'dd-mm-yyyy'), '3', '25', '025', '01', '2079', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28881, to_date('26-01-2079', 'dd-mm-yyyy'), '4', '26', '026', '01', '2079', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28882, to_date('27-01-2079', 'dd-mm-yyyy'), '5', '27', '027', '01', '2079', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28883, to_date('28-01-2079', 'dd-mm-yyyy'), '6', '28', '028', '01', '2079', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28884, to_date('29-01-2079', 'dd-mm-yyyy'), '7', '29', '029', '01', '2079', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28885, to_date('30-01-2079', 'dd-mm-yyyy'), '1', '30', '030', '01', '2079', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28886, to_date('31-01-2079', 'dd-mm-yyyy'), '2', '31', '031', '01', '2079', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28887, to_date('01-02-2079', 'dd-mm-yyyy'), '3', '01', '032', '02', '2079', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28888, to_date('02-02-2079', 'dd-mm-yyyy'), '4', '02', '033', '02', '2079', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28889, to_date('03-02-2079', 'dd-mm-yyyy'), '5', '03', '034', '02', '2079', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28890, to_date('04-02-2079', 'dd-mm-yyyy'), '6', '04', '035', '02', '2079', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28891, to_date('05-02-2079', 'dd-mm-yyyy'), '7', '05', '036', '02', '2079', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28892, to_date('06-02-2079', 'dd-mm-yyyy'), '1', '06', '037', '02', '2079', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28893, to_date('07-02-2079', 'dd-mm-yyyy'), '2', '07', '038', '02', '2079', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28894, to_date('08-02-2079', 'dd-mm-yyyy'), '3', '08', '039', '02', '2079', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28895, to_date('09-02-2079', 'dd-mm-yyyy'), '4', '09', '040', '02', '2079', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28896, to_date('10-02-2079', 'dd-mm-yyyy'), '5', '10', '041', '02', '2079', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28897, to_date('11-02-2079', 'dd-mm-yyyy'), '6', '11', '042', '02', '2079', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28898, to_date('12-02-2079', 'dd-mm-yyyy'), '7', '12', '043', '02', '2079', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28899, to_date('13-02-2079', 'dd-mm-yyyy'), '1', '13', '044', '02', '2079', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28900, to_date('14-02-2079', 'dd-mm-yyyy'), '2', '14', '045', '02', '2079', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28901, to_date('15-02-2079', 'dd-mm-yyyy'), '3', '15', '046', '02', '2079', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28902, to_date('16-02-2079', 'dd-mm-yyyy'), '4', '16', '047', '02', '2079', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28903, to_date('17-02-2079', 'dd-mm-yyyy'), '5', '17', '048', '02', '2079', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28904, to_date('18-02-2079', 'dd-mm-yyyy'), '6', '18', '049', '02', '2079', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28905, to_date('19-02-2079', 'dd-mm-yyyy'), '7', '19', '050', '02', '2079', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28906, to_date('20-02-2079', 'dd-mm-yyyy'), '1', '20', '051', '02', '2079', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28907, to_date('21-02-2079', 'dd-mm-yyyy'), '2', '21', '052', '02', '2079', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28908, to_date('22-02-2079', 'dd-mm-yyyy'), '3', '22', '053', '02', '2079', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28909, to_date('23-02-2079', 'dd-mm-yyyy'), '4', '23', '054', '02', '2079', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28910, to_date('24-02-2079', 'dd-mm-yyyy'), '5', '24', '055', '02', '2079', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28911, to_date('25-02-2079', 'dd-mm-yyyy'), '6', '25', '056', '02', '2079', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28912, to_date('26-02-2079', 'dd-mm-yyyy'), '7', '26', '057', '02', '2079', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30397, to_date('22-03-2083', 'dd-mm-yyyy'), '1', '22', '081', '03', '2083', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30398, to_date('23-03-2083', 'dd-mm-yyyy'), '2', '23', '082', '03', '2083', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30399, to_date('24-03-2083', 'dd-mm-yyyy'), '3', '24', '083', '03', '2083', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30400, to_date('25-03-2083', 'dd-mm-yyyy'), '4', '25', '084', '03', '2083', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30401, to_date('26-03-2083', 'dd-mm-yyyy'), '5', '26', '085', '03', '2083', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30402, to_date('27-03-2083', 'dd-mm-yyyy'), '6', '27', '086', '03', '2083', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30403, to_date('28-03-2083', 'dd-mm-yyyy'), '7', '28', '087', '03', '2083', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30404, to_date('29-03-2083', 'dd-mm-yyyy'), '1', '29', '088', '03', '2083', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30405, to_date('30-03-2083', 'dd-mm-yyyy'), '2', '30', '089', '03', '2083', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30406, to_date('31-03-2083', 'dd-mm-yyyy'), '3', '31', '090', '03', '2083', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30407, to_date('01-04-2083', 'dd-mm-yyyy'), '4', '01', '091', '04', '2083', '13', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30408, to_date('02-04-2083', 'dd-mm-yyyy'), '5', '02', '092', '04', '2083', '13', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30409, to_date('03-04-2083', 'dd-mm-yyyy'), '6', '03', '093', '04', '2083', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30410, to_date('04-04-2083', 'dd-mm-yyyy'), '7', '04', '094', '04', '2083', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30411, to_date('05-04-2083', 'dd-mm-yyyy'), '1', '05', '095', '04', '2083', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30412, to_date('06-04-2083', 'dd-mm-yyyy'), '2', '06', '096', '04', '2083', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30413, to_date('07-04-2083', 'dd-mm-yyyy'), '3', '07', '097', '04', '2083', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30414, to_date('08-04-2083', 'dd-mm-yyyy'), '4', '08', '098', '04', '2083', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30415, to_date('09-04-2083', 'dd-mm-yyyy'), '5', '09', '099', '04', '2083', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30416, to_date('10-04-2083', 'dd-mm-yyyy'), '6', '10', '100', '04', '2083', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30417, to_date('11-04-2083', 'dd-mm-yyyy'), '7', '11', '101', '04', '2083', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30418, to_date('12-04-2083', 'dd-mm-yyyy'), '1', '12', '102', '04', '2083', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30419, to_date('13-04-2083', 'dd-mm-yyyy'), '2', '13', '103', '04', '2083', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30420, to_date('14-04-2083', 'dd-mm-yyyy'), '3', '14', '104', '04', '2083', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30421, to_date('15-04-2083', 'dd-mm-yyyy'), '4', '15', '105', '04', '2083', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30422, to_date('16-04-2083', 'dd-mm-yyyy'), '5', '16', '106', '04', '2083', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30423, to_date('17-04-2083', 'dd-mm-yyyy'), '6', '17', '107', '04', '2083', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30424, to_date('18-04-2083', 'dd-mm-yyyy'), '7', '18', '108', '04', '2083', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30425, to_date('19-04-2083', 'dd-mm-yyyy'), '1', '19', '109', '04', '2083', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30426, to_date('20-04-2083', 'dd-mm-yyyy'), '2', '20', '110', '04', '2083', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30427, to_date('21-04-2083', 'dd-mm-yyyy'), '3', '21', '111', '04', '2083', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30428, to_date('22-04-2083', 'dd-mm-yyyy'), '4', '22', '112', '04', '2083', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30429, to_date('23-04-2083', 'dd-mm-yyyy'), '5', '23', '113', '04', '2083', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30430, to_date('24-04-2083', 'dd-mm-yyyy'), '6', '24', '114', '04', '2083', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30431, to_date('25-04-2083', 'dd-mm-yyyy'), '7', '25', '115', '04', '2083', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30432, to_date('26-04-2083', 'dd-mm-yyyy'), '1', '26', '116', '04', '2083', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30433, to_date('27-04-2083', 'dd-mm-yyyy'), '2', '27', '117', '04', '2083', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30434, to_date('28-04-2083', 'dd-mm-yyyy'), '3', '28', '118', '04', '2083', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30435, to_date('29-04-2083', 'dd-mm-yyyy'), '4', '29', '119', '04', '2083', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30436, to_date('30-04-2083', 'dd-mm-yyyy'), '5', '30', '120', '04', '2083', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30437, to_date('01-05-2083', 'dd-mm-yyyy'), '6', '01', '121', '05', '2083', '17', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30438, to_date('02-05-2083', 'dd-mm-yyyy'), '7', '02', '122', '05', '2083', '17', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30439, to_date('03-05-2083', 'dd-mm-yyyy'), '1', '03', '123', '05', '2083', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30440, to_date('04-05-2083', 'dd-mm-yyyy'), '2', '04', '124', '05', '2083', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30441, to_date('05-05-2083', 'dd-mm-yyyy'), '3', '05', '125', '05', '2083', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30442, to_date('06-05-2083', 'dd-mm-yyyy'), '4', '06', '126', '05', '2083', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30443, to_date('07-05-2083', 'dd-mm-yyyy'), '5', '07', '127', '05', '2083', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30444, to_date('08-05-2083', 'dd-mm-yyyy'), '6', '08', '128', '05', '2083', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30445, to_date('09-05-2083', 'dd-mm-yyyy'), '7', '09', '129', '05', '2083', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30446, to_date('10-05-2083', 'dd-mm-yyyy'), '1', '10', '130', '05', '2083', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30447, to_date('11-05-2083', 'dd-mm-yyyy'), '2', '11', '131', '05', '2083', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30448, to_date('12-05-2083', 'dd-mm-yyyy'), '3', '12', '132', '05', '2083', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30449, to_date('13-05-2083', 'dd-mm-yyyy'), '4', '13', '133', '05', '2083', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30450, to_date('14-05-2083', 'dd-mm-yyyy'), '5', '14', '134', '05', '2083', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30451, to_date('15-05-2083', 'dd-mm-yyyy'), '6', '15', '135', '05', '2083', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30452, to_date('16-05-2083', 'dd-mm-yyyy'), '7', '16', '136', '05', '2083', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30453, to_date('17-05-2083', 'dd-mm-yyyy'), '1', '17', '137', '05', '2083', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30454, to_date('18-05-2083', 'dd-mm-yyyy'), '2', '18', '138', '05', '2083', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30455, to_date('19-05-2083', 'dd-mm-yyyy'), '3', '19', '139', '05', '2083', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30456, to_date('20-05-2083', 'dd-mm-yyyy'), '4', '20', '140', '05', '2083', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30457, to_date('21-05-2083', 'dd-mm-yyyy'), '5', '21', '141', '05', '2083', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30458, to_date('22-05-2083', 'dd-mm-yyyy'), '6', '22', '142', '05', '2083', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30459, to_date('23-05-2083', 'dd-mm-yyyy'), '7', '23', '143', '05', '2083', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30460, to_date('24-05-2083', 'dd-mm-yyyy'), '1', '24', '144', '05', '2083', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30461, to_date('25-05-2083', 'dd-mm-yyyy'), '2', '25', '145', '05', '2083', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
commit;
prompt 35000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30462, to_date('26-05-2083', 'dd-mm-yyyy'), '3', '26', '146', '05', '2083', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30463, to_date('27-05-2083', 'dd-mm-yyyy'), '4', '27', '147', '05', '2083', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30464, to_date('28-05-2083', 'dd-mm-yyyy'), '5', '28', '148', '05', '2083', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30465, to_date('29-05-2083', 'dd-mm-yyyy'), '6', '29', '149', '05', '2083', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30466, to_date('30-05-2083', 'dd-mm-yyyy'), '7', '30', '150', '05', '2083', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30467, to_date('31-05-2083', 'dd-mm-yyyy'), '1', '31', '151', '05', '2083', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30468, to_date('01-06-2083', 'dd-mm-yyyy'), '2', '01', '152', '06', '2083', '22', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30469, to_date('02-06-2083', 'dd-mm-yyyy'), '3', '02', '153', '06', '2083', '22', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30470, to_date('03-06-2083', 'dd-mm-yyyy'), '4', '03', '154', '06', '2083', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30471, to_date('04-06-2083', 'dd-mm-yyyy'), '5', '04', '155', '06', '2083', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30472, to_date('05-06-2083', 'dd-mm-yyyy'), '6', '05', '156', '06', '2083', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30473, to_date('06-06-2083', 'dd-mm-yyyy'), '7', '06', '157', '06', '2083', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30474, to_date('07-06-2083', 'dd-mm-yyyy'), '1', '07', '158', '06', '2083', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30475, to_date('08-06-2083', 'dd-mm-yyyy'), '2', '08', '159', '06', '2083', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30476, to_date('09-06-2083', 'dd-mm-yyyy'), '3', '09', '160', '06', '2083', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30477, to_date('10-06-2083', 'dd-mm-yyyy'), '4', '10', '161', '06', '2083', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30478, to_date('11-06-2083', 'dd-mm-yyyy'), '5', '11', '162', '06', '2083', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30479, to_date('12-06-2083', 'dd-mm-yyyy'), '6', '12', '163', '06', '2083', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30480, to_date('13-06-2083', 'dd-mm-yyyy'), '7', '13', '164', '06', '2083', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30481, to_date('14-06-2083', 'dd-mm-yyyy'), '1', '14', '165', '06', '2083', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30482, to_date('15-06-2083', 'dd-mm-yyyy'), '2', '15', '166', '06', '2083', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30483, to_date('16-06-2083', 'dd-mm-yyyy'), '3', '16', '167', '06', '2083', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30484, to_date('17-06-2083', 'dd-mm-yyyy'), '4', '17', '168', '06', '2083', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30485, to_date('18-06-2083', 'dd-mm-yyyy'), '5', '18', '169', '06', '2083', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30486, to_date('19-06-2083', 'dd-mm-yyyy'), '6', '19', '170', '06', '2083', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30487, to_date('20-06-2083', 'dd-mm-yyyy'), '7', '20', '171', '06', '2083', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30488, to_date('21-06-2083', 'dd-mm-yyyy'), '1', '21', '172', '06', '2083', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30489, to_date('22-06-2083', 'dd-mm-yyyy'), '2', '22', '173', '06', '2083', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30490, to_date('23-06-2083', 'dd-mm-yyyy'), '3', '23', '174', '06', '2083', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30491, to_date('24-06-2083', 'dd-mm-yyyy'), '4', '24', '175', '06', '2083', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30492, to_date('25-06-2083', 'dd-mm-yyyy'), '5', '25', '176', '06', '2083', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30493, to_date('26-06-2083', 'dd-mm-yyyy'), '6', '26', '177', '06', '2083', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30494, to_date('27-06-2083', 'dd-mm-yyyy'), '7', '27', '178', '06', '2083', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30495, to_date('28-06-2083', 'dd-mm-yyyy'), '1', '28', '179', '06', '2083', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30496, to_date('29-06-2083', 'dd-mm-yyyy'), '2', '29', '180', '06', '2083', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30497, to_date('30-06-2083', 'dd-mm-yyyy'), '3', '30', '181', '06', '2083', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30498, to_date('01-07-2083', 'dd-mm-yyyy'), '4', '01', '182', '07', '2083', '26', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30499, to_date('02-07-2083', 'dd-mm-yyyy'), '5', '02', '183', '07', '2083', '26', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30500, to_date('03-07-2083', 'dd-mm-yyyy'), '6', '03', '184', '07', '2083', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30501, to_date('04-07-2083', 'dd-mm-yyyy'), '7', '04', '185', '07', '2083', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30502, to_date('05-07-2083', 'dd-mm-yyyy'), '1', '05', '186', '07', '2083', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31987, to_date('29-07-2087', 'dd-mm-yyyy'), '2', '29', '210', '07', '2087', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31988, to_date('30-07-2087', 'dd-mm-yyyy'), '3', '30', '211', '07', '2087', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31989, to_date('31-07-2087', 'dd-mm-yyyy'), '4', '31', '212', '07', '2087', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31990, to_date('01-08-2087', 'dd-mm-yyyy'), '5', '01', '213', '08', '2087', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31991, to_date('02-08-2087', 'dd-mm-yyyy'), '6', '02', '214', '08', '2087', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31992, to_date('03-08-2087', 'dd-mm-yyyy'), '7', '03', '215', '08', '2087', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31993, to_date('04-08-2087', 'dd-mm-yyyy'), '1', '04', '216', '08', '2087', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31994, to_date('05-08-2087', 'dd-mm-yyyy'), '2', '05', '217', '08', '2087', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31995, to_date('06-08-2087', 'dd-mm-yyyy'), '3', '06', '218', '08', '2087', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31996, to_date('07-08-2087', 'dd-mm-yyyy'), '4', '07', '219', '08', '2087', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31997, to_date('08-08-2087', 'dd-mm-yyyy'), '5', '08', '220', '08', '2087', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31998, to_date('09-08-2087', 'dd-mm-yyyy'), '6', '09', '221', '08', '2087', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (31999, to_date('10-08-2087', 'dd-mm-yyyy'), '7', '10', '222', '08', '2087', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32000, to_date('11-08-2087', 'dd-mm-yyyy'), '1', '11', '223', '08', '2087', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32001, to_date('12-08-2087', 'dd-mm-yyyy'), '2', '12', '224', '08', '2087', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32002, to_date('13-08-2087', 'dd-mm-yyyy'), '3', '13', '225', '08', '2087', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32003, to_date('14-08-2087', 'dd-mm-yyyy'), '4', '14', '226', '08', '2087', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32004, to_date('15-08-2087', 'dd-mm-yyyy'), '5', '15', '227', '08', '2087', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32005, to_date('16-08-2087', 'dd-mm-yyyy'), '6', '16', '228', '08', '2087', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32006, to_date('17-08-2087', 'dd-mm-yyyy'), '7', '17', '229', '08', '2087', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32007, to_date('18-08-2087', 'dd-mm-yyyy'), '1', '18', '230', '08', '2087', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32008, to_date('19-08-2087', 'dd-mm-yyyy'), '2', '19', '231', '08', '2087', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32009, to_date('20-08-2087', 'dd-mm-yyyy'), '3', '20', '232', '08', '2087', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32010, to_date('21-08-2087', 'dd-mm-yyyy'), '4', '21', '233', '08', '2087', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32011, to_date('22-08-2087', 'dd-mm-yyyy'), '5', '22', '234', '08', '2087', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32012, to_date('23-08-2087', 'dd-mm-yyyy'), '6', '23', '235', '08', '2087', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32013, to_date('24-08-2087', 'dd-mm-yyyy'), '7', '24', '236', '08', '2087', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32014, to_date('25-08-2087', 'dd-mm-yyyy'), '1', '25', '237', '08', '2087', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32015, to_date('26-08-2087', 'dd-mm-yyyy'), '2', '26', '238', '08', '2087', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32016, to_date('27-08-2087', 'dd-mm-yyyy'), '3', '27', '239', '08', '2087', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32017, to_date('28-08-2087', 'dd-mm-yyyy'), '4', '28', '240', '08', '2087', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32018, to_date('29-08-2087', 'dd-mm-yyyy'), '5', '29', '241', '08', '2087', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32019, to_date('30-08-2087', 'dd-mm-yyyy'), '6', '30', '242', '08', '2087', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32020, to_date('31-08-2087', 'dd-mm-yyyy'), '7', '31', '243', '08', '2087', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32021, to_date('01-09-2087', 'dd-mm-yyyy'), '1', '01', '244', '09', '2087', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32022, to_date('02-09-2087', 'dd-mm-yyyy'), '2', '02', '245', '09', '2087', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32023, to_date('03-09-2087', 'dd-mm-yyyy'), '3', '03', '246', '09', '2087', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32024, to_date('04-09-2087', 'dd-mm-yyyy'), '4', '04', '247', '09', '2087', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32025, to_date('05-09-2087', 'dd-mm-yyyy'), '5', '05', '248', '09', '2087', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32026, to_date('06-09-2087', 'dd-mm-yyyy'), '6', '06', '249', '09', '2087', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32027, to_date('07-09-2087', 'dd-mm-yyyy'), '7', '07', '250', '09', '2087', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32028, to_date('08-09-2087', 'dd-mm-yyyy'), '1', '08', '251', '09', '2087', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32029, to_date('09-09-2087', 'dd-mm-yyyy'), '2', '09', '252', '09', '2087', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32030, to_date('10-09-2087', 'dd-mm-yyyy'), '3', '10', '253', '09', '2087', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32031, to_date('11-09-2087', 'dd-mm-yyyy'), '4', '11', '254', '09', '2087', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32032, to_date('12-09-2087', 'dd-mm-yyyy'), '5', '12', '255', '09', '2087', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32033, to_date('13-09-2087', 'dd-mm-yyyy'), '6', '13', '256', '09', '2087', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32034, to_date('14-09-2087', 'dd-mm-yyyy'), '7', '14', '257', '09', '2087', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32035, to_date('15-09-2087', 'dd-mm-yyyy'), '1', '15', '258', '09', '2087', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32036, to_date('16-09-2087', 'dd-mm-yyyy'), '2', '16', '259', '09', '2087', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32037, to_date('17-09-2087', 'dd-mm-yyyy'), '3', '17', '260', '09', '2087', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32038, to_date('18-09-2087', 'dd-mm-yyyy'), '4', '18', '261', '09', '2087', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32039, to_date('19-09-2087', 'dd-mm-yyyy'), '5', '19', '262', '09', '2087', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32040, to_date('20-09-2087', 'dd-mm-yyyy'), '6', '20', '263', '09', '2087', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32041, to_date('21-09-2087', 'dd-mm-yyyy'), '7', '21', '264', '09', '2087', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32042, to_date('22-09-2087', 'dd-mm-yyyy'), '1', '22', '265', '09', '2087', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32043, to_date('23-09-2087', 'dd-mm-yyyy'), '2', '23', '266', '09', '2087', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32044, to_date('24-09-2087', 'dd-mm-yyyy'), '3', '24', '267', '09', '2087', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32045, to_date('25-09-2087', 'dd-mm-yyyy'), '4', '25', '268', '09', '2087', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32046, to_date('26-09-2087', 'dd-mm-yyyy'), '5', '26', '269', '09', '2087', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32047, to_date('27-09-2087', 'dd-mm-yyyy'), '6', '27', '270', '09', '2087', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32048, to_date('28-09-2087', 'dd-mm-yyyy'), '7', '28', '271', '09', '2087', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32049, to_date('29-09-2087', 'dd-mm-yyyy'), '1', '29', '272', '09', '2087', '40', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32050, to_date('30-09-2087', 'dd-mm-yyyy'), '2', '30', '273', '09', '2087', '40', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32051, to_date('01-10-2087', 'dd-mm-yyyy'), '3', '01', '274', '10', '2087', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32052, to_date('02-10-2087', 'dd-mm-yyyy'), '4', '02', '275', '10', '2087', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32053, to_date('03-10-2087', 'dd-mm-yyyy'), '5', '03', '276', '10', '2087', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32054, to_date('04-10-2087', 'dd-mm-yyyy'), '6', '04', '277', '10', '2087', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32055, to_date('05-10-2087', 'dd-mm-yyyy'), '7', '05', '278', '10', '2087', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32056, to_date('06-10-2087', 'dd-mm-yyyy'), '1', '06', '279', '10', '2087', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32057, to_date('07-10-2087', 'dd-mm-yyyy'), '2', '07', '280', '10', '2087', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32058, to_date('08-10-2087', 'dd-mm-yyyy'), '3', '08', '281', '10', '2087', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32059, to_date('09-10-2087', 'dd-mm-yyyy'), '4', '09', '282', '10', '2087', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32060, to_date('10-10-2087', 'dd-mm-yyyy'), '5', '10', '283', '10', '2087', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32061, to_date('11-10-2087', 'dd-mm-yyyy'), '6', '11', '284', '10', '2087', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32062, to_date('12-10-2087', 'dd-mm-yyyy'), '7', '12', '285', '10', '2087', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32063, to_date('13-10-2087', 'dd-mm-yyyy'), '1', '13', '286', '10', '2087', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32064, to_date('14-10-2087', 'dd-mm-yyyy'), '2', '14', '287', '10', '2087', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32065, to_date('15-10-2087', 'dd-mm-yyyy'), '3', '15', '288', '10', '2087', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32066, to_date('16-10-2087', 'dd-mm-yyyy'), '4', '16', '289', '10', '2087', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32067, to_date('17-10-2087', 'dd-mm-yyyy'), '5', '17', '290', '10', '2087', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32068, to_date('18-10-2087', 'dd-mm-yyyy'), '6', '18', '291', '10', '2087', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32069, to_date('19-10-2087', 'dd-mm-yyyy'), '7', '19', '292', '10', '2087', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32070, to_date('20-10-2087', 'dd-mm-yyyy'), '1', '20', '293', '10', '2087', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32071, to_date('21-10-2087', 'dd-mm-yyyy'), '2', '21', '294', '10', '2087', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32072, to_date('22-10-2087', 'dd-mm-yyyy'), '3', '22', '295', '10', '2087', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32073, to_date('23-10-2087', 'dd-mm-yyyy'), '4', '23', '296', '10', '2087', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32074, to_date('24-10-2087', 'dd-mm-yyyy'), '5', '24', '297', '10', '2087', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32075, to_date('25-10-2087', 'dd-mm-yyyy'), '6', '25', '298', '10', '2087', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32076, to_date('26-10-2087', 'dd-mm-yyyy'), '7', '26', '299', '10', '2087', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32077, to_date('27-10-2087', 'dd-mm-yyyy'), '1', '27', '300', '10', '2087', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32078, to_date('28-10-2087', 'dd-mm-yyyy'), '2', '28', '301', '10', '2087', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32079, to_date('29-10-2087', 'dd-mm-yyyy'), '3', '29', '302', '10', '2087', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32080, to_date('30-10-2087', 'dd-mm-yyyy'), '4', '30', '303', '10', '2087', '44', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32081, to_date('31-10-2087', 'dd-mm-yyyy'), '5', '31', '304', '10', '2087', '44', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32082, to_date('01-11-2087', 'dd-mm-yyyy'), '6', '01', '305', '11', '2087', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32083, to_date('02-11-2087', 'dd-mm-yyyy'), '7', '02', '306', '11', '2087', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32084, to_date('03-11-2087', 'dd-mm-yyyy'), '1', '03', '307', '11', '2087', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32085, to_date('04-11-2087', 'dd-mm-yyyy'), '2', '04', '308', '11', '2087', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32086, to_date('05-11-2087', 'dd-mm-yyyy'), '3', '05', '309', '11', '2087', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32087, to_date('06-11-2087', 'dd-mm-yyyy'), '4', '06', '310', '11', '2087', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32088, to_date('07-11-2087', 'dd-mm-yyyy'), '5', '07', '311', '11', '2087', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32089, to_date('08-11-2087', 'dd-mm-yyyy'), '6', '08', '312', '11', '2087', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32090, to_date('09-11-2087', 'dd-mm-yyyy'), '7', '09', '313', '11', '2087', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32091, to_date('10-11-2087', 'dd-mm-yyyy'), '1', '10', '314', '11', '2087', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32092, to_date('11-11-2087', 'dd-mm-yyyy'), '2', '11', '315', '11', '2087', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27217, to_date('07-07-2074', 'dd-mm-yyyy'), '6', '07', '188', '07', '2074', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27218, to_date('08-07-2074', 'dd-mm-yyyy'), '7', '08', '189', '07', '2074', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27219, to_date('09-07-2074', 'dd-mm-yyyy'), '1', '09', '190', '07', '2074', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27220, to_date('10-07-2074', 'dd-mm-yyyy'), '2', '10', '191', '07', '2074', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27221, to_date('11-07-2074', 'dd-mm-yyyy'), '3', '11', '192', '07', '2074', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27222, to_date('12-07-2074', 'dd-mm-yyyy'), '4', '12', '193', '07', '2074', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27223, to_date('13-07-2074', 'dd-mm-yyyy'), '5', '13', '194', '07', '2074', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27224, to_date('14-07-2074', 'dd-mm-yyyy'), '6', '14', '195', '07', '2074', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27225, to_date('15-07-2074', 'dd-mm-yyyy'), '7', '15', '196', '07', '2074', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27226, to_date('16-07-2074', 'dd-mm-yyyy'), '1', '16', '197', '07', '2074', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27227, to_date('17-07-2074', 'dd-mm-yyyy'), '2', '17', '198', '07', '2074', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27228, to_date('18-07-2074', 'dd-mm-yyyy'), '3', '18', '199', '07', '2074', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27229, to_date('19-07-2074', 'dd-mm-yyyy'), '4', '19', '200', '07', '2074', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27230, to_date('20-07-2074', 'dd-mm-yyyy'), '5', '20', '201', '07', '2074', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27231, to_date('21-07-2074', 'dd-mm-yyyy'), '6', '21', '202', '07', '2074', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27232, to_date('22-07-2074', 'dd-mm-yyyy'), '7', '22', '203', '07', '2074', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27233, to_date('23-07-2074', 'dd-mm-yyyy'), '1', '23', '204', '07', '2074', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27234, to_date('24-07-2074', 'dd-mm-yyyy'), '2', '24', '205', '07', '2074', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27235, to_date('25-07-2074', 'dd-mm-yyyy'), '3', '25', '206', '07', '2074', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27236, to_date('26-07-2074', 'dd-mm-yyyy'), '4', '26', '207', '07', '2074', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27237, to_date('27-07-2074', 'dd-mm-yyyy'), '5', '27', '208', '07', '2074', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27238, to_date('28-07-2074', 'dd-mm-yyyy'), '6', '28', '209', '07', '2074', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27239, to_date('29-07-2074', 'dd-mm-yyyy'), '7', '29', '210', '07', '2074', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27240, to_date('30-07-2074', 'dd-mm-yyyy'), '1', '30', '211', '07', '2074', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27241, to_date('31-07-2074', 'dd-mm-yyyy'), '2', '31', '212', '07', '2074', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27242, to_date('01-08-2074', 'dd-mm-yyyy'), '3', '01', '213', '08', '2074', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27243, to_date('02-08-2074', 'dd-mm-yyyy'), '4', '02', '214', '08', '2074', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27244, to_date('03-08-2074', 'dd-mm-yyyy'), '5', '03', '215', '08', '2074', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27245, to_date('04-08-2074', 'dd-mm-yyyy'), '6', '04', '216', '08', '2074', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27246, to_date('05-08-2074', 'dd-mm-yyyy'), '7', '05', '217', '08', '2074', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27247, to_date('06-08-2074', 'dd-mm-yyyy'), '1', '06', '218', '08', '2074', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27248, to_date('07-08-2074', 'dd-mm-yyyy'), '2', '07', '219', '08', '2074', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27249, to_date('08-08-2074', 'dd-mm-yyyy'), '3', '08', '220', '08', '2074', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27250, to_date('09-08-2074', 'dd-mm-yyyy'), '4', '09', '221', '08', '2074', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27251, to_date('10-08-2074', 'dd-mm-yyyy'), '5', '10', '222', '08', '2074', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27252, to_date('11-08-2074', 'dd-mm-yyyy'), '6', '11', '223', '08', '2074', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27253, to_date('12-08-2074', 'dd-mm-yyyy'), '7', '12', '224', '08', '2074', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27254, to_date('13-08-2074', 'dd-mm-yyyy'), '1', '13', '225', '08', '2074', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27255, to_date('14-08-2074', 'dd-mm-yyyy'), '2', '14', '226', '08', '2074', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27256, to_date('15-08-2074', 'dd-mm-yyyy'), '3', '15', '227', '08', '2074', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27257, to_date('16-08-2074', 'dd-mm-yyyy'), '4', '16', '228', '08', '2074', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27258, to_date('17-08-2074', 'dd-mm-yyyy'), '5', '17', '229', '08', '2074', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27259, to_date('18-08-2074', 'dd-mm-yyyy'), '6', '18', '230', '08', '2074', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27260, to_date('19-08-2074', 'dd-mm-yyyy'), '7', '19', '231', '08', '2074', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27261, to_date('20-08-2074', 'dd-mm-yyyy'), '1', '20', '232', '08', '2074', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27262, to_date('21-08-2074', 'dd-mm-yyyy'), '2', '21', '233', '08', '2074', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27263, to_date('22-08-2074', 'dd-mm-yyyy'), '3', '22', '234', '08', '2074', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27264, to_date('23-08-2074', 'dd-mm-yyyy'), '4', '23', '235', '08', '2074', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27265, to_date('24-08-2074', 'dd-mm-yyyy'), '5', '24', '236', '08', '2074', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27266, to_date('25-08-2074', 'dd-mm-yyyy'), '6', '25', '237', '08', '2074', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27267, to_date('26-08-2074', 'dd-mm-yyyy'), '7', '26', '238', '08', '2074', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27268, to_date('27-08-2074', 'dd-mm-yyyy'), '1', '27', '239', '08', '2074', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27269, to_date('28-08-2074', 'dd-mm-yyyy'), '2', '28', '240', '08', '2074', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27270, to_date('29-08-2074', 'dd-mm-yyyy'), '3', '29', '241', '08', '2074', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27271, to_date('30-08-2074', 'dd-mm-yyyy'), '4', '30', '242', '08', '2074', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27272, to_date('31-08-2074', 'dd-mm-yyyy'), '5', '31', '243', '08', '2074', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27273, to_date('01-09-2074', 'dd-mm-yyyy'), '6', '01', '244', '09', '2074', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27274, to_date('02-09-2074', 'dd-mm-yyyy'), '7', '02', '245', '09', '2074', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27275, to_date('03-09-2074', 'dd-mm-yyyy'), '1', '03', '246', '09', '2074', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27276, to_date('04-09-2074', 'dd-mm-yyyy'), '2', '04', '247', '09', '2074', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27277, to_date('05-09-2074', 'dd-mm-yyyy'), '3', '05', '248', '09', '2074', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27278, to_date('06-09-2074', 'dd-mm-yyyy'), '4', '06', '249', '09', '2074', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27279, to_date('07-09-2074', 'dd-mm-yyyy'), '5', '07', '250', '09', '2074', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27280, to_date('08-09-2074', 'dd-mm-yyyy'), '6', '08', '251', '09', '2074', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27281, to_date('09-09-2074', 'dd-mm-yyyy'), '7', '09', '252', '09', '2074', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27282, to_date('10-09-2074', 'dd-mm-yyyy'), '1', '10', '253', '09', '2074', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27283, to_date('11-09-2074', 'dd-mm-yyyy'), '2', '11', '254', '09', '2074', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27284, to_date('12-09-2074', 'dd-mm-yyyy'), '3', '12', '255', '09', '2074', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27285, to_date('13-09-2074', 'dd-mm-yyyy'), '4', '13', '256', '09', '2074', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27286, to_date('14-09-2074', 'dd-mm-yyyy'), '5', '14', '257', '09', '2074', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27287, to_date('15-09-2074', 'dd-mm-yyyy'), '6', '15', '258', '09', '2074', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27288, to_date('16-09-2074', 'dd-mm-yyyy'), '7', '16', '259', '09', '2074', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27289, to_date('17-09-2074', 'dd-mm-yyyy'), '1', '17', '260', '09', '2074', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27290, to_date('18-09-2074', 'dd-mm-yyyy'), '2', '18', '261', '09', '2074', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27291, to_date('19-09-2074', 'dd-mm-yyyy'), '3', '19', '262', '09', '2074', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27292, to_date('20-09-2074', 'dd-mm-yyyy'), '4', '20', '263', '09', '2074', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27293, to_date('21-09-2074', 'dd-mm-yyyy'), '5', '21', '264', '09', '2074', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27294, to_date('22-09-2074', 'dd-mm-yyyy'), '6', '22', '265', '09', '2074', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27295, to_date('23-09-2074', 'dd-mm-yyyy'), '7', '23', '266', '09', '2074', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27296, to_date('24-09-2074', 'dd-mm-yyyy'), '1', '24', '267', '09', '2074', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27297, to_date('25-09-2074', 'dd-mm-yyyy'), '2', '25', '268', '09', '2074', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27298, to_date('26-09-2074', 'dd-mm-yyyy'), '3', '26', '269', '09', '2074', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27299, to_date('27-09-2074', 'dd-mm-yyyy'), '4', '27', '270', '09', '2074', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27300, to_date('28-09-2074', 'dd-mm-yyyy'), '5', '28', '271', '09', '2074', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27301, to_date('29-09-2074', 'dd-mm-yyyy'), '6', '29', '272', '09', '2074', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27302, to_date('30-09-2074', 'dd-mm-yyyy'), '7', '30', '273', '09', '2074', '39', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27303, to_date('01-10-2074', 'dd-mm-yyyy'), '1', '01', '274', '10', '2074', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27304, to_date('02-10-2074', 'dd-mm-yyyy'), '2', '02', '275', '10', '2074', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27305, to_date('03-10-2074', 'dd-mm-yyyy'), '3', '03', '276', '10', '2074', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27306, to_date('04-10-2074', 'dd-mm-yyyy'), '4', '04', '277', '10', '2074', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27307, to_date('05-10-2074', 'dd-mm-yyyy'), '5', '05', '278', '10', '2074', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27308, to_date('06-10-2074', 'dd-mm-yyyy'), '6', '06', '279', '10', '2074', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27309, to_date('07-10-2074', 'dd-mm-yyyy'), '7', '07', '280', '10', '2074', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27310, to_date('08-10-2074', 'dd-mm-yyyy'), '1', '08', '281', '10', '2074', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27311, to_date('09-10-2074', 'dd-mm-yyyy'), '2', '09', '282', '10', '2074', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27312, to_date('10-10-2074', 'dd-mm-yyyy'), '3', '10', '283', '10', '2074', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27313, to_date('11-10-2074', 'dd-mm-yyyy'), '4', '11', '284', '10', '2074', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27314, to_date('12-10-2074', 'dd-mm-yyyy'), '5', '12', '285', '10', '2074', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27315, to_date('13-10-2074', 'dd-mm-yyyy'), '6', '13', '286', '10', '2074', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27316, to_date('14-10-2074', 'dd-mm-yyyy'), '7', '14', '287', '10', '2074', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27317, to_date('15-10-2074', 'dd-mm-yyyy'), '1', '15', '288', '10', '2074', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27318, to_date('16-10-2074', 'dd-mm-yyyy'), '2', '16', '289', '10', '2074', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27319, to_date('17-10-2074', 'dd-mm-yyyy'), '3', '17', '290', '10', '2074', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27320, to_date('18-10-2074', 'dd-mm-yyyy'), '4', '18', '291', '10', '2074', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27321, to_date('19-10-2074', 'dd-mm-yyyy'), '5', '19', '292', '10', '2074', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27322, to_date('20-10-2074', 'dd-mm-yyyy'), '6', '20', '293', '10', '2074', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28913, to_date('27-02-2079', 'dd-mm-yyyy'), '1', '27', '058', '02', '2079', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28914, to_date('28-02-2079', 'dd-mm-yyyy'), '2', '28', '059', '02', '2079', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28915, to_date('01-03-2079', 'dd-mm-yyyy'), '3', '01', '060', '03', '2079', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28916, to_date('02-03-2079', 'dd-mm-yyyy'), '4', '02', '061', '03', '2079', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28917, to_date('03-03-2079', 'dd-mm-yyyy'), '5', '03', '062', '03', '2079', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28918, to_date('04-03-2079', 'dd-mm-yyyy'), '6', '04', '063', '03', '2079', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28919, to_date('05-03-2079', 'dd-mm-yyyy'), '7', '05', '064', '03', '2079', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28920, to_date('06-03-2079', 'dd-mm-yyyy'), '1', '06', '065', '03', '2079', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28921, to_date('07-03-2079', 'dd-mm-yyyy'), '2', '07', '066', '03', '2079', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28922, to_date('08-03-2079', 'dd-mm-yyyy'), '3', '08', '067', '03', '2079', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28923, to_date('09-03-2079', 'dd-mm-yyyy'), '4', '09', '068', '03', '2079', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28924, to_date('10-03-2079', 'dd-mm-yyyy'), '5', '10', '069', '03', '2079', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28925, to_date('11-03-2079', 'dd-mm-yyyy'), '6', '11', '070', '03', '2079', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28926, to_date('12-03-2079', 'dd-mm-yyyy'), '7', '12', '071', '03', '2079', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28927, to_date('13-03-2079', 'dd-mm-yyyy'), '1', '13', '072', '03', '2079', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28928, to_date('14-03-2079', 'dd-mm-yyyy'), '2', '14', '073', '03', '2079', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28929, to_date('15-03-2079', 'dd-mm-yyyy'), '3', '15', '074', '03', '2079', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28930, to_date('16-03-2079', 'dd-mm-yyyy'), '4', '16', '075', '03', '2079', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28931, to_date('17-03-2079', 'dd-mm-yyyy'), '5', '17', '076', '03', '2079', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28932, to_date('18-03-2079', 'dd-mm-yyyy'), '6', '18', '077', '03', '2079', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28933, to_date('19-03-2079', 'dd-mm-yyyy'), '7', '19', '078', '03', '2079', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28934, to_date('20-03-2079', 'dd-mm-yyyy'), '1', '20', '079', '03', '2079', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28935, to_date('21-03-2079', 'dd-mm-yyyy'), '2', '21', '080', '03', '2079', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28936, to_date('22-03-2079', 'dd-mm-yyyy'), '3', '22', '081', '03', '2079', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28937, to_date('23-03-2079', 'dd-mm-yyyy'), '4', '23', '082', '03', '2079', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28938, to_date('24-03-2079', 'dd-mm-yyyy'), '5', '24', '083', '03', '2079', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28939, to_date('25-03-2079', 'dd-mm-yyyy'), '6', '25', '084', '03', '2079', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28940, to_date('26-03-2079', 'dd-mm-yyyy'), '7', '26', '085', '03', '2079', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28941, to_date('27-03-2079', 'dd-mm-yyyy'), '1', '27', '086', '03', '2079', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28942, to_date('28-03-2079', 'dd-mm-yyyy'), '2', '28', '087', '03', '2079', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28943, to_date('29-03-2079', 'dd-mm-yyyy'), '3', '29', '088', '03', '2079', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28944, to_date('30-03-2079', 'dd-mm-yyyy'), '4', '30', '089', '03', '2079', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28945, to_date('31-03-2079', 'dd-mm-yyyy'), '5', '31', '090', '03', '2079', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28946, to_date('01-04-2079', 'dd-mm-yyyy'), '6', '01', '091', '04', '2079', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28947, to_date('02-04-2079', 'dd-mm-yyyy'), '7', '02', '092', '04', '2079', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28948, to_date('03-04-2079', 'dd-mm-yyyy'), '1', '03', '093', '04', '2079', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28949, to_date('04-04-2079', 'dd-mm-yyyy'), '2', '04', '094', '04', '2079', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28950, to_date('05-04-2079', 'dd-mm-yyyy'), '3', '05', '095', '04', '2079', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28951, to_date('06-04-2079', 'dd-mm-yyyy'), '4', '06', '096', '04', '2079', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28952, to_date('07-04-2079', 'dd-mm-yyyy'), '5', '07', '097', '04', '2079', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28953, to_date('08-04-2079', 'dd-mm-yyyy'), '6', '08', '098', '04', '2079', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28954, to_date('09-04-2079', 'dd-mm-yyyy'), '7', '09', '099', '04', '2079', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28955, to_date('10-04-2079', 'dd-mm-yyyy'), '1', '10', '100', '04', '2079', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28956, to_date('11-04-2079', 'dd-mm-yyyy'), '2', '11', '101', '04', '2079', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28957, to_date('12-04-2079', 'dd-mm-yyyy'), '3', '12', '102', '04', '2079', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28958, to_date('13-04-2079', 'dd-mm-yyyy'), '4', '13', '103', '04', '2079', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28959, to_date('14-04-2079', 'dd-mm-yyyy'), '5', '14', '104', '04', '2079', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28960, to_date('15-04-2079', 'dd-mm-yyyy'), '6', '15', '105', '04', '2079', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28961, to_date('16-04-2079', 'dd-mm-yyyy'), '7', '16', '106', '04', '2079', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28962, to_date('17-04-2079', 'dd-mm-yyyy'), '1', '17', '107', '04', '2079', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28963, to_date('18-04-2079', 'dd-mm-yyyy'), '2', '18', '108', '04', '2079', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28964, to_date('19-04-2079', 'dd-mm-yyyy'), '3', '19', '109', '04', '2079', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28965, to_date('20-04-2079', 'dd-mm-yyyy'), '4', '20', '110', '04', '2079', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28966, to_date('21-04-2079', 'dd-mm-yyyy'), '5', '21', '111', '04', '2079', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28967, to_date('22-04-2079', 'dd-mm-yyyy'), '6', '22', '112', '04', '2079', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28968, to_date('23-04-2079', 'dd-mm-yyyy'), '7', '23', '113', '04', '2079', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28969, to_date('24-04-2079', 'dd-mm-yyyy'), '1', '24', '114', '04', '2079', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28970, to_date('25-04-2079', 'dd-mm-yyyy'), '2', '25', '115', '04', '2079', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28971, to_date('26-04-2079', 'dd-mm-yyyy'), '3', '26', '116', '04', '2079', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28972, to_date('27-04-2079', 'dd-mm-yyyy'), '4', '27', '117', '04', '2079', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28973, to_date('28-04-2079', 'dd-mm-yyyy'), '5', '28', '118', '04', '2079', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28974, to_date('29-04-2079', 'dd-mm-yyyy'), '6', '29', '119', '04', '2079', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28975, to_date('30-04-2079', 'dd-mm-yyyy'), '7', '30', '120', '04', '2079', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28976, to_date('01-05-2079', 'dd-mm-yyyy'), '1', '01', '121', '05', '2079', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28977, to_date('02-05-2079', 'dd-mm-yyyy'), '2', '02', '122', '05', '2079', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28978, to_date('03-05-2079', 'dd-mm-yyyy'), '3', '03', '123', '05', '2079', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28979, to_date('04-05-2079', 'dd-mm-yyyy'), '4', '04', '124', '05', '2079', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28980, to_date('05-05-2079', 'dd-mm-yyyy'), '5', '05', '125', '05', '2079', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28981, to_date('06-05-2079', 'dd-mm-yyyy'), '6', '06', '126', '05', '2079', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28982, to_date('07-05-2079', 'dd-mm-yyyy'), '7', '07', '127', '05', '2079', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28983, to_date('08-05-2079', 'dd-mm-yyyy'), '1', '08', '128', '05', '2079', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28984, to_date('09-05-2079', 'dd-mm-yyyy'), '2', '09', '129', '05', '2079', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28985, to_date('10-05-2079', 'dd-mm-yyyy'), '3', '10', '130', '05', '2079', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28986, to_date('11-05-2079', 'dd-mm-yyyy'), '4', '11', '131', '05', '2079', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28987, to_date('12-05-2079', 'dd-mm-yyyy'), '5', '12', '132', '05', '2079', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28988, to_date('13-05-2079', 'dd-mm-yyyy'), '6', '13', '133', '05', '2079', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28989, to_date('14-05-2079', 'dd-mm-yyyy'), '7', '14', '134', '05', '2079', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28990, to_date('15-05-2079', 'dd-mm-yyyy'), '1', '15', '135', '05', '2079', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28991, to_date('16-05-2079', 'dd-mm-yyyy'), '2', '16', '136', '05', '2079', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28992, to_date('17-05-2079', 'dd-mm-yyyy'), '3', '17', '137', '05', '2079', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28993, to_date('18-05-2079', 'dd-mm-yyyy'), '4', '18', '138', '05', '2079', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28994, to_date('19-05-2079', 'dd-mm-yyyy'), '5', '19', '139', '05', '2079', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28995, to_date('20-05-2079', 'dd-mm-yyyy'), '6', '20', '140', '05', '2079', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28996, to_date('21-05-2079', 'dd-mm-yyyy'), '7', '21', '141', '05', '2079', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28997, to_date('22-05-2079', 'dd-mm-yyyy'), '1', '22', '142', '05', '2079', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28998, to_date('23-05-2079', 'dd-mm-yyyy'), '2', '23', '143', '05', '2079', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (28999, to_date('24-05-2079', 'dd-mm-yyyy'), '3', '24', '144', '05', '2079', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29000, to_date('25-05-2079', 'dd-mm-yyyy'), '4', '25', '145', '05', '2079', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29001, to_date('26-05-2079', 'dd-mm-yyyy'), '5', '26', '146', '05', '2079', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29002, to_date('27-05-2079', 'dd-mm-yyyy'), '6', '27', '147', '05', '2079', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29003, to_date('28-05-2079', 'dd-mm-yyyy'), '7', '28', '148', '05', '2079', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29004, to_date('29-05-2079', 'dd-mm-yyyy'), '1', '29', '149', '05', '2079', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29005, to_date('30-05-2079', 'dd-mm-yyyy'), '2', '30', '150', '05', '2079', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29006, to_date('31-05-2079', 'dd-mm-yyyy'), '3', '31', '151', '05', '2079', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29007, to_date('01-06-2079', 'dd-mm-yyyy'), '4', '01', '152', '06', '2079', '22', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29008, to_date('02-06-2079', 'dd-mm-yyyy'), '5', '02', '153', '06', '2079', '22', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29009, to_date('03-06-2079', 'dd-mm-yyyy'), '6', '03', '154', '06', '2079', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29010, to_date('04-06-2079', 'dd-mm-yyyy'), '7', '04', '155', '06', '2079', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29011, to_date('05-06-2079', 'dd-mm-yyyy'), '1', '05', '156', '06', '2079', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29012, to_date('06-06-2079', 'dd-mm-yyyy'), '2', '06', '157', '06', '2079', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29013, to_date('07-06-2079', 'dd-mm-yyyy'), '3', '07', '158', '06', '2079', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29014, to_date('08-06-2079', 'dd-mm-yyyy'), '4', '08', '159', '06', '2079', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29015, to_date('09-06-2079', 'dd-mm-yyyy'), '5', '09', '160', '06', '2079', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29016, to_date('10-06-2079', 'dd-mm-yyyy'), '6', '10', '161', '06', '2079', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29017, to_date('11-06-2079', 'dd-mm-yyyy'), '7', '11', '162', '06', '2079', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29018, to_date('12-06-2079', 'dd-mm-yyyy'), '1', '12', '163', '06', '2079', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30503, to_date('06-07-2083', 'dd-mm-yyyy'), '2', '06', '187', '07', '2083', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30504, to_date('07-07-2083', 'dd-mm-yyyy'), '3', '07', '188', '07', '2083', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30505, to_date('08-07-2083', 'dd-mm-yyyy'), '4', '08', '189', '07', '2083', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30506, to_date('09-07-2083', 'dd-mm-yyyy'), '5', '09', '190', '07', '2083', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30507, to_date('10-07-2083', 'dd-mm-yyyy'), '6', '10', '191', '07', '2083', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30508, to_date('11-07-2083', 'dd-mm-yyyy'), '7', '11', '192', '07', '2083', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30509, to_date('12-07-2083', 'dd-mm-yyyy'), '1', '12', '193', '07', '2083', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30510, to_date('13-07-2083', 'dd-mm-yyyy'), '2', '13', '194', '07', '2083', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30511, to_date('14-07-2083', 'dd-mm-yyyy'), '3', '14', '195', '07', '2083', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30512, to_date('15-07-2083', 'dd-mm-yyyy'), '4', '15', '196', '07', '2083', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30513, to_date('16-07-2083', 'dd-mm-yyyy'), '5', '16', '197', '07', '2083', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30514, to_date('17-07-2083', 'dd-mm-yyyy'), '6', '17', '198', '07', '2083', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30515, to_date('18-07-2083', 'dd-mm-yyyy'), '7', '18', '199', '07', '2083', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30516, to_date('19-07-2083', 'dd-mm-yyyy'), '1', '19', '200', '07', '2083', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30517, to_date('20-07-2083', 'dd-mm-yyyy'), '2', '20', '201', '07', '2083', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30518, to_date('21-07-2083', 'dd-mm-yyyy'), '3', '21', '202', '07', '2083', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30519, to_date('22-07-2083', 'dd-mm-yyyy'), '4', '22', '203', '07', '2083', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30520, to_date('23-07-2083', 'dd-mm-yyyy'), '5', '23', '204', '07', '2083', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30521, to_date('24-07-2083', 'dd-mm-yyyy'), '6', '24', '205', '07', '2083', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30522, to_date('25-07-2083', 'dd-mm-yyyy'), '7', '25', '206', '07', '2083', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30523, to_date('26-07-2083', 'dd-mm-yyyy'), '1', '26', '207', '07', '2083', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30524, to_date('27-07-2083', 'dd-mm-yyyy'), '2', '27', '208', '07', '2083', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30525, to_date('28-07-2083', 'dd-mm-yyyy'), '3', '28', '209', '07', '2083', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30526, to_date('29-07-2083', 'dd-mm-yyyy'), '4', '29', '210', '07', '2083', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30527, to_date('30-07-2083', 'dd-mm-yyyy'), '5', '30', '211', '07', '2083', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30528, to_date('31-07-2083', 'dd-mm-yyyy'), '6', '31', '212', '07', '2083', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30529, to_date('01-08-2083', 'dd-mm-yyyy'), '7', '01', '213', '08', '2083', '30', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30530, to_date('02-08-2083', 'dd-mm-yyyy'), '1', '02', '214', '08', '2083', '31', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30531, to_date('03-08-2083', 'dd-mm-yyyy'), '2', '03', '215', '08', '2083', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30532, to_date('04-08-2083', 'dd-mm-yyyy'), '3', '04', '216', '08', '2083', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30533, to_date('05-08-2083', 'dd-mm-yyyy'), '4', '05', '217', '08', '2083', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30534, to_date('06-08-2083', 'dd-mm-yyyy'), '5', '06', '218', '08', '2083', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30535, to_date('07-08-2083', 'dd-mm-yyyy'), '6', '07', '219', '08', '2083', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30536, to_date('08-08-2083', 'dd-mm-yyyy'), '7', '08', '220', '08', '2083', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30537, to_date('09-08-2083', 'dd-mm-yyyy'), '1', '09', '221', '08', '2083', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30538, to_date('10-08-2083', 'dd-mm-yyyy'), '2', '10', '222', '08', '2083', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30539, to_date('11-08-2083', 'dd-mm-yyyy'), '3', '11', '223', '08', '2083', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30540, to_date('12-08-2083', 'dd-mm-yyyy'), '4', '12', '224', '08', '2083', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30541, to_date('13-08-2083', 'dd-mm-yyyy'), '5', '13', '225', '08', '2083', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30542, to_date('14-08-2083', 'dd-mm-yyyy'), '6', '14', '226', '08', '2083', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30543, to_date('15-08-2083', 'dd-mm-yyyy'), '7', '15', '227', '08', '2083', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30544, to_date('16-08-2083', 'dd-mm-yyyy'), '1', '16', '228', '08', '2083', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30545, to_date('17-08-2083', 'dd-mm-yyyy'), '2', '17', '229', '08', '2083', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30546, to_date('18-08-2083', 'dd-mm-yyyy'), '3', '18', '230', '08', '2083', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30547, to_date('19-08-2083', 'dd-mm-yyyy'), '4', '19', '231', '08', '2083', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30548, to_date('20-08-2083', 'dd-mm-yyyy'), '5', '20', '232', '08', '2083', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30549, to_date('21-08-2083', 'dd-mm-yyyy'), '6', '21', '233', '08', '2083', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30550, to_date('22-08-2083', 'dd-mm-yyyy'), '7', '22', '234', '08', '2083', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30551, to_date('23-08-2083', 'dd-mm-yyyy'), '1', '23', '235', '08', '2083', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30552, to_date('24-08-2083', 'dd-mm-yyyy'), '2', '24', '236', '08', '2083', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30553, to_date('25-08-2083', 'dd-mm-yyyy'), '3', '25', '237', '08', '2083', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30554, to_date('26-08-2083', 'dd-mm-yyyy'), '4', '26', '238', '08', '2083', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30555, to_date('27-08-2083', 'dd-mm-yyyy'), '5', '27', '239', '08', '2083', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30556, to_date('28-08-2083', 'dd-mm-yyyy'), '6', '28', '240', '08', '2083', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30557, to_date('29-08-2083', 'dd-mm-yyyy'), '7', '29', '241', '08', '2083', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30558, to_date('30-08-2083', 'dd-mm-yyyy'), '1', '30', '242', '08', '2083', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30559, to_date('31-08-2083', 'dd-mm-yyyy'), '2', '31', '243', '08', '2083', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30560, to_date('01-09-2083', 'dd-mm-yyyy'), '3', '01', '244', '09', '2083', '35', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30561, to_date('02-09-2083', 'dd-mm-yyyy'), '4', '02', '245', '09', '2083', '35', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30562, to_date('03-09-2083', 'dd-mm-yyyy'), '5', '03', '246', '09', '2083', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30563, to_date('04-09-2083', 'dd-mm-yyyy'), '6', '04', '247', '09', '2083', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30564, to_date('05-09-2083', 'dd-mm-yyyy'), '7', '05', '248', '09', '2083', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30565, to_date('06-09-2083', 'dd-mm-yyyy'), '1', '06', '249', '09', '2083', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30566, to_date('07-09-2083', 'dd-mm-yyyy'), '2', '07', '250', '09', '2083', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30567, to_date('08-09-2083', 'dd-mm-yyyy'), '3', '08', '251', '09', '2083', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30568, to_date('09-09-2083', 'dd-mm-yyyy'), '4', '09', '252', '09', '2083', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30569, to_date('10-09-2083', 'dd-mm-yyyy'), '5', '10', '253', '09', '2083', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30570, to_date('11-09-2083', 'dd-mm-yyyy'), '6', '11', '254', '09', '2083', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30571, to_date('12-09-2083', 'dd-mm-yyyy'), '7', '12', '255', '09', '2083', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30572, to_date('13-09-2083', 'dd-mm-yyyy'), '1', '13', '256', '09', '2083', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30573, to_date('14-09-2083', 'dd-mm-yyyy'), '2', '14', '257', '09', '2083', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30574, to_date('15-09-2083', 'dd-mm-yyyy'), '3', '15', '258', '09', '2083', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30575, to_date('16-09-2083', 'dd-mm-yyyy'), '4', '16', '259', '09', '2083', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30576, to_date('17-09-2083', 'dd-mm-yyyy'), '5', '17', '260', '09', '2083', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30577, to_date('18-09-2083', 'dd-mm-yyyy'), '6', '18', '261', '09', '2083', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30578, to_date('19-09-2083', 'dd-mm-yyyy'), '7', '19', '262', '09', '2083', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30579, to_date('20-09-2083', 'dd-mm-yyyy'), '1', '20', '263', '09', '2083', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30580, to_date('21-09-2083', 'dd-mm-yyyy'), '2', '21', '264', '09', '2083', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30581, to_date('22-09-2083', 'dd-mm-yyyy'), '3', '22', '265', '09', '2083', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30582, to_date('23-09-2083', 'dd-mm-yyyy'), '4', '23', '266', '09', '2083', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30583, to_date('24-09-2083', 'dd-mm-yyyy'), '5', '24', '267', '09', '2083', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30584, to_date('25-09-2083', 'dd-mm-yyyy'), '6', '25', '268', '09', '2083', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30585, to_date('26-09-2083', 'dd-mm-yyyy'), '7', '26', '269', '09', '2083', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30586, to_date('27-09-2083', 'dd-mm-yyyy'), '1', '27', '270', '09', '2083', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30587, to_date('28-09-2083', 'dd-mm-yyyy'), '2', '28', '271', '09', '2083', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30588, to_date('29-09-2083', 'dd-mm-yyyy'), '3', '29', '272', '09', '2083', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30589, to_date('30-09-2083', 'dd-mm-yyyy'), '4', '30', '273', '09', '2083', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30590, to_date('01-10-2083', 'dd-mm-yyyy'), '5', '01', '274', '10', '2083', '39', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30591, to_date('02-10-2083', 'dd-mm-yyyy'), '6', '02', '275', '10', '2083', '39', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30592, to_date('03-10-2083', 'dd-mm-yyyy'), '7', '03', '276', '10', '2083', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30593, to_date('04-10-2083', 'dd-mm-yyyy'), '1', '04', '277', '10', '2083', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30594, to_date('05-10-2083', 'dd-mm-yyyy'), '2', '05', '278', '10', '2083', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30595, to_date('06-10-2083', 'dd-mm-yyyy'), '3', '06', '279', '10', '2083', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30596, to_date('07-10-2083', 'dd-mm-yyyy'), '4', '07', '280', '10', '2083', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30597, to_date('08-10-2083', 'dd-mm-yyyy'), '5', '08', '281', '10', '2083', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30598, to_date('09-10-2083', 'dd-mm-yyyy'), '6', '09', '282', '10', '2083', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30599, to_date('10-10-2083', 'dd-mm-yyyy'), '7', '10', '283', '10', '2083', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30600, to_date('11-10-2083', 'dd-mm-yyyy'), '1', '11', '284', '10', '2083', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30601, to_date('12-10-2083', 'dd-mm-yyyy'), '2', '12', '285', '10', '2083', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30602, to_date('13-10-2083', 'dd-mm-yyyy'), '3', '13', '286', '10', '2083', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30603, to_date('14-10-2083', 'dd-mm-yyyy'), '4', '14', '287', '10', '2083', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30604, to_date('15-10-2083', 'dd-mm-yyyy'), '5', '15', '288', '10', '2083', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30605, to_date('16-10-2083', 'dd-mm-yyyy'), '6', '16', '289', '10', '2083', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30606, to_date('17-10-2083', 'dd-mm-yyyy'), '7', '17', '290', '10', '2083', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30607, to_date('18-10-2083', 'dd-mm-yyyy'), '1', '18', '291', '10', '2083', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30608, to_date('19-10-2083', 'dd-mm-yyyy'), '2', '19', '292', '10', '2083', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32093, to_date('12-11-2087', 'dd-mm-yyyy'), '3', '12', '316', '11', '2087', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32094, to_date('13-11-2087', 'dd-mm-yyyy'), '4', '13', '317', '11', '2087', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32095, to_date('14-11-2087', 'dd-mm-yyyy'), '5', '14', '318', '11', '2087', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32096, to_date('15-11-2087', 'dd-mm-yyyy'), '6', '15', '319', '11', '2087', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32097, to_date('16-11-2087', 'dd-mm-yyyy'), '7', '16', '320', '11', '2087', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32098, to_date('17-11-2087', 'dd-mm-yyyy'), '1', '17', '321', '11', '2087', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32099, to_date('18-11-2087', 'dd-mm-yyyy'), '2', '18', '322', '11', '2087', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32100, to_date('19-11-2087', 'dd-mm-yyyy'), '3', '19', '323', '11', '2087', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32101, to_date('20-11-2087', 'dd-mm-yyyy'), '4', '20', '324', '11', '2087', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32102, to_date('21-11-2087', 'dd-mm-yyyy'), '5', '21', '325', '11', '2087', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32103, to_date('22-11-2087', 'dd-mm-yyyy'), '6', '22', '326', '11', '2087', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32104, to_date('23-11-2087', 'dd-mm-yyyy'), '7', '23', '327', '11', '2087', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32105, to_date('24-11-2087', 'dd-mm-yyyy'), '1', '24', '328', '11', '2087', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32106, to_date('25-11-2087', 'dd-mm-yyyy'), '2', '25', '329', '11', '2087', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32107, to_date('26-11-2087', 'dd-mm-yyyy'), '3', '26', '330', '11', '2087', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32108, to_date('27-11-2087', 'dd-mm-yyyy'), '4', '27', '331', '11', '2087', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32109, to_date('28-11-2087', 'dd-mm-yyyy'), '5', '28', '332', '11', '2087', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32110, to_date('29-11-2087', 'dd-mm-yyyy'), '6', '29', '333', '11', '2087', '48', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32111, to_date('30-11-2087', 'dd-mm-yyyy'), '7', '30', '334', '11', '2087', '48', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32112, to_date('01-12-2087', 'dd-mm-yyyy'), '1', '01', '335', '12', '2087', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32113, to_date('02-12-2087', 'dd-mm-yyyy'), '2', '02', '336', '12', '2087', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32114, to_date('03-12-2087', 'dd-mm-yyyy'), '3', '03', '337', '12', '2087', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32115, to_date('04-12-2087', 'dd-mm-yyyy'), '4', '04', '338', '12', '2087', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32116, to_date('05-12-2087', 'dd-mm-yyyy'), '5', '05', '339', '12', '2087', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32117, to_date('06-12-2087', 'dd-mm-yyyy'), '6', '06', '340', '12', '2087', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32118, to_date('07-12-2087', 'dd-mm-yyyy'), '7', '07', '341', '12', '2087', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32119, to_date('08-12-2087', 'dd-mm-yyyy'), '1', '08', '342', '12', '2087', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32120, to_date('09-12-2087', 'dd-mm-yyyy'), '2', '09', '343', '12', '2087', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32121, to_date('10-12-2087', 'dd-mm-yyyy'), '3', '10', '344', '12', '2087', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32122, to_date('11-12-2087', 'dd-mm-yyyy'), '4', '11', '345', '12', '2087', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32123, to_date('12-12-2087', 'dd-mm-yyyy'), '5', '12', '346', '12', '2087', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32124, to_date('13-12-2087', 'dd-mm-yyyy'), '6', '13', '347', '12', '2087', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32125, to_date('14-12-2087', 'dd-mm-yyyy'), '7', '14', '348', '12', '2087', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32126, to_date('15-12-2087', 'dd-mm-yyyy'), '1', '15', '349', '12', '2087', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32127, to_date('16-12-2087', 'dd-mm-yyyy'), '2', '16', '350', '12', '2087', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32128, to_date('17-12-2087', 'dd-mm-yyyy'), '3', '17', '351', '12', '2087', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32129, to_date('18-12-2087', 'dd-mm-yyyy'), '4', '18', '352', '12', '2087', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32130, to_date('19-12-2087', 'dd-mm-yyyy'), '5', '19', '353', '12', '2087', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32131, to_date('20-12-2087', 'dd-mm-yyyy'), '6', '20', '354', '12', '2087', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32132, to_date('21-12-2087', 'dd-mm-yyyy'), '7', '21', '355', '12', '2087', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32133, to_date('22-12-2087', 'dd-mm-yyyy'), '1', '22', '356', '12', '2087', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32134, to_date('23-12-2087', 'dd-mm-yyyy'), '2', '23', '357', '12', '2087', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32135, to_date('24-12-2087', 'dd-mm-yyyy'), '3', '24', '358', '12', '2087', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32136, to_date('25-12-2087', 'dd-mm-yyyy'), '4', '25', '359', '12', '2087', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32137, to_date('26-12-2087', 'dd-mm-yyyy'), '5', '26', '360', '12', '2087', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32138, to_date('27-12-2087', 'dd-mm-yyyy'), '6', '27', '361', '12', '2087', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32139, to_date('28-12-2087', 'dd-mm-yyyy'), '7', '28', '362', '12', '2087', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32140, to_date('29-12-2087', 'dd-mm-yyyy'), '1', '29', '363', '12', '2087', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32141, to_date('30-12-2087', 'dd-mm-yyyy'), '2', '30', '364', '12', '2087', '01', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32142, to_date('31-12-2087', 'dd-mm-yyyy'), '3', '31', '365', '12', '2087', '01', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32143, to_date('01-01-2088', 'dd-mm-yyyy'), '4', '01', '001', '01', '2088', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32144, to_date('02-01-2088', 'dd-mm-yyyy'), '5', '02', '002', '01', '2088', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32145, to_date('03-01-2088', 'dd-mm-yyyy'), '6', '03', '003', '01', '2088', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32146, to_date('04-01-2088', 'dd-mm-yyyy'), '7', '04', '004', '01', '2088', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32147, to_date('05-01-2088', 'dd-mm-yyyy'), '1', '05', '005', '01', '2088', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32148, to_date('06-01-2088', 'dd-mm-yyyy'), '2', '06', '006', '01', '2088', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32149, to_date('07-01-2088', 'dd-mm-yyyy'), '3', '07', '007', '01', '2088', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32150, to_date('08-01-2088', 'dd-mm-yyyy'), '4', '08', '008', '01', '2088', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32151, to_date('09-01-2088', 'dd-mm-yyyy'), '5', '09', '009', '01', '2088', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32152, to_date('10-01-2088', 'dd-mm-yyyy'), '6', '10', '010', '01', '2088', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32153, to_date('11-01-2088', 'dd-mm-yyyy'), '7', '11', '011', '01', '2088', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32154, to_date('12-01-2088', 'dd-mm-yyyy'), '1', '12', '012', '01', '2088', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32155, to_date('13-01-2088', 'dd-mm-yyyy'), '2', '13', '013', '01', '2088', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32156, to_date('14-01-2088', 'dd-mm-yyyy'), '3', '14', '014', '01', '2088', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32157, to_date('15-01-2088', 'dd-mm-yyyy'), '4', '15', '015', '01', '2088', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32158, to_date('16-01-2088', 'dd-mm-yyyy'), '5', '16', '016', '01', '2088', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32159, to_date('17-01-2088', 'dd-mm-yyyy'), '6', '17', '017', '01', '2088', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32160, to_date('18-01-2088', 'dd-mm-yyyy'), '7', '18', '018', '01', '2088', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32161, to_date('19-01-2088', 'dd-mm-yyyy'), '1', '19', '019', '01', '2088', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32162, to_date('20-01-2088', 'dd-mm-yyyy'), '2', '20', '020', '01', '2088', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32163, to_date('21-01-2088', 'dd-mm-yyyy'), '3', '21', '021', '01', '2088', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32164, to_date('22-01-2088', 'dd-mm-yyyy'), '4', '22', '022', '01', '2088', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32165, to_date('23-01-2088', 'dd-mm-yyyy'), '5', '23', '023', '01', '2088', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32166, to_date('24-01-2088', 'dd-mm-yyyy'), '6', '24', '024', '01', '2088', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32167, to_date('25-01-2088', 'dd-mm-yyyy'), '7', '25', '025', '01', '2088', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32168, to_date('26-01-2088', 'dd-mm-yyyy'), '1', '26', '026', '01', '2088', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32169, to_date('27-01-2088', 'dd-mm-yyyy'), '2', '27', '027', '01', '2088', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32170, to_date('28-01-2088', 'dd-mm-yyyy'), '3', '28', '028', '01', '2088', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32171, to_date('29-01-2088', 'dd-mm-yyyy'), '4', '29', '029', '01', '2088', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32172, to_date('30-01-2088', 'dd-mm-yyyy'), '5', '30', '030', '01', '2088', '05', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32173, to_date('31-01-2088', 'dd-mm-yyyy'), '6', '31', '031', '01', '2088', '05', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32174, to_date('01-02-2088', 'dd-mm-yyyy'), '7', '01', '032', '02', '2088', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32175, to_date('02-02-2088', 'dd-mm-yyyy'), '1', '02', '033', '02', '2088', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32176, to_date('03-02-2088', 'dd-mm-yyyy'), '2', '03', '034', '02', '2088', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32177, to_date('04-02-2088', 'dd-mm-yyyy'), '3', '04', '035', '02', '2088', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32178, to_date('05-02-2088', 'dd-mm-yyyy'), '4', '05', '036', '02', '2088', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32179, to_date('06-02-2088', 'dd-mm-yyyy'), '5', '06', '037', '02', '2088', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32180, to_date('07-02-2088', 'dd-mm-yyyy'), '6', '07', '038', '02', '2088', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32181, to_date('08-02-2088', 'dd-mm-yyyy'), '7', '08', '039', '02', '2088', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32182, to_date('09-02-2088', 'dd-mm-yyyy'), '1', '09', '040', '02', '2088', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32183, to_date('10-02-2088', 'dd-mm-yyyy'), '2', '10', '041', '02', '2088', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32184, to_date('11-02-2088', 'dd-mm-yyyy'), '3', '11', '042', '02', '2088', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32185, to_date('12-02-2088', 'dd-mm-yyyy'), '4', '12', '043', '02', '2088', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32186, to_date('13-02-2088', 'dd-mm-yyyy'), '5', '13', '044', '02', '2088', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32187, to_date('14-02-2088', 'dd-mm-yyyy'), '6', '14', '045', '02', '2088', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32188, to_date('15-02-2088', 'dd-mm-yyyy'), '7', '15', '046', '02', '2088', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32189, to_date('16-02-2088', 'dd-mm-yyyy'), '1', '16', '047', '02', '2088', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32190, to_date('17-02-2088', 'dd-mm-yyyy'), '2', '17', '048', '02', '2088', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32191, to_date('18-02-2088', 'dd-mm-yyyy'), '3', '18', '049', '02', '2088', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32192, to_date('19-02-2088', 'dd-mm-yyyy'), '4', '19', '050', '02', '2088', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32193, to_date('20-02-2088', 'dd-mm-yyyy'), '5', '20', '051', '02', '2088', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32194, to_date('21-02-2088', 'dd-mm-yyyy'), '6', '21', '052', '02', '2088', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32195, to_date('22-02-2088', 'dd-mm-yyyy'), '7', '22', '053', '02', '2088', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32196, to_date('23-02-2088', 'dd-mm-yyyy'), '1', '23', '054', '02', '2088', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32197, to_date('24-02-2088', 'dd-mm-yyyy'), '2', '24', '055', '02', '2088', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32198, to_date('25-02-2088', 'dd-mm-yyyy'), '3', '25', '056', '02', '2088', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27323, to_date('21-10-2074', 'dd-mm-yyyy'), '7', '21', '294', '10', '2074', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27324, to_date('22-10-2074', 'dd-mm-yyyy'), '1', '22', '295', '10', '2074', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27325, to_date('23-10-2074', 'dd-mm-yyyy'), '2', '23', '296', '10', '2074', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27326, to_date('24-10-2074', 'dd-mm-yyyy'), '3', '24', '297', '10', '2074', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27327, to_date('25-10-2074', 'dd-mm-yyyy'), '4', '25', '298', '10', '2074', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27328, to_date('26-10-2074', 'dd-mm-yyyy'), '5', '26', '299', '10', '2074', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27329, to_date('27-10-2074', 'dd-mm-yyyy'), '6', '27', '300', '10', '2074', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27330, to_date('28-10-2074', 'dd-mm-yyyy'), '7', '28', '301', '10', '2074', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27331, to_date('29-10-2074', 'dd-mm-yyyy'), '1', '29', '302', '10', '2074', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27332, to_date('30-10-2074', 'dd-mm-yyyy'), '2', '30', '303', '10', '2074', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27333, to_date('31-10-2074', 'dd-mm-yyyy'), '3', '31', '304', '10', '2074', '44', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27334, to_date('01-11-2074', 'dd-mm-yyyy'), '4', '01', '305', '11', '2074', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27335, to_date('02-11-2074', 'dd-mm-yyyy'), '5', '02', '306', '11', '2074', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27336, to_date('03-11-2074', 'dd-mm-yyyy'), '6', '03', '307', '11', '2074', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27337, to_date('04-11-2074', 'dd-mm-yyyy'), '7', '04', '308', '11', '2074', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27338, to_date('05-11-2074', 'dd-mm-yyyy'), '1', '05', '309', '11', '2074', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27339, to_date('06-11-2074', 'dd-mm-yyyy'), '2', '06', '310', '11', '2074', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27340, to_date('07-11-2074', 'dd-mm-yyyy'), '3', '07', '311', '11', '2074', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27341, to_date('08-11-2074', 'dd-mm-yyyy'), '4', '08', '312', '11', '2074', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27342, to_date('09-11-2074', 'dd-mm-yyyy'), '5', '09', '313', '11', '2074', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27343, to_date('10-11-2074', 'dd-mm-yyyy'), '6', '10', '314', '11', '2074', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27344, to_date('11-11-2074', 'dd-mm-yyyy'), '7', '11', '315', '11', '2074', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27345, to_date('12-11-2074', 'dd-mm-yyyy'), '1', '12', '316', '11', '2074', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27346, to_date('13-11-2074', 'dd-mm-yyyy'), '2', '13', '317', '11', '2074', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27347, to_date('14-11-2074', 'dd-mm-yyyy'), '3', '14', '318', '11', '2074', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27348, to_date('15-11-2074', 'dd-mm-yyyy'), '4', '15', '319', '11', '2074', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27349, to_date('16-11-2074', 'dd-mm-yyyy'), '5', '16', '320', '11', '2074', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27350, to_date('17-11-2074', 'dd-mm-yyyy'), '6', '17', '321', '11', '2074', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27351, to_date('18-11-2074', 'dd-mm-yyyy'), '7', '18', '322', '11', '2074', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27352, to_date('19-11-2074', 'dd-mm-yyyy'), '1', '19', '323', '11', '2074', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27353, to_date('20-11-2074', 'dd-mm-yyyy'), '2', '20', '324', '11', '2074', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27354, to_date('21-11-2074', 'dd-mm-yyyy'), '3', '21', '325', '11', '2074', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27355, to_date('22-11-2074', 'dd-mm-yyyy'), '4', '22', '326', '11', '2074', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27356, to_date('23-11-2074', 'dd-mm-yyyy'), '5', '23', '327', '11', '2074', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27357, to_date('24-11-2074', 'dd-mm-yyyy'), '6', '24', '328', '11', '2074', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27358, to_date('25-11-2074', 'dd-mm-yyyy'), '7', '25', '329', '11', '2074', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27359, to_date('26-11-2074', 'dd-mm-yyyy'), '1', '26', '330', '11', '2074', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27360, to_date('27-11-2074', 'dd-mm-yyyy'), '2', '27', '331', '11', '2074', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27361, to_date('28-11-2074', 'dd-mm-yyyy'), '3', '28', '332', '11', '2074', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27362, to_date('29-11-2074', 'dd-mm-yyyy'), '4', '29', '333', '11', '2074', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27363, to_date('30-11-2074', 'dd-mm-yyyy'), '5', '30', '334', '11', '2074', '48', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27364, to_date('01-12-2074', 'dd-mm-yyyy'), '6', '01', '335', '12', '2074', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27365, to_date('02-12-2074', 'dd-mm-yyyy'), '7', '02', '336', '12', '2074', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27366, to_date('03-12-2074', 'dd-mm-yyyy'), '1', '03', '337', '12', '2074', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27367, to_date('04-12-2074', 'dd-mm-yyyy'), '2', '04', '338', '12', '2074', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27368, to_date('05-12-2074', 'dd-mm-yyyy'), '3', '05', '339', '12', '2074', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27369, to_date('06-12-2074', 'dd-mm-yyyy'), '4', '06', '340', '12', '2074', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27370, to_date('07-12-2074', 'dd-mm-yyyy'), '5', '07', '341', '12', '2074', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27371, to_date('08-12-2074', 'dd-mm-yyyy'), '6', '08', '342', '12', '2074', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27372, to_date('09-12-2074', 'dd-mm-yyyy'), '7', '09', '343', '12', '2074', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27373, to_date('10-12-2074', 'dd-mm-yyyy'), '1', '10', '344', '12', '2074', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27374, to_date('11-12-2074', 'dd-mm-yyyy'), '2', '11', '345', '12', '2074', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27375, to_date('12-12-2074', 'dd-mm-yyyy'), '3', '12', '346', '12', '2074', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27376, to_date('13-12-2074', 'dd-mm-yyyy'), '4', '13', '347', '12', '2074', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27377, to_date('14-12-2074', 'dd-mm-yyyy'), '5', '14', '348', '12', '2074', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27378, to_date('15-12-2074', 'dd-mm-yyyy'), '6', '15', '349', '12', '2074', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27379, to_date('16-12-2074', 'dd-mm-yyyy'), '7', '16', '350', '12', '2074', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27380, to_date('17-12-2074', 'dd-mm-yyyy'), '1', '17', '351', '12', '2074', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27381, to_date('18-12-2074', 'dd-mm-yyyy'), '2', '18', '352', '12', '2074', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27382, to_date('19-12-2074', 'dd-mm-yyyy'), '3', '19', '353', '12', '2074', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27383, to_date('20-12-2074', 'dd-mm-yyyy'), '4', '20', '354', '12', '2074', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27384, to_date('21-12-2074', 'dd-mm-yyyy'), '5', '21', '355', '12', '2074', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27385, to_date('22-12-2074', 'dd-mm-yyyy'), '6', '22', '356', '12', '2074', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27386, to_date('23-12-2074', 'dd-mm-yyyy'), '7', '23', '357', '12', '2074', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27387, to_date('24-12-2074', 'dd-mm-yyyy'), '1', '24', '358', '12', '2074', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27388, to_date('25-12-2074', 'dd-mm-yyyy'), '2', '25', '359', '12', '2074', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27389, to_date('26-12-2074', 'dd-mm-yyyy'), '3', '26', '360', '12', '2074', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27390, to_date('27-12-2074', 'dd-mm-yyyy'), '4', '27', '361', '12', '2074', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27391, to_date('28-12-2074', 'dd-mm-yyyy'), '5', '28', '362', '12', '2074', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27392, to_date('29-12-2074', 'dd-mm-yyyy'), '6', '29', '363', '12', '2074', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27393, to_date('30-12-2074', 'dd-mm-yyyy'), '7', '30', '364', '12', '2074', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27394, to_date('31-12-2074', 'dd-mm-yyyy'), '1', '31', '365', '12', '2074', '01', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27395, to_date('01-01-2075', 'dd-mm-yyyy'), '2', '01', '001', '01', '2075', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27396, to_date('02-01-2075', 'dd-mm-yyyy'), '3', '02', '002', '01', '2075', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27397, to_date('03-01-2075', 'dd-mm-yyyy'), '4', '03', '003', '01', '2075', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27398, to_date('04-01-2075', 'dd-mm-yyyy'), '5', '04', '004', '01', '2075', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27399, to_date('05-01-2075', 'dd-mm-yyyy'), '6', '05', '005', '01', '2075', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27400, to_date('06-01-2075', 'dd-mm-yyyy'), '7', '06', '006', '01', '2075', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27401, to_date('07-01-2075', 'dd-mm-yyyy'), '1', '07', '007', '01', '2075', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27402, to_date('08-01-2075', 'dd-mm-yyyy'), '2', '08', '008', '01', '2075', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27403, to_date('09-01-2075', 'dd-mm-yyyy'), '3', '09', '009', '01', '2075', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27404, to_date('10-01-2075', 'dd-mm-yyyy'), '4', '10', '010', '01', '2075', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27405, to_date('11-01-2075', 'dd-mm-yyyy'), '5', '11', '011', '01', '2075', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27406, to_date('12-01-2075', 'dd-mm-yyyy'), '6', '12', '012', '01', '2075', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27407, to_date('13-01-2075', 'dd-mm-yyyy'), '7', '13', '013', '01', '2075', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27408, to_date('14-01-2075', 'dd-mm-yyyy'), '1', '14', '014', '01', '2075', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27409, to_date('15-01-2075', 'dd-mm-yyyy'), '2', '15', '015', '01', '2075', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27410, to_date('16-01-2075', 'dd-mm-yyyy'), '3', '16', '016', '01', '2075', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27411, to_date('17-01-2075', 'dd-mm-yyyy'), '4', '17', '017', '01', '2075', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27412, to_date('18-01-2075', 'dd-mm-yyyy'), '5', '18', '018', '01', '2075', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27413, to_date('19-01-2075', 'dd-mm-yyyy'), '6', '19', '019', '01', '2075', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27414, to_date('20-01-2075', 'dd-mm-yyyy'), '7', '20', '020', '01', '2075', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27415, to_date('21-01-2075', 'dd-mm-yyyy'), '1', '21', '021', '01', '2075', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27416, to_date('22-01-2075', 'dd-mm-yyyy'), '2', '22', '022', '01', '2075', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27417, to_date('23-01-2075', 'dd-mm-yyyy'), '3', '23', '023', '01', '2075', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27418, to_date('24-01-2075', 'dd-mm-yyyy'), '4', '24', '024', '01', '2075', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27419, to_date('25-01-2075', 'dd-mm-yyyy'), '5', '25', '025', '01', '2075', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27420, to_date('26-01-2075', 'dd-mm-yyyy'), '6', '26', '026', '01', '2075', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27421, to_date('27-01-2075', 'dd-mm-yyyy'), '7', '27', '027', '01', '2075', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27422, to_date('28-01-2075', 'dd-mm-yyyy'), '1', '28', '028', '01', '2075', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27423, to_date('29-01-2075', 'dd-mm-yyyy'), '2', '29', '029', '01', '2075', '05', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27424, to_date('30-01-2075', 'dd-mm-yyyy'), '3', '30', '030', '01', '2075', '05', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27425, to_date('31-01-2075', 'dd-mm-yyyy'), '4', '31', '031', '01', '2075', '05', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27426, to_date('01-02-2075', 'dd-mm-yyyy'), '5', '01', '032', '02', '2075', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27427, to_date('02-02-2075', 'dd-mm-yyyy'), '6', '02', '033', '02', '2075', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27428, to_date('03-02-2075', 'dd-mm-yyyy'), '7', '03', '034', '02', '2075', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29019, to_date('13-06-2079', 'dd-mm-yyyy'), '2', '13', '164', '06', '2079', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29020, to_date('14-06-2079', 'dd-mm-yyyy'), '3', '14', '165', '06', '2079', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29021, to_date('15-06-2079', 'dd-mm-yyyy'), '4', '15', '166', '06', '2079', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29022, to_date('16-06-2079', 'dd-mm-yyyy'), '5', '16', '167', '06', '2079', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29023, to_date('17-06-2079', 'dd-mm-yyyy'), '6', '17', '168', '06', '2079', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29024, to_date('18-06-2079', 'dd-mm-yyyy'), '7', '18', '169', '06', '2079', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29025, to_date('19-06-2079', 'dd-mm-yyyy'), '1', '19', '170', '06', '2079', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29026, to_date('20-06-2079', 'dd-mm-yyyy'), '2', '20', '171', '06', '2079', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29027, to_date('21-06-2079', 'dd-mm-yyyy'), '3', '21', '172', '06', '2079', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29028, to_date('22-06-2079', 'dd-mm-yyyy'), '4', '22', '173', '06', '2079', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29029, to_date('23-06-2079', 'dd-mm-yyyy'), '5', '23', '174', '06', '2079', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29030, to_date('24-06-2079', 'dd-mm-yyyy'), '6', '24', '175', '06', '2079', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29031, to_date('25-06-2079', 'dd-mm-yyyy'), '7', '25', '176', '06', '2079', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29032, to_date('26-06-2079', 'dd-mm-yyyy'), '1', '26', '177', '06', '2079', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29033, to_date('27-06-2079', 'dd-mm-yyyy'), '2', '27', '178', '06', '2079', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29034, to_date('28-06-2079', 'dd-mm-yyyy'), '3', '28', '179', '06', '2079', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29035, to_date('29-06-2079', 'dd-mm-yyyy'), '4', '29', '180', '06', '2079', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29036, to_date('30-06-2079', 'dd-mm-yyyy'), '5', '30', '181', '06', '2079', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29037, to_date('01-07-2079', 'dd-mm-yyyy'), '6', '01', '182', '07', '2079', '26', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29038, to_date('02-07-2079', 'dd-mm-yyyy'), '7', '02', '183', '07', '2079', '26', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29039, to_date('03-07-2079', 'dd-mm-yyyy'), '1', '03', '184', '07', '2079', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29040, to_date('04-07-2079', 'dd-mm-yyyy'), '2', '04', '185', '07', '2079', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29041, to_date('05-07-2079', 'dd-mm-yyyy'), '3', '05', '186', '07', '2079', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29042, to_date('06-07-2079', 'dd-mm-yyyy'), '4', '06', '187', '07', '2079', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29043, to_date('07-07-2079', 'dd-mm-yyyy'), '5', '07', '188', '07', '2079', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29044, to_date('08-07-2079', 'dd-mm-yyyy'), '6', '08', '189', '07', '2079', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29045, to_date('09-07-2079', 'dd-mm-yyyy'), '7', '09', '190', '07', '2079', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29046, to_date('10-07-2079', 'dd-mm-yyyy'), '1', '10', '191', '07', '2079', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29047, to_date('11-07-2079', 'dd-mm-yyyy'), '2', '11', '192', '07', '2079', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29048, to_date('12-07-2079', 'dd-mm-yyyy'), '3', '12', '193', '07', '2079', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29049, to_date('13-07-2079', 'dd-mm-yyyy'), '4', '13', '194', '07', '2079', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29050, to_date('14-07-2079', 'dd-mm-yyyy'), '5', '14', '195', '07', '2079', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29051, to_date('15-07-2079', 'dd-mm-yyyy'), '6', '15', '196', '07', '2079', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29052, to_date('16-07-2079', 'dd-mm-yyyy'), '7', '16', '197', '07', '2079', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29053, to_date('17-07-2079', 'dd-mm-yyyy'), '1', '17', '198', '07', '2079', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29054, to_date('18-07-2079', 'dd-mm-yyyy'), '2', '18', '199', '07', '2079', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29055, to_date('19-07-2079', 'dd-mm-yyyy'), '3', '19', '200', '07', '2079', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29056, to_date('20-07-2079', 'dd-mm-yyyy'), '4', '20', '201', '07', '2079', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29057, to_date('21-07-2079', 'dd-mm-yyyy'), '5', '21', '202', '07', '2079', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29058, to_date('22-07-2079', 'dd-mm-yyyy'), '6', '22', '203', '07', '2079', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29059, to_date('23-07-2079', 'dd-mm-yyyy'), '7', '23', '204', '07', '2079', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29060, to_date('24-07-2079', 'dd-mm-yyyy'), '1', '24', '205', '07', '2079', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29061, to_date('25-07-2079', 'dd-mm-yyyy'), '2', '25', '206', '07', '2079', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29062, to_date('26-07-2079', 'dd-mm-yyyy'), '3', '26', '207', '07', '2079', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29063, to_date('27-07-2079', 'dd-mm-yyyy'), '4', '27', '208', '07', '2079', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29064, to_date('28-07-2079', 'dd-mm-yyyy'), '5', '28', '209', '07', '2079', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29065, to_date('29-07-2079', 'dd-mm-yyyy'), '6', '29', '210', '07', '2079', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29066, to_date('30-07-2079', 'dd-mm-yyyy'), '7', '30', '211', '07', '2079', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29067, to_date('31-07-2079', 'dd-mm-yyyy'), '1', '31', '212', '07', '2079', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29068, to_date('01-08-2079', 'dd-mm-yyyy'), '2', '01', '213', '08', '2079', '31', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29069, to_date('02-08-2079', 'dd-mm-yyyy'), '3', '02', '214', '08', '2079', '31', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29070, to_date('03-08-2079', 'dd-mm-yyyy'), '4', '03', '215', '08', '2079', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29071, to_date('04-08-2079', 'dd-mm-yyyy'), '5', '04', '216', '08', '2079', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29072, to_date('05-08-2079', 'dd-mm-yyyy'), '6', '05', '217', '08', '2079', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29073, to_date('06-08-2079', 'dd-mm-yyyy'), '7', '06', '218', '08', '2079', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29074, to_date('07-08-2079', 'dd-mm-yyyy'), '1', '07', '219', '08', '2079', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29075, to_date('08-08-2079', 'dd-mm-yyyy'), '2', '08', '220', '08', '2079', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29076, to_date('09-08-2079', 'dd-mm-yyyy'), '3', '09', '221', '08', '2079', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29077, to_date('10-08-2079', 'dd-mm-yyyy'), '4', '10', '222', '08', '2079', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29078, to_date('11-08-2079', 'dd-mm-yyyy'), '5', '11', '223', '08', '2079', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29079, to_date('12-08-2079', 'dd-mm-yyyy'), '6', '12', '224', '08', '2079', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29080, to_date('13-08-2079', 'dd-mm-yyyy'), '7', '13', '225', '08', '2079', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29081, to_date('14-08-2079', 'dd-mm-yyyy'), '1', '14', '226', '08', '2079', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29082, to_date('15-08-2079', 'dd-mm-yyyy'), '2', '15', '227', '08', '2079', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29083, to_date('16-08-2079', 'dd-mm-yyyy'), '3', '16', '228', '08', '2079', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29084, to_date('17-08-2079', 'dd-mm-yyyy'), '4', '17', '229', '08', '2079', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29085, to_date('18-08-2079', 'dd-mm-yyyy'), '5', '18', '230', '08', '2079', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29086, to_date('19-08-2079', 'dd-mm-yyyy'), '6', '19', '231', '08', '2079', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29087, to_date('20-08-2079', 'dd-mm-yyyy'), '7', '20', '232', '08', '2079', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29088, to_date('21-08-2079', 'dd-mm-yyyy'), '1', '21', '233', '08', '2079', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29089, to_date('22-08-2079', 'dd-mm-yyyy'), '2', '22', '234', '08', '2079', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29090, to_date('23-08-2079', 'dd-mm-yyyy'), '3', '23', '235', '08', '2079', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29091, to_date('24-08-2079', 'dd-mm-yyyy'), '4', '24', '236', '08', '2079', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29092, to_date('25-08-2079', 'dd-mm-yyyy'), '5', '25', '237', '08', '2079', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29093, to_date('26-08-2079', 'dd-mm-yyyy'), '6', '26', '238', '08', '2079', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29094, to_date('27-08-2079', 'dd-mm-yyyy'), '7', '27', '239', '08', '2079', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29095, to_date('28-08-2079', 'dd-mm-yyyy'), '1', '28', '240', '08', '2079', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29096, to_date('29-08-2079', 'dd-mm-yyyy'), '2', '29', '241', '08', '2079', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29097, to_date('30-08-2079', 'dd-mm-yyyy'), '3', '30', '242', '08', '2079', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29098, to_date('31-08-2079', 'dd-mm-yyyy'), '4', '31', '243', '08', '2079', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29099, to_date('01-09-2079', 'dd-mm-yyyy'), '5', '01', '244', '09', '2079', '35', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29100, to_date('02-09-2079', 'dd-mm-yyyy'), '6', '02', '245', '09', '2079', '35', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29101, to_date('03-09-2079', 'dd-mm-yyyy'), '7', '03', '246', '09', '2079', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29102, to_date('04-09-2079', 'dd-mm-yyyy'), '1', '04', '247', '09', '2079', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29103, to_date('05-09-2079', 'dd-mm-yyyy'), '2', '05', '248', '09', '2079', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29104, to_date('06-09-2079', 'dd-mm-yyyy'), '3', '06', '249', '09', '2079', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29105, to_date('07-09-2079', 'dd-mm-yyyy'), '4', '07', '250', '09', '2079', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29106, to_date('08-09-2079', 'dd-mm-yyyy'), '5', '08', '251', '09', '2079', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29107, to_date('09-09-2079', 'dd-mm-yyyy'), '6', '09', '252', '09', '2079', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29108, to_date('10-09-2079', 'dd-mm-yyyy'), '7', '10', '253', '09', '2079', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29109, to_date('11-09-2079', 'dd-mm-yyyy'), '1', '11', '254', '09', '2079', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29110, to_date('12-09-2079', 'dd-mm-yyyy'), '2', '12', '255', '09', '2079', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29111, to_date('13-09-2079', 'dd-mm-yyyy'), '3', '13', '256', '09', '2079', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29112, to_date('14-09-2079', 'dd-mm-yyyy'), '4', '14', '257', '09', '2079', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29113, to_date('15-09-2079', 'dd-mm-yyyy'), '5', '15', '258', '09', '2079', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29114, to_date('16-09-2079', 'dd-mm-yyyy'), '6', '16', '259', '09', '2079', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29115, to_date('17-09-2079', 'dd-mm-yyyy'), '7', '17', '260', '09', '2079', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29116, to_date('18-09-2079', 'dd-mm-yyyy'), '1', '18', '261', '09', '2079', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29117, to_date('19-09-2079', 'dd-mm-yyyy'), '2', '19', '262', '09', '2079', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29118, to_date('20-09-2079', 'dd-mm-yyyy'), '3', '20', '263', '09', '2079', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29119, to_date('21-09-2079', 'dd-mm-yyyy'), '4', '21', '264', '09', '2079', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29120, to_date('22-09-2079', 'dd-mm-yyyy'), '5', '22', '265', '09', '2079', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29121, to_date('23-09-2079', 'dd-mm-yyyy'), '6', '23', '266', '09', '2079', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29122, to_date('24-09-2079', 'dd-mm-yyyy'), '7', '24', '267', '09', '2079', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29123, to_date('25-09-2079', 'dd-mm-yyyy'), '1', '25', '268', '09', '2079', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29124, to_date('26-09-2079', 'dd-mm-yyyy'), '2', '26', '269', '09', '2079', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30609, to_date('20-10-2083', 'dd-mm-yyyy'), '3', '20', '293', '10', '2083', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30610, to_date('21-10-2083', 'dd-mm-yyyy'), '4', '21', '294', '10', '2083', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30611, to_date('22-10-2083', 'dd-mm-yyyy'), '5', '22', '295', '10', '2083', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30612, to_date('23-10-2083', 'dd-mm-yyyy'), '6', '23', '296', '10', '2083', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30613, to_date('24-10-2083', 'dd-mm-yyyy'), '7', '24', '297', '10', '2083', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30614, to_date('25-10-2083', 'dd-mm-yyyy'), '1', '25', '298', '10', '2083', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30615, to_date('26-10-2083', 'dd-mm-yyyy'), '2', '26', '299', '10', '2083', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30616, to_date('27-10-2083', 'dd-mm-yyyy'), '3', '27', '300', '10', '2083', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30617, to_date('28-10-2083', 'dd-mm-yyyy'), '4', '28', '301', '10', '2083', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30618, to_date('29-10-2083', 'dd-mm-yyyy'), '5', '29', '302', '10', '2083', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30619, to_date('30-10-2083', 'dd-mm-yyyy'), '6', '30', '303', '10', '2083', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30620, to_date('31-10-2083', 'dd-mm-yyyy'), '7', '31', '304', '10', '2083', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30621, to_date('01-11-2083', 'dd-mm-yyyy'), '1', '01', '305', '11', '2083', '44', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30622, to_date('02-11-2083', 'dd-mm-yyyy'), '2', '02', '306', '11', '2083', '44', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30623, to_date('03-11-2083', 'dd-mm-yyyy'), '3', '03', '307', '11', '2083', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30624, to_date('04-11-2083', 'dd-mm-yyyy'), '4', '04', '308', '11', '2083', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30625, to_date('05-11-2083', 'dd-mm-yyyy'), '5', '05', '309', '11', '2083', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30626, to_date('06-11-2083', 'dd-mm-yyyy'), '6', '06', '310', '11', '2083', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30627, to_date('07-11-2083', 'dd-mm-yyyy'), '7', '07', '311', '11', '2083', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30628, to_date('08-11-2083', 'dd-mm-yyyy'), '1', '08', '312', '11', '2083', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30629, to_date('09-11-2083', 'dd-mm-yyyy'), '2', '09', '313', '11', '2083', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30630, to_date('10-11-2083', 'dd-mm-yyyy'), '3', '10', '314', '11', '2083', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30631, to_date('11-11-2083', 'dd-mm-yyyy'), '4', '11', '315', '11', '2083', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30632, to_date('12-11-2083', 'dd-mm-yyyy'), '5', '12', '316', '11', '2083', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30633, to_date('13-11-2083', 'dd-mm-yyyy'), '6', '13', '317', '11', '2083', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30634, to_date('14-11-2083', 'dd-mm-yyyy'), '7', '14', '318', '11', '2083', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30635, to_date('15-11-2083', 'dd-mm-yyyy'), '1', '15', '319', '11', '2083', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30636, to_date('16-11-2083', 'dd-mm-yyyy'), '2', '16', '320', '11', '2083', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30637, to_date('17-11-2083', 'dd-mm-yyyy'), '3', '17', '321', '11', '2083', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30638, to_date('18-11-2083', 'dd-mm-yyyy'), '4', '18', '322', '11', '2083', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30639, to_date('19-11-2083', 'dd-mm-yyyy'), '5', '19', '323', '11', '2083', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30640, to_date('20-11-2083', 'dd-mm-yyyy'), '6', '20', '324', '11', '2083', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30641, to_date('21-11-2083', 'dd-mm-yyyy'), '7', '21', '325', '11', '2083', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30642, to_date('22-11-2083', 'dd-mm-yyyy'), '1', '22', '326', '11', '2083', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30643, to_date('23-11-2083', 'dd-mm-yyyy'), '2', '23', '327', '11', '2083', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30644, to_date('24-11-2083', 'dd-mm-yyyy'), '3', '24', '328', '11', '2083', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30645, to_date('25-11-2083', 'dd-mm-yyyy'), '4', '25', '329', '11', '2083', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30646, to_date('26-11-2083', 'dd-mm-yyyy'), '5', '26', '330', '11', '2083', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30647, to_date('27-11-2083', 'dd-mm-yyyy'), '6', '27', '331', '11', '2083', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30648, to_date('28-11-2083', 'dd-mm-yyyy'), '7', '28', '332', '11', '2083', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30649, to_date('29-11-2083', 'dd-mm-yyyy'), '1', '29', '333', '11', '2083', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30650, to_date('30-11-2083', 'dd-mm-yyyy'), '2', '30', '334', '11', '2083', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30651, to_date('01-12-2083', 'dd-mm-yyyy'), '3', '01', '335', '12', '2083', '48', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30652, to_date('02-12-2083', 'dd-mm-yyyy'), '4', '02', '336', '12', '2083', '48', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30653, to_date('03-12-2083', 'dd-mm-yyyy'), '5', '03', '337', '12', '2083', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30654, to_date('04-12-2083', 'dd-mm-yyyy'), '6', '04', '338', '12', '2083', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30655, to_date('05-12-2083', 'dd-mm-yyyy'), '7', '05', '339', '12', '2083', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30656, to_date('06-12-2083', 'dd-mm-yyyy'), '1', '06', '340', '12', '2083', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30657, to_date('07-12-2083', 'dd-mm-yyyy'), '2', '07', '341', '12', '2083', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30658, to_date('08-12-2083', 'dd-mm-yyyy'), '3', '08', '342', '12', '2083', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30659, to_date('09-12-2083', 'dd-mm-yyyy'), '4', '09', '343', '12', '2083', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30660, to_date('10-12-2083', 'dd-mm-yyyy'), '5', '10', '344', '12', '2083', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30661, to_date('11-12-2083', 'dd-mm-yyyy'), '6', '11', '345', '12', '2083', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30662, to_date('12-12-2083', 'dd-mm-yyyy'), '7', '12', '346', '12', '2083', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30663, to_date('13-12-2083', 'dd-mm-yyyy'), '1', '13', '347', '12', '2083', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30664, to_date('14-12-2083', 'dd-mm-yyyy'), '2', '14', '348', '12', '2083', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30665, to_date('15-12-2083', 'dd-mm-yyyy'), '3', '15', '349', '12', '2083', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30666, to_date('16-12-2083', 'dd-mm-yyyy'), '4', '16', '350', '12', '2083', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30667, to_date('17-12-2083', 'dd-mm-yyyy'), '5', '17', '351', '12', '2083', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30668, to_date('18-12-2083', 'dd-mm-yyyy'), '6', '18', '352', '12', '2083', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30669, to_date('19-12-2083', 'dd-mm-yyyy'), '7', '19', '353', '12', '2083', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30670, to_date('20-12-2083', 'dd-mm-yyyy'), '1', '20', '354', '12', '2083', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30671, to_date('21-12-2083', 'dd-mm-yyyy'), '2', '21', '355', '12', '2083', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30672, to_date('22-12-2083', 'dd-mm-yyyy'), '3', '22', '356', '12', '2083', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30673, to_date('23-12-2083', 'dd-mm-yyyy'), '4', '23', '357', '12', '2083', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30674, to_date('24-12-2083', 'dd-mm-yyyy'), '5', '24', '358', '12', '2083', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30675, to_date('25-12-2083', 'dd-mm-yyyy'), '6', '25', '359', '12', '2083', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30676, to_date('26-12-2083', 'dd-mm-yyyy'), '7', '26', '360', '12', '2083', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30677, to_date('27-12-2083', 'dd-mm-yyyy'), '1', '27', '361', '12', '2083', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30678, to_date('28-12-2083', 'dd-mm-yyyy'), '2', '28', '362', '12', '2083', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30679, to_date('29-12-2083', 'dd-mm-yyyy'), '3', '29', '363', '12', '2083', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30680, to_date('30-12-2083', 'dd-mm-yyyy'), '4', '30', '364', '12', '2083', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30681, to_date('31-12-2083', 'dd-mm-yyyy'), '5', '31', '365', '12', '2083', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30682, to_date('01-01-2084', 'dd-mm-yyyy'), '6', '01', '001', '01', '2084', '52', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30683, to_date('02-01-2084', 'dd-mm-yyyy'), '7', '02', '002', '01', '2084', '52', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30684, to_date('03-01-2084', 'dd-mm-yyyy'), '1', '03', '003', '01', '2084', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30685, to_date('04-01-2084', 'dd-mm-yyyy'), '2', '04', '004', '01', '2084', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30686, to_date('05-01-2084', 'dd-mm-yyyy'), '3', '05', '005', '01', '2084', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30687, to_date('06-01-2084', 'dd-mm-yyyy'), '4', '06', '006', '01', '2084', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30688, to_date('07-01-2084', 'dd-mm-yyyy'), '5', '07', '007', '01', '2084', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30689, to_date('08-01-2084', 'dd-mm-yyyy'), '6', '08', '008', '01', '2084', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30690, to_date('09-01-2084', 'dd-mm-yyyy'), '7', '09', '009', '01', '2084', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30691, to_date('10-01-2084', 'dd-mm-yyyy'), '1', '10', '010', '01', '2084', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30692, to_date('11-01-2084', 'dd-mm-yyyy'), '2', '11', '011', '01', '2084', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30693, to_date('12-01-2084', 'dd-mm-yyyy'), '3', '12', '012', '01', '2084', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30694, to_date('13-01-2084', 'dd-mm-yyyy'), '4', '13', '013', '01', '2084', '02', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30695, to_date('14-01-2084', 'dd-mm-yyyy'), '5', '14', '014', '01', '2084', '02', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30696, to_date('15-01-2084', 'dd-mm-yyyy'), '6', '15', '015', '01', '2084', '02', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30697, to_date('16-01-2084', 'dd-mm-yyyy'), '7', '16', '016', '01', '2084', '02', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30698, to_date('17-01-2084', 'dd-mm-yyyy'), '1', '17', '017', '01', '2084', '03', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30699, to_date('18-01-2084', 'dd-mm-yyyy'), '2', '18', '018', '01', '2084', '03', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30700, to_date('19-01-2084', 'dd-mm-yyyy'), '3', '19', '019', '01', '2084', '03', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30701, to_date('20-01-2084', 'dd-mm-yyyy'), '4', '20', '020', '01', '2084', '03', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30702, to_date('21-01-2084', 'dd-mm-yyyy'), '5', '21', '021', '01', '2084', '03', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30703, to_date('22-01-2084', 'dd-mm-yyyy'), '6', '22', '022', '01', '2084', '03', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30704, to_date('23-01-2084', 'dd-mm-yyyy'), '7', '23', '023', '01', '2084', '03', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30705, to_date('24-01-2084', 'dd-mm-yyyy'), '1', '24', '024', '01', '2084', '04', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30706, to_date('25-01-2084', 'dd-mm-yyyy'), '2', '25', '025', '01', '2084', '04', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30707, to_date('26-01-2084', 'dd-mm-yyyy'), '3', '26', '026', '01', '2084', '04', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30708, to_date('27-01-2084', 'dd-mm-yyyy'), '4', '27', '027', '01', '2084', '04', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30709, to_date('28-01-2084', 'dd-mm-yyyy'), '5', '28', '028', '01', '2084', '04', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30710, to_date('29-01-2084', 'dd-mm-yyyy'), '6', '29', '029', '01', '2084', '04', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30711, to_date('30-01-2084', 'dd-mm-yyyy'), '7', '30', '030', '01', '2084', '04', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30712, to_date('31-01-2084', 'dd-mm-yyyy'), '1', '31', '031', '01', '2084', '05', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30713, to_date('01-02-2084', 'dd-mm-yyyy'), '2', '01', '032', '02', '2084', '05', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30714, to_date('02-02-2084', 'dd-mm-yyyy'), '3', '02', '033', '02', '2084', '05', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32199, to_date('26-02-2088', 'dd-mm-yyyy'), '4', '26', '057', '02', '2088', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32200, to_date('27-02-2088', 'dd-mm-yyyy'), '5', '27', '058', '02', '2088', '09', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32201, to_date('28-02-2088', 'dd-mm-yyyy'), '6', '28', '059', '02', '2088', '09', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32202, to_date('29-02-2088', 'dd-mm-yyyy'), '7', '29', '060', '02', '2088', '09', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32203, to_date('01-03-2088', 'dd-mm-yyyy'), '1', '01', '061', '03', '2088', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32204, to_date('02-03-2088', 'dd-mm-yyyy'), '2', '02', '062', '03', '2088', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32205, to_date('03-03-2088', 'dd-mm-yyyy'), '3', '03', '063', '03', '2088', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32206, to_date('04-03-2088', 'dd-mm-yyyy'), '4', '04', '064', '03', '2088', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32207, to_date('05-03-2088', 'dd-mm-yyyy'), '5', '05', '065', '03', '2088', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32208, to_date('06-03-2088', 'dd-mm-yyyy'), '6', '06', '066', '03', '2088', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32209, to_date('07-03-2088', 'dd-mm-yyyy'), '7', '07', '067', '03', '2088', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32210, to_date('08-03-2088', 'dd-mm-yyyy'), '1', '08', '068', '03', '2088', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32211, to_date('09-03-2088', 'dd-mm-yyyy'), '2', '09', '069', '03', '2088', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32212, to_date('10-03-2088', 'dd-mm-yyyy'), '3', '10', '070', '03', '2088', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32213, to_date('11-03-2088', 'dd-mm-yyyy'), '4', '11', '071', '03', '2088', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32214, to_date('12-03-2088', 'dd-mm-yyyy'), '5', '12', '072', '03', '2088', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32215, to_date('13-03-2088', 'dd-mm-yyyy'), '6', '13', '073', '03', '2088', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32216, to_date('14-03-2088', 'dd-mm-yyyy'), '7', '14', '074', '03', '2088', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32217, to_date('15-03-2088', 'dd-mm-yyyy'), '1', '15', '075', '03', '2088', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32218, to_date('16-03-2088', 'dd-mm-yyyy'), '2', '16', '076', '03', '2088', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32219, to_date('17-03-2088', 'dd-mm-yyyy'), '3', '17', '077', '03', '2088', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32220, to_date('18-03-2088', 'dd-mm-yyyy'), '4', '18', '078', '03', '2088', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32221, to_date('19-03-2088', 'dd-mm-yyyy'), '5', '19', '079', '03', '2088', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32222, to_date('20-03-2088', 'dd-mm-yyyy'), '6', '20', '080', '03', '2088', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32223, to_date('21-03-2088', 'dd-mm-yyyy'), '7', '21', '081', '03', '2088', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32224, to_date('22-03-2088', 'dd-mm-yyyy'), '1', '22', '082', '03', '2088', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32225, to_date('23-03-2088', 'dd-mm-yyyy'), '2', '23', '083', '03', '2088', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32226, to_date('24-03-2088', 'dd-mm-yyyy'), '3', '24', '084', '03', '2088', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32227, to_date('25-03-2088', 'dd-mm-yyyy'), '4', '25', '085', '03', '2088', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32228, to_date('26-03-2088', 'dd-mm-yyyy'), '5', '26', '086', '03', '2088', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32229, to_date('27-03-2088', 'dd-mm-yyyy'), '6', '27', '087', '03', '2088', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32230, to_date('28-03-2088', 'dd-mm-yyyy'), '7', '28', '088', '03', '2088', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32231, to_date('29-03-2088', 'dd-mm-yyyy'), '1', '29', '089', '03', '2088', '14', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32232, to_date('30-03-2088', 'dd-mm-yyyy'), '2', '30', '090', '03', '2088', '14', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32233, to_date('31-03-2088', 'dd-mm-yyyy'), '3', '31', '091', '03', '2088', '14', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32234, to_date('01-04-2088', 'dd-mm-yyyy'), '4', '01', '092', '04', '2088', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32235, to_date('02-04-2088', 'dd-mm-yyyy'), '5', '02', '093', '04', '2088', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32236, to_date('03-04-2088', 'dd-mm-yyyy'), '6', '03', '094', '04', '2088', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32237, to_date('04-04-2088', 'dd-mm-yyyy'), '7', '04', '095', '04', '2088', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32238, to_date('05-04-2088', 'dd-mm-yyyy'), '1', '05', '096', '04', '2088', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32239, to_date('06-04-2088', 'dd-mm-yyyy'), '2', '06', '097', '04', '2088', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32240, to_date('07-04-2088', 'dd-mm-yyyy'), '3', '07', '098', '04', '2088', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32241, to_date('08-04-2088', 'dd-mm-yyyy'), '4', '08', '099', '04', '2088', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32242, to_date('09-04-2088', 'dd-mm-yyyy'), '5', '09', '100', '04', '2088', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32243, to_date('10-04-2088', 'dd-mm-yyyy'), '6', '10', '101', '04', '2088', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32244, to_date('11-04-2088', 'dd-mm-yyyy'), '7', '11', '102', '04', '2088', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32245, to_date('12-04-2088', 'dd-mm-yyyy'), '1', '12', '103', '04', '2088', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32246, to_date('13-04-2088', 'dd-mm-yyyy'), '2', '13', '104', '04', '2088', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32247, to_date('14-04-2088', 'dd-mm-yyyy'), '3', '14', '105', '04', '2088', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32248, to_date('15-04-2088', 'dd-mm-yyyy'), '4', '15', '106', '04', '2088', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32249, to_date('16-04-2088', 'dd-mm-yyyy'), '5', '16', '107', '04', '2088', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32250, to_date('17-04-2088', 'dd-mm-yyyy'), '6', '17', '108', '04', '2088', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32251, to_date('18-04-2088', 'dd-mm-yyyy'), '7', '18', '109', '04', '2088', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32252, to_date('19-04-2088', 'dd-mm-yyyy'), '1', '19', '110', '04', '2088', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32253, to_date('20-04-2088', 'dd-mm-yyyy'), '2', '20', '111', '04', '2088', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32254, to_date('21-04-2088', 'dd-mm-yyyy'), '3', '21', '112', '04', '2088', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32255, to_date('22-04-2088', 'dd-mm-yyyy'), '4', '22', '113', '04', '2088', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32256, to_date('23-04-2088', 'dd-mm-yyyy'), '5', '23', '114', '04', '2088', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32257, to_date('24-04-2088', 'dd-mm-yyyy'), '6', '24', '115', '04', '2088', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32258, to_date('25-04-2088', 'dd-mm-yyyy'), '7', '25', '116', '04', '2088', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32259, to_date('26-04-2088', 'dd-mm-yyyy'), '1', '26', '117', '04', '2088', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32260, to_date('27-04-2088', 'dd-mm-yyyy'), '2', '27', '118', '04', '2088', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32261, to_date('28-04-2088', 'dd-mm-yyyy'), '3', '28', '119', '04', '2088', '18', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32262, to_date('29-04-2088', 'dd-mm-yyyy'), '4', '29', '120', '04', '2088', '18', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32263, to_date('30-04-2088', 'dd-mm-yyyy'), '5', '30', '121', '04', '2088', '18', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32264, to_date('01-05-2088', 'dd-mm-yyyy'), '6', '01', '122', '05', '2088', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32265, to_date('02-05-2088', 'dd-mm-yyyy'), '7', '02', '123', '05', '2088', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32266, to_date('03-05-2088', 'dd-mm-yyyy'), '1', '03', '124', '05', '2088', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32267, to_date('04-05-2088', 'dd-mm-yyyy'), '2', '04', '125', '05', '2088', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32268, to_date('05-05-2088', 'dd-mm-yyyy'), '3', '05', '126', '05', '2088', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32269, to_date('06-05-2088', 'dd-mm-yyyy'), '4', '06', '127', '05', '2088', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32270, to_date('07-05-2088', 'dd-mm-yyyy'), '5', '07', '128', '05', '2088', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32271, to_date('08-05-2088', 'dd-mm-yyyy'), '6', '08', '129', '05', '2088', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32272, to_date('09-05-2088', 'dd-mm-yyyy'), '7', '09', '130', '05', '2088', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32273, to_date('10-05-2088', 'dd-mm-yyyy'), '1', '10', '131', '05', '2088', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32274, to_date('11-05-2088', 'dd-mm-yyyy'), '2', '11', '132', '05', '2088', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32275, to_date('12-05-2088', 'dd-mm-yyyy'), '3', '12', '133', '05', '2088', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32276, to_date('13-05-2088', 'dd-mm-yyyy'), '4', '13', '134', '05', '2088', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32277, to_date('14-05-2088', 'dd-mm-yyyy'), '5', '14', '135', '05', '2088', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32278, to_date('15-05-2088', 'dd-mm-yyyy'), '6', '15', '136', '05', '2088', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32279, to_date('16-05-2088', 'dd-mm-yyyy'), '7', '16', '137', '05', '2088', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32280, to_date('17-05-2088', 'dd-mm-yyyy'), '1', '17', '138', '05', '2088', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32281, to_date('18-05-2088', 'dd-mm-yyyy'), '2', '18', '139', '05', '2088', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32282, to_date('19-05-2088', 'dd-mm-yyyy'), '3', '19', '140', '05', '2088', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32283, to_date('20-05-2088', 'dd-mm-yyyy'), '4', '20', '141', '05', '2088', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32284, to_date('21-05-2088', 'dd-mm-yyyy'), '5', '21', '142', '05', '2088', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32285, to_date('22-05-2088', 'dd-mm-yyyy'), '6', '22', '143', '05', '2088', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32286, to_date('23-05-2088', 'dd-mm-yyyy'), '7', '23', '144', '05', '2088', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32287, to_date('24-05-2088', 'dd-mm-yyyy'), '1', '24', '145', '05', '2088', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32288, to_date('25-05-2088', 'dd-mm-yyyy'), '2', '25', '146', '05', '2088', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32289, to_date('26-05-2088', 'dd-mm-yyyy'), '3', '26', '147', '05', '2088', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32290, to_date('27-05-2088', 'dd-mm-yyyy'), '4', '27', '148', '05', '2088', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32291, to_date('28-05-2088', 'dd-mm-yyyy'), '5', '28', '149', '05', '2088', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32292, to_date('29-05-2088', 'dd-mm-yyyy'), '6', '29', '150', '05', '2088', '22', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32293, to_date('30-05-2088', 'dd-mm-yyyy'), '7', '30', '151', '05', '2088', '22', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32294, to_date('31-05-2088', 'dd-mm-yyyy'), '1', '31', '152', '05', '2088', '23', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32295, to_date('01-06-2088', 'dd-mm-yyyy'), '2', '01', '153', '06', '2088', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32296, to_date('02-06-2088', 'dd-mm-yyyy'), '3', '02', '154', '06', '2088', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32297, to_date('03-06-2088', 'dd-mm-yyyy'), '4', '03', '155', '06', '2088', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32298, to_date('04-06-2088', 'dd-mm-yyyy'), '5', '04', '156', '06', '2088', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32299, to_date('05-06-2088', 'dd-mm-yyyy'), '6', '05', '157', '06', '2088', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32300, to_date('06-06-2088', 'dd-mm-yyyy'), '7', '06', '158', '06', '2088', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32301, to_date('07-06-2088', 'dd-mm-yyyy'), '1', '07', '159', '06', '2088', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32302, to_date('08-06-2088', 'dd-mm-yyyy'), '2', '08', '160', '06', '2088', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32303, to_date('09-06-2088', 'dd-mm-yyyy'), '3', '09', '161', '06', '2088', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32304, to_date('10-06-2088', 'dd-mm-yyyy'), '4', '10', '162', '06', '2088', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27429, to_date('04-02-2075', 'dd-mm-yyyy'), '1', '04', '035', '02', '2075', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27430, to_date('05-02-2075', 'dd-mm-yyyy'), '2', '05', '036', '02', '2075', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27431, to_date('06-02-2075', 'dd-mm-yyyy'), '3', '06', '037', '02', '2075', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27432, to_date('07-02-2075', 'dd-mm-yyyy'), '4', '07', '038', '02', '2075', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27433, to_date('08-02-2075', 'dd-mm-yyyy'), '5', '08', '039', '02', '2075', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
commit;
prompt 36000 records committed...
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27434, to_date('09-02-2075', 'dd-mm-yyyy'), '6', '09', '040', '02', '2075', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27435, to_date('10-02-2075', 'dd-mm-yyyy'), '7', '10', '041', '02', '2075', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27436, to_date('11-02-2075', 'dd-mm-yyyy'), '1', '11', '042', '02', '2075', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27437, to_date('12-02-2075', 'dd-mm-yyyy'), '2', '12', '043', '02', '2075', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27438, to_date('13-02-2075', 'dd-mm-yyyy'), '3', '13', '044', '02', '2075', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27439, to_date('14-02-2075', 'dd-mm-yyyy'), '4', '14', '045', '02', '2075', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27440, to_date('15-02-2075', 'dd-mm-yyyy'), '5', '15', '046', '02', '2075', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27441, to_date('16-02-2075', 'dd-mm-yyyy'), '6', '16', '047', '02', '2075', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27442, to_date('17-02-2075', 'dd-mm-yyyy'), '7', '17', '048', '02', '2075', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27443, to_date('18-02-2075', 'dd-mm-yyyy'), '1', '18', '049', '02', '2075', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27444, to_date('19-02-2075', 'dd-mm-yyyy'), '2', '19', '050', '02', '2075', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27445, to_date('20-02-2075', 'dd-mm-yyyy'), '3', '20', '051', '02', '2075', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27446, to_date('21-02-2075', 'dd-mm-yyyy'), '4', '21', '052', '02', '2075', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27447, to_date('22-02-2075', 'dd-mm-yyyy'), '5', '22', '053', '02', '2075', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27448, to_date('23-02-2075', 'dd-mm-yyyy'), '6', '23', '054', '02', '2075', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27449, to_date('24-02-2075', 'dd-mm-yyyy'), '7', '24', '055', '02', '2075', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27450, to_date('25-02-2075', 'dd-mm-yyyy'), '1', '25', '056', '02', '2075', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27451, to_date('26-02-2075', 'dd-mm-yyyy'), '2', '26', '057', '02', '2075', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27452, to_date('27-02-2075', 'dd-mm-yyyy'), '3', '27', '058', '02', '2075', '09', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27453, to_date('28-02-2075', 'dd-mm-yyyy'), '4', '28', '059', '02', '2075', '09', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27454, to_date('01-03-2075', 'dd-mm-yyyy'), '5', '01', '060', '03', '2075', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27455, to_date('02-03-2075', 'dd-mm-yyyy'), '6', '02', '061', '03', '2075', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27456, to_date('03-03-2075', 'dd-mm-yyyy'), '7', '03', '062', '03', '2075', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27457, to_date('04-03-2075', 'dd-mm-yyyy'), '1', '04', '063', '03', '2075', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27458, to_date('05-03-2075', 'dd-mm-yyyy'), '2', '05', '064', '03', '2075', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27459, to_date('06-03-2075', 'dd-mm-yyyy'), '3', '06', '065', '03', '2075', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27460, to_date('07-03-2075', 'dd-mm-yyyy'), '4', '07', '066', '03', '2075', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27461, to_date('08-03-2075', 'dd-mm-yyyy'), '5', '08', '067', '03', '2075', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27462, to_date('09-03-2075', 'dd-mm-yyyy'), '6', '09', '068', '03', '2075', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27463, to_date('10-03-2075', 'dd-mm-yyyy'), '7', '10', '069', '03', '2075', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27464, to_date('11-03-2075', 'dd-mm-yyyy'), '1', '11', '070', '03', '2075', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27465, to_date('12-03-2075', 'dd-mm-yyyy'), '2', '12', '071', '03', '2075', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27466, to_date('13-03-2075', 'dd-mm-yyyy'), '3', '13', '072', '03', '2075', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27467, to_date('14-03-2075', 'dd-mm-yyyy'), '4', '14', '073', '03', '2075', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27468, to_date('15-03-2075', 'dd-mm-yyyy'), '5', '15', '074', '03', '2075', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27469, to_date('16-03-2075', 'dd-mm-yyyy'), '6', '16', '075', '03', '2075', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27470, to_date('17-03-2075', 'dd-mm-yyyy'), '7', '17', '076', '03', '2075', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27471, to_date('18-03-2075', 'dd-mm-yyyy'), '1', '18', '077', '03', '2075', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27472, to_date('19-03-2075', 'dd-mm-yyyy'), '2', '19', '078', '03', '2075', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27473, to_date('20-03-2075', 'dd-mm-yyyy'), '3', '20', '079', '03', '2075', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27474, to_date('21-03-2075', 'dd-mm-yyyy'), '4', '21', '080', '03', '2075', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27475, to_date('22-03-2075', 'dd-mm-yyyy'), '5', '22', '081', '03', '2075', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27476, to_date('23-03-2075', 'dd-mm-yyyy'), '6', '23', '082', '03', '2075', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27477, to_date('24-03-2075', 'dd-mm-yyyy'), '7', '24', '083', '03', '2075', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27478, to_date('25-03-2075', 'dd-mm-yyyy'), '1', '25', '084', '03', '2075', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27479, to_date('26-03-2075', 'dd-mm-yyyy'), '2', '26', '085', '03', '2075', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27480, to_date('27-03-2075', 'dd-mm-yyyy'), '3', '27', '086', '03', '2075', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27481, to_date('28-03-2075', 'dd-mm-yyyy'), '4', '28', '087', '03', '2075', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27482, to_date('29-03-2075', 'dd-mm-yyyy'), '5', '29', '088', '03', '2075', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27483, to_date('30-03-2075', 'dd-mm-yyyy'), '6', '30', '089', '03', '2075', '13', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27484, to_date('31-03-2075', 'dd-mm-yyyy'), '7', '31', '090', '03', '2075', '13', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27485, to_date('01-04-2075', 'dd-mm-yyyy'), '1', '01', '091', '04', '2075', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27486, to_date('02-04-2075', 'dd-mm-yyyy'), '2', '02', '092', '04', '2075', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27487, to_date('03-04-2075', 'dd-mm-yyyy'), '3', '03', '093', '04', '2075', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27488, to_date('04-04-2075', 'dd-mm-yyyy'), '4', '04', '094', '04', '2075', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27489, to_date('05-04-2075', 'dd-mm-yyyy'), '5', '05', '095', '04', '2075', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27490, to_date('06-04-2075', 'dd-mm-yyyy'), '6', '06', '096', '04', '2075', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27491, to_date('07-04-2075', 'dd-mm-yyyy'), '7', '07', '097', '04', '2075', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27492, to_date('08-04-2075', 'dd-mm-yyyy'), '1', '08', '098', '04', '2075', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27493, to_date('09-04-2075', 'dd-mm-yyyy'), '2', '09', '099', '04', '2075', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27494, to_date('10-04-2075', 'dd-mm-yyyy'), '3', '10', '100', '04', '2075', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27495, to_date('11-04-2075', 'dd-mm-yyyy'), '4', '11', '101', '04', '2075', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27496, to_date('12-04-2075', 'dd-mm-yyyy'), '5', '12', '102', '04', '2075', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27497, to_date('13-04-2075', 'dd-mm-yyyy'), '6', '13', '103', '04', '2075', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27498, to_date('14-04-2075', 'dd-mm-yyyy'), '7', '14', '104', '04', '2075', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27499, to_date('15-04-2075', 'dd-mm-yyyy'), '1', '15', '105', '04', '2075', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27500, to_date('16-04-2075', 'dd-mm-yyyy'), '2', '16', '106', '04', '2075', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27501, to_date('17-04-2075', 'dd-mm-yyyy'), '3', '17', '107', '04', '2075', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27502, to_date('18-04-2075', 'dd-mm-yyyy'), '4', '18', '108', '04', '2075', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27503, to_date('19-04-2075', 'dd-mm-yyyy'), '5', '19', '109', '04', '2075', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27504, to_date('20-04-2075', 'dd-mm-yyyy'), '6', '20', '110', '04', '2075', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27505, to_date('21-04-2075', 'dd-mm-yyyy'), '7', '21', '111', '04', '2075', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27506, to_date('22-04-2075', 'dd-mm-yyyy'), '1', '22', '112', '04', '2075', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27507, to_date('23-04-2075', 'dd-mm-yyyy'), '2', '23', '113', '04', '2075', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27508, to_date('24-04-2075', 'dd-mm-yyyy'), '3', '24', '114', '04', '2075', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27509, to_date('25-04-2075', 'dd-mm-yyyy'), '4', '25', '115', '04', '2075', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27510, to_date('26-04-2075', 'dd-mm-yyyy'), '5', '26', '116', '04', '2075', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27511, to_date('27-04-2075', 'dd-mm-yyyy'), '6', '27', '117', '04', '2075', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27512, to_date('28-04-2075', 'dd-mm-yyyy'), '7', '28', '118', '04', '2075', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27513, to_date('29-04-2075', 'dd-mm-yyyy'), '1', '29', '119', '04', '2075', '18', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27514, to_date('30-04-2075', 'dd-mm-yyyy'), '2', '30', '120', '04', '2075', '18', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27515, to_date('01-05-2075', 'dd-mm-yyyy'), '3', '01', '121', '05', '2075', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27516, to_date('02-05-2075', 'dd-mm-yyyy'), '4', '02', '122', '05', '2075', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27517, to_date('03-05-2075', 'dd-mm-yyyy'), '5', '03', '123', '05', '2075', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27518, to_date('04-05-2075', 'dd-mm-yyyy'), '6', '04', '124', '05', '2075', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27519, to_date('05-05-2075', 'dd-mm-yyyy'), '7', '05', '125', '05', '2075', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27520, to_date('06-05-2075', 'dd-mm-yyyy'), '1', '06', '126', '05', '2075', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27521, to_date('07-05-2075', 'dd-mm-yyyy'), '2', '07', '127', '05', '2075', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27522, to_date('08-05-2075', 'dd-mm-yyyy'), '3', '08', '128', '05', '2075', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27523, to_date('09-05-2075', 'dd-mm-yyyy'), '4', '09', '129', '05', '2075', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27524, to_date('10-05-2075', 'dd-mm-yyyy'), '5', '10', '130', '05', '2075', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27525, to_date('11-05-2075', 'dd-mm-yyyy'), '6', '11', '131', '05', '2075', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27526, to_date('12-05-2075', 'dd-mm-yyyy'), '7', '12', '132', '05', '2075', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27527, to_date('13-05-2075', 'dd-mm-yyyy'), '1', '13', '133', '05', '2075', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27528, to_date('14-05-2075', 'dd-mm-yyyy'), '2', '14', '134', '05', '2075', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27529, to_date('15-05-2075', 'dd-mm-yyyy'), '3', '15', '135', '05', '2075', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27530, to_date('16-05-2075', 'dd-mm-yyyy'), '4', '16', '136', '05', '2075', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27531, to_date('17-05-2075', 'dd-mm-yyyy'), '5', '17', '137', '05', '2075', '20', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27532, to_date('18-05-2075', 'dd-mm-yyyy'), '6', '18', '138', '05', '2075', '20', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27533, to_date('19-05-2075', 'dd-mm-yyyy'), '7', '19', '139', '05', '2075', '20', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27534, to_date('20-05-2075', 'dd-mm-yyyy'), '1', '20', '140', '05', '2075', '21', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29125, to_date('27-09-2079', 'dd-mm-yyyy'), '3', '27', '270', '09', '2079', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29126, to_date('28-09-2079', 'dd-mm-yyyy'), '4', '28', '271', '09', '2079', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29127, to_date('29-09-2079', 'dd-mm-yyyy'), '5', '29', '272', '09', '2079', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29128, to_date('30-09-2079', 'dd-mm-yyyy'), '6', '30', '273', '09', '2079', '39', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29129, to_date('01-10-2079', 'dd-mm-yyyy'), '7', '01', '274', '10', '2079', '39', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29130, to_date('02-10-2079', 'dd-mm-yyyy'), '1', '02', '275', '10', '2079', '40', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29131, to_date('03-10-2079', 'dd-mm-yyyy'), '2', '03', '276', '10', '2079', '40', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29132, to_date('04-10-2079', 'dd-mm-yyyy'), '3', '04', '277', '10', '2079', '40', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29133, to_date('05-10-2079', 'dd-mm-yyyy'), '4', '05', '278', '10', '2079', '40', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29134, to_date('06-10-2079', 'dd-mm-yyyy'), '5', '06', '279', '10', '2079', '40', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29135, to_date('07-10-2079', 'dd-mm-yyyy'), '6', '07', '280', '10', '2079', '40', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29136, to_date('08-10-2079', 'dd-mm-yyyy'), '7', '08', '281', '10', '2079', '40', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29137, to_date('09-10-2079', 'dd-mm-yyyy'), '1', '09', '282', '10', '2079', '41', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29138, to_date('10-10-2079', 'dd-mm-yyyy'), '2', '10', '283', '10', '2079', '41', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29139, to_date('11-10-2079', 'dd-mm-yyyy'), '3', '11', '284', '10', '2079', '41', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29140, to_date('12-10-2079', 'dd-mm-yyyy'), '4', '12', '285', '10', '2079', '41', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29141, to_date('13-10-2079', 'dd-mm-yyyy'), '5', '13', '286', '10', '2079', '41', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29142, to_date('14-10-2079', 'dd-mm-yyyy'), '6', '14', '287', '10', '2079', '41', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29143, to_date('15-10-2079', 'dd-mm-yyyy'), '7', '15', '288', '10', '2079', '41', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29144, to_date('16-10-2079', 'dd-mm-yyyy'), '1', '16', '289', '10', '2079', '42', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29145, to_date('17-10-2079', 'dd-mm-yyyy'), '2', '17', '290', '10', '2079', '42', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29146, to_date('18-10-2079', 'dd-mm-yyyy'), '3', '18', '291', '10', '2079', '42', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29147, to_date('19-10-2079', 'dd-mm-yyyy'), '4', '19', '292', '10', '2079', '42', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29148, to_date('20-10-2079', 'dd-mm-yyyy'), '5', '20', '293', '10', '2079', '42', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29149, to_date('21-10-2079', 'dd-mm-yyyy'), '6', '21', '294', '10', '2079', '42', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29150, to_date('22-10-2079', 'dd-mm-yyyy'), '7', '22', '295', '10', '2079', '42', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29151, to_date('23-10-2079', 'dd-mm-yyyy'), '1', '23', '296', '10', '2079', '43', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29152, to_date('24-10-2079', 'dd-mm-yyyy'), '2', '24', '297', '10', '2079', '43', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29153, to_date('25-10-2079', 'dd-mm-yyyy'), '3', '25', '298', '10', '2079', '43', '4', 'MITTWOCH  ', 'MI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29154, to_date('26-10-2079', 'dd-mm-yyyy'), '4', '26', '299', '10', '2079', '43', '4', 'DONNERSTAG', 'DO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29155, to_date('27-10-2079', 'dd-mm-yyyy'), '5', '27', '300', '10', '2079', '43', '4', 'FREITAG   ', 'FR', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29156, to_date('28-10-2079', 'dd-mm-yyyy'), '6', '28', '301', '10', '2079', '43', '4', 'SAMSTAG   ', 'SA', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29157, to_date('29-10-2079', 'dd-mm-yyyy'), '7', '29', '302', '10', '2079', '43', '4', 'SONNTAG   ', 'SO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29158, to_date('30-10-2079', 'dd-mm-yyyy'), '1', '30', '303', '10', '2079', '44', '4', 'MONTAG    ', 'MO', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29159, to_date('31-10-2079', 'dd-mm-yyyy'), '2', '31', '304', '10', '2079', '44', '4', 'DIENSTAG  ', 'DI', 'OKTOBER  ', 'OKT');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29160, to_date('01-11-2079', 'dd-mm-yyyy'), '3', '01', '305', '11', '2079', '44', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29161, to_date('02-11-2079', 'dd-mm-yyyy'), '4', '02', '306', '11', '2079', '44', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29162, to_date('03-11-2079', 'dd-mm-yyyy'), '5', '03', '307', '11', '2079', '44', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29163, to_date('04-11-2079', 'dd-mm-yyyy'), '6', '04', '308', '11', '2079', '44', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29164, to_date('05-11-2079', 'dd-mm-yyyy'), '7', '05', '309', '11', '2079', '44', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29165, to_date('06-11-2079', 'dd-mm-yyyy'), '1', '06', '310', '11', '2079', '45', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29166, to_date('07-11-2079', 'dd-mm-yyyy'), '2', '07', '311', '11', '2079', '45', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29167, to_date('08-11-2079', 'dd-mm-yyyy'), '3', '08', '312', '11', '2079', '45', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29168, to_date('09-11-2079', 'dd-mm-yyyy'), '4', '09', '313', '11', '2079', '45', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29169, to_date('10-11-2079', 'dd-mm-yyyy'), '5', '10', '314', '11', '2079', '45', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29170, to_date('11-11-2079', 'dd-mm-yyyy'), '6', '11', '315', '11', '2079', '45', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29171, to_date('12-11-2079', 'dd-mm-yyyy'), '7', '12', '316', '11', '2079', '45', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29172, to_date('13-11-2079', 'dd-mm-yyyy'), '1', '13', '317', '11', '2079', '46', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29173, to_date('14-11-2079', 'dd-mm-yyyy'), '2', '14', '318', '11', '2079', '46', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29174, to_date('15-11-2079', 'dd-mm-yyyy'), '3', '15', '319', '11', '2079', '46', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29175, to_date('16-11-2079', 'dd-mm-yyyy'), '4', '16', '320', '11', '2079', '46', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29176, to_date('17-11-2079', 'dd-mm-yyyy'), '5', '17', '321', '11', '2079', '46', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29177, to_date('18-11-2079', 'dd-mm-yyyy'), '6', '18', '322', '11', '2079', '46', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29178, to_date('19-11-2079', 'dd-mm-yyyy'), '7', '19', '323', '11', '2079', '46', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29179, to_date('20-11-2079', 'dd-mm-yyyy'), '1', '20', '324', '11', '2079', '47', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29180, to_date('21-11-2079', 'dd-mm-yyyy'), '2', '21', '325', '11', '2079', '47', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29181, to_date('22-11-2079', 'dd-mm-yyyy'), '3', '22', '326', '11', '2079', '47', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29182, to_date('23-11-2079', 'dd-mm-yyyy'), '4', '23', '327', '11', '2079', '47', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29183, to_date('24-11-2079', 'dd-mm-yyyy'), '5', '24', '328', '11', '2079', '47', '4', 'FREITAG   ', 'FR', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29184, to_date('25-11-2079', 'dd-mm-yyyy'), '6', '25', '329', '11', '2079', '47', '4', 'SAMSTAG   ', 'SA', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29185, to_date('26-11-2079', 'dd-mm-yyyy'), '7', '26', '330', '11', '2079', '47', '4', 'SONNTAG   ', 'SO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29186, to_date('27-11-2079', 'dd-mm-yyyy'), '1', '27', '331', '11', '2079', '48', '4', 'MONTAG    ', 'MO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29187, to_date('28-11-2079', 'dd-mm-yyyy'), '2', '28', '332', '11', '2079', '48', '4', 'DIENSTAG  ', 'DI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29188, to_date('29-11-2079', 'dd-mm-yyyy'), '3', '29', '333', '11', '2079', '48', '4', 'MITTWOCH  ', 'MI', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29189, to_date('30-11-2079', 'dd-mm-yyyy'), '4', '30', '334', '11', '2079', '48', '4', 'DONNERSTAG', 'DO', 'NOVEMBER ', 'NOV');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29190, to_date('01-12-2079', 'dd-mm-yyyy'), '5', '01', '335', '12', '2079', '48', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29191, to_date('02-12-2079', 'dd-mm-yyyy'), '6', '02', '336', '12', '2079', '48', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29192, to_date('03-12-2079', 'dd-mm-yyyy'), '7', '03', '337', '12', '2079', '48', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29193, to_date('04-12-2079', 'dd-mm-yyyy'), '1', '04', '338', '12', '2079', '49', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29194, to_date('05-12-2079', 'dd-mm-yyyy'), '2', '05', '339', '12', '2079', '49', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29195, to_date('06-12-2079', 'dd-mm-yyyy'), '3', '06', '340', '12', '2079', '49', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29196, to_date('07-12-2079', 'dd-mm-yyyy'), '4', '07', '341', '12', '2079', '49', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29197, to_date('08-12-2079', 'dd-mm-yyyy'), '5', '08', '342', '12', '2079', '49', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29198, to_date('09-12-2079', 'dd-mm-yyyy'), '6', '09', '343', '12', '2079', '49', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29199, to_date('10-12-2079', 'dd-mm-yyyy'), '7', '10', '344', '12', '2079', '49', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29200, to_date('11-12-2079', 'dd-mm-yyyy'), '1', '11', '345', '12', '2079', '50', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29201, to_date('12-12-2079', 'dd-mm-yyyy'), '2', '12', '346', '12', '2079', '50', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29202, to_date('13-12-2079', 'dd-mm-yyyy'), '3', '13', '347', '12', '2079', '50', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29203, to_date('14-12-2079', 'dd-mm-yyyy'), '4', '14', '348', '12', '2079', '50', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29204, to_date('15-12-2079', 'dd-mm-yyyy'), '5', '15', '349', '12', '2079', '50', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29205, to_date('16-12-2079', 'dd-mm-yyyy'), '6', '16', '350', '12', '2079', '50', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29206, to_date('17-12-2079', 'dd-mm-yyyy'), '7', '17', '351', '12', '2079', '50', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29207, to_date('18-12-2079', 'dd-mm-yyyy'), '1', '18', '352', '12', '2079', '51', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29208, to_date('19-12-2079', 'dd-mm-yyyy'), '2', '19', '353', '12', '2079', '51', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29209, to_date('20-12-2079', 'dd-mm-yyyy'), '3', '20', '354', '12', '2079', '51', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29210, to_date('21-12-2079', 'dd-mm-yyyy'), '4', '21', '355', '12', '2079', '51', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29211, to_date('22-12-2079', 'dd-mm-yyyy'), '5', '22', '356', '12', '2079', '51', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29212, to_date('23-12-2079', 'dd-mm-yyyy'), '6', '23', '357', '12', '2079', '51', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29213, to_date('24-12-2079', 'dd-mm-yyyy'), '7', '24', '358', '12', '2079', '51', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29214, to_date('25-12-2079', 'dd-mm-yyyy'), '1', '25', '359', '12', '2079', '52', '4', 'MONTAG    ', 'MO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29215, to_date('26-12-2079', 'dd-mm-yyyy'), '2', '26', '360', '12', '2079', '52', '4', 'DIENSTAG  ', 'DI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29216, to_date('27-12-2079', 'dd-mm-yyyy'), '3', '27', '361', '12', '2079', '52', '4', 'MITTWOCH  ', 'MI', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29217, to_date('28-12-2079', 'dd-mm-yyyy'), '4', '28', '362', '12', '2079', '52', '4', 'DONNERSTAG', 'DO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29218, to_date('29-12-2079', 'dd-mm-yyyy'), '5', '29', '363', '12', '2079', '52', '4', 'FREITAG   ', 'FR', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29219, to_date('30-12-2079', 'dd-mm-yyyy'), '6', '30', '364', '12', '2079', '52', '4', 'SAMSTAG   ', 'SA', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29220, to_date('31-12-2079', 'dd-mm-yyyy'), '7', '31', '365', '12', '2079', '52', '4', 'SONNTAG   ', 'SO', 'DEZEMBER ', 'DEZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29221, to_date('01-01-2080', 'dd-mm-yyyy'), '1', '01', '001', '01', '2080', '01', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29222, to_date('02-01-2080', 'dd-mm-yyyy'), '2', '02', '002', '01', '2080', '01', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29223, to_date('03-01-2080', 'dd-mm-yyyy'), '3', '03', '003', '01', '2080', '01', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29224, to_date('04-01-2080', 'dd-mm-yyyy'), '4', '04', '004', '01', '2080', '01', '1', 'DONNERSTAG', 'DO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29225, to_date('05-01-2080', 'dd-mm-yyyy'), '5', '05', '005', '01', '2080', '01', '1', 'FREITAG   ', 'FR', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29226, to_date('06-01-2080', 'dd-mm-yyyy'), '6', '06', '006', '01', '2080', '01', '1', 'SAMSTAG   ', 'SA', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29227, to_date('07-01-2080', 'dd-mm-yyyy'), '7', '07', '007', '01', '2080', '01', '1', 'SONNTAG   ', 'SO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29228, to_date('08-01-2080', 'dd-mm-yyyy'), '1', '08', '008', '01', '2080', '02', '1', 'MONTAG    ', 'MO', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29229, to_date('09-01-2080', 'dd-mm-yyyy'), '2', '09', '009', '01', '2080', '02', '1', 'DIENSTAG  ', 'DI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (29230, to_date('10-01-2080', 'dd-mm-yyyy'), '3', '10', '010', '01', '2080', '02', '1', 'MITTWOCH  ', 'MI', 'JANUAR   ', 'JAN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30715, to_date('03-02-2084', 'dd-mm-yyyy'), '4', '03', '034', '02', '2084', '05', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30716, to_date('04-02-2084', 'dd-mm-yyyy'), '5', '04', '035', '02', '2084', '05', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30717, to_date('05-02-2084', 'dd-mm-yyyy'), '6', '05', '036', '02', '2084', '05', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30718, to_date('06-02-2084', 'dd-mm-yyyy'), '7', '06', '037', '02', '2084', '05', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30719, to_date('07-02-2084', 'dd-mm-yyyy'), '1', '07', '038', '02', '2084', '06', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30720, to_date('08-02-2084', 'dd-mm-yyyy'), '2', '08', '039', '02', '2084', '06', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30721, to_date('09-02-2084', 'dd-mm-yyyy'), '3', '09', '040', '02', '2084', '06', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30722, to_date('10-02-2084', 'dd-mm-yyyy'), '4', '10', '041', '02', '2084', '06', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30723, to_date('11-02-2084', 'dd-mm-yyyy'), '5', '11', '042', '02', '2084', '06', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30724, to_date('12-02-2084', 'dd-mm-yyyy'), '6', '12', '043', '02', '2084', '06', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30725, to_date('13-02-2084', 'dd-mm-yyyy'), '7', '13', '044', '02', '2084', '06', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30726, to_date('14-02-2084', 'dd-mm-yyyy'), '1', '14', '045', '02', '2084', '07', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30727, to_date('15-02-2084', 'dd-mm-yyyy'), '2', '15', '046', '02', '2084', '07', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30728, to_date('16-02-2084', 'dd-mm-yyyy'), '3', '16', '047', '02', '2084', '07', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30729, to_date('17-02-2084', 'dd-mm-yyyy'), '4', '17', '048', '02', '2084', '07', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30730, to_date('18-02-2084', 'dd-mm-yyyy'), '5', '18', '049', '02', '2084', '07', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30731, to_date('19-02-2084', 'dd-mm-yyyy'), '6', '19', '050', '02', '2084', '07', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30732, to_date('20-02-2084', 'dd-mm-yyyy'), '7', '20', '051', '02', '2084', '07', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30733, to_date('21-02-2084', 'dd-mm-yyyy'), '1', '21', '052', '02', '2084', '08', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30734, to_date('22-02-2084', 'dd-mm-yyyy'), '2', '22', '053', '02', '2084', '08', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30735, to_date('23-02-2084', 'dd-mm-yyyy'), '3', '23', '054', '02', '2084', '08', '1', 'MITTWOCH  ', 'MI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30736, to_date('24-02-2084', 'dd-mm-yyyy'), '4', '24', '055', '02', '2084', '08', '1', 'DONNERSTAG', 'DO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30737, to_date('25-02-2084', 'dd-mm-yyyy'), '5', '25', '056', '02', '2084', '08', '1', 'FREITAG   ', 'FR', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30738, to_date('26-02-2084', 'dd-mm-yyyy'), '6', '26', '057', '02', '2084', '08', '1', 'SAMSTAG   ', 'SA', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30739, to_date('27-02-2084', 'dd-mm-yyyy'), '7', '27', '058', '02', '2084', '08', '1', 'SONNTAG   ', 'SO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30740, to_date('28-02-2084', 'dd-mm-yyyy'), '1', '28', '059', '02', '2084', '09', '1', 'MONTAG    ', 'MO', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30741, to_date('29-02-2084', 'dd-mm-yyyy'), '2', '29', '060', '02', '2084', '09', '1', 'DIENSTAG  ', 'DI', 'FEBRUAR  ', 'FEB');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30742, to_date('01-03-2084', 'dd-mm-yyyy'), '3', '01', '061', '03', '2084', '09', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30743, to_date('02-03-2084', 'dd-mm-yyyy'), '4', '02', '062', '03', '2084', '09', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30744, to_date('03-03-2084', 'dd-mm-yyyy'), '5', '03', '063', '03', '2084', '09', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30745, to_date('04-03-2084', 'dd-mm-yyyy'), '6', '04', '064', '03', '2084', '09', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30746, to_date('05-03-2084', 'dd-mm-yyyy'), '7', '05', '065', '03', '2084', '09', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30747, to_date('06-03-2084', 'dd-mm-yyyy'), '1', '06', '066', '03', '2084', '10', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30748, to_date('07-03-2084', 'dd-mm-yyyy'), '2', '07', '067', '03', '2084', '10', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30749, to_date('08-03-2084', 'dd-mm-yyyy'), '3', '08', '068', '03', '2084', '10', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30750, to_date('09-03-2084', 'dd-mm-yyyy'), '4', '09', '069', '03', '2084', '10', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30751, to_date('10-03-2084', 'dd-mm-yyyy'), '5', '10', '070', '03', '2084', '10', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30752, to_date('11-03-2084', 'dd-mm-yyyy'), '6', '11', '071', '03', '2084', '10', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30753, to_date('12-03-2084', 'dd-mm-yyyy'), '7', '12', '072', '03', '2084', '10', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30754, to_date('13-03-2084', 'dd-mm-yyyy'), '1', '13', '073', '03', '2084', '11', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30755, to_date('14-03-2084', 'dd-mm-yyyy'), '2', '14', '074', '03', '2084', '11', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30756, to_date('15-03-2084', 'dd-mm-yyyy'), '3', '15', '075', '03', '2084', '11', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30757, to_date('16-03-2084', 'dd-mm-yyyy'), '4', '16', '076', '03', '2084', '11', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30758, to_date('17-03-2084', 'dd-mm-yyyy'), '5', '17', '077', '03', '2084', '11', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30759, to_date('18-03-2084', 'dd-mm-yyyy'), '6', '18', '078', '03', '2084', '11', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30760, to_date('19-03-2084', 'dd-mm-yyyy'), '7', '19', '079', '03', '2084', '11', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30761, to_date('20-03-2084', 'dd-mm-yyyy'), '1', '20', '080', '03', '2084', '12', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30762, to_date('21-03-2084', 'dd-mm-yyyy'), '2', '21', '081', '03', '2084', '12', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30763, to_date('22-03-2084', 'dd-mm-yyyy'), '3', '22', '082', '03', '2084', '12', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30764, to_date('23-03-2084', 'dd-mm-yyyy'), '4', '23', '083', '03', '2084', '12', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30765, to_date('24-03-2084', 'dd-mm-yyyy'), '5', '24', '084', '03', '2084', '12', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30766, to_date('25-03-2084', 'dd-mm-yyyy'), '6', '25', '085', '03', '2084', '12', '1', 'SAMSTAG   ', 'SA', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30767, to_date('26-03-2084', 'dd-mm-yyyy'), '7', '26', '086', '03', '2084', '12', '1', 'SONNTAG   ', 'SO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30768, to_date('27-03-2084', 'dd-mm-yyyy'), '1', '27', '087', '03', '2084', '13', '1', 'MONTAG    ', 'MO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30769, to_date('28-03-2084', 'dd-mm-yyyy'), '2', '28', '088', '03', '2084', '13', '1', 'DIENSTAG  ', 'DI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30770, to_date('29-03-2084', 'dd-mm-yyyy'), '3', '29', '089', '03', '2084', '13', '1', 'MITTWOCH  ', 'MI', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30771, to_date('30-03-2084', 'dd-mm-yyyy'), '4', '30', '090', '03', '2084', '13', '1', 'DONNERSTAG', 'DO', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30772, to_date('31-03-2084', 'dd-mm-yyyy'), '5', '31', '091', '03', '2084', '13', '1', 'FREITAG   ', 'FR', 'MRZ     ', 'MRZ');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30773, to_date('01-04-2084', 'dd-mm-yyyy'), '6', '01', '092', '04', '2084', '13', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30774, to_date('02-04-2084', 'dd-mm-yyyy'), '7', '02', '093', '04', '2084', '13', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30775, to_date('03-04-2084', 'dd-mm-yyyy'), '1', '03', '094', '04', '2084', '14', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30776, to_date('04-04-2084', 'dd-mm-yyyy'), '2', '04', '095', '04', '2084', '14', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30777, to_date('05-04-2084', 'dd-mm-yyyy'), '3', '05', '096', '04', '2084', '14', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30778, to_date('06-04-2084', 'dd-mm-yyyy'), '4', '06', '097', '04', '2084', '14', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30779, to_date('07-04-2084', 'dd-mm-yyyy'), '5', '07', '098', '04', '2084', '14', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30780, to_date('08-04-2084', 'dd-mm-yyyy'), '6', '08', '099', '04', '2084', '14', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30781, to_date('09-04-2084', 'dd-mm-yyyy'), '7', '09', '100', '04', '2084', '14', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30782, to_date('10-04-2084', 'dd-mm-yyyy'), '1', '10', '101', '04', '2084', '15', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30783, to_date('11-04-2084', 'dd-mm-yyyy'), '2', '11', '102', '04', '2084', '15', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30784, to_date('12-04-2084', 'dd-mm-yyyy'), '3', '12', '103', '04', '2084', '15', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30785, to_date('13-04-2084', 'dd-mm-yyyy'), '4', '13', '104', '04', '2084', '15', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30786, to_date('14-04-2084', 'dd-mm-yyyy'), '5', '14', '105', '04', '2084', '15', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30787, to_date('15-04-2084', 'dd-mm-yyyy'), '6', '15', '106', '04', '2084', '15', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30788, to_date('16-04-2084', 'dd-mm-yyyy'), '7', '16', '107', '04', '2084', '15', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30789, to_date('17-04-2084', 'dd-mm-yyyy'), '1', '17', '108', '04', '2084', '16', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30790, to_date('18-04-2084', 'dd-mm-yyyy'), '2', '18', '109', '04', '2084', '16', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30791, to_date('19-04-2084', 'dd-mm-yyyy'), '3', '19', '110', '04', '2084', '16', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30792, to_date('20-04-2084', 'dd-mm-yyyy'), '4', '20', '111', '04', '2084', '16', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30793, to_date('21-04-2084', 'dd-mm-yyyy'), '5', '21', '112', '04', '2084', '16', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30794, to_date('22-04-2084', 'dd-mm-yyyy'), '6', '22', '113', '04', '2084', '16', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30795, to_date('23-04-2084', 'dd-mm-yyyy'), '7', '23', '114', '04', '2084', '16', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30796, to_date('24-04-2084', 'dd-mm-yyyy'), '1', '24', '115', '04', '2084', '17', '2', 'MONTAG    ', 'MO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30797, to_date('25-04-2084', 'dd-mm-yyyy'), '2', '25', '116', '04', '2084', '17', '2', 'DIENSTAG  ', 'DI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30798, to_date('26-04-2084', 'dd-mm-yyyy'), '3', '26', '117', '04', '2084', '17', '2', 'MITTWOCH  ', 'MI', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30799, to_date('27-04-2084', 'dd-mm-yyyy'), '4', '27', '118', '04', '2084', '17', '2', 'DONNERSTAG', 'DO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30800, to_date('28-04-2084', 'dd-mm-yyyy'), '5', '28', '119', '04', '2084', '17', '2', 'FREITAG   ', 'FR', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30801, to_date('29-04-2084', 'dd-mm-yyyy'), '6', '29', '120', '04', '2084', '17', '2', 'SAMSTAG   ', 'SA', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30802, to_date('30-04-2084', 'dd-mm-yyyy'), '7', '30', '121', '04', '2084', '17', '2', 'SONNTAG   ', 'SO', 'APRIL    ', 'APR');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30803, to_date('01-05-2084', 'dd-mm-yyyy'), '1', '01', '122', '05', '2084', '18', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30804, to_date('02-05-2084', 'dd-mm-yyyy'), '2', '02', '123', '05', '2084', '18', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30805, to_date('03-05-2084', 'dd-mm-yyyy'), '3', '03', '124', '05', '2084', '18', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30806, to_date('04-05-2084', 'dd-mm-yyyy'), '4', '04', '125', '05', '2084', '18', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30807, to_date('05-05-2084', 'dd-mm-yyyy'), '5', '05', '126', '05', '2084', '18', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30808, to_date('06-05-2084', 'dd-mm-yyyy'), '6', '06', '127', '05', '2084', '18', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30809, to_date('07-05-2084', 'dd-mm-yyyy'), '7', '07', '128', '05', '2084', '18', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30810, to_date('08-05-2084', 'dd-mm-yyyy'), '1', '08', '129', '05', '2084', '19', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30811, to_date('09-05-2084', 'dd-mm-yyyy'), '2', '09', '130', '05', '2084', '19', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30812, to_date('10-05-2084', 'dd-mm-yyyy'), '3', '10', '131', '05', '2084', '19', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30813, to_date('11-05-2084', 'dd-mm-yyyy'), '4', '11', '132', '05', '2084', '19', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30814, to_date('12-05-2084', 'dd-mm-yyyy'), '5', '12', '133', '05', '2084', '19', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30815, to_date('13-05-2084', 'dd-mm-yyyy'), '6', '13', '134', '05', '2084', '19', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30816, to_date('14-05-2084', 'dd-mm-yyyy'), '7', '14', '135', '05', '2084', '19', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30817, to_date('15-05-2084', 'dd-mm-yyyy'), '1', '15', '136', '05', '2084', '20', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30818, to_date('16-05-2084', 'dd-mm-yyyy'), '2', '16', '137', '05', '2084', '20', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30819, to_date('17-05-2084', 'dd-mm-yyyy'), '3', '17', '138', '05', '2084', '20', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (30820, to_date('18-05-2084', 'dd-mm-yyyy'), '4', '18', '139', '05', '2084', '20', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32305, to_date('11-06-2088', 'dd-mm-yyyy'), '5', '11', '163', '06', '2088', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32306, to_date('12-06-2088', 'dd-mm-yyyy'), '6', '12', '164', '06', '2088', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32307, to_date('13-06-2088', 'dd-mm-yyyy'), '7', '13', '165', '06', '2088', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32308, to_date('14-06-2088', 'dd-mm-yyyy'), '1', '14', '166', '06', '2088', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32309, to_date('15-06-2088', 'dd-mm-yyyy'), '2', '15', '167', '06', '2088', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32310, to_date('16-06-2088', 'dd-mm-yyyy'), '3', '16', '168', '06', '2088', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32311, to_date('17-06-2088', 'dd-mm-yyyy'), '4', '17', '169', '06', '2088', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32312, to_date('18-06-2088', 'dd-mm-yyyy'), '5', '18', '170', '06', '2088', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32313, to_date('19-06-2088', 'dd-mm-yyyy'), '6', '19', '171', '06', '2088', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32314, to_date('20-06-2088', 'dd-mm-yyyy'), '7', '20', '172', '06', '2088', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32315, to_date('21-06-2088', 'dd-mm-yyyy'), '1', '21', '173', '06', '2088', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32316, to_date('22-06-2088', 'dd-mm-yyyy'), '2', '22', '174', '06', '2088', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32317, to_date('23-06-2088', 'dd-mm-yyyy'), '3', '23', '175', '06', '2088', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32318, to_date('24-06-2088', 'dd-mm-yyyy'), '4', '24', '176', '06', '2088', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32319, to_date('25-06-2088', 'dd-mm-yyyy'), '5', '25', '177', '06', '2088', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32320, to_date('26-06-2088', 'dd-mm-yyyy'), '6', '26', '178', '06', '2088', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32321, to_date('27-06-2088', 'dd-mm-yyyy'), '7', '27', '179', '06', '2088', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32322, to_date('28-06-2088', 'dd-mm-yyyy'), '1', '28', '180', '06', '2088', '27', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32323, to_date('29-06-2088', 'dd-mm-yyyy'), '2', '29', '181', '06', '2088', '27', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32324, to_date('30-06-2088', 'dd-mm-yyyy'), '3', '30', '182', '06', '2088', '27', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32325, to_date('01-07-2088', 'dd-mm-yyyy'), '4', '01', '183', '07', '2088', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32326, to_date('02-07-2088', 'dd-mm-yyyy'), '5', '02', '184', '07', '2088', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32327, to_date('03-07-2088', 'dd-mm-yyyy'), '6', '03', '185', '07', '2088', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32328, to_date('04-07-2088', 'dd-mm-yyyy'), '7', '04', '186', '07', '2088', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32329, to_date('05-07-2088', 'dd-mm-yyyy'), '1', '05', '187', '07', '2088', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32330, to_date('06-07-2088', 'dd-mm-yyyy'), '2', '06', '188', '07', '2088', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32331, to_date('07-07-2088', 'dd-mm-yyyy'), '3', '07', '189', '07', '2088', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32332, to_date('08-07-2088', 'dd-mm-yyyy'), '4', '08', '190', '07', '2088', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32333, to_date('09-07-2088', 'dd-mm-yyyy'), '5', '09', '191', '07', '2088', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32334, to_date('10-07-2088', 'dd-mm-yyyy'), '6', '10', '192', '07', '2088', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32335, to_date('11-07-2088', 'dd-mm-yyyy'), '7', '11', '193', '07', '2088', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32336, to_date('12-07-2088', 'dd-mm-yyyy'), '1', '12', '194', '07', '2088', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32337, to_date('13-07-2088', 'dd-mm-yyyy'), '2', '13', '195', '07', '2088', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32338, to_date('14-07-2088', 'dd-mm-yyyy'), '3', '14', '196', '07', '2088', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32339, to_date('15-07-2088', 'dd-mm-yyyy'), '4', '15', '197', '07', '2088', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32340, to_date('16-07-2088', 'dd-mm-yyyy'), '5', '16', '198', '07', '2088', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32341, to_date('17-07-2088', 'dd-mm-yyyy'), '6', '17', '199', '07', '2088', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32342, to_date('18-07-2088', 'dd-mm-yyyy'), '7', '18', '200', '07', '2088', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32343, to_date('19-07-2088', 'dd-mm-yyyy'), '1', '19', '201', '07', '2088', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32344, to_date('20-07-2088', 'dd-mm-yyyy'), '2', '20', '202', '07', '2088', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32345, to_date('21-07-2088', 'dd-mm-yyyy'), '3', '21', '203', '07', '2088', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32346, to_date('22-07-2088', 'dd-mm-yyyy'), '4', '22', '204', '07', '2088', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32347, to_date('23-07-2088', 'dd-mm-yyyy'), '5', '23', '205', '07', '2088', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32348, to_date('24-07-2088', 'dd-mm-yyyy'), '6', '24', '206', '07', '2088', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32349, to_date('25-07-2088', 'dd-mm-yyyy'), '7', '25', '207', '07', '2088', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32350, to_date('26-07-2088', 'dd-mm-yyyy'), '1', '26', '208', '07', '2088', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32351, to_date('27-07-2088', 'dd-mm-yyyy'), '2', '27', '209', '07', '2088', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32352, to_date('28-07-2088', 'dd-mm-yyyy'), '3', '28', '210', '07', '2088', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32353, to_date('29-07-2088', 'dd-mm-yyyy'), '4', '29', '211', '07', '2088', '31', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32354, to_date('30-07-2088', 'dd-mm-yyyy'), '5', '30', '212', '07', '2088', '31', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32355, to_date('31-07-2088', 'dd-mm-yyyy'), '6', '31', '213', '07', '2088', '31', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32356, to_date('01-08-2088', 'dd-mm-yyyy'), '7', '01', '214', '08', '2088', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32357, to_date('02-08-2088', 'dd-mm-yyyy'), '1', '02', '215', '08', '2088', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32358, to_date('03-08-2088', 'dd-mm-yyyy'), '2', '03', '216', '08', '2088', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32359, to_date('04-08-2088', 'dd-mm-yyyy'), '3', '04', '217', '08', '2088', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32360, to_date('05-08-2088', 'dd-mm-yyyy'), '4', '05', '218', '08', '2088', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32361, to_date('06-08-2088', 'dd-mm-yyyy'), '5', '06', '219', '08', '2088', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32362, to_date('07-08-2088', 'dd-mm-yyyy'), '6', '07', '220', '08', '2088', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32363, to_date('08-08-2088', 'dd-mm-yyyy'), '7', '08', '221', '08', '2088', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32364, to_date('09-08-2088', 'dd-mm-yyyy'), '1', '09', '222', '08', '2088', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32365, to_date('10-08-2088', 'dd-mm-yyyy'), '2', '10', '223', '08', '2088', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32366, to_date('11-08-2088', 'dd-mm-yyyy'), '3', '11', '224', '08', '2088', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32367, to_date('12-08-2088', 'dd-mm-yyyy'), '4', '12', '225', '08', '2088', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32368, to_date('13-08-2088', 'dd-mm-yyyy'), '5', '13', '226', '08', '2088', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32369, to_date('14-08-2088', 'dd-mm-yyyy'), '6', '14', '227', '08', '2088', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32370, to_date('15-08-2088', 'dd-mm-yyyy'), '7', '15', '228', '08', '2088', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32371, to_date('16-08-2088', 'dd-mm-yyyy'), '1', '16', '229', '08', '2088', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32372, to_date('17-08-2088', 'dd-mm-yyyy'), '2', '17', '230', '08', '2088', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32373, to_date('18-08-2088', 'dd-mm-yyyy'), '3', '18', '231', '08', '2088', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32374, to_date('19-08-2088', 'dd-mm-yyyy'), '4', '19', '232', '08', '2088', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32375, to_date('20-08-2088', 'dd-mm-yyyy'), '5', '20', '233', '08', '2088', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32376, to_date('21-08-2088', 'dd-mm-yyyy'), '6', '21', '234', '08', '2088', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32377, to_date('22-08-2088', 'dd-mm-yyyy'), '7', '22', '235', '08', '2088', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32378, to_date('23-08-2088', 'dd-mm-yyyy'), '1', '23', '236', '08', '2088', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32379, to_date('24-08-2088', 'dd-mm-yyyy'), '2', '24', '237', '08', '2088', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32380, to_date('25-08-2088', 'dd-mm-yyyy'), '3', '25', '238', '08', '2088', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32381, to_date('26-08-2088', 'dd-mm-yyyy'), '4', '26', '239', '08', '2088', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32382, to_date('27-08-2088', 'dd-mm-yyyy'), '5', '27', '240', '08', '2088', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32383, to_date('28-08-2088', 'dd-mm-yyyy'), '6', '28', '241', '08', '2088', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32384, to_date('29-08-2088', 'dd-mm-yyyy'), '7', '29', '242', '08', '2088', '35', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32385, to_date('30-08-2088', 'dd-mm-yyyy'), '1', '30', '243', '08', '2088', '36', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32386, to_date('31-08-2088', 'dd-mm-yyyy'), '2', '31', '244', '08', '2088', '36', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32387, to_date('01-09-2088', 'dd-mm-yyyy'), '3', '01', '245', '09', '2088', '36', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32388, to_date('02-09-2088', 'dd-mm-yyyy'), '4', '02', '246', '09', '2088', '36', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32389, to_date('03-09-2088', 'dd-mm-yyyy'), '5', '03', '247', '09', '2088', '36', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32390, to_date('04-09-2088', 'dd-mm-yyyy'), '6', '04', '248', '09', '2088', '36', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32391, to_date('05-09-2088', 'dd-mm-yyyy'), '7', '05', '249', '09', '2088', '36', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32392, to_date('06-09-2088', 'dd-mm-yyyy'), '1', '06', '250', '09', '2088', '37', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32393, to_date('07-09-2088', 'dd-mm-yyyy'), '2', '07', '251', '09', '2088', '37', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32394, to_date('08-09-2088', 'dd-mm-yyyy'), '3', '08', '252', '09', '2088', '37', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32395, to_date('09-09-2088', 'dd-mm-yyyy'), '4', '09', '253', '09', '2088', '37', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32396, to_date('10-09-2088', 'dd-mm-yyyy'), '5', '10', '254', '09', '2088', '37', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32397, to_date('11-09-2088', 'dd-mm-yyyy'), '6', '11', '255', '09', '2088', '37', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32398, to_date('12-09-2088', 'dd-mm-yyyy'), '7', '12', '256', '09', '2088', '37', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32399, to_date('13-09-2088', 'dd-mm-yyyy'), '1', '13', '257', '09', '2088', '38', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32400, to_date('14-09-2088', 'dd-mm-yyyy'), '2', '14', '258', '09', '2088', '38', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32401, to_date('15-09-2088', 'dd-mm-yyyy'), '3', '15', '259', '09', '2088', '38', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32402, to_date('16-09-2088', 'dd-mm-yyyy'), '4', '16', '260', '09', '2088', '38', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32403, to_date('17-09-2088', 'dd-mm-yyyy'), '5', '17', '261', '09', '2088', '38', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32404, to_date('18-09-2088', 'dd-mm-yyyy'), '6', '18', '262', '09', '2088', '38', '3', 'SAMSTAG   ', 'SA', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32405, to_date('19-09-2088', 'dd-mm-yyyy'), '7', '19', '263', '09', '2088', '38', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32406, to_date('20-09-2088', 'dd-mm-yyyy'), '1', '20', '264', '09', '2088', '39', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32407, to_date('21-09-2088', 'dd-mm-yyyy'), '2', '21', '265', '09', '2088', '39', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32408, to_date('22-09-2088', 'dd-mm-yyyy'), '3', '22', '266', '09', '2088', '39', '3', 'MITTWOCH  ', 'MI', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32409, to_date('23-09-2088', 'dd-mm-yyyy'), '4', '23', '267', '09', '2088', '39', '3', 'DONNERSTAG', 'DO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (32410, to_date('24-09-2088', 'dd-mm-yyyy'), '5', '24', '268', '09', '2088', '39', '3', 'FREITAG   ', 'FR', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27535, to_date('21-05-2075', 'dd-mm-yyyy'), '2', '21', '141', '05', '2075', '21', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27536, to_date('22-05-2075', 'dd-mm-yyyy'), '3', '22', '142', '05', '2075', '21', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27537, to_date('23-05-2075', 'dd-mm-yyyy'), '4', '23', '143', '05', '2075', '21', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27538, to_date('24-05-2075', 'dd-mm-yyyy'), '5', '24', '144', '05', '2075', '21', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27539, to_date('25-05-2075', 'dd-mm-yyyy'), '6', '25', '145', '05', '2075', '21', '2', 'SAMSTAG   ', 'SA', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27540, to_date('26-05-2075', 'dd-mm-yyyy'), '7', '26', '146', '05', '2075', '21', '2', 'SONNTAG   ', 'SO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27541, to_date('27-05-2075', 'dd-mm-yyyy'), '1', '27', '147', '05', '2075', '22', '2', 'MONTAG    ', 'MO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27542, to_date('28-05-2075', 'dd-mm-yyyy'), '2', '28', '148', '05', '2075', '22', '2', 'DIENSTAG  ', 'DI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27543, to_date('29-05-2075', 'dd-mm-yyyy'), '3', '29', '149', '05', '2075', '22', '2', 'MITTWOCH  ', 'MI', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27544, to_date('30-05-2075', 'dd-mm-yyyy'), '4', '30', '150', '05', '2075', '22', '2', 'DONNERSTAG', 'DO', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27545, to_date('31-05-2075', 'dd-mm-yyyy'), '5', '31', '151', '05', '2075', '22', '2', 'FREITAG   ', 'FR', 'MAI      ', 'MAI');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27546, to_date('01-06-2075', 'dd-mm-yyyy'), '6', '01', '152', '06', '2075', '22', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27547, to_date('02-06-2075', 'dd-mm-yyyy'), '7', '02', '153', '06', '2075', '22', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27548, to_date('03-06-2075', 'dd-mm-yyyy'), '1', '03', '154', '06', '2075', '23', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27549, to_date('04-06-2075', 'dd-mm-yyyy'), '2', '04', '155', '06', '2075', '23', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27550, to_date('05-06-2075', 'dd-mm-yyyy'), '3', '05', '156', '06', '2075', '23', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27551, to_date('06-06-2075', 'dd-mm-yyyy'), '4', '06', '157', '06', '2075', '23', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27552, to_date('07-06-2075', 'dd-mm-yyyy'), '5', '07', '158', '06', '2075', '23', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27553, to_date('08-06-2075', 'dd-mm-yyyy'), '6', '08', '159', '06', '2075', '23', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27554, to_date('09-06-2075', 'dd-mm-yyyy'), '7', '09', '160', '06', '2075', '23', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27555, to_date('10-06-2075', 'dd-mm-yyyy'), '1', '10', '161', '06', '2075', '24', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27556, to_date('11-06-2075', 'dd-mm-yyyy'), '2', '11', '162', '06', '2075', '24', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27557, to_date('12-06-2075', 'dd-mm-yyyy'), '3', '12', '163', '06', '2075', '24', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27558, to_date('13-06-2075', 'dd-mm-yyyy'), '4', '13', '164', '06', '2075', '24', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27559, to_date('14-06-2075', 'dd-mm-yyyy'), '5', '14', '165', '06', '2075', '24', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27560, to_date('15-06-2075', 'dd-mm-yyyy'), '6', '15', '166', '06', '2075', '24', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27561, to_date('16-06-2075', 'dd-mm-yyyy'), '7', '16', '167', '06', '2075', '24', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27562, to_date('17-06-2075', 'dd-mm-yyyy'), '1', '17', '168', '06', '2075', '25', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27563, to_date('18-06-2075', 'dd-mm-yyyy'), '2', '18', '169', '06', '2075', '25', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27564, to_date('19-06-2075', 'dd-mm-yyyy'), '3', '19', '170', '06', '2075', '25', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27565, to_date('20-06-2075', 'dd-mm-yyyy'), '4', '20', '171', '06', '2075', '25', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27566, to_date('21-06-2075', 'dd-mm-yyyy'), '5', '21', '172', '06', '2075', '25', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27567, to_date('22-06-2075', 'dd-mm-yyyy'), '6', '22', '173', '06', '2075', '25', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27568, to_date('23-06-2075', 'dd-mm-yyyy'), '7', '23', '174', '06', '2075', '25', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27569, to_date('24-06-2075', 'dd-mm-yyyy'), '1', '24', '175', '06', '2075', '26', '2', 'MONTAG    ', 'MO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27570, to_date('25-06-2075', 'dd-mm-yyyy'), '2', '25', '176', '06', '2075', '26', '2', 'DIENSTAG  ', 'DI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27571, to_date('26-06-2075', 'dd-mm-yyyy'), '3', '26', '177', '06', '2075', '26', '2', 'MITTWOCH  ', 'MI', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27572, to_date('27-06-2075', 'dd-mm-yyyy'), '4', '27', '178', '06', '2075', '26', '2', 'DONNERSTAG', 'DO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27573, to_date('28-06-2075', 'dd-mm-yyyy'), '5', '28', '179', '06', '2075', '26', '2', 'FREITAG   ', 'FR', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27574, to_date('29-06-2075', 'dd-mm-yyyy'), '6', '29', '180', '06', '2075', '26', '2', 'SAMSTAG   ', 'SA', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27575, to_date('30-06-2075', 'dd-mm-yyyy'), '7', '30', '181', '06', '2075', '26', '2', 'SONNTAG   ', 'SO', 'JUNI     ', 'JUN');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27576, to_date('01-07-2075', 'dd-mm-yyyy'), '1', '01', '182', '07', '2075', '27', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27577, to_date('02-07-2075', 'dd-mm-yyyy'), '2', '02', '183', '07', '2075', '27', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27578, to_date('03-07-2075', 'dd-mm-yyyy'), '3', '03', '184', '07', '2075', '27', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27579, to_date('04-07-2075', 'dd-mm-yyyy'), '4', '04', '185', '07', '2075', '27', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27580, to_date('05-07-2075', 'dd-mm-yyyy'), '5', '05', '186', '07', '2075', '27', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27581, to_date('06-07-2075', 'dd-mm-yyyy'), '6', '06', '187', '07', '2075', '27', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27582, to_date('07-07-2075', 'dd-mm-yyyy'), '7', '07', '188', '07', '2075', '27', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27583, to_date('08-07-2075', 'dd-mm-yyyy'), '1', '08', '189', '07', '2075', '28', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27584, to_date('09-07-2075', 'dd-mm-yyyy'), '2', '09', '190', '07', '2075', '28', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27585, to_date('10-07-2075', 'dd-mm-yyyy'), '3', '10', '191', '07', '2075', '28', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27586, to_date('11-07-2075', 'dd-mm-yyyy'), '4', '11', '192', '07', '2075', '28', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27587, to_date('12-07-2075', 'dd-mm-yyyy'), '5', '12', '193', '07', '2075', '28', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27588, to_date('13-07-2075', 'dd-mm-yyyy'), '6', '13', '194', '07', '2075', '28', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27589, to_date('14-07-2075', 'dd-mm-yyyy'), '7', '14', '195', '07', '2075', '28', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27590, to_date('15-07-2075', 'dd-mm-yyyy'), '1', '15', '196', '07', '2075', '29', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27591, to_date('16-07-2075', 'dd-mm-yyyy'), '2', '16', '197', '07', '2075', '29', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27592, to_date('17-07-2075', 'dd-mm-yyyy'), '3', '17', '198', '07', '2075', '29', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27593, to_date('18-07-2075', 'dd-mm-yyyy'), '4', '18', '199', '07', '2075', '29', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27594, to_date('19-07-2075', 'dd-mm-yyyy'), '5', '19', '200', '07', '2075', '29', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27595, to_date('20-07-2075', 'dd-mm-yyyy'), '6', '20', '201', '07', '2075', '29', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27596, to_date('21-07-2075', 'dd-mm-yyyy'), '7', '21', '202', '07', '2075', '29', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27597, to_date('22-07-2075', 'dd-mm-yyyy'), '1', '22', '203', '07', '2075', '30', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27598, to_date('23-07-2075', 'dd-mm-yyyy'), '2', '23', '204', '07', '2075', '30', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27599, to_date('24-07-2075', 'dd-mm-yyyy'), '3', '24', '205', '07', '2075', '30', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27600, to_date('25-07-2075', 'dd-mm-yyyy'), '4', '25', '206', '07', '2075', '30', '3', 'DONNERSTAG', 'DO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27601, to_date('26-07-2075', 'dd-mm-yyyy'), '5', '26', '207', '07', '2075', '30', '3', 'FREITAG   ', 'FR', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27602, to_date('27-07-2075', 'dd-mm-yyyy'), '6', '27', '208', '07', '2075', '30', '3', 'SAMSTAG   ', 'SA', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27603, to_date('28-07-2075', 'dd-mm-yyyy'), '7', '28', '209', '07', '2075', '30', '3', 'SONNTAG   ', 'SO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27604, to_date('29-07-2075', 'dd-mm-yyyy'), '1', '29', '210', '07', '2075', '31', '3', 'MONTAG    ', 'MO', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27605, to_date('30-07-2075', 'dd-mm-yyyy'), '2', '30', '211', '07', '2075', '31', '3', 'DIENSTAG  ', 'DI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27606, to_date('31-07-2075', 'dd-mm-yyyy'), '3', '31', '212', '07', '2075', '31', '3', 'MITTWOCH  ', 'MI', 'JULI     ', 'JUL');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27607, to_date('01-08-2075', 'dd-mm-yyyy'), '4', '01', '213', '08', '2075', '31', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27608, to_date('02-08-2075', 'dd-mm-yyyy'), '5', '02', '214', '08', '2075', '31', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27609, to_date('03-08-2075', 'dd-mm-yyyy'), '6', '03', '215', '08', '2075', '31', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27610, to_date('04-08-2075', 'dd-mm-yyyy'), '7', '04', '216', '08', '2075', '31', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27611, to_date('05-08-2075', 'dd-mm-yyyy'), '1', '05', '217', '08', '2075', '32', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27612, to_date('06-08-2075', 'dd-mm-yyyy'), '2', '06', '218', '08', '2075', '32', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27613, to_date('07-08-2075', 'dd-mm-yyyy'), '3', '07', '219', '08', '2075', '32', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27614, to_date('08-08-2075', 'dd-mm-yyyy'), '4', '08', '220', '08', '2075', '32', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27615, to_date('09-08-2075', 'dd-mm-yyyy'), '5', '09', '221', '08', '2075', '32', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27616, to_date('10-08-2075', 'dd-mm-yyyy'), '6', '10', '222', '08', '2075', '32', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27617, to_date('11-08-2075', 'dd-mm-yyyy'), '7', '11', '223', '08', '2075', '32', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27618, to_date('12-08-2075', 'dd-mm-yyyy'), '1', '12', '224', '08', '2075', '33', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27619, to_date('13-08-2075', 'dd-mm-yyyy'), '2', '13', '225', '08', '2075', '33', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27620, to_date('14-08-2075', 'dd-mm-yyyy'), '3', '14', '226', '08', '2075', '33', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27621, to_date('15-08-2075', 'dd-mm-yyyy'), '4', '15', '227', '08', '2075', '33', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27622, to_date('16-08-2075', 'dd-mm-yyyy'), '5', '16', '228', '08', '2075', '33', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27623, to_date('17-08-2075', 'dd-mm-yyyy'), '6', '17', '229', '08', '2075', '33', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27624, to_date('18-08-2075', 'dd-mm-yyyy'), '7', '18', '230', '08', '2075', '33', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27625, to_date('19-08-2075', 'dd-mm-yyyy'), '1', '19', '231', '08', '2075', '34', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27626, to_date('20-08-2075', 'dd-mm-yyyy'), '2', '20', '232', '08', '2075', '34', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27627, to_date('21-08-2075', 'dd-mm-yyyy'), '3', '21', '233', '08', '2075', '34', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27628, to_date('22-08-2075', 'dd-mm-yyyy'), '4', '22', '234', '08', '2075', '34', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27629, to_date('23-08-2075', 'dd-mm-yyyy'), '5', '23', '235', '08', '2075', '34', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27630, to_date('24-08-2075', 'dd-mm-yyyy'), '6', '24', '236', '08', '2075', '34', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27631, to_date('25-08-2075', 'dd-mm-yyyy'), '7', '25', '237', '08', '2075', '34', '3', 'SONNTAG   ', 'SO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27632, to_date('26-08-2075', 'dd-mm-yyyy'), '1', '26', '238', '08', '2075', '35', '3', 'MONTAG    ', 'MO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27633, to_date('27-08-2075', 'dd-mm-yyyy'), '2', '27', '239', '08', '2075', '35', '3', 'DIENSTAG  ', 'DI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27634, to_date('28-08-2075', 'dd-mm-yyyy'), '3', '28', '240', '08', '2075', '35', '3', 'MITTWOCH  ', 'MI', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27635, to_date('29-08-2075', 'dd-mm-yyyy'), '4', '29', '241', '08', '2075', '35', '3', 'DONNERSTAG', 'DO', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27636, to_date('30-08-2075', 'dd-mm-yyyy'), '5', '30', '242', '08', '2075', '35', '3', 'FREITAG   ', 'FR', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27637, to_date('31-08-2075', 'dd-mm-yyyy'), '6', '31', '243', '08', '2075', '35', '3', 'SAMSTAG   ', 'SA', 'AUGUST   ', 'AUG');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27638, to_date('01-09-2075', 'dd-mm-yyyy'), '7', '01', '244', '09', '2075', '35', '3', 'SONNTAG   ', 'SO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27639, to_date('02-09-2075', 'dd-mm-yyyy'), '1', '02', '245', '09', '2075', '36', '3', 'MONTAG    ', 'MO', 'SEPTEMBER', 'SEP');
insert into DIM_DATE (date_id, day_date, day_of_week, day_of_month, day_of_year, month, year, iso_week, quarter, weekday_name, weekday_short_name, month_name, month_short_name)
values (27640, to_date('03-09-2075', 'dd-mm-yyyy'), '2', '03', '246', '09', '2075', '36', '3', 'DIENSTAG  ', 'DI', 'SEPTEMBER', 'SEP');
commit;
prompt 36525 records loaded
prompt Loading DIM_MATERIAL...
insert into DIM_MATERIAL (dma_id, dma_materialname)
values (1, 'Holz');
insert into DIM_MATERIAL (dma_id, dma_materialname)
values (2, 'Metall');
insert into DIM_MATERIAL (dma_id, dma_materialname)
values (3, 'Kunststoff');
insert into DIM_MATERIAL (dma_id, dma_materialname)
values (4, 'Glas');
commit;
prompt 4 records loaded
prompt Loading DIM_SHAPE...
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (6, 'Wrfel');
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (5, 'Kegel');
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (1, 'Quader');
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (2, 'Zylinder');
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (3, 'Kugel');
insert into DIM_SHAPE (dsh_id, dsh_shapename)
values (4, 'Pyramide');
commit;
prompt 6 records loaded
prompt Loading FINRESULTS...
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1990', 'dd-mm-yyyy'), 100000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1991', 'dd-mm-yyyy'), 150000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1992', 'dd-mm-yyyy'), 160000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1993', 'dd-mm-yyyy'), 200000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1994', 'dd-mm-yyyy'), 170000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1995', 'dd-mm-yyyy'), 130000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1996', 'dd-mm-yyyy'), 190000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1997', 'dd-mm-yyyy'), 160000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1998', 'dd-mm-yyyy'), 200000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-1999', 'dd-mm-yyyy'), 140000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2000', 'dd-mm-yyyy'), 120000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2001', 'dd-mm-yyyy'), 90000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2002', 'dd-mm-yyyy'), 100000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2003', 'dd-mm-yyyy'), 110000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2004', 'dd-mm-yyyy'), 150000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2005', 'dd-mm-yyyy'), 140000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2006', 'dd-mm-yyyy'), 160000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2007', 'dd-mm-yyyy'), 180000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2008', 'dd-mm-yyyy'), 200000);
insert into FINRESULTS (year, revenue)
values (to_date('01-07-2009', 'dd-mm-yyyy'), 210000);
commit;
prompt 20 records loaded
prompt Loading FKT_SALES...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 3, 4, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (92, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 3, 2, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (94, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (95, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 6, 1, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (96, 6, 4, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (97, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (97, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (98, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 5, 3, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 1, 3, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (99, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (100, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (101, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (102, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 2, 4, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (103, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (104, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (105, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (106, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 7, 2, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 5, 3, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (107, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (108, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (109, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 6, 4, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (110, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (111, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (111, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (111, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (112, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (113, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (114, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (114, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (114, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (114, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (114, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (115, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 1, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (117, 8, 4, 6, 73, 1314);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (118, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (118, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (119, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (119, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (119, 2, 2, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (119, 6, 1, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (120, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (121, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (122, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (123, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 7, 2, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 1, 1, 4, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (124, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (125, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 1, 2, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (126, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (127, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (128, 4, 4, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 6, 3, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (129, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (130, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (130, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (130, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (130, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (130, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 7, 2, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 4, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 5, 4, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (131, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (132, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (133, 1, 2, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (134, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (135, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 7, 3, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (136, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (137, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (138, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (139, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (6, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (7, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 6, 1, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 7, 1, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (8, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 2, 3, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (9, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (10, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (11, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (12, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (13, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (14, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (14, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (14, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 6, 3, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (15, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (16, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (17, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (18, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (19, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 3, 1, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 2, 2, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (20, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (21, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (22, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (23, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (24, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 3, 3, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (25, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (26, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (27, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (28, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (28, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 1, 1, 3, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (29, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 3, 3, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (30, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (31, 1, 1, 5, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 7, 1, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (32, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (33, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 1, 1, 1, 77, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (34, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (35, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (36, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (37, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (37, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (37, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (38, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (39, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 8, 4, 5, 28, 476);
commit;
prompt 1000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (40, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 5, 2, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (41, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (42, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (43, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (45, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (45, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (45, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (45, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (45, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (46, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (47, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 7, 2, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (48, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (49, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (50, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (51, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (53, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (54, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 4, 4, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (55, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (56, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (56, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (56, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (56, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 1, 4, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (57, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (59, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (60, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (60, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (60, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (60, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (60, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 7, 1, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (61, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (62, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 1, 2, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 6, 4, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (63, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (64, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 6, 1, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (65, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (66, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (67, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 8, 2, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 4, 2, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (68, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (69, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (69, 2, 3, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (69, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (69, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (70, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (71, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (71, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (71, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (71, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (72, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 7, 3, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (73, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (74, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (75, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (76, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (76, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (76, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (76, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (77, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (77, 8, 4, 5, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (77, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 3, 2, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (78, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 4, 3, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 3, 4, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (79, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (80, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (80, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (80, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (81, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (81, 1, 2, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 8, 4, 4, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (82, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (83, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (84, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (85, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (86, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 1, 1, 2, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (87, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (88, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (88, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (88, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (88, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (88, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 1, 4, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (89, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (90, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (91, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (279, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (280, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (281, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (282, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (282, 5, 3, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (282, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (283, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (284, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (284, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (284, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (284, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (285, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (286, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (287, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (288, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 7, 4, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (289, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (290, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (291, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 7, 2, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (292, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 4, 4, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (293, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 8, 4, 6, 64, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (294, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 6, 3, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (295, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (296, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (296, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (296, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 1, 4, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (297, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (298, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (299, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 8, 3, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 3, 1, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (300, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (301, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 8, 1, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 8, 3, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (302, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (303, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (304, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (305, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (306, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (307, 5, 3, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 1, 1, 6, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (308, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (309, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (309, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (309, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (309, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (309, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (310, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (310, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (310, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (310, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (310, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (311, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (312, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (313, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (314, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (314, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (314, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (314, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (314, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (315, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 1, 1, 3, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (316, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (317, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (317, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (317, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (317, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (318, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 3, 3, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (319, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 3, 4, 4, 75, 825);
commit;
prompt 2000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (320, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (321, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (322, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (323, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (324, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 7, 4, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (140, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 4, 4, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (141, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 3, 1, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (142, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (143, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (144, 8, 3, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (144, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (146, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (147, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (148, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (149, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (149, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (149, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 6, 1, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (150, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 1, 4, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 3, 3, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 7, 2, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (151, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 7, 4, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (152, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (153, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 5, 4, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (154, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 5, 4, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (155, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 3, 3, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (156, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 1, 4, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (157, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (158, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 3, 4, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 5, 4, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (159, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (160, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (161, 4, 3, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 8, 1, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (162, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (163, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 6, 4, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (164, 5, 3, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 6, 2, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (165, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (166, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (167, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (168, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (169, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (170, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (171, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (171, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (171, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (171, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (171, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (172, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 1, 3, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (173, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (174, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (175, 1, 2, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (176, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (177, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (177, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (177, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (177, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (180, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (181, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (181, 4, 4, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (181, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (181, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (182, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (183, 1, 1, 3, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (184, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 5, 1, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (185, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (186, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 5, 4, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 2, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (187, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 4, 3, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 1, 2, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (188, 5, 1, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 7, 2, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (189, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 3, 1, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 3, 3, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (190, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (191, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 8, 1, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 2, 3, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (192, 4, 3, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 1, 4, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (193, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (194, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (194, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (195, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (195, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (196, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 3, 3, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 8, 4, 4, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (197, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (198, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (199, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (201, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (201, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (202, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (203, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (204, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 1, 4, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 1, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (205, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (206, 6, 2, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (206, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (206, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (206, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (207, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 1, 2, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 8, 1, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 5, 1, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (208, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 3, 3, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (209, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 1, 1, 2, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (210, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (212, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (213, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (213, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (213, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (213, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (213, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (214, 8, 2, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (214, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (214, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (214, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 4, 2, 1, 64, 448);
commit;
prompt 3000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (215, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (216, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (216, 1, 4, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (216, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 5, 2, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (217, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 8, 2, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (218, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (219, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (219, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (219, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (219, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 5, 3, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (220, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (221, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (221, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (221, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (221, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (221, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 1, 1, 1, 95, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (222, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (223, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 3, 3, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (224, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (225, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (225, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (225, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (225, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (225, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (226, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 1, 1, 2, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (227, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (228, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (229, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (230, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (231, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (232, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (233, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (234, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (235, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (236, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (237, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 8, 4, 6, 38, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (238, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (239, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (240, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (240, 7, 4, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (240, 7, 1, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 8, 1, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (241, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (242, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (242, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (242, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (242, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (243, 6, 1, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 3, 4, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 2, 4, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (244, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (245, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 1, 3, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (246, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 1, 2, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (247, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (248, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 4, 1, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (249, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (250, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (250, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (251, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (252, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (253, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (254, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (255, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 7, 1, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (256, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 4, 3, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (257, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (258, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (259, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (259, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (259, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (260, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (261, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 5, 3, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (262, 6, 4, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (263, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (264, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (265, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 2, 1, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 4, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (266, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 7, 1, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (267, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 8, 3, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (268, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 2, 4, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (269, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 4, 2, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 4, 2, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (270, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (271, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (271, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (271, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (271, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 6, 3, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (272, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 6, 4, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 7, 2, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (273, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (274, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 6, 3, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (275, 7, 4, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 2, 1, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (276, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 8, 2, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 8, 4, 3, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 4, 1, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (277, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (278, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 3, 3, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (325, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (326, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (327, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (327, 3, 3, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (327, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (327, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (328, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (328, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (328, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 6, 2, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (329, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (330, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (331, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (332, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (333, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (334, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (335, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 5, 3, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (336, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (338, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (339, 3, 3, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (340, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (340, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (340, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 2, 2, 2, 18, 108);
commit;
prompt 4000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (341, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (342, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (343, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 6, 1, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (344, 7, 2, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (345, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (345, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (345, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (346, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 5, 4, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (347, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 1, 2, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (348, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 2, 2, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (349, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (350, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (351, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (352, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (353, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 6, 2, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (354, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (355, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (356, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (357, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (358, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 5, 2, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (359, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (360, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 3, 1, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (361, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 3, 2, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (362, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (363, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (364, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (364, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (364, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (364, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (364, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 1, 1, 1, 27, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 8, 3, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (365, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (366, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (366, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (367, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 2, 3, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 6, 2, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (368, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (369, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (369, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (369, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (369, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (369, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (370, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 8, 2, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 6, 2, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (371, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (372, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (373, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 7, 1, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (374, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (375, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (376, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (377, 1, 4, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (378, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (379, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (380, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 7, 2, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (381, 2, 3, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (382, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (383, 3, 2, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 7, 2, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 6, 1, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (384, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 3, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 1, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 4, 6, 12, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 4, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 4, 3, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (385, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 3, 4, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 6, 3, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 1, 4, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (386, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (387, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 7, 2, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (388, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 6, 1, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (389, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (446, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (447, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (448, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (449, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 7, 3, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (450, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (451, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (452, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 5, 1, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 4, 1, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (453, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (454, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (455, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 3, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 6, 4, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (456, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 3, 4, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (457, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 2, 1, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (458, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 4, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (459, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (460, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 4, 4, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (461, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 2, 3, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 1, 1, 1, 2, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (462, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 3, 1, 95, 855);
commit;
prompt 5000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (390, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 1, 1, 3, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 4, 2, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 7, 4, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (391, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (392, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (392, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (392, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (392, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (392, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 3, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (393, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 7, 1, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (394, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 7, 4, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 7, 2, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (396, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (397, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (398, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (399, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (400, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (401, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (402, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (402, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (402, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (402, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (402, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 8, 2, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (403, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (404, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 7, 4, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (405, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (406, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (407, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (408, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (409, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (410, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (411, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (412, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (412, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (412, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (412, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 2, 2, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 7, 2, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (413, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (414, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (415, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (417, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (417, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (417, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (417, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 6, 2, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (418, 4, 4, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 4, 4, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 1, 2, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (419, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 8, 1, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (420, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 3, 2, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (421, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (422, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 1, 4, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 5, 4, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (423, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 1, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 3, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (424, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (425, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 8, 4, 4, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (426, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 1, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 4, 2, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 1, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (427, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 1, 3, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (428, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 1, 3, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 8, 1, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (429, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 4, 3, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (430, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 8, 3, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (431, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 6, 3, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (432, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 6, 2, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (433, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (434, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (435, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (435, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (435, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (435, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (435, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (436, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 3, 1, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (437, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 7, 1, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (438, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 8, 4, 6, 62, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (439, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (440, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (440, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (440, 7, 1, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (440, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (441, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (441, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (441, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (441, 1, 3, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (441, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 8, 3, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (442, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (443, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (443, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (443, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (444, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (445, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 7, 1, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (572, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 5, 2, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (573, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 2, 4, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 7, 3, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (574, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (575, 1, 1, 4, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 7, 2, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (576, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (577, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (577, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (577, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (578, 7, 1, 4, 6, 72);
commit;
prompt 6000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 6, 4, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (579, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (580, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 6, 1, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (581, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 4, 2, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 5, 1, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (582, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (583, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (584, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (585, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 2, 4, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (586, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 2, 3, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 3, 1, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (587, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (588, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 1, 1, 1, 22, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (589, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (590, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (590, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (590, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 6, 4, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 8, 3, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (591, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (592, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (592, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (592, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (592, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (593, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (594, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (595, 2, 4, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (595, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (595, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (595, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (595, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 3, 2, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (596, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (597, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (598, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 8, 2, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 6, 4, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (599, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 6, 2, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (600, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 8, 4, 3, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (601, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (602, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (603, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (604, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (605, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 4, 1, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (463, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (464, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (465, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (465, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (465, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (465, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (466, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (467, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (468, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (469, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (470, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 1, 4, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (471, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (472, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 2, 2, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (473, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 3, 4, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 4, 1, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 5, 4, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (474, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (475, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 2, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (476, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (477, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 6, 4, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (478, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (479, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (479, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (479, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (479, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (479, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (480, 6, 3, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (480, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (480, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (480, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (480, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (481, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 4, 4, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 2, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (482, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 5, 2, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (483, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (484, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (485, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 1, 3, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (486, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (487, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (488, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (488, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (488, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (488, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (489, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (489, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (489, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (489, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (489, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (490, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 1, 1, 1, 44, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (491, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 1, 1, 1, 30, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 7, 3, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (492, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 2, 2, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 6, 3, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (493, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (494, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (495, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (495, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (495, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (495, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (496, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 3, 3, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 1, 2, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 1, 1, 1, 99, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 8, 1, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (497, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (498, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 7, 4, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (499, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (500, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 7, 1, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 6, 3, 5, 63, 882);
commit;
prompt 7000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 1, 4, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 7, 3, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 6, 1, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (501, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 7, 1, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (502, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 4, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (503, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 4, 4, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (504, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (505, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 5, 2, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (506, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (507, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (508, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 5, 1, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 8, 1, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 1, 4, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (509, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 7, 1, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (510, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 1, 1, 5, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (511, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 7, 1, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (512, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 5, 3, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (513, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (514, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (515, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (516, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 8, 4, 6, 95, 1710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (517, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 2, 4, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (518, 7, 2, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 2, 3, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (520, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 4, 4, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (521, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 3, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 1, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (522, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (523, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (524, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 5, 2, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (525, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (526, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (527, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (528, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 4, 4, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (529, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 3, 4, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (530, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (531, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (531, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (531, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (531, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (531, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (532, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 8, 2, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (533, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 3, 2, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (534, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 3, 4, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (535, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (536, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 4, 1, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (537, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (538, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (539, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 4, 1, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 1, 4, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 5, 2, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (540, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (541, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 4, 3, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (542, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (543, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 5, 1, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (544, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 3, 2, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 5, 4, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 7, 3, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (545, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (546, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (547, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 2, 1, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 4, 3, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (548, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 2, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (549, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (550, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 7, 3, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (551, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 8, 3, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (552, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 7, 2, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (553, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 6, 2, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (554, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 3, 4, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (555, 4, 3, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 1, 2, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (556, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (557, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 1, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (558, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 2, 1, 4, 16);
commit;
prompt 8000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (559, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (560, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (561, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 1, 2, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (562, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (563, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 6, 1, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (564, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (565, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (566, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 2, 4, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 8, 3, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (567, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 6, 3, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (568, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 4, 6, 1, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 4, 1, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 6, 4, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (569, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (570, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (571, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (606, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (607, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 3, 2, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (608, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 5, 2, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (609, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 4, 1, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (610, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 2, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (611, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 3, 1, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (612, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 2, 2, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 3, 1, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (613, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (614, 4, 4, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (615, 1, 2, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (616, 3, 4, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 6, 2, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (617, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 3, 3, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (618, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (619, 7, 2, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (619, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (619, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (620, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (621, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (622, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 1, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (623, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (624, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 6, 3, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (625, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 3, 4, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (626, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (627, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (628, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (628, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (628, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (628, 7, 2, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (629, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (630, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (631, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (632, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (633, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (634, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (635, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 1, 4, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (636, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 3, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 4, 3, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 1, 1, 1, 98, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (637, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 4, 2, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (638, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 7, 3, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (639, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (640, 8, 1, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (641, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (642, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (643, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 7, 1, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (644, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 5, 2, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (645, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (646, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 4, 1, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 1, 3, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (647, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 1, 2, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (648, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (649, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 4, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 2, 4, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (650, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (651, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (652, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 5, 3, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (653, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 1, 1, 3, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 6, 4, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 4, 1, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (654, 2, 4, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 2, 4, 5, 65, 715);
commit;
prompt 9000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (655, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (657, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (658, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (658, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (658, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (658, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (658, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 3, 3, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (659, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (660, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 5, 3, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 8, 4, 6, 28, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (716, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (717, 2, 4, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (718, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (718, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (718, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (719, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 7, 4, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (721, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 6, 1, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 1, 1, 3, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (722, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (724, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 1, 4, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 1, 1, 5, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 8, 4, 6, 18, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 4, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (725, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (726, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (727, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (728, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 5, 2, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (729, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 3, 2, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (730, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 7, 4, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 4, 1, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 2, 2, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 6, 3, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (731, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (732, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 8, 2, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (733, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (734, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 3, 1, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 7, 1, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (661, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (662, 7, 4, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (663, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (663, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (663, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (663, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (663, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (664, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (664, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (664, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (664, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (665, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (666, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 6, 2, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (667, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (668, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (669, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 7, 1, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (670, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (671, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 5, 4, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 6, 4, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (672, 3, 1, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (673, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (674, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 5, 2, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (675, 5, 2, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 5, 4, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 5, 2, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (677, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 6, 1, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (678, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (679, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (680, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 1, 3, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 6, 2, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (681, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (682, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 3, 3, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 1, 1, 6, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (683, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (684, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (684, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (684, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (684, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 3, 2, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (685, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (686, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (687, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 1, 1, 3, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 1, 4, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (688, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 3, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (689, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (690, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 3, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 2, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 8, 3, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (691, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 8, 4, 6, 95, 1710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (692, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 8, 4, 6, 81, 1458);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (693, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (694, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (695, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (696, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 6, 2, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (697, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 4, 3, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (698, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 2, 4, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 6, 2, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 1, 4, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (699, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 2, 3, 3, 6, 48);
commit;
prompt 10000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 7, 4, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 3, 1, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 6, 2, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 8, 3, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (700, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 1, 1, 1, 91, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 8, 2, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (701, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (702, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (703, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (704, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (704, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (704, 4, 1, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (704, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (704, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (705, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (706, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (707, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 1, 1, 2, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (708, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (709, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (710, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (711, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 2, 2, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (712, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (713, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (714, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 1, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (715, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 8, 2, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 8, 2, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (837, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (838, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 3, 4, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 1, 1, 2, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 7, 1, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 3, 3, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (839, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 3, 1, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (840, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 3, 3, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (841, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 6, 2, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 3, 1, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (842, 7, 2, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 1, 1, 1, 27, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (843, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (844, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (845, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 2, 4, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (846, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 2, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (847, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 2, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 3, 4, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 4, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (848, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 6, 3, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (849, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (850, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (851, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 7, 4, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (852, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (853, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (854, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (857, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 7, 4, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 5, 1, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (858, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (859, 3, 4, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (860, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 6, 1, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (861, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (862, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 1, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (863, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (735, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 4, 1, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 4, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 2, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 8, 2, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 4, 3, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (736, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 1, 1, 4, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (737, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 3, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 3, 4, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 8, 4, 6, 64, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (738, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 1, 1, 4, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 1, 2, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 2, 3, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 1, 1, 6, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (739, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 5, 4, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (741, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 1, 1, 4, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (742, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 4, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 8, 1, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (743, 7, 4, 1, 42, 504);
commit;
prompt 11000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (744, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 4, 2, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 2, 2, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (745, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 7, 2, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (746, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (747, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (748, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 6, 1, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (749, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 7, 1, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 2, 3, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (750, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 5, 4, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (751, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 8, 4, 1, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 1, 1, 1, 1, 3);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (752, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 7, 2, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 3, 3, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (753, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 1, 1, 5, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (754, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 4, 4, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 7, 4, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (755, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (756, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 4, 4, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (757, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 4, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (758, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 8, 3, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (759, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 3, 3, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (760, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (761, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 4, 1, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (762, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (764, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (764, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (764, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (764, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (764, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 4, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 8, 4, 1, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (765, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 6, 3, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (766, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 1, 4, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (768, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (769, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (769, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (769, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (769, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (770, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 5, 1, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (771, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 3, 2, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 6, 3, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (772, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (773, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 8, 4, 3, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (774, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 2, 2, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (775, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 3, 2, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (776, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (777, 4, 2, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (777, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (777, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (777, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (777, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 3, 1, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 1, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (778, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 6, 2, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (779, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (780, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (781, 4, 2, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (782, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 3, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 1, 3, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (783, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (784, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 6, 4, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (785, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (788, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 4, 2, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 4, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (789, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (790, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 5, 3, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 5, 3, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (791, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (792, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (793, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (794, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (795, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (795, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (795, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (795, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (795, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (796, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 1, 1, 30, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (798, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (799, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (800, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (801, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (802, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 2, 1, 4, 84, 588);
commit;
prompt 12000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (803, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (804, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 4, 3, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (805, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (806, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 3, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 6, 1, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (807, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 8, 1, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (808, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (809, 4, 2, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (810, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (811, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (811, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (811, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (811, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (811, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 3, 4, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 5, 3, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 7, 1, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (812, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 7, 2, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 4, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 3, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 6, 2, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 5, 1, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (813, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 3, 4, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 2, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (814, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (815, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (816, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (817, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (818, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 1, 1, 4, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 2, 4, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (819, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 2, 4, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (820, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (821, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (822, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 3, 3, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (823, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 3, 2, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (824, 2, 2, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 8, 3, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 1, 2, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 4, 3, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (825, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (826, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (827, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (827, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (827, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (827, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (827, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (828, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (829, 5, 2, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (830, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (831, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (832, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 5, 4, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (833, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 5, 3, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (834, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 5, 2, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (835, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (836, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (864, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 1, 3, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (865, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 1, 1, 1, 51, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (866, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 4, 1, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (867, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 1, 3, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (868, 8, 1, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (869, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 1, 1, 6, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (870, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (871, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 8, 3, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 4, 1, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 4, 3, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 1, 4, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (872, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (873, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 4, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 3, 3, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (874, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (875, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 8, 1, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (876, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (877, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (877, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (877, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (877, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (877, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 6, 3, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (878, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 6, 3, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (879, 2, 1, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (880, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (881, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 6, 4, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 2, 3, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (882, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (883, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 1, 2, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 5, 3, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (884, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (885, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 1, 2, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (886, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 8, 2, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 1, 4, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (887, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 4, 3, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (888, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 2, 1, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 3, 3, 48, 672);
commit;
prompt 13000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (889, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (890, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (891, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 2, 4, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (892, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (893, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (893, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (893, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (893, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (893, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 3, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (894, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 5, 4, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (895, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 6, 3, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 2, 1, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 1, 1, 2, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (896, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (897, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 7, 1, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (898, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (899, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (900, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (901, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (901, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (901, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (901, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (901, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 8, 4, 6, 22, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 1, 1, 53, 159);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 4, 3, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (902, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 7, 3, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (903, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (904, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (905, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (906, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 3, 1, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (907, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (908, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (910, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 5, 2, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 3, 1, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 2, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (911, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 2, 4, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (912, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 5, 3, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 2, 4, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (913, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (914, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 8, 4, 4, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 7, 3, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (915, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (916, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (917, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 5, 3, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 6, 3, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (969, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (970, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (971, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (971, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (971, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (971, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (971, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (972, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (972, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (972, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (972, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (972, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (973, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (974, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (974, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (974, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (974, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 4, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (975, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (976, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 4, 2, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (977, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 4, 4, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (978, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (979, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (980, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (981, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (984, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (918, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 4, 3, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (919, 7, 4, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (920, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (921, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 1, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 1, 1, 1, 63, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (922, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 4, 2, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 7, 4, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 6, 1, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (923, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (924, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 6, 2, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (925, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 1, 2, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (926, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 5, 4, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (927, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (928, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 6, 1, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 8, 2, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (929, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 8, 2, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (930, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 7, 4, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 4, 1, 35, 210);
commit;
prompt 14000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (931, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (932, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 7, 2, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (934, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 1, 2, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (935, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (936, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 6, 3, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (937, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 3, 4, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (938, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (939, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (940, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 1, 3, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 6, 3, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (941, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (942, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 4, 2, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 5, 2, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (943, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (944, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (946, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (947, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 3, 2, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (948, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 7, 1, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (949, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (950, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 2, 2, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (951, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (952, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (953, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 3, 4, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (955, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 6, 2, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (956, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (957, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (957, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (957, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (957, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (957, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (958, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 1, 4, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (959, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 8, 1, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (960, 1, 2, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (961, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (962, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (963, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 4, 3, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (964, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (965, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (966, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (966, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (966, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (966, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (966, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (967, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (968, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 5, 3, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1066, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1067, 3, 1, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1068, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 7, 1, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 6, 1, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1069, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1070, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 1, 3, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1071, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1072, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1072, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1072, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1072, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 7, 1, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1073, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 6, 4, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 6, 4, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 4, 3, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 7, 2, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1074, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 7, 2, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 2, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1075, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 3, 1, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1076, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 8, 2, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1077, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 2, 4, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 4, 1, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1078, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 4, 2, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1079, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1080, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1080, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1080, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1080, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 2, 4, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1081, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 2, 4, 1, 54, 378);
commit;
prompt 15000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 8, 1, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1082, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 3, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1083, 3, 2, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 7, 1, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 4, 3, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1084, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1085, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1086, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1087, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1088, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1089, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1090, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1090, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1090, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1090, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1090, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1091, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1092, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1093, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1094, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1094, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1094, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1094, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1094, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 8, 3, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 6, 4, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (985, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (986, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (987, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 1, 4, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 5, 3, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (988, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 2, 4, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (989, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (990, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 6, 2, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (991, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 5, 1, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (992, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (993, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (994, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (994, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (994, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (994, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 1, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 2, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 1, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (995, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (996, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 5, 1, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (997, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 4, 1, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 6, 3, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 4, 1, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (998, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (999, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 1, 2, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1000, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 1, 4, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1001, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 7, 4, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 2, 2, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1002, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1003, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 6, 2, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1004, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1005, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 4, 3, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 6, 4, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1006, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 4, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 3, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1007, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 6, 2, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1008, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 3, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 3, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1009, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 8, 1, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 4, 3, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1010, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 3, 3, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 6, 1, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1011, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 5, 3, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1012, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1013, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 7, 3, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1014, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 1, 4, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1015, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1016, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 8, 1, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1017, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1018, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 3, 1, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1019, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1020, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 4, 3, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1021, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 6, 2, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 3, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1022, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 6, 4, 3, 14, 182);
commit;
prompt 16000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 4, 3, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1023, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1024, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1025, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 2, 3, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1026, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1027, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 8, 3, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1028, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1029, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 8, 1, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 5, 1, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1030, 5, 2, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 4, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 2, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 3, 3, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1031, 2, 2, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 1, 1, 1, 92, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1032, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 7, 3, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1033, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1034, 7, 1, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1035, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 4, 4, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 7, 4, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1036, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 1, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1037, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1038, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 1, 2, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1039, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 5, 2, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 2, 4, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1040, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1041, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 8, 4, 6, 95, 1710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1042, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1043, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1044, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 6, 1, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1045, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 2, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 3, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 4, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 4, 3, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 4, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1046, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1047, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1048, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 8, 3, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 8, 3, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1049, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1050, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 5, 2, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 5, 1, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1051, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 2, 1, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 8, 3, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1052, 1, 4, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 4, 1, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1053, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 2, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1054, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1055, 8, 4, 6, 14, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 7, 3, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1056, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1057, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1058, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 2, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1059, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 4, 4, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1060, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1061, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 4, 4, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 8, 4, 6, 80, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1062, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 8, 1, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 3, 2, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1063, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 1, 1, 1, 99, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 3, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1064, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1065, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1095, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 8, 3, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1096, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 2, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 2, 4, 29, 319);
commit;
prompt 17000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 4, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 4, 1, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 8, 3, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1097, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1098, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 6, 1, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1099, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 1, 3, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 5, 3, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1100, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 7, 3, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1101, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 6, 1, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1102, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 4, 1, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1103, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 7, 2, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1104, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1105, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 7, 1, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1106, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 2, 4, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1107, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1108, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 1, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1109, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 6, 2, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1110, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1111, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 3, 1, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1112, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 7, 4, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1113, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1114, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 8, 1, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1115, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1116, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 3, 2, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 2, 1, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 3, 3, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 2, 3, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1117, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 3, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 5, 4, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 1, 4, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1118, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1119, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 4, 3, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1120, 8, 3, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1121, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 7, 2, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 4, 3, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1122, 7, 3, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 3, 4, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1123, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1124, 1, 1, 4, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 5, 4, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1125, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 8, 1, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1126, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 4, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1127, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 8, 2, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 1, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 1, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1128, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1130, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1131, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 8, 2, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1132, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1133, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1134, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1172, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 4, 1, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1173, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 1, 1, 1, 79, 237);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1174, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 1, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 1, 4, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 5, 2, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1175, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 4, 6, 80, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1176, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1177, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1178, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 6, 2, 4, 27, 324);
commit;
prompt 18000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 3, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 7, 1, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1179, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1180, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1181, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1182, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 7, 2, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1183, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1184, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1185, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1135, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1136, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 1, 2, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 1, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1137, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1138, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 4, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 8, 4, 1, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 1, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 5, 1, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1139, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1140, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1141, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 4, 3, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1142, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1143, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 4, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 6, 3, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 1, 2, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1144, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 7, 4, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1145, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1146, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 2, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1147, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1148, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1149, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1150, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 7, 2, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1151, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 8, 4, 6, 92, 1656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1152, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1153, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1154, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1155, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 3, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1156, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 1, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 2, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1157, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 4, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 7, 4, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1158, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 1, 1, 4, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1159, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 4, 4, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1160, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 4, 2, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1161, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 8, 4, 3, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1162, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 2, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1163, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1164, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1165, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 3, 1, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1166, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1168, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1169, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 7, 4, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1170, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 3, 2, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 4, 2, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1171, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 1, 3, 4, 70, 560);
commit;
prompt 19000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1259, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 5, 2, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 8, 1, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1260, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1261, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 4, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 8, 1, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1262, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1263, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 4, 6, 75, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 1, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1264, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1265, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1265, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1265, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1265, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1265, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 7, 4, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 6, 4, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 1, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1266, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1267, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 6, 4, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1268, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1269, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 6, 3, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1270, 7, 3, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 1, 2, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1271, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 7, 1, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1272, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 6, 2, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 8, 4, 3, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1273, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1274, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 1, 1, 99, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 3, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1275, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1276, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 2, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 8, 3, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 2, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1277, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 6, 3, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 8, 2, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1278, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 1, 1, 29, 87);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 1, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 1, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 1, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1279, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 3, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1280, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1281, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 3, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1186, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1188, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 3, 3, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1189, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1190, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1190, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1190, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1190, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1190, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 6, 2, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 2, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1191, 5, 1, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1192, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1193, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 4, 6, 22, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 3, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 4, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1194, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1196, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1197, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 6, 4, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 3, 4, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 4, 4, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1198, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1199, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1200, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1201, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 4, 2, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1202, 7, 1, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 3, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 2, 4, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1203, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 3, 2, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 2, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1204, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 3, 2, 46, 552);
commit;
prompt 20000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 4, 2, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1205, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 1, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 4, 4, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 3, 4, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1206, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 5, 4, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1207, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1208, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 6, 4, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1209, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1210, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 6, 4, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1211, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 2, 4, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1212, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1213, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1214, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 3, 1, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 1, 4, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1215, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 1, 3, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 3, 1, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1216, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1217, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 8, 4, 2, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1218, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1219, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1220, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 6, 4, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1221, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1222, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1223, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1224, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 5, 4, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1225, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 7, 2, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 2, 4, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1226, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 2, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 4, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 8, 4, 6, 94, 1692);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1227, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1228, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 4, 2, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 4, 2, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 3, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1229, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 7, 1, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 4, 3, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 5, 4, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1230, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 1, 1, 3, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 5, 2, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1231, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 1, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1232, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 1, 3, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1233, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1234, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 3, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 8, 1, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1235, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 7, 3, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1236, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 6, 1, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 1, 1, 56, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1237, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 3, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1238, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 3, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 4, 4, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 2, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1239, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1240, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 6, 2, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1241, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 8, 4, 6, 34, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1242, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1243, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 2, 2, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1244, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 2, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 3, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 2, 4, 66, 726);
commit;
prompt 21000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1245, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 1, 4, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 8, 3, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1246, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 7, 3, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 7, 3, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1247, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 5, 4, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 7, 2, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 5, 1, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1248, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1249, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1250, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 6, 2, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1251, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 2, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1252, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 4, 1, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1253, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1254, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 2, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 6, 4, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 3, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1255, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 8, 3, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1256, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1257, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1258, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 1, 2, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1282, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 8, 2, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 8, 4, 6, 61, 1098);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 2, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1283, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1284, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1285, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 3, 2, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 7, 2, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1286, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1287, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1288, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1289, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 3, 3, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1290, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 7, 3, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 3, 1, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1291, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1292, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1293, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 1, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1294, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1295, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 1, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 3, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 2, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 2, 2, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1296, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 3, 3, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1297, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 6, 3, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1298, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1299, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 2, 1, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1300, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 6, 2, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1301, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 6, 2, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1302, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 2, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 8, 2, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1303, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 1, 1, 3, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1304, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1305, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1306, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1307, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 2, 2, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 4, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1308, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 2, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1309, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 5, 4, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 1, 2, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1310, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1312, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 3, 4, 16, 192);
commit;
prompt 22000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1313, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 5, 1, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 3, 4, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1314, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1315, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 7, 4, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 1, 2, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 3, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 6, 2, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1316, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 7, 1, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 7, 4, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 5, 4, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1317, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1318, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 5, 1, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1319, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 1, 2, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 5, 1, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1320, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1362, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 5, 1, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1363, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 3, 3, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1364, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 3, 4, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1365, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 1, 4, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1366, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1367, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 6, 2, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 5, 3, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 1, 3, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1368, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1369, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1370, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 1, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1371, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 8, 4, 6, 17, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1372, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1373, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1321, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 2, 1, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 3, 3, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1322, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 8, 4, 3, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 1, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1323, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1324, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1325, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1325, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1325, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1325, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1325, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1326, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 8, 2, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 1, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1327, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 1, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1328, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1329, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 5, 2, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1330, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1331, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1332, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 2, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 3, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 3, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1333, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 7, 4, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1334, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 4, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1335, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 4, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 3, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1336, 5, 1, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 8, 4, 1, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1337, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 1, 2, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 3, 3, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1338, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1339, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 8, 3, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 7, 4, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 6, 1, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1340, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1341, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1342, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 5, 1, 4, 14, 140);
commit;
prompt 23000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1343, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1344, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 7, 1, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1345, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 6, 2, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1346, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1347, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1348, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 8, 3, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1349, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1350, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 4, 6, 92, 1656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1351, 5, 4, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1352, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1354, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 3, 4, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1355, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 5, 1, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1356, 7, 3, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1357, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 6, 1, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1358, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 8, 4, 6, 78, 1404);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1359, 6, 3, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1360, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 4, 2, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 2, 3, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 1, 1, 6, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1361, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 7, 1, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 8, 2, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 3, 1, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1451, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 7, 3, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 1, 1, 1, 39, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1452, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 6, 3, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1453, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 1, 1, 1, 30, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1454, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1455, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 1, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1456, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 5, 2, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1457, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 7, 4, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1458, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1459, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1460, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 1, 4, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1461, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1462, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 4, 3, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1463, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 6, 2, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 5, 2, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 1, 1, 1, 49, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1464, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 7, 2, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 7, 1, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1465, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 6, 3, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 2, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1466, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 3, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1467, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 7, 2, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1468, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 4, 1, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1469, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 6, 3, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1470, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1471, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1472, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 1, 4, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 3, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1473, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 1, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 2, 3, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 6, 3, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1474, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 3, 1, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1374, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1375, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1376, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 1, 4, 10, 110);
commit;
prompt 24000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 8, 2, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1377, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 8, 4, 6, 48, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 4, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 6, 2, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1378, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1379, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 2, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1380, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1381, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 2, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1382, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1383, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1384, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1385, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1386, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1386, 4, 3, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1386, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1386, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1386, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 6, 3, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 4, 2, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1387, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1388, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 5, 2, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 1, 3, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1389, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1390, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1391, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1392, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 7, 1, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1393, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 7, 3, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 3, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 2, 2, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1394, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 1, 3, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1395, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 4, 1, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1396, 6, 4, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 7, 3, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1397, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 8, 4, 6, 61, 1098);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 8, 4, 1, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1398, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1399, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 3, 1, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1400, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 3, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 8, 2, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1401, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 1, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1402, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1403, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1404, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 1, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 6, 1, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 6, 3, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1405, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 7, 2, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1406, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 1, 2, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1407, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1408, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1409, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1410, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1411, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 7, 4, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1412, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1413, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 4, 2, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 1, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 4, 4, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1414, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1415, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 1, 3, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1416, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 1, 4, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1417, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1418, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1418, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1418, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1418, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1418, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 1, 2, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1419, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 4, 1, 6, 71, 781);
commit;
prompt 25000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 7, 3, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1420, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1421, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 5, 3, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1422, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 8, 4, 2, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 1, 1, 2, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1423, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1424, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1426, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1427, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 8, 3, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 4, 2, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1428, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1429, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 6, 2, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1430, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1431, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1432, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 6, 3, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 8, 4, 4, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1433, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1434, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1435, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1436, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 2, 3, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1437, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 6, 1, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 5, 3, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1438, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1439, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 3, 1, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1440, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1441, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1442, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 3, 3, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 4, 4, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1443, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 2, 2, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1444, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1445, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 1, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 1, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1446, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 2, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 4, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1447, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 2, 4, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1448, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 1, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 7, 2, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1449, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1450, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1475, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 8, 4, 6, 58, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 3, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1476, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 7, 3, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1477, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1478, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1479, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1480, 1, 4, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 8, 1, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 3, 1, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1481, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 3, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 1, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 4, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1482, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1483, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 3, 1, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 5, 2, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 1, 3, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1484, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 6, 3, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 7, 3, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1485, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 4, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1486, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 4, 1, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 4, 1, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 7, 1, 4, 21, 252);
commit;
prompt 26000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1487, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 5, 4, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1488, 1, 1, 1, 22, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1489, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1490, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 2, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1491, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 8, 4, 4, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1492, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1493, 7, 4, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1494, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 1, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 4, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 1, 1, 1, 14, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 8, 1, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1495, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 2, 3, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 7, 1, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1496, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 3, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1497, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 8, 2, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1498, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 6, 4, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1499, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 5, 1, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1500, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 2, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 4, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 2, 2, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1501, 5, 1, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 1, 1, 28, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1502, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1503, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 2, 1, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 7, 3, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1504, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 8, 2, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1505, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 3, 3, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 3, 1, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 5, 4, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1506, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1507, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 5, 1, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1543, 4, 3, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 2, 4, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 7, 3, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1544, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1545, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1546, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 4, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1547, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 7, 3, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1548, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1549, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 4, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1550, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 4, 1, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 6, 3, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1551, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 7, 1, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1552, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 7, 3, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1508, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1509, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 1, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 3, 2, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1510, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1511, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 2, 1, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1512, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 5, 1, 3, 71, 639);
commit;
prompt 27000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 4, 2, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1513, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1514, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 5, 3, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 4, 3, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1515, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 1, 3, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1516, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 6, 1, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1518, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1519, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 3, 4, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1520, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 3, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1521, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 4, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1522, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 7, 2, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 4, 2, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 6, 1, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1523, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 3, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 6, 4, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1524, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 4, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1525, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 6, 2, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1526, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 1, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 2, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1527, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 8, 3, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1528, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 1, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 3, 1, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1529, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1530, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1531, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1533, 5, 4, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1534, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1535, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1536, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 7, 3, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1537, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 1, 1, 1, 74, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1538, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 8, 3, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1539, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 4, 4, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1540, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 3, 4, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 4, 2, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1541, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1542, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 3, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 4, 4, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 5, 2, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1626, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 1, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1627, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 8, 1, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 6, 3, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 2, 3, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 4, 3, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1628, 1, 2, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 8, 4, 5, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 5, 3, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1629, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1630, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1631, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 7, 4, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1632, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 7, 4, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1633, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 7, 2, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1634, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1635, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 6, 2, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 5, 1, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1636, 5, 2, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 6, 1, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 6, 1, 2, 48, 432);
commit;
prompt 28000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 1, 2, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 6, 4, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1637, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 3, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 6, 3, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1638, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1639, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1640, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1641, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 1, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1642, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 1, 2, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1643, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 1, 3, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1644, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 3, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 8, 3, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 1, 1, 1, 29, 87);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1645, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 2, 1, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 3, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 3, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 3, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1646, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 1, 1, 47, 141);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 4, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 1, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1553, 1, 1, 2, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 2, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 5, 4, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1554, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 3, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 2, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 4, 4, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1555, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 1, 1, 97, 291);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 4, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 2, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1556, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 1, 2, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1557, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1558, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 4, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 3, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 1, 4, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1559, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1560, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1561, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 1, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1562, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 6, 1, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1563, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1564, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1565, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 8, 4, 6, 76, 1368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1566, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 7, 3, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1567, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 4, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 3, 3, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1568, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 5, 3, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 8, 4, 4, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1569, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1570, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 2, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1571, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 7, 2, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1572, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 2, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 4, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 4, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 7, 3, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1573, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1574, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1575, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1576, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 1, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 1, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 3, 2, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 3, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 1, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1577, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 3, 2, 3, 58, 464);
commit;
prompt 29000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1578, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 7, 1, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 2, 2, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 1, 2, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 7, 1, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 5, 3, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1579, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1580, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1581, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1582, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1583, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 1, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1584, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 7, 3, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1585, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 1, 1, 1, 97, 291);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 8, 3, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 2, 1, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1586, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 6, 4, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1587, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1588, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 1, 1, 1, 40, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 3, 4, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 7, 2, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 4, 2, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1589, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 2, 1, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 8, 4, 6, 20, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 2, 1, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1590, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 2, 2, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 1, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1591, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 5, 2, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1592, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1593, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1595, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 4, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1596, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 2, 3, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 2, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1597, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1599, 4, 1, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1600, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 4, 3, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 2, 3, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1601, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 2, 1, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1602, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1603, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1604, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 1, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1605, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 3, 1, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1606, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 1, 1, 1, 26, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 7, 1, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1607, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 4, 4, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1608, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1609, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 2, 1, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1611, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1613, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1614, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 6, 3, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1615, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 3, 1, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 1, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1616, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 1, 1, 5, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1617, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 3, 4, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1618, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 1, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 1, 2, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 1, 1, 4, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 4, 3, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1619, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 6, 3, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1620, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 2, 4, 4, 8, 80);
commit;
prompt 30000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 3, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1621, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 3, 2, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 7, 1, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 7, 3, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1622, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1623, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1624, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 4, 4, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1625, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 5, 4, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1647, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1648, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1649, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1650, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 1, 1, 1, 11, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 3, 2, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 4, 4, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 8, 3, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1651, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 5, 2, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1653, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 1, 3, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 6, 1, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1654, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 6, 4, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1655, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1656, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 5, 3, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 2, 1, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 1, 4, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1657, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1658, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 8, 2, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 2, 2, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 4, 2, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1659, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 3, 2, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 1, 2, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 1, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 5, 3, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1660, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 2, 4, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1661, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 5, 3, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 5, 2, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 4, 1, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1662, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 2, 2, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1663, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 2, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1664, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 2, 4, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1665, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 3, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 1, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 8, 1, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 3, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1666, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 1, 4, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 1, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1667, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 3, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 4, 4, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1668, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 4, 1, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 4, 6, 20, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1669, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1670, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1671, 1, 2, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1672, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1673, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1674, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 4, 3, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1675, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1676, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 6, 1, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 1, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1677, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 5, 2, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 6, 3, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1678, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1679, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 3, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 3, 1, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1680, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1681, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 1, 4, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 4, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 6, 4, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 4, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 1, 2, 91, 364);
commit;
prompt 31000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1717, 2, 4, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 8, 1, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 6, 3, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 7, 3, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1718, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1719, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 3, 4, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 4, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 3, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1720, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 4, 3, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 4, 4, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 5, 1, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1721, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1722, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 8, 3, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1723, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1724, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1725, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 4, 1, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1682, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 3, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 8, 1, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1683, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1684, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1685, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1686, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1687, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 4, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1688, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1689, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 5, 3, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1691, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 4, 2, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1692, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 2, 2, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1693, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 4, 2, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1694, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 6, 4, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1695, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1696, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 8, 4, 6, 57, 1026);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1697, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1698, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 6, 4, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1699, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 2, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 1, 1, 80, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 7, 2, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1700, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 4, 5, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1701, 3, 3, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1702, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 2, 4, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 2, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 2, 1, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 5, 3, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 3, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1703, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 4, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1704, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 1, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 1, 1, 5, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 1, 1, 4, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 1, 4, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1705, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 1, 2, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1706, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 7, 1, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 3, 4, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1707, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1708, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 3, 1, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1709, 6, 2, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 7, 4, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1710, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 2, 2, 2, 10);
commit;
prompt 32000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 1, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1711, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 3, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 4, 2, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 2, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 8, 4, 5, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1712, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 7, 4, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1713, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1714, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1715, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 1, 1, 1, 92, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1716, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 3, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 1, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 3, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1789, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 2, 4, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 8, 3, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 3, 2, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1790, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 1, 2, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1791, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 4, 1, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1792, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 2, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1793, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1794, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 2, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 3, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 3, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 1, 2, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1795, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 4, 6, 29, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 2, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 2, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 4, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1796, 5, 4, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1797, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 7, 4, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1798, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 1, 1, 31, 93);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1799, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1800, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1801, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1802, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1803, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 1, 1, 4, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1804, 8, 4, 6, 49, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1805, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 4, 4, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 8, 2, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 1, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1806, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 6, 3, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 1, 1, 1, 89, 267);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1808, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 3, 3, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1809, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1810, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 2, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1726, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1727, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 4, 2, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1728, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1729, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 1, 3, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1730, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 8, 2, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 4, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1731, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1732, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 4, 4, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 4, 1, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1733, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1734, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 4, 3, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 4, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 4, 4, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1735, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1736, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1737, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 1, 4, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1738, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 3, 4, 33, 297);
commit;
prompt 33000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1739, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 1, 1, 1, 71, 213);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 5, 1, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1740, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 3, 4, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 1, 3, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1741, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 8, 3, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 3, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 1, 1, 2, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1742, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 3, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1743, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 2, 2, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 5, 3, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1744, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 1, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1745, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 3, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1746, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 5, 3, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1747, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 6, 3, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1748, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1749, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 8, 3, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 6, 4, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 4, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1750, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 1, 3, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 7, 4, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1751, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 1, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 4, 1, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 8, 3, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1752, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 5, 4, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1753, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 7, 3, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1754, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1755, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 5, 4, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 7, 1, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 1, 2, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1757, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 4, 6, 85, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1758, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 4, 4, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 1, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 4, 3, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 5, 4, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1759, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1760, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1761, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 7, 3, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1762, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1763, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1764, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 5, 1, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1765, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 5, 2, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1767, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 2, 1, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 2, 2, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 1, 4, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1768, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1769, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 3, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 1, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 2, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 7, 3, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1770, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 3, 1, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 4, 6, 85, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 2, 2, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1771, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 4, 2, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 4, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 5, 3, 4, 77, 924);
commit;
prompt 34000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1772, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 2, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1773, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1774, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 5, 1, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 4, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 6, 2, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 4, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 1, 1, 1, 85, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1775, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 4, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1777, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 2, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 7, 2, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1778, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 7, 1, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 7, 3, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1779, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 2, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 1, 2, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1780, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 5, 1, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1781, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 1, 3, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1782, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 2, 2, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 3, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 4, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 8, 4, 6, 45, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1783, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 8, 4, 6, 5, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 4, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 7, 2, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1784, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 2, 3, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1785, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 6, 4, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1786, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1787, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 2, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 3, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1788, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2022, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2023, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 7, 3, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2024, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 8, 3, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 2, 1, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 2, 4, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2025, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 3, 2, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2026, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 3, 1, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 8, 4, 6, 89, 1602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2027, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 1, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 2, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2028, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 3, 3, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 7, 1, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2029, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 3, 1, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 4, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 3, 1, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2031, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 1, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 8, 1, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 5, 2, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2182, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2183, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 1, 3, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 2, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2184, 5, 4, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 4, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 1, 4, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 7, 4, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 1, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2185, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2186, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 1, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2187, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 2, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 4, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2188, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 4, 4, 2, 98, 980);
commit;
prompt 35000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 4, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 4, 1, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2189, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 2, 2, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 3, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 4, 3, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 2, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 4, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2321, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2322, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2323, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 2, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 4, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 3, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 4, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2325, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2326, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 3, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 4, 6, 71, 1278);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2327, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 4, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 2, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 1, 1, 1, 45, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1871, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1872, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 6, 2, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 4, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1873, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1874, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 2, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1875, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1876, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1877, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1878, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 5, 2, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1879, 5, 2, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 7, 4, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 1, 1, 4, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2032, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 2, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2033, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 1, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 8, 3, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2034, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2035, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2036, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 1, 1, 1, 47, 141);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2037, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2038, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2039, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2040, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 4, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 1, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2042, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 1, 1, 4, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2043, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 4, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2190, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2192, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 2, 1, 80, 880);
commit;
prompt 36000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 4, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2193, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2194, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2195, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 4, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2196, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 4, 1, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2197, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2198, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 1, 4, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2328, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 1, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 2, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2329, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 2, 3, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2330, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2331, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2332, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 3, 1, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2333, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 7, 4, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2334, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 3, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2335, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 3, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 2, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2336, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 1, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 4, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 4, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 2, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2337, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 8, 4, 6, 36, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1880, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 5, 1, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1881, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 2, 4, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1882, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1883, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 5, 4, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 7, 2, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1884, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 3, 1, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1885, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 8, 3, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1886, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 5, 3, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1887, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 3, 2, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1888, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 8, 3, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 6, 1, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 3, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1889, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 3, 3, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 3, 4, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 4, 4, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1890, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 7, 4, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2044, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 4, 4, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2045, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2046, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 1, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2047, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2048, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 4, 6, 41, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 3, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2049, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 8, 3, 2, 9, 117);
commit;
prompt 37000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2050, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 8, 4, 1, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 6, 4, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2051, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 3, 1, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2052, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2053, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 2, 2, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 7, 4, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 1, 2, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 3, 3, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 2, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 4, 4, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2199, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 4, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 4, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 1, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2200, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2201, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2202, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2203, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 7, 1, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2205, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 3, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 1, 1, 59, 177);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 1, 1, 88, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2206, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 8, 4, 2, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 7, 2, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 1, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2207, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 2, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 4, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2338, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2339, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 2, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 5, 4, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2340, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2341, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 4, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 2, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 4, 1, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 2, 4, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2342, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 8, 2, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2343, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2344, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 1, 1, 6, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2345, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 2, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 8, 2, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1891, 8, 4, 4, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 5, 3, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 8, 3, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 8, 1, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 1, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1892, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 4, 1, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1893, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1894, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1895, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1896, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1897, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1898, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 2, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1899, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1900, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 3, 4, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1901, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 3, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 1, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1902, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2054, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2055, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2057, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 1, 1, 2, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 6, 3, 5, 32, 448);
commit;
prompt 38000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 4, 3, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2058, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 2, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2059, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 1, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2060, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 1, 1, 3, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2061, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 3, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 4, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 1, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 2, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 8, 2, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2062, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 2, 3, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2063, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2064, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2208, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 1, 3, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2209, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2210, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2211, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 4, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2212, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 6, 4, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 8, 4, 3, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2213, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2214, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 4, 1, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 2, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2215, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2216, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 4, 3, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2217, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 2, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 4, 3, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 3, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2346, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 3, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2347, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 2, 3, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 3, 1, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 2, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 2, 1, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2348, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 6, 4, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2349, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2350, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 2, 3, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 1, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2351, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2353, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2354, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 5, 1, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 4, 3, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 1, 2, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2355, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 1, 1, 5, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1903, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 1, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1904, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 7, 2, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 5, 3, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1905, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 8, 3, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 7, 1, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 3, 4, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1906, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 1, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1907, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1908, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 4, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 4, 2, 1, 86, 602);
commit;
prompt 39000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 1, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 7, 4, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1909, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 7, 1, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 6, 2, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1910, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1911, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 4, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 2, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 5, 4, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 2, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2065, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2066, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2067, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2068, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2069, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 6, 4, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2070, 1, 1, 1, 63, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 1, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 4, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2071, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 4, 2, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2072, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 1, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2073, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2218, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 4, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 5, 3, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2219, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 1, 1, 95, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 7, 3, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2220, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2221, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2222, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 2, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 1, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 4, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 8, 2, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 2, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 1, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2223, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2224, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 2, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 1, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2225, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2356, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2357, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2358, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 7, 4, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 2, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 7, 2, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 4, 1, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2359, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2360, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 4, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 4, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 8, 4, 6, 51, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2361, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2362, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2363, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 2, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2364, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 1, 2, 8, 88);
commit;
prompt 40000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1912, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1913, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 1, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 6, 3, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1914, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 3, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 1, 1, 5, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 4, 3, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1915, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 2, 2, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1916, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1917, 7, 2, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1918, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 1, 1, 1, 68, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1919, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1920, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 5, 4, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 7, 2, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 8, 4, 6, 81, 1458);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1921, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 2, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 1, 1, 14, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2074, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 2, 4, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 1, 4, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2075, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2076, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2077, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 4, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 4, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 3, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2078, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 6, 1, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2079, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 8, 3, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 4, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 4, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 2, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2080, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 3, 4, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2081, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 8, 4, 2, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 4, 3, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2082, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 4, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2226, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2227, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 8, 4, 6, 78, 1404);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 4, 2, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2228, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2229, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 5, 2, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2230, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 2, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 2, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2231, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 3, 1, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2232, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 5, 2, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 3, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2233, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 7, 3, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2234, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 3, 3, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2235, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 3, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 2, 4, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2375, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 8, 4, 6, 47, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 3, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 3, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 2, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2376, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 3, 4, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2377, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 1, 4, 2, 42, 294);
commit;
prompt 41000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 8, 2, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 3, 2, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2378, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2379, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 3, 2, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2380, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 6, 3, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 4, 6, 47, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 6, 4, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 3, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2381, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 8, 1, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1922, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 3, 3, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 8, 4, 6, 94, 1692);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 7, 2, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1924, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 4, 2, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1925, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 4, 1, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1926, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 4, 4, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1927, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 3, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1928, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1929, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2083, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 8, 2, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2084, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 1, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 1, 1, 5, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2085, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 2, 4, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2086, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2087, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2088, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2089, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 4, 1, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2090, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2091, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2092, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2236, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 3, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 2, 4, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2237, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2238, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 8, 1, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2239, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 1, 1, 1, 12, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 3, 3, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2240, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 4, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 3, 1, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2241, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 2, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 3, 1, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 2, 3, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2242, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 1, 4, 32, 192);
commit;
prompt 42000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 2, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 4, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 2, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 2, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 5, 2, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 3, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 2, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2395, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2396, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 2, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2397, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 4, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2398, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 7, 3, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2399, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 4, 3, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2400, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2401, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2402, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 4, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 2, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1930, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 3, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 3, 4, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1931, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 1, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1932, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1933, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1934, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 7, 4, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 3, 1, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1935, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1936, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1937, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1938, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2093, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 3, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 1, 2, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2094, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2095, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 1, 3, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 2, 1, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2096, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 2, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 3, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 1, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 8, 2, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2097, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 8, 4, 6, 45, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2098, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2099, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2100, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 3, 1, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2101, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 7, 3, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2102, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 1, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2243, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 6, 2, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2244, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 7, 3, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 2, 4, 63, 504);
commit;
prompt 43000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 3, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2245, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 7, 3, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 8, 2, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2247, 1, 2, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2248, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2249, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 3, 3, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2250, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2251, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 4, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2252, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 6, 2, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2253, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 4, 2, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 6, 3, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 4, 2, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 8, 3, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 1, 1, 1, 49, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2365, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 3, 4, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 1, 3, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 5, 1, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 4, 2, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2367, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 4, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 6, 2, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 1, 3, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2368, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 2, 2, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 7, 4, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 1, 1, 6, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2369, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 3, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 1, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2370, 6, 4, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 3, 2, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 1, 1, 1, 26, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 1, 1, 1, 96, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2371, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 1, 1, 4, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2372, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 5, 3, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 5, 2, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2373, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 3, 1, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 1, 1, 5, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 4, 3, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 2, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2374, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 2, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 1, 1, 22, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 1, 2, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1939, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1940, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 4, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 1, 1, 1, 71, 213);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1941, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 1, 2, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1943, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1944, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1945, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 3, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1946, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 2, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1947, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2103, 5, 2, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2104, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2105, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 5, 2, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2106, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 2, 4, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 4, 1, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2107, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 7, 3, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2108, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2109, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 4, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2110, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2112, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 1, 2, 3, 55, 330);
commit;
prompt 44000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 1, 2, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 3, 2, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 3, 1, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2113, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 4, 2, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 4, 2, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2114, 5, 1, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2254, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2255, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 3, 1, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 8, 3, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2256, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 3, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 1, 1, 5, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 1, 4, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 4, 3, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2257, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 2, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 2, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 3, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2258, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2259, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 2, 2, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2260, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 1, 3, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 1, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2261, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 6, 3, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2262, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 1, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 4, 2, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 4, 1, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 2, 4, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2382, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 3, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2383, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2384, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2385, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 3, 1, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 7, 4, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 3, 4, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2386, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2387, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2388, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 6, 2, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2389, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2390, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2392, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 4, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 8, 1, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 2, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2393, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2394, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1948, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 4, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 6, 1, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 4, 2, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 4, 1, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1949, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1950, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 2, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1951, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 8, 2, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1952, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 1, 2, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 8, 4, 3, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1953, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 8, 4, 5, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1954, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 4, 1, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 1, 2, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1955, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1956, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 4, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1957, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1958, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 8, 2, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 3, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 1, 1, 2, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 1, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2115, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 2, 4, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2116, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 1, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 1, 1, 1, 47, 141);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 1, 6, 57, 855);
commit;
prompt 45000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 4, 4, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2117, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 4, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 1, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2118, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 4, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 3, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 4, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 1, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 2, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2119, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 1, 4, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 1, 1, 1, 14, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2120, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 8, 4, 2, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2121, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 3, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 5, 2, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 3, 4, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2122, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 2, 2, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2263, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 3, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 1, 3, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 4, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 2, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2264, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 7, 3, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2265, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 1, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 1, 2, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2266, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 1, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 2, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 1, 4, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2267, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 8, 2, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2268, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 2, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 1, 1, 60, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 4, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 1, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2269, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 8, 4, 6, 41, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2403, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 1, 1, 50, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 3, 2, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2404, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 1, 1, 1, 95, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2405, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 2, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2406, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 1, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 5, 1, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 3, 1, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2407, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 3, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 4, 1, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2408, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 7, 3, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2409, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 4, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1959, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 2, 2, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 6, 1, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1960, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 1, 4, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1961, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 4, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1962, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 2, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1963, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 7, 4, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 7, 1, 2, 74, 740);
commit;
prompt 46000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1964, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1965, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1966, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 4, 4, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1967, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 2, 2, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 2, 4, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2123, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 2, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2124, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 7, 1, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 2, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 1, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2125, 3, 4, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 3, 1, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 1, 4, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2126, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2127, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 2, 1, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2128, 5, 3, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2129, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 4, 1, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2130, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2131, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 4, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 4, 5, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 2, 1, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 1, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 1, 1, 1, 87, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2270, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 4, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 4, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2271, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 3, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 6, 3, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 1, 3, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2272, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2273, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 1, 1, 1, 2, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 4, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2274, 7, 2, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 3, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 4, 3, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2275, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 1, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 2, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1822, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 3, 1, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 5, 3, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1823, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1824, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 5, 3, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 8, 4, 2, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1825, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 8, 3, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1826, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 1, 4, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1827, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 3, 2, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 2, 4, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1828, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1829, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 3, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 2, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 6, 2, 2, 53, 530);
commit;
prompt 47000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1968, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1969, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 1, 4, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1970, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 5, 3, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1971, 7, 4, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 8, 4, 3, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1972, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1973, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 1, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 2, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 4, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1974, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 7, 4, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1975, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 3, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 3, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1976, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 8, 3, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1977, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2132, 1, 3, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 3, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 1, 1, 1, 38, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2133, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 2, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2134, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2135, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2136, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 1, 4, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2137, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 1, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 3, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 2, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2138, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 3, 1, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2139, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 3, 4, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2140, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 2, 4, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 7, 2, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 5, 4, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2276, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 6, 2, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2277, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 3, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 2, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 3, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2278, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2279, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 4, 4, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 4, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 1, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 3, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2280, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 5, 3, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2281, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 1, 1, 91, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2282, 2, 3, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 4, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2283, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 4, 2, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 8, 3, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1830, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1831, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 2, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 7, 2, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1832, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 3, 1, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1833, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 4, 1, 2, 16, 112);
commit;
prompt 48000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1834, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 4, 4, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 2, 1, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 5, 4, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1835, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1836, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1837, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 5, 3, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1838, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 4, 4, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1839, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 6, 4, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 3, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1978, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 4, 1, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1979, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 6, 2, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 2, 1, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1980, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1981, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 3, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1982, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 3, 4, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1983, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1984, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1985, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 3, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 6, 2, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 2, 3, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1986, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 8, 4, 1, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 3, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 1, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1987, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 3, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 2, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2141, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 7, 1, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2142, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2143, 6, 3, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2144, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2145, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 7, 2, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 6, 4, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 5, 2, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2146, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2147, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 1, 4, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 3, 1, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2148, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2149, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 3, 1, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2150, 8, 2, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 7, 3, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 2, 3, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 1, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2151, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 3, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 4, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2284, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2285, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2286, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2287, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 3, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 2, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 2, 2, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2288, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2289, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 1, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 2, 3, 46, 598);
commit;
prompt 49000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 3, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 3, 2, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2290, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2291, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1840, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 3, 1, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1841, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1842, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 1, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 1, 4, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 2, 2, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1843, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1844, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 2, 4, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 8, 4, 6, 48, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1845, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 3, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 6, 2, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 1, 1, 89, 267);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 3, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1846, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 4, 4, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1847, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1848, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1849, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1850, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 4, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 4, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1988, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1989, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 1, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1990, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 7, 4, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1991, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 4, 2, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 2, 4, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1992, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1993, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 4, 2, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1994, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1995, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1996, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 2, 4, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1997, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 2, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 4, 6, 41, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2152, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 6, 3, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2153, 5, 2, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2154, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2155, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 1, 1, 1, 75, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2156, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 3, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 2, 4, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 1, 1, 12, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 4, 1, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 1, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2157, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 4, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 7, 3, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2158, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 1, 1, 5, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 4, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2159, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2160, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 3, 4, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 7, 2, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 6, 1, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 6, 4, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2292, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 8, 2, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 4, 4, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 2, 3, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2293, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 2, 4, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 3, 2, 5, 97, 970);
commit;
prompt 50000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2294, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 4, 2, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 4, 1, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 1, 2, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 3, 1, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2295, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2296, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 8, 4, 3, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2297, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 2, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2298, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 8, 4, 3, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1851, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 2, 2, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1852, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 2, 4, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1853, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 3, 1, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1854, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1855, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 1, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1856, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 3, 3, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 4, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1857, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1858, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 1, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 3, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 7, 3, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1859, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1860, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 4, 5, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 3, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 3, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 8, 4, 4, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1998, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 5, 3, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 4, 1, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1999, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2000, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 1, 4, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2001, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2002, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2003, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 4, 6, 36, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2004, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 3, 4, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 8, 1, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2005, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 3, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 6, 4, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2007, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2008, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2009, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 1, 1, 1, 56, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2161, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 1, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 3, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 3, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2162, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 3, 2, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 1, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2163, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 6, 4, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2164, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2165, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 4, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2166, 4, 3, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2167, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2168, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 1, 4, 2, 13, 91);
commit;
prompt 51000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2169, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 4, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 4, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2170, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 2, 2, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2299, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 3, 4, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2300, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 4, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2301, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 3, 1, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2302, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2303, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2305, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 5, 4, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2306, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 4, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 1, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 4, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2307, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 4, 3, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 1, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 1, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 3, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1861, 3, 4, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 3, 4, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1862, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 8, 2, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1863, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 1, 4, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1864, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 3, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 1, 3, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 6, 3, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 2, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1865, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 4, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1866, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 1, 4, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 6, 1, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1867, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 4, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 5, 3, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1868, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 3, 3, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1869, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1870, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 1, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 1, 2, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2010, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2011, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2012, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 2, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2013, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 2, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 3, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2014, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2015, 2, 1, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2016, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 3, 4, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2017, 8, 4, 2, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 8, 1, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2018, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 2, 2, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2019, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 3, 1, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2020, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 2, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 3, 4, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 1, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2021, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 3, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2171, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 8, 1, 3, 90, 1080);
commit;
prompt 52000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2172, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 5, 2, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2173, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 1, 2, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 2, 4, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 6, 4, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 2, 1, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 1, 1, 1, 50, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2174, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 8, 3, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 1, 4, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 2, 4, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2175, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2176, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2177, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 1, 2, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2178, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 1, 1, 1, 40, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2179, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2180, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2181, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 5, 3, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2308, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2309, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2310, 8, 3, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 3, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 4, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 3, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 8, 2, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2311, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 4, 2, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2312, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 1, 1, 11, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2313, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 8, 1, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2314, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 5, 3, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2315, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2316, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 3, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 8, 3, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 1, 1, 42, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2317, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2318, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 3, 3, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 1, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 7, 2, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2599, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 3, 3, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 8, 1, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2600, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 2, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 6, 4, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2601, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 6, 1, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2602, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2603, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 2, 2, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2604, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 8, 1, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2605, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2606, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 3, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2607, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2608, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2609, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 1, 4, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2731, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 1, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 2, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 7, 4, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 7, 4, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 3, 2, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2732, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 7, 4, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2733, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 1, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 2, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 2, 2, 26, 182);
commit;
prompt 53000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2734, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2735, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 7, 1, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 3, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2736, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 3, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 4, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 6, 1, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2867, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2869, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2870, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 4, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2871, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 8, 4, 6, 75, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 1, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2872, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2873, 1, 4, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 2, 4, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2874, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 2, 4, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 3, 2, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 4, 4, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2460, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 4, 6, 82, 1476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 2, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2461, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 8, 2, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2462, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 8, 2, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 4, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 7, 2, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 7, 1, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2463, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2464, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2465, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2466, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 4, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 2, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2610, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 8, 1, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2611, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 4, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 1, 1, 4, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2612, 5, 3, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2613, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 4, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2615, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2616, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 4, 2, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2617, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2618, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 3, 2, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 4, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 7, 2, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2619, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 5, 3, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2737, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 7, 4, 2, 20, 260);
commit;
prompt 54000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2738, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 1, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 3, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2739, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2740, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 1, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 1, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 8, 2, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2741, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2742, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 6, 4, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2743, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 2, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 4, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 1, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 1, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 2, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 2, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 3, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 1, 1, 63, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2744, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 1, 1, 4, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 5, 2, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 1, 4, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2875, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 2, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 8, 2, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 4, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2876, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 7, 3, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2877, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2878, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2879, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 8, 3, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2880, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 6, 1, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2881, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 1, 2, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2882, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 1, 3, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2883, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2884, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 2, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2467, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2468, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 5, 2, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 3, 4, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2469, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 8, 4, 6, 8, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 7, 1, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2470, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2471, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 4, 6, 61, 1098);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 7, 4, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 2, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 6, 4, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2472, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 5, 1, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2473, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 1, 3, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 3, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2474, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 2, 3, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2620, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2621, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 3, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 3, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2622, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2623, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 1, 3, 4, 21, 168);
commit;
prompt 55000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 2, 4, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2624, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 1, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2625, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 1, 2, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2626, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2627, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2628, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 1, 1, 85, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 1, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 3, 4, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2745, 5, 4, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2746, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2747, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 8, 3, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 4, 4, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 1, 1, 2, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 2, 3, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 2, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2748, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 7, 2, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2749, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 4, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2750, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 8, 4, 6, 62, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 3, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 2, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 4, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 4, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2751, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 3, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 3, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 4, 2, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 6, 1, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 3, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2752, 1, 1, 1, 72, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 4, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2885, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 8, 3, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2886, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 8, 2, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 2, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2887, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 2, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 4, 4, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2888, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2889, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 1, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 8, 4, 6, 62, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 8, 1, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2890, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2891, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 6, 1, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2892, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 2, 4, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 2, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 1, 5, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 2, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2475, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 5, 1, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 3, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2476, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 8, 4, 6, 6, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2477, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 4, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 6, 2, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 7, 2, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2478, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 3, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2479, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2480, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 3, 4, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2481, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2482, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 3, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 4, 4, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 6, 3, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2483, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 4, 3, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 3, 4, 37, 333);
commit;
prompt 56000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 3, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 3, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2484, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 1, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 3, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 1, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 3, 1, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2629, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 4, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 6, 4, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 4, 3, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2630, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2631, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 8, 4, 5, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2632, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 6, 1, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 1, 1, 2, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2633, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 2, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2634, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 1, 1, 60, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2635, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 8, 4, 6, 82, 1476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2753, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 7, 1, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2754, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 3, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 1, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 1, 4, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2755, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 2, 4, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 7, 3, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 6, 4, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2756, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 4, 4, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2757, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 8, 1, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 2, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 4, 2, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2758, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 2, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 4, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2759, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 1, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 3, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2760, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2761, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2893, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 6, 1, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2894, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 5, 4, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 2, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 3, 3, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 5, 1, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2895, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 1, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 1, 3, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 3, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 7, 3, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2896, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 1, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 3, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 1, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2897, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 4, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 4, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 4, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2898, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 4, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2899, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2900, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 4, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 7, 1, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2485, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 1, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 2, 1, 25, 100);
commit;
prompt 57000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2486, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2487, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 4, 3, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2488, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2489, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 2, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 1, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2490, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 2, 1, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 1, 3, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 4, 2, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2491, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 5, 3, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2492, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2493, 8, 3, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 4, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2494, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 1, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 4, 3, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2636, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 4, 6, 49, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 5, 4, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 6, 3, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2637, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2638, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2639, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 3, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2640, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 1, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 4, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2641, 7, 2, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2642, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 1, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 1, 1, 63, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 1, 3, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2643, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 3, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 5, 4, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2762, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 4, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 5, 4, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2763, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2765, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 6, 4, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 3, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2766, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 7, 4, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2767, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 5, 1, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 3, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 3, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 5, 4, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2768, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2769, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 2, 3, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2770, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 1, 2, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 8, 1, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 8, 4, 6, 61, 1098);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2771, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 5, 4, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 2, 1, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 8, 4, 6, 62, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 6, 3, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2772, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 4, 3, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 8, 3, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2901, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2902, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2903, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 4, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 2, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 3, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2904, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 6, 4, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2905, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 4, 3, 16, 240);
commit;
prompt 58000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 3, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 1, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2906, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 8, 4, 1, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 2, 2, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2495, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2496, 6, 4, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 2, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 4, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 4, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 3, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 2, 4, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2497, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 4, 6, 11, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 6, 2, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 4, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 2, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2498, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2499, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2500, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 5, 1, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 1, 1, 1, 39, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2501, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 4, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 2, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 4, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 3, 4, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2502, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 4, 3, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 8, 2, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2503, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2644, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 2, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 4, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 1, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 3, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 3, 3, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2645, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2646, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2647, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 8, 3, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2648, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 3, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 2, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 8, 4, 5, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 4, 3, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2649, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 7, 4, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2650, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 7, 4, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2651, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2652, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2773, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2774, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 6, 1, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2775, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 2, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2776, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2777, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 4, 4, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 1, 3, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 1, 1, 29, 87);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 4, 4, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2778, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 3, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 8, 4, 6, 92, 1656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 3, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 8, 2, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2779, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 1, 4, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 3, 1, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2780, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 1, 1, 1, 92, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2907, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 4, 4, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 1, 3, 60, 720);
commit;
prompt 59000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2908, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 3, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2909, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2910, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 2, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 8, 4, 6, 87, 1566);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2911, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 4, 1, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 2, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2912, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 3, 2, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 3, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 1, 4, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 8, 4, 6, 76, 1368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2504, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 3, 4, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2505, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 2, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 1, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 2, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 4, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2506, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2507, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 4, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 4, 4, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2508, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 1, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 7, 4, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 4, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 5, 1, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2510, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 1, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2511, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 5, 2, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 1, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2653, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 2, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 4, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 2, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 3, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 4, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2655, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2656, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 1, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 4, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2657, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 3, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 4, 1, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 8, 3, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2658, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 4, 2, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 2, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 7, 1, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2659, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 3, 3, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2660, 5, 2, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2781, 7, 2, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 4, 2, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2782, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 3, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2783, 7, 4, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 3, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 4, 1, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2784, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 6, 3, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 2, 3, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2785, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2786, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 1, 3, 23, 230);
commit;
prompt 60000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 2, 4, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 2, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2787, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 3, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 3, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 1, 4, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2788, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 6, 2, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 6, 1, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 1, 4, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 3, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2922, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2923, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 2, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 8, 4, 4, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2925, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 4, 6, 43, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2926, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2927, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2928, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 8, 1, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2929, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2512, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 2, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 4, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 5, 4, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 3, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 6, 4, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2513, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 3, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 8, 2, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2514, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 4, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 3, 3, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2515, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2516, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 7, 2, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 6, 2, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 6, 4, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 1, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 1, 1, 3, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 4, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 8, 1, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2517, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2520, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 8, 2, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2521, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 1, 3, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2522, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 2, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 4, 4, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 3, 1, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2661, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 1, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 5, 3, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 3, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2662, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 3, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 4, 6, 82, 1476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2663, 5, 1, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 1, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 4, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2664, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2665, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 2, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 2, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 5, 2, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 4, 3, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2667, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 2, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2668, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2789, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 1, 4, 1, 89, 534);
commit;
prompt 61000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 1, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 2, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 1, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 3, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2790, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2791, 8, 1, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 1, 1, 3, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2792, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2793, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 5, 2, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2794, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 6, 2, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 6, 4, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 3, 3, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 5, 2, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2795, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2796, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 8, 2, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 3, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2797, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2799, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 5, 2, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2800, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 4, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 1, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2801, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 2, 3, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2937, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 8, 3, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2938, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 3, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2939, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2940, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 2, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 3, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 2, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2941, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 4, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2942, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2523, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2524, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 1, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 4, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2525, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2526, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 3, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2527, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 3, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 2, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 1, 3, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2528, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 3, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2530, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 4, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2669, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 2, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 4, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 6, 3, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 3, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2670, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 7, 4, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 5, 4, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2671, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 1, 2, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2672, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 3, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 3, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 4, 6, 57, 684);
commit;
prompt 62000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 2, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 4, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 1, 2, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2673, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 2, 2, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2674, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 7, 3, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2675, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 1, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 1, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2802, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 1, 2, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2803, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 2, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2804, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2805, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 3, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 4, 1, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2806, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2807, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2808, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 8, 3, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2809, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2810, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 2, 1, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 2, 2, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 5, 2, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2811, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2913, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 5, 2, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2914, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 1, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 4, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2915, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 5, 1, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2916, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2917, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 3, 2, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2918, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 4, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 1, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 1, 2, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2919, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2920, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2921, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2531, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 1, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 4, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 4, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2532, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 8, 2, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2533, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2534, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 4, 4, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2535, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 1, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2536, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2537, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 5, 3, 1, 67, 603);
commit;
prompt 63000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2538, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 2, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 8, 4, 6, 84, 1512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 1, 1, 1, 33, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2676, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2677, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2678, 1, 1, 1, 96, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 8, 4, 6, 38, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2679, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2680, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 4, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 8, 2, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 8, 4, 6, 100, 1800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 8, 1, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2681, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 2, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 1, 5, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 3, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 1, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2682, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2683, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 1, 3, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2684, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 3, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 1, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 4, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 2, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 4, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2812, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2813, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 3, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 4, 4, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2814, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 3, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 3, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2815, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 3, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 5, 2, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 6, 2, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2816, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 4, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2817, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 2, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 3, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 6, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 4, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 1, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 2, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 8, 4, 6, 9, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 1, 4, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2930, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 4, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 1, 6, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 2, 2, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2931, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2932, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 2, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 1, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 8, 2, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 2, 2, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2933, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2934, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 2, 3, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2936, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2539, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2540, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 1, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2541, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 8, 3, 4, 37, 555);
commit;
prompt 64000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2542, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2543, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 8, 2, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 6, 4, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 7, 1, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2544, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2545, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2546, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2547, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2548, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 7, 4, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 6, 1, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 1, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2685, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 6, 4, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2686, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 3, 3, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2687, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 4, 6, 27, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 1, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 5, 4, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 2, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 3, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2688, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2689, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 3, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 3, 3, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 4, 4, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 8, 2, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2690, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2691, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 4, 1, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 6, 2, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 4, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 2, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 7, 3, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 2, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 3, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 4, 4, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 4, 6, 18, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2818, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 2, 3, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2819, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 5, 2, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 3, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2820, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 6, 2, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2821, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 3, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2822, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 1, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2823, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 1, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 8, 4, 4, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2824, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1811, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 1, 1, 75, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 7, 1, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1812, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1813, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1814, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 2, 4, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 6, 3, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1815, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 8, 1, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1816, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 3, 2, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1817, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 3, 4, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1818, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 5, 3, 1, 66, 594);
commit;
prompt 65000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1819, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 8, 2, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1820, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 3, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 4, 1, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (1821, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 1, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 8, 4, 6, 89, 1602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2549, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2550, 2, 2, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2551, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 3, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2552, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 1, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 4, 2, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2553, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 4, 4, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2554, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2555, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2556, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2557, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2692, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 3, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 8, 2, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2693, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 1, 2, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 2, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 8, 3, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 2, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2694, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2695, 3, 2, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2696, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 7, 2, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 4, 1, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 2, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 6, 2, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2697, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2698, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 4, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 5, 3, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2699, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 2, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 1, 1, 1, 88, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 4, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2825, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 4, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 4, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2826, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 3, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 4, 3, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 7, 4, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 2, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2827, 6, 4, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 3, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2828, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2829, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 4, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 3, 4, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2830, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2410, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 1, 4, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2411, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 3, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 2, 6, 99, 1386);
commit;
prompt 66000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2412, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 2, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 1, 2, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2413, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 4, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 6, 3, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 4, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 6, 2, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 3, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 2, 4, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2414, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2415, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 2, 4, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 6, 2, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2416, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 3, 1, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2417, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2418, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2558, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2559, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 5, 1, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 8, 4, 6, 19, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2560, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 4, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 1, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 2, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 3, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 3, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 6, 1, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2561, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 1, 1, 3, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 1, 3, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 4, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2562, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 7, 3, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 8, 2, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2563, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2564, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 1, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 1, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2565, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 4, 2, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 8, 3, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 1, 3, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2700, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 2, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2701, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2702, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2703, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 8, 3, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 5, 4, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 3, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2704, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 6, 2, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2705, 3, 4, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 1, 4, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2706, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 4, 4, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 8, 3, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2707, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 4, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 2, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2708, 1, 1, 3, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 3, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2831, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 1, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 4, 6, 51, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2832, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 1, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 6, 2, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2833, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2834, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 1, 1, 6, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 5, 4, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2835, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 3, 3, 1, 58, 406);
commit;
prompt 67000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 6, 1, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 6, 3, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 4, 6, 18, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 1, 1, 4, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2836, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2837, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 3, 2, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2838, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 6, 4, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2839, 3, 1, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2419, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2420, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2421, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 3, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2422, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 7, 4, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 4, 2, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2423, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2424, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2425, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 7, 1, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 4, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2426, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 8, 1, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 6, 4, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2427, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 2, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2428, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 1, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2566, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 2, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 6, 2, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 1, 4, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2567, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 8, 4, 6, 85, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2568, 4, 2, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 4, 1, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2569, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 3, 2, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 7, 1, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2570, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 1, 4, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 4, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2571, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2572, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 8, 2, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 3, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 8, 1, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 1, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 1, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 2, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2573, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 2, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 7, 3, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 3, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 4, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2709, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 4, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 1, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 1, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 1, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2710, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 5, 3, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 4, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2711, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 3, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 2, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2712, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 7, 1, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2713, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 8, 2, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2840, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 8, 4, 4, 39, 624);
commit;
prompt 68000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2841, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 3, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2842, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 1, 1, 3, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2843, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 5, 1, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 4, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 3, 4, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2845, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 5, 3, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 3, 2, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 5, 1, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2846, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 6, 4, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2847, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 5, 1, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 1, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2848, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 4, 3, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 8, 4, 1, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2849, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 2, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 4, 1, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 4, 1, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2429, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 2, 1, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 1, 2, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2430, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2431, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2432, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 5, 1, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2433, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 8, 4, 6, 9, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2434, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2435, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 4, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 3, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 4, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2436, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 8, 1, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2438, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 7, 4, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2439, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2440, 8, 1, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 3, 4, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2574, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2575, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2576, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 7, 2, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2577, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 2, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 1, 1, 1, 26, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2578, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 4, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 2, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2579, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 3, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2580, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2581, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 1, 6, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 2, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2582, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 1, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 4, 6, 43, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 2, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 4, 6, 76, 1368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 2, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 5, 4, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2714, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 3, 1, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 8, 2, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 3, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 5, 1, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2715, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 4, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 4, 2, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2716, 1, 2, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 2, 2, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 5, 3, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 6, 1, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 2, 4, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2717, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 2, 5, 91, 1274);
commit;
prompt 69000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 3, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2718, 1, 4, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 4, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 6, 2, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2719, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 1, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 4, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 2, 1, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2720, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 1, 1, 1, 45, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2850, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2851, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 3, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 4, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 2, 4, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2852, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 2, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 1, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 2, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 1, 1, 13, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 1, 4, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2853, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 8, 3, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2854, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2855, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2856, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 1, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 1, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2441, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 2, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2442, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 8, 4, 6, 16, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2443, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 3, 4, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2444, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 1, 1, 3, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 8, 4, 6, 28, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2445, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2446, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 2, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 4, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 2, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 4, 6, 11, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2447, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 5, 2, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2583, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 2, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 2, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2584, 1, 1, 1, 54, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 3, 4, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2585, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 2, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 2, 2, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2586, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 7, 4, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2587, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 8, 2, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 2, 3, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 6, 3, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2588, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2589, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 3, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 4, 1, 20, 220);
commit;
prompt 70000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 1, 2, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2590, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2722, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 8, 4, 6, 8, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 3, 3, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2723, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 4, 6, 8, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 4, 5, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 1, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2724, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 3, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 4, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 3, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 3, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 2, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2725, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 4, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2726, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 4, 2, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2727, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 3, 3, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 2, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 3, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2728, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 5, 1, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 2, 2, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 8, 4, 6, 35, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 7, 3, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2729, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 7, 1, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 8, 1, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2730, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 2, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 1, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 1, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 7, 2, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2857, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 7, 3, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 3, 2, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2858, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2859, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2860, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 7, 3, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 5, 3, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2861, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2862, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 1, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 7, 1, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2863, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 1, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2864, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 6, 1, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2865, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 5, 4, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2866, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2448, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2449, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 1, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2450, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 3, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 3, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 5, 2, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2451, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 1, 2, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 3, 3, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2452, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2453, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2455, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 6, 3, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2456, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 8, 3, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 4, 1, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2457, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2458, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2459, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 2, 1, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 1, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2591, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2593, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 1, 4, 22, 264);
commit;
prompt 71000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2594, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 5, 2, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 3, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2595, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 1, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 2, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 2, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2596, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 3, 3, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2597, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 4, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2598, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 5, 2, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 7, 4, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3099, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 4, 6, 43, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3100, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 1, 4, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 4, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 2, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 3, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 4, 1, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3101, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 3, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 3, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 4, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3102, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3103, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 3, 3, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 2, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3104, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 2, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 1, 4, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3215, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 4, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 3, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 4, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 4, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 3, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 2, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3216, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 3, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 1, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 4, 3, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3217, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 4, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3218, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 1, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 2, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 2, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3219, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 2, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 2, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3333, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 2, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 4, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 1, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 3, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 4, 6, 36, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3334, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 6, 39, 546);
commit;
prompt 72000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 4, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 4, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 1, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 4, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3335, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 1, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 4, 3, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2991, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 1, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 2, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 1, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 3, 3, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 2, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 3, 1, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2992, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2993, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 7, 4, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 2, 3, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 2, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2994, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 2, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2995, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 4, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 1, 3, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2996, 3, 2, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 2, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 8, 3, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 2, 4, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3105, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 3, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 2, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 3, 2, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3106, 1, 4, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3107, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 3, 1, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 1, 4, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3108, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3109, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 2, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 4, 6, 6, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 4, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3110, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 4, 3, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3111, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 5, 4, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 8, 4, 6, 8, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3220, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 1, 3, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3221, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 3, 2, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3222, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3223, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3224, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 1, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 3, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 4, 1, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 1, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 3, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 1, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 1, 1, 64, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3225, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 1, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3336, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 1, 1, 2, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 2, 6, 14, 182);
commit;
prompt 73000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 4, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3337, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3338, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3339, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3340, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 7, 2, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 5, 4, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 6, 1, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3341, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 8, 1, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3342, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3343, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 8, 4, 6, 71, 1278);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 2, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 3, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 2, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3344, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2997, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 1, 1, 6, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 3, 3, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2998, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2999, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3000, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3001, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 2, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 8, 3, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 7, 3, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3002, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 1, 1, 4, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 6, 3, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3003, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3004, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 6, 3, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3005, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 3, 4, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3112, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 1, 2, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 5, 3, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3113, 2, 4, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 1, 2, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 8, 2, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 1, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3114, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 6, 3, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 3, 2, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3115, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 2, 4, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3116, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 8, 4, 6, 75, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3117, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 4, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 1, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 3, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3118, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 1, 3, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3119, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 1, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 2, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 3, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 3, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 6, 1, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 3, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 4, 3, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 1, 1, 21, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3120, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3226, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 1, 2, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 3, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 4, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 1, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 2, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3227, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 4, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 1, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3229, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 1, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 3, 46, 598);
commit;
prompt 74000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3230, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3231, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 7, 1, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3232, 2, 4, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 1, 3, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 1, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 8, 2, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3345, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 1, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 2, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3346, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3347, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 4, 6, 22, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3348, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 1, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 2, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 1, 1, 44, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3006, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 2, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 1, 3, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 4, 3, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3007, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3008, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 3, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 3, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 1, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 7, 4, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3009, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 2, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 6, 1, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 3, 3, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 4, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 4, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3010, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 1, 2, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3011, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 1, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 6, 2, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 7, 4, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3012, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 4, 1, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3013, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 3, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3121, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 8, 1, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3122, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3123, 7, 2, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 4, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 8, 3, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 1, 2, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 3, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3124, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 7, 1, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3125, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 4, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 6, 2, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 1, 1, 85, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 3, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 8, 2, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3126, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3127, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 4, 2, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 3, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3128, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 3, 5, 7, 98);
commit;
prompt 75000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3233, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 5, 4, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3234, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 8, 2, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3235, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 1, 4, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3236, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 7, 3, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3237, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 2, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 1, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3238, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 2, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3239, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3349, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 4, 3, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3350, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3351, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 1, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 4, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 3, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 2, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 1, 1, 33, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3353, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 3, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 2, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 1, 6, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 2, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 4, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3354, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 2, 4, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 1, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3355, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 8, 2, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3356, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 4, 6, 20, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 1, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 3, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3014, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 4, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3015, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 4, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 3, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 2, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 3, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 1, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3016, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 4, 4, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3017, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 3, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 7, 1, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 2, 2, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 4, 2, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 1, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3018, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 2, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 2, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 1, 4, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 1, 2, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3129, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3130, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 3, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 6, 1, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 1, 2, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 6, 4, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 4, 1, 43, 430);
commit;
prompt 76000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3131, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3132, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3133, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 2, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 2, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 2, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 1, 6, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3134, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 2, 3, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 4, 2, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3240, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3241, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 1, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 1, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 7, 2, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 1, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3242, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3244, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3245, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 8, 4, 6, 16, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 3, 4, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3246, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 2, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 8, 1, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3247, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 4, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 8, 4, 6, 22, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3357, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3358, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3359, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 3, 2, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 7, 4, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3360, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 5, 2, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 3, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 7, 4, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3362, 8, 4, 3, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 1, 1, 1, 71, 213);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 8, 4, 2, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3363, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3364, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 3, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 1, 2, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3365, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 8, 2, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3019, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3020, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 3, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 4, 1, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 1, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3021, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 3, 3, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 2, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3022, 8, 4, 6, 46, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 3, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 1, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 6, 3, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 3, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3023, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 1, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 4, 6, 48, 720);
commit;
prompt 77000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3024, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 1, 1, 75, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3135, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 3, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 3, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 3, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3136, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 3, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 3, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 2, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 2, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3137, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3138, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 1, 3, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 8, 1, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3139, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 4, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 2, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 4, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 2, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 6, 4, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3140, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3141, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 2, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3142, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3248, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 5, 1, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3249, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 2, 3, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 5, 2, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3250, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 8, 4, 6, 64, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3251, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 5, 3, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3252, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 4, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 1, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 2, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3253, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3254, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 2, 4, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 5, 3, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 1, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3375, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 7, 1, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3377, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 4, 6, 23, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 2, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3378, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3379, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 1, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 5, 1, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 3, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3380, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 2, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 3, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 4, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3025, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3026, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 1, 4, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3027, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3028, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 7, 1, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 3, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 3, 2, 6, 35, 385);
commit;
prompt 78000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 2, 3, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3029, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 2, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 2, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 3, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3030, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3031, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3032, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 4, 2, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 6, 1, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3033, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 4, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 1, 2, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 3, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3034, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 2, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 8, 3, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3143, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 3, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 3, 3, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 8, 1, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3144, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 5, 2, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3145, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 8, 4, 2, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3146, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 6, 4, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 4, 6, 78, 1404);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 1, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 3, 4, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3147, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 6, 1, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3148, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 1, 2, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3149, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 3, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 6, 90, 1620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3255, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3256, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 2, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 4, 1, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3257, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 5, 3, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3258, 7, 3, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 8, 4, 6, 36, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 2, 2, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 1, 3, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3259, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 1, 1, 1, 14, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3260, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3261, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3262, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 4, 2, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3263, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 1, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 3, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 1, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 4, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 4, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 2, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 1, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3387, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3388, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 3, 2, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 3, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3389, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 2, 5, 96, 864);
commit;
prompt 79000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 1, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 4, 3, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3390, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 5, 4, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 5, 4, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3391, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3035, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 4, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3036, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 7, 3, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3037, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 4, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3038, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 8, 2, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3039, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3040, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 2, 3, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 6, 1, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3041, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3042, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 2, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 2, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 3, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 2, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3150, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 4, 4, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 5, 3, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3151, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 4, 1, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 4, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 2, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 2, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 2, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 4, 1, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 1, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3152, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 2, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 1, 1, 2, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3153, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 1, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3154, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 4, 4, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3155, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3264, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 4, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 2, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 4, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3265, 1, 3, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3266, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3267, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3268, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 3, 4, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3269, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 3, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 5, 1, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 5, 1, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3270, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 7, 3, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 5, 3, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3271, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 2, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 6, 1, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3366, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 1, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 1, 2, 61, 610);
commit;
prompt 80000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3367, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 1, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 5, 3, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3368, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 6, 1, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3369, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 4, 2, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 2, 2, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 3, 3, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 4, 1, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3370, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 7, 4, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 2, 4, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3371, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3372, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 4, 2, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 2, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 1, 3, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3373, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3374, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 1, 1, 1, 59, 177);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3043, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 5, 4, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 1, 4, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3044, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 7, 1, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3045, 3, 2, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 3, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3046, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 6, 3, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3047, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 3, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 3, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 2, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3048, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3049, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 2, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 8, 1, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 1, 49, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3156, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 3, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 6, 4, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3157, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 8, 2, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 5, 1, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 1, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3158, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 4, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 1, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 1, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 4, 4, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3159, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 8, 4, 6, 100, 1800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3160, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 1, 1, 77, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 1, 6, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 1, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 1, 3, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 1, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 3, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 4, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 1, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 1, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3272, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 1, 4, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3273, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 1, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3274, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 4, 5, 38, 570);
commit;
prompt 81000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 2, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 1, 1, 11, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 3, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3275, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 7, 4, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3276, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3277, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 2, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3278, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 2, 2, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 1, 6, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 3, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3381, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 2, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3382, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3383, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 1, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3384, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 1, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 1, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3385, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3386, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 3, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 7, 1, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 1, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 4, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 1, 1, 5, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3050, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 5, 3, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 3, 3, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 8, 4, 6, 43, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3051, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 5, 2, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 2, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3052, 5, 3, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 3, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 1, 4, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 2, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 1, 2, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3053, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 5, 4, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 1, 3, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 3, 4, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3054, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 1, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 6, 2, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3055, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 1, 3, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 1, 4, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 3, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3161, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3162, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 7, 3, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3163, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 8, 2, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 1, 2, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3164, 6, 4, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 1, 2, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 3, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3166, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 8, 3, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3167, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 7, 2, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 7, 4, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 4, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3168, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 4, 2, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 7, 1, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3169, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 4, 2, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3170, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 2, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 1, 2, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 3, 1, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3279, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 6, 4, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 8, 1, 5, 97, 1358);
commit;
prompt 82000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3280, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 1, 2, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 4, 3, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3281, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3282, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 2, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 4, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 4, 2, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 5, 4, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3283, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3284, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 3, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 3, 4, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 6, 1, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 2, 2, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3285, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 1, 3, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 1, 1, 3, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3286, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3287, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 3, 4, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 6, 4, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3392, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 1, 2, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 2, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 4, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3393, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 1, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 1, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 7, 2, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 2, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 1, 3, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3394, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 4, 4, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3395, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 4, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3396, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3397, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 1, 3, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3398, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 4, 1, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 4, 4, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 2, 1, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3056, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 8, 2, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 5, 3, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 4, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 1, 1, 52, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3057, 4, 1, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3058, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 4, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 1, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 3, 4, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 3, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 4, 4, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3059, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 5, 2, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 2, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 2, 3, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3060, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 8, 3, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 8, 3, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 1, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 4, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3061, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3171, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 4, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 3, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 3, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 4, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 1, 1, 2, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3172, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3173, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 5, 4, 2, 88, 968);
commit;
prompt 83000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3174, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3175, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 2, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 1, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 2, 4, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3176, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 1, 4, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3177, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3288, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3289, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3290, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3291, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 2, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 2, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 4, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 8, 1, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3292, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 1, 2, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 4, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 1, 2, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 5, 3, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2954, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 3, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 3, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 4, 3, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2955, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 1, 1, 3, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2956, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2957, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 4, 6, 57, 1026);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 7, 1, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2958, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 3, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2959, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 1, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 5, 3, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 3, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3062, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3063, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 1, 4, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 2, 2, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3064, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 1, 4, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3065, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 2, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3066, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 1, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3067, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 1, 1, 11, 55);
commit;
prompt 84000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3178, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3179, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 4, 3, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3180, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 2, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 4, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3181, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 3, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 1, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3182, 3, 1, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 2, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3183, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 2, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3184, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 4, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 3, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3293, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 6, 1, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3294, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 6, 1, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3295, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 4, 1, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 6, 4, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 1, 6, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 1, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 3, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 1, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 4, 2, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 1, 3, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3296, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3297, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 5, 3, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3298, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3299, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 3, 4, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 1, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 4, 1, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 7, 2, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2960, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2961, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 4, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2962, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 3, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 2, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 8, 4, 6, 58, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2963, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2965, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2966, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 1, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2967, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 4, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 4, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 1, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 2, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3068, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 2, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 4, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 3, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3069, 8, 4, 6, 32, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 6, 3, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 1, 2, 4, 30, 210);
commit;
prompt 85000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 2, 3, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3070, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 6, 2, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3071, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3072, 7, 3, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 3, 4, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3073, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 1, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 1, 3, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 5, 4, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3074, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 5, 1, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3075, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 3, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 2, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 2, 3, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3185, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3186, 3, 1, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 5, 1, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 3, 3, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3187, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 2, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3188, 6, 1, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 2, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 1, 3, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 1, 1, 4, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3189, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 8, 2, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 5, 3, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3190, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 7, 2, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 1, 1, 33, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 3, 1, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3191, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 3, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 3, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 2, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3192, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 6, 1, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 1, 1, 3, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3193, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3300, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 2, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 2, 3, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3301, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 1, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 3, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 8, 2, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 1, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3302, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3303, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 6, 1, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3304, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 3, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 4, 3, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3305, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 3, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 2, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 1, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 4, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3306, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 4, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3307, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 5, 4, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3308, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2968, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 5, 4, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 3, 3, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2969, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 3, 3, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2970, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 3, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 3, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 1, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 2, 3, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2971, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2972, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 1, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2973, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2974, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 8, 2, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 2, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 4, 2, 10, 130);
commit;
prompt 86000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2975, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 4, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 1, 3, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2976, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 4, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3076, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 4, 2, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 7, 3, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3077, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3078, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3079, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3080, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 5, 4, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3081, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 4, 2, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3082, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 4, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 3, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 1, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 3, 3, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 1, 2, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 1, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3194, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 3, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 3, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 4, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 3, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3195, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 2, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 3, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 4, 4, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 2, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 3, 2, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3196, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 1, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 3, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 4, 1, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3197, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 7, 3, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3198, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 2, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3309, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 1, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3310, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 3, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 4, 1, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3311, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3312, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 1, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 3, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 6, 2, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3313, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3314, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 1, 1, 52, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3315, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 2, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 3, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 2, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 8, 4, 5, 14, 238);
commit;
prompt 87000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2977, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 1, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 1, 1, 3, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2978, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 8, 4, 6, 80, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2979, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 1, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 7, 3, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2980, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 2, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 1, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 2, 2, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 4, 3, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2981, 1, 1, 3, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 8, 2, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2982, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 7, 3, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3083, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 4, 6, 57, 1026);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3084, 2, 4, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 5, 2, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 1, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 8, 4, 3, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 4, 3, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 7, 4, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3085, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 8, 3, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 2, 4, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3086, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 8, 2, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3087, 1, 2, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 4, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 1, 3, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 2, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3088, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 1, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 4, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3089, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3199, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 1, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 3, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3200, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3201, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 1, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 4, 1, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 4, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 2, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 4, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3202, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 7, 1, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 7, 1, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 6, 4, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3203, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 6, 1, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 4, 1, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3204, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 3, 4, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 2, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 2, 1, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 3, 4, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 6, 3, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3205, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 3, 3, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3317, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3318, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3319, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3320, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 3, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3321, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 8, 1, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 8, 4, 6, 12, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3322, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3323, 6, 1, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 8, 4, 6, 50, 900);
commit;
prompt 88000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 8, 2, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3324, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 2, 2, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3325, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 2, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 1, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 6, 3, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2983, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 1, 3, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2984, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2985, 5, 3, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 2, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 4, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 1, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2986, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 1, 1, 79, 237);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2987, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 2, 4, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 7, 2, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2988, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 4, 3, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 2, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 4, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2989, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2990, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 2, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 2, 4, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 2, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 1, 2, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3090, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 1, 1, 5, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 4, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3091, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 3, 4, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3092, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 4, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3093, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 2, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 4, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 4, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3094, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3095, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 4, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 1, 5, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3096, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3097, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3098, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 4, 6, 36, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3207, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 1, 4, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 2, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3208, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 3, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3209, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3210, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 1, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 4, 3, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3211, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 1, 4, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3212, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 1, 3, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 4, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 3, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3213, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 1, 1, 6, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 3, 2, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 7, 1, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3214, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 2, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 7, 1, 2, 10, 100);
commit;
prompt 89000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3326, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 1, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 7, 1, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 2, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 4, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 2, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 4, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 5, 1, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3327, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 3, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 3, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3328, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 1, 4, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 1, 3, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3329, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 1, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 4, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3330, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3331, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 2, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3332, 6, 4, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 2, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 1, 4, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3538, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 1, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 4, 5, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 1, 4, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 4, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3539, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 1, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 4, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 6, 4, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3540, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 2, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 4, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 4, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 7, 2, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 3, 4, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3541, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 6, 4, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 2, 3, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 4, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3542, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3543, 2, 2, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 2, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 1, 1, 49, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 4, 6, 47, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 1, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3648, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 3, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 2, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 3, 4, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3649, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3650, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 8, 3, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 1, 1, 1, 1, 3);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3651, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 6, 1, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 5, 1, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3652, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 3, 1, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 1, 1, 96, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3653, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 3, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 1, 2, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 5, 1, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3747, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 6, 2, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3748, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 4, 4, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 3, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 1, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3749, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 3, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 1, 2, 5, 15, 120);
commit;
prompt 90000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3750, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3751, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3752, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 3, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 4, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3753, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3754, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 8, 3, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 4, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3433, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 1, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 4, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3434, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 4, 6, 57, 1026);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 3, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3435, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 3, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 4, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3436, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 3, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3437, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3544, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3545, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 3, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 4, 3, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 4, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 1, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3546, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 4, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 4, 2, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3547, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3548, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 1, 2, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 3, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 4, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 6, 3, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 8, 4, 6, 1, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3549, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 2, 4, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 2, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 2, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 2, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3654, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 8, 1, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3655, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 4, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 7, 1, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 3, 1, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3656, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 4, 2, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 3, 4, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3657, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 2, 4, 26, 286);
commit;
prompt 91000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 4, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 3, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 4, 1, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 1, 1, 2, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 7, 2, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 4, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 4, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3755, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 8, 2, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3756, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 4, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 4, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3757, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 1, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3758, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 4, 6, 16, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 2, 2, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3759, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 1, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3438, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 1, 4, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3439, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 2, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 1, 4, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 2, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 1, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3440, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3441, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 5, 2, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3442, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 8, 2, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3443, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 1, 5, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 2, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 4, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 4, 6, 35, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3444, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 2, 2, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 4, 4, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3550, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3551, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 4, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 2, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3552, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 4, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 3, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3553, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 2, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3554, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 3, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 4, 3, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 1, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3555, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 2, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 4, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3658, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 3, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 1, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 2, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 1, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 4, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 4, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 4, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 4, 6, 61, 1098);
commit;
prompt 92000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3659, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 2, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 8, 2, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3660, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 8, 1, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 5, 4, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 3, 2, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3661, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 4, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 1, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 6, 2, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 4, 6, 100, 1800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 2, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 4, 5, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3760, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 6, 3, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 2, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 2, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3762, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 2, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 7, 2, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3763, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 3, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 2, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 3, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 4, 4, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3764, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 2, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 3, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 3, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 4, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 3, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 4, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 4, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 2, 2, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 3, 3, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3445, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 1, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 2, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 8, 4, 6, 12, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3446, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3447, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 2, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 4, 4, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 4, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 2, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3448, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 2, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 2, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3449, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 4, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 2, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 1, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 3, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3450, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 4, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3556, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 1, 5, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3557, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 1, 1, 2, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3558, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3559, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 1, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 4, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3560, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 4, 3, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 2, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3561, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3562, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 3, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 1, 4, 64, 384);
commit;
prompt 93000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 1, 1, 6, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 2, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3563, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3662, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 4, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 1, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 1, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 1, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 5, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3663, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 2, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3664, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 5, 2, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3665, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 8, 2, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3666, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 4, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 1, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 3, 1, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3667, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 2, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 4, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3765, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 4, 1, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 1, 4, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3766, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 3, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 1, 1, 40, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 2, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 4, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 3, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3767, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 4, 4, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 6, 4, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3769, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 1, 2, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 1, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 6, 1, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3770, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 2, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 3, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 4, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 8, 3, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3771, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3451, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3452, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 2, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 3, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 2, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 3, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3453, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 1, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 3, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 4, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 3, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3454, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3564, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 2, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 4, 3, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 4, 1, 12, 72);
commit;
prompt 94000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 4, 4, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 5, 2, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3565, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 3, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3566, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 3, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 2, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 1, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 3, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 8, 1, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 7, 1, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3567, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3568, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 2, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 5, 4, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3569, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 2, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 4, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 3, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3668, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3669, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 1, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 1, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 4, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 4, 3, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3670, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 4, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 3, 1, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3671, 7, 4, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 4, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 2, 3, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3672, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 2, 2, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 6, 1, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3673, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 1, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 1, 1, 52, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 2, 1, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3674, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 6, 3, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 4, 4, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3772, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 4, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 1, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3773, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 1, 1, 1, 4, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 1, 1, 1, 21, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3774, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 2, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 2, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3775, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 1, 2, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 1, 2, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 2, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 6, 2, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3776, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 4, 3, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 4, 2, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3777, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 4, 4, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3778, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 1, 1, 3, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3779, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 4, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 3, 3, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3455, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 3, 1, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 8, 3, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 8, 4, 3, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 2, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 7, 3, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3456, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 2, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 3, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 2, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 3, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 2, 1, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3457, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 2, 3, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3458, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 2, 5, 86, 860);
commit;
prompt 95000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3459, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 4, 5, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 1, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 2, 4, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3461, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 4, 6, 84, 1512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3570, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 3, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 3, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 2, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 2, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 2, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 3, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 7, 2, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3571, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 1, 6, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3572, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 1, 4, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3573, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 3, 2, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3574, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 6, 1, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 5, 2, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 8, 2, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3675, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 8, 3, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3676, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 3, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 4, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 3, 1, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 1, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3677, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 3, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 1, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 4, 5, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 4, 1, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 4, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 3, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3678, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 2, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 3, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 4, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3679, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 6, 1, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 3, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3680, 3, 1, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3681, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 4, 4, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 3, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3780, 3, 1, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 4, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 1, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3781, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 4, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 2, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 3, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 3, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 3, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 4, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 1, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 1, 2, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3782, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 1, 1, 5, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3783, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3784, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 7, 1, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 6, 3, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 1, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 7, 1, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3462, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 6, 3, 4, 49, 637);
commit;
prompt 96000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3463, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 1, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3464, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 6, 1, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 5, 2, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3465, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 4, 4, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 1, 6, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 1, 2, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 5, 1, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3466, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 4, 4, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 3, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3467, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3468, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 3, 4, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3575, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 4, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 6, 1, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3576, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 1, 1, 1, 2, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 3, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3578, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 8, 4, 6, 87, 1566);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 1, 4, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3579, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 3, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 5, 2, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3580, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 2, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3581, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 3, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 3, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 3, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3682, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3683, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 2, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 4, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 4, 2, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3684, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 3, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3685, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 4, 2, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3687, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 4, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 4, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 2, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 2, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 2, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 3, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 3, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 2, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3792, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 5, 1, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 3, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3793, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 2, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 8, 1, 2, 78, 858);
commit;
prompt 97000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 3, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 4, 2, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 2, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 1, 3, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 1, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3794, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 4, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 2, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 2, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 2, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 8, 1, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 3, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3795, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 1, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3469, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3470, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3471, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3472, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 7, 2, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 1, 1, 6, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3473, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 7, 1, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 4, 4, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 4, 4, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3474, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 1, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 1, 4, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 7, 3, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 4, 3, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3475, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 1, 2, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 2, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3476, 3, 1, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 3, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 3, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 3, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 1, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3582, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 5, 3, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3584, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3585, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3586, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 2, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 4, 3, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 2, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 3, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 6, 2, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 1, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 1, 4, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 4, 3, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3587, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 2, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 4, 5, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 2, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 4, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 3, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 1, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 2, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3588, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 4, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 3, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 1, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 1, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3688, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3689, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3690, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 3, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3691, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 5, 4, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 2, 2, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 8, 3, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3692, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 5, 2, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 4, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3693, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 3, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 2, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 4, 1, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3694, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 6, 2, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 2, 6, 33, 495);
commit;
prompt 98000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 4, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 6, 2, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3803, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3804, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 8, 2, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3805, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3806, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 1, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 1, 18, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 3, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 3, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 4, 1, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3807, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 3, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 1, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 1, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 2, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 4, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 1, 4, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3808, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3809, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 1, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3477, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 7, 1, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 7, 2, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3478, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 5, 1, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3479, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 4, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 1, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 5, 1, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3480, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 1, 4, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 1, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 8, 1, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3481, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 1, 2, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 3, 4, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3589, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 3, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3590, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 2, 1, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3591, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3592, 2, 2, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 1, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3593, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 2, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3594, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3695, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3696, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 2, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 2, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 3, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 3, 5, 7, 91);
commit;
prompt 99000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 8, 3, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 4, 3, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3697, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 2, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 2, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3698, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 8, 4, 6, 14, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3699, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3700, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 7, 2, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3701, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 3, 3, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3702, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3785, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 3, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 1, 6, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 1, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3786, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 1, 5, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 3, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 8, 2, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 1, 5, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3787, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 2, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3788, 8, 2, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3789, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 5, 1, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3790, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3791, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 7, 2, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3482, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 3, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3483, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 1, 1, 1, 33, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3484, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 6, 4, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 3, 3, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3485, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 1, 5, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3486, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3487, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3489, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 3, 3, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 6, 4, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3490, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 7, 1, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 3, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 2, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 1, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3595, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 2, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 6, 3, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3596, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 3, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 2, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 1, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3597, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 6, 1, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 3, 3, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3598, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 2, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 8, 1, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 3, 3, 36, 324);
commit;
prompt 100000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3599, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 6, 1, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 2, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 1, 1, 13, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3600, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3703, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 1, 4, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3704, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 1, 3, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 2, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3705, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 4, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3706, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 1, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 1, 1, 3, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 4, 6, 3, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3707, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 7, 4, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 1, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3708, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 4, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 4, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3709, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 1, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 4, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 8, 2, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3796, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 4, 1, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3797, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 3, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 1, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3798, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 4, 1, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3799, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 3, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3800, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 4, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 4, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3801, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 3, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3802, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 2, 1, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3491, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 8, 4, 5, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3492, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 6, 2, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 4, 4, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3493, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 3, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 2, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3494, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3495, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 1, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 3, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 2, 1, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 8, 3, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3496, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3497, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3601, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3602, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3603, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 3, 4, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 4, 49, 637);
commit;
prompt 101000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 3, 4, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3604, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3605, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 2, 2, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3606, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 4, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3607, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 1, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3710, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 2, 3, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3711, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 4, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 3, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 3, 1, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 3, 4, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 1, 2, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3712, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 4, 3, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 7, 1, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3713, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 2, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 5, 2, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3714, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 3, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 2, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 5, 2, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3715, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 1, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 8, 4, 6, 1, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3716, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3717, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 7, 3, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 3, 2, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2943, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 4, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2944, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2945, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 4, 3, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 4, 2, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 4, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2946, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 5, 4, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 7, 4, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 7, 4, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2947, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 1, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 4, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2948, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2949, 5, 4, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 4, 2, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 1, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2950, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2951, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 2, 1, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 3, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 7, 3, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2952, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (2953, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 4, 4, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3498, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 2, 3, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3499, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 3, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 3, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 7, 4, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 8, 4, 1, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 4, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3500, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 2, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 5, 2, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 1, 6, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3501, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 4, 6, 18, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 3, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 1, 6, 54, 756);
commit;
prompt 102000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 4, 2, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3502, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 4, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3503, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 2, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 2, 1, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 2, 2, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 2, 2, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 3, 3, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3504, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 4, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3608, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 2, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 8, 1, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 4, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3609, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 8, 4, 5, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3610, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 4, 4, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 4, 1, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3611, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 1, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 3, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 2, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3612, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 1, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 4, 2, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3613, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 6, 4, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3614, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3615, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3718, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 5, 4, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3719, 8, 1, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 4, 2, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 3, 1, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3720, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 1, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 1, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 3, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 1, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 2, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3721, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 1, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 1, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3722, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 1, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 4, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 4, 4, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3399, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 6, 4, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 6, 1, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3400, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 1, 6, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 1, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 4, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 3, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3401, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 4, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 6, 1, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 3, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 3, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 2, 1, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3402, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3403, 8, 3, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 3, 1, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3404, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3405, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 1, 3, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3406, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 2, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 4, 4, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 8, 2, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 4, 3, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 3, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3407, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 2, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 4, 1, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 4, 2, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 4, 1, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 6, 3, 4, 51, 663);
commit;
prompt 103000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3505, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 1, 4, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 1, 3, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3507, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 4, 4, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3508, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3509, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 4, 1, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3510, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 5, 2, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 4, 4, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3511, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 1, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 1, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 4, 2, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3512, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 4, 6, 26, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 3, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3513, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 1, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 2, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 3, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 1, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 1, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 3, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 4, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 8, 2, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 1, 4, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 1, 1, 6, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3616, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 2, 1, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 6, 2, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 1, 1, 3, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 8, 3, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3617, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 1, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3618, 3, 4, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3619, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 1, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 5, 1, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 2, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 8, 4, 6, 47, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3620, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 1, 1, 50, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 2, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 4, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 2, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 1, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 6, 4, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 2, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3621, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 4, 6, 42, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 4, 2, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3723, 5, 1, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 4, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 5, 2, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 1, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 8, 2, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3724, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 2, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 2, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3725, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3726, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 6, 1, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 2, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 3, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 3, 4, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 2, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 4, 4, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 3, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 2, 3, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3408, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 4, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3409, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 4, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 8, 3, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 7, 4, 4, 46, 690);
commit;
prompt 104000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3410, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 4, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 3, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 3, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 3, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 1, 2, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3411, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 1, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 2, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 3, 2, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3412, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 7, 4, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3413, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 2, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 3, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 3, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 1, 2, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 2, 4, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3514, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 3, 4, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 2, 3, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 2, 2, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 6, 2, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3517, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 1, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 5, 3, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3518, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3519, 5, 4, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 4, 6, 80, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 2, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3520, 2, 4, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 4, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 1, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3622, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 2, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3623, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 2, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3624, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 3, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 3, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 6, 3, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3625, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 6, 4, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 2, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 3, 1, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3626, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3627, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3628, 6, 1, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 1, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 4, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3629, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 1, 5, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3727, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3728, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 4, 4, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3729, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 1, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 2, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 2, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 2, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3730, 7, 4, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 8, 3, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3731, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 7, 3, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 1, 1, 11, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3732, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 8, 3, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 1, 1, 26, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3733, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 4, 4, 4, 19, 228);
commit;
prompt 105000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 3, 2, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3734, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 3, 1, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 3, 2, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 4, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3414, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 1, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 7, 3, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3415, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 4, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 7, 1, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3416, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 1, 3, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3417, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 4, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 3, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 2, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 1, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 1, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 3, 2, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3418, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3419, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 3, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3521, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 1, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 6, 4, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3522, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 6, 1, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 8, 1, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3523, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 3, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3524, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 4, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 1, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 4, 3, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 3, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3525, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 1, 1, 4, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3526, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 1, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 4, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 4, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 1, 1, 5, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3630, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 6, 4, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 2, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 1, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 1, 1, 1, 5, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 4, 2, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 2, 1, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3632, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3633, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 6, 4, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 3, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 8, 3, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3634, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 2, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 4, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 1, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 4, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 1, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 3, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 4, 6, 67, 1206);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 4, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 4, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 3, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 6, 3, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3635, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 3, 4, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 8, 2, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3636, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 1, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3637, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 1, 2, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 3, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 6, 1, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3735, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 4, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 3, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 3, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 7, 1, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 3, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3736, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 3, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 4, 4, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 2, 3, 3, 6, 48);
commit;
prompt 106000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3737, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 1, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 3, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 1, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3738, 6, 2, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 3, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 8, 2, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 1, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 1, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 2, 2, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3739, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 2, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 4, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 4, 4, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3420, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 2, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 4, 1, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 8, 3, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 3, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 3, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 5, 1, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 2, 1, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3421, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 3, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 6, 2, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3422, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 3, 3, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 5, 2, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 4, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 1, 1, 75, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3423, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 3, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 3, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 2, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3424, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 3, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3425, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 1, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 2, 3, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 2, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 1, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 7, 3, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 1, 1, 4, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 5, 4, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3527, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 3, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 4, 4, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3528, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 2, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 2, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 3, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3529, 4, 1, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 7, 3, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3530, 8, 1, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 1, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 2, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 4, 6, 14, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 3, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3531, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3638, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3639, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 4, 6, 9, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 1, 1, 92, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 4, 6, 68, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 4, 5, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 2, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 2, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 1, 3, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3640, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3641, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3642, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 4, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 5, 4, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3643, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 2, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3644, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 1, 4, 2, 30, 210);
commit;
prompt 107000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3646, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 2, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 2, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 2, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3647, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3740, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 1, 3, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 7, 2, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3741, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 2, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 4, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 1, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3742, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3743, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 1, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 2, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 3, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 4, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3744, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 3, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 2, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 1, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 1, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3745, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 3, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 2, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 2, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 3, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3746, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 4, 1, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 3, 1, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3426, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 3, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 4, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 3, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 7, 4, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3427, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 2, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 2, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 2, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3428, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 7, 3, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 7, 3, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3429, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 4, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 2, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 3, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 3, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 3, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 4, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 2, 2, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3430, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3431, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 4, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 1, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3432, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3532, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 1, 1, 2, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3533, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 2, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 3, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 4, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 1, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 4, 3, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3534, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3535, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3536, 5, 2, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3537, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3957, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3958, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 4, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 4, 1, 12, 144);
commit;
prompt 108000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 1, 3, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 4, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 3, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3959, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 3, 2, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 4, 1, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 6, 2, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3960, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 1, 2, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 2, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 7, 1, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3961, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 8, 1, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 3, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 2, 3, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 1, 1, 79, 237);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 2, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3963, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 3, 3, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 3, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 1, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 1, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3964, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 4, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4063, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 1, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 5, 1, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 3, 1, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 4, 4, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4064, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4065, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 4, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 1, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4066, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4067, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 3, 1, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 8, 4, 5, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4068, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 2, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 1, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 3, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 3, 4, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 6, 2, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 8, 4, 4, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 2, 2, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4162, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 4, 4, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 4, 6, 92, 1656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 2, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4163, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 4, 1, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 4, 4, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4164, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 2, 3, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4165, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 2, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 2, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 3, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 2, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4166, 7, 2, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 2, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 2, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 3, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 1, 3, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 4, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 6, 1, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3851, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3852, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 1, 4, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 1, 1, 6, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 4, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 2, 3, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3854, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 4, 3, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 3, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 3, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 6, 3, 6, 25, 375);
commit;
prompt 109000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3855, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 8, 4, 1, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 3, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 4, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3856, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 3, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 4, 1, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3857, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3859, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 1, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3965, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 5, 4, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3966, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 2, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3967, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 3, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 1, 4, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 2, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 1, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 2, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 2, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3968, 7, 1, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 2, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 7, 3, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3969, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3970, 5, 2, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 2, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 2, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4069, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 4, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4070, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 1, 3, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 1, 2, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4071, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 3, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 5, 3, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 4, 2, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4072, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 3, 4, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 6, 4, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4073, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 3, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 1, 2, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 3, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 2, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 1, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4167, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 5, 3, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 3, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 6, 1, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 3, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 3, 1, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4168, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 7, 4, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 7, 3, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4169, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 1, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 4, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 3, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4170, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4171, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 3, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 4, 3, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 5, 1, 5, 28, 308);
commit;
prompt 110000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 5, 1, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3860, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 3, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3861, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 2, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3862, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 2, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 4, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 3, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3863, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 3, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3864, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 6, 3, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3865, 2, 4, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 4, 2, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 3, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3971, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 1, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 4, 2, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 2, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 3, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 6, 2, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3972, 4, 3, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 3, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 4, 1, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 2, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 3, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3973, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 4, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 3, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 1, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3974, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 2, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 4, 6, 54, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 2, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4074, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 4, 1, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 2, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 1, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 4, 5, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4075, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4076, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 1, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 3, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 1, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4077, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 5, 2, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 4, 6, 43, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 4, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4078, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 3, 1, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4079, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 4, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 3, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 2, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4080, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 4, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 2, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4172, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 4, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 1, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 1, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 2, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 1, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 3, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 1, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 7, 3, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4173, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 4, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 3, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 1, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 1, 3, 80, 720);
commit;
prompt 111000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 4, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4174, 3, 4, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 4, 3, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 4, 4, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 1, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 8, 2, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4175, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4176, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 2, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 4, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 4, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 3, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 3, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 3, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 1, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3866, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 6, 4, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 3, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 3, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 3, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3868, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3869, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 7, 3, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3870, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3871, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 2, 3, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3872, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 6, 3, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 4, 2, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3873, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3874, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 3, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 2, 1, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3875, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 2, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 2, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 1, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3975, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 2, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 3, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 2, 4, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3976, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 2, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 3, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 3, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 1, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 2, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 1, 4, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3977, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 2, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 4, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 4, 4, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3978, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 6, 4, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4081, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 1, 4, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4082, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 1, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 1, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4083, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 3, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 2, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 4, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 4, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 5, 4, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4084, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 1, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 2, 3, 97, 776);
commit;
prompt 112000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4085, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 1, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 2, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 2, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4177, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 2, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 4, 6, 62, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4178, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4179, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 3, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4180, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 6, 4, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4181, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 2, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 1, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 1, 1, 29, 87);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 2, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 1, 5, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4182, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 2, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 3, 3, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 7, 4, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3876, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 1, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 1, 1, 4, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3877, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 3, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 2, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 1, 5, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 7, 3, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 4, 1, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3878, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 2, 3, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3879, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3880, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 1, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3881, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 8, 4, 6, 95, 1710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 5, 1, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3882, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3979, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 4, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3980, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 3, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 3, 4, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 1, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3981, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 4, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3982, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 1, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3983, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 4, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 1, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 1, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 4, 6, 5, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3984, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 7, 4, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 2, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 1, 3, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4086, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 4, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 2, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 4, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 1, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 3, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 3, 3, 1, 2, 14);
commit;
prompt 113000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4087, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 8, 1, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4088, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 2, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4089, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 4, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 4, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 1, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 4, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 3, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 8, 1, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 4, 3, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4090, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 2, 4, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4183, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 3, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 1, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 2, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 3, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 3, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 2, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 3, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 3, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4184, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 1, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4185, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 4, 2, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 8, 4, 6, 27, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4186, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 4, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 2, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 4, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 4, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 4, 2, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 1, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 1, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3883, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 2, 2, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 4, 4, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3884, 6, 2, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 4, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 1, 5, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 6, 1, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 3, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3885, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 3, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 2, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 1, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3886, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3887, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 2, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 4, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 4, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 2, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 2, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3888, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 3, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 1, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 8, 4, 6, 49, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3985, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 7, 1, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3986, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 2, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 2, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 1, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 4, 6, 6, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 5, 1, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3987, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 4, 3, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 3, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3988, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 3, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 1, 1, 5, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 1, 1, 2, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 3, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 2, 2, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3989, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 2, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3990, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 1, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 7, 4, 6, 60, 1020);
commit;
prompt 114000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 4, 4, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 8, 2, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3991, 4, 3, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 7, 3, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 4, 2, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 3, 1, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 3, 2, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4091, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4092, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 2, 3, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4093, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 4, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 1, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 3, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 3, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 3, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 2, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 1, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 1, 1, 4, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4094, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4095, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 5, 4, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 3, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 7, 4, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 2, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4096, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 7, 2, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4097, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 8, 4, 6, 78, 1404);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 1, 3, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 3, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 3, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4191, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 1, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 4, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 4, 1, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 2, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 4, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4192, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4193, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 2, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 1, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 3, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 2, 3, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4194, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 1, 1, 71, 213);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 3, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 4, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 3, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 2, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 5, 3, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3889, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 1, 3, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 8, 4, 6, 27, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3890, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 3, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 6, 3, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3891, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 3, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 4, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 1, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 4, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 7, 4, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3892, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 7, 3, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 2, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 1, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 3, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 2, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 4, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 3, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3893, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 1, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 4, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 8, 4, 4, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3894, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 1, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 2, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3992, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 3, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 4, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 3, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 3, 4, 45, 405);
commit;
prompt 115000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 4, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3993, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 2, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 6, 3, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3994, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 5, 1, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 1, 2, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3995, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 1, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 4, 1, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 4, 2, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3996, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3997, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 4, 6, 12, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 4, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3998, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 2, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 3, 3, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4098, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 5, 1, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 1, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4099, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 1, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 1, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 4, 4, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 4, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4100, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 4, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 4, 3, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4101, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4102, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 4, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 1, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 1, 2, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 2, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4103, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 2, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 4, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 4, 2, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 4, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 1, 4, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 2, 4, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 6, 3, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4203, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 1, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4204, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 8, 4, 6, 11, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4205, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 1, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 4, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 2, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 1, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 4, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 7, 2, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 4, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4207, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 1, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 6, 1, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 3, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3895, 1, 1, 1, 38, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 2, 1, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3896, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 3, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 3, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3897, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 2, 2, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 3, 1, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3898, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 7, 3, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 4, 4, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3899, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 4, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 2, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 3, 3, 29, 377);
commit;
prompt 116000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 4, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 3, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 6, 3, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 2, 3, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 7, 3, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3900, 5, 4, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 4, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 4, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 4, 2, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 2, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 3, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 4, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 3, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 4, 3, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3902, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 3, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3999, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 8, 4, 2, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 2, 2, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 4, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4000, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 4, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 6, 3, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 1, 2, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 2, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4001, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 3, 3, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 3, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4002, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 4, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 2, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 3, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 4, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 2, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 1, 2, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4003, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 1, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 1, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 4, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4004, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4104, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 8, 3, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 2, 1, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 5, 2, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4105, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 3, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 3, 2, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4106, 8, 4, 3, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 4, 2, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4107, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 2, 1, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 6, 2, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 8, 4, 3, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 6, 4, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4109, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 1, 3, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 2, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 3, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4110, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 1, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 1, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 1, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4187, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 3, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 2, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 1, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 7, 1, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4188, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 4, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 3, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 4, 6, 14, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 1, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 1, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 3, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 2, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4189, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 1, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 1, 4, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 3, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 4, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4190, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 5, 4, 4, 40, 520);
commit;
prompt 117000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 1, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 7, 3, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3903, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 1, 1, 8, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 4, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 4, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3904, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 3, 1, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 7, 1, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 4, 2, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3905, 7, 1, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 8, 4, 4, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 5, 1, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3906, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3907, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3908, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 3, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 3, 1, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 1, 1, 62, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4005, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 3, 1, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 6, 3, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4007, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 1, 1, 3, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 5, 1, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4008, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 2, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 3, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 4, 6, 4, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 2, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4009, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 4, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 4, 5, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 4, 5, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 4, 1, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 8, 1, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4010, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 5, 3, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4011, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 1, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 1, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 3, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4111, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4112, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 5, 2, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 4, 3, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 4, 3, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 5, 4, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 6, 3, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4113, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 2, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 7, 4, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 1, 4, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 3, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 4, 4, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4114, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 1, 2, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4115, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4116, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 4, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 4, 4, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 8, 1, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 4, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4117, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 3, 1, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 5, 3, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 2, 2, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 4, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4118, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 4, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 2, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 1, 4, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 4, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4195, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 8, 3, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 1, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 3, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4196, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 8, 1, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 1, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 8, 3, 5, 72, 1152);
commit;
prompt 118000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4197, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 7, 2, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4198, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 8, 1, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 3, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 2, 2, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 2, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 4, 3, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4199, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 4, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 4, 4, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 3, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4200, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 5, 1, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4201, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4202, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 4, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3909, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 6, 2, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 2, 1, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 6, 1, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3911, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3912, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 3, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 1, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 2, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 3, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 2, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 2, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 3, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 2, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3913, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 1, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 3, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 4, 2, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3914, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 4, 2, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3915, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 7, 2, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 7, 2, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3916, 5, 1, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 4, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 1, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 4, 3, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4012, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 1, 4, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 2, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4013, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4014, 1, 3, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 3, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 3, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 2, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 1, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 1, 4, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 2, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 2, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 2, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4015, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 4, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 4, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 1, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 2, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 2, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 2, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 1, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 1, 1, 6, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4016, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4017, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 4, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 4, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 6, 2, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 4, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 4, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 4, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 2, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 3, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4119, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 5, 1, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4120, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 4, 6, 87, 1566);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 3, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 3, 1, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4121, 4, 1, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 3, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 3, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 3, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 1, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 3, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 6, 1, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 7, 4, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4122, 3, 2, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 3, 1, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 6, 2, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 1, 6, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4123, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 2, 2, 69, 759);
commit;
prompt 119000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 1, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 3, 2, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4124, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 1, 1, 18, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 1, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 3, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 3, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 8, 1, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4208, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 4, 2, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 2, 4, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 1, 1, 2, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4209, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 2, 1, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 3, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 8, 1, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4210, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 4, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 3, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 4, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 4, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 6, 1, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4211, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 3, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 4, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4212, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 1, 1, 69, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 3, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 3, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 2, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 3, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3917, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3918, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 1, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 3, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 2, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 1, 4, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 7, 1, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 3, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3919, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 3, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 2, 4, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3920, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3921, 4, 4, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 1, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 1, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 2, 1, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4018, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 3, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 1, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 4, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 8, 4, 2, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4019, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 1, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 4, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 1, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 3, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4020, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 2, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 2, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4021, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 4, 4, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 1, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 4, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 8, 1, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4022, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 1, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 1, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 4, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 4, 6, 90, 1620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 1, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 3, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 6, 4, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 3, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 3, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 3, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 7, 2, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4125, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 4, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 4, 3, 95, 1045);
commit;
prompt 120000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 4, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 2, 4, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4126, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 3, 2, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 7, 4, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 2, 4, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4127, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 3, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 3, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 4, 4, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 3, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4128, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 5, 2, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 1, 1, 6, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 3, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4129, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 2, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 3, 2, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 3, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 2, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 4, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 2, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 3, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 3, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 2, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3816, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 2, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 2, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 4, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3817, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 3, 1, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 8, 1, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3818, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 4, 3, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 1, 3, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 4, 1, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3819, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 3, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 1, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 6, 3, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3820, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 3, 1, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 1, 1, 21, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 4, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3922, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 6, 3, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 3, 2, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3923, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 7, 3, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 3, 3, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 3, 2, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3924, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 2, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 8, 1, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3925, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 4, 4, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 3, 4, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3926, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 6, 1, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 4, 4, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 6, 3, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3927, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 2, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 3, 1, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 1, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 2, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3928, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 2, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 1, 2, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4023, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 6, 3, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4024, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 2, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 2, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 1, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4025, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 3, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 4, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4026, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 4, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 2, 4, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4027, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 1, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 3, 3, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4028, 6, 3, 1, 10, 100);
commit;
prompt 121000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 3, 4, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 1, 1, 1, 71, 213);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 1, 3, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4029, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 7, 3, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4030, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 6, 4, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 1, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 1, 4, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 6, 2, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 2, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 3, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 2, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 1, 3, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4130, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 1, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 8, 1, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 2, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4131, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 2, 4, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 5, 1, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4132, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 4, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 4, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 4, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4133, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 3, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 4, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 8, 4, 2, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4134, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 2, 2, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 7, 2, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 3, 2, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 8, 3, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 8, 2, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4135, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 5, 3, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 3, 1, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3821, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 4, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 3, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 3, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 3, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 1, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 1, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 5, 2, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 8, 2, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3822, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 3, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 1, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 2, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3823, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 3, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 3, 2, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 7, 2, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3824, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3825, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 1, 1, 92, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 4, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 5, 4, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3826, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 4, 3, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 1, 1, 80, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 3, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 2, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 2, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 1, 1, 1, 79, 237);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3827, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3929, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 2, 2, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 7, 3, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 2, 2, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 1, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 1, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 2, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 1, 2, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3930, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 3, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 2, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 2, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3931, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 2, 1, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3933, 3, 2, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 1, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 4, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 1, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 3, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3934, 6, 1, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 1, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 1, 5, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4031, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 2, 4, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4032, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 2, 1, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4033, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 1, 4, 75, 450);
commit;
prompt 122000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 4, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 2, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 3, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 2, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 2, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 4, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 1, 2, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4034, 5, 2, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 1, 4, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 2, 3, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4035, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 3, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 2, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 2, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 2, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 1, 6, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 4, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4036, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 4, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 2, 4, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4136, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 4, 2, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4137, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 1, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 3, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 4, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 4, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 6, 4, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4138, 1, 3, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 1, 3, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4139, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 4, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 3, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4140, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 3, 4, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4141, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 2, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 3, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 3, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 3, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 4, 3, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 1, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 3, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 4, 1, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 4, 3, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3828, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 3, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3829, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 3, 3, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 1, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 4, 1, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 2, 3, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3830, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 5, 4, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 4, 2, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3831, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 3, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 4, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 1, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 3, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 1, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 2, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 2, 3, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 1, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3832, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3833, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 3, 1, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3834, 1, 1, 1, 78, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 2, 1, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 2, 3, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 7, 3, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3835, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 4, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 1, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 1, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3935, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 1, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 1, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 2, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3936, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 3, 1, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 6, 3, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3937, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 4, 1, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 1, 1, 4, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3938, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 3, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 1, 2, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 3, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 3, 4, 4, 89, 979);
commit;
prompt 123000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3939, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 4, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 4, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3940, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 7, 4, 2, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 5, 2, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 4, 2, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3941, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 6, 94, 1692);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 3, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 3, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 3, 4, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4037, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 1, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 1, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 2, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 2, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4038, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 3, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 1, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 3, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 3, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 5, 1, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4041, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 4, 3, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 2, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 2, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 5, 2, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4042, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 3, 4, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 4, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4043, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 5, 1, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 1, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 2, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 3, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 2, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 3, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 2, 2, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4142, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 4, 1, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 1, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 4, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4143, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 1, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 3, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 1, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 4, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 1, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 4, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 4, 6, 19, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 2, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 7, 1, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4144, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 2, 3, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 7, 4, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 7, 1, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4145, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 2, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 1, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4146, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 3, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4147, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 3, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3836, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3837, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3838, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 5, 2, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3839, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 3, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 1, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3840, 1, 4, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 8, 3, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 4, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3841, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 6, 3, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 3, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 1, 4, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 3, 2, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3842, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 3, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 4, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 3, 4, 43, 602);
commit;
prompt 124000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3942, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 1, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3943, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 8, 1, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3944, 4, 4, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 5, 1, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3945, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 4, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 3, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 4, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 2, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3946, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 1, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 1, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 1, 5, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3947, 4, 4, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 6, 1, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 1, 2, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 8, 4, 4, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 2, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 1, 2, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 2, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 3, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4044, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 4, 3, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 2, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 5, 2, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4046, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 1, 2, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 4, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 4, 1, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 3, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 2, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 2, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 4, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 2, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 6, 1, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 2, 2, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 4, 1, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4047, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 8, 4, 6, 22, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 8, 1, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 4, 1, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4048, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 4, 4, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 2, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 7, 4, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 7, 3, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4049, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 4, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 1, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 4, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 3, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4050, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 1, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 1, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 2, 2, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 1, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4148, 1, 3, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 8, 2, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4149, 6, 1, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 4, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 5, 4, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 4, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 3, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4150, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 2, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 3, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 1, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4151, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 1, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 4, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 4, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 4, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 1, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4152, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 5, 3, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4153, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 2, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 4, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 1, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3843, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 4, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 3, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 1, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 4, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 2, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 3, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 4, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 1, 3, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3844, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 1, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 2, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 2, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 4, 3, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 1, 6, 6, 90);
commit;
prompt 125000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3845, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3846, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 3, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3848, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 3, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 7, 4, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 1, 1, 8, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3849, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3850, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 7, 1, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3948, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 4, 1, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 7, 1, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 3, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3949, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 1, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 5, 4, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3950, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 6, 4, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 8, 1, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 2, 3, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 3, 2, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3951, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 3, 3, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 1, 2, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 7, 1, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 6, 3, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3952, 5, 1, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 3, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 8, 1, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 7, 3, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3953, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 6, 1, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3954, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 4, 6, 54, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 4, 6, 65, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 1, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 7, 3, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 3, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3955, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 4, 4, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 1, 1, 6, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 2, 4, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3956, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4051, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 1, 2, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4052, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 1, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 1, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 3, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 2, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 1, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 4, 3, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 3, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 3, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4053, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 5, 2, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 4, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 7, 2, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 3, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 4, 1, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4054, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 6, 2, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 2, 4, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4055, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 3, 4, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 1, 1, 68, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 6, 1, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 6, 2, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4056, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 1, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 8, 2, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4057, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 5, 1, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 2, 1, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 5, 3, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 1, 1, 3, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4058, 8, 2, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 7, 2, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 1, 1, 5, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4059, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4061, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4062, 3, 4, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 3, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 3, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4154, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 4, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 2, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 2, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4155, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 1, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 1, 2, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 3, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 3, 1, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 4, 3, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4156, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 1, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 1, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 4, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 1, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4157, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 8, 3, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 1, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 8, 2, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4158, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 6, 2, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 7, 2, 1, 16, 160);
commit;
prompt 126000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 2, 2, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4159, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 1, 2, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 1, 3, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 1, 3, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4160, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4161, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 1, 3, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 1, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 4, 4, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 1, 3, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4331, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 4, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 2, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 1, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 7, 3, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 2, 3, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4332, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 4, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 3, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 4, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4333, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 7, 3, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 1, 1, 1, 26, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4334, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 3, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 4, 5, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 3, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 1, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 4, 2, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 6, 3, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4335, 8, 4, 2, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 2, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 8, 2, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 8, 3, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 1, 3, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 4, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 2, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 8, 3, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4419, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 3, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 8, 4, 1, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4420, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 5, 4, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 1, 1, 59, 236);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4421, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 4, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4422, 1, 1, 4, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 4, 2, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 7, 3, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 3, 3, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4423, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 2, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 6, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 1, 3, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 3, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 4, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 2, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 1, 4, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 3, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4424, 7, 3, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 7, 3, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 1, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 8, 4, 6, 81, 1458);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4512, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 1, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 3, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 1, 2, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 3, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 1, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4513, 4, 3, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 4, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 3, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 1, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 3, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 2, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 2, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 3, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4514, 4, 1, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 3, 3, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 2, 4, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 1, 2, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4515, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 1, 2, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 8, 4, 6, 17, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 1, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 4, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 8, 2, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4516, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 4, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 1, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 4, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 2, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 3, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 2, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 2, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 3, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 3, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 3, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 3, 3, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 3, 2, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4240, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 1, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 6, 14, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 3, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 2, 51, 714);
commit;
prompt 127000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 1, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 3, 6, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 2, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 3, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 2, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 3, 4, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4241, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 4, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 1, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 4, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 3, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 4, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 4, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 6, 4, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4336, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 2, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 1, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 4, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 2, 1, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4337, 7, 4, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 6, 1, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 2, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 4, 3, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 2, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4338, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 4, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 4, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 1, 1, 91, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 4, 6, 30, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 3, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4339, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 1, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 3, 2, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 2, 4, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 4, 4, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4340, 3, 3, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 8, 1, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 6, 3, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 4, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 2, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 3, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 1, 1, 5, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 1, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4341, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 2, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 8, 4, 5, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 3, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 4, 3, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4342, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 3, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 4, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 2, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4425, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 4, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 3, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 3, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 4, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 1, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 2, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 3, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 1, 5, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 1, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 8, 3, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4427, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 2, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 2, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4428, 5, 2, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 3, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 4, 1, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 1, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4429, 7, 4, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 1, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 2, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 4, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 1, 2, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 4, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 2, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4430, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 6, 2, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4431, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 7, 2, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 5, 2, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4517, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 8, 3, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 1, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4518, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 1, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 3, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 1, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 1, 4, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 2, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 5, 4, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4519, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 3, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 1, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 8, 4, 6, 93, 1674);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 4, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4520, 1, 4, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 3, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 2, 6, 51, 765);
commit;
prompt 128000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 1, 2, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 6, 2, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 3, 2, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4521, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 1, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 3, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 1, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 4, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 2, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 3, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 3, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4242, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 3, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 1, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 5, 4, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4243, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 1, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 8, 2, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 3, 1, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4244, 5, 4, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 8, 4, 4, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 7, 1, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 8, 3, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4245, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 2, 2, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 2, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 3, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 2, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 4, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 4, 3, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4246, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 4, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 1, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 4, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 1, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 1, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 3, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 2, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 3, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4343, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 4, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 3, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 2, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 3, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 1, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 1, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 1, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 1, 4, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 3, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 4, 4, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4344, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 3, 1, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 2, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 1, 2, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 4, 2, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4345, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 1, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 6, 3, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 2, 3, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 4, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4346, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 3, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 3, 3, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 8, 2, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 2, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4347, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 4, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 2, 1, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 4, 1, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 3, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4432, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 4, 1, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 6, 1, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 6, 4, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4433, 8, 2, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 5, 1, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4434, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 3, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 3, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 1, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 2, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 1, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 3, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4435, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 3, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 1, 1, 40, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 1, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 4, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 4, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 3, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 2, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 4, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 4, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 1, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 2, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 5, 3, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4436, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 4, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4522, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 2, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4523, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 3, 2, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 4, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 4, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 2, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 3, 5, 12, 168);
commit;
prompt 129000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4524, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 3, 4, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 4, 4, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4525, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 1, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 4, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 1, 1, 80, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 3, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4526, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 2, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 2, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 1, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 3, 4, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 3, 2, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 3, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 7, 4, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4527, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 7, 1, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 6, 4, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 3, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4528, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 1, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 4, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 1, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 1, 1, 5, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 4, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 2, 4, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 4, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 3, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4247, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 6, 4, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 6, 1, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4248, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 3, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 1, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 4, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 1, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4249, 4, 3, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 7, 3, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 1, 2, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 7, 4, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4250, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4251, 3, 1, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 1, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 3, 4, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 4, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 7, 1, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4252, 1, 1, 1, 10, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 4, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 4, 2, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 6, 3, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 3, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4253, 2, 4, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4348, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 5, 3, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4349, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 1, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 3, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 2, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 2, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 3, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 3, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4350, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 2, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 1, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 4, 2, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 3, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 3, 6, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 5, 2, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4351, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 3, 2, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 7, 4, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4352, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 4, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 3, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 4, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 7, 2, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 3, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 1, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 4, 6, 5, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 2, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 4, 3, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 3, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 4, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 1, 3, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4437, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 1, 1, 3, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 4, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 2, 1, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4438, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 3, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 4, 3, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 2, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 3, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 8, 1, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4439, 2, 3, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 2, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 1, 1, 1, 7, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 1, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 8, 3, 6, 66, 1122);
commit;
prompt 130000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 2, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 1, 4, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4440, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 4, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 2, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 1, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 6, 37, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 3, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 2, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 4, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 3, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4529, 4, 4, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 3, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 1, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 4, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 2, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 1, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 2, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4530, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 1, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 3, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 1, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 5, 4, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 2, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4531, 7, 4, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 2, 4, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 2, 2, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4532, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 8, 2, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 1, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 4, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 8, 1, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 6, 3, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 7, 4, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 1, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4533, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 1, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 6, 1, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 5, 3, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4254, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 1, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 3, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 3, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 4, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 2, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 1, 1, 82, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4255, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4256, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 2, 1, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 2, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4257, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 4, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4258, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 2, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 1, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 6, 2, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 4, 2, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4353, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 4, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 3, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 4, 6, 24, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 1, 99, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 2, 3, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4354, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 5, 4, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 1, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 4, 4, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 2, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 1, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4355, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 2, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 1, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 4, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 3, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 3, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 4, 60, 720);
commit;
prompt 131000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 2, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 4, 3, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4441, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 7, 4, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4442, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 3, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 7, 1, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 8, 1, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 4, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 4, 4, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4443, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 2, 2, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 6, 1, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4444, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 3, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 3, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 1, 1, 1, 6, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4445, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 3, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 4, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 4, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 1, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 1, 3, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 4, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 8, 2, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4446, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 2, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 6, 4, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 3, 4, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4534, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 2, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 4, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 1, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 4, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 1, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 3, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 4, 2, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 3, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4535, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 2, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 4, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 4, 6, 38, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 1, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 3, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 4, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 1, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4537, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 4, 6, 79, 1422);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 4, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 5, 3, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4539, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 4, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 1, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 2, 4, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4540, 3, 3, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 4, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 4, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 1, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 2, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 3, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4259, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 2, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 4, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 3, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 3, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 4, 2, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 3, 2, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4260, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 4, 4, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 3, 2, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 2, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 5, 4, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4261, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 7, 4, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4262, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 6, 2, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 3, 3, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 4, 3, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 7, 1, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4263, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 2, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 2, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 1, 3, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 4, 4, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4264, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4265, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 4, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4356, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 4, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 1, 2, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 3, 1, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 2, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4357, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 3, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 3, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 2, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 5, 2, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 3, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4358, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 7, 2, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 2, 4, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4359, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 3, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 2, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 3, 1, 17, 153);
commit;
prompt 132000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 1, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 3, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 3, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 3, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 1, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 4, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 3, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 6, 3, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 1, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4360, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 4, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 1, 6, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 3, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 3, 3, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 2, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 3, 3, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4361, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 3, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 5, 3, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 4, 1, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 1, 1, 1, 74, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4447, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 3, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 2, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 4, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 4, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 3, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 1, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 4, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 2, 3, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 4, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 1, 4, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 3, 4, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4448, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 3, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 6, 1, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4449, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 4, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 4, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 1, 3, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 3, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 1, 6, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 7, 3, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 8, 3, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 1, 3, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 4, 1, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4450, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 5, 2, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 2, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4451, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 2, 1, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 2, 1, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 3, 4, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 6, 4, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 6, 3, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 3, 4, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4452, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 2, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 1, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 3, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 4, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 3, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 1, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 2, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 7, 1, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 1, 1, 1, 64, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 1, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4541, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 3, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 4, 6, 98, 1764);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 6, 3, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 3, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 3, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 4, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 3, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4542, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 8, 1, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4543, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 1, 3, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 3, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 3, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 3, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 3, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 1, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 2, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 3, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 4, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4544, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 2, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 7, 1, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 1, 5, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 7, 3, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4545, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 4, 4, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 7, 2, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 5, 3, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 5, 4, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 7, 4, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4546, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4547, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 2, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 3, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 1, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 5, 4, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4266, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 3, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 1, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 4, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 2, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 1, 4, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 4, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 3, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 3, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 1, 1, 5, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 4, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 1, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 2, 3, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4267, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 4, 6, 34, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 3, 2, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 1, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 4, 1, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4268, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 4, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 1, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 6, 1, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 4, 4, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 6, 2, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 4, 3, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4269, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 7, 2, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 2, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 1, 4, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4270, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 2, 1, 73, 365);
commit;
prompt 133000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 3, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 4, 2, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4362, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 1, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 5, 4, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 4, 1, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 1, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 2, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 3, 1, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 2, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4363, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 1, 4, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 3, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 5, 4, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 4, 4, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4364, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 3, 2, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 3, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 4, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 3, 3, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4365, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 2, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 4, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 4, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 2, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 2, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 3, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 3, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 1, 4, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 1, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 1, 6, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 1, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 1, 4, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 2, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 1, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4453, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 2, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 1, 2, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 5, 3, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 3, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4454, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 2, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 3, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 2, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 2, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 2, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 4, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 2, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 3, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 4, 5, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 8, 2, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 2, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4455, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 2, 2, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 3, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 2, 1, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 2, 2, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 1, 2, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 2, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4457, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 4, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 1, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 1, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 2, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 2, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 4, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 2, 4, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 1, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 1, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 1, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 3, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 3, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 4, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 1, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 1, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 1, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 4, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 1, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 3, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 1, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 1, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4555, 4, 3, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 3, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 1, 1, 88, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 3, 1, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 3, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 1, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 2, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 5, 1, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4556, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 4, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 2, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 3, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 3, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 3, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 4, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 1, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4271, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 4, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 4, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 2, 4, 21, 189);
commit;
prompt 134000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4272, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 1, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 4, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 2, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 3, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 4, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 1, 1, 1, 15, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4273, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 1, 4, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 6, 3, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 7, 1, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4274, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 3, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 3, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4366, 3, 3, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 3, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 4, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 1, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 2, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 2, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 2, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 7, 4, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4367, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 3, 4, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 5, 2, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 2, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 5, 2, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 5, 3, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4368, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 4, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 2, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 1, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 4, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4369, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 4, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 4, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 1, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 1, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 1, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 2, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 2, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 4, 6, 20, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 3, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 2, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 3, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4370, 4, 3, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 2, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 4, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 4, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 2, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 2, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4458, 8, 1, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 3, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 2, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 3, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 2, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 1, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4459, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 2, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 2, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 4, 3, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 1, 2, 4, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4460, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 2, 4, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 4, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 1, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 3, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 1, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 5, 4, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 3, 2, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 6, 4, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4461, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 2, 4, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 5, 1, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 4, 2, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 1, 4, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4462, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 3, 4, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 3, 4, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4463, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 4, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 2, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 3, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 2, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 4, 1, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 4, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4464, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 1, 1, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 3, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 1, 1, 1, 30, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4465, 2, 4, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 3, 2, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4466, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 4, 4, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 4, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 1, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 3, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 4, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 2, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 2, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 1, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 6, 3, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 4, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 2, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 3, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4564, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 3, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 3, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 2, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 1, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 3, 3, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 2, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4565, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 4, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 4, 1, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 2, 3, 97, 1261);
commit;
prompt 135000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 2, 4, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4566, 7, 1, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 2, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 4, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 4, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 2, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 2, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 3, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 2, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 1, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4276, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 4, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 2, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 3, 2, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4277, 4, 4, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 4, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 3, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 1, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 2, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 4, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 1, 6, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 1, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 4, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 8, 4, 6, 41, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 4, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 4, 4, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4278, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 4, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 3, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 3, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 3, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 3, 3, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 4, 3, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 2, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 2, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 3, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 1, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 7, 4, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4279, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4371, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 5, 4, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4372, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 1, 4, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 4, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 2, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 4, 3, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4373, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 6, 1, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 2, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 3, 2, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 2, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4374, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 1, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 3, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 3, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 2, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 4, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 3, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 4, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 1, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 1, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 3, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 3, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 2, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 3, 4, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 5, 2, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4375, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 4, 6, 80, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 3, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 1, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 4, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 2, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 3, 3, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 1, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 1, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 2, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4467, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 4, 3, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 6, 4, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 3, 4, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4468, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 1, 4, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 3, 3, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 8, 4, 2, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 3, 3, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 1, 3, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 7, 1, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4470, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 1, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 1, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 2, 1, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4471, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 3, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 4, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 2, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 2, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 2, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 7, 1, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 1, 3, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 1, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4472, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 3, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 2, 4, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4473, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 1, 3, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 1, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 8, 4, 6, 88, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4474, 3, 2, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 2, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 4, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 7, 4, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 4, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 4, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 1, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 4, 3, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 2, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4548, 1, 1, 6, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 1, 1, 27, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 8, 1, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 4, 3, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 4, 3, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 8, 3, 1, 2, 24);
commit;
prompt 136000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 3, 4, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 4, 1, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4549, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 1, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 1, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 4, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 4, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 1, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 1, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 4, 3, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4550, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 6, 2, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 1, 1, 3, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4551, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 3, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 4, 3, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 8, 2, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4552, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 1, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 1, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 3, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 8, 1, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 2, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 4, 3, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 3, 3, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4553, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 1, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 5, 2, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 3, 1, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4280, 2, 3, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 4, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 3, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 2, 4, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 5, 4, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4281, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 4, 6, 94, 1692);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 4, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 3, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 3, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 3, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 4, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 4, 3, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4282, 8, 2, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 4, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 5, 1, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 7, 4, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 4, 3, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4283, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 2, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 3, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 1, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 1, 1, 4, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 1, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 7, 1, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 2, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4284, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 1, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 4, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 4, 3, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 2, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 1, 2, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4376, 2, 2, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 1, 1, 24, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 2, 3, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 3, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4377, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 4, 4, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 6, 3, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 5, 1, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 2, 3, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 2, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4378, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 4, 2, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 5, 1, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4379, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 1, 1, 1, 74, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 8, 4, 6, 21, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 2, 3, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 7, 2, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4380, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 4, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 1, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 2, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 3, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 1, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 2, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4381, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 3, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 1, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 4, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4382, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 2, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 1, 3, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4383, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 4, 3, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 2, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 1, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 1, 3, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 4, 6, 48, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 4, 2, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 1, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 2, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4476, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 3, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 3, 4, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 3, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4477, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 4, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 4, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 4, 4, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 1, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 4, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 1, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 4, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4478, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 4, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 2, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 3, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 2, 6, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 2, 6, 84, 1092);
commit;
prompt 137000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 4, 3, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4479, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 1, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 4, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 1, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 3, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 3, 1, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 2, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 2, 3, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 4, 1, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 2, 2, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4557, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 2, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 4, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 4, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 2, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 1, 2, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 3, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 1, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 3, 3, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 6, 4, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 2, 1, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4558, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 3, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 1, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 2, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 1, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 3, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 2, 3, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 3, 4, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 8, 3, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4559, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 7, 1, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 3, 4, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 4, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 3, 3, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 3, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4560, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 3, 1, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 6, 1, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 4, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 7, 1, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4561, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 8, 4, 6, 61, 1098);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4562, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 1, 1, 48, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 3, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 6, 2, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4563, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 4, 3, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4285, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 3, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 1, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 1, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 1, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4286, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 2, 4, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 1, 3, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4287, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 4, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 3, 2, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 1, 1, 2, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4288, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 4, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 4, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 1, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 3, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 1, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 1, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 1, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 2, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4289, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 3, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 2, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 1, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 3, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 8, 1, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 1, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 2, 3, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 2, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 3, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4290, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 4, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4384, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 1, 4, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 4, 3, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 3, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 3, 4, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 1, 3, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4385, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 4, 5, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 1, 4, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 3, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 3, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 3, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 2, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 1, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 1, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 1, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 3, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 3, 3, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 8, 1, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4386, 2, 3, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 4, 2, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 4, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 6, 4, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 2, 3, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 3, 4, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4387, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 3, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 3, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 4, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 3, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 4, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 1, 2, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4388, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4389, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 1, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 1, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 4, 4, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 4, 6, 17, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 5, 4, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 6, 3, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 4, 4, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4390, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 4, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 1, 1, 3, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4480, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 1, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 1, 6, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 4, 3, 66, 858);
commit;
prompt 138000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 3, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 3, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 2, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 1, 5, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 2, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 3, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 3, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 5, 4, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4481, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 1, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 2, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 1, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 4, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 7, 4, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 1, 3, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 4, 5, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 3, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 5, 3, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4482, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 1, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 1, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 1, 1, 47, 141);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 1, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 4, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 4, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 3, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 3, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 2, 2, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 4, 3, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4483, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 4, 1, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 2, 1, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4484, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 1, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 6, 3, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 2, 2, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 5, 2, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 4, 1, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4485, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 5, 4, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 2, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 2, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 2, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 1, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 4, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 2, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 1, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 1, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 3, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3810, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 4, 4, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 6, 4, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 4, 3, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3811, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 1, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 4, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 2, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 8, 3, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 1, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 1, 1, 63, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 1, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 1, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3812, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 3, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 3, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 2, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 1, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 2, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 2, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 3, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 4, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3813, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 4, 4, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 8, 1, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 2, 1, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 4, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 5, 4, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 1, 2, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3814, 2, 2, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 3, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 5, 3, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 3, 3, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 8, 4, 4, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (3815, 1, 2, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 5, 3, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 7, 1, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 1, 4, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 5, 2, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 1, 4, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 6, 4, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 4, 1, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4291, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 4, 4, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 6, 4, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 6, 2, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4292, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 8, 4, 1, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 7, 3, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 3, 2, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 4, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4293, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 2, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 1, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 4, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 3, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 4, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 1, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 4, 6, 37, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 8, 3, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 1, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 4, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4294, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 1, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 3, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 2, 4, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 3, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 2, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 4, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 8, 4, 3, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4295, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 2, 4, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 1, 4, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4296, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4297, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 4, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 2, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 3, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 3, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 2, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 3, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 1, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 2, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 2, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 1, 5, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 3, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 2, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 1, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 3, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 1, 2, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 3, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 1, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 1, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 4, 6, 78, 1404);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 7, 4, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4391, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 1, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 1, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 3, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 3, 3, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 8, 4, 1, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 6, 3, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 7, 1, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4392, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 2, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 4, 3, 45, 585);
commit;
prompt 139000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 4, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 1, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 2, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4393, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 1, 4, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 2, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 1, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 3, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 8, 1, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 7, 1, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 3, 1, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4394, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 3, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 3, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 3, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 1, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 4, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4486, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 1, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 1, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 1, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 1, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 3, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 3, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 4, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 2, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 3, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4487, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 8, 1, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 1, 2, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4488, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 3, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 1, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 2, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 1, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 1, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 1, 2, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4489, 2, 1, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 3, 4, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 7, 2, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 1, 4, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4490, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 3, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 2, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 4, 2, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 3, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 1, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 3, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 3, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 4, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 4, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 1, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 3, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 3, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 2, 4, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 2, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 3, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 4, 3, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4213, 3, 1, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 2, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 2, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 8, 4, 5, 91, 1547);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 8, 4, 6, 69, 1242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4214, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 4, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 1, 4, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 6, 3, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 2, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 2, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 2, 3, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 5, 1, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 4, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4215, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 2, 3, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4216, 2, 4, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 2, 3, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 2, 1, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 7, 2, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4217, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 1, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 1, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 3, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 1, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 6, 3, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 4, 1, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 2, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 6, 4, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4218, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 8, 4, 3, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 6, 2, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 1, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 4, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 1, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 5, 1, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 4, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 2, 3, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 7, 3, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4219, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 4, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 5, 3, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 2, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 1, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4299, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 3, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 3, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 2, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 4, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 3, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 1, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 2, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4300, 8, 3, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 2, 4, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 1, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 1, 4, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 2, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 3, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 3, 3, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 7, 3, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4301, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 1, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 4, 6, 5, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 1, 3, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 1, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 4, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 3, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 3, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4302, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 1, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 2, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 4, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 2, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 2, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 2, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 3, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 2, 5, 29, 319);
commit;
prompt 140000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 3, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 1, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 6, 4, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4303, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 1, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 4, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 2, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 2, 3, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 5, 3, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4395, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 4, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 1, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 3, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 5, 1, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4396, 7, 2, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 3, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 4, 1, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 3, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 1, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 3, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4397, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 3, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 2, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 3, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 2, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 2, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 1, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 1, 1, 44, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 2, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 2, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 4, 2, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4398, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 4, 2, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4399, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 7, 4, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 1, 2, 4, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 2, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 8, 4, 1, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 5, 1, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 4, 2, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 2, 2, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 1, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4491, 7, 1, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 4, 1, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 1, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 1, 5, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 2, 4, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 3, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 2, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 4, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 1, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 4, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 4, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 2, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 1, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 2, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 7, 4, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4492, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 4, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 1, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 4, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 1, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 4, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 3, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 3, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 2, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 6, 4, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 7, 3, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4493, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 8, 4, 3, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4494, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 1, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 3, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 3, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 3, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 3, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 3, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 1, 4, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4495, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 3, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 7, 2, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 1, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 3, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 2, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 1, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 6, 3, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4496, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 1, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 5, 1, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 4, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 1, 1, 70, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 1, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 4, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 6, 2, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 2, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 1, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 3, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 4, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 1, 4, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 3, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 3, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 4, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 3, 1, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4220, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 3, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 2, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 3, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 2, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 1, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 4, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 4, 3, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4221, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 2, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 4, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 1, 3, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 4, 2, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 1, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 3, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 2, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 2, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 3, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 3, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 2, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 1, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 2, 1, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 6, 1, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 4, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 3, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4222, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 3, 4, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 2, 4, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4223, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 4, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 2, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 4, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 2, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 3, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 2, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 2, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 1, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 2, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 2, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 1, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 6, 2, 2, 8, 80);
commit;
prompt 141000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4304, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 2, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 3, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 2, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 3, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 2, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 4, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 2, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4305, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 4, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 4, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 1, 4, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 8, 1, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 4, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 8, 1, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4306, 4, 2, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 2, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 3, 5, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 3, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 4, 2, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4307, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 5, 2, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4400, 1, 1, 4, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 4, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 2, 3, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 1, 1, 2, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 8, 4, 4, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4401, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 3, 2, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 2, 1, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 1, 1, 2, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4403, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 3, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 3, 4, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 4, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 3, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 4, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 3, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 1, 2, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 4, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4404, 4, 3, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 1, 2, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 6, 2, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 3, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 8, 2, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 1, 1, 5, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4405, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 4, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 1, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 2, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 1, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 7, 1, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4406, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 4, 1, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 1, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 3, 4, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 2, 2, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 2, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 4, 2, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 5, 2, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 3, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 1, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 5, 1, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 3, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 1, 6, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 5, 1, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 3, 1, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4498, 2, 1, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 2, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 4, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 5, 2, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 3, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 1, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 5, 4, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 3, 4, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 4, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4499, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 4, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 4, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 4, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 1, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 2, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 1, 1, 90, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 2, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 1, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 5, 2, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 1, 4, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4500, 3, 3, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 3, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 1, 2, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 1, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 2, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 1, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 1, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 4, 6, 34, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 2, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 1, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 3, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 3, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 4, 3, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4501, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 2, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 3, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 3, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 4, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 3, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 2, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4224, 7, 2, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 4, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 3, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 2, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 2, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 4, 2, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 1, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 3, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 1, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 1, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 1, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 3, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 1, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 3, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 2, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 5, 1, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 2, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4225, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 4, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 2, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 1, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 4, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 4, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 3, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 4, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 4, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 2, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 2, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 1, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 2, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 4, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 7, 2, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4226, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 1, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 2, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 2, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 2, 1, 53, 583);
commit;
prompt 142000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 3, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 4, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 1, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 2, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 2, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4308, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 3, 4, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 3, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 2, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 3, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 3, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 4, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 4, 3, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 3, 2, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4309, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 3, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 2, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 1, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 2, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 4, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 2, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 1, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 3, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4310, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 1, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 1, 1, 6, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 1, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 3, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 4, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 2, 2, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 3, 1, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4311, 2, 1, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 1, 1, 5, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 1, 1, 5, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 2, 3, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 3, 3, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 3, 1, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 1, 1, 4, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 7, 3, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4312, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 3, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 4, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 1, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4313, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 3, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 1, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 1, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 6, 4, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 1, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 3, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 6, 2, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 3, 1, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4314, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 3, 5, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 7, 3, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4315, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4407, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 3, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 2, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 1, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 3, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 1, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 2, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 8, 1, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 7, 2, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4408, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 1, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 4, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 7, 1, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 2, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 1, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 2, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 4, 2, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4409, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 3, 1, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 3, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 7, 4, 3, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 7, 3, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4410, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 1, 3, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 4, 1, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 6, 1, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4411, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 4, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 3, 3, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4412, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 2, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 2, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 4, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 1, 1, 5, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 3, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 1, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 2, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 5, 3, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 4, 4, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 3, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4502, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 3, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 5, 2, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 5, 1, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 2, 1, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 1, 6, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4503, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 7, 4, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 3, 2, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 7, 2, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 3, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4504, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 1, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 1, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 2, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 1, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 2, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 3, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 3, 4, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 8, 1, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 1, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 4, 3, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4505, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 1, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 7, 1, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 3, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 1, 2, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 3, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 2, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 4, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 4, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 3, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4506, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 4, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 4, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4227, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 2, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 4, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 3, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 3, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 2, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 1, 1, 79, 632);
commit;
prompt 143000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 4, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 1, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 2, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 1, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 7, 2, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 1, 4, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 3, 1, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4228, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 1, 1, 1, 27, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 4, 2, 3, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 4, 3, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 1, 1, 1, 50, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 2, 4, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4229, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 2, 3, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 1, 2, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 4, 1, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 3, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 1, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 3, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4230, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 8, 1, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 7, 1, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 7, 2, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 2, 1, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4231, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 4, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 4, 3, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 3, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 4, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 1, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 4, 1, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 1, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 4, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 4, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 2, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 4, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 1, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 2, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 4, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 1, 4, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4232, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 2, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 2, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 1, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 1, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 2, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 4, 1, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 3, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 4, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 2, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 1, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 1, 6, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 4, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4316, 2, 3, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 2, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 4, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 2, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 3, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 3, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 2, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 7, 1, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4317, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 3, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 3, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 4, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 2, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 3, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 3, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 1, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 1, 2, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 3, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 2, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 2, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 3, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 1, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 1, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 4, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 8, 2, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4318, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 3, 4, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 4, 3, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 7, 4, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 2, 1, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4319, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 3, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 3, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 1, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 2, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 4, 1, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 3, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 4, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 1, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 5, 2, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 6, 1, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4413, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 1, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 2, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 3, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 4, 3, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 1, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 2, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 3, 3, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 1, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 2, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 4, 1, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 4, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4414, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 1, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 4, 2, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 3, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 3, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 8, 4, 6, 89, 1602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 3, 4, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 3, 1, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4415, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 2, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 2, 3, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 1, 6, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 4, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4416, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 4, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 6, 4, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 4, 2, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 2, 3, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 4, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 3, 4, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 5, 3, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4417, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 4, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 2, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 2, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 4, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 1, 4, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4418, 7, 4, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 3, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 2, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 3, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 1, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 1, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 3, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 1, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 4, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 3, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 4, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 4, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 4, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 3, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 7, 2, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4507, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 4, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 3, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 4, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 4, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 4, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 1, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 8, 3, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4508, 4, 2, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 1, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 4, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 3, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 4, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 2, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 3, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 1, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 4, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 3, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 3, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 4, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 4, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 2, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 4, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 3, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 4, 4, 10, 130);
commit;
prompt 144000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 2, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 3, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4509, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 4, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 2, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 4, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 3, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 3, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 4, 1, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4510, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 4, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 3, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 1, 6, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 4, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4511, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 3, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 3, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 4, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 2, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 4, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 4, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 3, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 2, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 2, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 2, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4233, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 2, 3, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 2, 4, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 8, 1, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 1, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 4, 2, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 2, 4, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 5, 4, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4234, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 1, 6, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 6, 1, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 1, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 1, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 7, 4, 5, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 6, 4, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 2, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 3, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 1, 1, 96, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 4, 2, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 4, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 1, 6, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4235, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 2, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 3, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 3, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 4, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 2, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 4, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 3, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 3, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 1, 4, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 1, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 4, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 3, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 5, 3, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 2, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 2, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 4, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 3, 2, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4236, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 1, 4, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 2, 2, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 8, 3, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 1, 4, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4237, 8, 4, 6, 13, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 4, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 4, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 8, 1, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 2, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 4, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4238, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4239, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 6, 3, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 4, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 3, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 6, 2, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 3, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4320, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 5, 2, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 6, 4, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 3, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 3, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 2, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4321, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 2, 3, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 4, 4, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 4, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 8, 4, 5, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4322, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 8, 2, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4323, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 6, 4, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 8, 4, 5, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4324, 4, 4, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 7, 3, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 2, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 5, 2, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 4, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4325, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 8, 2, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4326, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 5, 3, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 5, 1, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 6, 2, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 7, 1, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 4, 4, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 2, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 4, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 2, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4327, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 2, 4, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 7, 2, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 2, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 3, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 2, 1, 1, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 1, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4328, 6, 3, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 1, 3, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 1, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 3, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 3, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 2, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4330, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 3, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 2, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 2, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 4, 1, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 3, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 4, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 4, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 3, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 4, 4, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 2, 2, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 7, 1, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 1, 4, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 3, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 4, 4, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 4, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 4, 6, 97, 1746);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4686, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 3, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 3, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 2, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 3, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 1, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 2, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 2, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 4, 1, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 3, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 4, 2, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 5, 1, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 4, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4687, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 8, 1, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 8, 1, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 8, 2, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 3, 3, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 1, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 1, 4, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 2, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 2, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 1, 3, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4688, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 1, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 4, 6, 23, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 1, 1, 4, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 2, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 3, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 3, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 6, 2, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4689, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 3, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 2, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 1, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 1, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 4, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 4, 1, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 4, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 1, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 2, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 1, 2, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 4, 5, 70);
commit;
prompt 145000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 3, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 2, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 4, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 3, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 4, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 1, 4, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 1, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 4, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 2, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 1, 4, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 3, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 3, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4771, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 1, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 5, 1, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 5, 3, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 1, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 1, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 1, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4772, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 2, 4, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 4, 2, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 2, 2, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4773, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 4, 1, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 3, 3, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 2, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 2, 4, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 4, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 1, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 1, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 1, 1, 1, 67, 201);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 2, 1, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 1, 2, 3, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4774, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 2, 2, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 8, 4, 3, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 1, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 2, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 1, 2, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 1, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4775, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 2, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 3, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 3, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 3, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 2, 5, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 2, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 2, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 4, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 1, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 5, 3, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 3, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 4, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 1, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 4, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 7, 1, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 2, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 8, 3, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 1, 5, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 6, 1, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 1, 2, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4851, 1, 3, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 8, 1, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 4, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 8, 2, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4852, 1, 1, 2, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 3, 3, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 4, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 3, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 6, 4, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 8, 1, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4853, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 2, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 2, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 2, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 3, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 2, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 3, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 4, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 8, 4, 3, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 6, 1, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4855, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 1, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 2, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 2, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 4, 1, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 7, 1, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 1, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 3, 1, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4856, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 1, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 1, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 2, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 1, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 1, 1, 3, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 2, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 3, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 4, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 2, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 1, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 2, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 4, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 3, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 4, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 2, 6, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 2, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 2, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 2, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 2, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 2, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 4, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 5, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 1, 6, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 3, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 1, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 8, 4, 2, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4600, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 4, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 2, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 3, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 4, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 1, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 4, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 1, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 2, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 1, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 2, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 4, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4601, 7, 1, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 3, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 2, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 2, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 4, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 4, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 3, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 1, 1, 6, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 2, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 1, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 3, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 4, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 2, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 1, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4690, 4, 4, 3, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 3, 3, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 4, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 8, 2, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 8, 3, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 1, 4, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 1, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4691, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 4, 2, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 3, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 7, 2, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 4, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 7, 3, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 1, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 7, 4, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 4, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 4, 1, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 2, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 3, 3, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4692, 1, 2, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 4, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 1, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 3, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 2, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 3, 5, 93, 1116);
commit;
prompt 146000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 4, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 1, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 4, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 4, 6, 31, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 2, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 2, 2, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 2, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 3, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 4, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 3, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4693, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 3, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 3, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 3, 1, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 1, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 2, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 1, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 4, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 4, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 3, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 2, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 3, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 1, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 6, 2, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 2, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 8, 2, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4694, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 3, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 1, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 3, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 2, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 3, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 4, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 4, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 7, 4, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 5, 1, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4776, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 2, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 4, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 2, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 2, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 3, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 1, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 4, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 2, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 4, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 3, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 1, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 4, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 1, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 4, 2, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 1, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 4, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 1, 5, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 2, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 1, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 3, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4777, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 3, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 1, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 2, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 4, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 1, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 4, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 4, 4, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4778, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 3, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 4, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 3, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 1, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 1, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 4, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 1, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 8, 4, 6, 1, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4779, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 1, 1, 4, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 1, 2, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 8, 4, 4, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 6, 2, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 3, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 4, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 2, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 2, 1, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4858, 1, 1, 1, 31, 93);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 1, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 3, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 6, 3, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 2, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 1, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 3, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 4, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 1, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 3, 2, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4859, 2, 4, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 4, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 3, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 2, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 3, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 4, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 4, 6, 10, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 4, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 2, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 3, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 2, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 1, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 2, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 1, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 5, 3, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 3, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4860, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 6, 1, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 8, 3, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 4, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 7, 2, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 7, 2, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4861, 7, 4, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 7, 1, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4862, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 1, 5, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 3, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 1, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 1, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 1, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4602, 4, 1, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 4, 3, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 8, 3, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 2, 4, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4603, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 1, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 2, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 3, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 1, 1, 6, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 3, 1, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 2, 2, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4604, 4, 3, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 3, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 1, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 3, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 3, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 1, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 3, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 7, 4, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 5, 2, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4605, 4, 4, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 1, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 4, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 2, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 2, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 2, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 4, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 2, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 4, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 3, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 2, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 1, 2, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 4, 2, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 1, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 3, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 1, 61, 183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 6, 1, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4606, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 2, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 3, 1, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 8, 2, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 1, 4, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 1, 4, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 3, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 4, 1, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4607, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 2, 4, 77, 924);
commit;
prompt 147000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 5, 4, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 1, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 2, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 4, 1, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 7, 4, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 4, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 2, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 1, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 2, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 1, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 4, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 4, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 1, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 1, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 2, 2, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4695, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 2, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 1, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 2, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 4, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 4, 3, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 1, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 3, 4, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 2, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 3, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 2, 2, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 3, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 4, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 5, 4, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4696, 6, 2, 2, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 4, 1, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 5, 4, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 6, 3, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 4, 4, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 4, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 5, 4, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 3, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 2, 2, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 1, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 3, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 2, 4, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 8, 2, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4697, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 3, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 4, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 3, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 1, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 2, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 3, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 2, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 4, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4698, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 4, 1, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 3, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 3, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4780, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 2, 2, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 6, 1, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 2, 3, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4781, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 2, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 6, 3, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 1, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 4, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 6, 3, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 1, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 5, 3, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 4, 4, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 5, 4, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4782, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 4, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 1, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 2, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 3, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 3, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 4, 6, 40, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 4, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 4, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 1, 6, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 1, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 3, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 2, 1, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 1, 3, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 3, 2, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4783, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 1, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 4, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 2, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 2, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 1, 1, 5, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 1, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 1, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 2, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 4, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 8, 3, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4784, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 3, 3, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 4, 1, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4785, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 1, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 2, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 1, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 2, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 3, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 3, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 3, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 3, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 4, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 4, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 4, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 3, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 1, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 4, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 1, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 4, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 3, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 1, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 1, 4, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 2, 2, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4863, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 4, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 1, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 1, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 1, 4, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 4, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 1, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 4, 3, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 3, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 3, 3, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 8, 2, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4864, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 1, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 1, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 4, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 1, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 8, 3, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 2, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 2, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 1, 1, 47, 141);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 3, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 1, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4865, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 3, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 3, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 2, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 2, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 2, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 1, 1, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 2, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 3, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4608, 6, 4, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 2, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 3, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 4, 5, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 4, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 3, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 2, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 3, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 1, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 2, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 1, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 1, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 3, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 1, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 1, 3, 87, 783);
commit;
prompt 148000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 2, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 7, 4, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 3, 4, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 1, 3, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 1, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4609, 5, 3, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 6, 4, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 2, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 2, 1, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 1, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 8, 4, 5, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4610, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 3, 2, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 7, 1, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 8, 2, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4612, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 3, 4, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4613, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 2, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 2, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 1, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4614, 4, 2, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 3, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 3, 2, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 8, 4, 4, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 1, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 2, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 8, 1, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4615, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 2, 3, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 4, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 3, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 4, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 1, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 2, 5, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 2, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4699, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 1, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 3, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 1, 5, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 3, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 2, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 2, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 1, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 3, 4, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 7, 4, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4700, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 1, 2, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 2, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 4, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 4, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 4, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 1, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 2, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 6, 1, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 4, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 3, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 2, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 4, 1, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 4, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 4, 5, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 2, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 1, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4701, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 4, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 4, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 4, 4, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 5, 3, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 7, 3, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 1, 4, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4702, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 3, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 3, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 1, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 4, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 3, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 1, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4786, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 1, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 3, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 7, 1, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 3, 3, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4787, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 4, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 4, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 4, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 2, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 3, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 1, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 1, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 8, 1, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4788, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 3, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 1, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 2, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 3, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 4, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 1, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 2, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 4, 1, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 3, 3, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 2, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 4, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 4, 3, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4789, 5, 2, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 4, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 4, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 3, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 4, 6, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 1, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 3, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 3, 4, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 4, 6, 94, 1692);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 1, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 4, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4790, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 6, 2, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 1, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 4, 3, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 4, 4, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 1, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 1, 5, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 2, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 4, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 1, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 3, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 1, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 1, 2, 3, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 2, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 7, 4, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4866, 6, 1, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 4, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 2, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 2, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 4, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 4, 6, 23, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 4, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 4, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 4, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 3, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 3, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 1, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 1, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 4, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 1, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 1, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 4, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 1, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 5, 3, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4867, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 3, 4, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4868, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 1, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 4, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 1, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 1, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 2, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 3, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 4, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 2, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 6, 1, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4869, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 2, 2, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 3, 5, 59, 649);
commit;
prompt 149000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 4, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 2, 4, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 3, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 4, 3, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 2, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 2, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 2, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 3, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 2, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 3, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 5, 4, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 1, 3, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4870, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 1, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4616, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 5, 4, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 1, 3, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 4, 1, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 1, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 2, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 2, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 6, 1, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 4, 3, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 1, 2, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 7, 4, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4617, 8, 1, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 4, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 2, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 4, 6, 47, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 2, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 4, 2, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 4, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 4, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 4, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 3, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 1, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 3, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 7, 4, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 1, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 3, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 3, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 2, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 4, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 1, 1, 3, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 8, 2, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4618, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 1, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 2, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 2, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 3, 2, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 4, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 6, 3, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 2, 2, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 6, 3, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 2, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 2, 3, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 1, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 4, 3, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 3, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 6, 4, 2, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 8, 3, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 1, 4, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4619, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 1, 6, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 8, 3, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 2, 1, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 2, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 4, 1, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 4, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 5, 3, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 2, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 6, 3, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 3, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4620, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 3, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 3, 1, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 4, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 6, 3, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 4, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 5, 4, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 3, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4621, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 7, 1, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 6, 2, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 3, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 2, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 1, 3, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 4, 4, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 2, 2, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 1, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 1, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4703, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 4, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 4, 4, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 8, 3, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 2, 2, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 2, 4, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 3, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4704, 1, 2, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 4, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 3, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 2, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 2, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 4, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 2, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 2, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 2, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 2, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 2, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 3, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 1, 1, 2, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4705, 3, 4, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 8, 2, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 3, 4, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 3, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 1, 4, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 8, 4, 3, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 1, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 5, 1, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4706, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 4, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 1, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 4, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 1, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 1, 6, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 1, 1, 1, 85, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 3, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 1, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 3, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 4, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 1, 1, 4, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4707, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 2, 4, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 2, 2, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 5, 3, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 1, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 7, 3, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 3, 3, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 8, 1, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 1, 4, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 7, 4, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 8, 4, 1, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 4, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 4, 4, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4708, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 3, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 2, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 4, 2, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 4, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 4, 5, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 1, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 3, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 3, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 1, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 4, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 3, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 3, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 3, 3, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4791, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 4, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 1, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 2, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 2, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 2, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 3, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 4, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 3, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 2, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 3, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 3, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 2, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 1, 5, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 8, 3, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 1, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 2, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 3, 3, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4793, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 2, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 4, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 2, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 3, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 3, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 2, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 2, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 1, 2, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 3, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 2, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 3, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4794, 4, 3, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 3, 2, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 1, 1, 6, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 3, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 7, 4, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4795, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 7, 3, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 5, 3, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 4, 1, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 1, 4, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4796, 3, 1, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 4, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 2, 2, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 1, 1, 6, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4797, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 8, 3, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 8, 2, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 6, 4, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 1, 4, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 2, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 2, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 1, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 4, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 2, 3, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 6, 4, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 8, 3, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 3, 2, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 3, 4, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 1, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 5, 1, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 7, 2, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4871, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 4, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 3, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 1, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 2, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 1, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 4, 2, 53, 371);
commit;
prompt 150000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 4, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 3, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 1, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 4, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 3, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 2, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 3, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 7, 4, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 5, 3, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 4, 4, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4872, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 1, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 2, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 2, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 2, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 2, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 4, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 3, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 3, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 4, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 1, 1, 84, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 4, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 2, 6, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 1, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 3, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 4, 2, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 3, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 7, 4, 1, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 3, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 5, 4, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4873, 8, 3, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 1, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 1, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 1, 1, 7, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 3, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 4, 3, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 4, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 3, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 3, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 4, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 3, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 1, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 3, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 4, 2, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4874, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 3, 3, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 2, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 7, 2, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 6, 1, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 4, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4622, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 2, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 2, 3, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 7, 4, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 1, 1, 4, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 2, 4, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4623, 8, 2, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 3, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 3, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 1, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 3, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 2, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 1, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 6, 1, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 2, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 5, 2, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 2, 3, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4624, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 7, 1, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 4, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 6, 3, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 4, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 8, 3, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 4, 2, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 5, 3, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 8, 4, 2, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4625, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 3, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 2, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 1, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 3, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 3, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 1, 1, 1, 18, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 4, 1, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 1, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 2, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4626, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 4, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 4, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 2, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 1, 2, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 4, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 1, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 1, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 3, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 4, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 3, 5, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 3, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 2, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 2, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 2, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 1, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 4, 3, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 8, 3, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 3, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 7, 1, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 4, 2, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4628, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 4, 3, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 3, 2, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 4, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 7, 2, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 2, 4, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4709, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 3, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 2, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 2, 1, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4710, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 1, 3, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 4, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 1, 4, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 4, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 1, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 4, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 7, 4, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 4, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 4, 4, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 3, 2, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 7, 1, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4711, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 5, 4, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 3, 3, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 5, 4, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 3, 4, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 8, 4, 1, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4712, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 2, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 4, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 3, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 4, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 3, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 3, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 3, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 4, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 1, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 4, 3, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 1, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 3, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 2, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 2, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 3, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 4, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 1, 4, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 2, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 3, 2, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 7, 4, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 4, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4713, 4, 3, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 1, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 4, 2, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 2, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 3, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 3, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 3, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 1, 2, 57, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 2, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 4, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 2, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 8, 4, 5, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4714, 1, 3, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 3, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 2, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 4, 2, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 3, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 1, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 3, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 3, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 1, 2, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 5, 2, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 3, 3, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4798, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 2, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 4, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 3, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 4, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 2, 2, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 8, 3, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 1, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 4, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 1, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 2, 3, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4799, 1, 1, 1, 13, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 4, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 4, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 3, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 4, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 2, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 1, 4, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 4, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 3, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 4, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 4, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 4, 4, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 4, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 2, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 6, 2, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4800, 8, 1, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 7, 2, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 1, 4, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 1, 4, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4801, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 2, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 4, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 2, 3, 41, 369);
commit;
prompt 151000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 3, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 3, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 4, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 4, 4, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 3, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 3, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 2, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 2, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 6, 2, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 1, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 8, 1, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4802, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 2, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 1, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 4, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 2, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 3, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 4, 3, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 4, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 2, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 3, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 3, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 2, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 4, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 2, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 4, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 3, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 1, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 2, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 4, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 1, 1, 5, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4882, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 8, 1, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 1, 3, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 2, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 2, 4, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 2, 2, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 4, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 2, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 3, 2, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 8, 2, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 3, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 4, 1, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4883, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 8, 3, 5, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 4, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 3, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 2, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 2, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 1, 1, 8, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 4, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 3, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 2, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 4, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 2, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 1, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 3, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4884, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 1, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 5, 3, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 2, 4, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 2, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 2, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 2, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 5, 3, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4885, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 4, 3, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 3, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 4, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 1, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 1, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 3, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 4, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 7, 3, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 3, 4, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 1, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 4, 1, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 5, 3, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4629, 7, 4, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 4, 1, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 5, 1, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 3, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 1, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 1, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 4, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4630, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 1, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 1, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 2, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 5, 1, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 3, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 5, 2, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 1, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 2, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 1, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 2, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 5, 2, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 5, 4, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 7, 3, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4631, 8, 4, 6, 76, 1368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 1, 2, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 2, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 4, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 1, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 6, 3, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 3, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 6, 4, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 7, 4, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4632, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 1, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 2, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 4, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 4, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 1, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 1, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 1, 1, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 2, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 4, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 1, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 4, 4, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 1, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 3, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 4, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 1, 5, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 2, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 4, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 8, 3, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 2, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 6, 2, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 5, 1, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 2, 2, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4633, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 2, 1, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 1, 2, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 4, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 2, 1, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 3, 2, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4634, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 1, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 1, 5, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 2, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 4, 3, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 1, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 2, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 4, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 1, 2, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 7, 1, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4715, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 2, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 1, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 1, 4, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 4, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 2, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 3, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 1, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 2, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 3, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 3, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 3, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 3, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4716, 6, 3, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 1, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 1, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 1, 4, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 4, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 2, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 4, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 4, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 2, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 1, 3, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 2, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 4, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 1, 6, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 5, 2, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 3, 3, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 6, 4, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4717, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 3, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 4, 5, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 7, 3, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 2, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 3, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 2, 2, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 1, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 3, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 3, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 2, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 4, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 7, 3, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 1, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 2, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 1, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 4, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 4, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 3, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 2, 2, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 6, 1, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 4, 2, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4718, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 1, 3, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 4, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 4, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 3, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 7, 2, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 2, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 6, 1, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 3, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 3, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 2, 1, 65, 390);
commit;
prompt 152000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 2, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4803, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 1, 5, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 2, 1, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 4, 4, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 2, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 4, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 4, 4, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 3, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 2, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 3, 1, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 6, 2, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4804, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 3, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 1, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 3, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 1, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 2, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 1, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 3, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 8, 3, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4805, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 3, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 1, 1, 88, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 3, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 3, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 3, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 4, 6, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 5, 3, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 2, 4, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 6, 1, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 7, 1, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 4, 4, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4806, 3, 4, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 1, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 4, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 2, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 4, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 2, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 1, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 2, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 4, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 4, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 3, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 2, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 3, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 1, 31, 93);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 1, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 2, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 4, 1, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 3, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 1, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 2, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 2, 3, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 4, 6, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 2, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 4, 2, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 4, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 2, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 4, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 2, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 1, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 1, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 3, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 3, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 2, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 3, 4, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 4, 5, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 4, 4, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 1, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 4, 2, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 2, 4, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4891, 6, 4, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 1, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 4, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 5, 4, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 1, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 7, 2, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 4, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 1, 2, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 5, 4, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 2, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 6, 3, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 2, 2, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4892, 7, 3, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 4, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 3, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 4, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 3, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 1, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 4, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 3, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 3, 3, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 4, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 1, 5, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 1, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 4, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 4, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 4, 1, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 3, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 4, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 2, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 2, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 4, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 1, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 4, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 3, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 1, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 3, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 4, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 1, 1, 64, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 3, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 3, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 1, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 4, 1, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4893, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 3, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 2, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 3, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 2, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 4, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 1, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 2, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 3, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 1, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 3, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 4, 6, 45, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 3, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 4, 1, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 1, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 3, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 2, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 2, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 4, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 2, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 2, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 1, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4635, 8, 1, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 4, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 3, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 2, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 1, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 4, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 4, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 1, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 4, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 3, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 4, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 4, 4, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4636, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 3, 3, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 2, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 1, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 1, 1, 58, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 1, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 6, 3, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 7, 4, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 2, 4, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 6, 1, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 7, 4, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 4, 4, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4637, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 1, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 4, 4, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 4, 1, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 4, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 2, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 1, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 1, 4, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 4, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 4, 2, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 3, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 3, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 2, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 4, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 7, 3, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 4, 3, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4638, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 5, 3, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 4, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 1, 1, 5, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 2, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 5, 1, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 5, 1, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 4, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 4, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 6, 4, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 2, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 1, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 3, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 3, 4, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4639, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 2, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 1, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 2, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 5, 3, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 2, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 2, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 2, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 4, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 2, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 4, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 2, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 3, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 1, 3, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 2, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4719, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 3, 2, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 8, 2, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 2, 1, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 3, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 4, 2, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 3, 4, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 7, 2, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4720, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 2, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 3, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 8, 4, 4, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 2, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 4, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 4, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 4, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 2, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 4, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 1, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 3, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 4, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 1, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 1, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 2, 3, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 7, 1, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 1, 4, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 5, 4, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4721, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 7, 4, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 5, 3, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 8, 2, 5, 74, 1110);
commit;
prompt 153000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 6, 3, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 1, 1, 5, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 6, 4, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4722, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 4, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 2, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 3, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 2, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 1, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 2, 3, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 1, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 7, 2, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 4, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 8, 4, 6, 38, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 2, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 2, 1, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 1, 4, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 6, 4, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4723, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 2, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 3, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 2, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 8, 1, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 2, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 1, 4, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 8, 2, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 3, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 1, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 2, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 3, 3, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4724, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 4, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 3, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 3, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 1, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 6, 4, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4807, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 4, 2, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 7, 2, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 8, 1, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 5, 2, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 5, 1, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4808, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 2, 3, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 1, 2, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 3, 4, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 6, 2, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 1, 4, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 1, 4, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 4, 4, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4809, 8, 1, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 3, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 6, 4, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 4, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 1, 3, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 1, 2, 6, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 4, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 4, 5, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 6, 1, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4810, 3, 4, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 2, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 4, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 2, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 3, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 1, 1, 94, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 4, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 4, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 4, 5, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 7, 4, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 1, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 3, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 3, 3, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 3, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4811, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 4, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 1, 1, 64, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 3, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 1, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 4, 2, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 1, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 1, 6, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 4, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 3, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 4, 5, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 1, 3, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 1, 2, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 1, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 4, 4, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 1, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 3, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 1, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 1, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 3, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 2, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 3, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 2, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 5, 4, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4812, 6, 1, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 1, 6, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 4, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 4, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 1, 2, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 4, 3, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 3, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 1, 6, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 4, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 2, 1, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 2, 4, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 1, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 6, 3, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4875, 8, 1, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 3, 4, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 2, 3, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 5, 1, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 1, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 7, 2, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 3, 1, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4876, 3, 4, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 4, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 1, 1, 3, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 3, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 2, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 2, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 3, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 6, 1, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 4, 1, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 2, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4877, 1, 2, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 1, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 5, 4, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 4, 1, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 3, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 8, 1, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 2, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 3, 3, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 8, 3, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 7, 3, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4878, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 3, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 1, 6, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 1, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 1, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 2, 3, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 4, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 4, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 4, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 4, 4, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 4, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 1, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 8, 3, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 4, 4, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4879, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 2, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 2, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 3, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 1, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 2, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 1, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 2, 4, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 2, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 1, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 4, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 6, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 2, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 3, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 3, 2, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 4, 4, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 7, 3, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4880, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 2, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 3, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 1, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 2, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 1, 5, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 7, 2, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 4, 2, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 2, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4640, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 1, 5, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 2, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 1, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 3, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 3, 1, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 8, 4, 6, 79, 1422);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 1, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 4, 2, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 2, 2, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 8, 3, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 1, 1, 1, 6, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4641, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 8, 4, 4, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 6, 4, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 3, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 1, 3, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 3, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 3, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 2, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 3, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 3, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 1, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 2, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 1, 4, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 2, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 6, 3, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 6, 2, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 8, 3, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4642, 7, 2, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 4, 1, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 7, 4, 4, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 4, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 2, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 4, 2, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 1, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 4, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 2, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 2, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 1, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 7, 4, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 4, 3, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 1, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 1, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 1, 1, 1, 37, 111);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4643, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 2, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 2, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 1, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 4, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 4, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 1, 1, 4, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 3, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 4, 1, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 3, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 4, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 4, 4, 2, 3, 30);
commit;
prompt 154000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 2, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4644, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 3, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 3, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 3, 5, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 2, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 3, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 2, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4725, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 2, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 3, 2, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 4, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 5, 1, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 3, 3, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 3, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 3, 1, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4726, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 4, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 1, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 2, 4, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 3, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 2, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 4, 3, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 2, 3, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 3, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 8, 2, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 3, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 1, 1, 2, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4727, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 3, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 3, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 1, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 1, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 2, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 3, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 4, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 3, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 2, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 3, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 2, 6, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 2, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 3, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 3, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 3, 2, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4728, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 3, 2, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 7, 4, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 3, 4, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 5, 4, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 2, 4, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 7, 4, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4729, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 4, 4, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 3, 3, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 7, 4, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 3, 2, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4730, 6, 4, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 2, 1, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 7, 1, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 4, 2, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 8, 4, 4, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 4, 4, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 4, 2, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 8, 2, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4731, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 1, 1, 38, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 2, 4, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 3, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 3, 3, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 2, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 3, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 7, 3, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 1, 4, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4732, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 8, 4, 6, 51, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 7, 3, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 2, 4, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 6, 4, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 3, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 3, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 3, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 1, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 3, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 2, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 3, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 2, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 4, 5, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 6, 2, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 1, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4813, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 2, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 2, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 3, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 1, 3, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 4, 4, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 4, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 7, 1, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 8, 2, 6, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4814, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 4, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 1, 3, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 2, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 1, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 1, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 4, 4, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 1, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 2, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 2, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 1, 3, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 8, 4, 6, 85, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4815, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 4, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 3, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 2, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 2, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 1, 1, 75, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 3, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 2, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 1, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 1, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 4, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 4, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 4, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 2, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 1, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 1, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 1, 4, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 1, 3, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 3, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 6, 2, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 1, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4816, 3, 3, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 1, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 5, 4, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 6, 2, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 6, 2, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 4, 4, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 8, 1, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 5, 4, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 7, 2, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 5, 3, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4817, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 2, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 3, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 2, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 2, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 3, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 4, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 3, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 3, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 2, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 2, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 3, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 2, 3, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 5, 4, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 3, 2, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4886, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 2, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 4, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 1, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 4, 1, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 4, 2, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 1, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 1, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 4, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 4, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 1, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 5, 2, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 1, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 4, 5, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 4, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4887, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 2, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 1, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 4, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 1, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 3, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 5, 2, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 2, 3, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 1, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 2, 4, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 3, 3, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 3, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 7, 3, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 7, 2, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4888, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 1, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 3, 2, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 1, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 3, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 2, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 1, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 3, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 7, 2, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 3, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 3, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 7, 1, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 4, 4, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 4, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 1, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 1, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 3, 3, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 1, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 3, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 2, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 1, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4889, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 3, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 1, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 4, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 2, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 4, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 4, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 1, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 5, 4, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 4, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 1, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 3, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 2, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 3, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4890, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 4, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 4, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 2, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 2, 4, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 3, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 4, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4645, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 4, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 5, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 1, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 2, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 4, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 4, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 1, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 4, 6, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 4, 6, 44, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 1, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 4, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 1, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 4, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 2, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 1, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 1, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 2, 3, 35, 315);
commit;
prompt 155000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 1, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 2, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 3, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 1, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 1, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 1, 3, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 4, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 1, 6, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 4, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 4, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4646, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 2, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 4, 4, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 5, 1, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 2, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 3, 1, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 4, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 3, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4647, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 4, 6, 92, 1564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 4, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 2, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 3, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 1, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 1, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 3, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 5, 1, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 3, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 3, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 3, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 4, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 4, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 3, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 3, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4648, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 3, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 2, 2, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 1, 1, 1, 13, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 7, 2, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 5, 4, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 6, 3, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 7, 4, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 4, 1, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4733, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 1, 1, 2, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 3, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 5, 4, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 1, 4, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 4, 3, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 2, 4, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 5, 4, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 4, 2, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 7, 2, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 4, 2, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4734, 6, 1, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 2, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 4, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 2, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 3, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 2, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 1, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 3, 2, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 3, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 2, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 3, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 2, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 1, 1, 27, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 4, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 2, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 4, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 3, 2, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 1, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 1, 4, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 7, 3, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 1, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 2, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 8, 1, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 6, 4, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 4, 4, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4735, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 4, 2, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 3, 4, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4736, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 2, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 3, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 2, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 3, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 3, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 2, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 3, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 7, 3, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 3, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 4, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 3, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 1, 4, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4737, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 2, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 4, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 3, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 2, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 3, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 3, 1, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 1, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 3, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 4, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 4, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 4, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 3, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 3, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 3, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 1, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 2, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 1, 3, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 2, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 1, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 3, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 3, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 4, 3, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 4, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 4, 3, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 3, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 1, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 3, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 4, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 4, 2, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 1, 5, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 6, 1, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 4, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 4, 6, 7, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 8, 3, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 4, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 1, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4818, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 7, 3, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 3, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 8, 1, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 6, 2, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 3, 3, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 3, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 2, 3, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4819, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 3, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 1, 4, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 2, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 2, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 4, 2, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 1, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 3, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 3, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 1, 1, 38, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 3, 2, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 6, 3, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 8, 4, 3, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4820, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 7, 3, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 6, 3, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 4, 4, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 3, 2, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 5, 1, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4821, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 4, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 1, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 1, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 2, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 3, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 1, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 1, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 4, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 3, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 1, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 1, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 2, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 3, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 2, 2, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 2, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 2, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 3, 4, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 2, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 1, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 1, 1, 4, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 4, 1, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 5, 1, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4822, 6, 4, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 3, 4, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 3, 4, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 4, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 6, 4, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 7, 2, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 2, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 2, 3, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 2, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 1, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 4, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 1, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 3, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 4, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 4, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 1, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 1, 3, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 2, 2, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4894, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 2, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 2, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 3, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 3, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 4, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 4, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 3, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 1, 6, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 4, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 2, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 3, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 1, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 2, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 1, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 3, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 2, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 2, 3, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 1, 4, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 8, 2, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 1, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 3, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4895, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 2, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 1, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 4, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 1, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 3, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 2, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 1, 3, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 1, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 4, 4, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 1, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 1, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 3, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 3, 2, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 5, 3, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4896, 7, 3, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 8, 2, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 3, 2, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 2, 1, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 8, 4, 4, 26, 416);
commit;
prompt 156000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 2, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 5, 2, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 8, 4, 2, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 2, 3, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 8, 1, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 2, 4, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 2, 1, 6, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 4, 3, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4897, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 4, 3, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 4, 4, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 1, 3, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 6, 1, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4898, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 4, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 2, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 1, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 3, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 4, 1, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4649, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 2, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 8, 3, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 5, 4, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 7, 2, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 2, 2, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 2, 3, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 1, 4, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 3, 4, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4651, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 2, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 1, 2, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 4, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 4, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 3, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 1, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 1, 2, 6, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 3, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 3, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 2, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 1, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 2, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 1, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 1, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 3, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 2, 3, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 1, 2, 4, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 4, 3, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4652, 8, 3, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 4, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 1, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 2, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 1, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 1, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 1, 2, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 2, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 1, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 3, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 2, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 3, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 1, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 3, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 4, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 1, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 4, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 3, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 1, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 3, 3, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 4, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 4, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 3, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 4, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 5, 4, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 1, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 3, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 8, 4, 3, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4653, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 1, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 2, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 4, 2, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 4, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 1, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 4, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 3, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 3, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 1, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 2, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 2, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 2, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 1, 4, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 3, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 2, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 1, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 4, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 2, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 4, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 7, 2, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4654, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 3, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 4, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 3, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 4, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 1, 2, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 2, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4738, 5, 3, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 4, 1, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 6, 2, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 2, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 3, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 4, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 1, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 3, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 4, 6, 54, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 1, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 3, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 8, 3, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 2, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 1, 1, 3, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 1, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4739, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 8, 3, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 2, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 4, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 3, 2, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 2, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 3, 1, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 3, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 1, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 8, 3, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 3, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 5, 1, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4740, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 4, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 1, 4, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 7, 2, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 3, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 3, 4, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 3, 4, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 3, 2, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 3, 2, 3, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 4, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 7, 2, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4741, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 1, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 1, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 3, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 2, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 3, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 2, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 1, 4, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 1, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 3, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 3, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 2, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 3, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 2, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 1, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 2, 2, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 3, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4742, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 2, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 2, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 1, 1, 1, 3);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 3, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 1, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 3, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 3, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4823, 8, 1, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 3, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 1, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 2, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 2, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 2, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 1, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 4, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 3, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 2, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 6, 2, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4824, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 7, 2, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 7, 2, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 3, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 3, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 4, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4825, 3, 4, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 4, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 1, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 4, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 2, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 1, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 4, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 4, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 2, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 2, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 2, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 3, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 8, 3, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 2, 2, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 8, 1, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 1, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 1, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 1, 3, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 7, 1, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 3, 4, 1, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 2, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 1, 2, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4826, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 2, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 1, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 5, 1, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 3, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 4, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 1, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 2, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 3, 2, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 2, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 4, 2, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 8, 3, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 3, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4828, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 2, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 2, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 3, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 3, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 1, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 2, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 1, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 2, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 3, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 3, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 2, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 1, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 1, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 2, 1, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 4, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 3, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 1, 3, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 3, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 1, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 1, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 2, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 3, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 1, 1, 6, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 4, 2, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 4, 2, 64, 768);
commit;
prompt 157000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 2, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 2, 3, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 4, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 1, 3, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4575, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 1, 6, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 2, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 2, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 1, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 1, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 3, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 1, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 1, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 1, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 1, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 3, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 2, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 1, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 3, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 2, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 8, 3, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 1, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 4, 3, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 7, 1, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 1, 1, 4, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4576, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 7, 4, 4, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 3, 4, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 7, 4, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 3, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 1, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 1, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 4, 5, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 4, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 4, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 2, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 4, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 3, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 1, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 2, 3, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 3, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 5, 2, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 7, 1, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4577, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 1, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 1, 4, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 4, 3, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 3, 4, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 3, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 4, 4, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 3, 3, 3, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 8, 3, 1, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 5, 2, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4578, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 2, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 1, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 1, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 1, 3, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 4, 4, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 4, 1, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 3, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 1, 3, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 2, 4, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 2, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4579, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 8, 1, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 7, 2, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 3, 1, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 8, 3, 2, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 5, 2, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 2, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 4, 3, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 1, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 4, 6, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 4, 2, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 4, 2, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 6, 1, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 3, 3, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 3, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4655, 8, 4, 4, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 1, 1, 1, 50, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 5, 4, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 8, 3, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 3, 4, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4656, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 3, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 2, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 3, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 4, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 3, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 2, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 2, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 2, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 3, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 2, 3, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 2, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 2, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 4, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 1, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 4, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 2, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 4, 3, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 1, 3, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 1, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 4, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4657, 4, 1, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 3, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 2, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 4, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 3, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 3, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 3, 3, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 1, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 3, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 1, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 3, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 3, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 1, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 4, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 4, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 1, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 3, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 2, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 8, 2, 5, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 3, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 4, 2, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 4, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4659, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 1, 4, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 1, 3, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 1, 1, 4, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4660, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 3, 3, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 4, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 2, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 4, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 3, 1, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 3, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 2, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 3, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 6, 4, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 6, 3, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 5, 4, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 3, 2, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 7, 4, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4661, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 6, 3, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 6, 3, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 7, 3, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 6, 4, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 8, 2, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4662, 4, 4, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 3, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 2, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 1, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 3, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 4, 2, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 1, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 4, 1, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 6, 4, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4743, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 4, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 3, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 4, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 1, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 2, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 2, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 4, 2, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 2, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 2, 4, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 3, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 2, 4, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 4, 1, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 1, 4, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 3, 1, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 8, 2, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4744, 5, 3, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 1, 4, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 4, 2, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 6, 3, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 6, 4, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 3, 1, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 1, 3, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 6, 4, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4745, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 6, 4, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 8, 3, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 3, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 8, 1, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 1, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 6, 1, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 2, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 3, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 7, 2, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 3, 3, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4746, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 1, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 3, 4, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 4, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 8, 3, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 4, 2, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 5, 4, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 2, 4, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4747, 5, 4, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 4, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 3, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 1, 2, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 3, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 3, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 3, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 1, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 3, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 3, 4, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 3, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 7, 4, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 2, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 1, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 6, 3, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 8, 4, 6, 44, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4748, 5, 4, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 3, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 1, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 1, 3, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 3, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 1, 1, 1, 96, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 2, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 3, 5, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 3, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 3, 3, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 2, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 4, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 2, 3, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 3, 3, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 1, 6, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 4, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 3, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 4, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 3, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 2, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 3, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 4, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 1, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 3, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 1, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 4, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 5, 1, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 4, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 2, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 7, 1, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 1, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 6, 4, 4, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 4, 2, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4829, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 2, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 7, 2, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 6, 4, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 6, 2, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 4, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 3, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 3, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 3, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 2, 4, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4830, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 2, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 4, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 2, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 2, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 3, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 4, 4, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 3, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 3, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 4, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 2, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 3, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 6, 99, 1188);
commit;
prompt 158000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 4, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 4, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 5, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 2, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 3, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 4, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 5, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 2, 2, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 4, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 1, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 4, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 3, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 3, 1, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 1, 16, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 3, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 3, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 2, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 4, 1, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 5, 1, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 1, 4, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4831, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 4, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 3, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 3, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 4, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 1, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 3, 1, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4580, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 4, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 4, 1, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 3, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 4, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 2, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 1, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 1, 3, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 4, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 6, 2, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 4, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 4, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 2, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 1, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 2, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 5, 4, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 5, 3, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4581, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 1, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 2, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 2, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 3, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 1, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 1, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 4, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 4, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 3, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 1, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 2, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 1, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 1, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 2, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 1, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 4, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 1, 2, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 4, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 2, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 3, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 2, 2, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 1, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 3, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 1, 1, 49, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 3, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 2, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 1, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 3, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 3, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 1, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 1, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 1, 6, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 6, 4, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 4, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 3, 4, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4582, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 1, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 2, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 2, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 4, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 3, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 2, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 3, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 3, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 4, 5, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 1, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 3, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 1, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 2, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 7, 3, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 3, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 1, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 1, 3, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 1, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 3, 3, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4583, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 1, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 3, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 2, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 1, 4, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 1, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 3, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 2, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 3, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 1, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 3, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 1, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 2, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 5, 4, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 3, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 4, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 2, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 3, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 2, 4, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 5, 4, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 1, 1, 6, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 1, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4663, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 5, 1, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 2, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 3, 2, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 2, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 2, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 4, 3, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 4, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 4, 2, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 1, 1, 5, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 3, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 4, 4, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 2, 1, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4664, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 3, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 1, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 2, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 2, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 2, 5, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 2, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 3, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 4, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 1, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 2, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 1, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 4, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 3, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 2, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 1, 4, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 4, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 2, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4665, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 2, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 2, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 4, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 4, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 4, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 3, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 4, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 2, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 4, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 4, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 1, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 4, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 4, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 2, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 4, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 2, 4, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 3, 2, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 2, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 4, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 1, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 8, 1, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 2, 1, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 2, 5, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 6, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 1, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 6, 4, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 3, 2, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4666, 5, 3, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 7, 4, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 3, 5, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 3, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 2, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 3, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 1, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 1, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4749, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 1, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 3, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 3, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 1, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 2, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 4, 2, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 4, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 5, 1, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 1, 2, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 4, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 4, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 4, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 4, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 2, 4, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 4, 4, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 3, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 4, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4750, 1, 4, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 3, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 2, 4, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 3, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 1, 1, 20, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 4, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 2, 4, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 3, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 2, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 2, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 2, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4751, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 1, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 4, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 3, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 4, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 4, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 1, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 4, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 4, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 2, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 2, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 4, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 1, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 1, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 2, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 3, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 2, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 4, 1, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 3, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 3, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 1, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 2, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 2, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 1, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 4, 3, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 3, 4, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 5, 2, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 6, 2, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4752, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 4, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 1, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 1, 2, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 3, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 2, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 4, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 4, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 8, 3, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 3, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 1, 1, 5, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 2, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 5, 3, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 6, 1, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 2, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4753, 2, 2, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 5, 4, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 6, 4, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 1, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 1, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 1, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 4, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 8, 4, 4, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 3, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 6, 3, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 6, 1, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 7, 1, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 5, 2, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4754, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 2, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 4, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 4, 6, 96, 1728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 2, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 2, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 1, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 1, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 2, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 1, 5, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 4, 4, 21, 231);
commit;
prompt 159000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 2, 2, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 2, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 3, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 1, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 3, 3, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 2, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 4, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 4, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 1, 6, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 3, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 2, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 1, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 5, 4, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 1, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 2, 2, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 2, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 1, 3, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 3, 2, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4832, 8, 2, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 1, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 8, 1, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 4, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 8, 4, 2, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 4, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 1, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 1, 1, 1, 76, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 4, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 5, 4, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 3, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 1, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 2, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 4, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 1, 1, 4, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 2, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 2, 1, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 2, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 6, 1, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 3, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4833, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 1, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 3, 2, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 4, 1, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 2, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 1, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 1, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 3, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 2, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 4, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 4, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 2, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 4, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 1, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 1, 4, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 3, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 1, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 3, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 2, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 1, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 8, 2, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 2, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4834, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 6, 1, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 1, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 1, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 3, 2, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 1, 4, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 5, 3, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 1, 3, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 1, 3, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 6, 1, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 1, 4, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 8, 1, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 4, 1, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4835, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 2, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 4, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 3, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 4, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 4, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 1, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 1, 1, 17, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 2, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 4, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 8, 2, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 8, 1, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 1, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 4, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 2, 5, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 3, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 2, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 6, 4, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4836, 3, 3, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 1, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 4, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 3, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 4, 1, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 1, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 1, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 1, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 1, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 4, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 2, 1, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 3, 2, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 5, 3, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 6, 3, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4584, 1, 3, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 1, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 7, 3, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 4, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 3, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 2, 2, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 2, 2, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 4, 4, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 1, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 4, 5, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 3, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 2, 2, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 3, 3, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4585, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 5, 3, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 2, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 4, 4, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 6, 1, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 6, 1, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 4, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 6, 3, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 1, 4, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 1, 1, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 8, 1, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 2, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4586, 7, 1, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 4, 4, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 1, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 3, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 1, 6, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 2, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 3, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 4, 4, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 4, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 1, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 8, 2, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4588, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 6, 1, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 3, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 3, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 4, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 1, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 3, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 2, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 4, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 2, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 2, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 1, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 2, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 2, 2, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 7, 4, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 1, 2, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 1, 2, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4589, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 2, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 1, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 2, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 1, 2, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 1, 6, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 1, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 4, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 1, 1, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 2, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 3, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 4, 3, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4667, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 5, 2, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 5, 1, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 8, 1, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 1, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 1, 6, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 8, 1, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 2, 2, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 5, 3, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4668, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 8, 3, 2, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 2, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 4, 1, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 2, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 4, 2, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 1, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 4, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 3, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 2, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 2, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 2, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 3, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 7, 2, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 8, 2, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 2, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4669, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 8, 2, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 5, 2, 2, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 7, 2, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 1, 2, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 8, 3, 4, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 4, 3, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4670, 2, 1, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 4, 2, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 5, 2, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 4, 1, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 4, 5, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 1, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 3, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 1, 3, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 1, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 1, 1, 95, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 1, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 4, 1, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 1, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 4, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 3, 1, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 3, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 4, 2, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 5, 3, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 4, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4671, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 7, 4, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 8, 3, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 7, 4, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 6, 2, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 4, 2, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 2, 2, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 3, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 8, 3, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4672, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 2, 3, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 2, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 1, 3, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 2, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 1, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 2, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 1, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 1, 1, 36, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 2, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 3, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 8, 3, 2, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 8, 1, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 1, 6, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 3, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 6, 2, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 1, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 1, 3, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4673, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 1, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 4, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 4, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 4, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 3, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 1, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 1, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 2, 1, 93, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 1, 5, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 3, 3, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 3, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 3, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 1, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 4, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 4, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 3, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 3, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 4, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 1, 3, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 2, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 4, 3, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 1, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 6, 1, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 4, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 1, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 2, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 4, 6, 59, 1062);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 5, 1, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4755, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 1, 4, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 1, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 2, 4, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 1, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 1, 3, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 3, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 2, 3, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 4, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 2, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 1, 4, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 3, 4, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 4, 1, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 5, 3, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4756, 8, 3, 1, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 3, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 2, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 3, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 3, 5, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 4, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 4, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 5, 19, 152);
commit;
prompt 160000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 4, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 1, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 2, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 1, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 4, 2, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 4, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 3, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 2, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 2, 2, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 3, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 8, 1, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 7, 1, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4757, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 2, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 3, 6, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 2, 5, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 1, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 1, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 4, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 4, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 2, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 1, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 2, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 2, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 4, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 4, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 2, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 3, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 1, 2, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 3, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 4, 4, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 8, 1, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 1, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4758, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 4, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 1, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 3, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 1, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 2, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 1, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 2, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 3, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 4, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 3, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 1, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 3, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 3, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 4, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 2, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 4, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 3, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 2, 1, 2, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 4, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 3, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 3, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 4, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4837, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 3, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 3, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 2, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 3, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 2, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 4, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 4, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 4, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 3, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 4, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 7, 1, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 1, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 5, 2, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 8, 3, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4838, 2, 1, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 3, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 3, 3, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 1, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 4, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 1, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 2, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 1, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 2, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 3, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 2, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 2, 1, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 4, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 1, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 1, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 2, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 4, 5, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 1, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 4, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 2, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 3, 6, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 2, 2, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 8, 1, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4839, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 4, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 2, 3, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 1, 1, 4, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 1, 4, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 1, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 4, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 4, 1, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 4, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 1, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 1, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 8, 1, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 3, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 3, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 1, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 3, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 5, 3, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4840, 6, 3, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 3, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 1, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 1, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 3, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 2, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 2, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 2, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 1, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 4, 4, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 4, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 4, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 2, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 4, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 3, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 1, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 3, 5, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 4, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 2, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 2, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 4, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 2, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 4, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 1, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 2, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 2, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 4, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 3, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 3, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 3, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 3, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 1, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 3, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 4, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 3, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 4, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 1, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 4, 4, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 1, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 1, 3, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 3, 2, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4590, 5, 3, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 6, 2, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 1, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 2, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 2, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 3, 2, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 4, 6, 76, 1368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 1, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 1, 2, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 2, 6, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 2, 2, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 4, 1, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 4, 2, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 5, 4, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 4, 4, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4591, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 5, 2, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 3, 3, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 4, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 1, 1, 5, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 6, 3, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4592, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 4, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 2, 5, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 1, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 4, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 4, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 3, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 2, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 3, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 4, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 3, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 2, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 2, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 3, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 2, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 4, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 4, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 2, 6, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 3, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 1, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 4, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 2, 1, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 1, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 3, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 1, 3, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 7, 3, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 2, 2, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 3, 2, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 4, 1, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 3, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 2, 4, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4593, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 4, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 2, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 2, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 1, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 4, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 2, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 3, 3, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 4, 4, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 8, 4, 2, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 5, 1, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 8, 1, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4674, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 3, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 7, 1, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 5, 1, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 4, 2, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 3, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 4, 3, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 5, 1, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 2, 1, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 2, 2, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 4, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 4, 6, 95, 1710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 1, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 8, 4, 6, 2, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 6, 4, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4675, 1, 2, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 2, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 2, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 2, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 4, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 2, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 6, 4, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 3, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 4, 3, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 3, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 2, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 4, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 4, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 1, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 4, 2, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 2, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 4, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 2, 3, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 4, 1, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 4, 3, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 4, 6, 68, 1156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 1, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 3, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 1, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4676, 8, 3, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 2, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 4, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 2, 3, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 3, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 1, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 1, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 2, 4, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 4, 1, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 3, 4, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 4, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 5, 2, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4677, 1, 2, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 4, 4, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 6, 4, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 6, 2, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 3, 3, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 7, 1, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 2, 2, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4678, 5, 3, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 6, 2, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 4, 6, 91, 1638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 2, 2, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 7, 1, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 6, 3, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 1, 4, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 7, 3, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 2, 1, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 4, 4, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4679, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 3, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 3, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 3, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 4, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 4, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 4, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 2, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 4, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 3, 5, 97, 1455);
commit;
prompt 161000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 3, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 4, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 2, 6, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 4, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 2, 4, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 3, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 2, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 2, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 2, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 1, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 3, 6, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 3, 4, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 6, 4, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 4, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 4, 4, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 3, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 4, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 3, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 4, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 1, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 4, 3, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 2, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 2, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 2, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 3, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 2, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 4, 4, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 3, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 1, 2, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 8, 1, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4759, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 3, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 4, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 2, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 3, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 3, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 4, 6, 58, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 2, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 1, 2, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 2, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 4, 3, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 3, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 4, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 2, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 3, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 4, 4, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 3, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 2, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 3, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 3, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 3, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 3, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 2, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 1, 3, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 3, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 1, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 2, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 4, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 4, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 3, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4760, 8, 2, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 1, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 3, 3, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 4, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 5, 4, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 2, 3, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 3, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 5, 3, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4761, 3, 1, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 1, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 3, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 4, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 3, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 1, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 3, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 1, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 6, 2, 4, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 4, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 7, 2, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 1, 1, 2, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 2, 3, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4762, 3, 1, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 1, 2, 3, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 7, 2, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 7, 4, 6, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 4, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 7, 2, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 2, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 6, 3, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 3, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 2, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 3, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 4, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 8, 2, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 5, 2, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 1, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 4, 3, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 3, 2, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 1, 1, 6, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4764, 2, 2, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 4, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 8, 2, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 8, 4, 4, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 2, 4, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 2, 2, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 1, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 3, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 6, 4, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 2, 3, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4765, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 3, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 3, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 3, 2, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 3, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 6, 4, 2, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 3, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 7, 2, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 4, 3, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4841, 1, 3, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 3, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 4, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 3, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 4, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 4, 1, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 4, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 3, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 4, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 3, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 1, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 3, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 2, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 1, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 4, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 3, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 3, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 4, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4842, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 3, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 1, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 3, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 1, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 3, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 4, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 3, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 1, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 4, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 1, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 4, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 3, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 3, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 6, 2, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 2, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 3, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 2, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 6, 4, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 7, 1, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 3, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 4, 3, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4843, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 3, 3, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 3, 6, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 3, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 2, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 1, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 4, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 4, 5, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 1, 1, 41, 123);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 4, 5, 98, 1666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 2, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 2, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 3, 4, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 4, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 2, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 3, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 1, 6, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 2, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 4, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 3, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 6, 4, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 4, 4, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4844, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 2, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 4, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 3, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 1, 1, 4, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 4, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 2, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 3, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 3, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 1, 4, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 4, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 3, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 2, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 8, 1, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 1, 2, 6, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 1, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 1, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 7, 4, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4845, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 5, 4, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 2, 1, 1, 89, 356);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 8, 2, 3, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 4, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 2, 2, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 4, 3, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 1, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 1, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 4, 3, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 1, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 2, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 1, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 4, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 4, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 4, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 2, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 4, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 2, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 4, 6, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 3, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 3, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 4, 1, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 1, 2, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 1, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 4, 2, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4594, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 3, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 1, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 5, 4, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 4, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 3, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 1, 3, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 3, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 2, 2, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 4, 1, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 1, 1, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 2, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 2, 3, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 2, 4, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4595, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 1, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 2, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 1, 1, 2, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 4, 4, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 1, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 1, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 3, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 1, 4, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 8, 1, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 2, 5, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 3, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 3, 2, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 1, 3, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 1, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 7, 4, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 8, 2, 5, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4596, 2, 2, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 2, 3, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 1, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 2, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 4, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 4, 5, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 2, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 1, 6, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 2, 4, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 1, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 4, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 7, 4, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 3, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4597, 6, 3, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 2, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 3, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 3, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 3, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 1, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 3, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 1, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 2, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 3, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 1, 3, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 2, 2, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 2, 6, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 3, 6, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 2, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 4, 2, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 4, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 4, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 2, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4598, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 1, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 2, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 2, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 1, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 4, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 4, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 2, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 5, 1, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 1, 4, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 6, 1, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4599, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 4, 5, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 2, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 3, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 3, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 3, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 4, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 3, 4, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4680, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 3, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 4, 3, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 1, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 1, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 1, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 3, 2, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 1, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 1, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 3, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 4, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 3, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 1, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 4, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 2, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 1, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 3, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 3, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 4, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 3, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 3, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 3, 6, 27, 270);
commit;
prompt 162000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 2, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 1, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 3, 3, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 3, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 4, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 3, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 1, 1, 4, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 3, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4681, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 2, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 2, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 1, 1, 56, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 2, 2, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 4, 4, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 1, 6, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 2, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 3, 4, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 3, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 7, 2, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 3, 4, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 4, 4, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4682, 6, 1, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 3, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 4, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 2, 1, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 1, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 4, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 4, 3, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 3, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 5, 2, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 2, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 3, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 2, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 2, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 2, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 2, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 3, 1, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 1, 5, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 4, 4, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 1, 1, 3, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4683, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 4, 4, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 5, 3, 3, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 3, 1, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 8, 1, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4684, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 2, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 2, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 2, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 4, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 4, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 4, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 1, 5, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 2, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 4, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 3, 1, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 4, 2, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 7, 1, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4685, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 8, 2, 1, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 3, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 2, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 8, 3, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 4, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 3, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 3, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 6, 4, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 1, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 3, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 3, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 1, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 4, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 3, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4766, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 1, 4, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 4, 2, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 2, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 4, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 4, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 2, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 4, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 3, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 1, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 1, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 1, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 1, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 1, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 4, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 1, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 2, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 4, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 3, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 2, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 1, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 1, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 1, 1, 68, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 1, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 2, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 2, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 2, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 1, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 1, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 1, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 1, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 4, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 1, 2, 4, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4767, 6, 4, 3, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 4, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 3, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 4, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 3, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 1, 4, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 2, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 5, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 3, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 2, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 2, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 1, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 4, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 2, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 1, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 4, 2, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 2, 5, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 7, 1, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 4, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 2, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 4, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 4, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 1, 2, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 3, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 5, 1, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 3, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 6, 3, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4768, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 3, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 3, 3, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 3, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 4, 3, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 8, 2, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 4, 3, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 4, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 2, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 4, 1, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 7, 3, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 3, 4, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4769, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 1, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 4, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 3, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 2, 3, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 3, 1, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 3, 3, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 3, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4770, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 6, 3, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 6, 3, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 5, 3, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 1, 4, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 6, 3, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 4, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 3, 2, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4846, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 1, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 2, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 6, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 3, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 3, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 2, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 2, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 4, 3, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 2, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 2, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 1, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 3, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 2, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 3, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 2, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 2, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 3, 2, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 1, 1, 5, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 5, 3, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 2, 4, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4847, 7, 3, 4, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 3, 1, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 1, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 4, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 1, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 2, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 3, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 1, 1, 3, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 3, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 1, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 3, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 2, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 4, 5, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 4, 3, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 3, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 1, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 1, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 3, 3, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 1, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 1, 3, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 4, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 1, 2, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 3, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 3, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 1, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 3, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4848, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 3, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 3, 6, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 2, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 2, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 1, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 4, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 4, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 4, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 4, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 1, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 1, 1, 28, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 4, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 1, 1, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 1, 3, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 3, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 3, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 3, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 1, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 2, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 1, 1, 32, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 4, 5, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 1, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 4, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4849, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 7, 2, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 5, 4, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 4, 3, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 4, 2, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 4, 2, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 5, 1, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 4, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 5, 3, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 2, 4, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 3, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 4, 3, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 3, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4850, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 4, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 1, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 2, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 2, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 2, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 2, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 1, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 4, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 3, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 2, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 4, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 2, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 3, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 1, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 1, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 2, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 1, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 3, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 2, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 3, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 4, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 2, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 5, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 3, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 2, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 3, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 3, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 3, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 2, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 3, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 3, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 1, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 3, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 1, 4, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 8, 1, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 1, 4, 1, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 4, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 4, 2, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 3, 4, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4998, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 7, 1, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 2, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 4, 3, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 2, 4, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 2, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 4, 4, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 2, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 2, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 2, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 4, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 2, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 4, 4, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 1, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 1, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 7, 4, 6, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 1, 5, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 4, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4999, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 2, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 3, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 4, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 4, 3, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 2, 1, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 3, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 2, 5, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 1, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 3, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 4, 1, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 2, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 1, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 3, 2, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 1, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 2, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 1, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 3, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 3, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 2, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 2, 4, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 3, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 3, 4, 52, 624);
commit;
prompt 163000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 4, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 3, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 3, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 1, 3, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 5, 2, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 4, 4, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5000, 6, 4, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 3, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 1, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 1, 3, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 2, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 1, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 8, 3, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 6, 3, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 4, 2, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 8, 4, 3, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 2, 1, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 4, 1, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 7, 4, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 1, 3, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5001, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 4, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 4, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 1, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 4, 2, 6, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 1, 3, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 2, 1, 1, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 2, 2, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 2, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 4, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 3, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 4, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 4, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 1, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 4, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 2, 2, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 1, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 2, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 1, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 4, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 4, 2, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 3, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 2, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 2, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 2, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 1, 5, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 1, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 1, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 5, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 3, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 3, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 7, 4, 4, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 2, 6, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 6, 2, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5090, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 4, 4, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 5, 3, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 2, 4, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 5, 3, 3, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 2, 4, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 5, 3, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 7, 1, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5091, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 6, 1, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 3, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 1, 1, 6, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5092, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 3, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 2, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 2, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 1, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 3, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 4, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 4, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 3, 5, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 4, 1, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 4, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 3, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 3, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 1, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 2, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 4, 3, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 3, 3, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 2, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 1, 1, 3, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 4, 3, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5093, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 4, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 1, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 8, 3, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 4, 4, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 2, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 5, 3, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 5, 1, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 3, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 3, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 4, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 6, 2, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5094, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 2, 5, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 4, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 4, 1, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 4, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 4, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 2, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 8, 2, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 1, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 2, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 1, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 4, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 7, 2, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 3, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 4, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 8, 1, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5095, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 4, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 2, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 4, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 2, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 2, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 4, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 4, 6, 58, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 3, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 2, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 1, 6, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 3, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 2, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 3, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 2, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 4, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 7, 2, 2, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 4, 6, 100, 1800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 7, 2, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 4, 4, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 2, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 2, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 1, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 2, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 1, 5, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 3, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 3, 2, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 3, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 4, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 4, 3, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 4, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 2, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 5, 3, 6, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 3, 4, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 3, 1, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 4, 1, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 4, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 4, 2, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 3, 1, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 1, 3, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 2, 4, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 4, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 4, 1, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 1, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 8, 3, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 2, 2, 1, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5168, 1, 1, 1, 31, 93);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 1, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 1, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 2, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 1, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 1, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 4, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 2, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 1, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 4, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 4, 1, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 3, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 2, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 1, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 3, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 1, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 1, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 3, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 2, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 1, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 2, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 2, 5, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 1, 2, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 3, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 2, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 6, 2, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 5, 4, 2, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 1, 4, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 8, 1, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 2, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5169, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 4, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 2, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 4, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 1, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 3, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 6, 3, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 6, 2, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 3, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 4, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 1, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 1, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 2, 2, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 4, 4, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 1, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 2, 3, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 4, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 4, 2, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 2, 4, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 1, 3, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 3, 2, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5170, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 1, 2, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 2, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 4, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 4, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 1, 5, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 3, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 3, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 1, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 3, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 2, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 4, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 4, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 3, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 2, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 1, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 3, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 3, 3, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 1, 3, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 3, 1, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5171, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 3, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 2, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 1, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 2, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 1, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 1, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 4, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 2, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 2, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 4, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 4, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 3, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 1, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 4, 6, 82, 1476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 4, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 3, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 4, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 3, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 3, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 1, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 8, 1, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 1, 4, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 8, 4, 3, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 3, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 2, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 4, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 4, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 2, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 8, 4, 4, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 8, 1, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 1, 1, 6, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 3, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 3, 3, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4926, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 2, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 4, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 2, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 4, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 4, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 3, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 3, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 2, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 4, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 4, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 2, 5, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 2, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 3, 2, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 4, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 4, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 4, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 4, 5, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 1, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 1, 6, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 6, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 4, 6, 9, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 5, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 4, 5, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 2, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 1, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 1, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 4, 3, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 4, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 6, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 3, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 4, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 8, 3, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 1, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 4, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 3, 1, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 1, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 1, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 1, 1, 4, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4927, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 3, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 2, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 1, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 3, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 2, 2, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 2, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 2, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 3, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 2, 1, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 4, 1, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 1, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 4, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 2, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 2, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 3, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 3, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 1, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 8, 1, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 2, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 3, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 3, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 1, 4, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 1, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 5, 3, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 2, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 3, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5002, 7, 1, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 4, 5, 64, 1024);
commit;
prompt 164000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 3, 2, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 4, 1, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 2, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 2, 1, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 2, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 4, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 2, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 2, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 1, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 3, 3, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 5, 2, 5, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 2, 3, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 3, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 3, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 3, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 2, 3, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5003, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 4, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 1, 5, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 2, 3, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 3, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 1, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 3, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 1, 6, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 4, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 1, 4, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 2, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 1, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 2, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 3, 4, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 3, 4, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 3, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 7, 3, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 4, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 3, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 3, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 2, 1, 2, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 8, 3, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 4, 3, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5005, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 5, 3, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 2, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 3, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 4, 2, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 2, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 3, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 5, 2, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 1, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 2, 3, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 3, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 8, 3, 3, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 4, 3, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 3, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 1, 6, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 6, 2, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 4, 1, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5006, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 3, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 6, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 2, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 4, 3, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 4, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 2, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 2, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 3, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 3, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 3, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 3, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 2, 3, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 1, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 2, 3, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 4, 2, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 4, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 1, 2, 4, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 4, 2, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 5, 4, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 4, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 4, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 8, 1, 1, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 3, 3, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 3, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 3, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 2, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 4, 3, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5096, 8, 3, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 1, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 2, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 8, 3, 3, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 2, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 2, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 1, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 2, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 2, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 2, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 3, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 3, 2, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 1, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 4, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 4, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 2, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 3, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 3, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 3, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 8, 3, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 4, 6, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 8, 1, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 2, 1, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 4, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 3, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5097, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 1, 4, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 2, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 3, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 3, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 3, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 1, 2, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 1, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 1, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 2, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 1, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 3, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 4, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 2, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 2, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 2, 4, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 4, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 1, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 4, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 3, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 1, 3, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 3, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 1, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 2, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 1, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 1, 5, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 2, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 3, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 2, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 4, 4, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 3, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 2, 1, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 3, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 3, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 5, 2, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 2, 1, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 1, 2, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 1, 4, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 2, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 2, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 4, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 1, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 2, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 4, 4, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 7, 1, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5098, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 3, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 4, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 3, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 3, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 3, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 4, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 4, 6, 33, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 2, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 3, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 2, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 3, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 1, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 3, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 4, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 3, 6, 72, 1224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 2, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 3, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 4, 6, 74, 1332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 1, 2, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 3, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 2, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 3, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 3, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 1, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 1, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 4, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 1, 1, 6, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 2, 3, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 2, 4, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 6, 1, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 1, 3, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 1, 3, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 4, 1, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 4, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 5, 3, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 7, 4, 4, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 1, 4, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 3, 2, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 8, 4, 5, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5172, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 2, 1, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 4, 4, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 4, 2, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 8, 2, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 7, 1, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 7, 4, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5173, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 1, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 4, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 2, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 2, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 4, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 2, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 1, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 4, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 1, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 1, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 4, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 2, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 2, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 2, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 1, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 4, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 1, 1, 1, 3);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 2, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 1, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 1, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 2, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 2, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 4, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 4, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 1, 5, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 1, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 3, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 2, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 7, 1, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5174, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 1, 6, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 1, 4, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 1, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 1, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 1, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 4, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 1, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 2, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 1, 1, 42, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 2, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 2, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 4, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 2, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 4, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 3, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 1, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 2, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 6, 4, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 1, 3, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 2, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 1, 1, 2, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 4, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 3, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 2, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 5, 4, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5175, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 3, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 2, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 3, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 1, 2, 1, 1, 4);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 3, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 3, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 1, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 3, 4, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 3, 2, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 3, 3, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 1, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 2, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 4, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 3, 5, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 4, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 2, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 1, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 1, 1, 1, 39, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 4, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 8, 4, 6, 49, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5176, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 4, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 2, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 4, 6, 3, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 1, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 2, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 2, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 3, 6, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 3, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 2, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 2, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 1, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 2, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 3, 3, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 1, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 1, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 2, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 2, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 3, 3, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 1, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 4, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 3, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 1, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 3, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 4, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 2, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 1, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 3, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 1, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 1, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 1, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 1, 4, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 1, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 1, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4928, 5, 1, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 5, 3, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 1, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 5, 3, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 2, 1, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 1, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 2, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 3, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 2, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4929, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 1, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 4, 3, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 1, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 1, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 3, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 1, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 2, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 1, 5, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 1, 5, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 3, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 2, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 1, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 4, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 3, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 3, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 1, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 2, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 2, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 4, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 1, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 2, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 1, 1, 98, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 4, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 2, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 3, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 1, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 6, 3, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 2, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 4, 2, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 2, 3, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4930, 1, 4, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 1, 4, 1, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 1, 1, 2, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 1, 2, 29, 290);
commit;
prompt 165000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 3, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 4, 6, 79, 1422);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 2, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 4, 4, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 2, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 4, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 4, 2, 3, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 4, 1, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 2, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 3, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 1, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 2, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 1, 2, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 1, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 2, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 2, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 4, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 1, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 1, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 2, 2, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 8, 3, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 3, 3, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4931, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 8, 1, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 4, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 1, 5, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 2, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 1, 2, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 8, 1, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 1, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 2, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 4, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 8, 3, 5, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 1, 2, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 1, 6, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 3, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 1, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 1, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 2, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 6, 3, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 4, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 1, 2, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 7, 2, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 4, 3, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4932, 2, 3, 6, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 4, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 4, 4, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 8, 1, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 2, 5, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 3, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 4, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 4, 2, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 6, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 1, 2, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 4, 4, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 2, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 4, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 4, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 7, 4, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 4, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 3, 2, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 6, 3, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 1, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 3, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 4, 2, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5007, 1, 4, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 3, 3, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 4, 4, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 5, 3, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 3, 2, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 5, 4, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 6, 1, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 2, 2, 1, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 6, 1, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 8, 2, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 1, 4, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 7, 3, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 7, 2, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5008, 3, 1, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 4, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 1, 1, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 4, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 4, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 4, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 2, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 1, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 1, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 4, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 1, 1, 25, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 2, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 1, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 1, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 1, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 1, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 2, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 3, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 4, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 4, 2, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 3, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 1, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 2, 6, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 3, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 4, 3, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 3, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 2, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 2, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 3, 4, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 2, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 3, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 2, 2, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5009, 1, 4, 1, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 4, 2, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 6, 4, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 8, 1, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 1, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 2, 2, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 1, 3, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 2, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 4, 2, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 1, 2, 2, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 2, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 4, 2, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 3, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 2, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 3, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 6, 1, 6, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5011, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 3, 3, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 7, 2, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 5, 2, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 1, 3, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 4, 3, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 1, 3, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5012, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 5, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 1, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 1, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 2, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 3, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 1, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 2, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 2, 2, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 3, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 1, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 2, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 4, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 2, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 2, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 3, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 1, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 2, 5, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 4, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 1, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 1, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 3, 4, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 2, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 1, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 1, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 1, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 2, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 2, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 1, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 1, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 4, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 3, 4, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 2, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 4, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 5, 2, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 4, 4, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 3, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 2, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 8, 4, 5, 16, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 1, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 4, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 1, 1, 1, 81, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5100, 7, 1, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 1, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 2, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 4, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 5, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 4, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 2, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 3, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 1, 1, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 2, 1, 31, 124);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 2, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 1, 4, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 1, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 3, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 3, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 4, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 1, 3, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 1, 2, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 2, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 3, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 2, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 2, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 3, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 4, 2, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 6, 4, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 3, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 1, 4, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 3, 3, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 2, 2, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5101, 4, 2, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 4, 3, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 3, 2, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 2, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 2, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 2, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 1, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 1, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 4, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 2, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 8, 3, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 8, 3, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 4, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 2, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 3, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 2, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 1, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 4, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 1, 2, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 5, 3, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 4, 1, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 3, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 4, 2, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 4, 1, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5102, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 2, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 2, 4, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 4, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 4, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 4, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 2, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 4, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 1, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 1, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 7, 3, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 2, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 1, 6, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 3, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 1, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 4, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 3, 5, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 3, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 4, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 3, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 1, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 2, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 7, 3, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 2, 3, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 2, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 2, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 1, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 3, 2, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 4, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 4, 4, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 3, 4, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5103, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 2, 1, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 2, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 2, 1, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 3, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 2, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 3, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 1, 3, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 4, 5, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 3, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 1, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 2, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 2, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 2, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 3, 1, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 2, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 4, 1, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 1, 1, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 4, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 1, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 3, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 4, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 1, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 3, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 4, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 8, 3, 5, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 4, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 3, 1, 2, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 1, 2, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 2, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 6, 4, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 4, 4, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5177, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 1, 2, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 1, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 4, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 3, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 1, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 2, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 1, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 1, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 3, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 2, 4, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 2, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 4, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 1, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 2, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 1, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 1, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 3, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 1, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 2, 1, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 3, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 3, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 2, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 3, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 3, 1, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 3, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 1, 2, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 5, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 3, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 4, 4, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 4, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5178, 6, 1, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 7, 4, 3, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 3, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 3, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 7, 3, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 3, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 1, 5, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 1, 3, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 4, 3, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 3, 2, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 4, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 1, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 2, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 2, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 2, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 2, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 4, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 2, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 7, 1, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 1, 3, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 2, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 2, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 3, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 4, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 3, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 2, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 2, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 3, 1, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 4, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 6, 4, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 8, 1, 3, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 1, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5179, 5, 4, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 1, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 4, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 2, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 1, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 2, 4, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 2, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 2, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 3, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 4, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 2, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 1, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 1, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 3, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 4, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 3, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 1, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 2, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 2, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 2, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 2, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 4, 1, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 5, 1, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 4, 1, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 3, 1, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 6, 1, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5180, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 4, 4, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 4, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 1, 3, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 1, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 4, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 2, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 1, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 3, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 3, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 1, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 8, 2, 3, 45, 585);
commit;
prompt 166000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 4, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 3, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 4, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 4, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 3, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 4, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 2, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 3, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 3, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 1, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 4, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 4, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 3, 1, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 4, 1, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 5, 3, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4933, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 7, 4, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 3, 6, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 3, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 3, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 3, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 3, 4, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 2, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 4, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 2, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 7, 2, 3, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 4, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 2, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 3, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 8, 3, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 5, 1, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 4, 4, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 7, 4, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4934, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 2, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 3, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 5, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 2, 2, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 1, 2, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 3, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 3, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 3, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 1, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 4, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 4, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 4, 5, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 3, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 1, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 4, 3, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 3, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 3, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 1, 2, 2, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 6, 2, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 3, 3, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 1, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 4, 4, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4935, 5, 2, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 8, 4, 2, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 8, 3, 6, 42, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 2, 4, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 1, 4, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 2, 4, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 7, 1, 4, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 1, 3, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 6, 2, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 5, 3, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 8, 2, 1, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 4, 4, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 4, 1, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 2, 4, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 2, 3, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4936, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 2, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 1, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 3, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 1, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 4, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 4, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 3, 5, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 4, 3, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 4, 6, 48, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 1, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 2, 5, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 2, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 2, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 4, 4, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 4, 6, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 3, 1, 1, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 4, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 2, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 2, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 4, 3, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 3, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 3, 4, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 4, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 2, 3, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4937, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 3, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 3, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 1, 2, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 2, 1, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 8, 1, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5013, 7, 2, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 1, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 4, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 2, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 3, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 2, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 3, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 2, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 3, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 2, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 1, 2, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 1, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 2, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 4, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 4, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 3, 6, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 3, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 3, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 4, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 2, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 4, 4, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 3, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 2, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 4, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 7, 2, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 4, 2, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 2, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 6, 4, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 2, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 4, 3, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 3, 3, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 3, 5, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 8, 1, 6, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5014, 1, 4, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 6, 2, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 3, 1, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 3, 2, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 7, 1, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 4, 4, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 3, 2, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 8, 3, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 1, 1, 2, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5015, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 2, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 6, 12, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 2, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 4, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 4, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 2, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 4, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 3, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 1, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 2, 4, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 2, 5, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 4, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 4, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 4, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 2, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 3, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 2, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 3, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 5, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 1, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 1, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 2, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 4, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 1, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 2, 1, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 7, 3, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 4, 1, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 3, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 2, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 1, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 4, 2, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 2, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 6, 1, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5016, 1, 3, 5, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 4, 2, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 7, 2, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 7, 1, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 1, 2, 2, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 7, 4, 5, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 5, 2, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 6, 2, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 5, 3, 6, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 2, 2, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5017, 4, 2, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 8, 2, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 4, 1, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 1, 3, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 5, 2, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 3, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 2, 4, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 1, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 2, 3, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 5, 1, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5104, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 3, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 1, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 2, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 4, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 3, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 1, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 4, 2, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 1, 4, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 1, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 2, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 2, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 4, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 1, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 4, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 4, 1, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 2, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 2, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 2, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 3, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 3, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 2, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 2, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 3, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 4, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 2, 6, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 3, 5, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 1, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 3, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 4, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 1, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 4, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 1, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 4, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 3, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 1, 4, 4, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 3, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 3, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 1, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 4, 1, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5105, 2, 3, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 1, 2, 2, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 1, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 2, 2, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 3, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 2, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 2, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 4, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 1, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 1, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 3, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 2, 3, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 1, 1, 4, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 6, 1, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 3, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 3, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 1, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 1, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 1, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 4, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 5, 2, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 1, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5106, 6, 3, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 1, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 3, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 4, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 4, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 4, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 2, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 4, 5, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 4, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 3, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 4, 1, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 4, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 1, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 4, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 3, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 4, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 4, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 1, 4, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 2, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 1, 4, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 8, 4, 3, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 1, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 4, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 3, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 4, 2, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 3, 3, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 1, 2, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 2, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 1, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 4, 3, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 3, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 6, 1, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5107, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 4, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 1, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 4, 2, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 4, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 1, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 2, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 1, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 2, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 7, 3, 6, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 1, 3, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 3, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 3, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 2, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 2, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 4, 2, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 8, 3, 6, 7, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 5, 1, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 4, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 1, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 4, 3, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 3, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 1, 2, 2, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 3, 3, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 6, 3, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5181, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 4, 1, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 3, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 2, 3, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 2, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 1, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 1, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 2, 4, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 4, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 2, 4, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 2, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 2, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 1, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 3, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 3, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 4, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 5, 3, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 4, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 8, 1, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 3, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 2, 1, 18, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 4, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 2, 3, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5182, 3, 2, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 8, 1, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 7, 4, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 4, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 7, 2, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 2, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 4, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 8, 4, 4, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 4, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 4, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 4, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 4, 1, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 3, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 3, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 1, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 2, 3, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 1, 4, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 3, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 3, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 3, 3, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 1, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 2, 1, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5183, 5, 3, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 1, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 2, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 4, 79, 948);
commit;
prompt 167000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 4, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 1, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 2, 1, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 1, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 3, 1, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 1, 6, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 4, 6, 52, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 2, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 2, 5, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 2, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 1, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 3, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 2, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 2, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 2, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 3, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 1, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 3, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 1, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 2, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 5, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 2, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 2, 6, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 4, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 1, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 2, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 2, 1, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 4, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 3, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 1, 1, 3, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 2, 3, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 3, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 5, 2, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 3, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5184, 1, 2, 2, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 1, 2, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 3, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 4, 6, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 2, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 8, 2, 6, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 4, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 3, 4, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 3, 2, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 4, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 3, 5, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 3, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 8, 1, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 5, 4, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 8, 4, 2, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 6, 1, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 7, 1, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5185, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 4, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 8, 3, 5, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 6, 2, 5, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 5, 3, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 2, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 4, 4, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 3, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 3, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 1, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 4, 5, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 3, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 2, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 1, 3, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 1, 6, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 4, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 1, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 1, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 2, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 7, 4, 6, 71, 1207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 4, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 4, 2, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 2, 1, 5, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 4, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 7, 4, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 3, 3, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4938, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 4, 3, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 3, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 4, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 4, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 1, 4, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 1, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 4, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 3, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 4, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 4, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 4, 1, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 4, 3, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 1, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 2, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 2, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 3, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 2, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 1, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 2, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 1, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 1, 4, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 4, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 2, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 1, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 2, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 2, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 1, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 1, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 2, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 1, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 2, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 3, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 3, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 3, 2, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 1, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 1, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 6, 2, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 2, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 2, 5, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 1, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 1, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 3, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 1, 1, 1, 23, 69);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4939, 5, 1, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 5, 3, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 8, 3, 6, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 4, 1, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 8, 4, 1, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 1, 1, 6, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 4, 2, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 2, 4, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 8, 2, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 4, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 1, 4, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 7, 1, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 6, 2, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4940, 1, 1, 3, 100, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 1, 2, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 1, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 7, 2, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 1, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 1, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 2, 5, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 5, 3, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 3, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 4, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 3, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 3, 5, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 4, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 2, 3, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 1, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 1, 3, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 4, 2, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 7, 3, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 3, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 4, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 5, 2, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 1, 6, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 2, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 6, 2, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 3, 1, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 7, 2, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4941, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 1, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 3, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 2, 4, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 1, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 3, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 4, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 1, 2, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 4, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 3, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 3, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 2, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 2, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 3, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 2, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 2, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 2, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 3, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 1, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 1, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 4, 1, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 4, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 4, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 3, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 4, 2, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 2, 1, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 1, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 3, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 3, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 4, 2, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 6, 1, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 1, 2, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 3, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 2, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 3, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 5, 4, 1, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 3, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 4, 4, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 2, 2, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5018, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 2, 3, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 7, 3, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 5, 1, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5020, 3, 3, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 3, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 1, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 8, 3, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 3, 2, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 1, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 4, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 4, 5, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 2, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 3, 4, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 8, 4, 1, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 4, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 3, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 3, 3, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 1, 6, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 4, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 3, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 1, 1, 3, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 8, 2, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 3, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 3, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5021, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 2, 1, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 2, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 3, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 2, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 3, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 2, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 4, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 3, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 4, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 4, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 2, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 7, 4, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 7, 1, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 7, 4, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 2, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 3, 4, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 2, 2, 1, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 7, 3, 1, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 1, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 7, 1, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5022, 4, 3, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 7, 1, 2, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 3, 2, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 3, 3, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 7, 2, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 1, 1, 5, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 7, 4, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5023, 6, 2, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 1, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 4, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 3, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 3, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 3, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 4, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 1, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 3, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 3, 5, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 1, 1, 3, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 3, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 1, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 1, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 1, 2, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 4, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 4, 3, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 4, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 1, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 1, 4, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 3, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 7, 2, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 2, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5024, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 8, 1, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 5, 2, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 8, 3, 5, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5026, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 4, 1, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 1, 1, 5, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 1, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 3, 2, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 2, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 1, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 4, 1, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 1, 4, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 2, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 2, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 7, 3, 4, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 1, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 5, 4, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 1, 1, 4, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 2, 2, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 7, 1, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 8, 2, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5027, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 3, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 2, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 3, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 1, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 2, 4, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 2, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 1, 3, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 4, 5, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 1, 4, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 1, 6, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 3, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 2, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 1, 5, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 1, 3, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 1, 4, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 2, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 4, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 3, 4, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 4, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 3, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 4, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 3, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 4, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 4, 1, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 2, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 5, 4, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 3, 3, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 3, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 2, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 4, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 2, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 1, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 2, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 4, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 3, 2, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 1, 3, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 3, 4, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 3, 1, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 1, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 6, 3, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 1, 3, 1, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5108, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 3, 3, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 4, 1, 4, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 2, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 3, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 3, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 5, 4, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 2, 3, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 5, 1, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 2, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 4, 4, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 2, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 4, 6, 46, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 4, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 4, 4, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 4, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 2, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 6, 2, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5109, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 1, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 4, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 3, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 2, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 3, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 5, 1, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 3, 2, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 4, 1, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 2, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 4, 1, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 7, 2, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 5, 2, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 5, 2, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 1, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 4, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 3, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 4, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 4, 1, 4, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 4, 2, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 3, 2, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5111, 1, 3, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 2, 2, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 6, 1, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 1, 4, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 4, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 1, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 3, 3, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 2, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 8, 1, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 1, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 2, 3, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 3, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 3, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 8, 4, 6, 66, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 2, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 1, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 1, 4, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 1, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 3, 4, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 1, 1, 2, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 1, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 2, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 2, 2, 3, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 2, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 1, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 3, 1, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5112, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 3, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 3, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 4, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 2, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 3, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 3, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 4, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 3, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 2, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 3, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 3, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 1, 1, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 1, 1, 72, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 3, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 1, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 1, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 2, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 4, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 1, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 4, 4, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 4, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 1, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 1, 72, 576);
commit;
prompt 168000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 2, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 6, 1, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 3, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 1, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 2, 1, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 1, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 3, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 7, 3, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 3, 3, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 5, 2, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 4, 4, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 5, 2, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 6, 4, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 6, 3, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 5, 2, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 6, 3, 6, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 2, 2, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 3, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 2, 2, 1, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 1, 2, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5186, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 4, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 4, 2, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 2, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 4, 2, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 1, 3, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 4, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 1, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 3, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 2, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 2, 5, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 1, 3, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 1, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 1, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 4, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 4, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 3, 4, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 8, 3, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 2, 1, 4, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5187, 6, 2, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 4, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 4, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 7, 2, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 3, 5, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 3, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 1, 4, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 4, 4, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 2, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 2, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 4, 4, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 1, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 3, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 4, 3, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 2, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 3, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 5, 3, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 3, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 1, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 1, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 2, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 2, 2, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5188, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 1, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 8, 3, 2, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 4, 1, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 6, 3, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 5, 2, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 4, 2, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 1, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 1, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 5, 3, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 3, 2, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 1, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 3, 4, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 1, 2, 1, 7, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 6, 2, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 6, 1, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5189, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 4, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 3, 1, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 2, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 1, 3, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 2, 6, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 2, 4, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 3, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 4, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 5, 1, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 2, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 1, 4, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 1, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 2, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 3, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 4, 4, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 4, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 3, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 2, 2, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 4, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 3, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 2, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 1, 1, 77, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 3, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 2, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 1, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 2, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 3, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 4, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 4, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 1, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 8, 4, 4, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 3, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 5, 2, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 3, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 4, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 1, 2, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 6, 1, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5190, 4, 2, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 1, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 2, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 3, 6, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 4, 5, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 4, 3, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 1, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 1, 3, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 4, 1, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 4, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 2, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 1, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 2, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 1, 1, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 3, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 1, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 2, 6, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 1, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 2, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 4, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 3, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 1, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 2, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 3, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 1, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 4, 4, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 2, 3, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 2, 4, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 3, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 4, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 2, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 8, 4, 3, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 4, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 2, 1, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 4, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 3, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 3, 2, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 4, 1, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4942, 5, 1, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 4, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 4, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 1, 2, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 4, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 3, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 4, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 3, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 4, 4, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 2, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 4, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 3, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 4, 2, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 1, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 4, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 3, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 3, 2, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 4, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 3, 4, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 2, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 1, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 1, 6, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 2, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 2, 4, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 2, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 1, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 1, 4, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 1, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 4, 3, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 3, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 3, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 1, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 1, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 4, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 1, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 2, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 3, 3, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 3, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 1, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 8, 3, 6, 51, 867);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 2, 2, 5, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 5, 3, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4943, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 3, 3, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 4, 1, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 2, 2, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 4, 4, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 1, 4, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 8, 2, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 6, 1, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 2, 4, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4944, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 1, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 1, 2, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 2, 2, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 4, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 3, 5, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 3, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 2, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 3, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 2, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 3, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 4, 1, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 3, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 3, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 1, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 3, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 3, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 1, 1, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 1, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 1, 4, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 1, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 2, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 2, 6, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 1, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 3, 3, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 4, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 2, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 3, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 4, 2, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 8, 2, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 1, 1, 5, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 3, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 3, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 3, 2, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4945, 4, 4, 1, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 3, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 2, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 4, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 4, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 1, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 2, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 4, 3, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 2, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 4, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 3, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 1, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 4, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 3, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 4, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 2, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 3, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 1, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 6, 4, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 1, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 2, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 2, 4, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 3, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 4, 4, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 1, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 1, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 7, 3, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 4, 1, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4946, 2, 1, 6, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 4, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 2, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 1, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 3, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 3, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 3, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 4, 4, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 1, 5, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 1, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 4, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 3, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 2, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 4, 1, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 2, 6, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 1, 6, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 6, 3, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 2, 4, 2, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 1, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 1, 2, 3, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 7, 2, 6, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 3, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5028, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 2, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 3, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 7, 4, 4, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 7, 4, 5, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 2, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 2, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 2, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 4, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 1, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 2, 5, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 1, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 2, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 3, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 4, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 3, 2, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 3, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 3, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 4, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 3, 1, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 4, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 2, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 1, 2, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 4, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 5, 2, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 2, 6, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 1, 4, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 8, 4, 2, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 3, 1, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5029, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 6, 1, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 4, 3, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 1, 2, 2, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 6, 2, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 3, 1, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 4, 3, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5030, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 5, 4, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 8, 3, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 7, 4, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 4, 3, 6, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 5, 3, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 2, 4, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 8, 3, 3, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 7, 4, 1, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 8, 3, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5031, 3, 1, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 4, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 6, 3, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 6, 3, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 4, 2, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 1, 1, 1, 55, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 2, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 6, 3, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 1, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 1, 4, 4, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 4, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 1, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 8, 4, 3, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 8, 3, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 5, 2, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 2, 1, 1, 95, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 1, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 7, 2, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5032, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 4, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 2, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 2, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 1, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 3, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 2, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 4, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 1, 5, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 3, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 3, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 2, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 3, 5, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 2, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 3, 6, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 4, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 1, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 3, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 2, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 2, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 2, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 4, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 3, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 3, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 1, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 1, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 1, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 4, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 8, 3, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 1, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 3, 4, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 3, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 6, 3, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 7, 2, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 1, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 4, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 4, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 3, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5033, 5, 3, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 4, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 1, 5, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 2, 4, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 8, 4, 3, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 4, 2, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 2, 4, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 7, 3, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 2, 3, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 2, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 7, 4, 4, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 6, 3, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5113, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 2, 6, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 2, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 4, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 1, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 1, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 1, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 4, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 1, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 2, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 3, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 3, 3, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 2, 5, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 3, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 3, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 1, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 3, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 4, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 2, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 3, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 3, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 4, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 3, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 3, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 4, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 1, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 4, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 3, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 2, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 1, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 4, 3, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 6, 2, 3, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 4, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 7, 2, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 8, 2, 5, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5114, 5, 1, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 3, 1, 1, 23, 115);
commit;
prompt 169000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 5, 2, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 2, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 3, 3, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 8, 1, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 8, 3, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 2, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 5, 4, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 2, 1, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 3, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 1, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 3, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 1, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 2, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 6, 4, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 1, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 6, 2, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 1, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 4, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 3, 3, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5115, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 4, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 2, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 4, 1, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 3, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 1, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 3, 4, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 5, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 3, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 1, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 4, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 3, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 2, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 3, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 4, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 1, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 1, 2, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 4, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 3, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 1, 4, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 3, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 3, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 2, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 1, 1, 1, 6, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 7, 2, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 3, 2, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 5, 2, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5116, 6, 3, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 3, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 4, 3, 2, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 5, 2, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 3, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 8, 4, 3, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 3, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 5, 3, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 2, 6, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 3, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 4, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 7, 4, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 2, 3, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 2, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 1, 2, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5117, 1, 2, 5, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 2, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 1, 3, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 3, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 1, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 1, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 2, 3, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 4, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 4, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 1, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 3, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 1, 1, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 2, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 2, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 2, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 3, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 2, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 2, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 1, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 4, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 3, 2, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 1, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 1, 5, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 2, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 3, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 3, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 1, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 3, 3, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 1, 1, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 7, 1, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 2, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 4, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 2, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 3, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 2, 4, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 4, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 8, 1, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 4, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 4, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 2, 6, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 6, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 3, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 1, 4, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 3, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 2, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 3, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 3, 3, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 1, 3, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 1, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 4, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 2, 4, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5191, 6, 2, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 5, 3, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 4, 3, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 2, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 3, 5, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 6, 1, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 1, 6, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 4, 3, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 5, 4, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 3, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 1, 5, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 4, 3, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 4, 4, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5192, 8, 1, 2, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 8, 2, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 1, 1, 4, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 8, 3, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 6, 1, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 4, 1, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 5, 3, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 3, 3, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 1, 1, 6, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5193, 8, 1, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 3, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 4, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 2, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 7, 2, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 3, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 2, 1, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 4, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 1, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 2, 5, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 2, 2, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 3, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 2, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 4, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 4, 1, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 1, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 4, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 2, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 4, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 2, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 2, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 4, 3, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 2, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 7, 1, 1, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 3, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 1, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 3, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 2, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 2, 1, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 5, 1, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 1, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 1, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 1, 3, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 3, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 4, 4, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 3, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 3, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 8, 4, 3, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5194, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 3, 1, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 6, 2, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 4, 6, 17, 289);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 4, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 4, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 3, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 1, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 1, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 6, 2, 2, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 4, 4, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 1, 5, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 2, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 4, 1, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 1, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 4, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 3, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 4, 3, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 2, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 1, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 1, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 1, 3, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 3, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 4, 1, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 2, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 6, 3, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 1, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 2, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 3, 2, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 4, 6, 19, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 2, 5, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 1, 6, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 1, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 6, 3, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 3, 6, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 1, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 3, 1, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 4, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 1, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 7, 2, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 8, 2, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 3, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 1, 2, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5195, 5, 4, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 1, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 4, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 3, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 4, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 4, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 1, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 4, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 4, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 4, 5, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 2, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 2, 2, 3, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 2, 3, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 2, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 4, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 3, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 1, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 4, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 2, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 7, 2, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 2, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 2, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 4, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 1, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 4, 1, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 3, 2, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 1, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 2, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 5, 2, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 3, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 5, 3, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 6, 3, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 3, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 1, 2, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 4, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 1, 4, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 7, 1, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 1, 4, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 7, 2, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 3, 3, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 5, 2, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4947, 2, 1, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 1, 4, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 2, 1, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 6, 3, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 4, 3, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 8, 4, 3, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 3, 2, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 2, 2, 4, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 8, 1, 5, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 5, 2, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4948, 5, 1, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 2, 3, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 1, 5, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 2, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 6, 2, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 2, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 1, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 1, 3, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 7, 2, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 5, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 1, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 2, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 1, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 6, 3, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 2, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 4, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 2, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 4, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 6, 2, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 3, 3, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 1, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 2, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 2, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 2, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 8, 2, 4, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 7, 4, 3, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 4, 3, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4949, 7, 1, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 1, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 4, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 2, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 4, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 1, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 1, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 3, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 1, 3, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 2, 3, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 1, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 4, 1, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 4, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 6, 3, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 2, 1, 3, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 3, 1, 5, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 1, 4, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 1, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 2, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 1, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 6, 2, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 5, 1, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 6, 2, 3, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4950, 1, 4, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 4, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 3, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 4, 1, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 2, 2, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 1, 2, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 1, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 3, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 2, 4, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 2, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 8, 2, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 3, 4, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 3, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 7, 4, 5, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 8, 4, 5, 82, 1394);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 4, 3, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 1, 1, 4, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 2, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 1, 1, 3, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 5, 2, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 4, 2, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4951, 6, 4, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 1, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 3, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 6, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 1, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 3, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 1, 6, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 1, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 2, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 3, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 4, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 3, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 3, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 1, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 2, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 2, 29, 116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 1, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 3, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 1, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 1, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 4, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 2, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 3, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 4, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 3, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 1, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 2, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 8, 1, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5034, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 4, 3, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 8, 2, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 7, 4, 3, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 7, 2, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 8, 3, 3, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 2, 3, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 1, 4, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5035, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 2, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 3, 1, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 7, 2, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 7, 3, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 4, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 2, 5, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 2, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 2, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 3, 3, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 4, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 6, 1, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 8, 3, 5, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 3, 2, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 3, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 3, 4, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 4, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 3, 4, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 2, 3, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 3, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 5, 2, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 1, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 6, 2, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 8, 4, 2, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 7, 1, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 1, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 1, 2, 4, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5036, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 8, 2, 2, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 6, 4, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 2, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 4, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 8, 2, 4, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 6, 3, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 2, 4, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 2, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 5, 2, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 1, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 2, 1, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 1, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 1, 4, 2, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 6, 1, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 2, 4, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 4, 3, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 5, 1, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 1, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 2, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 1, 1, 1, 23, 69);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 2, 1, 6, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5037, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 8, 4, 6, 84, 1512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 2, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 8, 2, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 1, 4, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 2, 2, 3, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 8, 1, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 1, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 2, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 4, 2, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 4, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 8, 4, 3, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 1, 4, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 1, 3, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 2, 3, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5038, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 4, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 2, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 3, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 7, 4, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 3, 4, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 3, 1, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 1, 4, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 7, 4, 2, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 1, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 3, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 3, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 2, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 2, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 5, 2, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 4, 1, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 7, 3, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 1, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 3, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 7, 4, 6, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 4, 2, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5039, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 3, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 1, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 2, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 2, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 2, 1, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 4, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 2, 3, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 3, 3, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 3, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 1, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 2, 3, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 8, 2, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 1, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 3, 2, 79, 711);
commit;
prompt 170000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 4, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 3, 4, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 3, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 2, 1, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 1, 2, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 2, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 6, 3, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 3, 4, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 1, 4, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 4, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 7, 3, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5040, 4, 3, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 4, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 4, 2, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 3, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 2, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 2, 6, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 4, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 3, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 3, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 3, 3, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 2, 2, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 2, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 1, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 3, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 2, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 5, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 2, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 3, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 1, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 1, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 1, 3, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 2, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 4, 3, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 3, 3, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 1, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 4, 3, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 2, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 1, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 5, 2, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 4, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 1, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 3, 4, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 6, 4, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 2, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 4, 1, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 8, 3, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 7, 2, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 2, 2, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5118, 1, 2, 1, 82, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 2, 1, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 2, 1, 6, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 4, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 5, 1, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 3, 4, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 1, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 4, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 4, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 5, 4, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 2, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 4, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 1, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 3, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 8, 3, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 3, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 5, 3, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 4, 6, 19, 323);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 6, 3, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 2, 2, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5119, 7, 3, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 3, 6, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 1, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 2, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 1, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 1, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 4, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 1, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 2, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 1, 1, 64, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 3, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 4, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 3, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 2, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 2, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 2, 6, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 1, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 2, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 5, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 1, 6, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 3, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 3, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 2, 3, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 1, 2, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 5, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 3, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 2, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 3, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 1, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 2, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 2, 2, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 1, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 3, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 1, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 1, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 5, 1, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 7, 1, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 1, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 4, 1, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 4, 1, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 3, 3, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 8, 2, 6, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5120, 6, 4, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 2, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 3, 5, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 2, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 2, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 3, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 2, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 4, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 1, 1, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 1, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 4, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 4, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 3, 4, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 2, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 6, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 3, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 4, 4, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 3, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 3, 1, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 3, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 4, 2, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 2, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 4, 4, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 4, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 1, 6, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 3, 4, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 1, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 1, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 2, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 1, 4, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 1, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 4, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 2, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 7, 1, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 4, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 3, 2, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 4, 1, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 2, 1, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 6, 3, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5121, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 2, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 2, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 2, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 2, 2, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 1, 1, 5, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 4, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 1, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 1, 4, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 4, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 2, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 1, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 2, 4, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 4, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 4, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 2, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 2, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 7, 4, 4, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 2, 1, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 3, 4, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 2, 3, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 2, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 1, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 1, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 4, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 3, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 1, 2, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 2, 4, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 5, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 3, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 4, 4, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 2, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 3, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 8, 1, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 1, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 3, 2, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 2, 5, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 4, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 1, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 1, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 3, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 2, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 3, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 3, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 1, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 3, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 8, 4, 6, 44, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 2, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 4, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 3, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 4, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 2, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 2, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 4, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 4, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 1, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 2, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 4, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 4, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 3, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 1, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 3, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 2, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 3, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 3, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 4, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 4, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 4, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 6, 3, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 1, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 3, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5201, 1, 2, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 1, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 4, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 1, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 4, 1, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 7, 4, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 3, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 4, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 2, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 1, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 1, 1, 39, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 4, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 1, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 4, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 2, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 3, 4, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 4, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 2, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 4, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 3, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 2, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 2, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 7, 4, 5, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 2, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 3, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 3, 3, 1, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5203, 2, 1, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 4, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 2, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 1, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 2, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 1, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 2, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 1, 6, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 3, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 3, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 4, 4, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 2, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 2, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 3, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 1, 5, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 1, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 2, 3, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 3, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 2, 1, 90, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 4, 6, 66, 1122);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 2, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 4, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 1, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 1, 4, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 2, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 2, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 1, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 3, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 2, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 3, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 2, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 1, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 4, 5, 14, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 1, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 4, 2, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 4, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 8, 3, 6, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 4, 2, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 6, 3, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 3, 1, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 2, 2, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5204, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 1, 6, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 3, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 2, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 2, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 6, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 4, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 1, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 1, 6, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 1, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 4, 1, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 4, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 3, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 2, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 1, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 3, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 4, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 2, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 4, 2, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 2, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 3, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 2, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 3, 4, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 3, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 3, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 3, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 4, 1, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 3, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 4, 3, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 4, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 2, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 4, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 4, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 1, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 2, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 4, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 4, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 1, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 3, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 1, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 4, 1, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 1, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 4, 2, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 4, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 2, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 5, 3, 4, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4952, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 1, 1, 33, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 4, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 1, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 3, 6, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 4, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 1, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 4, 5, 77, 1309);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 4, 2, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 4, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 4, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 3, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 2, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 4, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 1, 6, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 2, 1, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 4, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 3, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 4, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 2, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 2, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 3, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 4, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 3, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 2, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 3, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 1, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 2, 3, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 1, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 3, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 2, 3, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 4, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 2, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 1, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 1, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 3, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 4, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 3, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 5, 4, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 3, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 1, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 2, 6, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 4, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 2, 3, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 3, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 1, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 7, 3, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4953, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 3, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 6, 1, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 4, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 7, 4, 5, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 8, 4, 1, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 4, 5, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 5, 2, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 3, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 4, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 1, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 6, 3, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 2, 2, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 5, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 6, 3, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 4, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 2, 3, 6, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 1, 5, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 8, 3, 6, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 8, 3, 4, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4954, 1, 1, 6, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 1, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 1, 5, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 4, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 1, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 4, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 3, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 4, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 1, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 4, 3, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 2, 4, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 3, 4, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 3, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 6, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 2, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 1, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 3, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 4, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 3, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 1, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 1, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 4, 3, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 1, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 3, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 2, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 3, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 4, 2, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 1, 2, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 2, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 4, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 2, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 3, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 4, 1, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 4, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 1, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 4, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 4, 2, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 3, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 3, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 8, 2, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 3, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 1, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 1, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 2, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 6, 2, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 3, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 5, 2, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 3, 2, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4955, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 1, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 4, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 1, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 4, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 2, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 4, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 3, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 4, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 3, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 3, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 2, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 1, 4, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 3, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 2, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 1, 1, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 1, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 4, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 4, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 5, 4, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 2, 5, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 4, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 1, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 3, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 3, 4, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 6, 1, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 8, 2, 1, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5041, 2, 4, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 7, 4, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 2, 2, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 7, 2, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 7, 3, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 5, 4, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 2, 4, 4, 93, 930);
commit;
prompt 171000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 6, 4, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 3, 2, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 5, 1, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 6, 4, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 4, 4, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 4, 1, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5042, 2, 2, 5, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 4, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 2, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 3, 2, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 1, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 3, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 2, 3, 28, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 8, 2, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 1, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 3, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 2, 1, 3, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 3, 5, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 3, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 8, 3, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 2, 2, 4, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 2, 4, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 2, 4, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 4, 3, 6, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 4, 6, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 4, 5, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 2, 3, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 3, 3, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 1, 4, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 3, 1, 2, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 3, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 5, 2, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5043, 7, 2, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 1, 1, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 1, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 6, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 3, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 4, 4, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 2, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 4, 6, 45, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 1, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 1, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 2, 3, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 2, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 4, 2, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 2, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 1, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 4, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 4, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 3, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 1, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 2, 2, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 4, 1, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 4, 5, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 4, 5, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 4, 1, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 4, 4, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 4, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 3, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 4, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 4, 1, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 1, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 5, 4, 3, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 2, 3, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 2, 1, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 1, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 2, 4, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5044, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 2, 3, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 3, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 4, 6, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 3, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 2, 4, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 2, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 6, 3, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 4, 3, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 1, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 4, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 4, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 2, 4, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 3, 4, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 2, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 2, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 1, 6, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 1, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 2, 2, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 3, 1, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 4, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 3, 5, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 6, 2, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 4, 1, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 2, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 1, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 3, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 1, 5, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 2, 1, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 1, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 7, 1, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 2, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 1, 2, 84, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 1, 3, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5045, 5, 3, 1, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 1, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 4, 5, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 1, 6, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 1, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 1, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 3, 4, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 4, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 4, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 4, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 2, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 1, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 1, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 1, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 3, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 4, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 2, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 4, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 4, 2, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 3, 5, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 2, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 4, 6, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 3, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 2, 5, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 4, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 1, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 1, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 2, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 7, 4, 2, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 1, 4, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 6, 3, 3, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 1, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 5, 4, 4, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 1, 2, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 3, 4, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5122, 3, 4, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 3, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 3, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 2, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 2, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 2, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 4, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 2, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 1, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 2, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 4, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 3, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 4, 1, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 2, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 3, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 1, 6, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 1, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 2, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 3, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 3, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 1, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 4, 4, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 1, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 4, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 2, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 1, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 3, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 1, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 1, 1, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 1, 5, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 2, 2, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 2, 1, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 2, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 2, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 2, 4, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 6, 2, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 3, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 2, 2, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 3, 4, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 3, 5, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 3, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 4, 1, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5123, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 1, 1, 4, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 4, 1, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 1, 3, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 8, 2, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 6, 1, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 4, 3, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 7, 3, 3, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 1, 3, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 1, 3, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 6, 4, 6, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5124, 3, 3, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 4, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 1, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 3, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 1, 5, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 3, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 2, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 2, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 4, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 2, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 2, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 1, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 1, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 4, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 3, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 4, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 4, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 2, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 4, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 1, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 4, 5, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 3, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 4, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 3, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 1, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 4, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 4, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 3, 2, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 2, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 2, 3, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 3, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 1, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 3, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 4, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 3, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 1, 4, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 2, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 2, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 2, 1, 25, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 3, 2, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 1, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 2, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 2, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 1, 2, 54, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 8, 2, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 4, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 3, 2, 1, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 4, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 2, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 7, 4, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 5, 1, 4, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5125, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 1, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 4, 3, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 5, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 3, 5, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 5, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 1, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 1, 5, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 3, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 3, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 2, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 2, 3, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 3, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 3, 5, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 4, 5, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 3, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 1, 3, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 4, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 3, 1, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 4, 4, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 4, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 2, 6, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 1, 1, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 2, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 5, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 4, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 3, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 4, 1, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 2, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 3, 2, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 3, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 1, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 1, 2, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 3, 5, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 5, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 2, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 6, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 1, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 2, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 1, 4, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 4, 4, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 1, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 3, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 4, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 2, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 1, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 1, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 2, 2, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 1, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 6, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 3, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 4, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 3, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 3, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 2, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 4, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 1, 6, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 4, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 5, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 1, 5, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 3, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 1, 2, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 1, 3, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 2, 5, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 2, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 3, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 4, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 1, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 2, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 1, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 2, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 2, 1, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 4, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 3, 1, 2, 56, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 2, 4, 6, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5212, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 3, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 6, 1, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 2, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 7, 1, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 4, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 4, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 2, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 3, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 8, 1, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 4, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 2, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 1, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 1, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 3, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 7, 1, 3, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 1, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 4, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 3, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 1, 3, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 1, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 4, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 1, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 1, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 7, 3, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 8, 2, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 1, 3, 1, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 6, 1, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 2, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 6, 1, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5213, 3, 4, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 4, 2, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 2, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 3, 4, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 2, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 2, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 4, 4, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 2, 1, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 3, 2, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 2, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 3, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 3, 2, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 4, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 1, 2, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 1, 5, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 1, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 1, 1, 11, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 3, 3, 1, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 1, 3, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 3, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 1, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 2, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 2, 1, 97, 485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 4, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 4, 1, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 8, 4, 5, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 2, 3, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 4, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 1, 4, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 1, 2, 67, 268);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 3, 1, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 1, 2, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 8, 1, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 1, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 6, 1, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 8, 3, 2, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 5, 4, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 2, 2, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5214, 7, 2, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 1, 4, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 4, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 1, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 7, 3, 6, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 1, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 1, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 3, 1, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 2, 5, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 3, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 1, 4, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 3, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 3, 2, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 2, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 1, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 1, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 1, 5, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 1, 5, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 2, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 3, 3, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 7, 4, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 1, 5, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 2, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 4, 6, 29, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 3, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 7, 2, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 4, 6, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 2, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 2, 4, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 4, 1, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 5, 1, 3, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5215, 1, 1, 6, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 3, 3, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 3, 2, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 1, 2, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 2, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 3, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 3, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 4, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 2, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 3, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 3, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 2, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 3, 5, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 2, 5, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 4, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 3, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 5, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 1, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 4, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 4, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 3, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 4, 1, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 1, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 3, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 2, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 4, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 1, 3, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 2, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 1, 5, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 2, 3, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 3, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 1, 2, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 3, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 3, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 4, 6, 56, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 3, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 4, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 2, 6, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 1, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 2, 4, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 4, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 5, 1, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 4, 4, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 1, 14, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 2, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 7, 3, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 2, 1, 2, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 1, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 1, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 3, 4, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4956, 8, 1, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 2, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 2, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 4, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 3, 2, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 2, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 1, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 3, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 4, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 4, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 1, 3, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 1, 1, 66, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 4, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 3, 6, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 3, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 1, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 4, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 2, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 3, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 3, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 2, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 2, 2, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 4, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 4, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 3, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 4, 6, 70, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 2, 3, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 2, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 1, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 4, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 3, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 2, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 3, 6, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 2, 1, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 3, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 3, 2, 5, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 3, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 4, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 4, 6, 58, 986);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 1, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 2, 4, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 1, 3, 4, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 4, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 2, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 8, 1, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 4, 3, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 2, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4957, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 2, 1, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 8, 4, 2, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 3, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 3, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 3, 2, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 3, 3, 3, 23, 207);
commit;
prompt 172000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 3, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 8, 2, 2, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 1, 2, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 6, 3, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 4, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 5, 3, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 1, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 2, 1, 2, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 6, 4, 1, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 3, 1, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 8, 1, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 7, 4, 5, 5, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 1, 3, 2, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4958, 6, 2, 4, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 1, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 1, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 3, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 4, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 7, 1, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 2, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 4, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 1, 3, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 1, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 1, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 2, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 3, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 1, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 3, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 7, 2, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 1, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 7, 1, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 1, 5, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 1, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 2, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 1, 5, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 3, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 4, 2, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 1, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 2, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 2, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 1, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 2, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 2, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 8, 2, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 1, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 1, 3, 4, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 4, 3, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 2, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4959, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 4, 2, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 1, 2, 80, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 2, 1, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 3, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 4, 4, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 4, 3, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 1, 5, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 6, 1, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 2, 1, 5, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 1, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 2, 6, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 2, 4, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 4, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 1, 6, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 4, 4, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 1, 6, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 8, 3, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 1, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 3, 4, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 1, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 3, 4, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 4, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 4, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 3, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 6, 4, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 5, 3, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 3, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 4, 2, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5046, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 5, 4, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 7, 3, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 7, 1, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 8, 2, 6, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 2, 2, 2, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 3, 4, 5, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 8, 4, 4, 74, 1184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 4, 3, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 8, 2, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5047, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 2, 2, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 4, 3, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 3, 3, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 2, 2, 4, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 4, 3, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 2, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 4, 4, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 5, 1, 4, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 3, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 5, 1, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 2, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 3, 1, 1, 1, 5);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 3, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 4, 6, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 1, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 4, 2, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 6, 4, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 7, 2, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 5, 4, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 1, 4, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 7, 1, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 2, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 8, 2, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5048, 1, 2, 2, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 2, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 3, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 1, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 2, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 4, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 2, 4, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 1, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 2, 6, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 2, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 4, 2, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 1, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 4, 4, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 2, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 4, 3, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 4, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 1, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 4, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 1, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 2, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 4, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 1, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 1, 6, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 1, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 3, 4, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 2, 4, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 4, 2, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 4, 6, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 3, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 3, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 4, 2, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 1, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 2, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 2, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 2, 2, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 3, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 3, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 2, 4, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 3, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 4, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 1, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 2, 1, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 4, 6, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 1, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 1, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 3, 1, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 3, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 2, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 8, 3, 3, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 3, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 2, 1, 4, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 7, 4, 4, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 3, 1, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5049, 6, 3, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 1, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 4, 3, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 1, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 3, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 2, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 1, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 2, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 2, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 3, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 2, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 3, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 2, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 1, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 4, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 3, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 4, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 2, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 3, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 1, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 3, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 4, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 3, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 4, 6, 50, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 2, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 1, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 1, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 3, 1, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 1, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 1, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 3, 1, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 3, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 3, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 3, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 1, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 2, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 1, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 3, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 3, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 2, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 6, 3, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 4, 3, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 2, 4, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 3, 1, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 4, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 5, 1, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 1, 4, 4, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 1, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 7, 2, 5, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5050, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 1, 3, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 3, 2, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 2, 1, 3, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 4, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 2, 6, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 8, 3, 3, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 2, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 4, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 3, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 4, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 1, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 2, 3, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 4, 1, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 4, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 3, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 8, 3, 5, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 3, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 1, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 3, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 4, 2, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 1, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 2, 4, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 4, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 1, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 2, 1, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 3, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 2, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 1, 2, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 1, 3, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 3, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 6, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 1, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 1, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 3, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 2, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 1, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 4, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 1, 3, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 3, 4, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 3, 1, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 1, 6, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 3, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 4, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 1, 3, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5126, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 2, 3, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 8, 3, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 3, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 4, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 1, 2, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 1, 5, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 3, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 4, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 6, 1, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 8, 3, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 1, 3, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 2, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 2, 4, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 4, 1, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 4, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 4, 4, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 2, 5, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 4, 3, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 3, 4, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 8, 1, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 8, 1, 3, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 2, 4, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 6, 3, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 4, 4, 5, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 2, 3, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 1, 3, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 1, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 2, 1, 6, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 6, 2, 4, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5127, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 2, 1, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 2, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 2, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 1, 3, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 3, 5, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 2, 4, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 1, 3, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 1, 6, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 3, 6, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 1, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 6, 4, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 1, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 6, 3, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 4, 3, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 4, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 4, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 3, 3, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 1, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 3, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 1, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 4, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 1, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 6, 4, 2, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 2, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 2, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 7, 4, 3, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 3, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 1, 3, 3, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5128, 5, 4, 4, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 1, 4, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 3, 1, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 8, 4, 3, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 4, 2, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 3, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 7, 4, 1, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 5, 1, 4, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 3, 2, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 3, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 7, 2, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 2, 4, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 3, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 5, 3, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 2, 1, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 3, 1, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 6, 1, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 3, 1, 2, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 4, 1, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 1, 1, 2, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5129, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 3, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 8, 3, 5, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 2, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 4, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 1, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 2, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 3, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 2, 5, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 2, 3, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 3, 4, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 3, 3, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 8, 2, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 2, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 1, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 1, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 4, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 4, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 2, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 1, 1, 4, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 4, 3, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 3, 2, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 3, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 2, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 5, 2, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 3, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 7, 2, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 1, 1, 1, 18, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 1, 1, 1, 98, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 2, 2, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 3, 3, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 4, 4, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5130, 3, 2, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 1, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 4, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 2, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 6, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 1, 2, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 6, 82, 1312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 4, 3, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 4, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 2, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 3, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 6, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 1, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 3, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 4, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 3, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 3, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 3, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 3, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 1, 1, 7, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 4, 6, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 3, 5, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 2, 6, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 4, 2, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 4, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 5, 1, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 2, 5, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 3, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 2, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 2, 1, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5196, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 6, 1, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 2, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 4, 2, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 2, 1, 1, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 1, 1, 6, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 2, 1, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 3, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 4, 1, 2, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 6, 3, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 4, 4, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 4, 3, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 6, 1, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 1, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 5, 1, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 3, 2, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 4, 2, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 1, 4, 3, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 2, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 8, 3, 4, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 3, 3, 6, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 5, 3, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 2, 1, 3, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 7, 4, 6, 29, 493);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5197, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 4, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 2, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 1, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 4, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 2, 2, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 3, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 1, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 1, 3, 3, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 1, 3, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 3, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 1, 6, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 4, 6, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 2, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 4, 5, 23, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 3, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 4, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 4, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 2, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 2, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 2, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 1, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 2, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 4, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 4, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 3, 2, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 1, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 3, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 1, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 4, 1, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 2, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 2, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 4, 2, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 4, 3, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 3, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 4, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 4, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 1, 2, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 4, 4, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 3, 1, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 3, 1, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 4, 6, 24, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 4, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 3, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 1, 3, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 7, 2, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5198, 6, 4, 5, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 1, 6, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 4, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 4, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 2, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 3, 6, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 6, 3, 4, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 3, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 2, 3, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 6, 2, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 4, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 2, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 3, 2, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 2, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 4, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 1, 6, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 1, 2, 100, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 3, 4, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 3, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 2, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 4, 2, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 1, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 3, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 1, 2, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 1, 6, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 3, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 1, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 2, 1, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 2, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 4, 4, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 8, 2, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 3, 2, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 2, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 3, 3, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 1, 3, 5, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 4, 2, 5, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 7, 2, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5199, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 4, 4, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 4, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 2, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 3, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 3, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 3, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 1, 6, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 1, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 3, 1, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 6, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 1, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 1, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 4, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 4, 6, 77, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 4, 6, 72, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 6, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 4, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 3, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 3, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 4, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 3, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 3, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 4, 5, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 4, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 1, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 2, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 2, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 1, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 2, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 2, 4, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 3, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 2, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 2, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 2, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 2, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 4, 1, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 4, 2, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 2, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 4, 1, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 1, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 2, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 2, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 3, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 6, 2, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 8, 3, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 4, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 4, 1, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 2, 2, 3, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 5, 4, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5200, 3, 3, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 1, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 3, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 1, 6, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 2, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 6, 4, 6, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 1, 2, 53, 530);
commit;
prompt 173000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 4, 3, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 1, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 4, 6, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 6, 4, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 1, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 3, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 1, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 4, 1, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 2, 3, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 7, 4, 1, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 6, 2, 4, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4960, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 1, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 3, 1, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 1, 2, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 3, 5, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 3, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 1, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 2, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 3, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 1, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 4, 3, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 4, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 4, 1, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 3, 2, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 2, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 2, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 3, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 1, 4, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 1, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 2, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 3, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 3, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 3, 6, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 3, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 3, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 4, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 1, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 4, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 3, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 1, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 2, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 3, 4, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 3, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 4, 4, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 2, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 2, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 2, 1, 78, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 3, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 2, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 4, 2, 1, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 8, 2, 4, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 3, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4961, 1, 2, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 2, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 1, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 3, 6, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 1, 3, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 4, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 1, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 2, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 3, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 4, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 4, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 4, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 4, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 2, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 3, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 4, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 1, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 3, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 1, 3, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 1, 6, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 3, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 4, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 3, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 1, 1, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 4, 2, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 3, 3, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 1, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 4, 6, 20, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 4, 3, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 1, 1, 1, 65, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 2, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 2, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 3, 2, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 4, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 2, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 3, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 1, 1, 2, 76, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 4, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 6, 2, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 7, 4, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 1, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 4, 3, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 5, 1, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4962, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 2, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 5, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 2, 5, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 2, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 4, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 1, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 2, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 4, 3, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 3, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 1, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 3, 1, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 4, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 3, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 2, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 1, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 4, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 4, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 1, 3, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 3, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 1, 5, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 3, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 3, 5, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 3, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 5, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 6, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 1, 1, 9, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 6, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 3, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 2, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 1, 6, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 1, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 2, 1, 5, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 1, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 8, 3, 5, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 4, 4, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 4, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 3, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 1, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 4, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 7, 2, 4, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 6, 1, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5051, 1, 2, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 4, 1, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 3, 1, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 8, 1, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 4, 4, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 3, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 3, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 2, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 3, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 1, 4, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 6, 4, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 2, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 2, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 4, 5, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 7, 4, 4, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 4, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 4, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 1, 1, 4, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 4, 6, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 1, 4, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 3, 2, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 2, 3, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5052, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 2, 1, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 8, 1, 3, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 7, 1, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 5, 3, 3, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 5, 3, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 7, 1, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 1, 1, 33, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 6, 2, 1, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 3, 4, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 5, 4, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 2, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 4, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 1, 6, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5053, 1, 3, 6, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 4, 3, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 5, 2, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 4, 3, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 8, 4, 1, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 4, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 6, 4, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 2, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 6, 4, 6, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 7, 4, 5, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 7, 1, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 7, 4, 4, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 5, 3, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 3, 6, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 8, 2, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 2, 2, 1, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 5, 4, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 2, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 4, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 2, 2, 2, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 3, 1, 2, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5054, 1, 4, 5, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 1, 4, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 8, 1, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 4, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 6, 4, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 1, 4, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 3, 2, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 2, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 5, 4, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 3, 1, 1, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 2, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 3, 4, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 4, 1, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 8, 3, 5, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 2, 4, 1, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 4, 3, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 8, 2, 1, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 2, 1, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 5, 4, 4, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 2, 1, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 8, 2, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5055, 3, 1, 4, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 8, 4, 5, 61, 1037);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 5, 2, 6, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 4, 4, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 6, 4, 5, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 6, 3, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 5, 1, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 1, 3, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 8, 2, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 4, 2, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 7, 2, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 6, 1, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 1, 3, 1, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5056, 8, 3, 6, 21, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 5, 1, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 7, 4, 6, 40, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 3, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 6, 4, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 7, 1, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 8, 2, 1, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 4, 4, 2, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 1, 3, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 4, 4, 6, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 7, 3, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 3, 3, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 6, 3, 3, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 2, 2, 2, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 4, 1, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5057, 5, 1, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 3, 5, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 4, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 4, 4, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 7, 2, 2, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 3, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 2, 5, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 7, 1, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 2, 6, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 4, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 1, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 1, 6, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 3, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 3, 5, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 4, 3, 6, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 3, 3, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 1, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 2, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 3, 6, 99, 1683);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 1, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 1, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 4, 2, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 2, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 1, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 5, 3, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 4, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 4, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 2, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 1, 2, 4, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 3, 2, 2, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5058, 2, 4, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 1, 4, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 1, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 1, 6, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 3, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 3, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 4, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 4, 4, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 1, 2, 97, 388);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 2, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 3, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 3, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 4, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 2, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 3, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 4, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 4, 2, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 2, 2, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 4, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 1, 5, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 4, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 4, 2, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 4, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 1, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 2, 5, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 1, 6, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 3, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 3, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 3, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 3, 6, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 5, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 3, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 1, 5, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 5, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 1, 4, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 4, 1, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 4, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 4, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 1, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 4, 4, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 2, 5, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 1, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 1, 6, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 4, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 4, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 6, 86, 1548);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 4, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 1, 1, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 4, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 3, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 4, 6, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 4, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 6, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 2, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 6, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 2, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 4, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 6, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 4, 2, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 2, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 3, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 6, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 1, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 4, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 3, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 1, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 4, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 3, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 2, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 1, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 1, 2, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 1, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 1, 2, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 4, 4, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 4, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 1, 3, 3, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 5, 2, 4, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 2, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 3, 3, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5131, 7, 1, 5, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 1, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 3, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 1, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 4, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 2, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 1, 4, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 4, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 1, 5, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 1, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 1, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 6, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 1, 4, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 2, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 2, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 4, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 2, 2, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 1, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 4, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 2, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 3, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 4, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 6, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 2, 1, 45, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 3, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 2, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 2, 1, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 3, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 3, 5, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 4, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 4, 4, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 1, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 1, 4, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 2, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 1, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 2, 4, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 8, 4, 4, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 4, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 3, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 2, 2, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 1, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 1, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 4, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 4, 1, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 3, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5132, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 2, 4, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 1, 1, 3, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 5, 4, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 1, 1, 4, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 8, 3, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 3, 4, 5, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 8, 1, 3, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 3, 5, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 2, 3, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 7, 1, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 1, 3, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 4, 1, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 5, 1, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 1, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 4, 4, 3, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 7, 3, 1, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 5, 1, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 2, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 3, 1, 6, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 2, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 8, 4, 2, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 6, 4, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5133, 8, 3, 3, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 7, 2, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 3, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 2, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 7, 2, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 4, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 4, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 4, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 3, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 1, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 2, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 7, 4, 5, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 1, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 1, 6, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 3, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 3, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 3, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 2, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 1, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 2, 2, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 4, 6, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 2, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 2, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 1, 1, 73, 219);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 1, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 3, 1, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 1, 4, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 1, 3, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 3, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 3, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 4, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 4, 2, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 3, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 2, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 3, 2, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 4, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 3, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 3, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 1, 1, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 1, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 2, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 4, 2, 2, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 3, 4, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 6, 1, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 1, 4, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 4, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 3, 2, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 1, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 4, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 8, 1, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5205, 5, 2, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 1, 2, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 2, 1, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 8, 3, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 2, 4, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 2, 3, 5, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 3, 2, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 5, 4, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 7, 2, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 8, 1, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 3, 1, 2, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5206, 2, 4, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 2, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 2, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 5, 2, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 8, 4, 6, 39, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 2, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 5, 4, 3, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 4, 2, 1, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 4, 3, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 8, 4, 4, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 2, 2, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 2, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 1, 2, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 2, 1, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 2, 3, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 2, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 2, 1, 5, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 1, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 3, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 4, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 7, 1, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5207, 3, 1, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 4, 1, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 1, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 4, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 2, 1, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 2, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 2, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 3, 2, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 1, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 2, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 3, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 2, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 3, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 3, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 1, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 2, 3, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 1, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 2, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 4, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 2, 3, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 2, 6, 11, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 2, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 2, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 3, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 4, 1, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 4, 6, 27, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 2, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 3, 6, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 4, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 4, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 1, 5, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 2, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 1, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 1, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 1, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 3, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 3, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 1, 5, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 1, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 1, 6, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 6, 2, 5, 65, 845);
commit;
prompt 174000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 7, 4, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 3, 3, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 8, 2, 6, 99, 1584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 2, 4, 5, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5208, 5, 1, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 7, 1, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 5, 4, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 5, 4, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 7, 1, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 6, 2, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 4, 1, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 6, 4, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 4, 2, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 5, 1, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 7, 1, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5209, 7, 1, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 8, 1, 2, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 8, 2, 6, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 3, 4, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 4, 3, 4, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 7, 4, 2, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 8, 3, 5, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 6, 4, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 8, 2, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 1, 2, 2, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5210, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 3, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 2, 3, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 3, 5, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 3, 2, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 1, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 2, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 1, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 4, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 1, 2, 66, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 2, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 2, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 6, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 3, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 1, 6, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 1, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 1, 5, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 1, 5, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 1, 6, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 1, 6, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 3, 5, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 2, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 4, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 5, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 3, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 2, 6, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 2, 2, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 4, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 1, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 2, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 2, 4, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 4, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 2, 5, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 3, 6, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 1, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 2, 1, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 3, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 3, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 1, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 2, 2, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 3, 2, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 1, 5, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 1, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 4, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 3, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 2, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 6, 3, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 8, 1, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 2, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 1, 1, 4, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 1, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 5, 4, 6, 1, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 2, 5, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5211, 2, 3, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 1, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 5, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 2, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 2, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 4, 5, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 2, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 1, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 1, 3, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 4, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 6, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 2, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 2, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 1, 1, 70, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 2, 3, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 4, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 1, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 1, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 5, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 1, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 3, 2, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 2, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 5, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 4, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 4, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 1, 5, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 3, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 3, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 1, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 3, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 4, 3, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 1, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 1, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 1, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 2, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 4, 1, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 5, 2, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 3, 4, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 2, 2, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 8, 2, 3, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 2, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4963, 7, 1, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 3, 6, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 2, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 1, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 2, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 1, 2, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 3, 6, 6, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 1, 6, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 1, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 2, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 4, 1, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 4, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 1, 6, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 4, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 1, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 2, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 2, 6, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 1, 4, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 3, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 2, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 2, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 3, 6, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 3, 3, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 4, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 2, 1, 48, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 3, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 2, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 1, 4, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 1, 6, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 3, 2, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 4, 2, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 1, 1, 53, 212);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 3, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 4, 6, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 3, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 1, 3, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 1, 5, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 3, 4, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 1, 2, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 2, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 2, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 4, 3, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 2, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 1, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 3, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 1, 2, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 4, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 2, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 2, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 2, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 4, 2, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 1, 3, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 3, 1, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 1, 2, 1, 6);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 1, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 2, 4, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 3, 1, 1, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 3, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 5, 4, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 8, 2, 1, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 7, 4, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4964, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 2, 3, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 4, 1, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 3, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 2, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 2, 2, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 3, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 4, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 1, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 3, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 3, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 2, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 3, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 2, 2, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 4, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 5, 2, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 2, 4, 1, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 4, 5, 69, 1173);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 1, 5, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 4, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 2, 2, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 4, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 1, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 2, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 1, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 2, 4, 1, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 2, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 1, 6, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 3, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 2, 2, 56, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 3, 4, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 3, 1, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 1, 3, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 6, 2, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 7, 4, 4, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4965, 8, 2, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 1, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 2, 1, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 2, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 2, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 1, 6, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 2, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 4, 4, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 1, 4, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 3, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 3, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 3, 1, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 1, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 1, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 1, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 2, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 1, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 2, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 2, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 1, 2, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 3, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 4, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 1, 3, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 3, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 4, 5, 30, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 2, 2, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 4, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 1, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 1, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 4, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 3, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 2, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 3, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 2, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 4, 3, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 1, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 2, 2, 83, 498);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 1, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 4, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 2, 2, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 3, 4, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 2, 1, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 4, 2, 6, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 2, 1, 81, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 6, 1, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 5, 3, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 3, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 8, 2, 2, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 2, 4, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5059, 7, 2, 4, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 4, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 3, 4, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 3, 2, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 6, 3, 1, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 1, 1, 5, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 6, 2, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 1, 1, 4, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 8, 2, 3, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 2, 4, 3, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 7, 1, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 3, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 6, 4, 1, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 2, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 3, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 1, 2, 1, 50, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 4, 5, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 3, 2, 6, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 4, 2, 6, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 2, 2, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 8, 4, 1, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 2, 2, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 2, 4, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5060, 1, 2, 6, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 1, 1, 51, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 3, 3, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 3, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 1, 2, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 5, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 3, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 3, 5, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 1, 5, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 4, 1, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 2, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 4, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 1, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 2, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 4, 1, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 4, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 3, 1, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 3, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 4, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 2, 2, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 5, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 5, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 2, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 4, 1, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 1, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 4, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 1, 2, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 4, 5, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 3, 1, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 3, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 3, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 4, 4, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 1, 5, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 6, 1, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 3, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 4, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 6, 1, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 1, 1, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 2, 2, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 2, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 4, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 3, 6, 7, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 2, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 4, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 4, 2, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 2, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 2, 4, 4, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 4, 6, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 1, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 6, 3, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 7, 3, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5061, 3, 4, 5, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 2, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 4, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 2, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 1, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 4, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 1, 2, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 1, 2, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 1, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 1, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 3, 2, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 3, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 3, 6, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 4, 5, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 2, 1, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 3, 5, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 3, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 8, 1, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 3, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 4, 4, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 2, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 6, 3, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 3, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 2, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 1, 3, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 4, 1, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 4, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 8, 4, 5, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 2, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 1, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 2, 1, 6, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 3, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 5, 3, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 2, 4, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 1, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 1, 1, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 6, 2, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 2, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 4, 3, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 4, 6, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 3, 1, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 1, 3, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 6, 2, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 2, 4, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 7, 4, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5062, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 7, 4, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 6, 2, 5, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 6, 1, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 1, 3, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 6, 3, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 5, 2, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 4, 4, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 1, 3, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 2, 2, 2, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 2, 3, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5063, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 2, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 4, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 3, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 1, 1, 47, 235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 2, 3, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 3, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 3, 3, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 2, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 6, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 4, 4, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 2, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 1, 5, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 2, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 4, 5, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 3, 6, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 1, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 1, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 4, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 3, 2, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 2, 3, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 3, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 1, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 1, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 2, 5, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 4, 2, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 4, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 4, 3, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 2, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 2, 6, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 1, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 2, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 1, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 1, 3, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 4, 6, 43, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 4, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 2, 1, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 4, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 1, 5, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 1, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 2, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 1, 3, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 1, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 8, 2, 5, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 1, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 2, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 4, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 2, 4, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 2, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 4, 5, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 1, 5, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 1, 3, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 2, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 4, 3, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 3, 4, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 5, 3, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5134, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 1, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 4, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 3, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 4, 4, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 2, 1, 36, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 1, 1, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 3, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 3, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 1, 5, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 4, 3, 6, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 3, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 1, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 1, 4, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 4, 6, 18, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 1, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 4, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 2, 1, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 5, 2, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 4, 2, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 2, 1, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 5, 1, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 1, 2, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 4, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 4, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 1, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 1, 3, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 5, 2, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 1, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 2, 5, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 1, 3, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 2, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 8, 1, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 3, 4, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 2, 2, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5135, 7, 1, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 1, 4, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 7, 3, 5, 42, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 3, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 3, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 3, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 4, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 3, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 3, 4, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 2, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 2, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 4, 1, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 1, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 1, 5, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 2, 5, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 1, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 2, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 2, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 3, 1, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 3, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 2, 3, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 2, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 3, 4, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 1, 6, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 4, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 1, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 2, 3, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 7, 2, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 4, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 4, 5, 52, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 4, 2, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 3, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 4, 2, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 1, 5, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 8, 4, 5, 80, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 1, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 4, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 4, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 5, 2, 6, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 6, 2, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 2, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 3, 1, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 7, 1, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 1, 3, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5136, 4, 4, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 3, 5, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 3, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 2, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 8, 1, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 3, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 2, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 4, 2, 2, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 1, 4, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 3, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 6, 3, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 4, 4, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 3, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 6, 3, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 1, 2, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 4, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 4, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 3, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 4, 4, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 1, 3, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 2, 1, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 2, 6, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 1, 1, 5, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 3, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 5, 4, 2, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5137, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 2, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 3, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 2, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 4, 5, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 2, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 2, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 2, 2, 3, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 4, 2, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 2, 2, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 4, 4, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 3, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 4, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 3, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 3, 2, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 3, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 4, 1, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 3, 4, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 3, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 2, 2, 7, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 2, 5, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 7, 1, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 2, 2, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 4, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 3, 3, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 4, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 1, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 1, 6, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 2, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 4, 1, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 2, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 2, 4, 3, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 4, 5, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 3, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 4, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 1, 2, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 4, 2, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5138, 3, 3, 1, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 1, 1, 1, 57, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 7, 3, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 3, 4, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 2, 4, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 8, 2, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 5, 3, 1, 42, 378);
commit;
prompt 175000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 7, 2, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 1, 3, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 4, 2, 5, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 1, 4, 4, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 5, 2, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5139, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 4, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 4, 3, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 2, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 4, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 3, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 1, 2, 74, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 1, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 3, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 6, 1, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 4, 2, 2, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4567, 7, 3, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 1, 6, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 1, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 6, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 4, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 2, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 2, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 4, 6, 53, 954);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 1, 5, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 3, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 4, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 1, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 4, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 1, 5, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 2, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 3, 4, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 4, 2, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 3, 2, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 3, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 2, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 4, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 4, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 2, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 1, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 1, 5, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 2, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 4, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 5, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 1, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 4, 3, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 4, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 1, 5, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 1, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 2, 2, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 1, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 4, 2, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 3, 5, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 2, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 1, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 5, 2, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 5, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 4, 2, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 3, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 4, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 1, 2, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 7, 2, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 3, 4, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 3, 5, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 2, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 8, 3, 6, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 6, 3, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4568, 3, 4, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 3, 1, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 5, 1, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 8, 4, 2, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 6, 2, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 3, 2, 5, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 1, 3, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 5, 3, 2, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 7, 1, 3, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 2, 3, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4569, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 2, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 2, 2, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 3, 3, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 3, 3, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 4, 2, 5, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 6, 2, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 3, 3, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 3, 1, 16, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 7, 1, 2, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 4, 4, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 8, 4, 2, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 2, 1, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 6, 3, 5, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 6, 1, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 3, 1, 4, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 7, 3, 1, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 4, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 4, 1, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4570, 7, 2, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 8, 3, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 2, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 4, 4, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 4, 2, 5, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 3, 2, 1, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 4, 4, 2, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 3, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 4, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 4, 1, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 2, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 4, 2, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 8, 4, 5, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 2, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 8, 4, 4, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 2, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 3, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 3, 4, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 1, 4, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 1, 3, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 7, 4, 5, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 1, 3, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 4, 2, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 5, 1, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 2, 1, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 2, 4, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 6, 1, 4, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4571, 4, 1, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 2, 3, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 3, 3, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 2, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 4, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 3, 4, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 3, 4, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 3, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 2, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 4, 5, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 4, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 4, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 2, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 1, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 2, 6, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 4, 5, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 2, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 4, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 4, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 1, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 4, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 2, 1, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 1, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 4, 4, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 1, 1, 83, 249);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 6, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 1, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 2, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 4, 1, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 1, 4, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 4, 6, 96, 1632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 2, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 5, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 2, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 2, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 4, 6, 93, 1581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 3, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 1, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 2, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 1, 3, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 6, 1, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 1, 3, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 3, 2, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 4, 3, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 4, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 1, 4, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 1, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 4, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 1, 2, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 2, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 3, 2, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 3, 1, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 1, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 3, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 3, 1, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 4, 4, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 4, 1, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 8, 2, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 2, 4, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4572, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 1, 2, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 3, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 3, 3, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 3, 4, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 3, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 1, 3, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 3, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 1, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 2, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 3, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 2, 2, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 3, 2, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 8, 4, 4, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 3, 4, 4, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 4, 4, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 2, 4, 2, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4574, 6, 2, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 4, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 4, 5, 81, 1377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 3, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 2, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 4, 1, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 5, 2, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 4, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 4, 1, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 3, 4, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 3, 6, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 3, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 7, 1, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 4, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 3, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 2, 4, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 3, 5, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 2, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 2, 4, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 1, 3, 5, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 2, 2, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 6, 2, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 1, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4966, 3, 1, 4, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 1, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 8, 1, 2, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 4, 4, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 4, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 3, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 1, 3, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 4, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 1, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 3, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 8, 4, 2, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 1, 5, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 2, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 4, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 1, 1, 79, 316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 1, 4, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 1, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 2, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 1, 3, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 2, 5, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 2, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 3, 6, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 3, 3, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 2, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 4, 3, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 3, 6, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 2, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 3, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 4, 3, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 1, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 1, 4, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 3, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 1, 6, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 1, 5, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 8, 2, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 4, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 1, 4, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 2, 2, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 6, 2, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 2, 6, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4967, 5, 2, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 7, 3, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 3, 1, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 7, 4, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 6, 2, 1, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 4, 1, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 2, 3, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 3, 1, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 6, 3, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 8, 2, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 2, 1, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4968, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 1, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 3, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 4, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 2, 3, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 3, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 1, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 3, 1, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 1, 6, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 3, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 2, 1, 94, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 3, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 3, 2, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 1, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 3, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 3, 4, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 4, 5, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 4, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 2, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 2, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 4, 5, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 3, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 2, 5, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 4, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 2, 3, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 1, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 1, 4, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 2, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 4, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 3, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 1, 2, 9, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 3, 3, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 3, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 2, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 1, 2, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 1, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 4, 1, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 1, 2, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 4, 4, 1, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 2, 5, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 2, 5, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 2, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 1, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 3, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 2, 3, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 3, 2, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 2, 6, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 1, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 4, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 2, 1, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 8, 2, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 3, 3, 2, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 1, 2, 5, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 7, 2, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4969, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 3, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 5, 4, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 4, 2, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 6, 1, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 1, 4, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 3, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 6, 3, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 2, 1, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 6, 4, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 4, 4, 1, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4970, 1, 3, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 1, 2, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 1, 4, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 1, 2, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 4, 4, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 4, 4, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 8, 2, 4, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 5, 2, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 6, 4, 4, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 8, 3, 6, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 1, 4, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 1, 4, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4971, 8, 1, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 4, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 2, 2, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 2, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 4, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 4, 1, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 2, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 2, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 4, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 8, 3, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 3, 3, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 8, 2, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 3, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 3, 4, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 4, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 2, 6, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 4, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 1, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 1, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 4, 2, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 8, 1, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 3, 4, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 2, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 2, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 2, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 3, 2, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 2, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 2, 4, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 4, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 8, 1, 1, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 4, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 1, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 2, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 3, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 1, 4, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 3, 2, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 1, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 2, 2, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 4, 1, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 5, 1, 4, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4972, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 3, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 4, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 2, 2, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 1, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 1, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 2, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 1, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 4, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 3, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 1, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 1, 4, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 3, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 4, 5, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 3, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 4, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 1, 6, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 1, 1, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 2, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 1, 4, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 5, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 3, 4, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 4, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 7, 2, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 2, 1, 4, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 4, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 5, 3, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5064, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 5, 4, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 2, 3, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 4, 1, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 2, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 3, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 6, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 1, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 3, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 1, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 2, 3, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 3, 3, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 4, 4, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 5, 4, 1, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 3, 4, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 3, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 4, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 4, 5, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 4, 6, 48, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 1, 1, 27, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 1, 5, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 1, 6, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 4, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 4, 4, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 1, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 5, 1, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 2, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 1, 5, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 1, 2, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 3, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 1, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 4, 2, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 1, 4, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 4, 6, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 1, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 2, 3, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 1, 1, 2, 4, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 2, 4, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 4, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 1, 3, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 3, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 3, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 3, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 1, 5, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 1, 2, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 3, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 1, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 6, 4, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 7, 3, 3, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 1, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 2, 2, 3, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 3, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 3, 1, 3, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 1, 4, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 4, 3, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5065, 8, 3, 6, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 3, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 5, 2, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 4, 1, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 1, 4, 2, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 1, 1, 3, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 5, 1, 5, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 3, 5, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 2, 4, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 4, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 5, 1, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 2, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5066, 3, 3, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 2, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 2, 2, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 4, 3, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 3, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 1, 4, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 2, 2, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 2, 5, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 2, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 2, 3, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 2, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 3, 3, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 4, 3, 3, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 3, 1, 1, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 4, 1, 5, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 2, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 3, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 3, 6, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 2, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 4, 2, 5, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 4, 4, 4, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5067, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 4, 6, 55, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 2, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 4, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 4, 4, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 2, 3, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 4, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 5, 2, 3, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 4, 5, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 3, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 7, 1, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 4, 2, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 4, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 3, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 2, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 3, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 1, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 2, 4, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 4, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 2, 4, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 3, 4, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 7, 2, 4, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 1, 5, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 7, 2, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 3, 4, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 4, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 7, 3, 5, 13, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 4, 5, 3, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 2, 5, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 4, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 3, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 1, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 4, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 3, 1, 5, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 1, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 6, 1, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 2, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 4, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 1, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 5, 1, 3, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 4, 1, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 3, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 8, 1, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5068, 1, 2, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 1, 4, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 7, 4, 2, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 5, 4, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 4, 2, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 1, 3, 1, 84, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 2, 3, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 1, 1, 3, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 4, 3, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 2, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 8, 4, 4, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 4, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 4, 3, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 1, 4, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 6, 3, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 8, 4, 6, 60, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 1, 6, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 7, 2, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 3, 2, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 5, 2, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 3, 2, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5069, 6, 2, 3, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 4, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 7, 1, 5, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 1, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 3, 4, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 1, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 2, 2, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 2, 2, 5, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 3, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 1, 2, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 1, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 4, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 1, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 4, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 2, 5, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 3, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 1, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 1, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 1, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 1, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 2, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 3, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 3, 4, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 1, 2, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 4, 3, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 3, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 1, 3, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 1, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 4, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 2, 3, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 2, 4, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 2, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 2, 4, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 6, 3, 4, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 4, 3, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 3, 4, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 2, 2, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 3, 4, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 3, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 2, 1, 3, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 8, 3, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 4, 1, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 2, 5, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 7, 3, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 1, 3, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 3, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5140, 3, 3, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 1, 5, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 4, 4, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 5, 1, 5, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 1, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 3, 1, 20, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 3, 5, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 2, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 3, 2, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 2, 2, 5, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 2, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 2, 6, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 5, 2, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 4, 2, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 1, 5, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 2, 1, 4, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 2, 2, 1, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 2, 3, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 2, 6, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 7, 3, 1, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 4, 3, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 5, 2, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 3, 2, 3, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 8, 1, 3, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 3, 2, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 6, 4, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 1, 4, 89, 534);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 4, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5141, 1, 4, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 3, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 3, 1, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 2, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 3, 3, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 7, 1, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 4, 3, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 4, 4, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 4, 3, 71, 852);
commit;
prompt 176000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 2, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 2, 3, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 3, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 4, 6, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 2, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 3, 4, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 2, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 7, 3, 1, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 4, 6, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 1, 4, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 2, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 3, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 4, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 4, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 2, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 3, 6, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 1, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 2, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 3, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 6, 4, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 1, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 4, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 3, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 3, 6, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 1, 6, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 6, 2, 1, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 2, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 1, 6, 86, 688);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 2, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 4, 3, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 3, 3, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 2, 5, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 1, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 5, 2, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 4, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 2, 4, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5142, 1, 1, 2, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 1, 6, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 3, 3, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 5, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 6, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 3, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 1, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 2, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 6, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 2, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 3, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 1, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 1, 6, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 3, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 1, 5, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 4, 5, 41, 697);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 4, 2, 68, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 4, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 1, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 1, 4, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 1, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 3, 3, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 2, 1, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 3, 2, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 3, 1, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 2, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 3, 5, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 1, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 3, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 3, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 3, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 2, 6, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 5, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 2, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 3, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 2, 6, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 3, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 1, 2, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 2, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 1, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 6, 95, 1615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 3, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 1, 1, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 4, 5, 20, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 5, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 1, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 1, 6, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 3, 2, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 3, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 1, 3, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 3, 2, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 1, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 1, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 1, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 4, 4, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 4, 1, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 3, 3, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 2, 5, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 1, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 3, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 2, 1, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 1, 1, 4, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 1, 3, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 1, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 1, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 2, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 4, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 2, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 4, 1, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 7, 4, 4, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 2, 3, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 1, 2, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 4, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 3, 1, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 1, 5, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 2, 3, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 3, 3, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 1, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 6, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 3, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 4, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 1, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 2, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 4, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 1, 6, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 2, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 1, 5, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 4, 1, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 2, 6, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 2, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 2, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 4, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 3, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 2, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 2, 6, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 4, 2, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 3, 5, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 3, 1, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 4, 5, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 1, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 4, 6, 64, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 3, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 1, 6, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 2, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 2, 5, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 1, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 1, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 3, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 6, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 4, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 1, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 1, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 3, 1, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 1, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 2, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 1, 4, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 3, 6, 44, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 2, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 3, 1, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 4, 5, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 1, 6, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 1, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 2, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 2, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 2, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 1, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 4, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 2, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 2, 3, 4, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 4, 1, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 3, 2, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 4, 5, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 1, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 6, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 4, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 4, 3, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 4, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 3, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 4, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 6, 4, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 3, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 3, 2, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 1, 3, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 5, 3, 1, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 3, 4, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 4, 2, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4899, 7, 1, 6, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 1, 2, 2, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 4, 1, 2, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 1, 4, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 8, 2, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 7, 1, 5, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 8, 1, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 6, 3, 4, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 8, 4, 5, 97, 1649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 6, 2, 4, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 6, 3, 5, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 7, 4, 4, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4900, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 4, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 3, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 5, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 2, 3, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 3, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 4, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 3, 2, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 3, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 6, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 1, 2, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 5, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 1, 2, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 3, 6, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 1, 6, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 1, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 3, 2, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 6, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 2, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 4, 2, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 2, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 2, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 4, 2, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 1, 4, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 1, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 3, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 3, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 3, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 4, 3, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 3, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 4, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 4, 4, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 4, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 3, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 2, 4, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 4, 1, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 1, 6, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 2, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 4, 5, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 2, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 6, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 4, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 4, 4, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 4, 2, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 2, 4, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 4, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 3, 2, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 4, 5, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 4, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 2, 2, 2, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 1, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 1, 1, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 6, 3, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 4, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 4, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 5, 3, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 1, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 3, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 1, 1, 86, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 3, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 8, 2, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 7, 1, 3, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 4, 4, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4901, 3, 3, 5, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 2, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 2, 2, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 3, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 1, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 1, 3, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 1, 1, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 1, 3, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 4, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 4, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 1, 4, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 2, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 3, 5, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 4, 4, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 2, 2, 36, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 1, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 4, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 3, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 3, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 3, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 4, 1, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 2, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 2, 6, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 4, 2, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 4, 5, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 3, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 3, 1, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 4, 5, 48, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 4, 4, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 2, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 1, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 2, 3, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 2, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 1, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 8, 2, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 3, 5, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 4, 3, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 1, 2, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 1, 5, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 2, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 3, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 1, 4, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 2, 2, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 3, 1, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 4, 5, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 1, 3, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 3, 5, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 4, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 2, 4, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 2, 3, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 3, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 8, 4, 3, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 8, 4, 1, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 2, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 3, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 1, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 1, 4, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 2, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 2, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 1, 4, 3, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 1, 4, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 4, 6, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 5, 2, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 4, 5, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 2, 1, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 1, 6, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 4, 3, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 1, 4, 4, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 2, 1, 1, 15, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4973, 6, 4, 1, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 3, 5, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 4, 4, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 4, 1, 4, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 7, 2, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 3, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 2, 2, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 4, 2, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 4, 4, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 8, 3, 2, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 4, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 1, 4, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 3, 1, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 1, 3, 2, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 6, 2, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4975, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 6, 2, 3, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 6, 2, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 6, 3, 1, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 1, 3, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 2, 1, 5, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 8, 2, 2, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 4, 1, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 5, 1, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 5, 4, 4, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 2, 4, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 4, 3, 4, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 2, 1, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 3, 4, 5, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4976, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 2, 2, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 3, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 2, 6, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 4, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 2, 1, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 2, 3, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 2, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 2, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 2, 4, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 1, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 1, 6, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 4, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 1, 3, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 3, 4, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 4, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 2, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 2, 3, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 4, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 1, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 4, 2, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 4, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 2, 5, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 3, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 2, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 3, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 3, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 2, 1, 98, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 1, 3, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 1, 4, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 1, 1, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 5, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 6, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 1, 5, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 4, 3, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 4, 5, 53, 901);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 1, 3, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 3, 1, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 1, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 3, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 4, 4, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 4, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 1, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 2, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 2, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 2, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 1, 4, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 3, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 2, 2, 4, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 3, 5, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 5, 2, 6, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 3, 1, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 1, 3, 3, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 4, 2, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 3, 2, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 4, 1, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 7, 2, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 2, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 3, 4, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4977, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 4, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 4, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 3, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 4, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 3, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 3, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 2, 5, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 1, 2, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 2, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 3, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 4, 2, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 1, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 3, 3, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 5, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 3, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 4, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 4, 4, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 3, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 5, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 1, 5, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 2, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 5, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 1, 6, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 2, 5, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 5, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 2, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 5, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 3, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 5, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 4, 1, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 2, 5, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 4, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 3, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 3, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 4, 1, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 4, 1, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 1, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 1, 4, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 1, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 5, 80, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 3, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 4, 2, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 4, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 3, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 1, 5, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 4, 5, 10, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 4, 1, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 1, 2, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 2, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 4, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 2, 4, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 3, 3, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 2, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 1, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 2, 2, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 4, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 2, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 3, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 4, 3, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 4, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 2, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 1, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 3, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 4, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 3, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 4, 1, 2, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 1, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 2, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 1, 4, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 1, 3, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 1, 3, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 2, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 4, 4, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 1, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 1, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 5, 4, 4, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 3, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 6, 2, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4978, 2, 4, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 3, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 2, 5, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 3, 2, 4, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 3, 3, 2, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 3, 1, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 3, 2, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 2, 6, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 3, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 4, 4, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 4, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 4, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 2, 3, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 2, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 1, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 4, 1, 2, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 3, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 4, 6, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 2, 2, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 6, 3, 4, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 2, 1, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 3, 3, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 1, 5, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 2, 4, 6, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 7, 4, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 5, 4, 3, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5070, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 1, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 4, 2, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 1, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 2, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 3, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 1, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 1, 3, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 4, 6, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 4, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 3, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 4, 1, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 1, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 1, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 3, 5, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 1, 4, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 1, 4, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 4, 5, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 3, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 2, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 3, 1, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 1, 2, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 2, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 4, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 4, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 3, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 4, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 4, 6, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 2, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 4, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 4, 6, 13, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 4, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 2, 4, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 2, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 2, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 3, 6, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 1, 6, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 3, 4, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 1, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 3, 4, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 1, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 1, 5, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 1, 4, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 2, 5, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 2, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 3, 6, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 4, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 2, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 5, 2, 6, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 3, 3, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 2, 3, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 4, 5, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 3, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 3, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 8, 1, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 2, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 1, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 4, 6, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 4, 3, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 2, 3, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 1, 3, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 1, 1, 2, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 3, 3, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 7, 4, 3, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 2, 4, 2, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5071, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 3, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 2, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 1, 2, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 3, 4, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 2, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 5, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 3, 1, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 4, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 3, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 1, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 3, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 3, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 3, 2, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 2, 4, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 3, 4, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 4, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 4, 4, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 2, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 4, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 3, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 2, 47, 188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 2, 6, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 4, 3, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 3, 2, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 2, 4, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 4, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 3, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 4, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 1, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 3, 2, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 1, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 2, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 4, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 4, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 2, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 1, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 3, 6, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 2, 2, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 4, 4, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 2, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 1, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 4, 4, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 1, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 3, 1, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 4, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 1, 5, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 3, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 1, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 4, 1, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 3, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 1, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 2, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 1, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 2, 4, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 1, 3, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 3, 1, 3, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 2, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 2, 1, 5, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 1, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 1, 2, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 1, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 2, 6, 81, 1296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 2, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 7, 3, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 5, 4, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 2, 2, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 6, 1, 2, 53, 477);
commit;
prompt 177000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 6, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 3, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 8, 4, 4, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5072, 1, 1, 6, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 4, 3, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 1, 2, 3, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 6, 1, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 6, 2, 5, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 3, 2, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 3, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 7, 3, 4, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 8, 3, 2, 54, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 6, 3, 1, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 4, 1, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 8, 4, 4, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 2, 4, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 1, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 3, 4, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 2, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 2, 4, 5, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 8, 2, 4, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 3, 2, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 1, 1, 3, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 3, 4, 1, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5073, 5, 3, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 3, 2, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 4, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 5, 1, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 1, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 2, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 3, 3, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 5, 4, 4, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 3, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 2, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 3, 1, 2, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 4, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 3, 5, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 2, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 3, 3, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 4, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 3, 4, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 5, 3, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 3, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 1, 4, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 1, 3, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 2, 6, 83, 1328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 2, 1, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 4, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 2, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 4, 4, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 6, 4, 4, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 3, 1, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 2, 4, 1, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5143, 5, 2, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 1, 2, 31, 155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 8, 4, 2, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 6, 4, 4, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 5, 1, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 4, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 1, 1, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 3, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 8, 3, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 3, 1, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 4, 4, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 3, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 2, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 1, 3, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 1, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 6, 2, 3, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 2, 6, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 2, 4, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 1, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 5, 1, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 3, 5, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 1, 3, 39, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 2, 6, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 3, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 3, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 3, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 8, 3, 4, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 4, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 2, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 4, 5, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 5, 1, 4, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 4, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 5, 3, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 2, 3, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 3, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 5, 1, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 2, 2, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 3, 1, 6, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 2, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 4, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 6, 2, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 4, 6, 37, 629);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 5, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 2, 4, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 2, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 4, 1, 3, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 4, 2, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 6, 4, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 6, 3, 4, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 2, 4, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 1, 2, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5144, 7, 2, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 4, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 4, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 4, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 7, 4, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 2, 3, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 3, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 4, 4, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 3, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 3, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 3, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 1, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 1, 2, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 4, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 2, 1, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 4, 3, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 7, 2, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 4, 3, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 2, 1, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 4, 3, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 3, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 3, 2, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 4, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 2, 4, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 2, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 7, 1, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 3, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 4, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 1, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 3, 1, 3, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 1, 4, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 7, 3, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 3, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 2, 2, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 4, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 1, 1, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 1, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 1, 3, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 1, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 7, 1, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 6, 3, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 3, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 4, 3, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 1, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 4, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 2, 1, 4, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 3, 3, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 1, 2, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 3, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 4, 3, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 8, 3, 2, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5145, 5, 2, 2, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 3, 2, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 3, 4, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 2, 4, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 5, 3, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 5, 4, 6, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 7, 3, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 6, 1, 3, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 4, 4, 1, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 5, 2, 5, 100, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 5, 1, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 6, 4, 3, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 1, 4, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 6, 1, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 5, 2, 3, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 3, 1, 1, 85, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 6, 2, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5146, 6, 3, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 8, 2, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 6, 1, 2, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 1, 3, 6, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 8, 1, 6, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 5, 1, 1, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 2, 2, 3, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 7, 3, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 2, 1, 4, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 6, 1, 5, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 4, 1, 6, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 4, 3, 1, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 8, 3, 5, 94, 1504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 2, 3, 3, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 6, 1, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 3, 2, 2, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 3, 3, 4, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 7, 1, 4, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5147, 6, 2, 5, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 2, 3, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 1, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 4, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 2, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 3, 1, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 3, 4, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 2, 1, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 6, 18, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 3, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 3, 1, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 4, 4, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 1, 5, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 4, 6, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 1, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 4, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 4, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 3, 2, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 2, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 3, 4, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 3, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 2, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 1, 2, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 1, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 2, 5, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 2, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 3, 3, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 4, 3, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 4, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 4, 3, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 1, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 2, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 1, 3, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 2, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 4, 3, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 2, 5, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 3, 1, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 4, 5, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 1, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 4, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 2, 4, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 3, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 4, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 1, 5, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 3, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 1, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 4, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 4, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 3, 6, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 4, 5, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 3, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 1, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 4, 4, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 4, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 2, 4, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 1, 1, 3, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 4, 2, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 3, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 4, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 6, 4, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 7, 3, 3, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 5, 2, 4, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5148, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 4, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 6, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 4, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 1, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 1, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 1, 3, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 3, 6, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 2, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 1, 1, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 1, 6, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 1, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 1, 4, 6, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 7, 3, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4902, 5, 4, 4, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 2, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 2, 2, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 2, 2, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 4, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 2, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 1, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 3, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 4, 1, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 1, 2, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 3, 5, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 4, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 4, 1, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 1, 5, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 1, 4, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 4, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 1, 4, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 1, 4, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 4, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 2, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 3, 1, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 1, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 6, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 4, 2, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 1, 3, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 1, 4, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 1, 3, 62, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 1, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 4, 2, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 4, 6, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 2, 2, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 1, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 4, 1, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 3, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 4, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 4, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 1, 4, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 2, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 1, 1, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 3, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 1, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 4, 1, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 2, 4, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 2, 6, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 3, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 1, 6, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 4, 2, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 4, 4, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 2, 5, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 1, 6, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 1, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 4, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 3, 6, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 2, 1, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 2, 5, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 1, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 1, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 8, 4, 1, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 3, 3, 4, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 6, 1, 6, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 1, 2, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 4, 6, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 5, 2, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 1, 5, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 1, 2, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 4, 4, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4903, 2, 3, 5, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 4, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 7, 4, 4, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 2, 2, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 3, 3, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 1, 6, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 7, 3, 5, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 4, 3, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 4, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 3, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 1, 3, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 2, 5, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 1, 5, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 2, 6, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 2, 4, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 2, 2, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 1, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 7, 1, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 1, 3, 5, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 4, 4, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 1, 4, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 4, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 1, 4, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 2, 6, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 4, 2, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 5, 3, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 5, 2, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 1, 2, 6, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 4, 1, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 2, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 3, 1, 3, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 4, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 1, 4, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 1, 2, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 4, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4904, 2, 3, 1, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 4, 6, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 4, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 1, 4, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 4, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 2, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 5, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 4, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 4, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 1, 3, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 2, 3, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 6, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 1, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 3, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 3, 2, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 4, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 6, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 1, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 6, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 2, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 6, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 2, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 4, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 4, 2, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 1, 6, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 4, 5, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 3, 2, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 5, 1, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 3, 1, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 1, 6, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 3, 2, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 4, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 1, 5, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 3, 2, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 1, 6, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 1, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 4, 6, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 1, 4, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 7, 4, 4, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 6, 2, 4, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 8, 3, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 2, 2, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 3, 6, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 2, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 1, 6, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 5, 1, 3, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 2, 2, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4905, 4, 3, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 4, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 3, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 3, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 1, 4, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 2, 6, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 7, 2, 2, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 3, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 3, 3, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 3, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 1, 4, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 2, 4, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 4, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 6, 1, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 4, 6, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 2, 6, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 4, 4, 4, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 4, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 4, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 1, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 3, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 3, 1, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 6, 1, 5, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 4, 1, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 4, 2, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 4, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 3, 2, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 1, 3, 81, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 4, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 6, 4, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 3, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 2, 4, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 4, 1, 5, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 1, 4, 6, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 3, 6, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 3, 4, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 7, 2, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4906, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 3, 1, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 3, 2, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 6, 4, 4, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 5, 4, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 6, 4, 3, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 1, 3, 5, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 6, 2, 1, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 3, 4, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 6, 1, 6, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 4, 3, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 6, 1, 6, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4907, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 1, 1, 6, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 3, 5, 6, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 3, 5, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 2, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 1, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 3, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 4, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 2, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 1, 2, 5, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 2, 1, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 3, 4, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 7, 1, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 3, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 1, 4, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 2, 3, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 3, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 1, 3, 3, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 3, 2, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 4, 6, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 3, 4, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 8, 4, 1, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 3, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 8, 2, 2, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 7, 3, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 4, 2, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 8, 2, 3, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 7, 1, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 2, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 4, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 3, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 3, 2, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 7, 1, 3, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 2, 3, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 1, 4, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 2, 2, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 5, 3, 1, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 1, 1, 4, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 8, 2, 1, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4979, 4, 4, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 2, 3, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 1, 3, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 1, 2, 41, 164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 3, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 1, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 3, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 3, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 2, 6, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 4, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 3, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 1, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 3, 5, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 3, 6, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 1, 3, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 4, 4, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 2, 6, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 2, 1, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 1, 1, 70, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 4, 3, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 2, 5, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 4, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 3, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 1, 2, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 1, 5, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 4, 2, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 2, 5, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 2, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 1, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 4, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 3, 5, 51, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 1, 1, 19, 57);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 2, 5, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 2, 2, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 2, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 1, 4, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 3, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 1, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 2, 5, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 1, 2, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 2, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 4, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 8, 1, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 7, 4, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 2, 3, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 1, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 3, 2, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 1, 6, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 1, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 4, 2, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 4, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 6, 4, 3, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4980, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 4, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 4, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 2, 4, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 1, 3, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 2, 1, 10, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 1, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 3, 1, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 2, 6, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 2, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 4, 2, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 1, 26, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 1, 5, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 3, 3, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 1, 6, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 4, 4, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 4, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 3, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 4, 5, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 1, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 2, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 3, 2, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 4, 1, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 2, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 1, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 4, 4, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 1, 4, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 1, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 4, 3, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 4, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 3, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 4, 3, 4, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 1, 6, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 1, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 4, 4, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 3, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 1, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 4, 2, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 3, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 2, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 1, 5, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 1, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 1, 2, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 2, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 4, 6, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 3, 2, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 1, 3, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 1, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 3, 5, 16, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 3, 5, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 3, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 5, 2, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 1, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 2, 1, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 1, 4, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 4, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 8, 4, 1, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4981, 7, 3, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 3, 4, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 4, 6, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 3, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 2, 4, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 4, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 1, 5, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 2, 4, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 4, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 3, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 2, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 1, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 3, 2, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 3, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 3, 6, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 3, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 4, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 4, 1, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 3, 1, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 4, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 3, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 2, 6, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 4, 5, 39, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 1, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 2, 6, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 4, 5, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 3, 2, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 3, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 2, 5, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 4, 4, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 2, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 1, 3, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 1, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 4, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 1, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 2, 1, 2, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 3, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 7, 2, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 3, 6, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 4, 4, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 3, 3, 6, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 4, 2, 2, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 8, 3, 2, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 1, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4982, 6, 3, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 2, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 2, 3, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 4, 3, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 2, 4, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 1, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 3, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 3, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 2, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 4, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 1, 1, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 1, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 2, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 2, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 2, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 1, 4, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 1, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 1, 5, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 3, 2, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 4, 3, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 4, 2, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 5, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 4, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 1, 4, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 2, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 2, 4, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 2, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 3, 6, 68, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 2, 5, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 2, 3, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 1, 1, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 1, 4, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 5, 2, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 1, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 1, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 1, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 4, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 2, 4, 4, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 4, 1, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 2, 3, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 2, 2, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 3, 4, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 1, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 2, 2, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 1, 3, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 8, 1, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 5, 4, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 6, 4, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5074, 7, 2, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 3, 2, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 2, 3, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 3, 1, 6, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 4, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 1, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 1, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 1, 2, 4, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 2, 3, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 1, 3, 1, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 2, 2, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 1, 1, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 2, 4, 3, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 4, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 2, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 2, 4, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 1, 3, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 1, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 3, 3, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 1, 6, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 4, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 4, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 2, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 3, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 4, 1, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 3, 2, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 3, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 3, 4, 3, 16, 160);
commit;
prompt 178000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 3, 3, 88, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 3, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 5, 1, 5, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 3, 1, 3, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 3, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 2, 6, 28, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 3, 4, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 4, 6, 85, 1445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 2, 5, 55, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 7, 4, 6, 73, 1241);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 4, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 8, 2, 1, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5075, 4, 4, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 1, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 3, 2, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 3, 4, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 6, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 3, 4, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 2, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 3, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 2, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 2, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 1, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 4, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 2, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 4, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 4, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 4, 3, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 1, 40, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 2, 2, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 3, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 1, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 1, 6, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 5, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 1, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 2, 2, 60, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 1, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 1, 6, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 4, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 1, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 4, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 3, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 1, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 4, 5, 67, 1005);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 2, 2, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 4, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 1, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 4, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 2, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 2, 4, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 1, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 2, 3, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 4, 5, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 4, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 4, 5, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 2, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 2, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 2, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 2, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 1, 4, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 2, 6, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 1, 2, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 1, 3, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 6, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 6, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 4, 3, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 1, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 5, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 3, 4, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 4, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 3, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 4, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 2, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 3, 45, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 5, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 1, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 1, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 2, 2, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 2, 2, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 1, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 2, 5, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 6, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 4, 6, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 3, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 2, 5, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 3, 5, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 1, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 3, 1, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 4, 1, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 2, 3, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 2, 5, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 1, 6, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 1, 4, 5, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 1, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 4, 1, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 8, 3, 1, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 2, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 4, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 4, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 5, 2, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 2, 3, 5, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 6, 4, 5, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5076, 3, 2, 5, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 4, 4, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 3, 1, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 7, 1, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 2, 2, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 1, 6, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 4, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 4, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 2, 6, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 1, 2, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 2, 4, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 4, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 2, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 1, 2, 38, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 4, 6, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 1, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 7, 3, 4, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 4, 1, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 5, 3, 4, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 3, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 2, 6, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 4, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 3, 3, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 3, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 4, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 4, 4, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 7, 4, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 2, 5, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 4, 2, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 4, 6, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 3, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 2, 1, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 4, 3, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 4, 4, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 1, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 2, 2, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 3, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 1, 1, 5, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 6, 1, 3, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 2, 4, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 4, 2, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 3, 3, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5077, 8, 4, 2, 50, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 3, 3, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 3, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 1, 6, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 2, 2, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 2, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 4, 3, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 2, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 1, 6, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 3, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 2, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 1, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 4, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 4, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 3, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 3, 3, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 3, 4, 38, 494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 4, 4, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 3, 5, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 1, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 1, 5, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 1, 1, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 4, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 2, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 3, 6, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 2, 5, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 4, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 1, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 3, 2, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 2, 1, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 2, 4, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 1, 3, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 2, 5, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 2, 3, 86, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 2, 2, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 1, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 2, 4, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 5, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 3, 1, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 3, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 2, 1, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 1, 2, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 2, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 3, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 6, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 4, 5, 37, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 3, 5, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 4, 1, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 2, 4, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 8, 2, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 1, 2, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 2, 3, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 1, 2, 13, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 4, 6, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 4, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 2, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 2, 4, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 3, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 1, 3, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 4, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 5, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 2, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 3, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 4, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 2, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 3, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 4, 2, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 6, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 5, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 1, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 3, 3, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 4, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 4, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5149, 5, 4, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 3, 3, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 3, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 2, 4, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 3, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 2, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 1, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 3, 1, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 2, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 1, 4, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 4, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 1, 1, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 2, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 4, 1, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 2, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 2, 6, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 3, 1, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 2, 4, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 2, 2, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 4, 2, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 2, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 3, 1, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 3, 5, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 2, 2, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 3, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 1, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 4, 3, 77, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 1, 6, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 4, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 3, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 1, 2, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 4, 5, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 3, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 4, 3, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 4, 1, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 2, 4, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 4, 5, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 5, 3, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 4, 4, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 1, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 3, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 1, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 8, 3, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 4, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 4, 6, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 2, 1, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 3, 1, 5, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 7, 3, 3, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 4, 2, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 2, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 6, 2, 5, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5151, 1, 2, 3, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 3, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 1, 1, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 2, 4, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 4, 3, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 1, 3, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 2, 4, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 4, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 1, 1, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 3, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 2, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 4, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 3, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 4, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 3, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 1, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 2, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 2, 6, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 2, 2, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 4, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 2, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 2, 5, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 2, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 1, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 2, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 3, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 2, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 4, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 1, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 1, 2, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 3, 3, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 4, 2, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 1, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 4, 5, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 6, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 3, 3, 63, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 3, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 4, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 4, 2, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 4, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 1, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 3, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 1, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 6, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 4, 4, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 2, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 2, 3, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 1, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 6, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 2, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 2, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 1, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 1, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 4, 2, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 3, 52, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 3, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 3, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 4, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 3, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 2, 6, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 3, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 3, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 1, 3, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 1, 4, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 4, 3, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 2, 1, 2, 49, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 8, 3, 5, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 4, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 2, 5, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 3, 2, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5154, 5, 3, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 2, 1, 1, 51, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 5, 4, 6, 46, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 5, 4, 4, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 4, 2, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 7, 3, 4, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 1, 3, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 4, 1, 2, 24, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 1, 1, 3, 95, 475);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 5, 3, 6, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 3, 4, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 8, 2, 3, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 3, 4, 1, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 1, 4, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 3, 2, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5155, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 6, 4, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 3, 3, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 1, 2, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 1, 2, 92, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 3, 2, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 4, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 2, 5, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 3, 4, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 3, 2, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 8, 3, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 1, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 1, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 2, 2, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 4, 2, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 1, 4, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 1, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 4, 3, 6, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 2, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 1, 1, 6, 32, 256);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 3, 3, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 3, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 4, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 3, 4, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 6, 3, 1, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 3, 3, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 4, 1, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 2, 1, 61, 305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 3, 2, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 2, 6, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 6, 4, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 4, 3, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 1, 3, 5, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 6, 1, 6, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 7, 3, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 4, 3, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 2, 3, 3, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 2, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 6, 2, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 6, 3, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 4, 3, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 1, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 7, 1, 1, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 3, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 8, 4, 4, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4908, 5, 1, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 3, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 4, 2, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 2, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 4, 1, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 2, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 4, 6, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 3, 5, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 2, 3, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 2, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 5, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 3, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 2, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 2, 1, 91, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 6, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 1, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 3, 6, 54, 918);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 3, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 1, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 2, 2, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 3, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 4, 5, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 3, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 1, 5, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 3, 5, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 3, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 1, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 1, 3, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 3, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 4, 5, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 2, 1, 43, 215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 4, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 1, 1, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 2, 3, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 1, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 1, 1, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 3, 3, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 1, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 6, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 2, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 1, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 1, 4, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 4, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 2, 5, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 4, 1, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 4, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 3, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 3, 3, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 4, 5, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 3, 1, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 4, 6, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 2, 3, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 2, 3, 4, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 7, 2, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 3, 6, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 4, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 3, 2, 3, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 2, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 6, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 6, 3, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 1, 5, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 1, 4, 5, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4909, 4, 1, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 6, 1, 5, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 1, 4, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 4, 4, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 2, 2, 4, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 7, 3, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 4, 1, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 5, 2, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 7, 4, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 1, 3, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 8, 2, 2, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 7, 3, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 6, 2, 1, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4910, 5, 4, 2, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 2, 4, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 3, 2, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 2, 6, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 1, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 1, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 3, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 3, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 3, 1, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 1, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 3, 3, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 2, 3, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 3, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 2, 1, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 4, 4, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 4, 6, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 2, 3, 7, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 2, 6, 70, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 2, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 1, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 1, 2, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 1, 6, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 2, 5, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 1, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 4, 3, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 1, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 2, 4, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 3, 4, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 3, 2, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 4, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 5, 44, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 4, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 2, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 1, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 3, 1, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 2, 6, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 2, 5, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 6, 2, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 2, 5, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 4, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 2, 5, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 1, 5, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 2, 4, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 3, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 6, 83, 1411);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 3, 1, 5, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 3, 5, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 5, 4, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 3, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 3, 4, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 1, 1, 73, 292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 3, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 3, 4, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 2, 6, 34, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 1, 5, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 3, 1, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 4, 2, 3, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 2, 1, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 2, 4, 6, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4911, 7, 4, 6, 84, 1428);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 4, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 4, 1, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 4, 4, 2, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 4, 1, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 4, 2, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 2, 4, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 3, 1, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 6, 2, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 1, 5, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 3, 1, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 4, 6, 87, 1479);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 1, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 1, 6, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 4, 5, 15, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 4, 4, 4, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 4, 1, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 2, 1, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 6, 4, 4, 100, 1400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 1, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 4, 4, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 2, 3, 4, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 6, 3, 5, 90, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 3, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 3, 3, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 4, 5, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 3, 1, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 4, 3, 80, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 3, 2, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 1, 6, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 2, 2, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 1, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 3, 6, 53, 848);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 5, 3, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4912, 7, 3, 1, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 1, 1, 3, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 4, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 1, 2, 4, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 4, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 3, 4, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 3, 3, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 2, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 1, 3, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 7, 2, 2, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 3, 4, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 3, 2, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 5, 1, 4, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 7, 3, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 3, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 2, 3, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 1, 4, 6, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 8, 4, 1, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 4, 5, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 2, 6, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 4, 4, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 1, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 1, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 4, 4, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4913, 6, 3, 1, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 1, 2, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 7, 3, 3, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 4, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 4, 4, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 4, 5, 78, 1326);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 1, 5, 11, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 1, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 2, 2, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 2, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 1, 3, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 3, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 1, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 2, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 3, 3, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 1, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 2, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 3, 5, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 4, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 3, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 1, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 3, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 4, 3, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 3, 3, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 2, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 3, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 3, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 2, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 4, 6, 9, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 3, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 2, 1, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 4, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 2, 3, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 4, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 6, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 1, 2, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 1, 1, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 4, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 3, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 3, 2, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 3, 2, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 3, 2, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 2, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 2, 1, 4, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 1, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 2, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 8, 3, 2, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 1, 4, 2, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 1, 1, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 2, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 6, 4, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 3, 4, 6, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4983, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 4, 6, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 4, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 2, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 3, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 3, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 3, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 3, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 5, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 3, 5, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 4, 5, 48, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 2, 6, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 3, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 3, 58, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 2, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 2, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 5, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 6, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 3, 4, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 3, 4, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 1, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 2, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 4, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 2, 56, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 3, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 4, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 2, 44, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 3, 1, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 4, 2, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 2, 6, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 6, 68, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 4, 5, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 6, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 1, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 3, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 2, 27, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 1, 5, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 3, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 2, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 1, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 3, 4, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 4, 2, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 6, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 3, 3, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 2, 2, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 1, 2, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 6, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 3, 2, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 4, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 5, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 2, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 2, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 5, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 2, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 1, 3, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 4, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 3, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 2, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 3, 98, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 2, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 4, 6, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 3, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 5, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 3, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 4, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 4, 5, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 4, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 1, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 6, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 1, 5, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 3, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 3, 5, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 4, 4, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 5, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 2, 77, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 5, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 3, 6, 51, 867);
commit;
prompt 179000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 1, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 3, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 3, 5, 24, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 2, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 1, 2, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 4, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 1, 4, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 2, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 4, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 5, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 3, 6, 43, 731);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 1, 3, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 2, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 4, 5, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 4, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 7, 3, 4, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 4, 6, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 2, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 3, 4, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 2, 3, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 3, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 6, 2, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 3, 1, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 4, 3, 3, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4984, 3, 1, 1, 10, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 3, 3, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 1, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 2, 5, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 3, 5, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 2, 1, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 1, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 3, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 2, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 2, 1, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 3, 6, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 3, 1, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 1, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 2, 3, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 1, 5, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 3, 4, 21, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 7, 4, 4, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 1, 3, 21, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 2, 6, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 3, 3, 4, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 3, 1, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 4, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 2, 6, 54, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 2, 1, 6, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 4, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 3, 1, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 2, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 5, 3, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 2, 2, 2, 67, 402);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 2, 1, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 2, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 1, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 4, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 1, 6, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 4, 4, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 2, 6, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 4, 3, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 8, 4, 4, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 3, 2, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4985, 3, 2, 6, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 8, 2, 3, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 3, 6, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 4, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 2, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 4, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 3, 2, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 2, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 8, 2, 1, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 1, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 8, 4, 1, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 4, 6, 16, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 4, 5, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 4, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 1, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 2, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 2, 1, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 2, 5, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 4, 2, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 4, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 1, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 1, 4, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 3, 2, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 2, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 3, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 4, 2, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 3, 4, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 2, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 2, 2, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 2, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 3, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 1, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 5, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 4, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 3, 6, 50, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 2, 6, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 4, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 3, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 4, 1, 59, 354);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 2, 5, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 3, 6, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 2, 2, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 4, 4, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 1, 1, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 1, 4, 3, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 3, 3, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 2, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 3, 3, 4, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 4, 2, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 4, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 2, 4, 4, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 6, 4, 1, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 3, 6, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 1, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 8, 3, 3, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 5, 1, 2, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5078, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 6, 4, 5, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 7, 3, 1, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 7, 1, 6, 20, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 1, 4, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 2, 2, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 1, 2, 4, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 1, 2, 3, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 3, 3, 3, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 5, 4, 3, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 7, 3, 5, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 2, 3, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 2, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 3, 4, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 2, 1, 5, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 6, 2, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 4, 1, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 5, 3, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 7, 4, 6, 23, 391);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 4, 4, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 2, 1, 2, 32, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 1, 2, 3, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 1, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 5, 1, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 5, 2, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 4, 3, 1, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 1, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5079, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 3, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 2, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 3, 5, 72, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 1, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 2, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 1, 2, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 3, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 1, 3, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 2, 3, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 4, 3, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 1, 2, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 2, 3, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 2, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 1, 4, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 3, 4, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 1, 4, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 4, 6, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 3, 3, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 4, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 1, 5, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 1, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 1, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 3, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 3, 6, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 3, 5, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 3, 3, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 1, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 4, 2, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 1, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 1, 6, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 1, 5, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 2, 6, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 3, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 2, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 2, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 4, 4, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 4, 1, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 2, 2, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 1, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 5, 4, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 2, 6, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 4, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 1, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 3, 2, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 4, 5, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 6, 3, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 4, 2, 2, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 8, 3, 6, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 7, 1, 2, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 1, 4, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5080, 3, 2, 1, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 1, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 1, 1, 93, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 4, 4, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 4, 3, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 1, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 2, 5, 22, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 4, 3, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 1, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 2, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 2, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 3, 6, 69, 1035);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 1, 4, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 4, 2, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 1, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 3, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 1, 4, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 3, 4, 3, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 3, 1, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 2, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 3, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 4, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 1, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 2, 5, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 4, 4, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 2, 2, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 4, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 1, 3, 37, 185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 2, 5, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 1, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 2, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 2, 4, 3, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 4, 6, 28, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 2, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 2, 5, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 1, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 1, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 4, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 2, 6, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 4, 3, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 1, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 1, 4, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 4, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 3, 3, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 1, 3, 1, 55, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 7, 3, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 4, 6, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 2, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 2, 5, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 4, 2, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 4, 2, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 2, 3, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 4, 4, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 4, 5, 41, 615);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 1, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 2, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 4, 2, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 5, 1, 2, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 2, 3, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 8, 3, 1, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 3, 4, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 3, 1, 5, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 3, 5, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 4, 3, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5081, 6, 1, 1, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 1, 6, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 2, 4, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 2, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 2, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 2, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 1, 3, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 4, 1, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 1, 1, 48, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 2, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 1, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 1, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 3, 4, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 3, 5, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 3, 3, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 1, 2, 45, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 2, 1, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 1, 4, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 3, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 1, 1, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 4, 5, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 4, 3, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 3, 2, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 2, 1, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 2, 1, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 3, 2, 15, 195);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 1, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 1, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 4, 2, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 2, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 3, 3, 2, 14);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 1, 3, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 4, 5, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 2, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 1, 3, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 4, 5, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 2, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 3, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 2, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 1, 6, 1, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 4, 3, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 1, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 3, 1, 87, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 4, 2, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 4, 3, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 1, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 2, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 1, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 3, 2, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 4, 1, 3, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 3, 3, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 2, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 4, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 7, 1, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 4, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 7, 2, 2, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 5, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 6, 2, 3, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 3, 6, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 1, 1, 2, 26, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 4, 3, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 5, 68, 748);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 6, 3, 2, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 4, 1, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 7, 1, 5, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 1, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 2, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 2, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 6, 1, 4, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 1, 3, 6, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 8, 3, 5, 41, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 1, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 3, 2, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 8, 4, 1, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 6, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 2, 4, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 5, 2, 2, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 4, 2, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 8, 1, 2, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5156, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 6, 2, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 6, 3, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 5, 2, 2, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 5, 3, 4, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 8, 1, 5, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 4, 1, 3, 54, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 1, 4, 3, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 6, 1, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 2, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 2, 6, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 2, 2, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 6, 1, 3, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 4, 1, 1, 12, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 4, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 8, 4, 2, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 7, 1, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 7, 2, 1, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 1, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 4, 4, 2, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 1, 1, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 1, 1, 4, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 4, 1, 4, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 2, 4, 2, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 8, 2, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 2, 6, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 8, 2, 3, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 5, 1, 4, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5157, 1, 1, 5, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 4, 2, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 3, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 4, 2, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 1, 4, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 4, 1, 1, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 3, 4, 2, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 3, 2, 4, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 6, 1, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 1, 2, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 3, 5, 88, 1408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 5, 2, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 5, 4, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 6, 1, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 3, 2, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 2, 2, 1, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 3, 2, 3, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 1, 4, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 4, 2, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 3, 2, 1, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 2, 4, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 2, 4, 5, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 7, 2, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 4, 2, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 2, 4, 1, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 2, 4, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 7, 2, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 6, 1, 2, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 4, 1, 2, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 8, 3, 5, 25, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 4, 4, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 1, 4, 6, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5158, 5, 3, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 5, 3, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 4, 1, 5, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 8, 4, 5, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 3, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 4, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 2, 3, 3, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 4, 3, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 8, 2, 1, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 8, 1, 3, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 2, 1, 1, 21, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 7, 2, 2, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 3, 6, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 4, 2, 3, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 4, 3, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 2, 2, 6, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 4, 2, 5, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 7, 2, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 3, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 7, 3, 5, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 1, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 8, 2, 2, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 1, 1, 97, 291);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 6, 2, 1, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 7, 2, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 2, 4, 4, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 1, 1, 25, 125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 1, 3, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 1, 4, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 3, 2, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 8, 3, 6, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 2, 2, 1, 63, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 4, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5159, 1, 4, 5, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 3, 2, 2, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 7, 4, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 6, 1, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 1, 6, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 1, 1, 6, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 1, 5, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 2, 6, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 6, 4, 3, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 3, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 2, 5, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 1, 3, 3, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 4, 2, 2, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 3, 4, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 1, 5, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 1, 3, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 3, 5, 3, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 7, 4, 2, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 6, 3, 5, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 1, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 1, 4, 3, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 4, 4, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 1, 1, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 3, 4, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 8, 4, 5, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 4, 5, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 3, 1, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 6, 2, 2, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 2, 1, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 4, 3, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5160, 6, 3, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 6, 3, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 2, 1, 1, 37, 148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 3, 3, 5, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 4, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 6, 4, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 3, 3, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 4, 3, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 1, 1, 6, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 3, 3, 2, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 3, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 2, 6, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 4, 4, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 2, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 1, 1, 3, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 3, 2, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 1, 3, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 2, 2, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 3, 4, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 4, 6, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 3, 5, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 4, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 2, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 2, 1, 2, 72, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 1, 1, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 1, 1, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 2, 2, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 6, 1, 1, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 2, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 2, 4, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 1, 4, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 1, 1, 42, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 3, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 1, 6, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 8, 2, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 1, 5, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 4, 6, 67, 1139);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 3, 4, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 5, 1, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 1, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 7, 4, 3, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 2, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 4, 2, 1, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5162, 3, 2, 2, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 4, 6, 63, 1071);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 2, 3, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 1, 5, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 2, 5, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 3, 1, 6, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 2, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 4, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 3, 6, 42, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 2, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 3, 6, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 1, 4, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 4, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 1, 6, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 2, 4, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 3, 1, 4, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 4, 6, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 4, 2, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 3, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 1, 3, 4, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 1, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 3, 1, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 4, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 1, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 4, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 2, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 4, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 3, 5, 67, 1072);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 3, 4, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 3, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 1, 4, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 2, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 3, 4, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 2, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 1, 3, 2, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 6, 4, 4, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 3, 5, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 1, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 7, 1, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 5, 3, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5163, 4, 2, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 3, 4, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 2, 6, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 4, 1, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 2, 4, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 2, 1, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 2, 4, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 3, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 2, 4, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 4, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 3, 4, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 1, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 6, 4, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 2, 4, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 2, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 3, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 6, 1, 3, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 2, 6, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 4, 5, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 2, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 3, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 6, 4, 1, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 2, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 3, 2, 5, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 7, 2, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 1, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 1, 4, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 2, 1, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 4, 5, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 8, 4, 3, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 1, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 3, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 4, 1, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 4, 4, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4914, 5, 3, 4, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 6, 3, 4, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 2, 3, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 3, 2, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 7, 4, 6, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 4, 4, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 6, 3, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 3, 1, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 2, 3, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 4, 3, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 2, 3, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 2, 3, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 4, 3, 3, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 4, 3, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 7, 1, 3, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 7, 1, 3, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 5, 1, 1, 18, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 3, 1, 5, 70, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 3, 2, 2, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 1, 2, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 1, 6, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 3, 3, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 5, 2, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 3, 5, 85, 1360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 7, 4, 4, 84, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 7, 4, 1, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4915, 2, 3, 3, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 1, 6, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 4, 3, 10, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 1, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 3, 6, 77, 1232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 3, 2, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 2, 3, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 4, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 2, 1, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 2, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 2, 5, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 4, 6, 70, 1260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 4, 5, 33, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 1, 2, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 4, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 4, 3, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 2, 2, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 2, 6, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 4, 3, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 2, 4, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 1, 5, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 3, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 3, 1, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 2, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 4, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 1, 3, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 1, 1, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 2, 5, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 1, 6, 31, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 4, 4, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 2, 4, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 3, 5, 49, 735);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 1, 6, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 1, 1, 81, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 5, 3, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 3, 4, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 4, 1, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 2, 2, 21, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 2, 3, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 3, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 1, 4, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 1, 5, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 2, 2, 52, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 4, 5, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 3, 4, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 4, 5, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 3, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 2, 2, 40, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 2, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 3, 3, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 1, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 3, 2, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 4, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 1, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 3, 4, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 1, 4, 57, 399);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 1, 5, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 2, 2, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 1, 2, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 2, 2, 4, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 7, 1, 3, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 3, 4, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 6, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 3, 4, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 8, 1, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 4, 1, 1, 32, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4916, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 8, 4, 2, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 6, 4, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 1, 3, 6, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 4, 3, 3, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 2, 4, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 4, 3, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 1, 1, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 1, 2, 1, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 3, 3, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 4, 4, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 4, 4, 6, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 5, 3, 4, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 3, 1, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 3, 4, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 2, 3, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 1, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 8, 2, 3, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 3, 2, 6, 25, 275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 5, 1, 2, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 4, 5, 90, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 5, 2, 1, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 8, 4, 1, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 2, 1, 6, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 7, 3, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 2, 2, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4917, 3, 3, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 3, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 2, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 3, 5, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 1, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 4, 1, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 3, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 3, 4, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 1, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 3, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 4, 3, 66, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 1, 3, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 5, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 2, 3, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 3, 1, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 4, 2, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 1, 2, 3, 22, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 4, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 1, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 2, 2, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 4, 1, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 2, 2, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 2, 4, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 3, 3, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 2, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 8, 3, 3, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 3, 4, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 7, 2, 2, 88, 968);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 2, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 4, 1, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4918, 6, 4, 3, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 4, 1, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 7, 3, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 2, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 8, 2, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 2, 4, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 6, 1, 3, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 2, 1, 4, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 3, 3, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 4, 5, 43, 602);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 2, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 1, 1, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 1, 5, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 4, 1, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 4, 2, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 3, 1, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 2, 1, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 1, 6, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 8, 3, 2, 92, 1196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 1, 2, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 7, 3, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 2, 1, 83, 332);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 2, 3, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 2, 3, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 4, 1, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 2, 1, 4, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 1, 2, 74, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 2, 6, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 4, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 2, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 4, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 7, 4, 2, 65, 845);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 3, 3, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 5, 4, 5, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 4, 2, 6, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 8, 3, 1, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 4, 4, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 2, 1, 5, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4919, 6, 1, 5, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 1, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 3, 6, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 3, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 5, 3, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 1, 5, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 6, 3, 4, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 4, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 4, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 1, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 2, 4, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 1, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 4, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 2, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 4, 5, 100, 1600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 1, 3, 54, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 4, 4, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 2, 4, 2, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 4, 2, 59, 767);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 2, 3, 3, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 1, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 2, 4, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 3, 4, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 1, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 1, 4, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 3, 3, 6, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 2, 4, 1, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 4, 4, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 1, 6, 22, 242);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 3, 3, 64, 576);
commit;
prompt 180000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 1, 3, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 1, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 1, 4, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 1, 5, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 3, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 4, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 3, 1, 57, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 2, 1, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 4, 4, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 2, 2, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 1, 4, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 8, 2, 3, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 1, 5, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 3, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 2, 6, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 4, 4, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 3, 5, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 1, 3, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 3, 5, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 3, 4, 2, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 3, 4, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 1, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 3, 4, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 2, 4, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 4, 3, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 1, 6, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 6, 4, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 3, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 3, 5, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 7, 2, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4986, 2, 4, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 2, 2, 2, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 6, 1, 6, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 2, 4, 2, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 2, 2, 4, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 1, 1, 4, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 3, 1, 5, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 2, 3, 4, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 5, 2, 1, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 8, 3, 6, 25, 425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 1, 2, 5, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 1, 1, 4, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 5, 4, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4987, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 6, 2, 4, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 3, 2, 1, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 3, 4, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 1, 3, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 1, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 3, 3, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 4, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 2, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 3, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 3, 5, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 8, 3, 5, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 3, 5, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 2, 6, 6, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 2, 3, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 2, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 6, 3, 1, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 1, 1, 35, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 1, 2, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 1, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 3, 3, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 3, 4, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 1, 3, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 3, 3, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 4, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 2, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 3, 6, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 1, 3, 44, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 4, 6, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 3, 4, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 5, 1, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 8, 2, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 4, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 1, 3, 4, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 8, 3, 4, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 2, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 3, 2, 1, 9, 54);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 2, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 1, 2, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 8, 3, 4, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 7, 1, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 2, 1, 1, 34, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4988, 4, 4, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 6, 2, 1, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 3, 6, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 2, 3, 2, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 3, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 7, 2, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 2, 5, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 4, 1, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 7, 3, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 4, 1, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 6, 4, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 8, 2, 3, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 6, 3, 3, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 8, 2, 4, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 7, 3, 1, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 3, 1, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 3, 4, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 2, 3, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 5, 4, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 2, 2, 4, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 5, 3, 5, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 7, 3, 1, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 6, 4, 2, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 5, 3, 5, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 5, 3, 3, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 3, 2, 5, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 7, 4, 5, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 4, 1, 1, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 2, 4, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4989, 1, 1, 5, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 3, 3, 27, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 1, 4, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 3, 2, 37, 222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 3, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 1, 3, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 4, 5, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 3, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 1, 1, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 2, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 2, 3, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 4, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 1, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 4, 1, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 1, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 4, 2, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 4, 3, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 1, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 4, 3, 93, 1395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 3, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 4, 6, 94, 1598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 1, 4, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 4, 5, 65, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 3, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 3, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 4, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 3, 5, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 3, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 2, 6, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 3, 3, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 2, 4, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 1, 5, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 3, 4, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 4, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 1, 6, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 3, 3, 100, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 1, 1, 17, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 2, 1, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 1, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 1, 6, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 6, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 2, 1, 51, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 2, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 2, 5, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 4, 1, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 5, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 3, 5, 99, 1485);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 2, 5, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 1, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 3, 3, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 1, 2, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 2, 3, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 3, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 4, 1, 2, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 1, 1, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 4, 1, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 3, 1, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 1, 6, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 2, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 3, 6, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 6, 3, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 2, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 1, 4, 3, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 2, 2, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 5, 1, 1, 10, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 7, 4, 3, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 8, 2, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4990, 3, 4, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 5, 2, 6, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 1, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 8, 4, 4, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 6, 2, 2, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 3, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 2, 1, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 5, 3, 6, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 4, 5, 38, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 6, 2, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 2, 4, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 4, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 1, 3, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 8, 2, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 4, 1, 2, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 6, 3, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 1, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 8, 3, 6, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 8, 4, 3, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 1, 6, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 1, 3, 5, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 1, 1, 3, 13, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 8, 4, 2, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 1, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 1, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 3, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 3, 4, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 7, 2, 5, 49, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 4, 2, 1, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 6, 1, 4, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 3, 1, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4991, 5, 4, 6, 78, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 3, 3, 4, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 3, 3, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 5, 2, 4, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 6, 2, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 2, 4, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 5, 2, 4, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 4, 1, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 5, 4, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 8, 3, 3, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 3, 4, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 2, 3, 1, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 4, 2, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 7, 3, 2, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 1, 3, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 2, 4, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4992, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 2, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 1, 4, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 3, 6, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 1, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 2, 5, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 2, 6, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 4, 5, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 3, 1, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 4, 5, 55, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 1, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 3, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 2, 2, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 4, 5, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 2, 6, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 8, 3, 6, 18, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 2, 6, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 4, 5, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 3, 4, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 2, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 4, 6, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 3, 6, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 2, 1, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 3, 3, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 3, 4, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 3, 1, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 3, 6, 58, 928);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 3, 4, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 4, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 1, 2, 5, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 4, 5, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 1, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 4, 1, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 3, 6, 30, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 3, 4, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 3, 3, 3, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 6, 1, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 7, 1, 6, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5082, 2, 4, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 4, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 1, 1, 12, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 4, 4, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 1, 5, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 4, 2, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 1, 2, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 2, 6, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 2, 1, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 2, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 1, 6, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 3, 1, 94, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 2, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 2, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 1, 3, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 3, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 1, 3, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 3, 5, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 1, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 3, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 1, 2, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 1, 4, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 2, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 2, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 1, 1, 53, 159);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 2, 2, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 1, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 4, 6, 15, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 4, 5, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 3, 1, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 2, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 3, 4, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 3, 2, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 3, 4, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 2, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 1, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 4, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 1, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 2, 1, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 4, 6, 51, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 3, 2, 76, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 3, 6, 97, 1552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 2, 4, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 3, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 3, 2, 83, 747);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 4, 3, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 1, 6, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 2, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 2, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 2, 5, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 1, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 4, 6, 65, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 2, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 2, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 3, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 2, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 3, 1, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 3, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 2, 2, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 1, 3, 4, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 2, 3, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 1, 2, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 3, 2, 1, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 4, 6, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 4, 3, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 7, 2, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 2, 2, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 5, 2, 3, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 4, 1, 2, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 6, 1, 2, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 2, 1, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5083, 8, 2, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 2, 4, 47, 329);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 3, 5, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 1, 2, 29, 145);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 2, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 3, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 2, 1, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 1, 5, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 3, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 8, 2, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 8, 2, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 1, 5, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 3, 4, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 1, 6, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 2, 4, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 4, 1, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 3, 2, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 3, 1, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 4, 3, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 4, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 2, 1, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 3, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 2, 4, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 1, 6, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 3, 1, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 1, 2, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 4, 4, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 3, 2, 84, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 3, 4, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 1, 2, 8, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 4, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 3, 3, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 3, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 4, 1, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 4, 3, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 4, 4, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 4, 5, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 4, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 4, 6, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 4, 1, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 2, 4, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 2, 1, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 3, 4, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 3, 4, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 2, 6, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 1, 1, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 1, 4, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 4, 6, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 4, 2, 90, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 2, 3, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 8, 2, 6, 20, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 3, 3, 1, 31, 217);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 3, 2, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 1, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 4, 1, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 2, 4, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 6, 2, 6, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 7, 1, 5, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 8, 2, 6, 52, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5084, 1, 3, 6, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 3, 3, 5, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 7, 1, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 4, 4, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 3, 1, 6, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 2, 1, 2, 79, 395);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 7, 3, 4, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 6, 1, 5, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 6, 4, 1, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 3, 3, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 2, 4, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 8, 3, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 6, 3, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 8, 2, 6, 34, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 4, 3, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5085, 7, 3, 6, 61, 976);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 1, 3, 3, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 6, 2, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 5, 1, 1, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 3, 4, 74, 1110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 4, 1, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 3, 5, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 2, 2, 11, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 4, 3, 4, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 1, 4, 5, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 1, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 2, 5, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 6, 3, 1, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 6, 2, 5, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 3, 1, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 1, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 4, 2, 86, 1204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 1, 3, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 5, 1, 1, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 1, 3, 2, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 7, 1, 1, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 2, 2, 36, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 4, 1, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 2, 5, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 4, 4, 6, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 2, 1, 1, 11, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 8, 3, 5, 62, 992);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5086, 5, 3, 3, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 4, 2, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 2, 6, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 2, 4, 2, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 4, 3, 1, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 3, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 3, 2, 3, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 3, 4, 1, 46, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 2, 3, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 3, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 3, 3, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 1, 3, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 3, 2, 1, 60, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 4, 1, 1, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 3, 2, 2, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 8, 2, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 4, 4, 1, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 4, 3, 5, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 3, 2, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 3, 3, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 5, 2, 4, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 4, 3, 3, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 3, 5, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 2, 6, 69, 966);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 4, 1, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 2, 2, 4, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 1, 3, 5, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 1, 2, 3, 66, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 7, 1, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 2, 3, 4, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 8, 4, 6, 99, 1782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 2, 6, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5087, 6, 2, 3, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 1, 2, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 3, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 4, 5, 79, 1264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 4, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 4, 1, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 8, 4, 4, 21, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 2, 5, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 3, 2, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 3, 2, 5, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 4, 1, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 2, 5, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 3, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 1, 1, 1, 46, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 2, 1, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 4, 5, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 2, 3, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 2, 2, 6, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 1, 5, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 2, 4, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 2, 1, 6, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 6, 3, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 2, 1, 1, 69, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 1, 2, 3, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 5, 1, 6, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 4, 4, 1, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 3, 4, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 2, 3, 4, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 3, 6, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5088, 7, 3, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 3, 3, 4, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5089, 5, 3, 6, 67, 938);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 3, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 1, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 3, 2, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 3, 4, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 4, 6, 14, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 5, 1, 4, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 2, 1, 65, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 1, 2, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 1, 3, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 1, 1, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 4, 2, 6, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 2, 3, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 1, 6, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 5, 3, 4, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 4, 2, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 3, 2, 2, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 4, 3, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 4, 1, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 3, 5, 78, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 4, 1, 5, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 2, 4, 2, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 4, 1, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 4, 4, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 1, 3, 5, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 4, 4, 6, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 7, 1, 5, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 5, 1, 3, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 4, 3, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 3, 4, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 1, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 5, 3, 2, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 4, 3, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 1, 3, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 8, 2, 4, 7, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 2, 4, 2, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 2, 3, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5164, 6, 2, 3, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 1, 4, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 3, 4, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 6, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 1, 1, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 2, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 1, 4, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 1, 6, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 4, 1, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 2, 3, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 2, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 5, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 4, 5, 4, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 2, 1, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 2, 6, 4, 44);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 3, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 1, 3, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 4, 1, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 2, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 1, 2, 24, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 1, 3, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 4, 3, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 1, 22, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 4, 2, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 1, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 1, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 1, 6, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 1, 1, 56, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 1, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 4, 5, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 1, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 4, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 3, 3, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 3, 6, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 1, 3, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 2, 1, 85, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 2, 6, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 3, 2, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 4, 1, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 1, 3, 42, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 2, 30, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 1, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 3, 1, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 2, 6, 62, 682);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 3, 1, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 3, 5, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 4, 1, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 1, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 3, 2, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 6, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 6, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 1, 1, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 3, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 4, 1, 45, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 1, 6, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 3, 2, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 1, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 4, 5, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 3, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 3, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 3, 2, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 4, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 1, 4, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 3, 1, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 4, 5, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 4, 5, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 3, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 1, 2, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 3, 4, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 3, 3, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 1, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 3, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 4, 1, 33, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 1, 1, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 4, 3, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 4, 3, 51, 714);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 3, 5, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 4, 5, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 3, 1, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 1, 3, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 4, 1, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 1, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 8, 2, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 3, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 2, 2, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 1, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 2, 2, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 4, 2, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 6, 2, 2, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 7, 2, 3, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 5, 3, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5165, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 4, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 2, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 3, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 2, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 2, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 3, 4, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 2, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 5, 12, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 3, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 5, 94, 940);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 4, 4, 98, 1568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 3, 3, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 1, 3, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 3, 23, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 4, 1, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 2, 6, 4, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 3, 2, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 1, 2, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 1, 13, 78);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 2, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 4, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 3, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 1, 3, 64, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 2, 2, 74, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 4, 2, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 6, 14, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 5, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 3, 4, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 3, 3, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 4, 2, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 2, 3, 90, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 1, 90, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 6, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 1, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 3, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 4, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 2, 53, 265);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 4, 13, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 3, 6, 49, 833);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 1, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 4, 87, 609);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 6, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 1, 1, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 2, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 1, 4, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 4, 1, 77, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 4, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 3, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 1, 5, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 2, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 4, 3, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 4, 1, 28, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 3, 6, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 3, 3, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 4, 4, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 4, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 4, 1, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 1, 6, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 3, 2, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 1, 1, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 2, 54, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 6, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 1, 6, 8, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 2, 1, 36, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 3, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 2, 1, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 4, 6, 75, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 2, 6, 12, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 2, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 4, 1, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 4, 6, 41, 533);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 2, 5, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 6, 2, 6, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 2, 1, 1, 20, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 1, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 1, 20, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 1, 6, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 1, 3, 99, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 4, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 2, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 1, 4, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 4, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 4, 1, 83, 1079);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 5, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 8, 2, 2, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 7, 1, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 5, 2, 4, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 3, 2, 5, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5166, 4, 3, 2, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 3, 3, 1, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 3, 3, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 3, 3, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 1, 3, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 1, 6, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 4, 1, 2, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 1, 4, 4, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 5, 4, 3, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 2, 3, 6, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5167, 8, 2, 3, 25, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 4, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 2, 1, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 3, 2, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 3, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 5, 1, 4, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 1, 5, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 3, 6, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 5, 2, 3, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 1, 4, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 1, 1, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 4, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 1, 4, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 1, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 4, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 3, 2, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 2, 4, 55, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 1, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 6, 4, 2, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 4, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 4, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 4, 4, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 2, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 5, 3, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 3, 4, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 2, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 6, 1, 5, 9, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 3, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 3, 3, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 2, 6, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 3, 1, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 2, 3, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 2, 6, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 6, 4, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 3, 4, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 4, 3, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 1, 2, 3, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 1, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 4, 2, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 4, 1, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 4, 2, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 2, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 1, 2, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 7, 1, 5, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 3, 3, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 2, 3, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4920, 8, 3, 3, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 2, 6, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 3, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 3, 6, 1, 17);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 1, 5, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 2, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 4, 2, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 2, 6, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 1, 5, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 1, 6, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 2, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 3, 5, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 1, 6, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 3, 5, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 3, 1, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 2, 5, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 2, 4, 73, 876);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 1, 1, 55, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 4, 4, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 3, 2, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 2, 3, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 2, 1, 67, 335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 2, 1, 33, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 1, 2, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 2, 2, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 1, 3, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 1, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 4, 4, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 3, 5, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 2, 2, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 3, 3, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 3, 3, 93, 651);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 1, 4, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 2, 2, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 2, 5, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 4, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 2, 5, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 3, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 3, 3, 33, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 4, 4, 76, 1216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 1, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 2, 3, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 2, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 4, 1, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 1, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 4, 3, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 3, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 2, 3, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 1, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 1, 5, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 7, 4, 4, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 8, 4, 5, 4, 68);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 2, 3, 4, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 6, 1, 1, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 1, 2, 1, 99, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 5, 4, 3, 89, 1068);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4921, 3, 1, 5, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 7, 2, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 3, 1, 5, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 4, 4, 2, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 5, 4, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 3, 1, 2, 42, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 5, 1, 1, 30, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 1, 2, 2, 30, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 5, 1, 3, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 7, 3, 5, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 3, 1, 4, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 1, 3, 3, 27, 189);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 3, 1, 1, 71, 355);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 2, 3, 2, 89, 623);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 4, 4, 3, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4922, 3, 2, 5, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 2, 1, 1, 8, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 1, 2, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 1, 4, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 1, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 2, 6, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 1, 6, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 2, 4, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 2, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 1, 4, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 4, 2, 3, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 8, 2, 5, 31, 465);
commit;
prompt 181000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 2, 1, 1, 23, 92);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 4, 4, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 4, 4, 4, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 1, 1, 5, 51, 357);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 1, 1, 64, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 1, 4, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 2, 1, 6, 34, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 3, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 4, 2, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 1, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 1, 3, 3, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 6, 1, 3, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 3, 4, 3, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 8, 3, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 7, 4, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 2, 2, 2, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 5, 4, 6, 53, 795);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4923, 2, 2, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 3, 5, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 4, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 3, 6, 56, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 2, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 4, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 1, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 3, 3, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 1, 89, 445);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 1, 3, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 3, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 4, 3, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 1, 4, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 3, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 2, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 3, 1, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 1, 6, 1, 11);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 4, 4, 13, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 3, 1, 86, 946);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 2, 1, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 4, 2, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 1, 4, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 1, 5, 15, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 1, 6, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 1, 4, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 3, 5, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 2, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 1, 3, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 4, 6, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 3, 4, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 4, 1, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 3, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 1, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 3, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 1, 6, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 2, 11, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 4, 5, 16, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 3, 66, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 3, 5, 17, 255);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 4, 5, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 4, 3, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 3, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 4, 1, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 4, 2, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 4, 5, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 2, 2, 71, 568);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 5, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 5, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 2, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 2, 4, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 1, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 1, 63, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 4, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 2, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 3, 6, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 2, 3, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 3, 3, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 1, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 4, 5, 43, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 3, 1, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 3, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 2, 4, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 4, 6, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 1, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 2, 6, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 3, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 4, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 1, 4, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 3, 1, 86, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 1, 2, 5, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 2, 6, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 3, 5, 9, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 2, 1, 5, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 3, 6, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 4, 2, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 3, 6, 89, 1513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 6, 2, 4, 31, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 3, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 3, 1, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 1, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 3, 2, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 7, 2, 3, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 3, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 1, 4, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 1, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 4, 3, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 3, 1, 3, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 2, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 1, 5, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 8, 1, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4924, 4, 3, 5, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 4, 3, 60, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 2, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 3, 2, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 4, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 1, 2, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 4, 5, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 1, 2, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 2, 4, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 3, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 1, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 4, 4, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 2, 2, 1, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 4, 2, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 2, 3, 2, 4, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 5, 4, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 7, 3, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 4, 5, 38, 646);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 4, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 2, 5, 100, 1500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 8, 4, 6, 6, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 4, 2, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 6, 1, 1, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 3, 4, 6, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4925, 1, 3, 3, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 2, 6, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 3, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 3, 6, 88, 1320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 2, 3, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 4, 6, 33, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 3, 3, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 1, 6, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 2, 6, 60, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 4, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 1, 6, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 1, 2, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 1, 6, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 3, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 4, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 2, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 4, 3, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 4, 1, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 4, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 3, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 2, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 3, 5, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 3, 2, 2, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 1, 4, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 3, 3, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 1, 1, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 3, 2, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 1, 6, 26, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 3, 2, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 4, 4, 92, 1472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 4, 5, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 3, 6, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 2, 5, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 1, 6, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 4, 4, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 1, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 2, 4, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 1, 88, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 2, 3, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 1, 6, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 4, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 4, 2, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 1, 2, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 3, 1, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 3, 1, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 3, 4, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 1, 1, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 3, 1, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 2, 2, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 5, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 3, 1, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 4, 4, 85, 1275);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 3, 2, 6, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 6, 1, 1, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 3, 2, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 1, 6, 81, 1215);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 1, 4, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 5, 1, 3, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 4, 4, 26, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 4, 8, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 1, 3, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 3, 1, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 3, 6, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 1, 3, 6, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 2, 4, 5, 33, 363);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 7, 4, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 8, 1, 5, 14, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4993, 4, 4, 2, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 4, 5, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 3, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 3, 5, 28, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 3, 1, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 2, 6, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 4, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 3, 5, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 3, 6, 11, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 2, 2, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 4, 5, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 3, 3, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 4, 3, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 1, 3, 72, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 2, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 2, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 2, 5, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 2, 5, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 1, 4, 55, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 4, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 2, 1, 86, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 1, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 2, 3, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 2, 3, 85, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 4, 2, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 4, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 2, 3, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 3, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 4, 5, 26, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 2, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 4, 2, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 2, 4, 75, 1050);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 1, 2, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 4, 3, 74, 1036);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 2, 2, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 1, 6, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 2, 3, 40, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 4, 4, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 1, 6, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 1, 5, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 2, 2, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 1, 3, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 1, 1, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 4, 5, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 1, 1, 19, 76);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 2, 1, 5, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 3, 6, 99, 1386);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 1, 2, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 2, 6, 59, 944);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 3, 2, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 7, 4, 6, 31, 527);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 3, 6, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 2, 4, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 3, 2, 19, 247);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 1, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 2, 5, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 1, 2, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 2, 5, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 3, 2, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 3, 3, 18, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 1, 4, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 1, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 1, 3, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 8, 4, 2, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 3, 5, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 1, 2, 78, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 1, 1, 79, 553);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 3, 2, 3, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 5, 2, 5, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4994, 6, 4, 4, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 6, 2, 2, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 7, 3, 1, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 4, 3, 6, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 7, 4, 1, 46, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 4, 4, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 3, 1, 2, 70, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 5, 4, 2, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 6, 4, 2, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 4, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 7, 3, 6, 15, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 1, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 2, 3, 4, 39, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 7, 4, 3, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 4, 3, 2, 71, 639);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 4, 4, 2, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 1, 2, 4, 35, 245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 1, 3, 2, 82, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 6, 1, 6, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 3, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 7, 1, 6, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 8, 2, 6, 86, 1376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 6, 1, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 5, 2, 3, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 1, 3, 6, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 2, 3, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4995, 1, 1, 5, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 1, 3, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 3, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 2, 2, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 6, 4, 5, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 3, 5, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 5, 3, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 4, 1, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 3, 3, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 1, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 5, 3, 1, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 6, 3, 3, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 2, 3, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 5, 3, 3, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 4, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 2, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 2, 4, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 1, 5, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 2, 3, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 3, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 4, 2, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 6, 3, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 4, 1, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 1, 5, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 1, 2, 62, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 3, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 4, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 3, 3, 52, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 5, 4, 3, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 1, 4, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 2, 4, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 4, 60, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 3, 1, 47, 564);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 4, 9, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 4, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 1, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 4, 3, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 2, 2, 4, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 6, 1, 5, 52, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 3, 4, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 2, 2, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 1, 1, 48, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 7, 1, 1, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 8, 2, 6, 91, 1456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4996, 5, 3, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 4, 4, 74, 814);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 4, 2, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 1, 4, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 4, 6, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 3, 2, 5, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 3, 6, 27, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 1, 1, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 3, 3, 40, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 1, 2, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 2, 2, 8);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 4, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 3, 4, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 4, 4, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 1, 5, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 4, 1, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 4, 1, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 4, 2, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 8, 4, 5, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 5, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 4, 2, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 4, 5, 92, 1288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 2, 1, 96, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 3, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 1, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 1, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 2, 6, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 2, 3, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 2, 4, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 4, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 3, 1, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 1, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 2, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 7, 2, 5, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 3, 5, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 2, 4, 64, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 1, 6, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 3, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 4, 6, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 2, 4, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 4, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 2, 4, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 2, 1, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 2, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 1, 5, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 2, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 2, 5, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 4, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 2, 1, 1, 68, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 2, 1, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 4, 5, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 6, 4, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 4, 2, 1, 25, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 5, 3, 6, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (4997, 3, 4, 3, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 3, 2, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 7, 3, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 6, 4, 1, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 7, 1, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 2, 1, 1, 60, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 2, 4, 6, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 3, 4, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 7, 2, 5, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 7, 1, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 4, 4, 3, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 5, 3, 3, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 3, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 4, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 5, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 3, 3, 87, 1044);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 4, 4, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 4, 4, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 7, 3, 1, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 2, 3, 73, 584);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 2, 6, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 6, 36, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 1, 2, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 2, 4, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 5, 59, 708);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 4, 3, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 2, 6, 80, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 4, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 3, 2, 64, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 2, 6, 5, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 1, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 3, 1, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 4, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 1, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 2, 3, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 1, 1, 31, 93);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 4, 6, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 4, 4, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 3, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 8, 2, 2, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 2, 6, 6, 66);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 2, 6, 29, 377);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 4, 1, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 1, 5, 98, 686);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 3, 4, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 1, 2, 62, 372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 1, 5, 58, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 3, 63, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 4, 6, 95, 1425);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 4, 1, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 3, 6, 48, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 3, 2, 3, 33);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 3, 4, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 1, 4, 96, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 3, 4, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 2, 3, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 3, 5, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 3, 6, 6, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 2, 6, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 2, 5, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 4, 5, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 1, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 8, 3, 5, 46, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 2, 6, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 2, 6, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 3, 1, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 4, 4, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 4, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 3, 4, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 1, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 4, 4, 72, 1080);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 1, 3, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 4, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 4, 3, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 4, 6, 7, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 8, 2, 2, 38, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 4, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 4, 6, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 1, 4, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 1, 2, 93, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 4, 1, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 2, 2, 4, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 2, 3, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 4, 5, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 2, 2, 30, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 2, 3, 53, 636);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 4, 6, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 1, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 3, 3, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 1, 43, 301);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 3, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 2, 5, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 1, 1, 43, 129);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 8, 4, 4, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 1, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 2, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 4, 6, 29, 319);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 3, 3, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 7, 3, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 5, 4, 5, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 1, 4, 6, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5220, 6, 1, 2, 98, 882);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 5, 1, 3, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 4, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 3, 2, 3, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 3, 2, 5, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 5, 3, 6, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 3, 3, 5, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 1, 2, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 4, 3, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 3, 3, 3, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 3, 6, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 2, 4, 4, 71, 710);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 4, 2, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 7, 4, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 8, 2, 4, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5221, 8, 4, 4, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 2, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 8, 3, 6, 59, 1003);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 3, 5, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 3, 4, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 3, 3, 73, 949);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 3, 5, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 4, 2, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 4, 1, 5, 62, 620);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 2, 2, 1, 62, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 4, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 2, 1, 4, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 2, 4, 6, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 1, 6, 13, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 2, 2, 5, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 4, 4, 2, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 1, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 3, 6, 81, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 8, 4, 3, 87, 1305);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 8, 2, 5, 43, 645);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 1, 6, 57, 798);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 1, 5, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 1, 1, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 1, 5, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 4, 2, 5, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 6, 4, 2, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 2, 1, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 7, 1, 3, 41, 451);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 1, 2, 3, 17, 102);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 3, 4, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 5, 4, 3, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 8, 4, 5, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 1, 4, 6, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 3, 4, 2, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 4, 2, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5222, 1, 1, 4, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 2, 4, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 5, 4, 2, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 4, 5, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 2, 2, 6, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 2, 4, 4, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 1, 2, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 2, 5, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 3, 4, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 4, 5, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 7, 3, 3, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 5, 3, 2, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 2, 4, 26, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 4, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 2, 5, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 1, 6, 82, 1066);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 4, 1, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 1, 3, 56, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 3, 2, 51, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 2, 5, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 4, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 7, 4, 1, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 1, 4, 43, 387);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 4, 5, 100, 1000);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 2, 2, 47, 470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 1, 1, 8, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 1, 1, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 1, 4, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 1, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 1, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 2, 4, 89, 801);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 1, 4, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 2, 1, 5, 63, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 1, 6, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 2, 1, 35, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 4, 2, 76, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 3, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 3, 2, 3, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 2, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 2, 1, 49, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 4, 5, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 2, 1, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 7, 4, 1, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 1, 1, 3, 41, 205);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 2, 1, 5, 43, 344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 5, 1, 4, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 5, 1, 4, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 8, 4, 5, 62, 1054);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 5, 1, 6, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 3, 3, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 4, 4, 5, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5223, 6, 4, 4, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 2, 1, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 3, 3, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 2, 3, 6, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 8, 2, 6, 39, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 8, 1, 5, 39, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 7, 1, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 1, 6, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 8, 3, 6, 74, 1258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 4, 1, 58, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 3, 1, 2, 39, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 2, 3, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 5, 1, 2, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 1, 4, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 4, 3, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 3, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 2, 3, 2, 85, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 2, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 8, 1, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 5, 4, 3, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 1, 3, 4, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 1, 4, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 1, 4, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 3, 1, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 4, 4, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 2, 4, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 3, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 1, 1, 17, 51);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 7, 2, 6, 44, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 3, 2, 5, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 8, 3, 4, 56, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 1, 6, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 5, 2, 6, 53, 689);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 3, 6, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 4, 6, 71, 1136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 5, 1, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 4, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 3, 1, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 2, 1, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 3, 5, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 1, 2, 4, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 2, 6, 25, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 4, 1, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 7, 4, 6, 46, 782);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 7, 1, 4, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 2, 4, 5, 100, 1100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 3, 2, 2, 33, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 5, 3, 1, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 7, 4, 1, 57, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 2, 5, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5225, 6, 1, 2, 23, 207);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 3, 6, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 7, 2, 4, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 3, 2, 1, 74, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 6, 3, 6, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 6, 4, 4, 87, 1218);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 3, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 1, 3, 21);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 1, 1, 5, 67, 469);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 3, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 4, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 2, 5, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 2, 3, 6, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 6, 3, 6, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 3, 2, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 7, 2, 1, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 8, 2, 5, 82, 1230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 1, 2, 5, 53, 424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 4, 1, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 2, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 1, 3, 4, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 4, 3, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 6, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 1, 2, 4, 50, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 3, 4, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 8, 1, 5, 46, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 3, 2, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 1, 96, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 4, 1, 3, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 3, 1, 5, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5226, 5, 1, 2, 92, 736);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 1, 6, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 2, 1, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 3, 1, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 4, 5, 84, 1176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 1, 4, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 1, 5, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 1, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 2, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 3, 3, 94, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 4, 6, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 1, 5, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 4, 2, 26, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 4, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 3, 6, 59, 649);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 3, 2, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 1, 3, 3, 15);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 4, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 2, 3, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 1, 5, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 3, 4, 59, 826);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 1, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 1, 3, 15, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 4, 13, 169);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 1, 2, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 2, 5, 10, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 4, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 3, 1, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 1, 5, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 4, 1, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 4, 1, 29, 261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 2, 3, 15, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 2, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 1, 100, 1300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 2, 4, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 1, 5, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 1, 1, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 1, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 1, 42, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 4, 3, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 3, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 4, 3, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 1, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 4, 5, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 2, 2, 44, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 1, 41, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 3, 1, 69, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 4, 5, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 4, 4, 42, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 1, 6, 73, 1022);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 4, 4, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 2, 6, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 3, 6, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 3, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 4, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 3, 1, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 1, 1, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 5, 5, 85);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 1, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 3, 3, 88, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 2, 6, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 4, 3, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 2, 2, 16, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 1, 1, 23, 138);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 2, 4, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 1, 2, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 2, 5, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 3, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 2, 6, 36, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 2, 3, 1, 18, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 2, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 3, 58, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 2, 2, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 3, 2, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 3, 3, 44, 484);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 4, 6, 11, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 4, 5, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 3, 3, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 2, 1, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 2, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 2, 2, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 4, 4, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 3, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 2, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 2, 1, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 1, 2, 22, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 4, 2, 19, 133);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 1, 2, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 4, 4, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 4, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 7, 2, 1, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 3, 6, 8, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 5, 4, 4, 71, 923);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 4, 3, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 1, 2, 6, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 3, 3, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 3, 2, 3, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 8, 3, 2, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5227, 6, 4, 2, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 4, 3, 1, 100, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 6, 4, 5, 94, 1410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 1, 4, 4, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 7, 4, 6, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 3, 4, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 4, 5, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 1, 3, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 7, 4, 3, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 8, 4, 3, 64, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 2, 2, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 5, 4, 1, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 1, 2, 6, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 8, 3, 4, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 4, 3, 2, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 3, 3, 3, 59, 531);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 1, 1, 4, 91, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 4, 4, 3, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 4, 2, 2, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 6, 4, 6, 50, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 3, 3, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 1, 1, 4, 41, 246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 3, 4, 2, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 1, 2, 4, 29, 203);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 6, 4, 4, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 4, 1, 4, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 7, 2, 5, 71, 994);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 8, 1, 4, 80, 1040);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 6, 4, 5, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 2, 4, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 3, 2, 5, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 5, 3, 4, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5229, 6, 2, 1, 88, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 6, 4, 1, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 4, 2, 14, 98);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 1, 4, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 6, 1, 5, 32, 384);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 2, 5, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 3, 4, 3, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 1, 3, 83, 996);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 2, 6, 99, 1188);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 2, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 3, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 1, 4, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 1, 3, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 6, 2, 4, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 7, 1, 6, 58, 812);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 6, 4, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 7, 2, 6, 5, 75);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 2, 4, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 2, 4, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 3, 2, 25, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 2, 1, 12, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 4, 3, 32, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 2, 1, 2, 88, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 2, 3, 6, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 1, 2, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 7, 2, 4, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 1, 2, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 2, 2, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 1, 4, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 8, 2, 3, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 3, 1, 4, 58, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 2, 1, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5230, 4, 3, 6, 37, 481);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 1, 2, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 4, 6, 63, 1134);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 3, 3, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 2, 3, 92, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 2, 5, 25);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 4, 2, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 3, 1, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 3, 6, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 2, 6, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 4, 2, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 4, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 3, 4, 3, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 1, 4, 69, 828);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 1, 2, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 5, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 6, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 2, 4, 91, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 4, 3, 39, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 2, 4, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 4, 6, 82, 902);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 5, 2, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 1, 43, 172);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 4, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 4, 5, 15, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 1, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 2, 2, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 6, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 2, 4, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 3, 4, 32, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 2, 3, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 3, 3, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 3, 1, 47, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 3, 1, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 2, 5, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 3, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 2, 4, 2, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 2, 2, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 2, 3, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 3, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 4, 2, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 3, 4, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 3, 4, 67, 603);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 1, 1, 38, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 1, 5, 64, 832);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 2, 2, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 2, 2, 49, 343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 3, 1, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 3, 3, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 4, 4, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 4, 5, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 4, 1, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 2, 1, 6, 100, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 4, 3, 90, 1350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 1, 2, 25, 225);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 5, 2, 5, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 1, 3, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 2, 4, 82, 1148);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 3, 1, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 1, 6, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 6, 3, 6, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 3, 1, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 8, 3, 4, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 3, 2, 5, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 4, 2, 6, 1, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 7, 2, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5231, 1, 3, 2, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 3, 1, 6, 9, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 1, 49, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 1, 6, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 3, 3, 2, 95, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 4, 1, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 1, 5, 39, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 3, 2, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 1, 5, 12, 132);
commit;
prompt 182000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 4, 5, 100, 1700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 3, 2, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 4, 3, 97, 1358);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 4, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 3, 5, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 3, 6, 24, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 1, 6, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 2, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 2, 2, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 4, 4, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 1, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 3, 1, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 1, 3, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 3, 1, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 2, 3, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 3, 3, 55, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 4, 4, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 1, 1, 92, 552);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 2, 4, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 4, 3, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 2, 6, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 2, 6, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 4, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 2, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 1, 2, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 3, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 3, 4, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 1, 1, 71, 284);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 2, 4, 70, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 3, 1, 19, 95);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 2, 1, 68, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 1, 6, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 2, 3, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 2, 3, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 2, 1, 29, 290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 4, 2, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 4, 5, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 4, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 3, 1, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 2, 3, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 6, 3, 1, 61, 610);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 2, 3, 61, 366);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 2, 4, 6, 2, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 3, 4, 4, 67, 737);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 4, 4, 64, 1024);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 2, 5, 64, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 1, 3, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 3, 6, 89, 1424);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 1, 4, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 7, 4, 1, 54, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 4, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 2, 5, 3, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 1, 5, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 3, 3, 1, 1, 7);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 4, 1, 2, 7, 49);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 5, 3, 6, 12, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5232, 8, 4, 3, 83, 1245);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 7, 4, 3, 37, 518);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 7, 4, 2, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 3, 2, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 6, 3, 1, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 4, 1, 5, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 3, 1, 6, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 3, 2, 1, 46, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 2, 4, 4, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 8, 3, 1, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 8, 3, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 7, 1, 2, 95, 950);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 8, 1, 5, 95, 1330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 8, 4, 4, 73, 1168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 1, 4, 1, 48, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 8, 3, 5, 93, 1488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5233, 4, 3, 6, 79, 1027);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 1, 1, 61, 244);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 3, 92, 644);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 2, 1, 100, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 1, 23, 115);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 2, 4, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 4, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 1, 2, 77, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 6, 7, 91);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 4, 2, 95, 665);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 3, 4, 19, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 3, 5, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 3, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 2, 5, 38, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 2, 3, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 3, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 4, 3, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 1, 4, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 5, 60, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 4, 6, 64, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 2, 6, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 3, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 1, 4, 38, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 2, 1, 5, 35);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 2, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 4, 80, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 4, 3, 32, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 3, 2, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 3, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 3, 3, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 4, 5, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 1, 4, 69, 759);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 1, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 1, 3, 99, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 1, 3, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 5, 16, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 1, 88, 1144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 2, 3, 29, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 4, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 3, 17, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 3, 73, 511);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 4, 5, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 3, 6, 16, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 4, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 4, 2, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 5, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 1, 1, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 4, 2, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 3, 3, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 3, 2, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 3, 3, 97, 776);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 2, 5, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 2, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 2, 3, 56, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 2, 5, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 4, 2, 94, 1222);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 3, 2, 13, 104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 5, 22, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 1, 4, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 2, 2, 89, 979);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 1, 2, 34, 170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 1, 4, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 3, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 1, 4, 93, 1209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 4, 1, 85, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 4, 6, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 1, 6, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 4, 2, 19, 209);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 4, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 1, 2, 6, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 3, 6, 49, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 7, 2, 1, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 4, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 4, 1, 76, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 2, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 2, 4, 44, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 4, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 4, 5, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 2, 79, 474);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 2, 5, 90, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 2, 1, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 1, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 2, 4, 25, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 1, 2, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 1, 6, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 4, 2, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 5, 1, 2, 50, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 2, 74, 666);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 4, 2, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 3, 5, 91, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 5, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 3, 6, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 4, 1, 2, 52, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 3, 6, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 1, 18, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 6, 4, 4, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 2, 2, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 8, 1, 6, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5234, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 1, 2, 5, 16, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 3, 3, 6, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 4, 2, 4, 16, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 5, 3, 3, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 2, 6, 36, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 8, 2, 3, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 8, 4, 5, 64, 1088);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 1, 4, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 4, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 6, 3, 4, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 3, 6, 29, 464);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 1, 3, 4, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 4, 5, 96, 1536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 1, 1, 3, 91, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 2, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 6, 3, 3, 79, 948);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 1, 6, 53, 477);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 6, 1, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 3, 6, 22, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 4, 1, 80, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 3, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 3, 1, 5, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 1, 3, 3, 70, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 4, 2, 2, 66, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 6, 1, 4, 98, 1078);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 8, 3, 5, 63, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 5, 4, 1, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 6, 2, 4, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 7, 3, 1, 48, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 3, 4, 3, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 2, 4, 1, 72, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5235, 5, 4, 3, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 3, 4, 2, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 1, 2, 90, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 2, 3, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 2, 5, 89, 712);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 1, 5, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 3, 1, 82, 820);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 3, 5, 6, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 1, 5, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 1, 6, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 3, 4, 8, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 1, 6, 10, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 4, 2, 16, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 4, 2, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 2, 5, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 2, 1, 39, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 4, 1, 4, 13, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 5, 4, 2, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 3, 1, 75, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 4, 6, 92, 1012);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 4, 2, 3, 26, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 1, 4, 84, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 3, 4, 8, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 3, 1, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 3, 4, 47, 705);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 2, 3, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 3, 1, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 1, 1, 72, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 4, 1, 5, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 2, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 3, 6, 19, 304);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 2, 1, 19, 190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 2, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 1, 5, 65, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 5, 1, 3, 40, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 2, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 4, 3, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 5, 1, 3, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 4, 4, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 2, 1, 6, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 1, 3, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 1, 3, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 5, 3, 4, 45, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 3, 4, 3, 34, 340);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 5, 4, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 7, 4, 2, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 8, 2, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 2, 4, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 1, 1, 4, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5236, 6, 4, 1, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 1, 6, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 4, 3, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 2, 5, 78, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 3, 3, 92, 920);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 2, 2, 6, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 1, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 3, 3, 39);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 4, 4, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 2, 6, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 2, 5, 63, 945);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 4, 2, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 2, 5, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 4, 21, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 1, 6, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 3, 1, 56, 448);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 4, 6, 86, 1462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 3, 24, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 1, 1, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 2, 5, 66, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 6, 56, 896);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 1, 1, 59, 472);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 2, 3, 2, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 2, 2, 65, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 4, 6, 35, 595);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 2, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 2, 6, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 1, 3, 66, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 4, 3, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 4, 2, 81, 729);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 1, 2, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 4, 4, 42, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 4, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 3, 5, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 2, 2, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 4, 4, 56, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 2, 2, 43, 473);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 1, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 2, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 4, 1, 68, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 1, 3, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 2, 5, 46, 598);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 2, 5, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 1, 1, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 4, 1, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 2, 6, 56, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 3, 6, 61, 915);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 1, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 1, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 1, 1, 100, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 4, 1, 53, 318);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 2, 2, 28, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 3, 6, 81, 972);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 1, 6, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 2, 56, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 2, 2, 37, 333);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 1, 1, 19, 152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 1, 1, 3, 46, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 3, 4, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 4, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 1, 4, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 2, 3, 3, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 4, 2, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 7, 3, 4, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 6, 4, 6, 26, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 8, 1, 1, 75, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 3, 4, 6, 76, 988);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5237, 5, 3, 3, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 3, 5, 27, 351);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 2, 5, 7, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 2, 3, 84, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 7, 3, 3, 69, 897);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 1, 1, 32, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 2, 3, 88, 880);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 8, 3, 4, 79, 1185);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 2, 5, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 8, 4, 2, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 2, 2, 69, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 6, 1, 1, 57, 456);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 6, 4, 2, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 8, 1, 1, 25, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 2, 1, 75, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 4, 1, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 3, 6, 52, 676);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 1, 2, 5, 49, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 7, 4, 5, 17, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 3, 3, 91, 728);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 4, 6, 17, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 6, 2, 1, 68, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 7, 4, 4, 86, 1290);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 8, 2, 1, 52, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 2, 5, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 8, 2, 6, 57, 912);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 6, 2, 1, 69, 621);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 1, 6, 41, 492);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 2, 4, 4, 80, 800);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 1, 2, 2, 28, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 6, 2, 4, 71, 852);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 5, 2, 2, 77, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 2, 3, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 3, 3, 2, 60, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 4, 1, 3, 75, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5239, 3, 4, 6, 86, 1118);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 2, 5, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 8, 1, 2, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 1, 5, 99, 990);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 1, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 7, 3, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 3, 3, 3, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 6, 3, 5, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 3, 2, 6, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 4, 6, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 2, 1, 61, 427);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 1, 1, 3, 65, 325);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 3, 1, 4, 96, 768);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 3, 2, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 3, 3, 5, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 2, 5, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 6, 1, 6, 87, 1131);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 3, 6, 79, 1106);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 2, 4, 4, 69, 690);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 7, 3, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 1, 2, 17, 136);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 7, 2, 2, 61, 671);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 3, 2, 1, 43, 258);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 4, 1, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 2, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 2, 4, 5, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 1, 3, 1, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 2, 3, 3, 27);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 8, 2, 5, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 4, 4, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 7, 1, 3, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 3, 4, 63, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 5, 3, 1, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 6, 1, 3, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 2, 3, 5, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5240, 4, 2, 3, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 1, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 1, 1, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 1, 2, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 3, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 3, 5, 35, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 4, 2, 90, 1170);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 1, 3, 44, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 4, 4, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 3, 3, 85, 1020);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 2, 1, 52, 416);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 3, 3, 33, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 1, 4, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 4, 6, 10, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 2, 5, 40, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 2, 10, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 2, 1, 9);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 3, 6, 2, 34);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 3, 27, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 3, 3, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 4, 5, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 4, 4, 14, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 1, 4, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 3, 6, 36, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 4, 5, 90, 1530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 4, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 2, 5, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 1, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 4, 77, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 1, 5, 23, 276);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 1, 8, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 4, 2, 61, 854);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 3, 1, 81, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 5, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 1, 5, 59, 413);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 1, 6, 24, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 4, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 1, 2, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 2, 1, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 1, 72, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 1, 4, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 3, 3, 20, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 1, 6, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 2, 85, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 3, 3, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 3, 2, 51, 663);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 2, 2, 69, 345);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 1, 2, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 2, 5, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 2, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 3, 3, 83, 581);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 4, 1, 28, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 3, 5, 35, 490);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 3, 5, 93, 837);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 2, 2, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 3, 4, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 2, 6, 75, 825);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 4, 1, 84, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 4, 2, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 2, 12, 108);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 4, 1, 71, 426);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 5, 35, 315);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 1, 2, 93, 1023);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 3, 4, 53, 530);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 4, 1, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 3, 4, 76, 684);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 3, 4, 40, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 1, 3, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 2, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 4, 5, 32, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 1, 5, 49, 539);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 4, 3, 29, 406);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 3, 6, 38, 418);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 4, 2, 79, 869);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 3, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 2, 6, 72, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 4, 6, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 4, 6, 25, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 2, 5, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 3, 6, 11, 121);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 5, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 1, 5, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 4, 5, 31, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 4, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 1, 4, 73, 438);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 6, 43, 559);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 6, 31, 310);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 3, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 7, 2, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 4, 3, 37, 296);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 5, 86, 1032);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 1, 1, 95, 285);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 3, 5, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 2, 5, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 6, 4, 6, 78, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 4, 2, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 1, 5, 82, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 2, 4, 6, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 3, 4, 1, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 1, 4, 1, 13);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 1, 3, 2, 54, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 5, 3, 4, 95, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 2, 4, 6, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 8, 2, 3, 30, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5241, 4, 4, 1, 38, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 3, 4, 55, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 4, 4, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 4, 6, 27, 459);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 2, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 2, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 3, 2, 99, 1287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 4, 1, 1, 19, 114);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 2, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 5, 4, 3, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 2, 2, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 2, 5, 47, 658);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 2, 1, 80, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 4, 1, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 5, 2, 2, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 4, 6, 77, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 1, 3, 83, 830);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 1, 1, 98, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 4, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 3, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 3, 2, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 3, 3, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 2, 5, 33, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 5, 1, 4, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 4, 2, 6, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 1, 5, 34, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 5, 3, 1, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 3, 6, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 1, 6, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 4, 1, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 3, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 3, 3, 70, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 3, 4, 55, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 3, 1, 13, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 4, 2, 1, 37, 259);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 3, 3, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 4, 5, 79, 1343);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 1, 6, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 8, 1, 6, 38, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 2, 6, 42, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 2, 6, 89, 1246);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 4, 2, 89, 1157);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 5, 3, 3, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 3, 1, 95, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 3, 3, 4, 85, 850);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 2, 4, 5, 27, 297);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 2, 3, 86, 516);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 1, 3, 5, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 6, 2, 6, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 2, 6, 18, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 3, 6, 36, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5242, 7, 3, 3, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 1, 1, 11, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 1, 4, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 8, 1, 5, 19, 266);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 2, 4, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 2, 1, 23, 161);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 3, 6, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 4, 6, 45, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 2, 1, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 1, 5, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 3, 5, 91, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 8, 2, 5, 73, 1095);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 3, 4, 1, 90, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 3, 2, 1, 49, 294);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 2, 4, 1, 78, 546);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 2, 4, 3, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 4, 3, 45, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 5, 1, 5, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 4, 5, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 1, 4, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 2, 6, 67, 804);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 2, 4, 30, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 5, 3, 2, 58, 580);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 8, 3, 4, 45, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 3, 1, 5, 97, 873);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 3, 3, 29, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 5, 4, 2, 23, 253);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 3, 1, 4, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 4, 1, 1, 4, 24);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 1, 3, 5, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 3, 1, 6, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 7, 4, 4, 98, 1470);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 6, 3, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5243, 2, 4, 1, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 1, 3, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 3, 6, 63, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 8, 1, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 3, 4, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 2, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 5, 3, 3, 70, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 8, 1, 1, 23, 230);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 7, 3, 6, 60, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 3, 2, 47, 282);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 2, 4, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 3, 2, 5, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 1, 6, 73, 803);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 7, 3, 1, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 1, 1, 9, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 3, 6, 70, 700);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 4, 6, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 1, 2, 50, 250);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 1, 3, 16, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 4, 2, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 1, 2, 54, 486);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 1, 2, 6, 91, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 3, 1, 4, 39, 312);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 5, 2, 3, 97, 970);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 2, 3, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 1, 2, 47, 423);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 5, 3, 2, 43, 430);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 7, 2, 6, 76, 1140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 8, 2, 4, 23, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 1, 3, 35, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 3, 5, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 3, 4, 20, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 3, 5, 4, 48);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 7, 2, 2, 7, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 8, 3, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 7, 3, 5, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 2, 2, 96, 960);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 2, 6, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 2, 2, 18, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 2, 3, 41, 287);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 4, 1, 4, 41, 369);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 4, 2, 19, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 3, 5, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 4, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 3, 6, 2, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 6, 1, 6, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 3, 3, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 1, 1, 75, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 1, 3, 50, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5244, 2, 4, 6, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 4, 1, 75, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 2, 3, 53, 371);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 1, 3, 3, 46, 322);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 2, 2, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 3, 1, 1, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 1, 5, 22, 176);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 1, 1, 17, 119);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 1, 5, 84, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 1, 3, 6, 50, 500);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 2, 2, 44, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 4, 4, 63, 819);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 2, 4, 74, 962);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 2, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 1, 2, 1, 87, 348);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 6, 1, 6, 62, 806);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 4, 2, 83, 913);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 1, 4, 6, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 2, 5, 18, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 4, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 2, 5, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 2, 6, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 2, 1, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 1, 1, 5, 45);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 4, 5, 33, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 4, 2, 2, 14, 112);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 2, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 1, 2, 80, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 1, 5, 51, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 3, 3, 6, 94, 1128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 5, 3, 3, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 1, 4, 35, 455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 2, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 2, 4, 2, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 2, 5, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 8, 1, 1, 33, 330);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5245, 7, 4, 4, 57, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 6, 1, 5, 68, 816);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 4, 1, 21, 252);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 1, 1, 5, 12, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 4, 1, 1, 63, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 3, 1, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 2, 2, 5, 82, 738);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 6, 2, 3, 94, 1034);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 6, 3, 5, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 1, 2, 2, 21, 105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 2, 3, 3, 85, 680);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 1, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 2, 2, 2, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 5, 4, 4, 77, 1001);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 1, 6, 28, 392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 5, 3, 3, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 5, 3, 6, 24, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 2, 1, 37, 407);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 3, 2, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 1, 2, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 6, 4, 6, 80, 1280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 5, 4, 6, 54, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 2, 6, 91, 1365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 1, 1, 6, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 3, 2, 3, 81, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 4, 5, 34, 578);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 4, 3, 71, 1065);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 4, 1, 4, 17, 153);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 1, 1, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 7, 1, 6, 94, 1316);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 3, 3, 4, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 5, 4, 2, 28, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 8, 4, 5, 55, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 2, 3, 4, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5246, 1, 1, 6, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 4, 3, 6, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 1, 3, 4, 61, 488);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 1, 2, 6, 96, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 4, 3, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 6, 2, 6, 9, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 6, 2, 3, 72, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 4, 2, 33, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 1, 4, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 1, 3, 75, 675);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 4, 4, 2, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 3, 4, 56, 504);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 1, 4, 3, 74, 592);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 2, 6, 51, 510);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 7, 2, 5, 2, 28);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 4, 4, 38, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 7, 4, 2, 96, 1248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 3, 3, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 1, 4, 6, 15, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 1, 5, 41, 328);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 1, 4, 3, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 6, 3, 2, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 3, 4, 6, 95, 1235);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 6, 2, 6, 3, 42);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 4, 4, 61, 793);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 3, 3, 6, 58, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 3, 1, 73, 657);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 4, 6, 24, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 4, 2, 2, 79, 632);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 5, 2, 2, 30, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 2, 3, 5, 89, 890);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 6, 3, 3, 12, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 4, 3, 1, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5247, 4, 1, 1, 96, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 3, 6, 23, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 2, 2, 48, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 6, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 3, 4, 59, 885);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 2, 2, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 1, 5, 15, 150);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 1, 5, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 2, 3, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 1, 4, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 4, 5, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 4, 1, 57, 741);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 4, 5, 62, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 2, 1, 32, 352);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 3, 2, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 4, 3, 72, 648);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 1, 4, 1, 51, 306);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 1, 2, 12, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 2, 5, 66, 792);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 3, 3, 14, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 1, 4, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 1, 4, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 4, 4, 39, 507);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 1, 5, 4, 52);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 2, 2, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 2, 3, 48, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 1, 1, 16, 64);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 4, 3, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 4, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 3, 1, 57, 570);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 3, 2, 27, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 4, 6, 50, 750);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 4, 21, 231);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 4, 3, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 3, 3, 13, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 1, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 1, 6, 65, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 3, 4, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 3, 2, 44, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 1, 5, 76, 836);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 4, 3, 61, 549);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 3, 3, 36, 324);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 2, 3, 42, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 4, 1, 9, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 5, 44, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 3, 5, 97, 1455);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 3, 3, 62, 868);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 4, 2, 62, 496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 4, 2, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 1, 3, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 1, 6, 20, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 2, 5, 17, 187);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 1, 4, 64, 704);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 1, 2, 67, 670);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 3, 3, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 1, 2, 6, 4, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 3, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 6, 1, 2, 2, 18);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 1, 20, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 8, 2, 6, 70, 1120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 1, 4, 6, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 2, 4, 6, 62, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 2, 4, 87, 957);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 1, 3, 77, 847);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 7, 1, 4, 78, 936);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 4, 3, 5, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 1, 3, 6, 18, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 2, 4, 78, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 1, 4, 6, 13, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 1, 3, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 5, 3, 2, 74, 740);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 3, 6, 48, 576);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5248, 3, 4, 5, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 1, 4, 5, 77, 770);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 1, 1, 2, 30, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 7, 3, 6, 2, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 8, 3, 6, 88, 1496);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 4, 4, 2, 6, 60);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 5, 1, 1, 63, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 3, 3, 5, 81, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 4, 1, 1, 31, 186);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 8, 2, 1, 51, 561);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 6, 2, 5, 14, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 5, 3, 1, 7, 63);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 2, 3, 5, 59, 590);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 6, 3, 6, 92, 1380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 1, 1, 2, 9, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 5, 1, 4, 91, 910);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5249, 3, 4, 5, 49, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 3, 6, 9, 117);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 4, 3, 37, 555);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 1, 6, 44, 572);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 2, 1, 59, 295);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 2, 2, 5, 50);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 7, 2, 1, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 4, 6, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 1, 6, 50, 650);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 4, 5, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 4, 2, 98, 1372);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 3, 6, 39, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 2, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 2, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 4, 2, 40, 440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 1, 1, 10, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 3, 1, 83, 415);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 1, 3, 80, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 4, 2, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 1, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 1, 6, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 3, 3, 17, 238);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 4, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 4, 6, 83, 1494);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 1, 2, 64, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 1, 5, 26, 182);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 7, 1, 2, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 2, 5, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 2, 5, 55, 495);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 3, 4, 58, 638);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 1, 2, 72, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 3, 4, 60, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 4, 6, 65, 715);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 3, 3, 78, 702);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 7, 1, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 4, 5, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 3, 1, 32, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 4, 3, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 3, 6, 60, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 4, 3, 87, 870);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 4, 1, 24, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 4, 1, 1, 5, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 5, 1, 6, 96, 1152);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 1, 3, 97, 582);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 1, 4, 36, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 8, 3, 6, 65, 1105);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 7, 2, 2, 85, 935);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 2, 2, 4, 42, 336);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 3, 3, 72, 864);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 1, 4, 5, 35, 350);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 1, 4, 67, 536);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 7, 3, 3, 26, 338);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 6, 3, 5, 41, 574);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5250, 3, 1, 1, 76, 380);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 1, 1, 4, 6, 36);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 5, 1, 6, 84, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 3, 1, 2, 27, 162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5251, 2, 4, 3, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 3, 3, 76, 1064);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 4, 4, 5, 98, 1274);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 1, 1, 2, 24, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 1, 5, 68, 952);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 1, 3, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 4, 3, 19, 171);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 1, 2, 95, 1045);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 4, 4, 6, 83, 1162);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 3, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 4, 2, 5, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 1, 3, 6, 26, 260);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 3, 4, 4, 60, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 1, 1, 6, 76, 608);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 1, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 2, 1, 57, 513);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 2, 2, 70, 840);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 5, 3, 5, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 4, 3, 50, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 2, 6, 10, 160);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 1, 4, 6, 55, 605);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 8, 2, 2, 36, 432);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 5, 2, 2, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 3, 3, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 1, 2, 6, 9, 81);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 2, 4, 3, 49, 441);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5216, 6, 4, 3, 97, 1261);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 2, 5, 20, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 4, 1, 40, 400);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 4, 2, 26);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 1, 3, 81, 567);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 6, 45, 765);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 3, 3, 96, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 6, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 3, 1, 60, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 3, 5, 98, 980);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 3, 2, 39, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 2, 1, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 1, 20, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 4, 1, 78, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 3, 6, 8, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 4, 2, 8, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 5, 30, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 1, 4, 8, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 3, 3, 50, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 4, 22, 286);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 2, 6, 45, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 1, 2, 14, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 3, 6, 76, 1292);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 3, 1, 21, 147);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 3, 1, 34, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 4, 6, 44, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 3, 5, 89, 1335);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 4, 66, 660);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 1, 6, 32, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 4, 1, 5, 40);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 3, 5, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 4, 18, 234);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 1, 2, 84, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 1, 5, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 6, 61, 732);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 4, 6, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 5, 47, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 2, 4, 97, 1067);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 3, 2, 14, 168);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 3, 93, 1116);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 5, 32, 512);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 2, 5, 78, 1014);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 2, 1, 52, 468);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 3, 2, 34, 204);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 1, 2, 22, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 3, 6, 66, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 4, 6, 48, 672);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 2, 4, 79, 790);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 4, 3, 24, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 2, 3, 99, 693);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 6, 20, 300);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 1, 3, 54, 378);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 4, 2, 22, 308);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 1, 2, 58, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 1, 6, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 1, 1, 26, 130);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 3, 1, 62, 558);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 4, 47, 611);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 5, 69, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 2, 5, 65);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 2, 5, 11, 132);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 2, 3, 10, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 4, 2, 15, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 2, 1, 44, 264);
commit;
prompt 183000 records committed...
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 3, 6, 22, 264);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 1, 2, 50, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 1, 5, 67, 871);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 3, 94, 846);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 1, 18, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 3, 1, 90, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 1, 6, 31, 403);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 5, 56, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 1, 4, 45, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 3, 4, 73, 730);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 2, 1, 92, 368);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 1, 4, 22, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 3, 5, 5, 55);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 4, 5, 49, 637);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 4, 5, 71, 781);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 1, 5, 11, 77);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 4, 2, 30, 360);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 6, 52, 780);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 2, 42, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 2, 6, 12, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 1, 1, 57, 342);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 2, 1, 76, 760);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 4, 4, 63, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 1, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 1, 6, 58, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 2, 6, 1, 16);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 3, 5, 34, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 2, 6, 30, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 4, 1, 14, 84);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 6, 1, 6, 11, 143);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 4, 2, 86, 860);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 3, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 2, 6, 27, 243);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 8, 2, 6, 40, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 1, 3, 82, 410);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 2, 2, 3, 88, 616);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 1, 3, 1, 27, 135);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 2, 3, 15, 120);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 4, 2, 2, 29, 232);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 5, 1, 1, 97, 679);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 2, 3, 65, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 3, 6, 87, 1392);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 3, 3, 2, 83, 664);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5217, 7, 4, 2, 28, 364);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 1, 1, 4, 20);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 1, 4, 21, 126);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 4, 5, 17, 221);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 3, 2, 45, 450);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 2, 40, 320);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 3, 5, 45, 630);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 4, 3, 48, 624);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 5, 46, 460);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 3, 5, 8, 88);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 1, 38, 228);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 2, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 1, 35, 175);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 2, 1, 94, 376);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 3, 3, 94, 752);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 3, 46, 414);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 4, 4, 79, 711);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 2, 5, 33, 462);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 2, 4, 18, 198);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 1, 75, 900);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 3, 69, 483);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 1, 3, 78, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 4, 5, 29, 435);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 4, 84, 924);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 4, 11, 110);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 1, 36, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 1, 20, 140);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 4, 2, 85, 1190);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 4, 2, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 4, 4, 90, 810);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 5, 75, 1200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 1, 4, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 1, 91, 1092);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 1, 2, 31, 341);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 1, 6, 66, 726);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 3, 4, 87, 696);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 1, 6, 68, 544);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 4, 77, 1155);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 5, 87, 783);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 1, 4, 21, 273);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 4, 6, 53, 742);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 2, 2, 48, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 2, 2, 2, 10);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 1, 2, 73, 365);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 3, 6, 96, 1440);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 4, 1, 34, 374);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 3, 4, 68, 884);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 3, 1, 86, 774);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 2, 2, 24, 216);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 4, 6, 53, 583);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 3, 98, 784);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 3, 5, 14, 154);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 1, 2, 3, 45, 270);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 3, 11, 99);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 4, 6, 95, 1520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 1, 1, 15, 90);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 3, 2, 54, 540);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 3, 4, 66, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 1, 1, 52, 208);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 4, 99, 1089);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 3, 4, 6, 72);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 2, 1, 10, 80);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 1, 6, 37, 444);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 3, 4, 82, 984);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 1, 2, 98, 588);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 4, 3, 35, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 3, 6, 26, 442);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 3, 5, 28, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 1, 5, 16, 224);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 4, 93, 744);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 3, 40, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 2, 5, 23, 299);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 2, 3, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 1, 1, 22, 220);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 3, 1, 99, 594);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 3, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 4, 2, 2, 22);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 2, 2, 97, 1164);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 1, 3, 88, 1056);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 5, 92, 1104);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 2, 2, 35, 420);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 1, 6, 36, 396);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 3, 4, 38, 532);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 4, 5, 47, 799);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 5, 7, 70);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 3, 6, 39, 429);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 5, 8, 128);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 3, 5, 65, 975);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 1, 93, 465);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 3, 2, 31, 279);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 2, 2, 3, 75, 525);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 3, 3, 65, 585);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 6, 47, 517);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 3, 5, 9, 144);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 4, 5, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 2, 6, 35, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 5, 4, 1, 60, 600);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 4, 2, 4, 10, 100);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 6, 1, 2, 80, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 7, 4, 4, 16, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 3, 2, 66, 858);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 2, 6, 84, 1344);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 8, 4, 1, 81, 1053);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5218, 3, 1, 4, 25, 200);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 4, 5, 57, 969);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 1, 5, 46, 506);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 2, 5, 70, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 4, 5, 91, 1183);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 3, 1, 28, 196);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 4, 5, 72, 720);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 2, 6, 40, 560);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 1, 5, 30, 240);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 1, 1, 4, 32);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 3, 72, 1008);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 3, 5, 37, 370);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 1, 1, 34, 272);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 2, 5, 12, 96);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 3, 1, 68, 408);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 4, 5, 11, 165);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 4, 5, 27, 405);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 2, 4, 93, 1302);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 1, 1, 58, 174);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 2, 1, 57, 627);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 3, 3, 74, 888);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 1, 4, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 1, 3, 87, 522);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 3, 3, 7, 56);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 1, 4, 3, 30);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 4, 6, 34, 476);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 4, 1, 71, 497);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 2, 5, 32, 288);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 3, 21, 210);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 2, 3, 65, 390);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 2, 4, 31, 434);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 7, 4, 1, 15, 180);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 1, 3, 77, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 2, 4, 93, 930);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 2, 5, 35, 280);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 3, 4, 95, 855);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 3, 1, 24, 192);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 1, 2, 96, 480);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 1, 51, 612);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 5, 2, 3, 64, 640);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 1, 5, 54, 756);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 1, 2, 46, 184);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 1, 5, 31, 248);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 3, 1, 55, 550);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 7, 2, 1, 52, 520);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 4, 2, 3, 99, 891);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 2, 5, 75, 1125);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 3, 1, 2, 88, 528);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 1, 4, 2, 55, 385);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 3, 1, 2, 12);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 6, 4, 5, 25, 375);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 4, 1, 58, 754);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 2, 2, 4, 82, 656);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 8, 3, 2, 12, 156);
insert into FKT_SALES (date_id, dcl_id, dma_id, dsh_id, quantity, amount)
values (5219, 7, 1, 4, 59, 708);
commit;
prompt 183202 records loaded
prompt Loading INVOICES...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307003062, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 5, 5747, to_date('11-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000904003063, to_date('04-09-2000', 'dd-mm-yyyy'), to_date('18-09-2000', 'dd-mm-yyyy'), 11, 1966, to_date('23-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504003064, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 11, 2505, to_date('19-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112003065, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 10, 11675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050329003066, to_date('29-03-2005', 'dd-mm-yyyy'), to_date('12-04-2005', 'dd-mm-yyyy'), 9, 5725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130620003067, to_date('20-06-2013', 'dd-mm-yyyy'), to_date('04-07-2013', 'dd-mm-yyyy'), 2, 6167, to_date('03-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118003068, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 9, 9106, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119003069, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 7, 11682, to_date('29-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140225003070, to_date('25-02-2014', 'dd-mm-yyyy'), to_date('11-03-2014', 'dd-mm-yyyy'), 6, 8554, to_date('12-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050708003071, to_date('08-07-2005', 'dd-mm-yyyy'), to_date('22-07-2005', 'dd-mm-yyyy'), 6, 2854, to_date('21-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060209003072, to_date('09-02-2006', 'dd-mm-yyyy'), to_date('23-02-2006', 'dd-mm-yyyy'), 7, 5303, to_date('19-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330003073, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 8, 7617, to_date('09-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020425003074, to_date('25-04-2002', 'dd-mm-yyyy'), to_date('09-05-2002', 'dd-mm-yyyy'), 5, 2358, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070626003075, to_date('26-06-2007', 'dd-mm-yyyy'), to_date('10-07-2007', 'dd-mm-yyyy'), 11, 3030, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100414003076, to_date('14-04-2010', 'dd-mm-yyyy'), to_date('28-04-2010', 'dd-mm-yyyy'), 5, 3786, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061209003077, to_date('09-12-2006', 'dd-mm-yyyy'), to_date('23-12-2006', 'dd-mm-yyyy'), 7, 5191, to_date('21-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130117003078, to_date('17-01-2013', 'dd-mm-yyyy'), to_date('31-01-2013', 'dd-mm-yyyy'), 9, 8863, to_date('28-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116003079, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 8, 7762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020326003080, to_date('26-03-2002', 'dd-mm-yyyy'), to_date('09-04-2002', 'dd-mm-yyyy'), 2, 2796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130719003081, to_date('19-07-2013', 'dd-mm-yyyy'), to_date('02-08-2013', 'dd-mm-yyyy'), 1, 8549, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120621003082, to_date('21-06-2012', 'dd-mm-yyyy'), to_date('05-07-2012', 'dd-mm-yyyy'), 6, 9708, to_date('02-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021216003083, to_date('16-12-2002', 'dd-mm-yyyy'), to_date('30-12-2002', 'dd-mm-yyyy'), 10, 3032, to_date('24-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110124003084, to_date('24-01-2011', 'dd-mm-yyyy'), to_date('07-02-2011', 'dd-mm-yyyy'), 6, 5185, to_date('26-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120719003085, to_date('19-07-2012', 'dd-mm-yyyy'), to_date('02-08-2012', 'dd-mm-yyyy'), 6, 9938, to_date('21-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110918003086, to_date('18-09-2011', 'dd-mm-yyyy'), to_date('02-10-2011', 'dd-mm-yyyy'), 6, 8692, to_date('01-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207003087, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 6, 4439, to_date('23-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010206003088, to_date('06-02-2001', 'dd-mm-yyyy'), to_date('20-02-2001', 'dd-mm-yyyy'), 10, 830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706003089, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 5, 3828, to_date('21-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040419003090, to_date('19-04-2004', 'dd-mm-yyyy'), to_date('03-05-2004', 'dd-mm-yyyy'), 11, 5876, to_date('03-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110709003091, to_date('09-07-2011', 'dd-mm-yyyy'), to_date('23-07-2011', 'dd-mm-yyyy'), 6, 8991, to_date('27-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130522003092, to_date('22-05-2013', 'dd-mm-yyyy'), to_date('05-06-2013', 'dd-mm-yyyy'), 4, 10928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100117003093, to_date('17-01-2010', 'dd-mm-yyyy'), to_date('31-01-2010', 'dd-mm-yyyy'), 11, 6601, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070210003094, to_date('10-02-2007', 'dd-mm-yyyy'), to_date('24-02-2007', 'dd-mm-yyyy'), 3, 8235, to_date('22-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000717003095, to_date('17-07-2000', 'dd-mm-yyyy'), to_date('31-07-2000', 'dd-mm-yyyy'), 3, 2370, to_date('26-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050208003096, to_date('08-02-2005', 'dd-mm-yyyy'), to_date('22-02-2005', 'dd-mm-yyyy'), 9, 4276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011117003097, to_date('17-11-2001', 'dd-mm-yyyy'), to_date('01-12-2001', 'dd-mm-yyyy'), 7, 1379, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213003098, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 2, 2629, to_date('23-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111221003099, to_date('21-12-2011', 'dd-mm-yyyy'), to_date('04-01-2012', 'dd-mm-yyyy'), 7, 6778, to_date('04-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901003100, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 2, 6467, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120830003101, to_date('30-08-2012', 'dd-mm-yyyy'), to_date('13-09-2012', 'dd-mm-yyyy'), 5, 8084, to_date('31-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725003102, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 5, 5468, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081106003103, to_date('06-11-2008', 'dd-mm-yyyy'), to_date('20-11-2008', 'dd-mm-yyyy'), 5, 3038, to_date('08-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010726003104, to_date('26-07-2001', 'dd-mm-yyyy'), to_date('09-08-2001', 'dd-mm-yyyy'), 10, 2641, to_date('11-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100817003105, to_date('17-08-2010', 'dd-mm-yyyy'), to_date('31-08-2010', 'dd-mm-yyyy'), 4, 9355, to_date('24-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010917003106, to_date('17-09-2001', 'dd-mm-yyyy'), to_date('01-10-2001', 'dd-mm-yyyy'), 5, 1766, to_date('02-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020211003107, to_date('11-02-2002', 'dd-mm-yyyy'), to_date('25-02-2002', 'dd-mm-yyyy'), 7, 3032, to_date('19-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217003108, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 8, 5164, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100227003109, to_date('27-02-2010', 'dd-mm-yyyy'), to_date('13-03-2010', 'dd-mm-yyyy'), 3, 6816, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020506003110, to_date('06-05-2002', 'dd-mm-yyyy'), to_date('20-05-2002', 'dd-mm-yyyy'), 4, 3069, to_date('21-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010803003111, to_date('03-08-2001', 'dd-mm-yyyy'), to_date('17-08-2001', 'dd-mm-yyyy'), 7, 3074, to_date('22-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120514003112, to_date('14-05-2012', 'dd-mm-yyyy'), to_date('28-05-2012', 'dd-mm-yyyy'), 1, 7543, to_date('03-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921003113, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 2, 6412, to_date('03-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070324003114, to_date('24-03-2007', 'dd-mm-yyyy'), to_date('07-04-2007', 'dd-mm-yyyy'), 4, 6432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020926003115, to_date('26-09-2002', 'dd-mm-yyyy'), to_date('10-10-2002', 'dd-mm-yyyy'), 4, 3274, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130824003116, to_date('24-08-2013', 'dd-mm-yyyy'), to_date('07-09-2013', 'dd-mm-yyyy'), 1, 10623, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826003117, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 2, 5846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091005003118, to_date('05-10-2009', 'dd-mm-yyyy'), to_date('19-10-2009', 'dd-mm-yyyy'), 1, 8847, to_date('09-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081226003119, to_date('26-12-2008', 'dd-mm-yyyy'), to_date('09-01-2009', 'dd-mm-yyyy'), 10, 6629, to_date('02-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040702003120, to_date('02-07-2004', 'dd-mm-yyyy'), to_date('16-07-2004', 'dd-mm-yyyy'), 2, 3480, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060125003121, to_date('25-01-2006', 'dd-mm-yyyy'), to_date('08-02-2006', 'dd-mm-yyyy'), 8, 3672, to_date('27-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120316003122, to_date('16-03-2012', 'dd-mm-yyyy'), to_date('30-03-2012', 'dd-mm-yyyy'), 12, 10829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050201003123, to_date('01-02-2005', 'dd-mm-yyyy'), to_date('15-02-2005', 'dd-mm-yyyy'), 2, 6333, to_date('18-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110419003124, to_date('19-04-2011', 'dd-mm-yyyy'), to_date('03-05-2011', 'dd-mm-yyyy'), 5, 7947, to_date('03-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050304003125, to_date('04-03-2005', 'dd-mm-yyyy'), to_date('18-03-2005', 'dd-mm-yyyy'), 7, 3843, to_date('19-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070715003126, to_date('15-07-2007', 'dd-mm-yyyy'), to_date('29-07-2007', 'dd-mm-yyyy'), 3, 5620, to_date('27-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916003127, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 10, 6938, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050714003128, to_date('14-07-2005', 'dd-mm-yyyy'), to_date('28-07-2005', 'dd-mm-yyyy'), 11, 4989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118003129, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 11, 7655, to_date('08-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130324003130, to_date('24-03-2013', 'dd-mm-yyyy'), to_date('07-04-2013', 'dd-mm-yyyy'), 4, 8885, to_date('12-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090327003131, to_date('27-03-2009', 'dd-mm-yyyy'), to_date('10-04-2009', 'dd-mm-yyyy'), 9, 7358, to_date('31-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020127003132, to_date('27-01-2002', 'dd-mm-yyyy'), to_date('10-02-2002', 'dd-mm-yyyy'), 6, 2663, to_date('31-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120915003133, to_date('15-09-2012', 'dd-mm-yyyy'), to_date('29-09-2012', 'dd-mm-yyyy'), 9, 8234, to_date('26-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051015003134, to_date('15-10-2005', 'dd-mm-yyyy'), to_date('29-10-2005', 'dd-mm-yyyy'), 3, 5754, to_date('18-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111027003135, to_date('27-10-2011', 'dd-mm-yyyy'), to_date('10-11-2011', 'dd-mm-yyyy'), 10, 4869, to_date('28-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020628003136, to_date('28-06-2002', 'dd-mm-yyyy'), to_date('12-07-2002', 'dd-mm-yyyy'), 3, 3131, to_date('04-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723003137, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 11, 2606, to_date('28-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101206003138, to_date('06-12-2010', 'dd-mm-yyyy'), to_date('20-12-2010', 'dd-mm-yyyy'), 5, 6835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040804003139, to_date('04-08-2004', 'dd-mm-yyyy'), to_date('18-08-2004', 'dd-mm-yyyy'), 10, 2288, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010923003140, to_date('23-09-2001', 'dd-mm-yyyy'), to_date('07-10-2001', 'dd-mm-yyyy'), 7, 2846, to_date('07-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031009003141, to_date('09-10-2003', 'dd-mm-yyyy'), to_date('23-10-2003', 'dd-mm-yyyy'), 9, 4174, to_date('12-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100409003142, to_date('09-04-2010', 'dd-mm-yyyy'), to_date('23-04-2010', 'dd-mm-yyyy'), 6, 7203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070813003143, to_date('13-08-2007', 'dd-mm-yyyy'), to_date('27-08-2007', 'dd-mm-yyyy'), 4, 5244, to_date('28-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130506003144, to_date('06-05-2013', 'dd-mm-yyyy'), to_date('20-05-2013', 'dd-mm-yyyy'), 2, 8680, to_date('25-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020311003145, to_date('11-03-2002', 'dd-mm-yyyy'), to_date('25-03-2002', 'dd-mm-yyyy'), 10, 4454, to_date('27-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119003146, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 7, 2231, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130426003147, to_date('26-04-2013', 'dd-mm-yyyy'), to_date('10-05-2013', 'dd-mm-yyyy'), 5, 9254, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129003148, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 11, 12165, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010407003149, to_date('07-04-2001', 'dd-mm-yyyy'), to_date('21-04-2001', 'dd-mm-yyyy'), 9, 3459, to_date('11-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110204003150, to_date('04-02-2011', 'dd-mm-yyyy'), to_date('18-02-2011', 'dd-mm-yyyy'), 11, 9632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100517003151, to_date('17-05-2010', 'dd-mm-yyyy'), to_date('31-05-2010', 'dd-mm-yyyy'), 8, 7088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100217003152, to_date('17-02-2010', 'dd-mm-yyyy'), to_date('03-03-2010', 'dd-mm-yyyy'), 10, 9150, to_date('01-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614003153, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 11, 5869, to_date('20-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130615003154, to_date('15-06-2013', 'dd-mm-yyyy'), to_date('29-06-2013', 'dd-mm-yyyy'), 11, 9895, to_date('01-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226003155, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 3, 1715, to_date('04-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120115003156, to_date('15-01-2012', 'dd-mm-yyyy'), to_date('29-01-2012', 'dd-mm-yyyy'), 10, 6172, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021128003157, to_date('28-11-2002', 'dd-mm-yyyy'), to_date('12-12-2002', 'dd-mm-yyyy'), 10, 4556, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110829003158, to_date('29-08-2011', 'dd-mm-yyyy'), to_date('12-09-2011', 'dd-mm-yyyy'), 6, 8801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090119003159, to_date('19-01-2009', 'dd-mm-yyyy'), to_date('02-02-2009', 'dd-mm-yyyy'), 7, 6636, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207003160, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 2, 6489, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015003161, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 7, 4195, to_date('25-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140510003162, to_date('10-05-2014', 'dd-mm-yyyy'), to_date('24-05-2014', 'dd-mm-yyyy'), 7, 8173, to_date('25-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010811003163, to_date('11-08-2001', 'dd-mm-yyyy'), to_date('25-08-2001', 'dd-mm-yyyy'), 7, 1386, to_date('18-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060831003164, to_date('31-08-2006', 'dd-mm-yyyy'), to_date('14-09-2006', 'dd-mm-yyyy'), 3, 4800, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423003165, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 9, 5465, to_date('28-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080310003166, to_date('10-03-2008', 'dd-mm-yyyy'), to_date('24-03-2008', 'dd-mm-yyyy'), 8, 6352, to_date('25-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000910003167, to_date('10-09-2000', 'dd-mm-yyyy'), to_date('24-09-2000', 'dd-mm-yyyy'), 2, 1792, to_date('18-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100410003168, to_date('10-04-2010', 'dd-mm-yyyy'), to_date('24-04-2010', 'dd-mm-yyyy'), 6, 8406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080305003169, to_date('05-03-2008', 'dd-mm-yyyy'), to_date('19-03-2008', 'dd-mm-yyyy'), 8, 5139, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710003170, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 6, 4487, to_date('23-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050731003171, to_date('31-07-2005', 'dd-mm-yyyy'), to_date('14-08-2005', 'dd-mm-yyyy'), 3, 5280, to_date('02-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411003172, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 8, 8682, to_date('26-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110513003173, to_date('13-05-2011', 'dd-mm-yyyy'), to_date('27-05-2011', 'dd-mm-yyyy'), 3, 6388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070121003174, to_date('21-01-2007', 'dd-mm-yyyy'), to_date('04-02-2007', 'dd-mm-yyyy'), 10, 5677, to_date('07-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111230003175, to_date('30-12-2011', 'dd-mm-yyyy'), to_date('13-01-2012', 'dd-mm-yyyy'), 11, 7552, to_date('15-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101226003176, to_date('26-12-2010', 'dd-mm-yyyy'), to_date('09-01-2011', 'dd-mm-yyyy'), 10, 5684, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080512003177, to_date('12-05-2008', 'dd-mm-yyyy'), to_date('26-05-2008', 'dd-mm-yyyy'), 3, 6240, to_date('21-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001023003178, to_date('23-10-2000', 'dd-mm-yyyy'), to_date('06-11-2000', 'dd-mm-yyyy'), 8, 2660, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026003179, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 9, 3990, to_date('10-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021120003180, to_date('20-11-2002', 'dd-mm-yyyy'), to_date('04-12-2002', 'dd-mm-yyyy'), 10, 3492, to_date('09-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100320003181, to_date('20-03-2010', 'dd-mm-yyyy'), to_date('03-04-2010', 'dd-mm-yyyy'), 3, 5690, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000724003182, to_date('24-07-2000', 'dd-mm-yyyy'), to_date('07-08-2000', 'dd-mm-yyyy'), 11, 3189, to_date('12-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020327003183, to_date('27-03-2002', 'dd-mm-yyyy'), to_date('10-04-2002', 'dd-mm-yyyy'), 2, 3235, to_date('10-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106003184, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 7, 4630, to_date('24-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120329003185, to_date('29-03-2012', 'dd-mm-yyyy'), to_date('12-04-2012', 'dd-mm-yyyy'), 8, 8845, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070415003186, to_date('15-04-2007', 'dd-mm-yyyy'), to_date('29-04-2007', 'dd-mm-yyyy'), 4, 5670, to_date('05-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040630003187, to_date('30-06-2004', 'dd-mm-yyyy'), to_date('14-07-2004', 'dd-mm-yyyy'), 9, 3284, to_date('05-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120221003188, to_date('21-02-2012', 'dd-mm-yyyy'), to_date('06-03-2012', 'dd-mm-yyyy'), 3, 9499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060927003189, to_date('27-09-2006', 'dd-mm-yyyy'), to_date('11-10-2006', 'dd-mm-yyyy'), 2, 3784, to_date('16-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140301003190, to_date('01-03-2014', 'dd-mm-yyyy'), to_date('15-03-2014', 'dd-mm-yyyy'), 7, 8049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070730003191, to_date('30-07-2007', 'dd-mm-yyyy'), to_date('13-08-2007', 'dd-mm-yyyy'), 7, 6717, to_date('11-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130226003192, to_date('26-02-2013', 'dd-mm-yyyy'), to_date('12-03-2013', 'dd-mm-yyyy'), 11, 8511, to_date('03-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110309003193, to_date('09-03-2011', 'dd-mm-yyyy'), to_date('23-03-2011', 'dd-mm-yyyy'), 5, 6554, to_date('11-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104003194, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 10, 4675, to_date('21-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824003195, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 8, 6325, to_date('05-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618003196, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 9, 1440, to_date('27-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091018003197, to_date('18-10-2009', 'dd-mm-yyyy'), to_date('01-11-2009', 'dd-mm-yyyy'), 10, 7917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110627003198, to_date('27-06-2011', 'dd-mm-yyyy'), to_date('11-07-2011', 'dd-mm-yyyy'), 11, 8008, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011230003199, to_date('30-12-2001', 'dd-mm-yyyy'), to_date('13-01-2002', 'dd-mm-yyyy'), 2, 2976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070830003200, to_date('30-08-2007', 'dd-mm-yyyy'), to_date('13-09-2007', 'dd-mm-yyyy'), 8, 5796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051225003201, to_date('25-12-2005', 'dd-mm-yyyy'), to_date('08-01-2006', 'dd-mm-yyyy'), 12, 2350, to_date('04-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000401003202, to_date('01-04-2000', 'dd-mm-yyyy'), to_date('15-04-2000', 'dd-mm-yyyy'), 7, 1461, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101003203, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 3, 2143, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100327003204, to_date('27-03-2010', 'dd-mm-yyyy'), to_date('10-04-2010', 'dd-mm-yyyy'), 5, 8712, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227003205, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 9, 6690, to_date('04-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808003206, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 1, 2065, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110501003207, to_date('01-05-2011', 'dd-mm-yyyy'), to_date('15-05-2011', 'dd-mm-yyyy'), 12, 9638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101225003208, to_date('25-12-2010', 'dd-mm-yyyy'), to_date('08-01-2011', 'dd-mm-yyyy'), 7, 7791, to_date('07-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041004003209, to_date('04-10-2004', 'dd-mm-yyyy'), to_date('18-10-2004', 'dd-mm-yyyy'), 10, 5529, to_date('20-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070927003210, to_date('27-09-2007', 'dd-mm-yyyy'), to_date('11-10-2007', 'dd-mm-yyyy'), 7, 3117, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110720003211, to_date('20-07-2011', 'dd-mm-yyyy'), to_date('03-08-2011', 'dd-mm-yyyy'), 11, 8895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100222003212, to_date('22-02-2010', 'dd-mm-yyyy'), to_date('08-03-2010', 'dd-mm-yyyy'), 9, 5407, to_date('14-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003003213, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 8, 2867, to_date('17-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040316003214, to_date('16-03-2004', 'dd-mm-yyyy'), to_date('30-03-2004', 'dd-mm-yyyy'), 9, 3319, to_date('21-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722003215, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 11, 7624, to_date('07-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140511003216, to_date('11-05-2014', 'dd-mm-yyyy'), to_date('25-05-2014', 'dd-mm-yyyy'), 6, 9692, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001101005356, to_date('01-11-2000', 'dd-mm-yyyy'), to_date('15-11-2000', 'dd-mm-yyyy'), 4, 1985, to_date('02-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050424005357, to_date('24-04-2005', 'dd-mm-yyyy'), to_date('08-05-2005', 'dd-mm-yyyy'), 10, 3914, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100831005358, to_date('31-08-2010', 'dd-mm-yyyy'), to_date('14-09-2010', 'dd-mm-yyyy'), 7, 7780, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010303005359, to_date('03-03-2001', 'dd-mm-yyyy'), to_date('17-03-2001', 'dd-mm-yyyy'), 1, 3156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010419005360, to_date('19-04-2001', 'dd-mm-yyyy'), to_date('03-05-2001', 'dd-mm-yyyy'), 6, 2746, to_date('01-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080921005361, to_date('21-09-2008', 'dd-mm-yyyy'), to_date('05-10-2008', 'dd-mm-yyyy'), 9, 7972, to_date('11-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090203005362, to_date('03-02-2009', 'dd-mm-yyyy'), to_date('17-02-2009', 'dd-mm-yyyy'), 12, 7266, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100207005363, to_date('07-02-2010', 'dd-mm-yyyy'), to_date('21-02-2010', 'dd-mm-yyyy'), 12, 7049, to_date('23-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004005364, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 1, 2471, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119005365, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 7, 3309, to_date('28-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060207005366, to_date('07-02-2006', 'dd-mm-yyyy'), to_date('21-02-2006', 'dd-mm-yyyy'), 4, 2989, to_date('25-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090617005367, to_date('17-06-2009', 'dd-mm-yyyy'), to_date('01-07-2009', 'dd-mm-yyyy'), 4, 6832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130312005368, to_date('12-03-2013', 'dd-mm-yyyy'), to_date('26-03-2013', 'dd-mm-yyyy'), 9, 8287, to_date('19-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140224005369, to_date('24-02-2014', 'dd-mm-yyyy'), to_date('10-03-2014', 'dd-mm-yyyy'), 3, 7968, to_date('25-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020726005370, to_date('26-07-2002', 'dd-mm-yyyy'), to_date('09-08-2002', 'dd-mm-yyyy'), 10, 2566, to_date('29-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011016005371, to_date('16-10-2001', 'dd-mm-yyyy'), to_date('30-10-2001', 'dd-mm-yyyy'), 10, 1304, to_date('24-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080112005372, to_date('12-01-2008', 'dd-mm-yyyy'), to_date('26-01-2008', 'dd-mm-yyyy'), 3, 6768, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121031005373, to_date('31-10-2012', 'dd-mm-yyyy'), to_date('14-11-2012', 'dd-mm-yyyy'), 1, 7497, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091116005374, to_date('16-11-2009', 'dd-mm-yyyy'), to_date('30-11-2009', 'dd-mm-yyyy'), 1, 8054, to_date('05-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923005375, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 7, 2188, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026005376, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 12, 1422, to_date('10-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070911005377, to_date('11-09-2007', 'dd-mm-yyyy'), to_date('25-09-2007', 'dd-mm-yyyy'), 12, 7331, to_date('12-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001007005378, to_date('07-10-2000', 'dd-mm-yyyy'), to_date('21-10-2000', 'dd-mm-yyyy'), 2, 2469, to_date('14-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021011005379, to_date('11-10-2002', 'dd-mm-yyyy'), to_date('25-10-2002', 'dd-mm-yyyy'), 12, 2096, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070628005380, to_date('28-06-2007', 'dd-mm-yyyy'), to_date('12-07-2007', 'dd-mm-yyyy'), 9, 5500, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070821005381, to_date('21-08-2007', 'dd-mm-yyyy'), to_date('04-09-2007', 'dd-mm-yyyy'), 3, 3627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140330005382, to_date('30-03-2014', 'dd-mm-yyyy'), to_date('13-04-2014', 'dd-mm-yyyy'), 11, 11156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515005383, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 11, 2762, to_date('17-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423005384, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 8, 10927, to_date('10-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908005385, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 6, 7803, to_date('23-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021128005386, to_date('28-11-2002', 'dd-mm-yyyy'), to_date('12-12-2002', 'dd-mm-yyyy'), 10, 4329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071125005387, to_date('25-11-2007', 'dd-mm-yyyy'), to_date('09-12-2007', 'dd-mm-yyyy'), 2, 5435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060502005388, to_date('02-05-2006', 'dd-mm-yyyy'), to_date('16-05-2006', 'dd-mm-yyyy'), 1, 5481, to_date('14-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080719005389, to_date('19-07-2008', 'dd-mm-yyyy'), to_date('02-08-2008', 'dd-mm-yyyy'), 8, 6358, to_date('31-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026005390, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 3, 2898, to_date('13-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011029005391, to_date('29-10-2001', 'dd-mm-yyyy'), to_date('12-11-2001', 'dd-mm-yyyy'), 5, 4902, to_date('03-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041025005392, to_date('25-10-2004', 'dd-mm-yyyy'), to_date('08-11-2004', 'dd-mm-yyyy'), 3, 4248, to_date('07-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100714005393, to_date('14-07-2010', 'dd-mm-yyyy'), to_date('28-07-2010', 'dd-mm-yyyy'), 4, 4924, to_date('01-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409005394, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 1, 3904, to_date('20-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130607005395, to_date('07-06-2013', 'dd-mm-yyyy'), to_date('21-06-2013', 'dd-mm-yyyy'), 3, 9133, to_date('18-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130510005396, to_date('10-05-2013', 'dd-mm-yyyy'), to_date('24-05-2013', 'dd-mm-yyyy'), 5, 10527, to_date('27-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205005397, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 5, 3867, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090928005398, to_date('28-09-2009', 'dd-mm-yyyy'), to_date('12-10-2009', 'dd-mm-yyyy'), 5, 7063, to_date('06-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140113005399, to_date('13-01-2014', 'dd-mm-yyyy'), to_date('27-01-2014', 'dd-mm-yyyy'), 11, 8053, to_date('31-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110215005400, to_date('15-02-2011', 'dd-mm-yyyy'), to_date('01-03-2011', 'dd-mm-yyyy'), 2, 8635, to_date('04-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020107005401, to_date('07-01-2002', 'dd-mm-yyyy'), to_date('21-01-2002', 'dd-mm-yyyy'), 4, 4108, to_date('26-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529005402, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 4, 7412, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070504005403, to_date('04-05-2007', 'dd-mm-yyyy'), to_date('18-05-2007', 'dd-mm-yyyy'), 9, 6588, to_date('19-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000623005404, to_date('23-06-2000', 'dd-mm-yyyy'), to_date('07-07-2000', 'dd-mm-yyyy'), 7, 3330, to_date('25-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060323005405, to_date('23-03-2006', 'dd-mm-yyyy'), to_date('06-04-2006', 'dd-mm-yyyy'), 7, 4118, to_date('12-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723005406, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 10, 6658, to_date('11-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011105005407, to_date('05-11-2001', 'dd-mm-yyyy'), to_date('19-11-2001', 'dd-mm-yyyy'), 9, 2711, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100810005408, to_date('10-08-2010', 'dd-mm-yyyy'), to_date('24-08-2010', 'dd-mm-yyyy'), 6, 6965, to_date('24-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207005409, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 10, 7738, to_date('10-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010625005410, to_date('25-06-2001', 'dd-mm-yyyy'), to_date('09-07-2001', 'dd-mm-yyyy'), 2, 1068, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110309005411, to_date('09-03-2011', 'dd-mm-yyyy'), to_date('23-03-2011', 'dd-mm-yyyy'), 2, 6066, to_date('25-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040408005412, to_date('08-04-2004', 'dd-mm-yyyy'), to_date('22-04-2004', 'dd-mm-yyyy'), 11, 3875, to_date('22-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071105005413, to_date('05-11-2007', 'dd-mm-yyyy'), to_date('19-11-2007', 'dd-mm-yyyy'), 2, 4691, to_date('16-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001119005414, to_date('19-11-2000', 'dd-mm-yyyy'), to_date('03-12-2000', 'dd-mm-yyyy'), 2, 2328, to_date('21-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020701005415, to_date('01-07-2002', 'dd-mm-yyyy'), to_date('15-07-2002', 'dd-mm-yyyy'), 5, 2683, to_date('10-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111020005416, to_date('20-10-2011', 'dd-mm-yyyy'), to_date('03-11-2011', 'dd-mm-yyyy'), 1, 8953, to_date('27-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080205005417, to_date('05-02-2008', 'dd-mm-yyyy'), to_date('19-02-2008', 'dd-mm-yyyy'), 2, 4949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010904005418, to_date('04-09-2001', 'dd-mm-yyyy'), to_date('18-09-2001', 'dd-mm-yyyy'), 5, 3708, to_date('12-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110903005419, to_date('03-09-2011', 'dd-mm-yyyy'), to_date('17-09-2011', 'dd-mm-yyyy'), 6, 8838, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011118005420, to_date('18-11-2001', 'dd-mm-yyyy'), to_date('02-12-2001', 'dd-mm-yyyy'), 4, 488, to_date('02-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131201005421, to_date('01-12-2013', 'dd-mm-yyyy'), to_date('15-12-2013', 'dd-mm-yyyy'), 3, 7469, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050508005422, to_date('08-05-2005', 'dd-mm-yyyy'), to_date('22-05-2005', 'dd-mm-yyyy'), 5, 2346, to_date('15-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100521005423, to_date('21-05-2010', 'dd-mm-yyyy'), to_date('04-06-2010', 'dd-mm-yyyy'), 5, 5914, to_date('03-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423005424, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 2, 9769, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524005425, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 2, 9000, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020818005426, to_date('18-08-2002', 'dd-mm-yyyy'), to_date('01-09-2002', 'dd-mm-yyyy'), 3, 2309, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070108005427, to_date('08-01-2007', 'dd-mm-yyyy'), to_date('22-01-2007', 'dd-mm-yyyy'), 8, 5299, to_date('15-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090620005428, to_date('20-06-2009', 'dd-mm-yyyy'), to_date('04-07-2009', 'dd-mm-yyyy'), 8, 6464, to_date('25-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140222005429, to_date('22-02-2014', 'dd-mm-yyyy'), to_date('08-03-2014', 'dd-mm-yyyy'), 8, 8109, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101011005430, to_date('11-10-2010', 'dd-mm-yyyy'), to_date('25-10-2010', 'dd-mm-yyyy'), 11, 5754, to_date('13-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214005431, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 3, 9015, to_date('20-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040916005432, to_date('16-09-2004', 'dd-mm-yyyy'), to_date('30-09-2004', 'dd-mm-yyyy'), 6, 2551, to_date('04-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130907005433, to_date('07-09-2013', 'dd-mm-yyyy'), to_date('21-09-2013', 'dd-mm-yyyy'), 4, 8153, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021031005434, to_date('31-10-2002', 'dd-mm-yyyy'), to_date('14-11-2002', 'dd-mm-yyyy'), 7, 2021, to_date('13-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020116005435, to_date('16-01-2002', 'dd-mm-yyyy'), to_date('30-01-2002', 'dd-mm-yyyy'), 4, 1819, to_date('24-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131225005436, to_date('25-12-2013', 'dd-mm-yyyy'), to_date('08-01-2014', 'dd-mm-yyyy'), 5, 8948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120114005437, to_date('14-01-2012', 'dd-mm-yyyy'), to_date('28-01-2012', 'dd-mm-yyyy'), 7, 8735, to_date('22-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021018005438, to_date('18-10-2002', 'dd-mm-yyyy'), to_date('01-11-2002', 'dd-mm-yyyy'), 7, 2542, to_date('30-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030420005439, to_date('20-04-2003', 'dd-mm-yyyy'), to_date('04-05-2003', 'dd-mm-yyyy'), 12, 3819, to_date('07-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060524005440, to_date('24-05-2006', 'dd-mm-yyyy'), to_date('07-06-2006', 'dd-mm-yyyy'), 10, 7676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070616005441, to_date('16-06-2007', 'dd-mm-yyyy'), to_date('30-06-2007', 'dd-mm-yyyy'), 3, 3907, to_date('03-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031207005442, to_date('07-12-2003', 'dd-mm-yyyy'), to_date('21-12-2003', 'dd-mm-yyyy'), 2, 3976, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010916005443, to_date('16-09-2001', 'dd-mm-yyyy'), to_date('30-09-2001', 'dd-mm-yyyy'), 12, 2439, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101201005444, to_date('01-12-2010', 'dd-mm-yyyy'), to_date('15-12-2010', 'dd-mm-yyyy'), 8, 6495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115005445, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 4, 1719, to_date('23-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130731005446, to_date('31-07-2013', 'dd-mm-yyyy'), to_date('14-08-2013', 'dd-mm-yyyy'), 3, 7859, to_date('03-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025005447, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 8, 6802, to_date('30-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050825005448, to_date('25-08-2005', 'dd-mm-yyyy'), to_date('08-09-2005', 'dd-mm-yyyy'), 10, 5824, to_date('03-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050329005449, to_date('29-03-2005', 'dd-mm-yyyy'), to_date('12-04-2005', 'dd-mm-yyyy'), 4, 5928, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070809005450, to_date('09-08-2007', 'dd-mm-yyyy'), to_date('23-08-2007', 'dd-mm-yyyy'), 6, 6326, to_date('27-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000616005451, to_date('16-06-2000', 'dd-mm-yyyy'), to_date('30-06-2000', 'dd-mm-yyyy'), 7, 2190, to_date('30-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080207005452, to_date('07-02-2008', 'dd-mm-yyyy'), to_date('21-02-2008', 'dd-mm-yyyy'), 8, 5905, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525005453, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 9, 3063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090126005454, to_date('26-01-2009', 'dd-mm-yyyy'), to_date('09-02-2009', 'dd-mm-yyyy'), 3, 6839, to_date('15-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070521005455, to_date('21-05-2007', 'dd-mm-yyyy'), to_date('04-06-2007', 'dd-mm-yyyy'), 8, 5579, to_date('22-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081216005456, to_date('16-12-2008', 'dd-mm-yyyy'), to_date('30-12-2008', 'dd-mm-yyyy'), 8, 6265, to_date('01-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816005457, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 3, 5601, to_date('22-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111009005458, to_date('09-10-2011', 'dd-mm-yyyy'), to_date('23-10-2011', 'dd-mm-yyyy'), 4, 8108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220005459, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 4, 9753, to_date('01-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119005460, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 2, 10143, to_date('03-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112005461, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 12, 4608, to_date('30-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010721005462, to_date('21-07-2001', 'dd-mm-yyyy'), to_date('04-08-2001', 'dd-mm-yyyy'), 5, 1791, to_date('28-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051027005463, to_date('27-10-2005', 'dd-mm-yyyy'), to_date('10-11-2005', 'dd-mm-yyyy'), 5, 3516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130821005464, to_date('21-08-2013', 'dd-mm-yyyy'), to_date('04-09-2013', 'dd-mm-yyyy'), 4, 8526, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219005465, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 2, 3448, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060501005466, to_date('01-05-2006', 'dd-mm-yyyy'), to_date('15-05-2006', 'dd-mm-yyyy'), 2, 3493, to_date('12-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060722005467, to_date('22-07-2006', 'dd-mm-yyyy'), to_date('05-08-2006', 'dd-mm-yyyy'), 3, 5060, to_date('24-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001217005468, to_date('17-12-2000', 'dd-mm-yyyy'), to_date('31-12-2000', 'dd-mm-yyyy'), 11, 1758, to_date('01-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430005469, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 7, 6851, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525005470, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 7, 4438, to_date('31-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100507005471, to_date('07-05-2010', 'dd-mm-yyyy'), to_date('21-05-2010', 'dd-mm-yyyy'), 7, 7532, to_date('10-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110929005472, to_date('29-09-2011', 'dd-mm-yyyy'), to_date('13-10-2011', 'dd-mm-yyyy'), 10, 8661, to_date('13-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100901005473, to_date('01-09-2010', 'dd-mm-yyyy'), to_date('15-09-2010', 'dd-mm-yyyy'), 3, 7140, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061114005474, to_date('14-11-2006', 'dd-mm-yyyy'), to_date('28-11-2006', 'dd-mm-yyyy'), 10, 4254, to_date('17-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130715005475, to_date('15-07-2013', 'dd-mm-yyyy'), to_date('29-07-2013', 'dd-mm-yyyy'), 9, 9290, to_date('21-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060222005476, to_date('22-02-2006', 'dd-mm-yyyy'), to_date('08-03-2006', 'dd-mm-yyyy'), 6, 4112, to_date('27-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060411005477, to_date('11-04-2006', 'dd-mm-yyyy'), to_date('25-04-2006', 'dd-mm-yyyy'), 2, 4225, to_date('17-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080724005478, to_date('24-07-2008', 'dd-mm-yyyy'), to_date('07-08-2008', 'dd-mm-yyyy'), 2, 4458, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060122005479, to_date('22-01-2006', 'dd-mm-yyyy'), to_date('05-02-2006', 'dd-mm-yyyy'), 6, 4950, to_date('02-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423005480, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 2, 5163, to_date('09-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080207005481, to_date('07-02-2008', 'dd-mm-yyyy'), to_date('21-02-2008', 'dd-mm-yyyy'), 6, 3596, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040320005482, to_date('20-03-2004', 'dd-mm-yyyy'), to_date('03-04-2004', 'dd-mm-yyyy'), 8, 4023, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050904005483, to_date('04-09-2005', 'dd-mm-yyyy'), to_date('18-09-2005', 'dd-mm-yyyy'), 8, 4698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617005484, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 12, 2009, to_date('26-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080204005485, to_date('04-02-2008', 'dd-mm-yyyy'), to_date('18-02-2008', 'dd-mm-yyyy'), 8, 8405, to_date('23-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000610005486, to_date('10-06-2000', 'dd-mm-yyyy'), to_date('24-06-2000', 'dd-mm-yyyy'), 4, 3356, to_date('20-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607005487, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 9, 4005, to_date('15-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131006005488, to_date('06-10-2013', 'dd-mm-yyyy'), to_date('20-10-2013', 'dd-mm-yyyy'), 11, 7502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121005489, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 7, 4508, to_date('25-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513005490, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 5, 2701, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423005491, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 5, 2722, to_date('09-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607005492, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 7, 5702, to_date('14-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131225005493, to_date('25-12-2013', 'dd-mm-yyyy'), to_date('08-01-2014', 'dd-mm-yyyy'), 6, 10090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305005494, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 2, 7781, to_date('07-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071009005495, to_date('09-10-2007', 'dd-mm-yyyy'), to_date('23-10-2007', 'dd-mm-yyyy'), 5, 6839, to_date('28-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922005496, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 2, 8435, to_date('05-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111123005497, to_date('23-11-2011', 'dd-mm-yyyy'), to_date('07-12-2011', 'dd-mm-yyyy'), 10, 6279, to_date('04-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020115005498, to_date('15-01-2002', 'dd-mm-yyyy'), to_date('29-01-2002', 'dd-mm-yyyy'), 4, 4773, to_date('21-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061018005499, to_date('18-10-2006', 'dd-mm-yyyy'), to_date('01-11-2006', 'dd-mm-yyyy'), 3, 5012, to_date('22-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031011005500, to_date('11-10-2003', 'dd-mm-yyyy'), to_date('25-10-2003', 'dd-mm-yyyy'), 9, 4202, to_date('15-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071012005501, to_date('12-10-2007', 'dd-mm-yyyy'), to_date('26-10-2007', 'dd-mm-yyyy'), 6, 5179, to_date('21-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001127005502, to_date('27-11-2000', 'dd-mm-yyyy'), to_date('11-12-2000', 'dd-mm-yyyy'), 9, 3492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050507005503, to_date('07-05-2005', 'dd-mm-yyyy'), to_date('21-05-2005', 'dd-mm-yyyy'), 10, 4251, to_date('10-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226005504, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 5, 1055, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020419005505, to_date('19-04-2002', 'dd-mm-yyyy'), to_date('03-05-2002', 'dd-mm-yyyy'), 1, 3039, to_date('21-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090411005506, to_date('11-04-2009', 'dd-mm-yyyy'), to_date('25-04-2009', 'dd-mm-yyyy'), 4, 6199, to_date('21-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100405005507, to_date('05-04-2010', 'dd-mm-yyyy'), to_date('19-04-2010', 'dd-mm-yyyy'), 8, 7092, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071203007651, to_date('03-12-2007', 'dd-mm-yyyy'), to_date('17-12-2007', 'dd-mm-yyyy'), 4, 5788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061219007652, to_date('19-12-2006', 'dd-mm-yyyy'), to_date('02-01-2007', 'dd-mm-yyyy'), 7, 5119, to_date('28-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000310007653, to_date('10-03-2000', 'dd-mm-yyyy'), to_date('24-03-2000', 'dd-mm-yyyy'), 10, 2004, to_date('23-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050809007654, to_date('09-08-2005', 'dd-mm-yyyy'), to_date('23-08-2005', 'dd-mm-yyyy'), 7, 6582, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070216007655, to_date('16-02-2007', 'dd-mm-yyyy'), to_date('02-03-2007', 'dd-mm-yyyy'), 2, 5220, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101119007656, to_date('19-11-2010', 'dd-mm-yyyy'), to_date('03-12-2010', 'dd-mm-yyyy'), 9, 7700, to_date('27-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000531007657, to_date('31-05-2000', 'dd-mm-yyyy'), to_date('14-06-2000', 'dd-mm-yyyy'), 6, 1904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624007658, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 5, 2112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031014007659, to_date('14-10-2003', 'dd-mm-yyyy'), to_date('28-10-2003', 'dd-mm-yyyy'), 7, 2360, to_date('02-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815007660, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 10, 3114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050124007661, to_date('24-01-2005', 'dd-mm-yyyy'), to_date('07-02-2005', 'dd-mm-yyyy'), 3, 4620, to_date('26-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050507007662, to_date('07-05-2005', 'dd-mm-yyyy'), to_date('21-05-2005', 'dd-mm-yyyy'), 4, 3789, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104007663, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 10, 3683, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020612007664, to_date('12-06-2002', 'dd-mm-yyyy'), to_date('26-06-2002', 'dd-mm-yyyy'), 7, 3170, to_date('26-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090401007665, to_date('01-04-2009', 'dd-mm-yyyy'), to_date('15-04-2009', 'dd-mm-yyyy'), 3, 6520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030824007666, to_date('24-08-2003', 'dd-mm-yyyy'), to_date('07-09-2003', 'dd-mm-yyyy'), 9, 2460, to_date('07-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000610007667, to_date('10-06-2000', 'dd-mm-yyyy'), to_date('24-06-2000', 'dd-mm-yyyy'), 2, 1635, to_date('27-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110228007668, to_date('28-02-2011', 'dd-mm-yyyy'), to_date('14-03-2011', 'dd-mm-yyyy'), 10, 6343, to_date('20-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050926007669, to_date('26-09-2005', 'dd-mm-yyyy'), to_date('10-10-2005', 'dd-mm-yyyy'), 6, 3738, to_date('10-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011215007670, to_date('15-12-2001', 'dd-mm-yyyy'), to_date('29-12-2001', 'dd-mm-yyyy'), 7, 942, to_date('26-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413007671, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 7, 8865, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425007672, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 5, 5652, to_date('11-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031007673, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 1, 2733, to_date('11-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728007674, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 11, 7121, to_date('04-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127007675, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 11, 1864, to_date('07-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111007676, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 1, 5647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040327007677, to_date('27-03-2004', 'dd-mm-yyyy'), to_date('10-04-2004', 'dd-mm-yyyy'), 7, 2454, to_date('02-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804007678, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 7, 10121, to_date('07-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711007679, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 11, 6440, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080721007680, to_date('21-07-2008', 'dd-mm-yyyy'), to_date('04-08-2008', 'dd-mm-yyyy'), 6, 6978, to_date('09-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021122007681, to_date('22-11-2002', 'dd-mm-yyyy'), to_date('06-12-2002', 'dd-mm-yyyy'), 10, 2510, to_date('06-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308007682, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 4, 3038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071211007683, to_date('11-12-2007', 'dd-mm-yyyy'), to_date('25-12-2007', 'dd-mm-yyyy'), 4, 3535, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110826007684, to_date('26-08-2011', 'dd-mm-yyyy'), to_date('09-09-2011', 'dd-mm-yyyy'), 10, 4905, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130903007685, to_date('03-09-2013', 'dd-mm-yyyy'), to_date('17-09-2013', 'dd-mm-yyyy'), 8, 7668, to_date('19-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070611007686, to_date('11-06-2007', 'dd-mm-yyyy'), to_date('25-06-2007', 'dd-mm-yyyy'), 5, 4591, to_date('18-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001214007687, to_date('14-12-2000', 'dd-mm-yyyy'), to_date('28-12-2000', 'dd-mm-yyyy'), 10, 1309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040111007688, to_date('11-01-2004', 'dd-mm-yyyy'), to_date('25-01-2004', 'dd-mm-yyyy'), 2, 3587, to_date('28-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620007689, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 12, 3969, to_date('01-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302007690, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 7, 6209, to_date('12-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000816007691, to_date('16-08-2000', 'dd-mm-yyyy'), to_date('30-08-2000', 'dd-mm-yyyy'), 5, 3224, to_date('02-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090530007692, to_date('30-05-2009', 'dd-mm-yyyy'), to_date('13-06-2009', 'dd-mm-yyyy'), 12, 7343, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031103007693, to_date('03-11-2003', 'dd-mm-yyyy'), to_date('17-11-2003', 'dd-mm-yyyy'), 7, 3601, to_date('07-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121108007694, to_date('08-11-2012', 'dd-mm-yyyy'), to_date('22-11-2012', 'dd-mm-yyyy'), 10, 7664, to_date('19-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128007695, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 10, 3453, to_date('16-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010718007696, to_date('18-07-2001', 'dd-mm-yyyy'), to_date('01-08-2001', 'dd-mm-yyyy'), 2, 1561, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070624007697, to_date('24-06-2007', 'dd-mm-yyyy'), to_date('08-07-2007', 'dd-mm-yyyy'), 4, 5029, to_date('02-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110221007698, to_date('21-02-2011', 'dd-mm-yyyy'), to_date('07-03-2011', 'dd-mm-yyyy'), 7, 8729, to_date('07-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021002007699, to_date('02-10-2002', 'dd-mm-yyyy'), to_date('16-10-2002', 'dd-mm-yyyy'), 6, 4252, to_date('09-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110221007700, to_date('21-02-2011', 'dd-mm-yyyy'), to_date('07-03-2011', 'dd-mm-yyyy'), 3, 6920, to_date('01-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008007701, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 12, 6027, to_date('19-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060202007702, to_date('02-02-2006', 'dd-mm-yyyy'), to_date('16-02-2006', 'dd-mm-yyyy'), 7, 5625, to_date('04-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010520007703, to_date('20-05-2001', 'dd-mm-yyyy'), to_date('03-06-2001', 'dd-mm-yyyy'), 3, 1926, to_date('30-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100119007704, to_date('19-01-2010', 'dd-mm-yyyy'), to_date('02-02-2010', 'dd-mm-yyyy'), 3, 5439, to_date('02-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020429007705, to_date('29-04-2002', 'dd-mm-yyyy'), to_date('13-05-2002', 'dd-mm-yyyy'), 10, 4018, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912007706, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 5, 3787, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013007707, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 6, 4472, to_date('18-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080811007708, to_date('11-08-2008', 'dd-mm-yyyy'), to_date('25-08-2008', 'dd-mm-yyyy'), 10, 5389, to_date('18-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080526007709, to_date('26-05-2008', 'dd-mm-yyyy'), to_date('09-06-2008', 'dd-mm-yyyy'), 11, 3693, to_date('12-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121107007710, to_date('07-11-2012', 'dd-mm-yyyy'), to_date('21-11-2012', 'dd-mm-yyyy'), 10, 9835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071228007711, to_date('28-12-2007', 'dd-mm-yyyy'), to_date('11-01-2008', 'dd-mm-yyyy'), 6, 4619, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606007712, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 6, 2667, to_date('10-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507007713, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 7, 3057, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040420007714, to_date('20-04-2004', 'dd-mm-yyyy'), to_date('04-05-2004', 'dd-mm-yyyy'), 8, 4194, to_date('07-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061208007715, to_date('08-12-2006', 'dd-mm-yyyy'), to_date('22-12-2006', 'dd-mm-yyyy'), 3, 4124, to_date('13-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008007716, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 1, 3223, to_date('23-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041231007717, to_date('31-12-2004', 'dd-mm-yyyy'), to_date('14-01-2005', 'dd-mm-yyyy'), 7, 4778, to_date('12-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070306007718, to_date('06-03-2007', 'dd-mm-yyyy'), to_date('20-03-2007', 'dd-mm-yyyy'), 7, 7313, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512007719, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 8, 4526, to_date('26-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101026007720, to_date('26-10-2010', 'dd-mm-yyyy'), to_date('09-11-2010', 'dd-mm-yyyy'), 9, 5874, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090506007721, to_date('06-05-2009', 'dd-mm-yyyy'), to_date('20-05-2009', 'dd-mm-yyyy'), 7, 5578, to_date('09-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090402007722, to_date('02-04-2009', 'dd-mm-yyyy'), to_date('16-04-2009', 'dd-mm-yyyy'), 4, 9230, to_date('03-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120810007723, to_date('10-08-2012', 'dd-mm-yyyy'), to_date('24-08-2012', 'dd-mm-yyyy'), 6, 8257, to_date('19-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140121007724, to_date('21-01-2014', 'dd-mm-yyyy'), to_date('04-02-2014', 'dd-mm-yyyy'), 11, 8544, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071029007725, to_date('29-10-2007', 'dd-mm-yyyy'), to_date('12-11-2007', 'dd-mm-yyyy'), 1, 4818, to_date('14-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120221007726, to_date('21-02-2012', 'dd-mm-yyyy'), to_date('06-03-2012', 'dd-mm-yyyy'), 3, 7455, to_date('03-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916007727, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 7, 5729, to_date('30-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071101007728, to_date('01-11-2007', 'dd-mm-yyyy'), to_date('15-11-2007', 'dd-mm-yyyy'), 11, 6231, to_date('05-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071004007729, to_date('04-10-2007', 'dd-mm-yyyy'), to_date('18-10-2007', 'dd-mm-yyyy'), 2, 5971, to_date('14-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813007730, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 9, 2190, to_date('18-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030128007731, to_date('28-01-2003', 'dd-mm-yyyy'), to_date('11-02-2003', 'dd-mm-yyyy'), 4, 4992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621007732, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 6, 8213, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090814007733, to_date('14-08-2009', 'dd-mm-yyyy'), to_date('28-08-2009', 'dd-mm-yyyy'), 8, 6774, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080704007734, to_date('04-07-2008', 'dd-mm-yyyy'), to_date('18-07-2008', 'dd-mm-yyyy'), 12, 4777, to_date('23-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011209007735, to_date('09-12-2001', 'dd-mm-yyyy'), to_date('23-12-2001', 'dd-mm-yyyy'), 9, 2660, to_date('29-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090908007736, to_date('08-09-2009', 'dd-mm-yyyy'), to_date('22-09-2009', 'dd-mm-yyyy'), 2, 3497, to_date('15-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618007737, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 2, 8111, to_date('29-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051013007738, to_date('13-10-2005', 'dd-mm-yyyy'), to_date('27-10-2005', 'dd-mm-yyyy'), 8, 5923, to_date('16-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110827007739, to_date('27-08-2011', 'dd-mm-yyyy'), to_date('10-09-2011', 'dd-mm-yyyy'), 9, 10273, to_date('11-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060128007740, to_date('28-01-2006', 'dd-mm-yyyy'), to_date('11-02-2006', 'dd-mm-yyyy'), 2, 6298, to_date('07-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120629007741, to_date('29-06-2012', 'dd-mm-yyyy'), to_date('13-07-2012', 'dd-mm-yyyy'), 11, 9581, to_date('05-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130407007742, to_date('07-04-2013', 'dd-mm-yyyy'), to_date('21-04-2013', 'dd-mm-yyyy'), 10, 9254, to_date('17-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001007743, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 4, 3536, to_date('17-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110007744, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 5, 7247, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326007745, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 1, 7924, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121006007746, to_date('06-10-2012', 'dd-mm-yyyy'), to_date('20-10-2012', 'dd-mm-yyyy'), 5, 8372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090315007747, to_date('15-03-2009', 'dd-mm-yyyy'), to_date('29-03-2009', 'dd-mm-yyyy'), 8, 8967, to_date('27-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806007748, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 4, 7214, to_date('24-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000126007749, to_date('26-01-2000', 'dd-mm-yyyy'), to_date('09-02-2000', 'dd-mm-yyyy'), 4, 1854, to_date('04-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030502007750, to_date('02-05-2003', 'dd-mm-yyyy'), to_date('16-05-2003', 'dd-mm-yyyy'), 6, 4109, to_date('16-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080320007751, to_date('20-03-2008', 'dd-mm-yyyy'), to_date('03-04-2008', 'dd-mm-yyyy'), 12, 6351, to_date('25-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090625007752, to_date('25-06-2009', 'dd-mm-yyyy'), to_date('09-07-2009', 'dd-mm-yyyy'), 10, 5596, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113007753, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 10, 10740, to_date('02-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511007754, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 4, 2079, to_date('27-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011013007755, to_date('13-10-2001', 'dd-mm-yyyy'), to_date('27-10-2001', 'dd-mm-yyyy'), 1, 3050, to_date('18-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030818007756, to_date('18-08-2003', 'dd-mm-yyyy'), to_date('01-09-2003', 'dd-mm-yyyy'), 1, 2750, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224007757, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 12, 5884, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100527007758, to_date('27-05-2010', 'dd-mm-yyyy'), to_date('10-06-2010', 'dd-mm-yyyy'), 6, 10474, to_date('30-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100115007759, to_date('15-01-2010', 'dd-mm-yyyy'), to_date('29-01-2010', 'dd-mm-yyyy'), 3, 6008, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020923007760, to_date('23-09-2002', 'dd-mm-yyyy'), to_date('07-10-2002', 'dd-mm-yyyy'), 10, 940, to_date('08-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080626007761, to_date('26-06-2008', 'dd-mm-yyyy'), to_date('10-07-2008', 'dd-mm-yyyy'), 6, 6206, to_date('04-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030209007762, to_date('09-02-2003', 'dd-mm-yyyy'), to_date('23-02-2003', 'dd-mm-yyyy'), 4, 3086, to_date('10-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060616007763, to_date('16-06-2006', 'dd-mm-yyyy'), to_date('30-06-2006', 'dd-mm-yyyy'), 9, 5570, to_date('19-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110226007764, to_date('26-02-2011', 'dd-mm-yyyy'), to_date('12-03-2011', 'dd-mm-yyyy'), 4, 7856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080227007765, to_date('27-02-2008', 'dd-mm-yyyy'), to_date('12-03-2008', 'dd-mm-yyyy'), 9, 6257, to_date('06-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020927007766, to_date('27-09-2002', 'dd-mm-yyyy'), to_date('11-10-2002', 'dd-mm-yyyy'), 1, 1876, to_date('10-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130910007767, to_date('10-09-2013', 'dd-mm-yyyy'), to_date('24-09-2013', 'dd-mm-yyyy'), 2, 7111, to_date('21-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011020007768, to_date('20-10-2001', 'dd-mm-yyyy'), to_date('03-11-2001', 'dd-mm-yyyy'), 11, 2278, to_date('30-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131015007769, to_date('15-10-2013', 'dd-mm-yyyy'), to_date('29-10-2013', 'dd-mm-yyyy'), 1, 8312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090905007770, to_date('05-09-2009', 'dd-mm-yyyy'), to_date('19-09-2009', 'dd-mm-yyyy'), 6, 5117, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608007771, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 9, 6158, to_date('09-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104007772, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 8, 2256, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231007773, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 2, 8088, to_date('11-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090416007774, to_date('16-04-2009', 'dd-mm-yyyy'), to_date('30-04-2009', 'dd-mm-yyyy'), 11, 6641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417007775, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 7, 5042, to_date('03-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130427007776, to_date('27-04-2013', 'dd-mm-yyyy'), to_date('11-05-2013', 'dd-mm-yyyy'), 7, 11021, to_date('16-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080528007777, to_date('28-05-2008', 'dd-mm-yyyy'), to_date('11-06-2008', 'dd-mm-yyyy'), 7, 5912, to_date('13-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218007778, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 2, 4741, to_date('23-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111011007779, to_date('11-10-2011', 'dd-mm-yyyy'), to_date('25-10-2011', 'dd-mm-yyyy'), 5, 7474, to_date('14-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714007780, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 1, 6679, to_date('20-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129007781, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 10, 8986, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080421007782, to_date('21-04-2008', 'dd-mm-yyyy'), to_date('05-05-2008', 'dd-mm-yyyy'), 5, 4944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224007783, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 4, 8094, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071123007784, to_date('23-11-2007', 'dd-mm-yyyy'), to_date('07-12-2007', 'dd-mm-yyyy'), 5, 4089, to_date('27-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080727007785, to_date('27-07-2008', 'dd-mm-yyyy'), to_date('10-08-2008', 'dd-mm-yyyy'), 11, 5858, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080112007786, to_date('12-01-2008', 'dd-mm-yyyy'), to_date('26-01-2008', 'dd-mm-yyyy'), 2, 6059, to_date('15-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311007787, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 5, 6133, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110809007788, to_date('09-08-2011', 'dd-mm-yyyy'), to_date('23-08-2011', 'dd-mm-yyyy'), 12, 7028, to_date('18-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020519007789, to_date('19-05-2002', 'dd-mm-yyyy'), to_date('02-06-2002', 'dd-mm-yyyy'), 9, 2492, to_date('04-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702007790, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 10, 2495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021024007791, to_date('24-10-2002', 'dd-mm-yyyy'), to_date('07-11-2002', 'dd-mm-yyyy'), 10, 3460, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010610007792, to_date('10-06-2001', 'dd-mm-yyyy'), to_date('24-06-2001', 'dd-mm-yyyy'), 12, 2093, to_date('28-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010704007793, to_date('04-07-2001', 'dd-mm-yyyy'), to_date('18-07-2001', 'dd-mm-yyyy'), 4, 3708, to_date('24-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020923007794, to_date('23-09-2002', 'dd-mm-yyyy'), to_date('07-10-2002', 'dd-mm-yyyy'), 3, 2383, to_date('02-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040416007795, to_date('16-04-2004', 'dd-mm-yyyy'), to_date('30-04-2004', 'dd-mm-yyyy'), 10, 3672, to_date('29-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100528007796, to_date('28-05-2010', 'dd-mm-yyyy'), to_date('11-06-2010', 'dd-mm-yyyy'), 5, 5382, to_date('15-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080625007797, to_date('25-06-2008', 'dd-mm-yyyy'), to_date('09-07-2008', 'dd-mm-yyyy'), 6, 6192, to_date('04-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824007798, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 7, 6958, to_date('25-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110818007799, to_date('18-08-2011', 'dd-mm-yyyy'), to_date('01-09-2011', 'dd-mm-yyyy'), 9, 6957, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120501007800, to_date('01-05-2012', 'dd-mm-yyyy'), to_date('15-05-2012', 'dd-mm-yyyy'), 8, 8086, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040701007801, to_date('01-07-2004', 'dd-mm-yyyy'), to_date('15-07-2004', 'dd-mm-yyyy'), 1, 6148, to_date('03-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815007802, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 9, 4106, to_date('19-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429007803, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 10, 4031, to_date('17-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091116000765, to_date('16-11-2009', 'dd-mm-yyyy'), to_date('30-11-2009', 'dd-mm-yyyy'), 7, 8942, to_date('05-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515000766, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 6, 2837, to_date('03-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101000767, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 4, 3116, to_date('03-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111020000768, to_date('20-10-2011', 'dd-mm-yyyy'), to_date('03-11-2011', 'dd-mm-yyyy'), 8, 8389, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000604000769, to_date('04-06-2000', 'dd-mm-yyyy'), to_date('18-06-2000', 'dd-mm-yyyy'), 6, 2186, to_date('12-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725000770, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 12, 3323, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000310000771, to_date('10-03-2000', 'dd-mm-yyyy'), to_date('24-03-2000', 'dd-mm-yyyy'), 3, 1492, to_date('29-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418000772, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 8, 370, to_date('02-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020803000773, to_date('03-08-2002', 'dd-mm-yyyy'), to_date('17-08-2002', 'dd-mm-yyyy'), 9, 3291, to_date('19-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101123000774, to_date('23-11-2010', 'dd-mm-yyyy'), to_date('07-12-2010', 'dd-mm-yyyy'), 9, 7409, to_date('13-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110321000775, to_date('21-03-2011', 'dd-mm-yyyy'), to_date('04-04-2011', 'dd-mm-yyyy'), 9, 5715, to_date('31-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127000776, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 2, 1667, to_date('05-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117000777, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 8, 10007, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010223000778, to_date('23-02-2001', 'dd-mm-yyyy'), to_date('09-03-2001', 'dd-mm-yyyy'), 4, 1552, to_date('03-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915000779, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 11, 5315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030303000780, to_date('03-03-2003', 'dd-mm-yyyy'), to_date('17-03-2003', 'dd-mm-yyyy'), 11, 3415, to_date('04-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120211000781, to_date('11-02-2012', 'dd-mm-yyyy'), to_date('25-02-2012', 'dd-mm-yyyy'), 12, 9432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121209000782, to_date('09-12-2012', 'dd-mm-yyyy'), to_date('23-12-2012', 'dd-mm-yyyy'), 7, 7086, to_date('11-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061217000783, to_date('17-12-2006', 'dd-mm-yyyy'), to_date('31-12-2006', 'dd-mm-yyyy'), 2, 7018, to_date('24-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703000784, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 10, 5698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110301000785, to_date('01-03-2011', 'dd-mm-yyyy'), to_date('15-03-2011', 'dd-mm-yyyy'), 11, 8175, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108000786, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 4, 3079, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924000787, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 1, 3204, to_date('04-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627000788, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 11, 6965, to_date('30-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109000789, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 8, 3340, to_date('27-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050730000790, to_date('30-07-2005', 'dd-mm-yyyy'), to_date('13-08-2005', 'dd-mm-yyyy'), 3, 8192, to_date('06-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000525000791, to_date('25-05-2000', 'dd-mm-yyyy'), to_date('08-06-2000', 'dd-mm-yyyy'), 5, 792, to_date('05-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321000792, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 11, 10721, to_date('31-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060407000793, to_date('07-04-2006', 'dd-mm-yyyy'), to_date('21-04-2006', 'dd-mm-yyyy'), 6, 4547, to_date('18-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001217000794, to_date('17-12-2000', 'dd-mm-yyyy'), to_date('31-12-2000', 'dd-mm-yyyy'), 3, 769, to_date('19-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222000795, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 5, 2389, to_date('01-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080818000796, to_date('18-08-2008', 'dd-mm-yyyy'), to_date('01-09-2008', 'dd-mm-yyyy'), 1, 6899, to_date('01-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050930000797, to_date('30-09-2005', 'dd-mm-yyyy'), to_date('14-10-2005', 'dd-mm-yyyy'), 9, 5401, to_date('20-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020329000798, to_date('29-03-2002', 'dd-mm-yyyy'), to_date('12-04-2002', 'dd-mm-yyyy'), 10, 3412, to_date('01-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001127000799, to_date('27-11-2000', 'dd-mm-yyyy'), to_date('11-12-2000', 'dd-mm-yyyy'), 10, 1927, to_date('09-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111000800, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 10, 6342, to_date('22-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040921000801, to_date('21-09-2004', 'dd-mm-yyyy'), to_date('05-10-2004', 'dd-mm-yyyy'), 7, 1703, to_date('27-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130301000802, to_date('01-03-2013', 'dd-mm-yyyy'), to_date('15-03-2013', 'dd-mm-yyyy'), 3, 9772, to_date('07-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061013000803, to_date('13-10-2006', 'dd-mm-yyyy'), to_date('27-10-2006', 'dd-mm-yyyy'), 1, 7368, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116000804, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 12, 5345, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111000805, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 3, 1070, to_date('30-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130913000806, to_date('13-09-2013', 'dd-mm-yyyy'), to_date('27-09-2013', 'dd-mm-yyyy'), 10, 7576, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926000807, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 8, 6922, to_date('14-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100503000808, to_date('03-05-2010', 'dd-mm-yyyy'), to_date('17-05-2010', 'dd-mm-yyyy'), 1, 6201, to_date('04-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011000809, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 9, 1242, to_date('17-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417000810, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 1, 4751, to_date('27-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908000811, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 11, 3928, to_date('15-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100526000812, to_date('26-05-2010', 'dd-mm-yyyy'), to_date('09-06-2010', 'dd-mm-yyyy'), 5, 7521, to_date('06-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011127000813, to_date('27-11-2001', 'dd-mm-yyyy'), to_date('11-12-2001', 'dd-mm-yyyy'), 6, 3188, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823000814, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 12, 3534, to_date('02-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061015000815, to_date('15-10-2006', 'dd-mm-yyyy'), to_date('29-10-2006', 'dd-mm-yyyy'), 5, 6020, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050313000816, to_date('13-03-2005', 'dd-mm-yyyy'), to_date('27-03-2005', 'dd-mm-yyyy'), 11, 2747, to_date('20-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051221000817, to_date('21-12-2005', 'dd-mm-yyyy'), to_date('04-01-2006', 'dd-mm-yyyy'), 6, 3741, to_date('28-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010711000818, to_date('11-07-2001', 'dd-mm-yyyy'), to_date('25-07-2001', 'dd-mm-yyyy'), 10, 320, to_date('20-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130422000819, to_date('22-04-2013', 'dd-mm-yyyy'), to_date('06-05-2013', 'dd-mm-yyyy'), 1, 7593, to_date('29-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315000820, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 2, 4956, to_date('03-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020406000821, to_date('06-04-2002', 'dd-mm-yyyy'), to_date('20-04-2002', 'dd-mm-yyyy'), 3, 3178, to_date('08-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031112000822, to_date('12-11-2003', 'dd-mm-yyyy'), to_date('26-11-2003', 'dd-mm-yyyy'), 6, 2248, to_date('22-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020403000823, to_date('03-04-2002', 'dd-mm-yyyy'), to_date('17-04-2002', 'dd-mm-yyyy'), 6, 2373, to_date('17-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823000824, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 7, 7466, to_date('02-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028000825, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 10, 6860, to_date('13-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011010000826, to_date('10-10-2001', 'dd-mm-yyyy'), to_date('24-10-2001', 'dd-mm-yyyy'), 11, 4010, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030501000827, to_date('01-05-2003', 'dd-mm-yyyy'), to_date('15-05-2003', 'dd-mm-yyyy'), 11, 2008, to_date('08-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030529000828, to_date('29-05-2003', 'dd-mm-yyyy'), to_date('12-06-2003', 'dd-mm-yyyy'), 11, 4377, to_date('12-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051105000829, to_date('05-11-2005', 'dd-mm-yyyy'), to_date('19-11-2005', 'dd-mm-yyyy'), 9, 5120, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070927000830, to_date('27-09-2007', 'dd-mm-yyyy'), to_date('11-10-2007', 'dd-mm-yyyy'), 8, 3862, to_date('30-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021125000831, to_date('25-11-2002', 'dd-mm-yyyy'), to_date('09-12-2002', 'dd-mm-yyyy'), 10, 1988, to_date('11-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131112000832, to_date('12-11-2013', 'dd-mm-yyyy'), to_date('26-11-2013', 'dd-mm-yyyy'), 9, 9010, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051220000833, to_date('20-12-2005', 'dd-mm-yyyy'), to_date('03-01-2006', 'dd-mm-yyyy'), 7, 4162, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119000834, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 6, 10729, to_date('04-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101000835, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 11, 3874, to_date('07-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060806000836, to_date('06-08-2006', 'dd-mm-yyyy'), to_date('20-08-2006', 'dd-mm-yyyy'), 8, 5686, to_date('22-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101222000837, to_date('22-12-2010', 'dd-mm-yyyy'), to_date('05-01-2011', 'dd-mm-yyyy'), 11, 7908, to_date('24-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070411000838, to_date('11-04-2007', 'dd-mm-yyyy'), to_date('25-04-2007', 'dd-mm-yyyy'), 12, 5907, to_date('01-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070403000839, to_date('03-04-2007', 'dd-mm-yyyy'), to_date('17-04-2007', 'dd-mm-yyyy'), 5, 6096, to_date('09-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090119000840, to_date('19-01-2009', 'dd-mm-yyyy'), to_date('02-02-2009', 'dd-mm-yyyy'), 3, 6691, to_date('02-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130625000841, to_date('25-06-2013', 'dd-mm-yyyy'), to_date('09-07-2013', 'dd-mm-yyyy'), 10, 8597, to_date('28-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000910000842, to_date('10-09-2000', 'dd-mm-yyyy'), to_date('24-09-2000', 'dd-mm-yyyy'), 2, 1748, to_date('22-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061130000843, to_date('30-11-2006', 'dd-mm-yyyy'), to_date('14-12-2006', 'dd-mm-yyyy'), 11, 3469, to_date('04-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201000844, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 3, 3917, to_date('08-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100414000845, to_date('14-04-2010', 'dd-mm-yyyy'), to_date('28-04-2010', 'dd-mm-yyyy'), 2, 8383, to_date('01-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030909000846, to_date('09-09-2003', 'dd-mm-yyyy'), to_date('23-09-2003', 'dd-mm-yyyy'), 8, 2992, to_date('14-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101103000847, to_date('03-11-2010', 'dd-mm-yyyy'), to_date('17-11-2010', 'dd-mm-yyyy'), 2, 6823, to_date('16-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100207000848, to_date('07-02-2010', 'dd-mm-yyyy'), to_date('21-02-2010', 'dd-mm-yyyy'), 7, 7392, to_date('12-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010723000849, to_date('23-07-2001', 'dd-mm-yyyy'), to_date('06-08-2001', 'dd-mm-yyyy'), 11, 1813, to_date('01-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100324000850, to_date('24-03-2010', 'dd-mm-yyyy'), to_date('07-04-2010', 'dd-mm-yyyy'), 8, 9088, to_date('12-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029000851, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 7, 5632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071220000852, to_date('20-12-2007', 'dd-mm-yyyy'), to_date('03-01-2008', 'dd-mm-yyyy'), 11, 3347, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011228000853, to_date('28-12-2001', 'dd-mm-yyyy'), to_date('11-01-2002', 'dd-mm-yyyy'), 6, 1365, to_date('11-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603000854, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 4, 7114, to_date('07-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000428000855, to_date('28-04-2000', 'dd-mm-yyyy'), to_date('12-05-2000', 'dd-mm-yyyy'), 2, 1896, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101124000856, to_date('24-11-2010', 'dd-mm-yyyy'), to_date('08-12-2010', 'dd-mm-yyyy'), 12, 6642, to_date('12-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831000857, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 2, 6645, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080316000858, to_date('16-03-2008', 'dd-mm-yyyy'), to_date('30-03-2008', 'dd-mm-yyyy'), 6, 7956, to_date('26-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080531000859, to_date('31-05-2008', 'dd-mm-yyyy'), to_date('14-06-2008', 'dd-mm-yyyy'), 10, 8526, to_date('18-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009000860, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 7, 3698, to_date('26-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311000861, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 4, 8894, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529000862, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 4, 8738, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101130000863, to_date('30-11-2010', 'dd-mm-yyyy'), to_date('14-12-2010', 'dd-mm-yyyy'), 11, 5726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127000864, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 7, 5215, to_date('13-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031021000865, to_date('21-10-2003', 'dd-mm-yyyy'), to_date('04-11-2003', 'dd-mm-yyyy'), 5, 4223, to_date('23-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526000866, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 11, 7711, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020906000867, to_date('06-09-2002', 'dd-mm-yyyy'), to_date('20-09-2002', 'dd-mm-yyyy'), 5, 2049, to_date('22-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030105000868, to_date('05-01-2003', 'dd-mm-yyyy'), to_date('19-01-2003', 'dd-mm-yyyy'), 10, 3157, to_date('11-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313000869, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 10, 4635, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716000870, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 3, 3442, to_date('19-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050724000871, to_date('24-07-2005', 'dd-mm-yyyy'), to_date('07-08-2005', 'dd-mm-yyyy'), 3, 5464, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090926000872, to_date('26-09-2009', 'dd-mm-yyyy'), to_date('10-10-2009', 'dd-mm-yyyy'), 12, 5024, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130310000873, to_date('10-03-2013', 'dd-mm-yyyy'), to_date('24-03-2013', 'dd-mm-yyyy'), 8, 9308, to_date('24-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604000874, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 2, 11699, to_date('06-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070610000875, to_date('10-06-2007', 'dd-mm-yyyy'), to_date('24-06-2007', 'dd-mm-yyyy'), 10, 6584, to_date('26-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020618000876, to_date('18-06-2002', 'dd-mm-yyyy'), to_date('02-07-2002', 'dd-mm-yyyy'), 10, 2436, to_date('24-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000606000877, to_date('06-06-2000', 'dd-mm-yyyy'), to_date('20-06-2000', 'dd-mm-yyyy'), 10, 1525, to_date('10-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120219000878, to_date('19-02-2012', 'dd-mm-yyyy'), to_date('04-03-2012', 'dd-mm-yyyy'), 10, 7593, to_date('07-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110528000879, to_date('28-05-2011', 'dd-mm-yyyy'), to_date('11-06-2011', 'dd-mm-yyyy'), 12, 9390, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050525000880, to_date('25-05-2005', 'dd-mm-yyyy'), to_date('08-06-2005', 'dd-mm-yyyy'), 8, 3827, to_date('06-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512000881, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 12, 3450, to_date('22-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210000882, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 9, 2580, to_date('25-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090315000883, to_date('15-03-2009', 'dd-mm-yyyy'), to_date('29-03-2009', 'dd-mm-yyyy'), 9, 5176, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040624000884, to_date('24-06-2004', 'dd-mm-yyyy'), to_date('08-07-2004', 'dd-mm-yyyy'), 7, 4605, to_date('05-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070414000885, to_date('14-04-2007', 'dd-mm-yyyy'), to_date('28-04-2007', 'dd-mm-yyyy'), 11, 7284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140214000886, to_date('14-02-2014', 'dd-mm-yyyy'), to_date('28-02-2014', 'dd-mm-yyyy'), 6, 8229, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719000887, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 7, 4407, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080412000888, to_date('12-04-2008', 'dd-mm-yyyy'), to_date('26-04-2008', 'dd-mm-yyyy'), 5, 6174, to_date('15-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101021000889, to_date('21-10-2010', 'dd-mm-yyyy'), to_date('04-11-2010', 'dd-mm-yyyy'), 6, 8482, to_date('25-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106000890, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 2, 3199, to_date('22-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513000891, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 11, 6306, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213000892, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 3, 6683, to_date('26-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070414000893, to_date('14-04-2007', 'dd-mm-yyyy'), to_date('28-04-2007', 'dd-mm-yyyy'), 1, 6238, to_date('03-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130630000894, to_date('30-06-2013', 'dd-mm-yyyy'), to_date('14-07-2013', 'dd-mm-yyyy'), 6, 8733, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041126000895, to_date('26-11-2004', 'dd-mm-yyyy'), to_date('10-12-2004', 'dd-mm-yyyy'), 11, 4119, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020409000896, to_date('09-04-2002', 'dd-mm-yyyy'), to_date('23-04-2002', 'dd-mm-yyyy'), 8, 1220, to_date('16-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912000897, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 4, 1183, to_date('15-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910000898, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 9, 6128, to_date('12-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026000899, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 3, 7180, to_date('13-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050320000900, to_date('20-03-2005', 'dd-mm-yyyy'), to_date('03-04-2005', 'dd-mm-yyyy'), 8, 4623, to_date('27-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081102000901, to_date('02-11-2008', 'dd-mm-yyyy'), to_date('16-11-2008', 'dd-mm-yyyy'), 11, 5534, to_date('18-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000416000902, to_date('16-04-2000', 'dd-mm-yyyy'), to_date('30-04-2000', 'dd-mm-yyyy'), 7, 1449, to_date('30-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010112000903, to_date('12-01-2001', 'dd-mm-yyyy'), to_date('26-01-2001', 'dd-mm-yyyy'), 8, 1194, to_date('29-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213000904, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 6, 3432, to_date('21-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140130000905, to_date('30-01-2014', 'dd-mm-yyyy'), to_date('13-02-2014', 'dd-mm-yyyy'), 10, 10388, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120924000906, to_date('24-09-2012', 'dd-mm-yyyy'), to_date('08-10-2012', 'dd-mm-yyyy'), 10, 12341, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825000907, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 1, 3013, to_date('09-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061127000908, to_date('27-11-2006', 'dd-mm-yyyy'), to_date('11-12-2006', 'dd-mm-yyyy'), 7, 3860, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100327000909, to_date('27-03-2010', 'dd-mm-yyyy'), to_date('10-04-2010', 'dd-mm-yyyy'), 12, 7179, to_date('12-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090916000910, to_date('16-09-2009', 'dd-mm-yyyy'), to_date('30-09-2009', 'dd-mm-yyyy'), 6, 5862, to_date('01-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130521000911, to_date('21-05-2013', 'dd-mm-yyyy'), to_date('04-06-2013', 'dd-mm-yyyy'), 2, 7335, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040220000912, to_date('20-02-2004', 'dd-mm-yyyy'), to_date('05-03-2004', 'dd-mm-yyyy'), 1, 5038, to_date('02-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112000913, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 1, 9981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081106000914, to_date('06-11-2008', 'dd-mm-yyyy'), to_date('20-11-2008', 'dd-mm-yyyy'), 2, 3678, to_date('12-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070129000915, to_date('29-01-2007', 'dd-mm-yyyy'), to_date('12-02-2007', 'dd-mm-yyyy'), 6, 3996, to_date('15-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020108003217, to_date('08-01-2002', 'dd-mm-yyyy'), to_date('22-01-2002', 'dd-mm-yyyy'), 10, 1613, to_date('26-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090420003218, to_date('20-04-2009', 'dd-mm-yyyy'), to_date('04-05-2009', 'dd-mm-yyyy'), 4, 8693, to_date('24-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071122003219, to_date('22-11-2007', 'dd-mm-yyyy'), to_date('06-12-2007', 'dd-mm-yyyy'), 2, 5294, to_date('28-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031031003220, to_date('31-10-2003', 'dd-mm-yyyy'), to_date('14-11-2003', 'dd-mm-yyyy'), 5, 3684, to_date('11-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070607003221, to_date('07-06-2007', 'dd-mm-yyyy'), to_date('21-06-2007', 'dd-mm-yyyy'), 9, 6587, to_date('24-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222003222, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 2, 625, to_date('09-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110730003223, to_date('30-07-2011', 'dd-mm-yyyy'), to_date('13-08-2011', 'dd-mm-yyyy'), 10, 8301, to_date('17-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510003224, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 2, 922, to_date('14-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120511003225, to_date('11-05-2012', 'dd-mm-yyyy'), to_date('25-05-2012', 'dd-mm-yyyy'), 5, 6499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020123003226, to_date('23-01-2002', 'dd-mm-yyyy'), to_date('06-02-2002', 'dd-mm-yyyy'), 9, 3006, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091009003227, to_date('09-10-2009', 'dd-mm-yyyy'), to_date('23-10-2009', 'dd-mm-yyyy'), 10, 5611, to_date('25-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060322003228, to_date('22-03-2006', 'dd-mm-yyyy'), to_date('05-04-2006', 'dd-mm-yyyy'), 8, 3053, to_date('09-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070120003229, to_date('20-01-2007', 'dd-mm-yyyy'), to_date('03-02-2007', 'dd-mm-yyyy'), 2, 5725, to_date('04-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040212003230, to_date('12-02-2004', 'dd-mm-yyyy'), to_date('26-02-2004', 'dd-mm-yyyy'), 5, 3759, to_date('01-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120503003231, to_date('03-05-2012', 'dd-mm-yyyy'), to_date('17-05-2012', 'dd-mm-yyyy'), 1, 6417, to_date('13-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061210003232, to_date('10-12-2006', 'dd-mm-yyyy'), to_date('24-12-2006', 'dd-mm-yyyy'), 10, 4542, to_date('17-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090624003233, to_date('24-06-2009', 'dd-mm-yyyy'), to_date('08-07-2009', 'dd-mm-yyyy'), 5, 4604, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050623003234, to_date('23-06-2005', 'dd-mm-yyyy'), to_date('07-07-2005', 'dd-mm-yyyy'), 9, 5791, to_date('01-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100828003235, to_date('28-08-2010', 'dd-mm-yyyy'), to_date('11-09-2010', 'dd-mm-yyyy'), 7, 7256, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110619003236, to_date('19-06-2011', 'dd-mm-yyyy'), to_date('03-07-2011', 'dd-mm-yyyy'), 4, 7559, to_date('04-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050531003237, to_date('31-05-2005', 'dd-mm-yyyy'), to_date('14-06-2005', 'dd-mm-yyyy'), 9, 3031, to_date('16-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119003238, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 6, 10104, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513003239, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 5, 4433, to_date('22-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919003240, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 2, 8874, to_date('22-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050121003241, to_date('21-01-2005', 'dd-mm-yyyy'), to_date('04-02-2005', 'dd-mm-yyyy'), 7, 6353, to_date('03-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030129003242, to_date('29-01-2003', 'dd-mm-yyyy'), to_date('12-02-2003', 'dd-mm-yyyy'), 6, 4233, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080610003243, to_date('10-06-2008', 'dd-mm-yyyy'), to_date('24-06-2008', 'dd-mm-yyyy'), 2, 7891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000314003244, to_date('14-03-2000', 'dd-mm-yyyy'), to_date('28-03-2000', 'dd-mm-yyyy'), 2, 2335, to_date('30-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120807003245, to_date('07-08-2012', 'dd-mm-yyyy'), to_date('21-08-2012', 'dd-mm-yyyy'), 8, 6348, to_date('12-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070813003246, to_date('13-08-2007', 'dd-mm-yyyy'), to_date('27-08-2007', 'dd-mm-yyyy'), 5, 4840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091012003247, to_date('12-10-2009', 'dd-mm-yyyy'), to_date('26-10-2009', 'dd-mm-yyyy'), 10, 4770, to_date('22-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010713003248, to_date('13-07-2001', 'dd-mm-yyyy'), to_date('27-07-2001', 'dd-mm-yyyy'), 10, 1192, to_date('17-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040405003249, to_date('05-04-2004', 'dd-mm-yyyy'), to_date('19-04-2004', 'dd-mm-yyyy'), 9, 2680, to_date('21-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423003250, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 10, 10342, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608003251, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 6, 7559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100121003252, to_date('21-01-2010', 'dd-mm-yyyy'), to_date('04-02-2010', 'dd-mm-yyyy'), 8, 6705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010307003253, to_date('07-03-2001', 'dd-mm-yyyy'), to_date('21-03-2001', 'dd-mm-yyyy'), 4, 2795, to_date('26-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227003254, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 11, 1402, to_date('07-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000404003255, to_date('04-04-2000', 'dd-mm-yyyy'), to_date('18-04-2000', 'dd-mm-yyyy'), 11, 1845, to_date('13-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020911003256, to_date('11-09-2002', 'dd-mm-yyyy'), to_date('25-09-2002', 'dd-mm-yyyy'), 8, 1840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090211003257, to_date('11-02-2009', 'dd-mm-yyyy'), to_date('25-02-2009', 'dd-mm-yyyy'), 7, 4818, to_date('02-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080829003258, to_date('29-08-2008', 'dd-mm-yyyy'), to_date('12-09-2008', 'dd-mm-yyyy'), 6, 4294, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090412003259, to_date('12-04-2009', 'dd-mm-yyyy'), to_date('26-04-2009', 'dd-mm-yyyy'), 4, 8038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010003260, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 5, 7075, to_date('20-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040921003261, to_date('21-09-2004', 'dd-mm-yyyy'), to_date('05-10-2004', 'dd-mm-yyyy'), 8, 3549, to_date('07-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000318003262, to_date('18-03-2000', 'dd-mm-yyyy'), to_date('01-04-2000', 'dd-mm-yyyy'), 6, 2681, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080520003263, to_date('20-05-2008', 'dd-mm-yyyy'), to_date('03-06-2008', 'dd-mm-yyyy'), 11, 8418, to_date('09-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100809003264, to_date('09-08-2010', 'dd-mm-yyyy'), to_date('23-08-2010', 'dd-mm-yyyy'), 9, 7752, to_date('17-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730003265, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 5, 5702, to_date('02-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020220003266, to_date('20-02-2002', 'dd-mm-yyyy'), to_date('06-03-2002', 'dd-mm-yyyy'), 5, 3216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311003267, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 1, 9010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522003268, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 6, 5121, to_date('25-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615003269, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 10, 9751, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081017003270, to_date('17-10-2008', 'dd-mm-yyyy'), to_date('31-10-2008', 'dd-mm-yyyy'), 6, 6080, to_date('04-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090319003271, to_date('19-03-2009', 'dd-mm-yyyy'), to_date('02-04-2009', 'dd-mm-yyyy'), 4, 6522, to_date('04-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010209003272, to_date('09-02-2001', 'dd-mm-yyyy'), to_date('23-02-2001', 'dd-mm-yyyy'), 4, 2044, to_date('14-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060814003273, to_date('14-08-2006', 'dd-mm-yyyy'), to_date('28-08-2006', 'dd-mm-yyyy'), 5, 6801, to_date('28-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080105003274, to_date('05-01-2008', 'dd-mm-yyyy'), to_date('19-01-2008', 'dd-mm-yyyy'), 5, 5390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020826003275, to_date('26-08-2002', 'dd-mm-yyyy'), to_date('09-09-2002', 'dd-mm-yyyy'), 11, 2945, to_date('14-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091024003276, to_date('24-10-2009', 'dd-mm-yyyy'), to_date('07-11-2009', 'dd-mm-yyyy'), 4, 7697, to_date('12-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110624003277, to_date('24-06-2011', 'dd-mm-yyyy'), to_date('08-07-2011', 'dd-mm-yyyy'), 7, 7587, to_date('28-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110502003278, to_date('02-05-2011', 'dd-mm-yyyy'), to_date('16-05-2011', 'dd-mm-yyyy'), 8, 8928, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408003279, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 4, 6586, to_date('20-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120204003280, to_date('04-02-2012', 'dd-mm-yyyy'), to_date('18-02-2012', 'dd-mm-yyyy'), 5, 11165, to_date('07-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120112003281, to_date('12-01-2012', 'dd-mm-yyyy'), to_date('26-01-2012', 'dd-mm-yyyy'), 8, 8107, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080805003282, to_date('05-08-2008', 'dd-mm-yyyy'), to_date('19-08-2008', 'dd-mm-yyyy'), 2, 6612, to_date('16-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050127003283, to_date('27-01-2005', 'dd-mm-yyyy'), to_date('10-02-2005', 'dd-mm-yyyy'), 4, 3835, to_date('31-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121123003284, to_date('23-11-2012', 'dd-mm-yyyy'), to_date('07-12-2012', 'dd-mm-yyyy'), 5, 5910, to_date('11-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041209003285, to_date('09-12-2004', 'dd-mm-yyyy'), to_date('23-12-2004', 'dd-mm-yyyy'), 9, 4747, to_date('18-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131204003286, to_date('04-12-2013', 'dd-mm-yyyy'), to_date('18-12-2013', 'dd-mm-yyyy'), 9, 13108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009003287, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 5, 5110, to_date('26-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090118003288, to_date('18-01-2009', 'dd-mm-yyyy'), to_date('01-02-2009', 'dd-mm-yyyy'), 6, 7313, to_date('01-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120126003289, to_date('26-01-2012', 'dd-mm-yyyy'), to_date('09-02-2012', 'dd-mm-yyyy'), 12, 9619, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070412003290, to_date('12-04-2007', 'dd-mm-yyyy'), to_date('26-04-2007', 'dd-mm-yyyy'), 5, 5646, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030915003291, to_date('15-09-2003', 'dd-mm-yyyy'), to_date('29-09-2003', 'dd-mm-yyyy'), 3, 3583, to_date('24-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110304003292, to_date('04-03-2011', 'dd-mm-yyyy'), to_date('18-03-2011', 'dd-mm-yyyy'), 3, 9464, to_date('17-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090923003293, to_date('23-09-2009', 'dd-mm-yyyy'), to_date('07-10-2009', 'dd-mm-yyyy'), 11, 7595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101214003294, to_date('14-12-2010', 'dd-mm-yyyy'), to_date('28-12-2010', 'dd-mm-yyyy'), 3, 6815, to_date('18-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060611003295, to_date('11-06-2006', 'dd-mm-yyyy'), to_date('25-06-2006', 'dd-mm-yyyy'), 4, 4945, to_date('28-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614003296, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 6, 7363, to_date('17-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110218003297, to_date('18-02-2011', 'dd-mm-yyyy'), to_date('04-03-2011', 'dd-mm-yyyy'), 3, 8538, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916003298, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 2, 8547, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120909003299, to_date('09-09-2012', 'dd-mm-yyyy'), to_date('23-09-2012', 'dd-mm-yyyy'), 11, 7243, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010630003300, to_date('30-06-2001', 'dd-mm-yyyy'), to_date('14-07-2001', 'dd-mm-yyyy'), 8, 561, to_date('13-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070417003301, to_date('17-04-2007', 'dd-mm-yyyy'), to_date('01-05-2007', 'dd-mm-yyyy'), 6, 8512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225003302, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 5, 4972, to_date('09-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714003303, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 1, 7232, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000131003304, to_date('31-01-2000', 'dd-mm-yyyy'), to_date('14-02-2000', 'dd-mm-yyyy'), 4, 1252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000205003305, to_date('05-02-2000', 'dd-mm-yyyy'), to_date('19-02-2000', 'dd-mm-yyyy'), 6, 2020, to_date('08-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070511003306, to_date('11-05-2007', 'dd-mm-yyyy'), to_date('25-05-2007', 'dd-mm-yyyy'), 9, 5961, to_date('13-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040831003307, to_date('31-08-2004', 'dd-mm-yyyy'), to_date('14-09-2004', 'dd-mm-yyyy'), 3, 4284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100812003308, to_date('12-08-2010', 'dd-mm-yyyy'), to_date('26-08-2010', 'dd-mm-yyyy'), 3, 6350, to_date('15-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000925003309, to_date('25-09-2000', 'dd-mm-yyyy'), to_date('09-10-2000', 'dd-mm-yyyy'), 12, 1332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040425003310, to_date('25-04-2004', 'dd-mm-yyyy'), to_date('09-05-2004', 'dd-mm-yyyy'), 11, 3076, to_date('01-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040824003311, to_date('24-08-2004', 'dd-mm-yyyy'), to_date('07-09-2004', 'dd-mm-yyyy'), 12, 3915, to_date('05-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090310003312, to_date('10-03-2009', 'dd-mm-yyyy'), to_date('24-03-2009', 'dd-mm-yyyy'), 2, 7142, to_date('21-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000127003313, to_date('27-01-2000', 'dd-mm-yyyy'), to_date('10-02-2000', 'dd-mm-yyyy'), 7, 1226, to_date('13-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402003314, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 1, 1942, to_date('15-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723003315, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 3, 2569, to_date('01-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131003316, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 11, 4611, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130003317, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 2, 5453, to_date('09-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080128003318, to_date('28-01-2008', 'dd-mm-yyyy'), to_date('11-02-2008', 'dd-mm-yyyy'), 5, 7083, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100207003319, to_date('07-02-2010', 'dd-mm-yyyy'), to_date('21-02-2010', 'dd-mm-yyyy'), 1, 8817, to_date('19-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060622003320, to_date('22-06-2006', 'dd-mm-yyyy'), to_date('06-07-2006', 'dd-mm-yyyy'), 12, 6520, to_date('06-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130124003321, to_date('24-01-2013', 'dd-mm-yyyy'), to_date('07-02-2013', 'dd-mm-yyyy'), 4, 8924, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090727003322, to_date('27-07-2009', 'dd-mm-yyyy'), to_date('10-08-2009', 'dd-mm-yyyy'), 2, 6836, to_date('11-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140101003323, to_date('01-01-2014', 'dd-mm-yyyy'), to_date('15-01-2014', 'dd-mm-yyyy'), 10, 8095, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004003324, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 12, 3182, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050109003325, to_date('09-01-2005', 'dd-mm-yyyy'), to_date('23-01-2005', 'dd-mm-yyyy'), 7, 4034, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120910003326, to_date('10-09-2012', 'dd-mm-yyyy'), to_date('24-09-2012', 'dd-mm-yyyy'), 11, 9205, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010328003327, to_date('28-03-2001', 'dd-mm-yyyy'), to_date('11-04-2001', 'dd-mm-yyyy'), 4, 1619, to_date('01-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110820003328, to_date('20-08-2011', 'dd-mm-yyyy'), to_date('03-09-2011', 'dd-mm-yyyy'), 2, 7382, to_date('07-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020905003329, to_date('05-09-2002', 'dd-mm-yyyy'), to_date('19-09-2002', 'dd-mm-yyyy'), 9, 2533, to_date('24-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061001003330, to_date('01-10-2006', 'dd-mm-yyyy'), to_date('15-10-2006', 'dd-mm-yyyy'), 7, 4829, to_date('13-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041201003331, to_date('01-12-2004', 'dd-mm-yyyy'), to_date('15-12-2004', 'dd-mm-yyyy'), 11, 2777, to_date('06-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603003332, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 2, 6299, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071207003333, to_date('07-12-2007', 'dd-mm-yyyy'), to_date('21-12-2007', 'dd-mm-yyyy'), 7, 3921, to_date('25-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040526003334, to_date('26-05-2004', 'dd-mm-yyyy'), to_date('09-06-2004', 'dd-mm-yyyy'), 1, 5620, to_date('27-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926003335, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 7, 9414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210003336, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 5, 10044, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130217003337, to_date('17-02-2013', 'dd-mm-yyyy'), to_date('03-03-2013', 'dd-mm-yyyy'), 9, 7451, to_date('26-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050524003338, to_date('24-05-2005', 'dd-mm-yyyy'), to_date('07-06-2005', 'dd-mm-yyyy'), 9, 6644, to_date('26-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040807003339, to_date('07-08-2004', 'dd-mm-yyyy'), to_date('21-08-2004', 'dd-mm-yyyy'), 12, 4651, to_date('24-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100827003340, to_date('27-08-2010', 'dd-mm-yyyy'), to_date('10-09-2010', 'dd-mm-yyyy'), 10, 6843, to_date('04-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060620003341, to_date('20-06-2006', 'dd-mm-yyyy'), to_date('04-07-2006', 'dd-mm-yyyy'), 2, 4795, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071218003342, to_date('18-12-2007', 'dd-mm-yyyy'), to_date('01-01-2008', 'dd-mm-yyyy'), 10, 6496, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090827003343, to_date('27-08-2009', 'dd-mm-yyyy'), to_date('10-09-2009', 'dd-mm-yyyy'), 9, 5461, to_date('29-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060301003344, to_date('01-03-2006', 'dd-mm-yyyy'), to_date('15-03-2006', 'dd-mm-yyyy'), 8, 5394, to_date('09-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060702003345, to_date('02-07-2006', 'dd-mm-yyyy'), to_date('16-07-2006', 'dd-mm-yyyy'), 5, 4009, to_date('12-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120107003346, to_date('07-01-2012', 'dd-mm-yyyy'), to_date('21-01-2012', 'dd-mm-yyyy'), 4, 8892, to_date('16-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041003003347, to_date('03-10-2004', 'dd-mm-yyyy'), to_date('17-10-2004', 'dd-mm-yyyy'), 8, 3395, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080129003348, to_date('29-01-2008', 'dd-mm-yyyy'), to_date('12-02-2008', 'dd-mm-yyyy'), 11, 5781, to_date('16-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060625003349, to_date('25-06-2006', 'dd-mm-yyyy'), to_date('09-07-2006', 'dd-mm-yyyy'), 2, 7069, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031020003350, to_date('20-10-2003', 'dd-mm-yyyy'), to_date('03-11-2003', 'dd-mm-yyyy'), 1, 4460, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070814003351, to_date('14-08-2007', 'dd-mm-yyyy'), to_date('28-08-2007', 'dd-mm-yyyy'), 9, 5813, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030901003352, to_date('01-09-2003', 'dd-mm-yyyy'), to_date('15-09-2003', 'dd-mm-yyyy'), 3, 2511, to_date('03-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030818003353, to_date('18-08-2003', 'dd-mm-yyyy'), to_date('01-09-2003', 'dd-mm-yyyy'), 7, 3182, to_date('01-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051024003354, to_date('24-10-2005', 'dd-mm-yyyy'), to_date('07-11-2005', 'dd-mm-yyyy'), 6, 6140, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080202003355, to_date('02-02-2008', 'dd-mm-yyyy'), to_date('16-02-2008', 'dd-mm-yyyy'), 4, 7292, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080402003356, to_date('02-04-2008', 'dd-mm-yyyy'), to_date('16-04-2008', 'dd-mm-yyyy'), 10, 4985, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101125003357, to_date('25-11-2010', 'dd-mm-yyyy'), to_date('09-12-2010', 'dd-mm-yyyy'), 5, 6012, to_date('11-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091030003358, to_date('30-10-2009', 'dd-mm-yyyy'), to_date('13-11-2009', 'dd-mm-yyyy'), 4, 6339, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120330003359, to_date('30-03-2012', 'dd-mm-yyyy'), to_date('13-04-2012', 'dd-mm-yyyy'), 8, 8388, to_date('10-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050608003360, to_date('08-06-2005', 'dd-mm-yyyy'), to_date('22-06-2005', 'dd-mm-yyyy'), 11, 3475, to_date('25-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323003361, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 5, 6011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060207003362, to_date('07-02-2006', 'dd-mm-yyyy'), to_date('21-02-2006', 'dd-mm-yyyy'), 12, 6036, to_date('27-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030828003363, to_date('28-08-2003', 'dd-mm-yyyy'), to_date('11-09-2003', 'dd-mm-yyyy'), 9, 3613, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603003364, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 4, 7399, to_date('11-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040224003365, to_date('24-02-2004', 'dd-mm-yyyy'), to_date('09-03-2004', 'dd-mm-yyyy'), 9, 3789, to_date('26-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040422003366, to_date('22-04-2004', 'dd-mm-yyyy'), to_date('06-05-2004', 'dd-mm-yyyy'), 5, 3934, to_date('26-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027003367, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 9, 6736, to_date('02-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901003368, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 3, 4451, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111003369, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 9, 8618, to_date('22-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090317005508, to_date('17-03-2009', 'dd-mm-yyyy'), to_date('31-03-2009', 'dd-mm-yyyy'), 9, 3537, to_date('05-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010823005509, to_date('23-08-2001', 'dd-mm-yyyy'), to_date('06-09-2001', 'dd-mm-yyyy'), 8, 760, to_date('10-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020324005510, to_date('24-03-2002', 'dd-mm-yyyy'), to_date('07-04-2002', 'dd-mm-yyyy'), 6, 3498, to_date('10-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080902005511, to_date('02-09-2008', 'dd-mm-yyyy'), to_date('16-09-2008', 'dd-mm-yyyy'), 2, 6833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001122005512, to_date('22-11-2000', 'dd-mm-yyyy'), to_date('06-12-2000', 'dd-mm-yyyy'), 12, 1135, to_date('29-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111005513, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 11, 4686, to_date('21-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020327005514, to_date('27-03-2002', 'dd-mm-yyyy'), to_date('10-04-2002', 'dd-mm-yyyy'), 11, 4077, to_date('03-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131021005515, to_date('21-10-2013', 'dd-mm-yyyy'), to_date('04-11-2013', 'dd-mm-yyyy'), 5, 10472, to_date('06-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030601005516, to_date('01-06-2003', 'dd-mm-yyyy'), to_date('15-06-2003', 'dd-mm-yyyy'), 4, 4005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050909005517, to_date('09-09-2005', 'dd-mm-yyyy'), to_date('23-09-2005', 'dd-mm-yyyy'), 11, 5710, to_date('24-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226005518, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 7, 2576, to_date('27-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070628005519, to_date('28-06-2007', 'dd-mm-yyyy'), to_date('12-07-2007', 'dd-mm-yyyy'), 11, 4877, to_date('01-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809005520, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 9, 2482, to_date('12-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110803005521, to_date('03-08-2011', 'dd-mm-yyyy'), to_date('17-08-2011', 'dd-mm-yyyy'), 1, 6328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061229005522, to_date('29-12-2006', 'dd-mm-yyyy'), to_date('12-01-2007', 'dd-mm-yyyy'), 6, 6303, to_date('30-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001118005523, to_date('18-11-2000', 'dd-mm-yyyy'), to_date('02-12-2000', 'dd-mm-yyyy'), 11, 2343, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080127005524, to_date('27-01-2008', 'dd-mm-yyyy'), to_date('10-02-2008', 'dd-mm-yyyy'), 7, 4274, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050208005525, to_date('08-02-2005', 'dd-mm-yyyy'), to_date('22-02-2005', 'dd-mm-yyyy'), 5, 4268, to_date('24-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120516005526, to_date('16-05-2012', 'dd-mm-yyyy'), to_date('30-05-2012', 'dd-mm-yyyy'), 6, 8694, to_date('28-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020302005527, to_date('02-03-2002', 'dd-mm-yyyy'), to_date('16-03-2002', 'dd-mm-yyyy'), 10, 2411, to_date('08-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060928005528, to_date('28-09-2006', 'dd-mm-yyyy'), to_date('12-10-2006', 'dd-mm-yyyy'), 6, 5162, to_date('02-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070612005529, to_date('12-06-2007', 'dd-mm-yyyy'), to_date('26-06-2007', 'dd-mm-yyyy'), 4, 6248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110614005530, to_date('14-06-2011', 'dd-mm-yyyy'), to_date('28-06-2011', 'dd-mm-yyyy'), 11, 7094, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010623005531, to_date('23-06-2001', 'dd-mm-yyyy'), to_date('07-07-2001', 'dd-mm-yyyy'), 2, 2075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826005532, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 11, 5447, to_date('13-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110416005533, to_date('16-04-2011', 'dd-mm-yyyy'), to_date('30-04-2011', 'dd-mm-yyyy'), 1, 4907, to_date('04-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040911005534, to_date('11-09-2004', 'dd-mm-yyyy'), to_date('25-09-2004', 'dd-mm-yyyy'), 7, 3981, to_date('20-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020911005535, to_date('11-09-2002', 'dd-mm-yyyy'), to_date('25-09-2002', 'dd-mm-yyyy'), 2, 1697, to_date('30-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001204005536, to_date('04-12-2000', 'dd-mm-yyyy'), to_date('18-12-2000', 'dd-mm-yyyy'), 9, 1937, to_date('20-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000308005537, to_date('08-03-2000', 'dd-mm-yyyy'), to_date('22-03-2000', 'dd-mm-yyyy'), 5, 2728, to_date('19-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100922005538, to_date('22-09-2010', 'dd-mm-yyyy'), to_date('06-10-2010', 'dd-mm-yyyy'), 3, 6879, to_date('04-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617005539, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 2, 5142, to_date('06-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608005540, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 11, 2890, to_date('27-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081016005541, to_date('16-10-2008', 'dd-mm-yyyy'), to_date('30-10-2008', 'dd-mm-yyyy'), 11, 8619, to_date('01-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905005542, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 6, 1033, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100615005543, to_date('15-06-2010', 'dd-mm-yyyy'), to_date('29-06-2010', 'dd-mm-yyyy'), 3, 7889, to_date('30-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031005544, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 2, 1464, to_date('06-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000905005545, to_date('05-09-2000', 'dd-mm-yyyy'), to_date('19-09-2000', 'dd-mm-yyyy'), 3, 1763, to_date('16-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090728005546, to_date('28-07-2009', 'dd-mm-yyyy'), to_date('11-08-2009', 'dd-mm-yyyy'), 7, 7491, to_date('13-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130913005547, to_date('13-09-2013', 'dd-mm-yyyy'), to_date('27-09-2013', 'dd-mm-yyyy'), 5, 5368, to_date('24-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051009005548, to_date('09-10-2005', 'dd-mm-yyyy'), to_date('23-10-2005', 'dd-mm-yyyy'), 4, 2686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050602005549, to_date('02-06-2005', 'dd-mm-yyyy'), to_date('16-06-2005', 'dd-mm-yyyy'), 12, 4799, to_date('10-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090915005550, to_date('15-09-2009', 'dd-mm-yyyy'), to_date('29-09-2009', 'dd-mm-yyyy'), 12, 8128, to_date('25-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120106005551, to_date('06-01-2012', 'dd-mm-yyyy'), to_date('20-01-2012', 'dd-mm-yyyy'), 3, 8077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000905005552, to_date('05-09-2000', 'dd-mm-yyyy'), to_date('19-09-2000', 'dd-mm-yyyy'), 8, 2288, to_date('07-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021209005553, to_date('09-12-2002', 'dd-mm-yyyy'), to_date('23-12-2002', 'dd-mm-yyyy'), 11, 3973, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071008005554, to_date('08-10-2007', 'dd-mm-yyyy'), to_date('22-10-2007', 'dd-mm-yyyy'), 6, 6277, to_date('09-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602005555, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 8, 5550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040531005556, to_date('31-05-2004', 'dd-mm-yyyy'), to_date('14-06-2004', 'dd-mm-yyyy'), 11, 4960, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120809005557, to_date('09-08-2012', 'dd-mm-yyyy'), to_date('23-08-2012', 'dd-mm-yyyy'), 11, 9697, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070416005558, to_date('16-04-2007', 'dd-mm-yyyy'), to_date('30-04-2007', 'dd-mm-yyyy'), 4, 5794, to_date('04-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020622005559, to_date('22-06-2002', 'dd-mm-yyyy'), to_date('06-07-2002', 'dd-mm-yyyy'), 5, 4080, to_date('05-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030711005560, to_date('11-07-2003', 'dd-mm-yyyy'), to_date('25-07-2003', 'dd-mm-yyyy'), 11, 2242, to_date('13-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016005561, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 4, 2647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100415005562, to_date('15-04-2010', 'dd-mm-yyyy'), to_date('29-04-2010', 'dd-mm-yyyy'), 4, 7341, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140416005563, to_date('16-04-2014', 'dd-mm-yyyy'), to_date('30-04-2014', 'dd-mm-yyyy'), 7, 10788, to_date('05-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030529005564, to_date('29-05-2003', 'dd-mm-yyyy'), to_date('12-06-2003', 'dd-mm-yyyy'), 2, 3167, to_date('16-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100313005565, to_date('13-03-2010', 'dd-mm-yyyy'), to_date('27-03-2010', 'dd-mm-yyyy'), 10, 5145, to_date('31-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081118005566, to_date('18-11-2008', 'dd-mm-yyyy'), to_date('02-12-2008', 'dd-mm-yyyy'), 5, 5556, to_date('27-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030208005567, to_date('08-02-2003', 'dd-mm-yyyy'), to_date('22-02-2003', 'dd-mm-yyyy'), 5, 3171, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051114005568, to_date('14-11-2005', 'dd-mm-yyyy'), to_date('28-11-2005', 'dd-mm-yyyy'), 6, 2595, to_date('02-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924005569, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 3, 8856, to_date('03-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090908005570, to_date('08-09-2009', 'dd-mm-yyyy'), to_date('22-09-2009', 'dd-mm-yyyy'), 4, 4988, to_date('25-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821005571, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 6, 3493, to_date('26-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100828005572, to_date('28-08-2010', 'dd-mm-yyyy'), to_date('11-09-2010', 'dd-mm-yyyy'), 4, 8694, to_date('08-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080320005573, to_date('20-03-2008', 'dd-mm-yyyy'), to_date('03-04-2008', 'dd-mm-yyyy'), 6, 7387, to_date('06-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060103005574, to_date('03-01-2006', 'dd-mm-yyyy'), to_date('17-01-2006', 'dd-mm-yyyy'), 2, 5628, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000605005575, to_date('05-06-2000', 'dd-mm-yyyy'), to_date('19-06-2000', 'dd-mm-yyyy'), 2, 2007, to_date('09-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020107005576, to_date('07-01-2002', 'dd-mm-yyyy'), to_date('21-01-2002', 'dd-mm-yyyy'), 7, 2477, to_date('14-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070108005577, to_date('08-01-2007', 'dd-mm-yyyy'), to_date('22-01-2007', 'dd-mm-yyyy'), 5, 4743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426005578, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 4, 6210, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041105005579, to_date('05-11-2004', 'dd-mm-yyyy'), to_date('19-11-2004', 'dd-mm-yyyy'), 9, 2416, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040114005580, to_date('14-01-2004', 'dd-mm-yyyy'), to_date('28-01-2004', 'dd-mm-yyyy'), 1, 5151, to_date('21-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011003005581, to_date('03-10-2001', 'dd-mm-yyyy'), to_date('17-10-2001', 'dd-mm-yyyy'), 7, 3371, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726005582, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 10, 10236, to_date('14-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726005583, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 5, 3030, to_date('28-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090320005584, to_date('20-03-2009', 'dd-mm-yyyy'), to_date('03-04-2009', 'dd-mm-yyyy'), 3, 5996, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901005585, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 10, 2164, to_date('08-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121222005586, to_date('22-12-2012', 'dd-mm-yyyy'), to_date('05-01-2013', 'dd-mm-yyyy'), 8, 9337, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010405005587, to_date('05-04-2001', 'dd-mm-yyyy'), to_date('19-04-2001', 'dd-mm-yyyy'), 7, 3417, to_date('25-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910005588, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 11, 3567, to_date('26-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326005589, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 12, 4406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131206005590, to_date('06-12-2013', 'dd-mm-yyyy'), to_date('20-12-2013', 'dd-mm-yyyy'), 5, 10072, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612005591, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 9, 1515, to_date('01-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030420005592, to_date('20-04-2003', 'dd-mm-yyyy'), to_date('04-05-2003', 'dd-mm-yyyy'), 8, 4141, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060824005593, to_date('24-08-2006', 'dd-mm-yyyy'), to_date('07-09-2006', 'dd-mm-yyyy'), 5, 4675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071210005594, to_date('10-12-2007', 'dd-mm-yyyy'), to_date('24-12-2007', 'dd-mm-yyyy'), 4, 4011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031023005595, to_date('23-10-2003', 'dd-mm-yyyy'), to_date('06-11-2003', 'dd-mm-yyyy'), 2, 4449, to_date('31-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109005596, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 2, 6017, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020128005597, to_date('28-01-2002', 'dd-mm-yyyy'), to_date('11-02-2002', 'dd-mm-yyyy'), 8, 1472, to_date('04-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121227005598, to_date('27-12-2012', 'dd-mm-yyyy'), to_date('10-01-2013', 'dd-mm-yyyy'), 8, 7368, to_date('15-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090213005599, to_date('13-02-2009', 'dd-mm-yyyy'), to_date('27-02-2009', 'dd-mm-yyyy'), 5, 6579, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071126005600, to_date('26-11-2007', 'dd-mm-yyyy'), to_date('10-12-2007', 'dd-mm-yyyy'), 10, 7648, to_date('29-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070210005601, to_date('10-02-2007', 'dd-mm-yyyy'), to_date('24-02-2007', 'dd-mm-yyyy'), 10, 6969, to_date('19-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106005602, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 8, 7584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020727005603, to_date('27-07-2002', 'dd-mm-yyyy'), to_date('10-08-2002', 'dd-mm-yyyy'), 11, 914, to_date('01-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010316005604, to_date('16-03-2001', 'dd-mm-yyyy'), to_date('30-03-2001', 'dd-mm-yyyy'), 3, 3055, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106005605, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 10, 9135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104005606, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 3, 7321, to_date('18-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030721005607, to_date('21-07-2003', 'dd-mm-yyyy'), to_date('04-08-2003', 'dd-mm-yyyy'), 11, 4148, to_date('05-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822005608, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 1, 8889, to_date('04-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070908005609, to_date('08-09-2007', 'dd-mm-yyyy'), to_date('22-09-2007', 'dd-mm-yyyy'), 3, 7748, to_date('11-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120419005610, to_date('19-04-2012', 'dd-mm-yyyy'), to_date('03-05-2012', 'dd-mm-yyyy'), 4, 7665, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001125005611, to_date('25-11-2000', 'dd-mm-yyyy'), to_date('09-12-2000', 'dd-mm-yyyy'), 10, 3816, to_date('09-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010606005612, to_date('06-06-2001', 'dd-mm-yyyy'), to_date('20-06-2001', 'dd-mm-yyyy'), 3, 1650, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140122005613, to_date('22-01-2014', 'dd-mm-yyyy'), to_date('05-02-2014', 'dd-mm-yyyy'), 6, 9040, to_date('02-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523005614, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 10, 4131, to_date('05-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061124005615, to_date('24-11-2006', 'dd-mm-yyyy'), to_date('08-12-2006', 'dd-mm-yyyy'), 12, 4827, to_date('29-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011101005616, to_date('01-11-2001', 'dd-mm-yyyy'), to_date('15-11-2001', 'dd-mm-yyyy'), 6, 2389, to_date('06-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070203005617, to_date('03-02-2007', 'dd-mm-yyyy'), to_date('17-02-2007', 'dd-mm-yyyy'), 8, 6231, to_date('07-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090503005618, to_date('03-05-2009', 'dd-mm-yyyy'), to_date('17-05-2009', 'dd-mm-yyyy'), 9, 7359, to_date('20-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702005619, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 11, 3767, to_date('08-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030107005620, to_date('07-01-2003', 'dd-mm-yyyy'), to_date('21-01-2003', 'dd-mm-yyyy'), 2, 2674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110505005621, to_date('05-05-2011', 'dd-mm-yyyy'), to_date('19-05-2011', 'dd-mm-yyyy'), 8, 7869, to_date('23-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000223005622, to_date('23-02-2000', 'dd-mm-yyyy'), to_date('08-03-2000', 'dd-mm-yyyy'), 12, 1214, to_date('08-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101214005623, to_date('14-12-2010', 'dd-mm-yyyy'), to_date('28-12-2010', 'dd-mm-yyyy'), 6, 7401, to_date('27-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061107005624, to_date('07-11-2006', 'dd-mm-yyyy'), to_date('21-11-2006', 'dd-mm-yyyy'), 9, 6772, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030502005625, to_date('02-05-2003', 'dd-mm-yyyy'), to_date('16-05-2003', 'dd-mm-yyyy'), 11, 3381, to_date('10-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120127005626, to_date('27-01-2012', 'dd-mm-yyyy'), to_date('10-02-2012', 'dd-mm-yyyy'), 6, 8111, to_date('08-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020422005627, to_date('22-04-2002', 'dd-mm-yyyy'), to_date('06-05-2002', 'dd-mm-yyyy'), 3, 2101, to_date('11-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060720005628, to_date('20-07-2006', 'dd-mm-yyyy'), to_date('03-08-2006', 'dd-mm-yyyy'), 6, 6188, to_date('01-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405005629, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 11, 4490, to_date('06-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091215005630, to_date('15-12-2009', 'dd-mm-yyyy'), to_date('29-12-2009', 'dd-mm-yyyy'), 5, 5625, to_date('17-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091228005631, to_date('28-12-2009', 'dd-mm-yyyy'), to_date('11-01-2010', 'dd-mm-yyyy'), 8, 7119, to_date('11-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013005632, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 5, 7787, to_date('16-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070827005633, to_date('27-08-2007', 'dd-mm-yyyy'), to_date('10-09-2007', 'dd-mm-yyyy'), 2, 6770, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040921005634, to_date('21-09-2004', 'dd-mm-yyyy'), to_date('05-10-2004', 'dd-mm-yyyy'), 6, 3724, to_date('27-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050804005635, to_date('04-08-2005', 'dd-mm-yyyy'), to_date('18-08-2005', 'dd-mm-yyyy'), 5, 4820, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427005636, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 9, 1988, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120107005637, to_date('07-01-2012', 'dd-mm-yyyy'), to_date('21-01-2012', 'dd-mm-yyyy'), 6, 9967, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091208005638, to_date('08-12-2009', 'dd-mm-yyyy'), to_date('22-12-2009', 'dd-mm-yyyy'), 3, 5322, to_date('20-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090301005639, to_date('01-03-2009', 'dd-mm-yyyy'), to_date('15-03-2009', 'dd-mm-yyyy'), 3, 7447, to_date('08-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070905005640, to_date('05-09-2007', 'dd-mm-yyyy'), to_date('19-09-2007', 'dd-mm-yyyy'), 3, 6393, to_date('13-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030907005641, to_date('07-09-2003', 'dd-mm-yyyy'), to_date('21-09-2003', 'dd-mm-yyyy'), 8, 3141, to_date('21-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921005642, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 4, 2680, to_date('28-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080410005643, to_date('10-04-2008', 'dd-mm-yyyy'), to_date('24-04-2008', 'dd-mm-yyyy'), 9, 7495, to_date('17-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601005644, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 7, 4315, to_date('20-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100614005645, to_date('14-06-2010', 'dd-mm-yyyy'), to_date('28-06-2010', 'dd-mm-yyyy'), 8, 6749, to_date('16-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080321005646, to_date('21-03-2008', 'dd-mm-yyyy'), to_date('04-04-2008', 'dd-mm-yyyy'), 5, 5739, to_date('25-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109005647, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 9, 6376, to_date('13-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111005648, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 8, 4506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130609005649, to_date('09-06-2013', 'dd-mm-yyyy'), to_date('23-06-2013', 'dd-mm-yyyy'), 5, 8794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130626005650, to_date('26-06-2013', 'dd-mm-yyyy'), to_date('10-07-2013', 'dd-mm-yyyy'), 11, 7582, to_date('16-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020726005651, to_date('26-07-2002', 'dd-mm-yyyy'), to_date('09-08-2002', 'dd-mm-yyyy'), 10, 3650, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000806005652, to_date('06-08-2000', 'dd-mm-yyyy'), to_date('20-08-2000', 'dd-mm-yyyy'), 5, 1967, to_date('09-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060305005653, to_date('05-03-2006', 'dd-mm-yyyy'), to_date('19-03-2006', 'dd-mm-yyyy'), 2, 4776, to_date('13-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080729005654, to_date('29-07-2008', 'dd-mm-yyyy'), to_date('12-08-2008', 'dd-mm-yyyy'), 1, 5485, to_date('02-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051123005655, to_date('23-11-2005', 'dd-mm-yyyy'), to_date('07-12-2005', 'dd-mm-yyyy'), 3, 4954, to_date('03-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061030005656, to_date('30-10-2006', 'dd-mm-yyyy'), to_date('13-11-2006', 'dd-mm-yyyy'), 10, 5360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071001005657, to_date('01-10-2007', 'dd-mm-yyyy'), to_date('15-10-2007', 'dd-mm-yyyy'), 3, 6306, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010524005658, to_date('24-05-2001', 'dd-mm-yyyy'), to_date('07-06-2001', 'dd-mm-yyyy'), 3, 2542, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061108005659, to_date('08-11-2006', 'dd-mm-yyyy'), to_date('22-11-2006', 'dd-mm-yyyy'), 3, 3485, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110405005660, to_date('05-04-2011', 'dd-mm-yyyy'), to_date('19-04-2011', 'dd-mm-yyyy'), 7, 7192, to_date('11-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319007804, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 5, 5187, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121204007805, to_date('04-12-2012', 'dd-mm-yyyy'), to_date('18-12-2012', 'dd-mm-yyyy'), 9, 9438, to_date('10-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118007806, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 7, 9717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120606007807, to_date('06-06-2012', 'dd-mm-yyyy'), to_date('20-06-2012', 'dd-mm-yyyy'), 6, 6498, to_date('10-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010319007808, to_date('19-03-2001', 'dd-mm-yyyy'), to_date('02-04-2001', 'dd-mm-yyyy'), 11, 769, to_date('24-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060914007809, to_date('14-09-2006', 'dd-mm-yyyy'), to_date('28-09-2006', 'dd-mm-yyyy'), 5, 4521, to_date('26-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906007810, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 5, 5540, to_date('11-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928007811, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 3, 5151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100726007812, to_date('26-07-2010', 'dd-mm-yyyy'), to_date('09-08-2010', 'dd-mm-yyyy'), 2, 6208, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120721007813, to_date('21-07-2012', 'dd-mm-yyyy'), to_date('04-08-2012', 'dd-mm-yyyy'), 9, 7085, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090825007814, to_date('25-08-2009', 'dd-mm-yyyy'), to_date('08-09-2009', 'dd-mm-yyyy'), 8, 8140, to_date('26-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020007815, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 7, 5497, to_date('30-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803007816, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 1, 10846, to_date('12-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813007817, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 2, 8879, to_date('24-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020527007818, to_date('27-05-2002', 'dd-mm-yyyy'), to_date('10-06-2002', 'dd-mm-yyyy'), 6, 2954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031230007819, to_date('30-12-2003', 'dd-mm-yyyy'), to_date('13-01-2004', 'dd-mm-yyyy'), 7, 3932, to_date('15-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010807007820, to_date('07-08-2001', 'dd-mm-yyyy'), to_date('21-08-2001', 'dd-mm-yyyy'), 4, 5292, to_date('15-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060908007821, to_date('08-09-2006', 'dd-mm-yyyy'), to_date('22-09-2006', 'dd-mm-yyyy'), 4, 4996, to_date('24-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130602007822, to_date('02-06-2013', 'dd-mm-yyyy'), to_date('16-06-2013', 'dd-mm-yyyy'), 9, 4620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091222007823, to_date('22-12-2009', 'dd-mm-yyyy'), to_date('05-01-2010', 'dd-mm-yyyy'), 9, 6442, to_date('03-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414007824, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 7, 10672, to_date('02-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110915007825, to_date('15-09-2011', 'dd-mm-yyyy'), to_date('29-09-2011', 'dd-mm-yyyy'), 9, 8188, to_date('25-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101013007826, to_date('13-10-2010', 'dd-mm-yyyy'), to_date('27-10-2010', 'dd-mm-yyyy'), 8, 9652, to_date('18-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111206007827, to_date('06-12-2011', 'dd-mm-yyyy'), to_date('20-12-2011', 'dd-mm-yyyy'), 5, 7771, to_date('11-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726007828, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 8, 8016, to_date('01-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215007829, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 9, 2983, to_date('25-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030308007830, to_date('08-03-2003', 'dd-mm-yyyy'), to_date('22-03-2003', 'dd-mm-yyyy'), 5, 4229, to_date('21-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110813007831, to_date('13-08-2011', 'dd-mm-yyyy'), to_date('27-08-2011', 'dd-mm-yyyy'), 2, 7628, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050730007832, to_date('30-07-2005', 'dd-mm-yyyy'), to_date('13-08-2005', 'dd-mm-yyyy'), 11, 7004, to_date('13-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227007833, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 10, 5188, to_date('03-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070924007834, to_date('24-09-2007', 'dd-mm-yyyy'), to_date('08-10-2007', 'dd-mm-yyyy'), 11, 5649, to_date('27-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110709007835, to_date('09-07-2011', 'dd-mm-yyyy'), to_date('23-07-2011', 'dd-mm-yyyy'), 3, 6760, to_date('13-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051205007836, to_date('05-12-2005', 'dd-mm-yyyy'), to_date('19-12-2005', 'dd-mm-yyyy'), 1, 5948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090616007837, to_date('16-06-2009', 'dd-mm-yyyy'), to_date('30-06-2009', 'dd-mm-yyyy'), 5, 7500, to_date('26-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011224007838, to_date('24-12-2001', 'dd-mm-yyyy'), to_date('07-01-2002', 'dd-mm-yyyy'), 5, 1548, to_date('28-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100225007839, to_date('25-02-2010', 'dd-mm-yyyy'), to_date('11-03-2010', 'dd-mm-yyyy'), 5, 5823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090707007840, to_date('07-07-2009', 'dd-mm-yyyy'), to_date('21-07-2009', 'dd-mm-yyyy'), 9, 5402, to_date('26-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121117007841, to_date('17-11-2012', 'dd-mm-yyyy'), to_date('01-12-2012', 'dd-mm-yyyy'), 12, 7257, to_date('07-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131028007842, to_date('28-10-2013', 'dd-mm-yyyy'), to_date('11-11-2013', 'dd-mm-yyyy'), 10, 7479, to_date('10-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050320007843, to_date('20-03-2005', 'dd-mm-yyyy'), to_date('03-04-2005', 'dd-mm-yyyy'), 7, 5253, to_date('31-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130820007844, to_date('20-08-2013', 'dd-mm-yyyy'), to_date('03-09-2013', 'dd-mm-yyyy'), 10, 7334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010311007845, to_date('11-03-2001', 'dd-mm-yyyy'), to_date('25-03-2001', 'dd-mm-yyyy'), 3, 3343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050912007846, to_date('12-09-2005', 'dd-mm-yyyy'), to_date('26-09-2005', 'dd-mm-yyyy'), 5, 6526, to_date('16-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110930007847, to_date('30-09-2011', 'dd-mm-yyyy'), to_date('14-10-2011', 'dd-mm-yyyy'), 10, 9232, to_date('04-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080223007848, to_date('23-02-2008', 'dd-mm-yyyy'), to_date('08-03-2008', 'dd-mm-yyyy'), 11, 5569, to_date('05-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000415007849, to_date('15-04-2000', 'dd-mm-yyyy'), to_date('29-04-2000', 'dd-mm-yyyy'), 8, 1375, to_date('01-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110415007850, to_date('15-04-2011', 'dd-mm-yyyy'), to_date('29-04-2011', 'dd-mm-yyyy'), 7, 8370, to_date('04-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409007851, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 4, 7436, to_date('11-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427007852, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 5, 2328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111215007853, to_date('15-12-2011', 'dd-mm-yyyy'), to_date('29-12-2011', 'dd-mm-yyyy'), 8, 6935, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040407007854, to_date('07-04-2004', 'dd-mm-yyyy'), to_date('21-04-2004', 'dd-mm-yyyy'), 12, 4564, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100331007855, to_date('31-03-2010', 'dd-mm-yyyy'), to_date('14-04-2010', 'dd-mm-yyyy'), 6, 8502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426007856, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 6, 2060, to_date('16-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130712007857, to_date('12-07-2013', 'dd-mm-yyyy'), to_date('26-07-2013', 'dd-mm-yyyy'), 1, 9051, to_date('30-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021007858, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 2, 1340, to_date('01-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080610007859, to_date('10-06-2008', 'dd-mm-yyyy'), to_date('24-06-2008', 'dd-mm-yyyy'), 6, 7722, to_date('29-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000830007860, to_date('30-08-2000', 'dd-mm-yyyy'), to_date('13-09-2000', 'dd-mm-yyyy'), 8, 747, to_date('18-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041125007861, to_date('25-11-2004', 'dd-mm-yyyy'), to_date('09-12-2004', 'dd-mm-yyyy'), 7, 3269, to_date('27-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130320007862, to_date('20-03-2013', 'dd-mm-yyyy'), to_date('03-04-2013', 'dd-mm-yyyy'), 6, 9054, to_date('27-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090921007863, to_date('21-09-2009', 'dd-mm-yyyy'), to_date('05-10-2009', 'dd-mm-yyyy'), 9, 8910, to_date('29-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121226007864, to_date('26-12-2012', 'dd-mm-yyyy'), to_date('09-01-2013', 'dd-mm-yyyy'), 9, 8785, to_date('05-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060302007865, to_date('02-03-2006', 'dd-mm-yyyy'), to_date('16-03-2006', 'dd-mm-yyyy'), 9, 5586, to_date('10-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111016007866, to_date('16-10-2011', 'dd-mm-yyyy'), to_date('30-10-2011', 'dd-mm-yyyy'), 6, 9776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100126007867, to_date('26-01-2010', 'dd-mm-yyyy'), to_date('09-02-2010', 'dd-mm-yyyy'), 8, 5295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071017007868, to_date('17-10-2007', 'dd-mm-yyyy'), to_date('31-10-2007', 'dd-mm-yyyy'), 6, 3586, to_date('05-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030315007869, to_date('15-03-2003', 'dd-mm-yyyy'), to_date('29-03-2003', 'dd-mm-yyyy'), 4, 3584, to_date('25-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101024007870, to_date('24-10-2010', 'dd-mm-yyyy'), to_date('07-11-2010', 'dd-mm-yyyy'), 2, 8087, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030727007871, to_date('27-07-2003', 'dd-mm-yyyy'), to_date('10-08-2003', 'dd-mm-yyyy'), 4, 3701, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011128007872, to_date('28-11-2001', 'dd-mm-yyyy'), to_date('12-12-2001', 'dd-mm-yyyy'), 9, 1339, to_date('05-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326007873, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 2, 2552, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080627007874, to_date('27-06-2008', 'dd-mm-yyyy'), to_date('11-07-2008', 'dd-mm-yyyy'), 3, 5687, to_date('15-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121031007875, to_date('31-10-2012', 'dd-mm-yyyy'), to_date('14-11-2012', 'dd-mm-yyyy'), 9, 7157, to_date('03-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917007876, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 12, 8665, to_date('02-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120007877, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 8, 8559, to_date('06-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060930007878, to_date('30-09-2006', 'dd-mm-yyyy'), to_date('14-10-2006', 'dd-mm-yyyy'), 9, 5268, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031005007879, to_date('05-10-2003', 'dd-mm-yyyy'), to_date('19-10-2003', 'dd-mm-yyyy'), 6, 3313, to_date('23-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910007880, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 8, 2817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070506007881, to_date('06-05-2007', 'dd-mm-yyyy'), to_date('20-05-2007', 'dd-mm-yyyy'), 7, 4692, to_date('11-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020426007882, to_date('26-04-2002', 'dd-mm-yyyy'), to_date('10-05-2002', 'dd-mm-yyyy'), 8, 1088, to_date('01-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091029007883, to_date('29-10-2009', 'dd-mm-yyyy'), to_date('12-11-2009', 'dd-mm-yyyy'), 9, 7180, to_date('06-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111007884, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 7, 10809, to_date('19-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051119007885, to_date('19-11-2005', 'dd-mm-yyyy'), to_date('03-12-2005', 'dd-mm-yyyy'), 1, 4371, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040417007886, to_date('17-04-2004', 'dd-mm-yyyy'), to_date('01-05-2004', 'dd-mm-yyyy'), 10, 3291, to_date('28-04-2004', 'dd-mm-yyyy'));
commit;
prompt 1000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090513007887, to_date('13-05-2009', 'dd-mm-yyyy'), to_date('27-05-2009', 'dd-mm-yyyy'), 1, 7274, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030714007888, to_date('14-07-2003', 'dd-mm-yyyy'), to_date('28-07-2003', 'dd-mm-yyyy'), 5, 2580, to_date('02-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021027007889, to_date('27-10-2002', 'dd-mm-yyyy'), to_date('10-11-2002', 'dd-mm-yyyy'), 12, 2483, to_date('14-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010330007890, to_date('30-03-2001', 'dd-mm-yyyy'), to_date('13-04-2001', 'dd-mm-yyyy'), 6, 2996, to_date('11-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030119007891, to_date('19-01-2003', 'dd-mm-yyyy'), to_date('02-02-2003', 'dd-mm-yyyy'), 2, 2091, to_date('26-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111122007892, to_date('22-11-2011', 'dd-mm-yyyy'), to_date('06-12-2011', 'dd-mm-yyyy'), 5, 8315, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228007893, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 7, 8699, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430007894, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 8, 8747, to_date('16-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040201007895, to_date('01-02-2004', 'dd-mm-yyyy'), to_date('15-02-2004', 'dd-mm-yyyy'), 3, 2794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101005007896, to_date('05-10-2010', 'dd-mm-yyyy'), to_date('19-10-2010', 'dd-mm-yyyy'), 12, 8913, to_date('19-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030915007897, to_date('15-09-2003', 'dd-mm-yyyy'), to_date('29-09-2003', 'dd-mm-yyyy'), 6, 3465, to_date('23-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227007898, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 2, 6985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121210007899, to_date('10-12-2012', 'dd-mm-yyyy'), to_date('24-12-2012', 'dd-mm-yyyy'), 1, 7626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001021007900, to_date('21-10-2000', 'dd-mm-yyyy'), to_date('04-11-2000', 'dd-mm-yyyy'), 4, 1498, to_date('27-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110129007901, to_date('29-01-2011', 'dd-mm-yyyy'), to_date('12-02-2011', 'dd-mm-yyyy'), 11, 7035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020830007902, to_date('30-08-2002', 'dd-mm-yyyy'), to_date('13-09-2002', 'dd-mm-yyyy'), 3, 5073, to_date('02-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926007903, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 7, 4817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100818007904, to_date('18-08-2010', 'dd-mm-yyyy'), to_date('01-09-2010', 'dd-mm-yyyy'), 8, 7063, to_date('03-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070314007905, to_date('14-03-2007', 'dd-mm-yyyy'), to_date('28-03-2007', 'dd-mm-yyyy'), 5, 5252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071207007906, to_date('07-12-2007', 'dd-mm-yyyy'), to_date('21-12-2007', 'dd-mm-yyyy'), 10, 4075, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319007907, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 9, 5393, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713007908, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 7, 3512, to_date('17-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080426007909, to_date('26-04-2008', 'dd-mm-yyyy'), to_date('10-05-2008', 'dd-mm-yyyy'), 3, 3759, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050518007910, to_date('18-05-2005', 'dd-mm-yyyy'), to_date('01-06-2005', 'dd-mm-yyyy'), 9, 4703, to_date('06-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020614007911, to_date('14-06-2002', 'dd-mm-yyyy'), to_date('28-06-2002', 'dd-mm-yyyy'), 11, 2927, to_date('29-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214007912, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 3, 3518, to_date('18-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120007913, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 11, 2555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030731007914, to_date('31-07-2003', 'dd-mm-yyyy'), to_date('14-08-2003', 'dd-mm-yyyy'), 3, 2670, to_date('09-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120115007915, to_date('15-01-2012', 'dd-mm-yyyy'), to_date('29-01-2012', 'dd-mm-yyyy'), 11, 5489, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090526007916, to_date('26-05-2009', 'dd-mm-yyyy'), to_date('09-06-2009', 'dd-mm-yyyy'), 12, 5125, to_date('31-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608007917, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 4, 4403, to_date('25-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090113007918, to_date('13-01-2009', 'dd-mm-yyyy'), to_date('27-01-2009', 'dd-mm-yyyy'), 6, 6492, to_date('31-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021007919, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 12, 5558, to_date('26-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140331007920, to_date('31-03-2014', 'dd-mm-yyyy'), to_date('14-04-2014', 'dd-mm-yyyy'), 10, 8870, to_date('15-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100107007921, to_date('07-01-2010', 'dd-mm-yyyy'), to_date('21-01-2010', 'dd-mm-yyyy'), 6, 6620, to_date('22-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411007922, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 12, 12557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060721007923, to_date('21-07-2006', 'dd-mm-yyyy'), to_date('04-08-2006', 'dd-mm-yyyy'), 7, 4245, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120510007924, to_date('10-05-2012', 'dd-mm-yyyy'), to_date('24-05-2012', 'dd-mm-yyyy'), 7, 7456, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090403007925, to_date('03-04-2009', 'dd-mm-yyyy'), to_date('17-04-2009', 'dd-mm-yyyy'), 5, 7443, to_date('10-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060626007926, to_date('26-06-2006', 'dd-mm-yyyy'), to_date('10-07-2006', 'dd-mm-yyyy'), 1, 4403, to_date('02-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091009007927, to_date('09-10-2009', 'dd-mm-yyyy'), to_date('23-10-2009', 'dd-mm-yyyy'), 9, 6539, to_date('23-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031109007928, to_date('09-11-2003', 'dd-mm-yyyy'), to_date('23-11-2003', 'dd-mm-yyyy'), 10, 2616, to_date('21-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080628007929, to_date('28-06-2008', 'dd-mm-yyyy'), to_date('12-07-2008', 'dd-mm-yyyy'), 9, 5758, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010607007930, to_date('07-06-2001', 'dd-mm-yyyy'), to_date('21-06-2001', 'dd-mm-yyyy'), 7, 2691, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525007931, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 4, 7031, to_date('30-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021223007932, to_date('23-12-2002', 'dd-mm-yyyy'), to_date('06-01-2003', 'dd-mm-yyyy'), 6, 1459, to_date('30-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080116007933, to_date('16-01-2008', 'dd-mm-yyyy'), to_date('30-01-2008', 'dd-mm-yyyy'), 11, 7185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405007934, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 4, 3280, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131129007935, to_date('29-11-2013', 'dd-mm-yyyy'), to_date('13-12-2013', 'dd-mm-yyyy'), 11, 7064, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100823007936, to_date('23-08-2010', 'dd-mm-yyyy'), to_date('06-09-2010', 'dd-mm-yyyy'), 4, 7055, to_date('06-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326007937, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 3, 8137, to_date('30-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130829007938, to_date('29-08-2013', 'dd-mm-yyyy'), to_date('12-09-2013', 'dd-mm-yyyy'), 3, 13079, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051025007939, to_date('25-10-2005', 'dd-mm-yyyy'), to_date('08-11-2005', 'dd-mm-yyyy'), 2, 3824, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100116007940, to_date('16-01-2010', 'dd-mm-yyyy'), to_date('30-01-2010', 'dd-mm-yyyy'), 5, 7443, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030309007941, to_date('09-03-2003', 'dd-mm-yyyy'), to_date('23-03-2003', 'dd-mm-yyyy'), 1, 1572, to_date('19-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617007942, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 12, 4954, to_date('02-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070518007943, to_date('18-05-2007', 'dd-mm-yyyy'), to_date('01-06-2007', 'dd-mm-yyyy'), 9, 4841, to_date('04-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060816007944, to_date('16-08-2006', 'dd-mm-yyyy'), to_date('30-08-2006', 'dd-mm-yyyy'), 8, 3913, to_date('22-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324007945, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 3, 4070, to_date('13-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080221007946, to_date('21-02-2008', 'dd-mm-yyyy'), to_date('06-03-2008', 'dd-mm-yyyy'), 4, 7565, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000112007947, to_date('12-01-2000', 'dd-mm-yyyy'), to_date('26-01-2000', 'dd-mm-yyyy'), 6, 1517, to_date('28-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110505007948, to_date('05-05-2011', 'dd-mm-yyyy'), to_date('19-05-2011', 'dd-mm-yyyy'), 3, 7752, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510007949, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 11, 3437, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529007950, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 10, 5588, to_date('11-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419007951, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 11, 5260, to_date('22-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407007952, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 10, 9058, to_date('18-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208007953, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 1, 8177, to_date('26-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040722007954, to_date('22-07-2004', 'dd-mm-yyyy'), to_date('05-08-2004', 'dd-mm-yyyy'), 6, 4912, to_date('05-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120315007955, to_date('15-03-2012', 'dd-mm-yyyy'), to_date('29-03-2012', 'dd-mm-yyyy'), 5, 6461, to_date('27-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729007956, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 12, 6171, to_date('09-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929000916, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 11, 7352, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050903000917, to_date('03-09-2005', 'dd-mm-yyyy'), to_date('17-09-2005', 'dd-mm-yyyy'), 11, 3769, to_date('20-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020729000918, to_date('29-07-2002', 'dd-mm-yyyy'), to_date('12-08-2002', 'dd-mm-yyyy'), 2, 3398, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306000919, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 3, 2908, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040113000920, to_date('13-01-2004', 'dd-mm-yyyy'), to_date('27-01-2004', 'dd-mm-yyyy'), 7, 4788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000516000921, to_date('16-05-2000', 'dd-mm-yyyy'), to_date('30-05-2000', 'dd-mm-yyyy'), 2, 2089, to_date('25-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707000922, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 6, 5887, to_date('14-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050903000923, to_date('03-09-2005', 'dd-mm-yyyy'), to_date('17-09-2005', 'dd-mm-yyyy'), 8, 6179, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040702000924, to_date('02-07-2004', 'dd-mm-yyyy'), to_date('16-07-2004', 'dd-mm-yyyy'), 2, 3823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040527000925, to_date('27-05-2004', 'dd-mm-yyyy'), to_date('10-06-2004', 'dd-mm-yyyy'), 11, 5654, to_date('09-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000219000926, to_date('19-02-2000', 'dd-mm-yyyy'), to_date('04-03-2000', 'dd-mm-yyyy'), 2, 1228, to_date('24-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010523000927, to_date('23-05-2001', 'dd-mm-yyyy'), to_date('06-06-2001', 'dd-mm-yyyy'), 2, 2368, to_date('10-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090622000928, to_date('22-06-2009', 'dd-mm-yyyy'), to_date('06-07-2009', 'dd-mm-yyyy'), 10, 6628, to_date('07-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031111000929, to_date('11-11-2003', 'dd-mm-yyyy'), to_date('25-11-2003', 'dd-mm-yyyy'), 8, 2379, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129000930, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 9, 4432, to_date('12-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827000931, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 6, 3368, to_date('01-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060730000932, to_date('30-07-2006', 'dd-mm-yyyy'), to_date('13-08-2006', 'dd-mm-yyyy'), 5, 4147, to_date('04-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130818000933, to_date('18-08-2013', 'dd-mm-yyyy'), to_date('01-09-2013', 'dd-mm-yyyy'), 10, 8644, to_date('28-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100119000934, to_date('19-01-2010', 'dd-mm-yyyy'), to_date('02-02-2010', 'dd-mm-yyyy'), 4, 6904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020628000935, to_date('28-06-2002', 'dd-mm-yyyy'), to_date('12-07-2002', 'dd-mm-yyyy'), 9, 2522, to_date('04-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080222000936, to_date('22-02-2008', 'dd-mm-yyyy'), to_date('07-03-2008', 'dd-mm-yyyy'), 1, 3595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825000937, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 4, 5455, to_date('08-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041004000938, to_date('04-10-2004', 'dd-mm-yyyy'), to_date('18-10-2004', 'dd-mm-yyyy'), 6, 1850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130131000939, to_date('31-01-2013', 'dd-mm-yyyy'), to_date('14-02-2013', 'dd-mm-yyyy'), 10, 8995, to_date('06-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061216000940, to_date('16-12-2006', 'dd-mm-yyyy'), to_date('30-12-2006', 'dd-mm-yyyy'), 9, 3862, to_date('29-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081115000941, to_date('15-11-2008', 'dd-mm-yyyy'), to_date('29-11-2008', 'dd-mm-yyyy'), 6, 6261, to_date('02-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080120000942, to_date('20-01-2008', 'dd-mm-yyyy'), to_date('03-02-2008', 'dd-mm-yyyy'), 4, 6408, to_date('28-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011000943, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 7, 5431, to_date('18-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129000944, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 9, 5664, to_date('30-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090213000945, to_date('13-02-2009', 'dd-mm-yyyy'), to_date('27-02-2009', 'dd-mm-yyyy'), 11, 3801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215000946, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 6, 5712, to_date('28-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060702000947, to_date('02-07-2006', 'dd-mm-yyyy'), to_date('16-07-2006', 'dd-mm-yyyy'), 9, 4946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010518000948, to_date('18-05-2001', 'dd-mm-yyyy'), to_date('01-06-2001', 'dd-mm-yyyy'), 11, 870, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106000949, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 12, 6703, to_date('16-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140429000950, to_date('29-04-2014', 'dd-mm-yyyy'), to_date('13-05-2014', 'dd-mm-yyyy'), 7, 13466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080905000951, to_date('05-09-2008', 'dd-mm-yyyy'), to_date('19-09-2008', 'dd-mm-yyyy'), 12, 4705, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081212000952, to_date('12-12-2008', 'dd-mm-yyyy'), to_date('26-12-2008', 'dd-mm-yyyy'), 10, 5998, to_date('17-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090225000953, to_date('25-02-2009', 'dd-mm-yyyy'), to_date('11-03-2009', 'dd-mm-yyyy'), 3, 5522, to_date('07-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403000954, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 4, 7127, to_date('15-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051204000955, to_date('04-12-2005', 'dd-mm-yyyy'), to_date('18-12-2005', 'dd-mm-yyyy'), 8, 5082, to_date('06-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212000956, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 7, 2534, to_date('02-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008000957, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 10, 4031, to_date('27-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628000958, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 2, 4672, to_date('16-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051125000959, to_date('25-11-2005', 'dd-mm-yyyy'), to_date('09-12-2005', 'dd-mm-yyyy'), 3, 3542, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216000960, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 4, 7004, to_date('27-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000518000961, to_date('18-05-2000', 'dd-mm-yyyy'), to_date('01-06-2000', 'dd-mm-yyyy'), 10, 1765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050303000962, to_date('03-03-2005', 'dd-mm-yyyy'), to_date('17-03-2005', 'dd-mm-yyyy'), 6, 3984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901000963, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 9, 8842, to_date('03-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010530000964, to_date('30-05-2001', 'dd-mm-yyyy'), to_date('13-06-2001', 'dd-mm-yyyy'), 8, 2210, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070826000965, to_date('26-08-2007', 'dd-mm-yyyy'), to_date('09-09-2007', 'dd-mm-yyyy'), 6, 5324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121213000966, to_date('13-12-2012', 'dd-mm-yyyy'), to_date('27-12-2012', 'dd-mm-yyyy'), 7, 6861, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101023000967, to_date('23-10-2010', 'dd-mm-yyyy'), to_date('06-11-2010', 'dd-mm-yyyy'), 2, 8654, to_date('06-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101117000968, to_date('17-11-2010', 'dd-mm-yyyy'), to_date('01-12-2010', 'dd-mm-yyyy'), 10, 10841, to_date('23-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011104000969, to_date('04-11-2001', 'dd-mm-yyyy'), to_date('18-11-2001', 'dd-mm-yyyy'), 11, 2855, to_date('24-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011207000970, to_date('07-12-2001', 'dd-mm-yyyy'), to_date('21-12-2001', 'dd-mm-yyyy'), 8, 1281, to_date('14-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041014000971, to_date('14-10-2004', 'dd-mm-yyyy'), to_date('28-10-2004', 'dd-mm-yyyy'), 5, 4852, to_date('23-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050318000972, to_date('18-03-2005', 'dd-mm-yyyy'), to_date('01-04-2005', 'dd-mm-yyyy'), 12, 6331, to_date('23-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106000973, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 10, 3267, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010603000974, to_date('03-06-2001', 'dd-mm-yyyy'), to_date('17-06-2001', 'dd-mm-yyyy'), 11, 1133, to_date('04-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080611000975, to_date('11-06-2008', 'dd-mm-yyyy'), to_date('25-06-2008', 'dd-mm-yyyy'), 2, 6094, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730000976, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 6, 7305, to_date('09-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090201000977, to_date('01-02-2009', 'dd-mm-yyyy'), to_date('15-02-2009', 'dd-mm-yyyy'), 5, 6180, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201000978, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 7, 4902, to_date('15-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120410000979, to_date('10-04-2012', 'dd-mm-yyyy'), to_date('24-04-2012', 'dd-mm-yyyy'), 2, 6393, to_date('30-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041027000980, to_date('27-10-2004', 'dd-mm-yyyy'), to_date('10-11-2004', 'dd-mm-yyyy'), 3, 4173, to_date('14-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001222000981, to_date('22-12-2000', 'dd-mm-yyyy'), to_date('05-01-2001', 'dd-mm-yyyy'), 8, 1396, to_date('07-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020916000982, to_date('16-09-2002', 'dd-mm-yyyy'), to_date('30-09-2002', 'dd-mm-yyyy'), 4, 2160, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101211000983, to_date('11-12-2010', 'dd-mm-yyyy'), to_date('25-12-2010', 'dd-mm-yyyy'), 9, 6736, to_date('30-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101119000984, to_date('19-11-2010', 'dd-mm-yyyy'), to_date('03-12-2010', 'dd-mm-yyyy'), 11, 6108, to_date('07-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041111000985, to_date('11-11-2004', 'dd-mm-yyyy'), to_date('25-11-2004', 'dd-mm-yyyy'), 1, 4488, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031018000986, to_date('18-10-2003', 'dd-mm-yyyy'), to_date('01-11-2003', 'dd-mm-yyyy'), 12, 3063, to_date('21-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911000987, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 8, 6928, to_date('14-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041207000988, to_date('07-12-2004', 'dd-mm-yyyy'), to_date('21-12-2004', 'dd-mm-yyyy'), 10, 3302, to_date('20-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010518000989, to_date('18-05-2001', 'dd-mm-yyyy'), to_date('01-06-2001', 'dd-mm-yyyy'), 10, 1411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602000990, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 9, 8289, to_date('04-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806000991, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 6, 7931, to_date('10-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131214000992, to_date('14-12-2013', 'dd-mm-yyyy'), to_date('28-12-2013', 'dd-mm-yyyy'), 11, 8998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120605000993, to_date('05-06-2012', 'dd-mm-yyyy'), to_date('19-06-2012', 'dd-mm-yyyy'), 4, 7129, to_date('12-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011201000994, to_date('01-12-2001', 'dd-mm-yyyy'), to_date('15-12-2001', 'dd-mm-yyyy'), 7, 2155, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070518000995, to_date('18-05-2007', 'dd-mm-yyyy'), to_date('01-06-2007', 'dd-mm-yyyy'), 7, 6167, to_date('30-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503000996, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 2, 5706, to_date('06-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080921000997, to_date('21-09-2008', 'dd-mm-yyyy'), to_date('05-10-2008', 'dd-mm-yyyy'), 9, 6140, to_date('22-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120522000998, to_date('22-05-2012', 'dd-mm-yyyy'), to_date('05-06-2012', 'dd-mm-yyyy'), 6, 8861, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618000999, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 8, 8191, to_date('02-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070929001000, to_date('29-09-2007', 'dd-mm-yyyy'), to_date('13-10-2007', 'dd-mm-yyyy'), 3, 5799, to_date('30-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070131001001, to_date('31-01-2007', 'dd-mm-yyyy'), to_date('14-02-2007', 'dd-mm-yyyy'), 11, 3513, to_date('17-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608001002, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 12, 4974, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131212001003, to_date('12-12-2013', 'dd-mm-yyyy'), to_date('26-12-2013', 'dd-mm-yyyy'), 11, 9390, to_date('25-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020717001004, to_date('17-07-2002', 'dd-mm-yyyy'), to_date('31-07-2002', 'dd-mm-yyyy'), 5, 2140, to_date('31-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060108001005, to_date('08-01-2006', 'dd-mm-yyyy'), to_date('22-01-2006', 'dd-mm-yyyy'), 10, 6898, to_date('20-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080331001006, to_date('31-03-2008', 'dd-mm-yyyy'), to_date('14-04-2008', 'dd-mm-yyyy'), 6, 7649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140218001007, to_date('18-02-2014', 'dd-mm-yyyy'), to_date('04-03-2014', 'dd-mm-yyyy'), 3, 9253, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020324001008, to_date('24-03-2002', 'dd-mm-yyyy'), to_date('07-04-2002', 'dd-mm-yyyy'), 6, 2401, to_date('31-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030418001009, to_date('18-04-2003', 'dd-mm-yyyy'), to_date('02-05-2003', 'dd-mm-yyyy'), 11, 4028, to_date('05-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601001010, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 3, 10877, to_date('08-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070916001011, to_date('16-09-2007', 'dd-mm-yyyy'), to_date('30-09-2007', 'dd-mm-yyyy'), 4, 7439, to_date('27-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090208001012, to_date('08-02-2009', 'dd-mm-yyyy'), to_date('22-02-2009', 'dd-mm-yyyy'), 6, 8620, to_date('10-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030829001013, to_date('29-08-2003', 'dd-mm-yyyy'), to_date('12-09-2003', 'dd-mm-yyyy'), 7, 3400, to_date('18-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090418001014, to_date('18-04-2009', 'dd-mm-yyyy'), to_date('02-05-2009', 'dd-mm-yyyy'), 4, 6324, to_date('29-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408001015, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 3, 5492, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130408001016, to_date('08-04-2013', 'dd-mm-yyyy'), to_date('22-04-2013', 'dd-mm-yyyy'), 8, 10494, to_date('15-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001206001017, to_date('06-12-2000', 'dd-mm-yyyy'), to_date('20-12-2000', 'dd-mm-yyyy'), 2, 2991, to_date('18-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000131001018, to_date('31-01-2000', 'dd-mm-yyyy'), to_date('14-02-2000', 'dd-mm-yyyy'), 5, 884, to_date('16-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020709001019, to_date('09-07-2002', 'dd-mm-yyyy'), to_date('23-07-2002', 'dd-mm-yyyy'), 6, 3682, to_date('27-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111222001020, to_date('22-12-2011', 'dd-mm-yyyy'), to_date('05-01-2012', 'dd-mm-yyyy'), 5, 6921, to_date('28-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041216001021, to_date('16-12-2004', 'dd-mm-yyyy'), to_date('30-12-2004', 'dd-mm-yyyy'), 11, 4855, to_date('30-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130101001022, to_date('01-01-2013', 'dd-mm-yyyy'), to_date('15-01-2013', 'dd-mm-yyyy'), 9, 8674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091128001023, to_date('28-11-2009', 'dd-mm-yyyy'), to_date('12-12-2009', 'dd-mm-yyyy'), 4, 7191, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031001024, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 4, 6949, to_date('17-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090412001025, to_date('12-04-2009', 'dd-mm-yyyy'), to_date('26-04-2009', 'dd-mm-yyyy'), 4, 9108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051122001026, to_date('22-11-2005', 'dd-mm-yyyy'), to_date('06-12-2005', 'dd-mm-yyyy'), 9, 4541, to_date('03-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100401001027, to_date('01-04-2010', 'dd-mm-yyyy'), to_date('15-04-2010', 'dd-mm-yyyy'), 5, 7443, to_date('04-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090420001028, to_date('20-04-2009', 'dd-mm-yyyy'), to_date('04-05-2009', 'dd-mm-yyyy'), 11, 5310, to_date('01-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001203001029, to_date('03-12-2000', 'dd-mm-yyyy'), to_date('17-12-2000', 'dd-mm-yyyy'), 2, 1888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071207001030, to_date('07-12-2007', 'dd-mm-yyyy'), to_date('21-12-2007', 'dd-mm-yyyy'), 11, 6378, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225001031, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 8, 5738, to_date('09-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060716001032, to_date('16-07-2006', 'dd-mm-yyyy'), to_date('30-07-2006', 'dd-mm-yyyy'), 12, 4942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001001033, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 9, 939, to_date('08-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617001034, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 4, 3619, to_date('25-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110001035, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 12, 4899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100711001036, to_date('11-07-2010', 'dd-mm-yyyy'), to_date('25-07-2010', 'dd-mm-yyyy'), 3, 7422, to_date('18-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081014001037, to_date('14-10-2008', 'dd-mm-yyyy'), to_date('28-10-2008', 'dd-mm-yyyy'), 2, 7292, to_date('31-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110628001038, to_date('28-06-2011', 'dd-mm-yyyy'), to_date('12-07-2011', 'dd-mm-yyyy'), 8, 6947, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001123001039, to_date('23-11-2000', 'dd-mm-yyyy'), to_date('07-12-2000', 'dd-mm-yyyy'), 5, 1324, to_date('04-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110622001040, to_date('22-06-2011', 'dd-mm-yyyy'), to_date('06-07-2011', 'dd-mm-yyyy'), 6, 6951, to_date('27-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215001041, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 5, 5022, to_date('01-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302001042, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 5, 3513, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071029001043, to_date('29-10-2007', 'dd-mm-yyyy'), to_date('12-11-2007', 'dd-mm-yyyy'), 5, 2722, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070620001044, to_date('20-06-2007', 'dd-mm-yyyy'), to_date('04-07-2007', 'dd-mm-yyyy'), 12, 2930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080324001045, to_date('24-03-2008', 'dd-mm-yyyy'), to_date('07-04-2008', 'dd-mm-yyyy'), 5, 3613, to_date('26-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110720001046, to_date('20-07-2011', 'dd-mm-yyyy'), to_date('03-08-2011', 'dd-mm-yyyy'), 8, 8815, to_date('02-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080202001047, to_date('02-02-2008', 'dd-mm-yyyy'), to_date('16-02-2008', 'dd-mm-yyyy'), 3, 6494, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081205001048, to_date('05-12-2008', 'dd-mm-yyyy'), to_date('19-12-2008', 'dd-mm-yyyy'), 2, 5408, to_date('09-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722001049, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 9, 2040, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021130001050, to_date('30-11-2002', 'dd-mm-yyyy'), to_date('14-12-2002', 'dd-mm-yyyy'), 10, 2189, to_date('08-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101231001051, to_date('31-12-2010', 'dd-mm-yyyy'), to_date('14-01-2011', 'dd-mm-yyyy'), 1, 6214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040609001052, to_date('09-06-2004', 'dd-mm-yyyy'), to_date('23-06-2004', 'dd-mm-yyyy'), 10, 4251, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430001053, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 1, 9673, to_date('19-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001119001054, to_date('19-11-2000', 'dd-mm-yyyy'), to_date('03-12-2000', 'dd-mm-yyyy'), 7, 1596, to_date('01-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000417001055, to_date('17-04-2000', 'dd-mm-yyyy'), to_date('01-05-2000', 'dd-mm-yyyy'), 4, 1260, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080109001056, to_date('09-01-2008', 'dd-mm-yyyy'), to_date('23-01-2008', 'dd-mm-yyyy'), 4, 5519, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120409001057, to_date('09-04-2012', 'dd-mm-yyyy'), to_date('23-04-2012', 'dd-mm-yyyy'), 6, 11090, to_date('13-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090219001058, to_date('19-02-2009', 'dd-mm-yyyy'), to_date('05-03-2009', 'dd-mm-yyyy'), 4, 4416, to_date('27-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100105001059, to_date('05-01-2010', 'dd-mm-yyyy'), to_date('19-01-2010', 'dd-mm-yyyy'), 2, 6511, to_date('10-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020110001060, to_date('10-01-2002', 'dd-mm-yyyy'), to_date('24-01-2002', 'dd-mm-yyyy'), 8, 2421, to_date('15-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060622001061, to_date('22-06-2006', 'dd-mm-yyyy'), to_date('06-07-2006', 'dd-mm-yyyy'), 12, 4898, to_date('25-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080620001062, to_date('20-06-2008', 'dd-mm-yyyy'), to_date('04-07-2008', 'dd-mm-yyyy'), 9, 6883, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070624001063, to_date('24-06-2007', 'dd-mm-yyyy'), to_date('08-07-2007', 'dd-mm-yyyy'), 4, 5007, to_date('06-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091231001064, to_date('31-12-2009', 'dd-mm-yyyy'), to_date('14-01-2010', 'dd-mm-yyyy'), 11, 6441, to_date('11-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070117001065, to_date('17-01-2007', 'dd-mm-yyyy'), to_date('31-01-2007', 'dd-mm-yyyy'), 3, 4467, to_date('03-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091203001066, to_date('03-12-2009', 'dd-mm-yyyy'), to_date('17-12-2009', 'dd-mm-yyyy'), 10, 7624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101206001067, to_date('06-12-2010', 'dd-mm-yyyy'), to_date('20-12-2010', 'dd-mm-yyyy'), 5, 6716, to_date('16-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413001068, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 10, 9721, to_date('29-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090528003370, to_date('28-05-2009', 'dd-mm-yyyy'), to_date('11-06-2009', 'dd-mm-yyyy'), 5, 4805, to_date('16-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060707003371, to_date('07-07-2006', 'dd-mm-yyyy'), to_date('21-07-2006', 'dd-mm-yyyy'), 11, 3432, to_date('22-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825003372, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 2, 3956, to_date('04-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110302003373, to_date('02-03-2011', 'dd-mm-yyyy'), to_date('16-03-2011', 'dd-mm-yyyy'), 5, 9833, to_date('14-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120103003374, to_date('03-01-2012', 'dd-mm-yyyy'), to_date('17-01-2012', 'dd-mm-yyyy'), 7, 9808, to_date('22-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121101003375, to_date('01-11-2012', 'dd-mm-yyyy'), to_date('15-11-2012', 'dd-mm-yyyy'), 3, 7832, to_date('21-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919003376, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 9, 5739, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614003377, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 12, 5191, to_date('01-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030615003378, to_date('15-06-2003', 'dd-mm-yyyy'), to_date('29-06-2003', 'dd-mm-yyyy'), 3, 1519, to_date('24-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021005003379, to_date('05-10-2002', 'dd-mm-yyyy'), to_date('19-10-2002', 'dd-mm-yyyy'), 2, 563, to_date('23-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081120003380, to_date('20-11-2008', 'dd-mm-yyyy'), to_date('04-12-2008', 'dd-mm-yyyy'), 8, 5272, to_date('04-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020228003381, to_date('28-02-2002', 'dd-mm-yyyy'), to_date('14-03-2002', 'dd-mm-yyyy'), 3, 2071, to_date('15-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090410003382, to_date('10-04-2009', 'dd-mm-yyyy'), to_date('24-04-2009', 'dd-mm-yyyy'), 7, 6175, to_date('22-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071120003383, to_date('20-11-2007', 'dd-mm-yyyy'), to_date('04-12-2007', 'dd-mm-yyyy'), 5, 4101, to_date('08-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030714003384, to_date('14-07-2003', 'dd-mm-yyyy'), to_date('28-07-2003', 'dd-mm-yyyy'), 8, 3033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010218003385, to_date('18-02-2001', 'dd-mm-yyyy'), to_date('04-03-2001', 'dd-mm-yyyy'), 7, 3108, to_date('23-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060128003386, to_date('28-01-2006', 'dd-mm-yyyy'), to_date('11-02-2006', 'dd-mm-yyyy'), 2, 6498, to_date('10-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130917003387, to_date('17-09-2013', 'dd-mm-yyyy'), to_date('01-10-2013', 'dd-mm-yyyy'), 5, 10659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120719003388, to_date('19-07-2012', 'dd-mm-yyyy'), to_date('02-08-2012', 'dd-mm-yyyy'), 4, 6427, to_date('29-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019003389, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 3, 5133, to_date('05-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220003390, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 10, 9097, to_date('26-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090603003391, to_date('03-06-2009', 'dd-mm-yyyy'), to_date('17-06-2009', 'dd-mm-yyyy'), 7, 5128, to_date('16-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000117003392, to_date('17-01-2000', 'dd-mm-yyyy'), to_date('31-01-2000', 'dd-mm-yyyy'), 10, 1007, to_date('02-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071013003393, to_date('13-10-2007', 'dd-mm-yyyy'), to_date('27-10-2007', 'dd-mm-yyyy'), 1, 7324, to_date('26-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020907003394, to_date('07-09-2002', 'dd-mm-yyyy'), to_date('21-09-2002', 'dd-mm-yyyy'), 4, 4100, to_date('16-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101001003395, to_date('01-10-2010', 'dd-mm-yyyy'), to_date('15-10-2010', 'dd-mm-yyyy'), 6, 8041, to_date('08-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031003396, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 11, 1696, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928003397, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 1, 5556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709003398, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 4, 7257, to_date('26-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040523003399, to_date('23-05-2004', 'dd-mm-yyyy'), to_date('06-06-2004', 'dd-mm-yyyy'), 5, 3811, to_date('02-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001012003400, to_date('12-10-2000', 'dd-mm-yyyy'), to_date('26-10-2000', 'dd-mm-yyyy'), 8, 1396, to_date('01-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120515003401, to_date('15-05-2012', 'dd-mm-yyyy'), to_date('29-05-2012', 'dd-mm-yyyy'), 3, 6950, to_date('28-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313003402, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 8, 5606, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140215003403, to_date('15-02-2014', 'dd-mm-yyyy'), to_date('01-03-2014', 'dd-mm-yyyy'), 8, 7069, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129003404, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 9, 7473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824003405, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 7, 7208, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040505003406, to_date('05-05-2004', 'dd-mm-yyyy'), to_date('19-05-2004', 'dd-mm-yyyy'), 2, 2371, to_date('21-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090612003407, to_date('12-06-2009', 'dd-mm-yyyy'), to_date('26-06-2009', 'dd-mm-yyyy'), 3, 6028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040711003408, to_date('11-07-2004', 'dd-mm-yyyy'), to_date('25-07-2004', 'dd-mm-yyyy'), 6, 3550, to_date('29-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041224003409, to_date('24-12-2004', 'dd-mm-yyyy'), to_date('07-01-2005', 'dd-mm-yyyy'), 1, 4662, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140121003410, to_date('21-01-2014', 'dd-mm-yyyy'), to_date('04-02-2014', 'dd-mm-yyyy'), 10, 8431, to_date('26-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825003411, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 6, 8948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120315003412, to_date('15-03-2012', 'dd-mm-yyyy'), to_date('29-03-2012', 'dd-mm-yyyy'), 9, 9289, to_date('01-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030224003413, to_date('24-02-2003', 'dd-mm-yyyy'), to_date('10-03-2003', 'dd-mm-yyyy'), 8, 4516, to_date('08-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061213003414, to_date('13-12-2006', 'dd-mm-yyyy'), to_date('27-12-2006', 'dd-mm-yyyy'), 4, 6842, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070831003415, to_date('31-08-2007', 'dd-mm-yyyy'), to_date('14-09-2007', 'dd-mm-yyyy'), 9, 6450, to_date('04-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009003416, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 4, 6740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130308003417, to_date('08-03-2013', 'dd-mm-yyyy'), to_date('22-03-2013', 'dd-mm-yyyy'), 2, 5631, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051030003418, to_date('30-10-2005', 'dd-mm-yyyy'), to_date('13-11-2005', 'dd-mm-yyyy'), 11, 4104, to_date('16-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090818003419, to_date('18-08-2009', 'dd-mm-yyyy'), to_date('01-09-2009', 'dd-mm-yyyy'), 5, 4286, to_date('28-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080610003420, to_date('10-06-2008', 'dd-mm-yyyy'), to_date('24-06-2008', 'dd-mm-yyyy'), 11, 7700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050301003421, to_date('01-03-2005', 'dd-mm-yyyy'), to_date('15-03-2005', 'dd-mm-yyyy'), 7, 4445, to_date('21-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110118003422, to_date('18-01-2011', 'dd-mm-yyyy'), to_date('01-02-2011', 'dd-mm-yyyy'), 9, 8441, to_date('04-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118003423, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 5, 2028, to_date('05-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090318003424, to_date('18-03-2009', 'dd-mm-yyyy'), to_date('01-04-2009', 'dd-mm-yyyy'), 1, 6829, to_date('01-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040327003425, to_date('27-03-2004', 'dd-mm-yyyy'), to_date('10-04-2004', 'dd-mm-yyyy'), 3, 3939, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212003426, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 5, 2329, to_date('16-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050726003427, to_date('26-07-2005', 'dd-mm-yyyy'), to_date('09-08-2005', 'dd-mm-yyyy'), 3, 5961, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120823003428, to_date('23-08-2012', 'dd-mm-yyyy'), to_date('06-09-2012', 'dd-mm-yyyy'), 7, 6712, to_date('24-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071118003429, to_date('18-11-2007', 'dd-mm-yyyy'), to_date('02-12-2007', 'dd-mm-yyyy'), 3, 4890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003003430, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 11, 3632, to_date('23-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050621003431, to_date('21-06-2005', 'dd-mm-yyyy'), to_date('05-07-2005', 'dd-mm-yyyy'), 3, 4801, to_date('27-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040729003432, to_date('29-07-2004', 'dd-mm-yyyy'), to_date('12-08-2004', 'dd-mm-yyyy'), 9, 3518, to_date('31-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625003433, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 4, 2878, to_date('10-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031207003434, to_date('07-12-2003', 'dd-mm-yyyy'), to_date('21-12-2003', 'dd-mm-yyyy'), 3, 5091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519003435, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 5, 3375, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000409003436, to_date('09-04-2000', 'dd-mm-yyyy'), to_date('23-04-2000', 'dd-mm-yyyy'), 7, 2176, to_date('23-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000112003437, to_date('12-01-2000', 'dd-mm-yyyy'), to_date('26-01-2000', 'dd-mm-yyyy'), 6, 1840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090622003438, to_date('22-06-2009', 'dd-mm-yyyy'), to_date('06-07-2009', 'dd-mm-yyyy'), 6, 5329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802003439, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 9616, to_date('11-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090918003440, to_date('18-09-2009', 'dd-mm-yyyy'), to_date('02-10-2009', 'dd-mm-yyyy'), 5, 2821, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111031003441, to_date('31-10-2011', 'dd-mm-yyyy'), to_date('14-11-2011', 'dd-mm-yyyy'), 6, 3593, to_date('03-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603003442, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 1, 6815, to_date('15-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140225003443, to_date('25-02-2014', 'dd-mm-yyyy'), to_date('11-03-2014', 'dd-mm-yyyy'), 12, 8694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090118003444, to_date('18-01-2009', 'dd-mm-yyyy'), to_date('01-02-2009', 'dd-mm-yyyy'), 10, 6164, to_date('01-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051117003445, to_date('17-11-2005', 'dd-mm-yyyy'), to_date('01-12-2005', 'dd-mm-yyyy'), 7, 6198, to_date('01-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130511003446, to_date('11-05-2013', 'dd-mm-yyyy'), to_date('25-05-2013', 'dd-mm-yyyy'), 8, 8434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227003447, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 4, 2797, to_date('29-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130003448, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 12, 4803, to_date('01-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519003449, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 9, 8428, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060807003450, to_date('07-08-2006', 'dd-mm-yyyy'), to_date('21-08-2006', 'dd-mm-yyyy'), 6, 5065, to_date('15-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020618003451, to_date('18-06-2002', 'dd-mm-yyyy'), to_date('02-07-2002', 'dd-mm-yyyy'), 7, 4857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110627003452, to_date('27-06-2011', 'dd-mm-yyyy'), to_date('11-07-2011', 'dd-mm-yyyy'), 3, 8925, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130921003453, to_date('21-09-2013', 'dd-mm-yyyy'), to_date('05-10-2013', 'dd-mm-yyyy'), 12, 9512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417003454, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 5, 4448, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924003455, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 5, 7073, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010506003456, to_date('06-05-2001', 'dd-mm-yyyy'), to_date('20-05-2001', 'dd-mm-yyyy'), 5, 4566, to_date('22-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050530003457, to_date('30-05-2005', 'dd-mm-yyyy'), to_date('13-06-2005', 'dd-mm-yyyy'), 2, 6167, to_date('12-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101203003458, to_date('03-12-2010', 'dd-mm-yyyy'), to_date('17-12-2010', 'dd-mm-yyyy'), 5, 6671, to_date('10-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120913003459, to_date('13-09-2012', 'dd-mm-yyyy'), to_date('27-09-2012', 'dd-mm-yyyy'), 11, 6280, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080420003460, to_date('20-04-2008', 'dd-mm-yyyy'), to_date('04-05-2008', 'dd-mm-yyyy'), 3, 5637, to_date('26-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090123003461, to_date('23-01-2009', 'dd-mm-yyyy'), to_date('06-02-2009', 'dd-mm-yyyy'), 11, 8708, to_date('05-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131220003462, to_date('20-12-2013', 'dd-mm-yyyy'), to_date('03-01-2014', 'dd-mm-yyyy'), 9, 9905, to_date('03-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010331003463, to_date('31-03-2001', 'dd-mm-yyyy'), to_date('14-04-2001', 'dd-mm-yyyy'), 8, 3092, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090209003464, to_date('09-02-2009', 'dd-mm-yyyy'), to_date('23-02-2009', 'dd-mm-yyyy'), 4, 8507, to_date('15-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100316003465, to_date('16-03-2010', 'dd-mm-yyyy'), to_date('30-03-2010', 'dd-mm-yyyy'), 3, 5935, to_date('25-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101026003466, to_date('26-10-2010', 'dd-mm-yyyy'), to_date('09-11-2010', 'dd-mm-yyyy'), 9, 7092, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203003467, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 11, 3748, to_date('07-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104003468, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 12, 5143, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110518003469, to_date('18-05-2011', 'dd-mm-yyyy'), to_date('01-06-2011', 'dd-mm-yyyy'), 10, 9088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010203003470, to_date('03-02-2001', 'dd-mm-yyyy'), to_date('17-02-2001', 'dd-mm-yyyy'), 10, 3249, to_date('06-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124003471, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 3, 7118, to_date('13-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080616003472, to_date('16-06-2008', 'dd-mm-yyyy'), to_date('30-06-2008', 'dd-mm-yyyy'), 9, 6983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825003473, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 1, 2818, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131106003474, to_date('06-11-2013', 'dd-mm-yyyy'), to_date('20-11-2013', 'dd-mm-yyyy'), 10, 7790, to_date('12-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703003475, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 10, 3030, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830003476, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 4, 7032, to_date('11-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070915003477, to_date('15-09-2007', 'dd-mm-yyyy'), to_date('29-09-2007', 'dd-mm-yyyy'), 2, 5248, to_date('26-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100416003478, to_date('16-04-2010', 'dd-mm-yyyy'), to_date('30-04-2010', 'dd-mm-yyyy'), 2, 5968, to_date('27-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010301003479, to_date('01-03-2001', 'dd-mm-yyyy'), to_date('15-03-2001', 'dd-mm-yyyy'), 8, 4349, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000307003480, to_date('07-03-2000', 'dd-mm-yyyy'), to_date('21-03-2000', 'dd-mm-yyyy'), 2, 1462, to_date('20-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060731003481, to_date('31-07-2006', 'dd-mm-yyyy'), to_date('14-08-2006', 'dd-mm-yyyy'), 10, 4724, to_date('02-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010404003482, to_date('04-04-2001', 'dd-mm-yyyy'), to_date('18-04-2001', 'dd-mm-yyyy'), 5, 2173, to_date('21-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129003483, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 4, 4640, to_date('15-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010811003484, to_date('11-08-2001', 'dd-mm-yyyy'), to_date('25-08-2001', 'dd-mm-yyyy'), 6, 3777, to_date('16-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050101003485, to_date('01-01-2005', 'dd-mm-yyyy'), to_date('15-01-2005', 'dd-mm-yyyy'), 5, 5395, to_date('13-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110101003486, to_date('01-01-2011', 'dd-mm-yyyy'), to_date('15-01-2011', 'dd-mm-yyyy'), 4, 7198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001003487, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 1, 6238, to_date('05-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080126003488, to_date('26-01-2008', 'dd-mm-yyyy'), to_date('09-02-2008', 'dd-mm-yyyy'), 7, 4340, to_date('09-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016003489, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 11, 3950, to_date('22-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100704003490, to_date('04-07-2010', 'dd-mm-yyyy'), to_date('18-07-2010', 'dd-mm-yyyy'), 5, 6190, to_date('16-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202003491, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 12, 7911, to_date('07-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041002003492, to_date('02-10-2004', 'dd-mm-yyyy'), to_date('16-10-2004', 'dd-mm-yyyy'), 3, 3307, to_date('19-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030313003493, to_date('13-03-2003', 'dd-mm-yyyy'), to_date('27-03-2003', 'dd-mm-yyyy'), 3, 3096, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100613003494, to_date('13-06-2010', 'dd-mm-yyyy'), to_date('27-06-2010', 'dd-mm-yyyy'), 9, 8564, to_date('15-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020329003495, to_date('29-03-2002', 'dd-mm-yyyy'), to_date('12-04-2002', 'dd-mm-yyyy'), 2, 1606, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070908003496, to_date('08-09-2007', 'dd-mm-yyyy'), to_date('22-09-2007', 'dd-mm-yyyy'), 5, 4630, to_date('11-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110117003497, to_date('17-01-2011', 'dd-mm-yyyy'), to_date('31-01-2011', 'dd-mm-yyyy'), 10, 7712, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060306003498, to_date('06-03-2006', 'dd-mm-yyyy'), to_date('20-03-2006', 'dd-mm-yyyy'), 6, 5970, to_date('24-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011015003499, to_date('15-10-2001', 'dd-mm-yyyy'), to_date('29-10-2001', 'dd-mm-yyyy'), 3, 2827, to_date('18-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090628003500, to_date('28-06-2009', 'dd-mm-yyyy'), to_date('12-07-2009', 'dd-mm-yyyy'), 6, 5931, to_date('08-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060516003501, to_date('16-05-2006', 'dd-mm-yyyy'), to_date('30-05-2006', 'dd-mm-yyyy'), 6, 5327, to_date('28-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001128003502, to_date('28-11-2000', 'dd-mm-yyyy'), to_date('12-12-2000', 'dd-mm-yyyy'), 4, 1351, to_date('16-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130629003503, to_date('29-06-2013', 'dd-mm-yyyy'), to_date('13-07-2013', 'dd-mm-yyyy'), 11, 8423, to_date('18-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060427003504, to_date('27-04-2006', 'dd-mm-yyyy'), to_date('11-05-2006', 'dd-mm-yyyy'), 4, 4739, to_date('05-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207003505, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 5, 2710, to_date('26-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050114003506, to_date('14-01-2005', 'dd-mm-yyyy'), to_date('28-01-2005', 'dd-mm-yyyy'), 1, 4115, to_date('17-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030512003507, to_date('12-05-2003', 'dd-mm-yyyy'), to_date('26-05-2003', 'dd-mm-yyyy'), 3, 2329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426003508, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 7, 3070, to_date('28-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020319003509, to_date('19-03-2002', 'dd-mm-yyyy'), to_date('02-04-2002', 'dd-mm-yyyy'), 7, 3339, to_date('30-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040714003510, to_date('14-07-2004', 'dd-mm-yyyy'), to_date('28-07-2004', 'dd-mm-yyyy'), 4, 3755, to_date('31-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010120003511, to_date('20-01-2001', 'dd-mm-yyyy'), to_date('03-02-2001', 'dd-mm-yyyy'), 10, 3474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000908003512, to_date('08-09-2000', 'dd-mm-yyyy'), to_date('22-09-2000', 'dd-mm-yyyy'), 7, 2263, to_date('18-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000201003513, to_date('01-02-2000', 'dd-mm-yyyy'), to_date('15-02-2000', 'dd-mm-yyyy'), 8, 1848, to_date('07-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020106003514, to_date('06-01-2002', 'dd-mm-yyyy'), to_date('20-01-2002', 'dd-mm-yyyy'), 12, 3942, to_date('12-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010801003515, to_date('01-08-2001', 'dd-mm-yyyy'), to_date('15-08-2001', 'dd-mm-yyyy'), 11, 3578, to_date('03-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130405003516, to_date('05-04-2013', 'dd-mm-yyyy'), to_date('19-04-2013', 'dd-mm-yyyy'), 2, 9466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090717003517, to_date('17-07-2009', 'dd-mm-yyyy'), to_date('31-07-2009', 'dd-mm-yyyy'), 11, 4851, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100424003518, to_date('24-04-2010', 'dd-mm-yyyy'), to_date('08-05-2010', 'dd-mm-yyyy'), 4, 8159, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817003519, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 2, 5664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110920003520, to_date('20-09-2011', 'dd-mm-yyyy'), to_date('04-10-2011', 'dd-mm-yyyy'), 4, 7805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050201003521, to_date('01-02-2005', 'dd-mm-yyyy'), to_date('15-02-2005', 'dd-mm-yyyy'), 6, 3877, to_date('16-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000325003522, to_date('25-03-2000', 'dd-mm-yyyy'), to_date('08-04-2000', 'dd-mm-yyyy'), 4, 1673, to_date('08-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120518003523, to_date('18-05-2012', 'dd-mm-yyyy'), to_date('01-06-2012', 'dd-mm-yyyy'), 8, 6843, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120730003524, to_date('30-07-2012', 'dd-mm-yyyy'), to_date('13-08-2012', 'dd-mm-yyyy'), 6, 9105, to_date('17-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070811005661, to_date('11-08-2007', 'dd-mm-yyyy'), to_date('25-08-2007', 'dd-mm-yyyy'), 5, 6494, to_date('30-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100406005662, to_date('06-04-2010', 'dd-mm-yyyy'), to_date('20-04-2010', 'dd-mm-yyyy'), 5, 7906, to_date('26-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091027005663, to_date('27-10-2009', 'dd-mm-yyyy'), to_date('10-11-2009', 'dd-mm-yyyy'), 9, 6065, to_date('12-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070214005664, to_date('14-02-2007', 'dd-mm-yyyy'), to_date('28-02-2007', 'dd-mm-yyyy'), 6, 6172, to_date('21-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050213005665, to_date('13-02-2005', 'dd-mm-yyyy'), to_date('27-02-2005', 'dd-mm-yyyy'), 11, 3520, to_date('16-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215005666, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 6, 8776, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120104005667, to_date('04-01-2012', 'dd-mm-yyyy'), to_date('18-01-2012', 'dd-mm-yyyy'), 6, 13457, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207005668, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 1, 9133, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100709005669, to_date('09-07-2010', 'dd-mm-yyyy'), to_date('23-07-2010', 'dd-mm-yyyy'), 2, 7839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131018005670, to_date('18-10-2013', 'dd-mm-yyyy'), to_date('01-11-2013', 'dd-mm-yyyy'), 3, 6667, to_date('23-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201005671, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 11, 2809, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030912005672, to_date('12-09-2003', 'dd-mm-yyyy'), to_date('26-09-2003', 'dd-mm-yyyy'), 1, 4776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090915005673, to_date('15-09-2009', 'dd-mm-yyyy'), to_date('29-09-2009', 'dd-mm-yyyy'), 3, 6212, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111005674, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 3, 10770, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130416005675, to_date('16-04-2013', 'dd-mm-yyyy'), to_date('30-04-2013', 'dd-mm-yyyy'), 5, 11789, to_date('27-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128005676, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 6, 11386, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011027005677, to_date('27-10-2001', 'dd-mm-yyyy'), to_date('10-11-2001', 'dd-mm-yyyy'), 1, 1880, to_date('30-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030907005678, to_date('07-09-2003', 'dd-mm-yyyy'), to_date('21-09-2003', 'dd-mm-yyyy'), 8, 2546, to_date('13-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091102005679, to_date('02-11-2009', 'dd-mm-yyyy'), to_date('16-11-2009', 'dd-mm-yyyy'), 5, 7407, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060626005680, to_date('26-06-2006', 'dd-mm-yyyy'), to_date('10-07-2006', 'dd-mm-yyyy'), 8, 5766, to_date('01-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728005681, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 4, 6721, to_date('09-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040315005682, to_date('15-03-2004', 'dd-mm-yyyy'), to_date('29-03-2004', 'dd-mm-yyyy'), 4, 3652, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111010005683, to_date('10-10-2011', 'dd-mm-yyyy'), to_date('24-10-2011', 'dd-mm-yyyy'), 5, 8108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110420005684, to_date('20-04-2011', 'dd-mm-yyyy'), to_date('04-05-2011', 'dd-mm-yyyy'), 8, 7431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109005685, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 4, 10096, to_date('17-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001017005686, to_date('17-10-2000', 'dd-mm-yyyy'), to_date('31-10-2000', 'dd-mm-yyyy'), 7, 2558, to_date('31-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110424005687, to_date('24-04-2011', 'dd-mm-yyyy'), to_date('08-05-2011', 'dd-mm-yyyy'), 4, 8831, to_date('27-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100618005688, to_date('18-06-2010', 'dd-mm-yyyy'), to_date('02-07-2010', 'dd-mm-yyyy'), 1, 4870, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080223005689, to_date('23-02-2008', 'dd-mm-yyyy'), to_date('08-03-2008', 'dd-mm-yyyy'), 4, 7363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040902005690, to_date('02-09-2004', 'dd-mm-yyyy'), to_date('16-09-2004', 'dd-mm-yyyy'), 3, 4708, to_date('16-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060330005691, to_date('30-03-2006', 'dd-mm-yyyy'), to_date('13-04-2006', 'dd-mm-yyyy'), 1, 3698, to_date('08-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102005692, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 7, 1502, to_date('14-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031208005693, to_date('08-12-2003', 'dd-mm-yyyy'), to_date('22-12-2003', 'dd-mm-yyyy'), 9, 4284, to_date('26-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116005694, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 11, 7879, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226005695, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 4, 5118, to_date('30-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040505005696, to_date('05-05-2004', 'dd-mm-yyyy'), to_date('19-05-2004', 'dd-mm-yyyy'), 11, 4751, to_date('15-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121121005697, to_date('21-11-2012', 'dd-mm-yyyy'), to_date('05-12-2012', 'dd-mm-yyyy'), 1, 5667, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070115005698, to_date('15-01-2007', 'dd-mm-yyyy'), to_date('29-01-2007', 'dd-mm-yyyy'), 6, 4877, to_date('26-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110425005699, to_date('25-04-2011', 'dd-mm-yyyy'), to_date('09-05-2011', 'dd-mm-yyyy'), 3, 8457, to_date('28-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107005700, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 9, 8624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120207005701, to_date('07-02-2012', 'dd-mm-yyyy'), to_date('21-02-2012', 'dd-mm-yyyy'), 10, 7183, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100403005702, to_date('03-04-2010', 'dd-mm-yyyy'), to_date('17-04-2010', 'dd-mm-yyyy'), 4, 8319, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050519005703, to_date('19-05-2005', 'dd-mm-yyyy'), to_date('02-06-2005', 'dd-mm-yyyy'), 4, 3830, to_date('30-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123005704, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 4, 4538, to_date('26-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041106005705, to_date('06-11-2004', 'dd-mm-yyyy'), to_date('20-11-2004', 'dd-mm-yyyy'), 1, 5841, to_date('15-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050607005706, to_date('07-06-2005', 'dd-mm-yyyy'), to_date('21-06-2005', 'dd-mm-yyyy'), 8, 3233, to_date('17-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040329005707, to_date('29-03-2004', 'dd-mm-yyyy'), to_date('12-04-2004', 'dd-mm-yyyy'), 2, 5987, to_date('11-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100404005708, to_date('04-04-2010', 'dd-mm-yyyy'), to_date('18-04-2010', 'dd-mm-yyyy'), 5, 5383, to_date('13-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041102005709, to_date('02-11-2004', 'dd-mm-yyyy'), to_date('16-11-2004', 'dd-mm-yyyy'), 1, 4640, to_date('10-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040125005710, to_date('25-01-2004', 'dd-mm-yyyy'), to_date('08-02-2004', 'dd-mm-yyyy'), 6, 4118, to_date('29-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040612005711, to_date('12-06-2004', 'dd-mm-yyyy'), to_date('26-06-2004', 'dd-mm-yyyy'), 2, 2807, to_date('25-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030225005712, to_date('25-02-2003', 'dd-mm-yyyy'), to_date('11-03-2003', 'dd-mm-yyyy'), 2, 3041, to_date('15-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620005713, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 12, 7506, to_date('27-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090810005714, to_date('10-08-2009', 'dd-mm-yyyy'), to_date('24-08-2009', 'dd-mm-yyyy'), 10, 6766, to_date('29-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120324005715, to_date('24-03-2012', 'dd-mm-yyyy'), to_date('07-04-2012', 'dd-mm-yyyy'), 3, 9501, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921005716, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 6, 1845, to_date('11-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050822005717, to_date('22-08-2005', 'dd-mm-yyyy'), to_date('05-09-2005', 'dd-mm-yyyy'), 7, 4457, to_date('27-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220005718, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 10, 10259, to_date('08-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304005719, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 9, 5259, to_date('08-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201005720, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 6, 2339, to_date('20-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130122005721, to_date('22-01-2013', 'dd-mm-yyyy'), to_date('05-02-2013', 'dd-mm-yyyy'), 10, 6042, to_date('04-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031127005722, to_date('27-11-2003', 'dd-mm-yyyy'), to_date('11-12-2003', 'dd-mm-yyyy'), 10, 3259, to_date('29-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070803005723, to_date('03-08-2007', 'dd-mm-yyyy'), to_date('17-08-2007', 'dd-mm-yyyy'), 6, 3536, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110303005724, to_date('03-03-2011', 'dd-mm-yyyy'), to_date('17-03-2011', 'dd-mm-yyyy'), 2, 7553, to_date('23-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120005725, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 9, 5623, to_date('09-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100214005726, to_date('14-02-2010', 'dd-mm-yyyy'), to_date('28-02-2010', 'dd-mm-yyyy'), 6, 6783, to_date('24-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071023005727, to_date('23-10-2007', 'dd-mm-yyyy'), to_date('06-11-2007', 'dd-mm-yyyy'), 5, 3659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050210005728, to_date('10-02-2005', 'dd-mm-yyyy'), to_date('24-02-2005', 'dd-mm-yyyy'), 3, 4450, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051012005729, to_date('12-10-2005', 'dd-mm-yyyy'), to_date('26-10-2005', 'dd-mm-yyyy'), 6, 4447, to_date('24-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060211005730, to_date('11-02-2006', 'dd-mm-yyyy'), to_date('25-02-2006', 'dd-mm-yyyy'), 3, 4904, to_date('19-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725005731, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 7, 8713, to_date('11-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010509005732, to_date('09-05-2001', 'dd-mm-yyyy'), to_date('23-05-2001', 'dd-mm-yyyy'), 8, 2164, to_date('10-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010521005733, to_date('21-05-2001', 'dd-mm-yyyy'), to_date('04-06-2001', 'dd-mm-yyyy'), 11, 3135, to_date('24-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000203005734, to_date('03-02-2000', 'dd-mm-yyyy'), to_date('17-02-2000', 'dd-mm-yyyy'), 3, 1948, to_date('23-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204005735, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 6, 8368, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080312005736, to_date('12-03-2008', 'dd-mm-yyyy'), to_date('26-03-2008', 'dd-mm-yyyy'), 6, 6403, to_date('25-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706005737, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 11, 1957, to_date('17-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826005738, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 10, 3903, to_date('07-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426005739, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 10, 2456, to_date('04-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313005740, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 4, 4025, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215005741, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 6, 4028, to_date('04-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060201005742, to_date('01-02-2006', 'dd-mm-yyyy'), to_date('15-02-2006', 'dd-mm-yyyy'), 4, 3253, to_date('21-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080724005743, to_date('24-07-2008', 'dd-mm-yyyy'), to_date('07-08-2008', 'dd-mm-yyyy'), 6, 5568, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000616005744, to_date('16-06-2000', 'dd-mm-yyyy'), to_date('30-06-2000', 'dd-mm-yyyy'), 7, 2410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041215005745, to_date('15-12-2004', 'dd-mm-yyyy'), to_date('29-12-2004', 'dd-mm-yyyy'), 6, 4357, to_date('27-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716005746, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 7, 4173, to_date('29-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121224005747, to_date('24-12-2012', 'dd-mm-yyyy'), to_date('07-01-2013', 'dd-mm-yyyy'), 11, 8726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061108005748, to_date('08-11-2006', 'dd-mm-yyyy'), to_date('22-11-2006', 'dd-mm-yyyy'), 2, 3959, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917005749, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 7, 5709, to_date('30-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071204005750, to_date('04-12-2007', 'dd-mm-yyyy'), to_date('18-12-2007', 'dd-mm-yyyy'), 2, 5479, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000728005751, to_date('28-07-2000', 'dd-mm-yyyy'), to_date('11-08-2000', 'dd-mm-yyyy'), 7, 897, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020726005752, to_date('26-07-2002', 'dd-mm-yyyy'), to_date('09-08-2002', 'dd-mm-yyyy'), 3, 3582, to_date('09-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020805005753, to_date('05-08-2002', 'dd-mm-yyyy'), to_date('19-08-2002', 'dd-mm-yyyy'), 7, 2516, to_date('20-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070507005754, to_date('07-05-2007', 'dd-mm-yyyy'), to_date('21-05-2007', 'dd-mm-yyyy'), 11, 5781, to_date('26-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409005755, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 3, 2796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418005756, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 7, 6774, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121012005757, to_date('12-10-2012', 'dd-mm-yyyy'), to_date('26-10-2012', 'dd-mm-yyyy'), 6, 10830, to_date('15-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131120005758, to_date('20-11-2013', 'dd-mm-yyyy'), to_date('04-12-2013', 'dd-mm-yyyy'), 7, 6683, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020107005759, to_date('07-01-2002', 'dd-mm-yyyy'), to_date('21-01-2002', 'dd-mm-yyyy'), 10, 2363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011120005760, to_date('20-11-2001', 'dd-mm-yyyy'), to_date('04-12-2001', 'dd-mm-yyyy'), 8, 1679, to_date('02-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802005761, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 11, 1266, to_date('05-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100506005762, to_date('06-05-2010', 'dd-mm-yyyy'), to_date('20-05-2010', 'dd-mm-yyyy'), 7, 9352, to_date('22-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040208005763, to_date('08-02-2004', 'dd-mm-yyyy'), to_date('22-02-2004', 'dd-mm-yyyy'), 9, 3726, to_date('22-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080426005764, to_date('26-04-2008', 'dd-mm-yyyy'), to_date('10-05-2008', 'dd-mm-yyyy'), 2, 6480, to_date('06-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615005765, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 4, 6941, to_date('19-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040222005766, to_date('22-02-2004', 'dd-mm-yyyy'), to_date('07-03-2004', 'dd-mm-yyyy'), 8, 4331, to_date('07-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010601005767, to_date('01-06-2001', 'dd-mm-yyyy'), to_date('15-06-2001', 'dd-mm-yyyy'), 11, 4026, to_date('08-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020423005768, to_date('23-04-2002', 'dd-mm-yyyy'), to_date('07-05-2002', 'dd-mm-yyyy'), 2, 4468, to_date('27-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121129005769, to_date('29-11-2012', 'dd-mm-yyyy'), to_date('13-12-2012', 'dd-mm-yyyy'), 6, 8971, to_date('15-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090525005770, to_date('25-05-2009', 'dd-mm-yyyy'), to_date('08-06-2009', 'dd-mm-yyyy'), 10, 6729, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020518005771, to_date('18-05-2002', 'dd-mm-yyyy'), to_date('01-06-2002', 'dd-mm-yyyy'), 2, 2538, to_date('07-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060325005772, to_date('25-03-2006', 'dd-mm-yyyy'), to_date('08-04-2006', 'dd-mm-yyyy'), 10, 4178, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100414005773, to_date('14-04-2010', 'dd-mm-yyyy'), to_date('28-04-2010', 'dd-mm-yyyy'), 4, 7903, to_date('03-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020918005774, to_date('18-09-2002', 'dd-mm-yyyy'), to_date('02-10-2002', 'dd-mm-yyyy'), 11, 2740, to_date('23-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902005775, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 2, 4626, to_date('21-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213005776, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 5, 5748, to_date('14-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110005777, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 7, 8794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111029005778, to_date('29-10-2011', 'dd-mm-yyyy'), to_date('12-11-2011', 'dd-mm-yyyy'), 12, 6846, to_date('15-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110818005779, to_date('18-08-2011', 'dd-mm-yyyy'), to_date('01-09-2011', 'dd-mm-yyyy'), 11, 8145, to_date('03-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040402005780, to_date('02-04-2004', 'dd-mm-yyyy'), to_date('16-04-2004', 'dd-mm-yyyy'), 8, 4912, to_date('05-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040214005781, to_date('14-02-2004', 'dd-mm-yyyy'), to_date('28-02-2004', 'dd-mm-yyyy'), 5, 2695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100912005782, to_date('12-09-2010', 'dd-mm-yyyy'), to_date('26-09-2010', 'dd-mm-yyyy'), 6, 5359, to_date('16-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080617005783, to_date('17-06-2008', 'dd-mm-yyyy'), to_date('01-07-2008', 'dd-mm-yyyy'), 6, 5223, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302005784, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 2, 4425, to_date('15-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030127005785, to_date('27-01-2003', 'dd-mm-yyyy'), to_date('10-02-2003', 'dd-mm-yyyy'), 11, 3593, to_date('02-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802005786, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 6, 7156, to_date('22-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230005787, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 2, 1564, to_date('04-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217005788, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 10, 2119, to_date('25-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130523005789, to_date('23-05-2013', 'dd-mm-yyyy'), to_date('06-06-2013', 'dd-mm-yyyy'), 10, 10223, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081122005790, to_date('22-11-2008', 'dd-mm-yyyy'), to_date('06-12-2008', 'dd-mm-yyyy'), 10, 5990, to_date('06-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319005791, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 6, 5397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090413005792, to_date('13-04-2009', 'dd-mm-yyyy'), to_date('27-04-2009', 'dd-mm-yyyy'), 11, 8617, to_date('30-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001215005793, to_date('15-12-2000', 'dd-mm-yyyy'), to_date('29-12-2000', 'dd-mm-yyyy'), 7, 2036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080921005794, to_date('21-09-2008', 'dd-mm-yyyy'), to_date('05-10-2008', 'dd-mm-yyyy'), 5, 5263, to_date('06-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040125005795, to_date('25-01-2004', 'dd-mm-yyyy'), to_date('08-02-2004', 'dd-mm-yyyy'), 1, 2289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080417005796, to_date('17-04-2008', 'dd-mm-yyyy'), to_date('01-05-2008', 'dd-mm-yyyy'), 8, 6277, to_date('23-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101215005797, to_date('15-12-2010', 'dd-mm-yyyy'), to_date('29-12-2010', 'dd-mm-yyyy'), 8, 6608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130005798, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 9, 6565, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120405005799, to_date('05-04-2012', 'dd-mm-yyyy'), to_date('19-04-2012', 'dd-mm-yyyy'), 11, 7735, to_date('14-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110801005800, to_date('01-08-2011', 'dd-mm-yyyy'), to_date('15-08-2011', 'dd-mm-yyyy'), 7, 7329, to_date('19-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030524005801, to_date('24-05-2003', 'dd-mm-yyyy'), to_date('07-06-2003', 'dd-mm-yyyy'), 2, 3925, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426005802, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 12, 2141, to_date('16-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051005005803, to_date('05-10-2005', 'dd-mm-yyyy'), to_date('19-10-2005', 'dd-mm-yyyy'), 3, 3929, to_date('09-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627005804, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 9, 9681, to_date('30-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618005805, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 8, 5156, to_date('03-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031130005806, to_date('30-11-2003', 'dd-mm-yyyy'), to_date('14-12-2003', 'dd-mm-yyyy'), 1, 1768, to_date('03-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026005807, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 7, 6020, to_date('11-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100807005808, to_date('07-08-2010', 'dd-mm-yyyy'), to_date('21-08-2010', 'dd-mm-yyyy'), 6, 7261, to_date('24-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051017005809, to_date('17-10-2005', 'dd-mm-yyyy'), to_date('31-10-2005', 'dd-mm-yyyy'), 5, 4455, to_date('18-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131017005810, to_date('17-10-2013', 'dd-mm-yyyy'), to_date('31-10-2013', 'dd-mm-yyyy'), 11, 12629, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000312005811, to_date('12-03-2000', 'dd-mm-yyyy'), to_date('26-03-2000', 'dd-mm-yyyy'), 3, 1334, to_date('26-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912005812, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 11, 2853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130809005813, to_date('09-08-2013', 'dd-mm-yyyy'), to_date('23-08-2013', 'dd-mm-yyyy'), 7, 7028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713007957, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 3, 2355, to_date('23-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060726007958, to_date('26-07-2006', 'dd-mm-yyyy'), to_date('09-08-2006', 'dd-mm-yyyy'), 11, 5238, to_date('10-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000918007959, to_date('18-09-2000', 'dd-mm-yyyy'), to_date('02-10-2000', 'dd-mm-yyyy'), 10, 986, to_date('26-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130314007960, to_date('14-03-2013', 'dd-mm-yyyy'), to_date('28-03-2013', 'dd-mm-yyyy'), 7, 7489, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627007961, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 8, 6128, to_date('29-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000308007962, to_date('08-03-2000', 'dd-mm-yyyy'), to_date('22-03-2000', 'dd-mm-yyyy'), 11, 2876, to_date('23-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020408007963, to_date('08-04-2002', 'dd-mm-yyyy'), to_date('22-04-2002', 'dd-mm-yyyy'), 3, 4228, to_date('22-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121120007964, to_date('20-11-2012', 'dd-mm-yyyy'), to_date('04-12-2012', 'dd-mm-yyyy'), 8, 8357, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011005007965, to_date('05-10-2001', 'dd-mm-yyyy'), to_date('19-10-2001', 'dd-mm-yyyy'), 2, 2100, to_date('22-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080626007966, to_date('26-06-2008', 'dd-mm-yyyy'), to_date('10-07-2008', 'dd-mm-yyyy'), 7, 4560, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307007967, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 8, 9892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326007968, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 4, 6945, to_date('29-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051102007969, to_date('02-11-2005', 'dd-mm-yyyy'), to_date('16-11-2005', 'dd-mm-yyyy'), 11, 3673, to_date('14-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118007970, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 9, 1694, to_date('27-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131115007971, to_date('15-11-2013', 'dd-mm-yyyy'), to_date('29-11-2013', 'dd-mm-yyyy'), 3, 8031, to_date('02-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030621007972, to_date('21-06-2003', 'dd-mm-yyyy'), to_date('05-07-2003', 'dd-mm-yyyy'), 5, 2559, to_date('25-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111215007973, to_date('15-12-2011', 'dd-mm-yyyy'), to_date('29-12-2011', 'dd-mm-yyyy'), 10, 9246, to_date('31-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060412007974, to_date('12-04-2006', 'dd-mm-yyyy'), to_date('26-04-2006', 'dd-mm-yyyy'), 11, 4886, to_date('21-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022007975, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 8, 5068, to_date('24-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131024007976, to_date('24-10-2013', 'dd-mm-yyyy'), to_date('07-11-2013', 'dd-mm-yyyy'), 4, 10018, to_date('28-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080303007977, to_date('03-03-2008', 'dd-mm-yyyy'), to_date('17-03-2008', 'dd-mm-yyyy'), 6, 6871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021007978, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 2, 3739, to_date('29-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010109007979, to_date('09-01-2001', 'dd-mm-yyyy'), to_date('23-01-2001', 'dd-mm-yyyy'), 6, 1635, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811007980, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 3, 954, to_date('31-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060116007981, to_date('16-01-2006', 'dd-mm-yyyy'), to_date('30-01-2006', 'dd-mm-yyyy'), 8, 4354, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513007982, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 9, 7365, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031114007983, to_date('14-11-2003', 'dd-mm-yyyy'), to_date('28-11-2003', 'dd-mm-yyyy'), 11, 3847, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100706007984, to_date('06-07-2010', 'dd-mm-yyyy'), to_date('20-07-2010', 'dd-mm-yyyy'), 3, 8807, to_date('20-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110830007985, to_date('30-08-2011', 'dd-mm-yyyy'), to_date('13-09-2011', 'dd-mm-yyyy'), 11, 7915, to_date('11-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121029007986, to_date('29-10-2012', 'dd-mm-yyyy'), to_date('12-11-2012', 'dd-mm-yyyy'), 3, 10496, to_date('09-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020517007987, to_date('17-05-2002', 'dd-mm-yyyy'), to_date('31-05-2002', 'dd-mm-yyyy'), 3, 1946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120312007988, to_date('12-03-2012', 'dd-mm-yyyy'), to_date('26-03-2012', 'dd-mm-yyyy'), 5, 9507, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080425007989, to_date('25-04-2008', 'dd-mm-yyyy'), to_date('09-05-2008', 'dd-mm-yyyy'), 12, 6638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090914007990, to_date('14-09-2009', 'dd-mm-yyyy'), to_date('28-09-2009', 'dd-mm-yyyy'), 12, 6449, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070131007991, to_date('31-01-2007', 'dd-mm-yyyy'), to_date('14-02-2007', 'dd-mm-yyyy'), 6, 5409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051128007992, to_date('28-11-2005', 'dd-mm-yyyy'), to_date('12-12-2005', 'dd-mm-yyyy'), 11, 2545, to_date('06-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910007993, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 3, 5424, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050114007994, to_date('14-01-2005', 'dd-mm-yyyy'), to_date('28-01-2005', 'dd-mm-yyyy'), 2, 3836, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000220007995, to_date('20-02-2000', 'dd-mm-yyyy'), to_date('05-03-2000', 'dd-mm-yyyy'), 11, 1343, to_date('25-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070520007996, to_date('20-05-2007', 'dd-mm-yyyy'), to_date('03-06-2007', 'dd-mm-yyyy'), 3, 4969, to_date('31-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912007997, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 2, 5199, to_date('23-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050927007998, to_date('27-09-2005', 'dd-mm-yyyy'), to_date('11-10-2005', 'dd-mm-yyyy'), 8, 5747, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325007999, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 1, 2903, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019008000, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 1, 3887, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091028008001, to_date('28-10-2009', 'dd-mm-yyyy'), to_date('11-11-2009', 'dd-mm-yyyy'), 11, 5940, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071214008002, to_date('14-12-2007', 'dd-mm-yyyy'), to_date('28-12-2007', 'dd-mm-yyyy'), 4, 5757, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210008003, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 8, 5932, to_date('28-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130703008004, to_date('03-07-2013', 'dd-mm-yyyy'), to_date('17-07-2013', 'dd-mm-yyyy'), 3, 7950, to_date('07-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231008005, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 5, 6927, to_date('13-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521008006, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 9, 4459, to_date('08-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604008007, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 6, 8308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130008008, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 5, 9163, to_date('03-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080322008009, to_date('22-03-2008', 'dd-mm-yyyy'), to_date('05-04-2008', 'dd-mm-yyyy'), 7, 4784, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020916008010, to_date('16-09-2002', 'dd-mm-yyyy'), to_date('30-09-2002', 'dd-mm-yyyy'), 11, 2296, to_date('01-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051118008011, to_date('18-11-2005', 'dd-mm-yyyy'), to_date('02-12-2005', 'dd-mm-yyyy'), 7, 4535, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050924008012, to_date('24-09-2005', 'dd-mm-yyyy'), to_date('08-10-2005', 'dd-mm-yyyy'), 10, 5194, to_date('28-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707008013, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 3, 4592, to_date('13-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020711008014, to_date('11-07-2002', 'dd-mm-yyyy'), to_date('25-07-2002', 'dd-mm-yyyy'), 1, 2321, to_date('30-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030308008015, to_date('08-03-2003', 'dd-mm-yyyy'), to_date('22-03-2003', 'dd-mm-yyyy'), 7, 1989, to_date('23-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205008016, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 9, 4913, to_date('06-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050510008017, to_date('10-05-2005', 'dd-mm-yyyy'), to_date('24-05-2005', 'dd-mm-yyyy'), 5, 1987, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100419008018, to_date('19-04-2010', 'dd-mm-yyyy'), to_date('03-05-2010', 'dd-mm-yyyy'), 8, 8179, to_date('07-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101122008019, to_date('22-11-2010', 'dd-mm-yyyy'), to_date('06-12-2010', 'dd-mm-yyyy'), 8, 6736, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100419008020, to_date('19-04-2010', 'dd-mm-yyyy'), to_date('03-05-2010', 'dd-mm-yyyy'), 2, 7442, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060717008021, to_date('17-07-2006', 'dd-mm-yyyy'), to_date('31-07-2006', 'dd-mm-yyyy'), 3, 4078, to_date('26-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525008022, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 11, 4968, to_date('05-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111220008023, to_date('20-12-2011', 'dd-mm-yyyy'), to_date('03-01-2012', 'dd-mm-yyyy'), 5, 7055, to_date('21-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000914008024, to_date('14-09-2000', 'dd-mm-yyyy'), to_date('28-09-2000', 'dd-mm-yyyy'), 6, 3061, to_date('21-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604008025, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 11, 12011, to_date('19-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071108008026, to_date('08-11-2007', 'dd-mm-yyyy'), to_date('22-11-2007', 'dd-mm-yyyy'), 8, 5519, to_date('12-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001008027, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 9, 6742, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011111008028, to_date('11-11-2001', 'dd-mm-yyyy'), to_date('25-11-2001', 'dd-mm-yyyy'), 8, 1596, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011001008029, to_date('01-10-2001', 'dd-mm-yyyy'), to_date('15-10-2001', 'dd-mm-yyyy'), 5, 2181, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060805008030, to_date('05-08-2006', 'dd-mm-yyyy'), to_date('19-08-2006', 'dd-mm-yyyy'), 1, 5341, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120521008031, to_date('21-05-2012', 'dd-mm-yyyy'), to_date('04-06-2012', 'dd-mm-yyyy'), 8, 8293, to_date('08-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507008032, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 12, 9282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101109008033, to_date('09-11-2010', 'dd-mm-yyyy'), to_date('23-11-2010', 'dd-mm-yyyy'), 11, 9316, to_date('29-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090713008034, to_date('13-07-2009', 'dd-mm-yyyy'), to_date('27-07-2009', 'dd-mm-yyyy'), 7, 6489, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030411008035, to_date('11-04-2003', 'dd-mm-yyyy'), to_date('25-04-2003', 'dd-mm-yyyy'), 4, 2573, to_date('26-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120121008036, to_date('21-01-2012', 'dd-mm-yyyy'), to_date('04-02-2012', 'dd-mm-yyyy'), 2, 6168, to_date('10-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120602008037, to_date('02-06-2012', 'dd-mm-yyyy'), to_date('16-06-2012', 'dd-mm-yyyy'), 4, 9205, to_date('17-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060304008038, to_date('04-03-2006', 'dd-mm-yyyy'), to_date('18-03-2006', 'dd-mm-yyyy'), 11, 6880, to_date('09-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090519008039, to_date('19-05-2009', 'dd-mm-yyyy'), to_date('02-06-2009', 'dd-mm-yyyy'), 8, 6895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716008040, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 11, 5837, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050502008041, to_date('02-05-2005', 'dd-mm-yyyy'), to_date('16-05-2005', 'dd-mm-yyyy'), 10, 4134, to_date('21-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121115008042, to_date('15-11-2012', 'dd-mm-yyyy'), to_date('29-11-2012', 'dd-mm-yyyy'), 10, 8106, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040622008043, to_date('22-06-2004', 'dd-mm-yyyy'), to_date('06-07-2004', 'dd-mm-yyyy'), 2, 4132, to_date('27-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000310008044, to_date('10-03-2000', 'dd-mm-yyyy'), to_date('24-03-2000', 'dd-mm-yyyy'), 5, 1330, to_date('14-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802008045, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 3, 1773, to_date('15-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111008046, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 3, 2297, to_date('30-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111016008047, to_date('16-10-2011', 'dd-mm-yyyy'), to_date('30-10-2011', 'dd-mm-yyyy'), 2, 8801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120228008048, to_date('28-02-2012', 'dd-mm-yyyy'), to_date('13-03-2012', 'dd-mm-yyyy'), 11, 6466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090805008049, to_date('05-08-2009', 'dd-mm-yyyy'), to_date('19-08-2009', 'dd-mm-yyyy'), 3, 6316, to_date('17-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041009008050, to_date('09-10-2004', 'dd-mm-yyyy'), to_date('23-10-2004', 'dd-mm-yyyy'), 3, 3376, to_date('18-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021027008051, to_date('27-10-2002', 'dd-mm-yyyy'), to_date('10-11-2002', 'dd-mm-yyyy'), 7, 2131, to_date('03-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090402008052, to_date('02-04-2009', 'dd-mm-yyyy'), to_date('16-04-2009', 'dd-mm-yyyy'), 6, 7781, to_date('09-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030223008053, to_date('23-02-2003', 'dd-mm-yyyy'), to_date('09-03-2003', 'dd-mm-yyyy'), 5, 4499, to_date('12-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060320008054, to_date('20-03-2006', 'dd-mm-yyyy'), to_date('03-04-2006', 'dd-mm-yyyy'), 10, 6463, to_date('27-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020511008055, to_date('11-05-2002', 'dd-mm-yyyy'), to_date('25-05-2002', 'dd-mm-yyyy'), 3, 2724, to_date('17-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010705008056, to_date('05-07-2001', 'dd-mm-yyyy'), to_date('19-07-2001', 'dd-mm-yyyy'), 4, 3342, to_date('07-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031014008057, to_date('14-10-2003', 'dd-mm-yyyy'), to_date('28-10-2003', 'dd-mm-yyyy'), 2, 3385, to_date('25-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824008058, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 5, 3747, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060310008059, to_date('10-03-2006', 'dd-mm-yyyy'), to_date('24-03-2006', 'dd-mm-yyyy'), 7, 2420, to_date('28-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915008060, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 4, 7945, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228008061, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 3, 6085, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110008062, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 1, 2647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121117008063, to_date('17-11-2012', 'dd-mm-yyyy'), to_date('01-12-2012', 'dd-mm-yyyy'), 9, 9218, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020525008064, to_date('25-05-2002', 'dd-mm-yyyy'), to_date('08-06-2002', 'dd-mm-yyyy'), 7, 1607, to_date('14-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112008065, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 8, 2457, to_date('24-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050907008066, to_date('07-09-2005', 'dd-mm-yyyy'), to_date('21-09-2005', 'dd-mm-yyyy'), 2, 4711, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010828008067, to_date('28-08-2001', 'dd-mm-yyyy'), to_date('11-09-2001', 'dd-mm-yyyy'), 7, 2433, to_date('16-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120724008068, to_date('24-07-2012', 'dd-mm-yyyy'), to_date('07-08-2012', 'dd-mm-yyyy'), 11, 8582, to_date('29-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030619008069, to_date('19-06-2003', 'dd-mm-yyyy'), to_date('03-07-2003', 'dd-mm-yyyy'), 9, 2828, to_date('20-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070611008070, to_date('11-06-2007', 'dd-mm-yyyy'), to_date('25-06-2007', 'dd-mm-yyyy'), 12, 4488, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090406008071, to_date('06-04-2009', 'dd-mm-yyyy'), to_date('20-04-2009', 'dd-mm-yyyy'), 7, 5152, to_date('13-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020227008072, to_date('27-02-2002', 'dd-mm-yyyy'), to_date('13-03-2002', 'dd-mm-yyyy'), 8, 2257, to_date('12-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010218008073, to_date('18-02-2001', 'dd-mm-yyyy'), to_date('04-03-2001', 'dd-mm-yyyy'), 7, 2328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417008074, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 12, 6995, to_date('03-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011025008075, to_date('25-10-2001', 'dd-mm-yyyy'), to_date('08-11-2001', 'dd-mm-yyyy'), 10, 1743, to_date('11-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000917008076, to_date('17-09-2000', 'dd-mm-yyyy'), to_date('01-10-2000', 'dd-mm-yyyy'), 8, 2282, to_date('28-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011207008077, to_date('07-12-2001', 'dd-mm-yyyy'), to_date('21-12-2001', 'dd-mm-yyyy'), 5, 1449, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000819008078, to_date('19-08-2000', 'dd-mm-yyyy'), to_date('02-09-2000', 'dd-mm-yyyy'), 5, 3682, to_date('29-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100720008079, to_date('20-07-2010', 'dd-mm-yyyy'), to_date('03-08-2010', 'dd-mm-yyyy'), 9, 7608, to_date('26-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110817008080, to_date('17-08-2011', 'dd-mm-yyyy'), to_date('31-08-2011', 'dd-mm-yyyy'), 1, 6914, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120110008081, to_date('10-01-2012', 'dd-mm-yyyy'), to_date('24-01-2012', 'dd-mm-yyyy'), 2, 9916, to_date('30-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001216008082, to_date('16-12-2000', 'dd-mm-yyyy'), to_date('30-12-2000', 'dd-mm-yyyy'), 10, 1314, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926008083, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 9, 7398, to_date('05-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020425008084, to_date('25-04-2002', 'dd-mm-yyyy'), to_date('09-05-2002', 'dd-mm-yyyy'), 6, 846, to_date('09-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040613008085, to_date('13-06-2004', 'dd-mm-yyyy'), to_date('27-06-2004', 'dd-mm-yyyy'), 4, 3852, to_date('23-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002008086, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 9, 4450, to_date('10-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000131008087, to_date('31-01-2000', 'dd-mm-yyyy'), to_date('14-02-2000', 'dd-mm-yyyy'), 2, 2121, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120704008088, to_date('04-07-2012', 'dd-mm-yyyy'), to_date('18-07-2012', 'dd-mm-yyyy'), 8, 7212, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000222008089, to_date('22-02-2000', 'dd-mm-yyyy'), to_date('07-03-2000', 'dd-mm-yyyy'), 9, 3036, to_date('13-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070807008090, to_date('07-08-2007', 'dd-mm-yyyy'), to_date('21-08-2007', 'dd-mm-yyyy'), 7, 4411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100120008091, to_date('20-01-2010', 'dd-mm-yyyy'), to_date('03-02-2010', 'dd-mm-yyyy'), 8, 5599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030424008092, to_date('24-04-2003', 'dd-mm-yyyy'), to_date('08-05-2003', 'dd-mm-yyyy'), 4, 5318, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513008093, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 4, 5350, to_date('15-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081214008094, to_date('14-12-2008', 'dd-mm-yyyy'), to_date('28-12-2008', 'dd-mm-yyyy'), 3, 5624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031227008095, to_date('27-12-2003', 'dd-mm-yyyy'), to_date('10-01-2004', 'dd-mm-yyyy'), 8, 2898, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140109008096, to_date('09-01-2014', 'dd-mm-yyyy'), to_date('23-01-2014', 'dd-mm-yyyy'), 4, 10797, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021006008097, to_date('06-10-2002', 'dd-mm-yyyy'), to_date('20-10-2002', 'dd-mm-yyyy'), 8, 1797, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111031008098, to_date('31-10-2011', 'dd-mm-yyyy'), to_date('14-11-2011', 'dd-mm-yyyy'), 5, 4967, to_date('10-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001019008099, to_date('19-10-2000', 'dd-mm-yyyy'), to_date('02-11-2000', 'dd-mm-yyyy'), 7, 3302, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116008100, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 10, 4959, to_date('27-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071230008101, to_date('30-12-2007', 'dd-mm-yyyy'), to_date('13-01-2008', 'dd-mm-yyyy'), 5, 4924, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000508008102, to_date('08-05-2000', 'dd-mm-yyyy'), to_date('22-05-2000', 'dd-mm-yyyy'), 6, 2563, to_date('27-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040621008103, to_date('21-06-2004', 'dd-mm-yyyy'), to_date('05-07-2004', 'dd-mm-yyyy'), 10, 5432, to_date('29-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000204008104, to_date('04-02-2000', 'dd-mm-yyyy'), to_date('18-02-2000', 'dd-mm-yyyy'), 11, 1369, to_date('18-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717008105, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 5, 8436, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040522008106, to_date('22-05-2004', 'dd-mm-yyyy'), to_date('05-06-2004', 'dd-mm-yyyy'), 4, 2140, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000107008107, to_date('07-01-2000', 'dd-mm-yyyy'), to_date('21-01-2000', 'dd-mm-yyyy'), 10, 1366, to_date('22-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060614008108, to_date('14-06-2006', 'dd-mm-yyyy'), to_date('28-06-2006', 'dd-mm-yyyy'), 11, 3505, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080228008109, to_date('28-02-2008', 'dd-mm-yyyy'), to_date('13-03-2008', 'dd-mm-yyyy'), 6, 6737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304008110, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 11, 1646, to_date('17-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130101001069, to_date('01-01-2013', 'dd-mm-yyyy'), to_date('15-01-2013', 'dd-mm-yyyy'), 11, 7513, to_date('14-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020701001070, to_date('01-07-2002', 'dd-mm-yyyy'), to_date('15-07-2002', 'dd-mm-yyyy'), 6, 2835, to_date('16-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000818001071, to_date('18-08-2000', 'dd-mm-yyyy'), to_date('01-09-2000', 'dd-mm-yyyy'), 7, 2382, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050414001072, to_date('14-04-2005', 'dd-mm-yyyy'), to_date('28-04-2005', 'dd-mm-yyyy'), 3, 6352, to_date('23-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419001073, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 6, 4089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070818001074, to_date('18-08-2007', 'dd-mm-yyyy'), to_date('01-09-2007', 'dd-mm-yyyy'), 1, 4408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061104001075, to_date('04-11-2006', 'dd-mm-yyyy'), to_date('18-11-2006', 'dd-mm-yyyy'), 11, 3457, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120411001076, to_date('11-04-2012', 'dd-mm-yyyy'), to_date('25-04-2012', 'dd-mm-yyyy'), 6, 6619, to_date('19-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061209001077, to_date('09-12-2006', 'dd-mm-yyyy'), to_date('23-12-2006', 'dd-mm-yyyy'), 7, 3848, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070718001078, to_date('18-07-2007', 'dd-mm-yyyy'), to_date('01-08-2007', 'dd-mm-yyyy'), 12, 4331, to_date('03-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106001079, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 3, 7963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007001080, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 3, 2888, to_date('17-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080909001081, to_date('09-09-2008', 'dd-mm-yyyy'), to_date('23-09-2008', 'dd-mm-yyyy'), 1, 4731, to_date('13-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606001082, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 5, 3609, to_date('22-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010419001083, to_date('19-04-2001', 'dd-mm-yyyy'), to_date('03-05-2001', 'dd-mm-yyyy'), 12, 3381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110118001084, to_date('18-01-2011', 'dd-mm-yyyy'), to_date('01-02-2011', 'dd-mm-yyyy'), 8, 8014, to_date('29-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020927001085, to_date('27-09-2002', 'dd-mm-yyyy'), to_date('11-10-2002', 'dd-mm-yyyy'), 11, 2773, to_date('29-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110603001086, to_date('03-06-2011', 'dd-mm-yyyy'), to_date('17-06-2011', 'dd-mm-yyyy'), 6, 7061, to_date('11-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131214001087, to_date('14-12-2013', 'dd-mm-yyyy'), to_date('28-12-2013', 'dd-mm-yyyy'), 11, 7247, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080720001088, to_date('20-07-2008', 'dd-mm-yyyy'), to_date('03-08-2008', 'dd-mm-yyyy'), 5, 7165, to_date('02-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128001089, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 2, 6586, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222001090, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 3, 7997, to_date('05-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040427001091, to_date('27-04-2004', 'dd-mm-yyyy'), to_date('11-05-2004', 'dd-mm-yyyy'), 7, 3954, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081229001092, to_date('29-12-2008', 'dd-mm-yyyy'), to_date('12-01-2009', 'dd-mm-yyyy'), 7, 7095, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090615001093, to_date('15-06-2009', 'dd-mm-yyyy'), to_date('29-06-2009', 'dd-mm-yyyy'), 5, 5943, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040502001094, to_date('02-05-2004', 'dd-mm-yyyy'), to_date('16-05-2004', 'dd-mm-yyyy'), 11, 4188, to_date('05-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120429001095, to_date('29-04-2012', 'dd-mm-yyyy'), to_date('13-05-2012', 'dd-mm-yyyy'), 6, 9990, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121201001096, to_date('01-12-2012', 'dd-mm-yyyy'), to_date('15-12-2012', 'dd-mm-yyyy'), 11, 9095, to_date('16-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514001097, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 6, 6482, to_date('18-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100318001098, to_date('18-03-2010', 'dd-mm-yyyy'), to_date('01-04-2010', 'dd-mm-yyyy'), 7, 8201, to_date('02-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050729001099, to_date('29-07-2005', 'dd-mm-yyyy'), to_date('12-08-2005', 'dd-mm-yyyy'), 7, 2203, to_date('10-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041121001100, to_date('21-11-2004', 'dd-mm-yyyy'), to_date('05-12-2004', 'dd-mm-yyyy'), 9, 4022, to_date('24-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040318001101, to_date('18-03-2004', 'dd-mm-yyyy'), to_date('01-04-2004', 'dd-mm-yyyy'), 10, 2839, to_date('07-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903001102, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 10, 5790, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131001103, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 3, 5582, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130108001104, to_date('08-01-2013', 'dd-mm-yyyy'), to_date('22-01-2013', 'dd-mm-yyyy'), 8, 8076, to_date('15-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120322001105, to_date('22-03-2012', 'dd-mm-yyyy'), to_date('05-04-2012', 'dd-mm-yyyy'), 10, 7647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031230001106, to_date('30-12-2003', 'dd-mm-yyyy'), to_date('13-01-2004', 'dd-mm-yyyy'), 8, 2246, to_date('17-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070623001107, to_date('23-06-2007', 'dd-mm-yyyy'), to_date('07-07-2007', 'dd-mm-yyyy'), 5, 5255, to_date('07-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120001108, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 9, 8236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040607001109, to_date('07-06-2004', 'dd-mm-yyyy'), to_date('21-06-2004', 'dd-mm-yyyy'), 9, 4059, to_date('23-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060226001110, to_date('26-02-2006', 'dd-mm-yyyy'), to_date('12-03-2006', 'dd-mm-yyyy'), 9, 2766, to_date('14-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719001111, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 11, 2460, to_date('03-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809001112, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 3, 1453, to_date('21-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111112001113, to_date('12-11-2011', 'dd-mm-yyyy'), to_date('26-11-2011', 'dd-mm-yyyy'), 3, 7358, to_date('02-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140114001114, to_date('14-01-2014', 'dd-mm-yyyy'), to_date('28-01-2014', 'dd-mm-yyyy'), 9, 8570, to_date('17-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000803001115, to_date('03-08-2000', 'dd-mm-yyyy'), to_date('17-08-2000', 'dd-mm-yyyy'), 11, 1110, to_date('05-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050226001116, to_date('26-02-2005', 'dd-mm-yyyy'), to_date('12-03-2005', 'dd-mm-yyyy'), 8, 4103, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020830001117, to_date('30-08-2002', 'dd-mm-yyyy'), to_date('13-09-2002', 'dd-mm-yyyy'), 3, 2945, to_date('05-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131001118, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 3, 6217, to_date('05-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100426001119, to_date('26-04-2010', 'dd-mm-yyyy'), to_date('10-05-2010', 'dd-mm-yyyy'), 7, 8184, to_date('16-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120404001120, to_date('04-04-2012', 'dd-mm-yyyy'), to_date('18-04-2012', 'dd-mm-yyyy'), 9, 8619, to_date('10-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041102001121, to_date('02-11-2004', 'dd-mm-yyyy'), to_date('16-11-2004', 'dd-mm-yyyy'), 5, 4491, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110513001122, to_date('13-05-2011', 'dd-mm-yyyy'), to_date('27-05-2011', 'dd-mm-yyyy'), 2, 7966, to_date('20-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101209001123, to_date('09-12-2010', 'dd-mm-yyyy'), to_date('23-12-2010', 'dd-mm-yyyy'), 7, 6151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030117001124, to_date('17-01-2003', 'dd-mm-yyyy'), to_date('31-01-2003', 'dd-mm-yyyy'), 11, 3356, to_date('20-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026001125, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 7, 5753, to_date('14-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120327001126, to_date('27-03-2012', 'dd-mm-yyyy'), to_date('10-04-2012', 'dd-mm-yyyy'), 3, 9574, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041215001127, to_date('15-12-2004', 'dd-mm-yyyy'), to_date('29-12-2004', 'dd-mm-yyyy'), 9, 2710, to_date('26-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615001128, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 8, 5643, to_date('18-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103001129, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 3, 5334, to_date('14-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100314001130, to_date('14-03-2010', 'dd-mm-yyyy'), to_date('28-03-2010', 'dd-mm-yyyy'), 4, 8413, to_date('19-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131225001131, to_date('25-12-2013', 'dd-mm-yyyy'), to_date('08-01-2014', 'dd-mm-yyyy'), 3, 9031, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021128001132, to_date('28-11-2002', 'dd-mm-yyyy'), to_date('12-12-2002', 'dd-mm-yyyy'), 10, 3318, to_date('04-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023001133, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 4, 2883, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130730001134, to_date('30-07-2013', 'dd-mm-yyyy'), to_date('13-08-2013', 'dd-mm-yyyy'), 3, 10055, to_date('03-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804001135, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 10, 7936, to_date('24-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022001136, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 12, 5073, to_date('11-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061127001137, to_date('27-11-2006', 'dd-mm-yyyy'), to_date('11-12-2006', 'dd-mm-yyyy'), 7, 5662, to_date('08-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030530001138, to_date('30-05-2003', 'dd-mm-yyyy'), to_date('13-06-2003', 'dd-mm-yyyy'), 12, 3792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113001139, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 5, 3041, to_date('23-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050926001140, to_date('26-09-2005', 'dd-mm-yyyy'), to_date('10-10-2005', 'dd-mm-yyyy'), 9, 5144, to_date('16-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080517001141, to_date('17-05-2008', 'dd-mm-yyyy'), to_date('31-05-2008', 'dd-mm-yyyy'), 2, 6564, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120226001142, to_date('26-02-2012', 'dd-mm-yyyy'), to_date('11-03-2012', 'dd-mm-yyyy'), 11, 9742, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081105001143, to_date('05-11-2008', 'dd-mm-yyyy'), to_date('19-11-2008', 'dd-mm-yyyy'), 4, 7998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120611001144, to_date('11-06-2012', 'dd-mm-yyyy'), to_date('25-06-2012', 'dd-mm-yyyy'), 12, 9691, to_date('24-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071113001145, to_date('13-11-2007', 'dd-mm-yyyy'), to_date('27-11-2007', 'dd-mm-yyyy'), 6, 5231, to_date('24-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110822001146, to_date('22-08-2011', 'dd-mm-yyyy'), to_date('05-09-2011', 'dd-mm-yyyy'), 11, 8650, to_date('01-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727001147, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 4, 1611, to_date('12-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091113001148, to_date('13-11-2009', 'dd-mm-yyyy'), to_date('27-11-2009', 'dd-mm-yyyy'), 9, 6860, to_date('25-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205001149, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 5, 5620, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703001150, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 2, 1677, to_date('11-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120321001151, to_date('21-03-2012', 'dd-mm-yyyy'), to_date('04-04-2012', 'dd-mm-yyyy'), 10, 6763, to_date('26-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040520001152, to_date('20-05-2004', 'dd-mm-yyyy'), to_date('03-06-2004', 'dd-mm-yyyy'), 11, 5150, to_date('03-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020325001153, to_date('25-03-2002', 'dd-mm-yyyy'), to_date('08-04-2002', 'dd-mm-yyyy'), 9, 2891, to_date('12-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031121001154, to_date('21-11-2003', 'dd-mm-yyyy'), to_date('05-12-2003', 'dd-mm-yyyy'), 12, 2939, to_date('27-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227001155, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 7, 2658, to_date('03-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917001156, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 9, 5691, to_date('28-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030224001157, to_date('24-02-2003', 'dd-mm-yyyy'), to_date('10-03-2003', 'dd-mm-yyyy'), 8, 3559, to_date('10-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090905001158, to_date('05-09-2009', 'dd-mm-yyyy'), to_date('19-09-2009', 'dd-mm-yyyy'), 4, 7449, to_date('25-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050726001159, to_date('26-07-2005', 'dd-mm-yyyy'), to_date('09-08-2005', 'dd-mm-yyyy'), 3, 5267, to_date('01-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019001160, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 5, 8917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130716001161, to_date('16-07-2013', 'dd-mm-yyyy'), to_date('30-07-2013', 'dd-mm-yyyy'), 4, 8686, to_date('26-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001215001162, to_date('15-12-2000', 'dd-mm-yyyy'), to_date('29-12-2000', 'dd-mm-yyyy'), 3, 2330, to_date('26-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203001163, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 6, 3452, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140516001164, to_date('16-05-2014', 'dd-mm-yyyy'), to_date('30-05-2014', 'dd-mm-yyyy'), 9, 8203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000520001165, to_date('20-05-2000', 'dd-mm-yyyy'), to_date('03-06-2000', 'dd-mm-yyyy'), 10, 2001, to_date('02-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081030001166, to_date('30-10-2008', 'dd-mm-yyyy'), to_date('13-11-2008', 'dd-mm-yyyy'), 7, 8877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121110001167, to_date('10-11-2012', 'dd-mm-yyyy'), to_date('24-11-2012', 'dd-mm-yyyy'), 5, 8146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010204001168, to_date('04-02-2001', 'dd-mm-yyyy'), to_date('18-02-2001', 'dd-mm-yyyy'), 7, 3516, to_date('21-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090316001169, to_date('16-03-2009', 'dd-mm-yyyy'), to_date('30-03-2009', 'dd-mm-yyyy'), 10, 7970, to_date('04-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050921001170, to_date('21-09-2005', 'dd-mm-yyyy'), to_date('05-10-2005', 'dd-mm-yyyy'), 1, 5026, to_date('22-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020323001171, to_date('23-03-2002', 'dd-mm-yyyy'), to_date('06-04-2002', 'dd-mm-yyyy'), 10, 4071, to_date('04-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000306001172, to_date('06-03-2000', 'dd-mm-yyyy'), to_date('20-03-2000', 'dd-mm-yyyy'), 4, 1523, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003001173, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 7, 7582, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021209001174, to_date('09-12-2002', 'dd-mm-yyyy'), to_date('23-12-2002', 'dd-mm-yyyy'), 1, 2695, to_date('19-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020704001175, to_date('04-07-2002', 'dd-mm-yyyy'), to_date('18-07-2002', 'dd-mm-yyyy'), 9, 2764, to_date('18-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628001176, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 11, 8886, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020001177, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 5, 5217, to_date('05-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120808001178, to_date('08-08-2012', 'dd-mm-yyyy'), to_date('22-08-2012', 'dd-mm-yyyy'), 5, 8605, to_date('16-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080801001179, to_date('01-08-2008', 'dd-mm-yyyy'), to_date('15-08-2008', 'dd-mm-yyyy'), 8, 5354, to_date('11-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130224001180, to_date('24-02-2013', 'dd-mm-yyyy'), to_date('10-03-2013', 'dd-mm-yyyy'), 5, 7144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040708001181, to_date('08-07-2004', 'dd-mm-yyyy'), to_date('22-07-2004', 'dd-mm-yyyy'), 11, 3568, to_date('14-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131221001182, to_date('21-12-2013', 'dd-mm-yyyy'), to_date('04-01-2014', 'dd-mm-yyyy'), 2, 9250, to_date('30-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110124001183, to_date('24-01-2011', 'dd-mm-yyyy'), to_date('07-02-2011', 'dd-mm-yyyy'), 8, 7302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101122001184, to_date('22-11-2010', 'dd-mm-yyyy'), to_date('06-12-2010', 'dd-mm-yyyy'), 2, 5621, to_date('25-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070105001185, to_date('05-01-2007', 'dd-mm-yyyy'), to_date('19-01-2007', 'dd-mm-yyyy'), 1, 8115, to_date('24-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070404001186, to_date('04-04-2007', 'dd-mm-yyyy'), to_date('18-04-2007', 'dd-mm-yyyy'), 11, 4873, to_date('05-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225001187, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 12, 1548, to_date('03-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801001188, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 4, 8119, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031225001189, to_date('25-12-2003', 'dd-mm-yyyy'), to_date('08-01-2004', 'dd-mm-yyyy'), 5, 2561, to_date('13-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100206001190, to_date('06-02-2010', 'dd-mm-yyyy'), to_date('20-02-2010', 'dd-mm-yyyy'), 10, 6593, to_date('19-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010404001191, to_date('04-04-2001', 'dd-mm-yyyy'), to_date('18-04-2001', 'dd-mm-yyyy'), 7, 1101, to_date('16-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511001192, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 5, 3947, to_date('31-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120001193, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 2, 5474, to_date('08-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120519001194, to_date('19-05-2012', 'dd-mm-yyyy'), to_date('02-06-2012', 'dd-mm-yyyy'), 12, 11721, to_date('27-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205001195, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 9, 2831, to_date('21-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220001196, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 9, 8175, to_date('05-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622001197, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 8, 6084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050627001198, to_date('27-06-2005', 'dd-mm-yyyy'), to_date('11-07-2005', 'dd-mm-yyyy'), 5, 5586, to_date('15-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011107001199, to_date('07-11-2001', 'dd-mm-yyyy'), to_date('21-11-2001', 'dd-mm-yyyy'), 6, 1371, to_date('18-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213001200, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 1, 6200, to_date('15-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060503001201, to_date('03-05-2006', 'dd-mm-yyyy'), to_date('17-05-2006', 'dd-mm-yyyy'), 9, 4864, to_date('22-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010821001202, to_date('21-08-2001', 'dd-mm-yyyy'), to_date('04-09-2001', 'dd-mm-yyyy'), 6, 2307, to_date('02-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060817001203, to_date('17-08-2006', 'dd-mm-yyyy'), to_date('31-08-2006', 'dd-mm-yyyy'), 3, 7222, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100510001204, to_date('10-05-2010', 'dd-mm-yyyy'), to_date('24-05-2010', 'dd-mm-yyyy'), 12, 6742, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051029001205, to_date('29-10-2005', 'dd-mm-yyyy'), to_date('12-11-2005', 'dd-mm-yyyy'), 3, 3543, to_date('16-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921001206, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 7, 6391, to_date('01-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050621001207, to_date('21-06-2005', 'dd-mm-yyyy'), to_date('05-07-2005', 'dd-mm-yyyy'), 2, 4634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050505001208, to_date('05-05-2005', 'dd-mm-yyyy'), to_date('19-05-2005', 'dd-mm-yyyy'), 11, 3482, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010221001209, to_date('21-02-2001', 'dd-mm-yyyy'), to_date('07-03-2001', 'dd-mm-yyyy'), 7, 4999, to_date('06-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430001210, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 5, 5743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070531001211, to_date('31-05-2007', 'dd-mm-yyyy'), to_date('14-06-2007', 'dd-mm-yyyy'), 6, 6376, to_date('02-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130001212, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 11, 6687, to_date('16-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040510001213, to_date('10-05-2004', 'dd-mm-yyyy'), to_date('24-05-2004', 'dd-mm-yyyy'), 10, 3112, to_date('13-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070402001214, to_date('02-04-2007', 'dd-mm-yyyy'), to_date('16-04-2007', 'dd-mm-yyyy'), 11, 7003, to_date('19-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060625001215, to_date('25-06-2006', 'dd-mm-yyyy'), to_date('09-07-2006', 'dd-mm-yyyy'), 6, 4859, to_date('05-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601001216, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 8, 6023, to_date('09-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061217001217, to_date('17-12-2006', 'dd-mm-yyyy'), to_date('31-12-2006', 'dd-mm-yyyy'), 6, 4890, to_date('22-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060310001218, to_date('10-03-2006', 'dd-mm-yyyy'), to_date('24-03-2006', 'dd-mm-yyyy'), 5, 6436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080807001219, to_date('07-08-2008', 'dd-mm-yyyy'), to_date('21-08-2008', 'dd-mm-yyyy'), 9, 6458, to_date('25-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090111001220, to_date('11-01-2009', 'dd-mm-yyyy'), to_date('25-01-2009', 'dd-mm-yyyy'), 7, 6186, to_date('13-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070519001221, to_date('19-05-2007', 'dd-mm-yyyy'), to_date('02-06-2007', 'dd-mm-yyyy'), 3, 7010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050926003525, to_date('26-09-2005', 'dd-mm-yyyy'), to_date('10-10-2005', 'dd-mm-yyyy'), 9, 4978, to_date('14-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214003526, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 6, 6722, to_date('25-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110506003527, to_date('06-05-2011', 'dd-mm-yyyy'), to_date('20-05-2011', 'dd-mm-yyyy'), 11, 6809, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060822003528, to_date('22-08-2006', 'dd-mm-yyyy'), to_date('05-09-2006', 'dd-mm-yyyy'), 5, 5565, to_date('09-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070501003529, to_date('01-05-2007', 'dd-mm-yyyy'), to_date('15-05-2007', 'dd-mm-yyyy'), 11, 3484, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020806003530, to_date('06-08-2002', 'dd-mm-yyyy'), to_date('20-08-2002', 'dd-mm-yyyy'), 9, 2469, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402003531, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 2, 10802, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714003532, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 4, 5949, to_date('19-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010904003533, to_date('04-09-2001', 'dd-mm-yyyy'), to_date('18-09-2001', 'dd-mm-yyyy'), 11, 2263, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050416003534, to_date('16-04-2005', 'dd-mm-yyyy'), to_date('30-04-2005', 'dd-mm-yyyy'), 10, 4219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000403003535, to_date('03-04-2000', 'dd-mm-yyyy'), to_date('17-04-2000', 'dd-mm-yyyy'), 8, 2825, to_date('11-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020503003536, to_date('03-05-2002', 'dd-mm-yyyy'), to_date('17-05-2002', 'dd-mm-yyyy'), 7, 3317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130225003537, to_date('25-02-2013', 'dd-mm-yyyy'), to_date('11-03-2013', 'dd-mm-yyyy'), 8, 8908, to_date('15-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060523003538, to_date('23-05-2006', 'dd-mm-yyyy'), to_date('06-06-2006', 'dd-mm-yyyy'), 7, 3968, to_date('05-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020817003539, to_date('17-08-2002', 'dd-mm-yyyy'), to_date('31-08-2002', 'dd-mm-yyyy'), 12, 3079, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000301003540, to_date('01-03-2000', 'dd-mm-yyyy'), to_date('15-03-2000', 'dd-mm-yyyy'), 3, 2417, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120425003541, to_date('25-04-2012', 'dd-mm-yyyy'), to_date('09-05-2012', 'dd-mm-yyyy'), 9, 6906, to_date('05-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040204003542, to_date('04-02-2004', 'dd-mm-yyyy'), to_date('18-02-2004', 'dd-mm-yyyy'), 6, 4042, to_date('13-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130416003543, to_date('16-04-2013', 'dd-mm-yyyy'), to_date('30-04-2013', 'dd-mm-yyyy'), 6, 10852, to_date('05-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040714003544, to_date('14-07-2004', 'dd-mm-yyyy'), to_date('28-07-2004', 'dd-mm-yyyy'), 2, 3196, to_date('26-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011003545, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 6, 5054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070304003546, to_date('04-03-2007', 'dd-mm-yyyy'), to_date('18-03-2007', 'dd-mm-yyyy'), 2, 4536, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030816003547, to_date('16-08-2003', 'dd-mm-yyyy'), to_date('30-08-2003', 'dd-mm-yyyy'), 9, 5075, to_date('19-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130003548, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 2, 4598, to_date('04-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120417003549, to_date('17-04-2012', 'dd-mm-yyyy'), to_date('01-05-2012', 'dd-mm-yyyy'), 2, 5711, to_date('27-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010528003550, to_date('28-05-2001', 'dd-mm-yyyy'), to_date('11-06-2001', 'dd-mm-yyyy'), 6, 2154, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331003551, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 11, 4575, to_date('12-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100101003552, to_date('01-01-2010', 'dd-mm-yyyy'), to_date('15-01-2010', 'dd-mm-yyyy'), 11, 6892, to_date('08-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106003553, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 5, 10569, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020320003554, to_date('20-03-2002', 'dd-mm-yyyy'), to_date('03-04-2002', 'dd-mm-yyyy'), 9, 3698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503003555, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 12, 3485, to_date('10-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205003556, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 8, 3961, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010923003557, to_date('23-09-2001', 'dd-mm-yyyy'), to_date('07-10-2001', 'dd-mm-yyyy'), 10, 1799, to_date('10-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080818003558, to_date('18-08-2008', 'dd-mm-yyyy'), to_date('01-09-2008', 'dd-mm-yyyy'), 1, 7279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061028003559, to_date('28-10-2006', 'dd-mm-yyyy'), to_date('11-11-2006', 'dd-mm-yyyy'), 11, 5852, to_date('01-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070219003560, to_date('19-02-2007', 'dd-mm-yyyy'), to_date('05-03-2007', 'dd-mm-yyyy'), 3, 5590, to_date('04-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090209003561, to_date('09-02-2009', 'dd-mm-yyyy'), to_date('23-02-2009', 'dd-mm-yyyy'), 11, 7370, to_date('28-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091227003562, to_date('27-12-2009', 'dd-mm-yyyy'), to_date('10-01-2010', 'dd-mm-yyyy'), 1, 6125, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140118003563, to_date('18-01-2014', 'dd-mm-yyyy'), to_date('01-02-2014', 'dd-mm-yyyy'), 3, 9251, to_date('02-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010413003564, to_date('13-04-2001', 'dd-mm-yyyy'), to_date('27-04-2001', 'dd-mm-yyyy'), 5, 3515, to_date('01-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910003565, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 6, 4920, to_date('27-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217003566, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 8, 9074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070430003567, to_date('30-04-2007', 'dd-mm-yyyy'), to_date('14-05-2007', 'dd-mm-yyyy'), 1, 2981, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081003003568, to_date('03-10-2008', 'dd-mm-yyyy'), to_date('17-10-2008', 'dd-mm-yyyy'), 10, 5829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030115003569, to_date('15-01-2003', 'dd-mm-yyyy'), to_date('29-01-2003', 'dd-mm-yyyy'), 7, 3858, to_date('31-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050516003570, to_date('16-05-2005', 'dd-mm-yyyy'), to_date('30-05-2005', 'dd-mm-yyyy'), 6, 5776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060426003571, to_date('26-04-2006', 'dd-mm-yyyy'), to_date('10-05-2006', 'dd-mm-yyyy'), 10, 3606, to_date('16-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130405003572, to_date('05-04-2013', 'dd-mm-yyyy'), to_date('19-04-2013', 'dd-mm-yyyy'), 8, 8516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020707003573, to_date('07-07-2002', 'dd-mm-yyyy'), to_date('21-07-2002', 'dd-mm-yyyy'), 2, 2661, to_date('14-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030108003574, to_date('08-01-2003', 'dd-mm-yyyy'), to_date('22-01-2003', 'dd-mm-yyyy'), 3, 4124, to_date('15-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131116003575, to_date('16-11-2013', 'dd-mm-yyyy'), to_date('30-11-2013', 'dd-mm-yyyy'), 5, 9050, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130423003576, to_date('23-04-2013', 'dd-mm-yyyy'), to_date('07-05-2013', 'dd-mm-yyyy'), 8, 6701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091017003577, to_date('17-10-2009', 'dd-mm-yyyy'), to_date('31-10-2009', 'dd-mm-yyyy'), 5, 8869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140120003578, to_date('20-01-2014', 'dd-mm-yyyy'), to_date('03-02-2014', 'dd-mm-yyyy'), 4, 7884, to_date('24-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080109003579, to_date('09-01-2008', 'dd-mm-yyyy'), to_date('23-01-2008', 'dd-mm-yyyy'), 1, 6717, to_date('28-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040707003580, to_date('07-07-2004', 'dd-mm-yyyy'), to_date('21-07-2004', 'dd-mm-yyyy'), 10, 3364, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080207003581, to_date('07-02-2008', 'dd-mm-yyyy'), to_date('21-02-2008', 'dd-mm-yyyy'), 9, 4105, to_date('16-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130711003582, to_date('11-07-2013', 'dd-mm-yyyy'), to_date('25-07-2013', 'dd-mm-yyyy'), 5, 8960, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080713003583, to_date('13-07-2008', 'dd-mm-yyyy'), to_date('27-07-2008', 'dd-mm-yyyy'), 7, 8273, to_date('17-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120426003584, to_date('26-04-2012', 'dd-mm-yyyy'), to_date('10-05-2012', 'dd-mm-yyyy'), 4, 8086, to_date('30-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120917003585, to_date('17-09-2012', 'dd-mm-yyyy'), to_date('01-10-2012', 'dd-mm-yyyy'), 5, 7568, to_date('19-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911003586, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 2, 8879, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140206003587, to_date('06-02-2014', 'dd-mm-yyyy'), to_date('20-02-2014', 'dd-mm-yyyy'), 5, 11534, to_date('11-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715003588, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 5, 1878, to_date('19-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090924003589, to_date('24-09-2009', 'dd-mm-yyyy'), to_date('08-10-2009', 'dd-mm-yyyy'), 5, 5162, to_date('02-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140310003590, to_date('10-03-2014', 'dd-mm-yyyy'), to_date('24-03-2014', 'dd-mm-yyyy'), 2, 6336, to_date('30-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823003591, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 5, 7526, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115003592, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 4, 6852, to_date('05-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030930003593, to_date('30-09-2003', 'dd-mm-yyyy'), to_date('14-10-2003', 'dd-mm-yyyy'), 7, 3149, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927003594, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 11, 8902, to_date('06-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011019003595, to_date('19-10-2001', 'dd-mm-yyyy'), to_date('02-11-2001', 'dd-mm-yyyy'), 4, 3992, to_date('04-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061214003596, to_date('14-12-2006', 'dd-mm-yyyy'), to_date('28-12-2006', 'dd-mm-yyyy'), 2, 4565, to_date('21-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811003597, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 4, 1372, to_date('13-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000503003598, to_date('03-05-2000', 'dd-mm-yyyy'), to_date('17-05-2000', 'dd-mm-yyyy'), 10, 1439, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205003599, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 6, 5612, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100129003600, to_date('29-01-2010', 'dd-mm-yyyy'), to_date('12-02-2010', 'dd-mm-yyyy'), 4, 7081, to_date('10-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010920003601, to_date('20-09-2001', 'dd-mm-yyyy'), to_date('04-10-2001', 'dd-mm-yyyy'), 11, 3348, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001206003602, to_date('06-12-2000', 'dd-mm-yyyy'), to_date('20-12-2000', 'dd-mm-yyyy'), 8, 1022, to_date('13-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061102003603, to_date('02-11-2006', 'dd-mm-yyyy'), to_date('16-11-2006', 'dd-mm-yyyy'), 10, 4629, to_date('15-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080630003604, to_date('30-06-2008', 'dd-mm-yyyy'), to_date('14-07-2008', 'dd-mm-yyyy'), 9, 6201, to_date('18-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040215003605, to_date('15-02-2004', 'dd-mm-yyyy'), to_date('29-02-2004', 'dd-mm-yyyy'), 5, 4420, to_date('19-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723003606, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 6, 3681, to_date('12-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000904003607, to_date('04-09-2000', 'dd-mm-yyyy'), to_date('18-09-2000', 'dd-mm-yyyy'), 2, 3142, to_date('16-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108003608, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 11, 3972, to_date('21-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817003609, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 6, 6468, to_date('19-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030712003610, to_date('12-07-2003', 'dd-mm-yyyy'), to_date('26-07-2003', 'dd-mm-yyyy'), 9, 3734, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051214003611, to_date('14-12-2005', 'dd-mm-yyyy'), to_date('28-12-2005', 'dd-mm-yyyy'), 9, 4385, to_date('21-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051012003612, to_date('12-10-2005', 'dd-mm-yyyy'), to_date('26-10-2005', 'dd-mm-yyyy'), 11, 4016, to_date('23-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140306003613, to_date('06-03-2014', 'dd-mm-yyyy'), to_date('20-03-2014', 'dd-mm-yyyy'), 4, 13410, to_date('08-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041018003614, to_date('18-10-2004', 'dd-mm-yyyy'), to_date('01-11-2004', 'dd-mm-yyyy'), 7, 2795, to_date('29-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110814003615, to_date('14-08-2011', 'dd-mm-yyyy'), to_date('28-08-2011', 'dd-mm-yyyy'), 5, 8146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111012003616, to_date('12-10-2011', 'dd-mm-yyyy'), to_date('26-10-2011', 'dd-mm-yyyy'), 9, 7016, to_date('17-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231003617, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 4, 8002, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120003618, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 8, 2316, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060724003619, to_date('24-07-2006', 'dd-mm-yyyy'), to_date('07-08-2006', 'dd-mm-yyyy'), 7, 4573, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020422003620, to_date('22-04-2002', 'dd-mm-yyyy'), to_date('06-05-2002', 'dd-mm-yyyy'), 7, 1358, to_date('23-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040615003621, to_date('15-06-2004', 'dd-mm-yyyy'), to_date('29-06-2004', 'dd-mm-yyyy'), 3, 3757, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061110003622, to_date('10-11-2006', 'dd-mm-yyyy'), to_date('24-11-2006', 'dd-mm-yyyy'), 6, 3633, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050316003623, to_date('16-03-2005', 'dd-mm-yyyy'), to_date('30-03-2005', 'dd-mm-yyyy'), 9, 2856, to_date('22-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020426003624, to_date('26-04-2002', 'dd-mm-yyyy'), to_date('10-05-2002', 'dd-mm-yyyy'), 1, 2225, to_date('09-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071026003625, to_date('26-10-2007', 'dd-mm-yyyy'), to_date('09-11-2007', 'dd-mm-yyyy'), 6, 4899, to_date('29-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130701003626, to_date('01-07-2013', 'dd-mm-yyyy'), to_date('15-07-2013', 'dd-mm-yyyy'), 6, 8898, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021002003627, to_date('02-10-2002', 'dd-mm-yyyy'), to_date('16-10-2002', 'dd-mm-yyyy'), 8, 2195, to_date('19-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031111003628, to_date('11-11-2003', 'dd-mm-yyyy'), to_date('25-11-2003', 'dd-mm-yyyy'), 2, 4682, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071217003629, to_date('17-12-2007', 'dd-mm-yyyy'), to_date('31-12-2007', 'dd-mm-yyyy'), 4, 7268, to_date('31-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060731003630, to_date('31-07-2006', 'dd-mm-yyyy'), to_date('14-08-2006', 'dd-mm-yyyy'), 8, 5497, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104003631, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 7, 3088, to_date('18-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215003632, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 10, 6284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000413003633, to_date('13-04-2000', 'dd-mm-yyyy'), to_date('27-04-2000', 'dd-mm-yyyy'), 7, 2002, to_date('25-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707003634, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 9, 6640, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090306003635, to_date('06-03-2009', 'dd-mm-yyyy'), to_date('20-03-2009', 'dd-mm-yyyy'), 5, 6521, to_date('15-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216003636, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 6, 3055, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529003637, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 10, 10282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101013003638, to_date('13-10-2010', 'dd-mm-yyyy'), to_date('27-10-2010', 'dd-mm-yyyy'), 12, 6426, to_date('28-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120523003639, to_date('23-05-2012', 'dd-mm-yyyy'), to_date('06-06-2012', 'dd-mm-yyyy'), 2, 7034, to_date('30-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040701003640, to_date('01-07-2004', 'dd-mm-yyyy'), to_date('15-07-2004', 'dd-mm-yyyy'), 5, 4835, to_date('21-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121109003641, to_date('09-11-2012', 'dd-mm-yyyy'), to_date('23-11-2012', 'dd-mm-yyyy'), 1, 9309, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021219003642, to_date('19-12-2002', 'dd-mm-yyyy'), to_date('02-01-2003', 'dd-mm-yyyy'), 8, 2769, to_date('01-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430003643, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 12, 4268, to_date('06-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226003644, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 10, 6497, to_date('06-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010211003645, to_date('11-02-2001', 'dd-mm-yyyy'), to_date('25-02-2001', 'dd-mm-yyyy'), 2, 2410, to_date('24-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000322003646, to_date('22-03-2000', 'dd-mm-yyyy'), to_date('05-04-2000', 'dd-mm-yyyy'), 11, 1610, to_date('29-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726003647, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 1, 7604, to_date('05-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041216003648, to_date('16-12-2004', 'dd-mm-yyyy'), to_date('30-12-2004', 'dd-mm-yyyy'), 10, 2000, to_date('28-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813003649, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 6, 6055, to_date('20-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120213003650, to_date('13-02-2012', 'dd-mm-yyyy'), to_date('27-02-2012', 'dd-mm-yyyy'), 4, 8956, to_date('27-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120109003651, to_date('09-01-2012', 'dd-mm-yyyy'), to_date('23-01-2012', 'dd-mm-yyyy'), 10, 7513, to_date('19-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060411003652, to_date('11-04-2006', 'dd-mm-yyyy'), to_date('25-04-2006', 'dd-mm-yyyy'), 6, 3458, to_date('24-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060421003653, to_date('21-04-2006', 'dd-mm-yyyy'), to_date('05-05-2006', 'dd-mm-yyyy'), 3, 5655, to_date('04-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000123003654, to_date('23-01-2000', 'dd-mm-yyyy'), to_date('06-02-2000', 'dd-mm-yyyy'), 11, 1912, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090310003655, to_date('10-03-2009', 'dd-mm-yyyy'), to_date('24-03-2009', 'dd-mm-yyyy'), 10, 5958, to_date('19-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111213003656, to_date('13-12-2011', 'dd-mm-yyyy'), to_date('27-12-2011', 'dd-mm-yyyy'), 5, 8287, to_date('31-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090502003657, to_date('02-05-2009', 'dd-mm-yyyy'), to_date('16-05-2009', 'dd-mm-yyyy'), 11, 8585, to_date('04-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906003658, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 5, 6739, to_date('07-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120628003659, to_date('28-06-2012', 'dd-mm-yyyy'), to_date('12-07-2012', 'dd-mm-yyyy'), 5, 8382, to_date('13-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050725003660, to_date('25-07-2005', 'dd-mm-yyyy'), to_date('08-08-2005', 'dd-mm-yyyy'), 5, 3197, to_date('08-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120113003661, to_date('13-01-2012', 'dd-mm-yyyy'), to_date('27-01-2012', 'dd-mm-yyyy'), 8, 8886, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120528003662, to_date('28-05-2012', 'dd-mm-yyyy'), to_date('11-06-2012', 'dd-mm-yyyy'), 2, 11049, to_date('05-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060113003663, to_date('13-01-2006', 'dd-mm-yyyy'), to_date('27-01-2006', 'dd-mm-yyyy'), 1, 5675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081030003664, to_date('30-10-2008', 'dd-mm-yyyy'), to_date('13-11-2008', 'dd-mm-yyyy'), 1, 6499, to_date('18-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000628003665, to_date('28-06-2000', 'dd-mm-yyyy'), to_date('12-07-2000', 'dd-mm-yyyy'), 8, 2864, to_date('29-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031025003666, to_date('25-10-2003', 'dd-mm-yyyy'), to_date('08-11-2003', 'dd-mm-yyyy'), 10, 2885, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080118003667, to_date('18-01-2008', 'dd-mm-yyyy'), to_date('01-02-2008', 'dd-mm-yyyy'), 5, 5462, to_date('05-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060619003668, to_date('19-06-2006', 'dd-mm-yyyy'), to_date('03-07-2006', 'dd-mm-yyyy'), 2, 7440, to_date('05-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120617003669, to_date('17-06-2012', 'dd-mm-yyyy'), to_date('01-07-2012', 'dd-mm-yyyy'), 5, 8769, to_date('01-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110804003670, to_date('04-08-2011', 'dd-mm-yyyy'), to_date('18-08-2011', 'dd-mm-yyyy'), 6, 8831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620003671, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 11, 7909, to_date('07-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070925003672, to_date('25-09-2007', 'dd-mm-yyyy'), to_date('09-10-2007', 'dd-mm-yyyy'), 10, 7902, to_date('12-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909003673, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 8, 5790, to_date('12-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070727003674, to_date('27-07-2007', 'dd-mm-yyyy'), to_date('10-08-2007', 'dd-mm-yyyy'), 5, 4189, to_date('30-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030306003675, to_date('06-03-2003', 'dd-mm-yyyy'), to_date('20-03-2003', 'dd-mm-yyyy'), 4, 1826, to_date('21-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130003676, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 6, 2298, to_date('11-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020417003677, to_date('17-04-2002', 'dd-mm-yyyy'), to_date('01-05-2002', 'dd-mm-yyyy'), 10, 1271, to_date('05-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020514005814, to_date('14-05-2002', 'dd-mm-yyyy'), to_date('28-05-2002', 'dd-mm-yyyy'), 3, 2645, to_date('18-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051208005815, to_date('08-12-2005', 'dd-mm-yyyy'), to_date('22-12-2005', 'dd-mm-yyyy'), 3, 4867, to_date('18-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070521005816, to_date('21-05-2007', 'dd-mm-yyyy'), to_date('04-06-2007', 'dd-mm-yyyy'), 11, 3532, to_date('06-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060407005817, to_date('07-04-2006', 'dd-mm-yyyy'), to_date('21-04-2006', 'dd-mm-yyyy'), 4, 3927, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031201005818, to_date('01-12-2003', 'dd-mm-yyyy'), to_date('15-12-2003', 'dd-mm-yyyy'), 10, 3006, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220005819, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 9, 4659, to_date('26-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217005820, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 10, 5789, to_date('23-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710005821, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 5, 1777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001005822, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 2, 7983, to_date('10-10-2008', 'dd-mm-yyyy'));
commit;
prompt 2000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041213005823, to_date('13-12-2004', 'dd-mm-yyyy'), to_date('27-12-2004', 'dd-mm-yyyy'), 11, 5484, to_date('14-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000907005824, to_date('07-09-2000', 'dd-mm-yyyy'), to_date('21-09-2000', 'dd-mm-yyyy'), 6, 2698, to_date('12-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725005825, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 2, 5771, to_date('04-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081207005826, to_date('07-12-2008', 'dd-mm-yyyy'), to_date('21-12-2008', 'dd-mm-yyyy'), 5, 6448, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030820005827, to_date('20-08-2003', 'dd-mm-yyyy'), to_date('03-09-2003', 'dd-mm-yyyy'), 7, 2646, to_date('08-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011021005828, to_date('21-10-2001', 'dd-mm-yyyy'), to_date('04-11-2001', 'dd-mm-yyyy'), 12, 1912, to_date('30-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329005829, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 7, 6104, to_date('16-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110108005830, to_date('08-01-2011', 'dd-mm-yyyy'), to_date('22-01-2011', 'dd-mm-yyyy'), 11, 6227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060211005831, to_date('11-02-2006', 'dd-mm-yyyy'), to_date('25-02-2006', 'dd-mm-yyyy'), 5, 5276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040807005832, to_date('07-08-2004', 'dd-mm-yyyy'), to_date('21-08-2004', 'dd-mm-yyyy'), 9, 4358, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090803005833, to_date('03-08-2009', 'dd-mm-yyyy'), to_date('17-08-2009', 'dd-mm-yyyy'), 7, 7174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050410005834, to_date('10-04-2005', 'dd-mm-yyyy'), to_date('24-04-2005', 'dd-mm-yyyy'), 1, 4307, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090814005835, to_date('14-08-2009', 'dd-mm-yyyy'), to_date('28-08-2009', 'dd-mm-yyyy'), 10, 6502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090319005836, to_date('19-03-2009', 'dd-mm-yyyy'), to_date('02-04-2009', 'dd-mm-yyyy'), 3, 8155, to_date('07-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706005837, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 3, 3767, to_date('11-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050222005838, to_date('22-02-2005', 'dd-mm-yyyy'), to_date('08-03-2005', 'dd-mm-yyyy'), 8, 2824, to_date('11-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060104005839, to_date('04-01-2006', 'dd-mm-yyyy'), to_date('18-01-2006', 'dd-mm-yyyy'), 7, 5530, to_date('07-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024005840, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 10, 7844, to_date('01-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000730005841, to_date('30-07-2000', 'dd-mm-yyyy'), to_date('13-08-2000', 'dd-mm-yyyy'), 2, 2202, to_date('06-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227005842, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 11, 3102, to_date('12-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080425005843, to_date('25-04-2008', 'dd-mm-yyyy'), to_date('09-05-2008', 'dd-mm-yyyy'), 7, 9881, to_date('06-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214005844, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 12, 3223, to_date('17-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111125005845, to_date('25-11-2011', 'dd-mm-yyyy'), to_date('09-12-2011', 'dd-mm-yyyy'), 2, 5937, to_date('30-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110623005846, to_date('23-06-2011', 'dd-mm-yyyy'), to_date('07-07-2011', 'dd-mm-yyyy'), 10, 9051, to_date('06-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010709005847, to_date('09-07-2001', 'dd-mm-yyyy'), to_date('23-07-2001', 'dd-mm-yyyy'), 3, 2766, to_date('11-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100319005848, to_date('19-03-2010', 'dd-mm-yyyy'), to_date('02-04-2010', 'dd-mm-yyyy'), 6, 8998, to_date('27-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091107005849, to_date('07-11-2009', 'dd-mm-yyyy'), to_date('21-11-2009', 'dd-mm-yyyy'), 12, 5567, to_date('22-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060424005850, to_date('24-04-2006', 'dd-mm-yyyy'), to_date('08-05-2006', 'dd-mm-yyyy'), 2, 5353, to_date('27-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107005851, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 4, 4118, to_date('15-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218005852, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 3, 5837, to_date('06-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010715005853, to_date('15-07-2001', 'dd-mm-yyyy'), to_date('29-07-2001', 'dd-mm-yyyy'), 7, 2938, to_date('19-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020623005854, to_date('23-06-2002', 'dd-mm-yyyy'), to_date('07-07-2002', 'dd-mm-yyyy'), 7, 2642, to_date('30-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620005855, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 2, 6546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217005856, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 3, 9771, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001118005857, to_date('18-11-2000', 'dd-mm-yyyy'), to_date('02-12-2000', 'dd-mm-yyyy'), 11, 833, to_date('24-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000516005858, to_date('16-05-2000', 'dd-mm-yyyy'), to_date('30-05-2000', 'dd-mm-yyyy'), 2, 2107, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126005859, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 10, 5761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020913005860, to_date('13-09-2002', 'dd-mm-yyyy'), to_date('27-09-2002', 'dd-mm-yyyy'), 3, 1843, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111119005861, to_date('19-11-2011', 'dd-mm-yyyy'), to_date('03-12-2011', 'dd-mm-yyyy'), 11, 5224, to_date('25-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021017005862, to_date('17-10-2002', 'dd-mm-yyyy'), to_date('31-10-2002', 'dd-mm-yyyy'), 7, 2147, to_date('01-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030808005863, to_date('08-08-2003', 'dd-mm-yyyy'), to_date('22-08-2003', 'dd-mm-yyyy'), 1, 4631, to_date('24-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121219005864, to_date('19-12-2012', 'dd-mm-yyyy'), to_date('02-01-2013', 'dd-mm-yyyy'), 10, 7836, to_date('21-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080122005865, to_date('22-01-2008', 'dd-mm-yyyy'), to_date('05-02-2008', 'dd-mm-yyyy'), 11, 4781, to_date('04-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030905005866, to_date('05-09-2003', 'dd-mm-yyyy'), to_date('19-09-2003', 'dd-mm-yyyy'), 6, 3660, to_date('12-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000214005867, to_date('14-02-2000', 'dd-mm-yyyy'), to_date('28-02-2000', 'dd-mm-yyyy'), 2, 3220, to_date('25-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130920005868, to_date('20-09-2013', 'dd-mm-yyyy'), to_date('04-10-2013', 'dd-mm-yyyy'), 4, 7640, to_date('10-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214005869, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 5, 4347, to_date('20-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010314005870, to_date('14-03-2001', 'dd-mm-yyyy'), to_date('28-03-2001', 'dd-mm-yyyy'), 10, 3596, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318005871, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 2, 8899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000315005872, to_date('15-03-2000', 'dd-mm-yyyy'), to_date('29-03-2000', 'dd-mm-yyyy'), 6, 2726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040725005873, to_date('25-07-2004', 'dd-mm-yyyy'), to_date('08-08-2004', 'dd-mm-yyyy'), 12, 3404, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000411005874, to_date('11-04-2000', 'dd-mm-yyyy'), to_date('25-04-2000', 'dd-mm-yyyy'), 7, 2354, to_date('25-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130622005875, to_date('22-06-2013', 'dd-mm-yyyy'), to_date('06-07-2013', 'dd-mm-yyyy'), 2, 7486, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120123005876, to_date('23-01-2012', 'dd-mm-yyyy'), to_date('06-02-2012', 'dd-mm-yyyy'), 11, 9040, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100227005877, to_date('27-02-2010', 'dd-mm-yyyy'), to_date('13-03-2010', 'dd-mm-yyyy'), 8, 4295, to_date('13-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070815005878, to_date('15-08-2007', 'dd-mm-yyyy'), to_date('29-08-2007', 'dd-mm-yyyy'), 7, 9173, to_date('02-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090922005879, to_date('22-09-2009', 'dd-mm-yyyy'), to_date('06-10-2009', 'dd-mm-yyyy'), 11, 5785, to_date('29-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071216005880, to_date('16-12-2007', 'dd-mm-yyyy'), to_date('30-12-2007', 'dd-mm-yyyy'), 8, 4746, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308005881, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 3, 2586, to_date('20-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621005882, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 9, 7116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030303005883, to_date('03-03-2003', 'dd-mm-yyyy'), to_date('17-03-2003', 'dd-mm-yyyy'), 4, 3185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070625005884, to_date('25-06-2007', 'dd-mm-yyyy'), to_date('09-07-2007', 'dd-mm-yyyy'), 6, 4721, to_date('10-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120322005885, to_date('22-03-2012', 'dd-mm-yyyy'), to_date('05-04-2012', 'dd-mm-yyyy'), 9, 8882, to_date('29-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140227005886, to_date('27-02-2014', 'dd-mm-yyyy'), to_date('13-03-2014', 'dd-mm-yyyy'), 12, 11719, to_date('11-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122005887, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 12, 4027, to_date('09-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040109005888, to_date('09-01-2004', 'dd-mm-yyyy'), to_date('23-01-2004', 'dd-mm-yyyy'), 4, 5069, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114005889, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 4, 3218, to_date('17-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001219005890, to_date('19-12-2000', 'dd-mm-yyyy'), to_date('02-01-2001', 'dd-mm-yyyy'), 6, 1293, to_date('01-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113005891, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 7, 4591, to_date('15-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120005892, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 6, 6338, to_date('09-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011005893, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 11, 3567, to_date('30-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050427005894, to_date('27-04-2005', 'dd-mm-yyyy'), to_date('11-05-2005', 'dd-mm-yyyy'), 11, 4208, to_date('30-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405005895, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 10, 9135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020220005896, to_date('20-02-2002', 'dd-mm-yyyy'), to_date('06-03-2002', 'dd-mm-yyyy'), 7, 2473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120128005897, to_date('28-01-2012', 'dd-mm-yyyy'), to_date('11-02-2012', 'dd-mm-yyyy'), 10, 7007, to_date('04-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070801005898, to_date('01-08-2007', 'dd-mm-yyyy'), to_date('15-08-2007', 'dd-mm-yyyy'), 5, 5189, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140123005899, to_date('23-01-2014', 'dd-mm-yyyy'), to_date('06-02-2014', 'dd-mm-yyyy'), 8, 9751, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090605005900, to_date('05-06-2009', 'dd-mm-yyyy'), to_date('19-06-2009', 'dd-mm-yyyy'), 12, 5113, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000508005901, to_date('08-05-2000', 'dd-mm-yyyy'), to_date('22-05-2000', 'dd-mm-yyyy'), 10, 1944, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081130005902, to_date('30-11-2008', 'dd-mm-yyyy'), to_date('14-12-2008', 'dd-mm-yyyy'), 10, 7155, to_date('10-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071120005903, to_date('20-11-2007', 'dd-mm-yyyy'), to_date('04-12-2007', 'dd-mm-yyyy'), 12, 3715, to_date('27-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110327005904, to_date('27-03-2011', 'dd-mm-yyyy'), to_date('10-04-2011', 'dd-mm-yyyy'), 9, 7564, to_date('06-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040501005905, to_date('01-05-2004', 'dd-mm-yyyy'), to_date('15-05-2004', 'dd-mm-yyyy'), 6, 5031, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121102005906, to_date('02-11-2012', 'dd-mm-yyyy'), to_date('16-11-2012', 'dd-mm-yyyy'), 8, 7187, to_date('14-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090208005907, to_date('08-02-2009', 'dd-mm-yyyy'), to_date('22-02-2009', 'dd-mm-yyyy'), 2, 7960, to_date('11-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110814005908, to_date('14-08-2011', 'dd-mm-yyyy'), to_date('28-08-2011', 'dd-mm-yyyy'), 8, 6928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224005909, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 1, 5621, to_date('27-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090122005910, to_date('22-01-2009', 'dd-mm-yyyy'), to_date('05-02-2009', 'dd-mm-yyyy'), 2, 5819, to_date('23-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100125005911, to_date('25-01-2010', 'dd-mm-yyyy'), to_date('08-02-2010', 'dd-mm-yyyy'), 5, 8331, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000604005912, to_date('04-06-2000', 'dd-mm-yyyy'), to_date('18-06-2000', 'dd-mm-yyyy'), 7, 914, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030116005913, to_date('16-01-2003', 'dd-mm-yyyy'), to_date('30-01-2003', 'dd-mm-yyyy'), 8, 2913, to_date('28-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708005914, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 2, 2529, to_date('23-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511005915, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 3, 874, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130303005916, to_date('03-03-2013', 'dd-mm-yyyy'), to_date('17-03-2013', 'dd-mm-yyyy'), 5, 7170, to_date('21-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110413005917, to_date('13-04-2011', 'dd-mm-yyyy'), to_date('27-04-2011', 'dd-mm-yyyy'), 6, 6070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103005918, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 5, 8040, to_date('04-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040314005919, to_date('14-03-2004', 'dd-mm-yyyy'), to_date('28-03-2004', 'dd-mm-yyyy'), 8, 3359, to_date('18-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120617005920, to_date('17-06-2012', 'dd-mm-yyyy'), to_date('01-07-2012', 'dd-mm-yyyy'), 4, 9068, to_date('23-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130505005921, to_date('05-05-2013', 'dd-mm-yyyy'), to_date('19-05-2013', 'dd-mm-yyyy'), 9, 9500, to_date('06-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715005922, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 10, 1099, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110129005923, to_date('29-01-2011', 'dd-mm-yyyy'), to_date('12-02-2011', 'dd-mm-yyyy'), 1, 6265, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010403005924, to_date('03-04-2001', 'dd-mm-yyyy'), to_date('17-04-2001', 'dd-mm-yyyy'), 10, 2810, to_date('13-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011129005925, to_date('29-11-2001', 'dd-mm-yyyy'), to_date('13-12-2001', 'dd-mm-yyyy'), 3, 2606, to_date('17-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050423005926, to_date('23-04-2005', 'dd-mm-yyyy'), to_date('07-05-2005', 'dd-mm-yyyy'), 11, 1921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050926005927, to_date('26-09-2005', 'dd-mm-yyyy'), to_date('10-10-2005', 'dd-mm-yyyy'), 5, 5405, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051008005928, to_date('08-10-2005', 'dd-mm-yyyy'), to_date('22-10-2005', 'dd-mm-yyyy'), 7, 3026, to_date('12-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070409005929, to_date('09-04-2007', 'dd-mm-yyyy'), to_date('23-04-2007', 'dd-mm-yyyy'), 7, 6921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001117005930, to_date('17-11-2000', 'dd-mm-yyyy'), to_date('01-12-2000', 'dd-mm-yyyy'), 8, 1488, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603005931, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 3, 3467, to_date('05-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201005932, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 6, 3553, to_date('07-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060630005933, to_date('30-06-2006', 'dd-mm-yyyy'), to_date('14-07-2006', 'dd-mm-yyyy'), 9, 3403, to_date('07-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002005934, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 11, 869, to_date('22-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006005935, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 8, 6377, to_date('24-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061117005936, to_date('17-11-2006', 'dd-mm-yyyy'), to_date('01-12-2006', 'dd-mm-yyyy'), 5, 3712, to_date('24-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111005937, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 7, 714, to_date('29-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130104005938, to_date('04-01-2013', 'dd-mm-yyyy'), to_date('18-01-2013', 'dd-mm-yyyy'), 7, 7560, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070320005939, to_date('20-03-2007', 'dd-mm-yyyy'), to_date('03-04-2007', 'dd-mm-yyyy'), 11, 5059, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011109005940, to_date('09-11-2001', 'dd-mm-yyyy'), to_date('23-11-2001', 'dd-mm-yyyy'), 11, 3273, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060908005941, to_date('08-09-2006', 'dd-mm-yyyy'), to_date('22-09-2006', 'dd-mm-yyyy'), 11, 4694, to_date('17-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130427005942, to_date('27-04-2013', 'dd-mm-yyyy'), to_date('11-05-2013', 'dd-mm-yyyy'), 10, 5458, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723005943, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 5, 4547, to_date('07-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070908005944, to_date('08-09-2007', 'dd-mm-yyyy'), to_date('22-09-2007', 'dd-mm-yyyy'), 5, 6017, to_date('12-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081124005945, to_date('24-11-2008', 'dd-mm-yyyy'), to_date('08-12-2008', 'dd-mm-yyyy'), 8, 6287, to_date('09-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403005946, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 11, 8854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525005947, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 4, 7259, to_date('13-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090823005948, to_date('23-08-2009', 'dd-mm-yyyy'), to_date('06-09-2009', 'dd-mm-yyyy'), 6, 4739, to_date('24-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050316005949, to_date('16-03-2005', 'dd-mm-yyyy'), to_date('30-03-2005', 'dd-mm-yyyy'), 5, 3994, to_date('18-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022005950, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 1, 5919, to_date('07-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060901005951, to_date('01-09-2006', 'dd-mm-yyyy'), to_date('15-09-2006', 'dd-mm-yyyy'), 10, 4363, to_date('17-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120426005952, to_date('26-04-2012', 'dd-mm-yyyy'), to_date('10-05-2012', 'dd-mm-yyyy'), 10, 7637, to_date('03-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061210005953, to_date('10-12-2006', 'dd-mm-yyyy'), to_date('24-12-2006', 'dd-mm-yyyy'), 10, 6810, to_date('16-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000501005954, to_date('01-05-2000', 'dd-mm-yyyy'), to_date('15-05-2000', 'dd-mm-yyyy'), 4, 1742, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716005955, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 3, 7775, to_date('04-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316005956, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 10, 4496, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020708005957, to_date('08-07-2002', 'dd-mm-yyyy'), to_date('22-07-2002', 'dd-mm-yyyy'), 10, 2252, to_date('19-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114005958, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 7, 4590, to_date('30-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060308005959, to_date('08-03-2006', 'dd-mm-yyyy'), to_date('22-03-2006', 'dd-mm-yyyy'), 7, 3734, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121002005960, to_date('02-10-2012', 'dd-mm-yyyy'), to_date('16-10-2012', 'dd-mm-yyyy'), 4, 10448, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060310005961, to_date('10-03-2006', 'dd-mm-yyyy'), to_date('24-03-2006', 'dd-mm-yyyy'), 1, 3628, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110807005962, to_date('07-08-2011', 'dd-mm-yyyy'), to_date('21-08-2011', 'dd-mm-yyyy'), 7, 6798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210005963, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 7, 2405, to_date('26-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090220005964, to_date('20-02-2009', 'dd-mm-yyyy'), to_date('06-03-2009', 'dd-mm-yyyy'), 6, 8093, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627005965, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 12, 4102, to_date('03-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000911005966, to_date('11-09-2000', 'dd-mm-yyyy'), to_date('25-09-2000', 'dd-mm-yyyy'), 8, 1563, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080902005967, to_date('02-09-2008', 'dd-mm-yyyy'), to_date('16-09-2008', 'dd-mm-yyyy'), 10, 6851, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030610008720, to_date('10-06-2003', 'dd-mm-yyyy'), to_date('24-06-2003', 'dd-mm-yyyy'), 11, 2351, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015008721, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 2, 1450, to_date('03-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822008722, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 8, 8411, to_date('10-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531008723, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 4, 4071, to_date('01-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213008724, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 6, 4683, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100321008725, to_date('21-03-2010', 'dd-mm-yyyy'), to_date('04-04-2010', 'dd-mm-yyyy'), 2, 6687, to_date('31-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080924008726, to_date('24-09-2008', 'dd-mm-yyyy'), to_date('08-10-2008', 'dd-mm-yyyy'), 8, 4625, to_date('02-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026008727, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 3, 3924, to_date('05-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080702008728, to_date('02-07-2008', 'dd-mm-yyyy'), to_date('16-07-2008', 'dd-mm-yyyy'), 7, 6428, to_date('21-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303008729, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 11, 8965, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917008730, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 2, 7068, to_date('22-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108008731, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 2, 7195, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070222008732, to_date('22-02-2007', 'dd-mm-yyyy'), to_date('08-03-2007', 'dd-mm-yyyy'), 2, 8761, to_date('26-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329008733, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 12, 3062, to_date('06-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091029008734, to_date('29-10-2009', 'dd-mm-yyyy'), to_date('12-11-2009', 'dd-mm-yyyy'), 11, 6326, to_date('05-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100226008735, to_date('26-02-2010', 'dd-mm-yyyy'), to_date('12-03-2010', 'dd-mm-yyyy'), 9, 5456, to_date('16-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000203008736, to_date('03-02-2000', 'dd-mm-yyyy'), to_date('17-02-2000', 'dd-mm-yyyy'), 1, 459, to_date('18-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105008737, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 11, 4446, to_date('18-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620008738, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 5, 2011, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090512008739, to_date('12-05-2009', 'dd-mm-yyyy'), to_date('26-05-2009', 'dd-mm-yyyy'), 3, 6670, to_date('20-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121016008740, to_date('16-10-2012', 'dd-mm-yyyy'), to_date('30-10-2012', 'dd-mm-yyyy'), 8, 6323, to_date('20-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615008741, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 12, 9930, to_date('30-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110518008742, to_date('18-05-2011', 'dd-mm-yyyy'), to_date('01-06-2011', 'dd-mm-yyyy'), 6, 4416, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125008743, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 2, 2122, to_date('03-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010415008744, to_date('15-04-2001', 'dd-mm-yyyy'), to_date('29-04-2001', 'dd-mm-yyyy'), 4, 2275, to_date('17-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123008745, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 9, 7224, to_date('06-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101115008746, to_date('15-11-2010', 'dd-mm-yyyy'), to_date('29-11-2010', 'dd-mm-yyyy'), 8, 7678, to_date('21-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031012008747, to_date('12-10-2003', 'dd-mm-yyyy'), to_date('26-10-2003', 'dd-mm-yyyy'), 3, 2856, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090714008748, to_date('14-07-2009', 'dd-mm-yyyy'), to_date('28-07-2009', 'dd-mm-yyyy'), 11, 8166, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230008749, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 2, 931, to_date('04-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131029008750, to_date('29-10-2013', 'dd-mm-yyyy'), to_date('12-11-2013', 'dd-mm-yyyy'), 5, 5324, to_date('14-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050613008751, to_date('13-06-2005', 'dd-mm-yyyy'), to_date('27-06-2005', 'dd-mm-yyyy'), 12, 3261, to_date('17-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602008752, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 12, 1225, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130217008753, to_date('17-02-2013', 'dd-mm-yyyy'), to_date('03-03-2013', 'dd-mm-yyyy'), 9, 8212, to_date('04-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121104008754, to_date('04-11-2012', 'dd-mm-yyyy'), to_date('18-11-2012', 'dd-mm-yyyy'), 3, 7515, to_date('20-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080417008755, to_date('17-04-2008', 'dd-mm-yyyy'), to_date('01-05-2008', 'dd-mm-yyyy'), 1, 6038, to_date('05-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030524008756, to_date('24-05-2003', 'dd-mm-yyyy'), to_date('07-06-2003', 'dd-mm-yyyy'), 12, 2880, to_date('27-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031227008757, to_date('27-12-2003', 'dd-mm-yyyy'), to_date('10-01-2004', 'dd-mm-yyyy'), 11, 1904, to_date('05-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723008758, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 6, 5423, to_date('26-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110923008759, to_date('23-09-2011', 'dd-mm-yyyy'), to_date('07-10-2011', 'dd-mm-yyyy'), 6, 9442, to_date('30-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001223008760, to_date('23-12-2000', 'dd-mm-yyyy'), to_date('06-01-2001', 'dd-mm-yyyy'), 4, 1722, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110613008761, to_date('13-06-2011', 'dd-mm-yyyy'), to_date('27-06-2011', 'dd-mm-yyyy'), 12, 8533, to_date('14-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120417008762, to_date('17-04-2012', 'dd-mm-yyyy'), to_date('01-05-2012', 'dd-mm-yyyy'), 10, 10052, to_date('23-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113008763, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 6, 7451, to_date('14-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071226008764, to_date('26-12-2007', 'dd-mm-yyyy'), to_date('09-01-2008', 'dd-mm-yyyy'), 7, 4655, to_date('08-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080227008765, to_date('27-02-2008', 'dd-mm-yyyy'), to_date('12-03-2008', 'dd-mm-yyyy'), 6, 8395, to_date('06-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000705008766, to_date('05-07-2000', 'dd-mm-yyyy'), to_date('19-07-2000', 'dd-mm-yyyy'), 9, 1708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011230008767, to_date('30-12-2001', 'dd-mm-yyyy'), to_date('13-01-2002', 'dd-mm-yyyy'), 8, 1197, to_date('05-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111019008768, to_date('19-10-2011', 'dd-mm-yyyy'), to_date('02-11-2011', 'dd-mm-yyyy'), 6, 7140, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140328008769, to_date('28-03-2014', 'dd-mm-yyyy'), to_date('11-04-2014', 'dd-mm-yyyy'), 9, 10449, to_date('01-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140203008770, to_date('03-02-2014', 'dd-mm-yyyy'), to_date('17-02-2014', 'dd-mm-yyyy'), 4, 11187, to_date('11-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120319008771, to_date('19-03-2012', 'dd-mm-yyyy'), to_date('02-04-2012', 'dd-mm-yyyy'), 7, 6967, to_date('02-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010224008772, to_date('24-02-2001', 'dd-mm-yyyy'), to_date('10-03-2001', 'dd-mm-yyyy'), 6, 2013, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050113008773, to_date('13-01-2005', 'dd-mm-yyyy'), to_date('27-01-2005', 'dd-mm-yyyy'), 10, 6467, to_date('01-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110605008774, to_date('05-06-2011', 'dd-mm-yyyy'), to_date('19-06-2011', 'dd-mm-yyyy'), 5, 7149, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050806008775, to_date('06-08-2005', 'dd-mm-yyyy'), to_date('20-08-2005', 'dd-mm-yyyy'), 7, 4047, to_date('11-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010706008776, to_date('06-07-2001', 'dd-mm-yyyy'), to_date('20-07-2001', 'dd-mm-yyyy'), 3, 3051, to_date('17-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041207008777, to_date('07-12-2004', 'dd-mm-yyyy'), to_date('21-12-2004', 'dd-mm-yyyy'), 7, 4337, to_date('16-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010806008778, to_date('06-08-2001', 'dd-mm-yyyy'), to_date('20-08-2001', 'dd-mm-yyyy'), 6, 1445, to_date('10-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050124008779, to_date('24-01-2005', 'dd-mm-yyyy'), to_date('07-02-2005', 'dd-mm-yyyy'), 10, 5094, to_date('13-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090805008780, to_date('05-08-2009', 'dd-mm-yyyy'), to_date('19-08-2009', 'dd-mm-yyyy'), 11, 9345, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002008781, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 2, 1023, to_date('14-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131116008782, to_date('16-11-2013', 'dd-mm-yyyy'), to_date('30-11-2013', 'dd-mm-yyyy'), 3, 9564, to_date('23-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091008008783, to_date('08-10-2009', 'dd-mm-yyyy'), to_date('22-10-2009', 'dd-mm-yyyy'), 11, 6212, to_date('13-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827008784, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 10, 4314, to_date('11-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131101008785, to_date('01-11-2013', 'dd-mm-yyyy'), to_date('15-11-2013', 'dd-mm-yyyy'), 9, 7962, to_date('16-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070629008786, to_date('29-06-2007', 'dd-mm-yyyy'), to_date('13-07-2007', 'dd-mm-yyyy'), 6, 6073, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041003008787, to_date('03-10-2004', 'dd-mm-yyyy'), to_date('17-10-2004', 'dd-mm-yyyy'), 8, 4117, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020208008788, to_date('08-02-2002', 'dd-mm-yyyy'), to_date('22-02-2002', 'dd-mm-yyyy'), 4, 3458, to_date('15-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111206008789, to_date('06-12-2011', 'dd-mm-yyyy'), to_date('20-12-2011', 'dd-mm-yyyy'), 4, 8495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227008790, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 10, 3034, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030124008791, to_date('24-01-2003', 'dd-mm-yyyy'), to_date('07-02-2003', 'dd-mm-yyyy'), 4, 3361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120414008792, to_date('14-04-2012', 'dd-mm-yyyy'), to_date('28-04-2012', 'dd-mm-yyyy'), 12, 9671, to_date('01-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000111008793, to_date('11-01-2000', 'dd-mm-yyyy'), to_date('25-01-2000', 'dd-mm-yyyy'), 7, 997, to_date('30-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120702008794, to_date('02-07-2012', 'dd-mm-yyyy'), to_date('16-07-2012', 'dd-mm-yyyy'), 12, 6384, to_date('05-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050327008795, to_date('27-03-2005', 'dd-mm-yyyy'), to_date('10-04-2005', 'dd-mm-yyyy'), 3, 5556, to_date('04-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120503008796, to_date('03-05-2012', 'dd-mm-yyyy'), to_date('17-05-2012', 'dd-mm-yyyy'), 9, 7117, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020613008797, to_date('13-06-2002', 'dd-mm-yyyy'), to_date('27-06-2002', 'dd-mm-yyyy'), 6, 3849, to_date('24-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041102008798, to_date('02-11-2004', 'dd-mm-yyyy'), to_date('16-11-2004', 'dd-mm-yyyy'), 5, 4942, to_date('16-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624008799, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 11, 1747, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000810008800, to_date('10-08-2000', 'dd-mm-yyyy'), to_date('24-08-2000', 'dd-mm-yyyy'), 6, 436, to_date('21-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121008801, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 10, 5512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100427008802, to_date('27-04-2010', 'dd-mm-yyyy'), to_date('11-05-2010', 'dd-mm-yyyy'), 5, 6948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924008803, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 6, 4148, to_date('13-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100527008804, to_date('27-05-2010', 'dd-mm-yyyy'), to_date('10-06-2010', 'dd-mm-yyyy'), 8, 7944, to_date('13-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050501008805, to_date('01-05-2005', 'dd-mm-yyyy'), to_date('15-05-2005', 'dd-mm-yyyy'), 3, 4492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080612008806, to_date('12-06-2008', 'dd-mm-yyyy'), to_date('26-06-2008', 'dd-mm-yyyy'), 10, 6788, to_date('01-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090809008807, to_date('09-08-2009', 'dd-mm-yyyy'), to_date('23-08-2009', 'dd-mm-yyyy'), 11, 7867, to_date('29-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070209008808, to_date('09-02-2007', 'dd-mm-yyyy'), to_date('23-02-2007', 'dd-mm-yyyy'), 7, 5997, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040123008809, to_date('23-01-2004', 'dd-mm-yyyy'), to_date('06-02-2004', 'dd-mm-yyyy'), 11, 4082, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131008810, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 10, 4824, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408008811, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 12, 10410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080926008812, to_date('26-09-2008', 'dd-mm-yyyy'), to_date('10-10-2008', 'dd-mm-yyyy'), 12, 6813, to_date('02-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060712008813, to_date('12-07-2006', 'dd-mm-yyyy'), to_date('26-07-2006', 'dd-mm-yyyy'), 3, 3029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090504008814, to_date('04-05-2009', 'dd-mm-yyyy'), to_date('18-05-2009', 'dd-mm-yyyy'), 9, 7919, to_date('21-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130519008815, to_date('19-05-2013', 'dd-mm-yyyy'), to_date('02-06-2013', 'dd-mm-yyyy'), 3, 9343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001013008816, to_date('13-10-2000', 'dd-mm-yyyy'), to_date('27-10-2000', 'dd-mm-yyyy'), 11, 1980, to_date('25-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130411008817, to_date('11-04-2013', 'dd-mm-yyyy'), to_date('25-04-2013', 'dd-mm-yyyy'), 5, 10524, to_date('20-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010823008818, to_date('23-08-2001', 'dd-mm-yyyy'), to_date('06-09-2001', 'dd-mm-yyyy'), 7, 3667, to_date('29-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120829008819, to_date('29-08-2012', 'dd-mm-yyyy'), to_date('12-09-2012', 'dd-mm-yyyy'), 11, 6919, to_date('12-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822008820, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 8, 7612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011009008821, to_date('09-10-2001', 'dd-mm-yyyy'), to_date('23-10-2001', 'dd-mm-yyyy'), 5, 2913, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505008822, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 1, 4040, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080924008823, to_date('24-09-2008', 'dd-mm-yyyy'), to_date('08-10-2008', 'dd-mm-yyyy'), 12, 4920, to_date('11-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100328008824, to_date('28-03-2010', 'dd-mm-yyyy'), to_date('11-04-2010', 'dd-mm-yyyy'), 4, 6812, to_date('06-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129008825, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 9, 3201, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703008826, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 4, 3261, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120731008827, to_date('31-07-2012', 'dd-mm-yyyy'), to_date('14-08-2012', 'dd-mm-yyyy'), 2, 6663, to_date('18-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051013008828, to_date('13-10-2005', 'dd-mm-yyyy'), to_date('27-10-2005', 'dd-mm-yyyy'), 6, 5368, to_date('28-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104008829, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 11, 4551, to_date('14-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111028008830, to_date('28-10-2011', 'dd-mm-yyyy'), to_date('11-11-2011', 'dd-mm-yyyy'), 8, 7189, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120510008831, to_date('10-05-2012', 'dd-mm-yyyy'), to_date('24-05-2012', 'dd-mm-yyyy'), 11, 7109, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509008832, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 7, 8663, to_date('25-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070223008833, to_date('23-02-2007', 'dd-mm-yyyy'), to_date('09-03-2007', 'dd-mm-yyyy'), 6, 4505, to_date('09-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000218008834, to_date('18-02-2000', 'dd-mm-yyyy'), to_date('03-03-2000', 'dd-mm-yyyy'), 4, 1235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040705008835, to_date('05-07-2004', 'dd-mm-yyyy'), to_date('19-07-2004', 'dd-mm-yyyy'), 3, 2968, to_date('12-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040314008836, to_date('14-03-2004', 'dd-mm-yyyy'), to_date('28-03-2004', 'dd-mm-yyyy'), 3, 5510, to_date('16-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525008837, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 10, 10196, to_date('10-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028008838, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 3, 10727, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119008839, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 9, 3520, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130710008840, to_date('10-07-2013', 'dd-mm-yyyy'), to_date('24-07-2013', 'dd-mm-yyyy'), 11, 10063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061121008841, to_date('21-11-2006', 'dd-mm-yyyy'), to_date('05-12-2006', 'dd-mm-yyyy'), 9, 5017, to_date('03-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125008842, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 11, 2497, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006008843, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 1, 4839, to_date('15-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090517008844, to_date('17-05-2009', 'dd-mm-yyyy'), to_date('31-05-2009', 'dd-mm-yyyy'), 2, 7685, to_date('06-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522008845, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 8, 7208, to_date('28-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020008846, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 4, 6706, to_date('30-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060402008847, to_date('02-04-2006', 'dd-mm-yyyy'), to_date('16-04-2006', 'dd-mm-yyyy'), 8, 4514, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140118008848, to_date('18-01-2014', 'dd-mm-yyyy'), to_date('01-02-2014', 'dd-mm-yyyy'), 8, 10676, to_date('04-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000416008849, to_date('16-04-2000', 'dd-mm-yyyy'), to_date('30-04-2000', 'dd-mm-yyyy'), 8, 1965, to_date('21-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020305008850, to_date('05-03-2002', 'dd-mm-yyyy'), to_date('19-03-2002', 'dd-mm-yyyy'), 9, 2172, to_date('07-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050824008851, to_date('24-08-2005', 'dd-mm-yyyy'), to_date('07-09-2005', 'dd-mm-yyyy'), 4, 5127, to_date('04-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050729008852, to_date('29-07-2005', 'dd-mm-yyyy'), to_date('12-08-2005', 'dd-mm-yyyy'), 8, 4200, to_date('31-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703008853, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 10, 3560, to_date('17-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100313008854, to_date('13-03-2010', 'dd-mm-yyyy'), to_date('27-03-2010', 'dd-mm-yyyy'), 10, 9711, to_date('29-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050222008855, to_date('22-02-2005', 'dd-mm-yyyy'), to_date('08-03-2005', 'dd-mm-yyyy'), 2, 4013, to_date('08-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070712008856, to_date('12-07-2007', 'dd-mm-yyyy'), to_date('26-07-2007', 'dd-mm-yyyy'), 6, 6724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000417008857, to_date('17-04-2000', 'dd-mm-yyyy'), to_date('01-05-2000', 'dd-mm-yyyy'), 6, 1588, to_date('28-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070606008858, to_date('06-06-2007', 'dd-mm-yyyy'), to_date('20-06-2007', 'dd-mm-yyyy'), 6, 6518, to_date('22-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051021008859, to_date('21-10-2005', 'dd-mm-yyyy'), to_date('04-11-2005', 'dd-mm-yyyy'), 5, 5633, to_date('04-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021218008860, to_date('18-12-2002', 'dd-mm-yyyy'), to_date('01-01-2003', 'dd-mm-yyyy'), 8, 2965, to_date('25-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525008861, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 3, 6510, to_date('30-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529008862, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 6, 5059, to_date('16-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080703008863, to_date('03-07-2008', 'dd-mm-yyyy'), to_date('17-07-2008', 'dd-mm-yyyy'), 12, 5665, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060309008864, to_date('09-03-2006', 'dd-mm-yyyy'), to_date('23-03-2006', 'dd-mm-yyyy'), 9, 3909, to_date('27-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110414008865, to_date('14-04-2011', 'dd-mm-yyyy'), to_date('28-04-2011', 'dd-mm-yyyy'), 9, 8676, to_date('30-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040125008866, to_date('25-01-2004', 'dd-mm-yyyy'), to_date('08-02-2004', 'dd-mm-yyyy'), 8, 3121, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080218008867, to_date('18-02-2008', 'dd-mm-yyyy'), to_date('03-03-2008', 'dd-mm-yyyy'), 4, 5308, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080129008868, to_date('29-01-2008', 'dd-mm-yyyy'), to_date('12-02-2008', 'dd-mm-yyyy'), 4, 8467, to_date('03-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100516008869, to_date('16-05-2010', 'dd-mm-yyyy'), to_date('30-05-2010', 'dd-mm-yyyy'), 4, 9328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120930008870, to_date('30-09-2012', 'dd-mm-yyyy'), to_date('14-10-2012', 'dd-mm-yyyy'), 5, 8888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100525008871, to_date('25-05-2010', 'dd-mm-yyyy'), to_date('08-06-2010', 'dd-mm-yyyy'), 10, 5136, to_date('10-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090201001222, to_date('01-02-2009', 'dd-mm-yyyy'), to_date('15-02-2009', 'dd-mm-yyyy'), 7, 4891, to_date('17-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110803001223, to_date('03-08-2011', 'dd-mm-yyyy'), to_date('17-08-2011', 'dd-mm-yyyy'), 3, 8905, to_date('08-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111001224, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 7, 3853, to_date('22-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140123001225, to_date('23-01-2014', 'dd-mm-yyyy'), to_date('06-02-2014', 'dd-mm-yyyy'), 9, 10460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040917001226, to_date('17-09-2004', 'dd-mm-yyyy'), to_date('01-10-2004', 'dd-mm-yyyy'), 7, 4153, to_date('23-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504001227, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 2, 6266, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070925001228, to_date('25-09-2007', 'dd-mm-yyyy'), to_date('09-10-2007', 'dd-mm-yyyy'), 9, 4375, to_date('08-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717001229, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 8, 6731, to_date('27-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121221001230, to_date('21-12-2012', 'dd-mm-yyyy'), to_date('04-01-2013', 'dd-mm-yyyy'), 9, 10190, to_date('24-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000216001231, to_date('16-02-2000', 'dd-mm-yyyy'), to_date('01-03-2000', 'dd-mm-yyyy'), 4, 1962, to_date('25-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504001232, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 5, 4989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090629001233, to_date('29-06-2009', 'dd-mm-yyyy'), to_date('13-07-2009', 'dd-mm-yyyy'), 9, 4956, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131210001234, to_date('10-12-2013', 'dd-mm-yyyy'), to_date('24-12-2013', 'dd-mm-yyyy'), 7, 8852, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020612001235, to_date('12-06-2002', 'dd-mm-yyyy'), to_date('26-06-2002', 'dd-mm-yyyy'), 8, 2966, to_date('29-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120001236, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 7, 1802, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040619001237, to_date('19-06-2004', 'dd-mm-yyyy'), to_date('03-07-2004', 'dd-mm-yyyy'), 1, 4762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121110001238, to_date('10-11-2012', 'dd-mm-yyyy'), to_date('24-11-2012', 'dd-mm-yyyy'), 8, 7795, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090227001239, to_date('27-02-2009', 'dd-mm-yyyy'), to_date('13-03-2009', 'dd-mm-yyyy'), 6, 7242, to_date('17-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070318001240, to_date('18-03-2007', 'dd-mm-yyyy'), to_date('01-04-2007', 'dd-mm-yyyy'), 5, 4908, to_date('31-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081105001241, to_date('05-11-2008', 'dd-mm-yyyy'), to_date('19-11-2008', 'dd-mm-yyyy'), 9, 5471, to_date('06-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051031001242, to_date('31-10-2005', 'dd-mm-yyyy'), to_date('14-11-2005', 'dd-mm-yyyy'), 3, 3319, to_date('12-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018001243, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 8, 2770, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429001244, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 2, 3507, to_date('13-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010412001245, to_date('12-04-2001', 'dd-mm-yyyy'), to_date('26-04-2001', 'dd-mm-yyyy'), 11, 1217, to_date('30-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050117001246, to_date('17-01-2005', 'dd-mm-yyyy'), to_date('31-01-2005', 'dd-mm-yyyy'), 4, 6927, to_date('24-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091019001247, to_date('19-10-2009', 'dd-mm-yyyy'), to_date('02-11-2009', 'dd-mm-yyyy'), 9, 5139, to_date('21-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070710001248, to_date('10-07-2007', 'dd-mm-yyyy'), to_date('24-07-2007', 'dd-mm-yyyy'), 8, 7504, to_date('17-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071024001249, to_date('24-10-2007', 'dd-mm-yyyy'), to_date('07-11-2007', 'dd-mm-yyyy'), 4, 5363, to_date('05-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120509001250, to_date('09-05-2012', 'dd-mm-yyyy'), to_date('23-05-2012', 'dd-mm-yyyy'), 6, 7825, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041222001251, to_date('22-12-2004', 'dd-mm-yyyy'), to_date('05-01-2005', 'dd-mm-yyyy'), 3, 4900, to_date('28-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051219001252, to_date('19-12-2005', 'dd-mm-yyyy'), to_date('02-01-2006', 'dd-mm-yyyy'), 5, 4671, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130908001253, to_date('08-09-2013', 'dd-mm-yyyy'), to_date('22-09-2013', 'dd-mm-yyyy'), 3, 9003, to_date('10-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010519001254, to_date('19-05-2001', 'dd-mm-yyyy'), to_date('02-06-2001', 'dd-mm-yyyy'), 3, 259, to_date('23-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040314001255, to_date('14-03-2004', 'dd-mm-yyyy'), to_date('28-03-2004', 'dd-mm-yyyy'), 3, 4720, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001124001256, to_date('24-11-2000', 'dd-mm-yyyy'), to_date('08-12-2000', 'dd-mm-yyyy'), 11, 1940, to_date('27-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131213001257, to_date('13-12-2013', 'dd-mm-yyyy'), to_date('27-12-2013', 'dd-mm-yyyy'), 6, 8525, to_date('31-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000205001258, to_date('05-02-2000', 'dd-mm-yyyy'), to_date('19-02-2000', 'dd-mm-yyyy'), 4, 3032, to_date('11-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081016001259, to_date('16-10-2008', 'dd-mm-yyyy'), to_date('30-10-2008', 'dd-mm-yyyy'), 8, 7478, to_date('18-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121110001260, to_date('10-11-2012', 'dd-mm-yyyy'), to_date('24-11-2012', 'dd-mm-yyyy'), 2, 9794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080720001261, to_date('20-07-2008', 'dd-mm-yyyy'), to_date('03-08-2008', 'dd-mm-yyyy'), 3, 3480, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723001262, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 6, 2450, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071016001263, to_date('16-10-2007', 'dd-mm-yyyy'), to_date('30-10-2007', 'dd-mm-yyyy'), 1, 5398, to_date('19-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416001264, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 4, 4760, to_date('26-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203001265, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 8, 1841, to_date('04-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061126001266, to_date('26-11-2006', 'dd-mm-yyyy'), to_date('10-12-2006', 'dd-mm-yyyy'), 12, 6689, to_date('08-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000809001267, to_date('09-08-2000', 'dd-mm-yyyy'), to_date('23-08-2000', 'dd-mm-yyyy'), 5, 2604, to_date('23-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031103001268, to_date('03-11-2003', 'dd-mm-yyyy'), to_date('17-11-2003', 'dd-mm-yyyy'), 9, 3719, to_date('22-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031223001269, to_date('23-12-2003', 'dd-mm-yyyy'), to_date('06-01-2004', 'dd-mm-yyyy'), 6, 3346, to_date('11-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030621001270, to_date('21-06-2003', 'dd-mm-yyyy'), to_date('05-07-2003', 'dd-mm-yyyy'), 6, 4046, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327001271, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 7, 10761, to_date('29-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030319001272, to_date('19-03-2003', 'dd-mm-yyyy'), to_date('02-04-2003', 'dd-mm-yyyy'), 4, 2784, to_date('01-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130605001273, to_date('05-06-2013', 'dd-mm-yyyy'), to_date('19-06-2013', 'dd-mm-yyyy'), 4, 10151, to_date('15-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020604001274, to_date('04-06-2002', 'dd-mm-yyyy'), to_date('18-06-2002', 'dd-mm-yyyy'), 3, 2608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040612001275, to_date('12-06-2004', 'dd-mm-yyyy'), to_date('26-06-2004', 'dd-mm-yyyy'), 6, 4070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507001276, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 6, 6331, to_date('17-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815001277, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 2, 4574, to_date('27-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100519001278, to_date('19-05-2010', 'dd-mm-yyyy'), to_date('02-06-2010', 'dd-mm-yyyy'), 2, 6763, to_date('05-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926001279, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 12, 3151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100523001280, to_date('23-05-2010', 'dd-mm-yyyy'), to_date('06-06-2010', 'dd-mm-yyyy'), 9, 7214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090210001281, to_date('10-02-2009', 'dd-mm-yyyy'), to_date('24-02-2009', 'dd-mm-yyyy'), 10, 6998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030721001282, to_date('21-07-2003', 'dd-mm-yyyy'), to_date('04-08-2003', 'dd-mm-yyyy'), 6, 2880, to_date('29-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040312001283, to_date('12-03-2004', 'dd-mm-yyyy'), to_date('26-03-2004', 'dd-mm-yyyy'), 9, 5445, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081226001284, to_date('26-12-2008', 'dd-mm-yyyy'), to_date('09-01-2009', 'dd-mm-yyyy'), 3, 7867, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522001285, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 2, 6785, to_date('27-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080514001286, to_date('14-05-2008', 'dd-mm-yyyy'), to_date('28-05-2008', 'dd-mm-yyyy'), 1, 4892, to_date('02-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918001287, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 3, 2962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050518001288, to_date('18-05-2005', 'dd-mm-yyyy'), to_date('01-06-2005', 'dd-mm-yyyy'), 9, 4090, to_date('02-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809001289, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 6, 2613, to_date('15-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031227001290, to_date('27-12-2003', 'dd-mm-yyyy'), to_date('10-01-2004', 'dd-mm-yyyy'), 11, 2524, to_date('29-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821001291, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 2, 3787, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100326001292, to_date('26-03-2010', 'dd-mm-yyyy'), to_date('09-04-2010', 'dd-mm-yyyy'), 3, 4933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090822001293, to_date('22-08-2009', 'dd-mm-yyyy'), to_date('05-09-2009', 'dd-mm-yyyy'), 6, 7923, to_date('31-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070608001294, to_date('08-06-2007', 'dd-mm-yyyy'), to_date('22-06-2007', 'dd-mm-yyyy'), 6, 5203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090110001295, to_date('10-01-2009', 'dd-mm-yyyy'), to_date('24-01-2009', 'dd-mm-yyyy'), 11, 6867, to_date('29-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000328001296, to_date('28-03-2000', 'dd-mm-yyyy'), to_date('11-04-2000', 'dd-mm-yyyy'), 9, 1300, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826001297, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 7, 2888, to_date('09-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722001298, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 6, 7769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010324001299, to_date('24-03-2001', 'dd-mm-yyyy'), to_date('07-04-2001', 'dd-mm-yyyy'), 11, 1156, to_date('01-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091105001300, to_date('05-11-2009', 'dd-mm-yyyy'), to_date('19-11-2009', 'dd-mm-yyyy'), 3, 5494, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130720001301, to_date('20-07-2013', 'dd-mm-yyyy'), to_date('03-08-2013', 'dd-mm-yyyy'), 9, 8677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000731001302, to_date('31-07-2000', 'dd-mm-yyyy'), to_date('14-08-2000', 'dd-mm-yyyy'), 11, 2531, to_date('11-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128001303, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 9, 4098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010925001304, to_date('25-09-2001', 'dd-mm-yyyy'), to_date('09-10-2001', 'dd-mm-yyyy'), 2, 2416, to_date('03-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081008001305, to_date('08-10-2008', 'dd-mm-yyyy'), to_date('22-10-2008', 'dd-mm-yyyy'), 1, 5876, to_date('12-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620001306, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 11, 7621, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010518001307, to_date('18-05-2001', 'dd-mm-yyyy'), to_date('01-06-2001', 'dd-mm-yyyy'), 2, 2360, to_date('06-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140219001308, to_date('19-02-2014', 'dd-mm-yyyy'), to_date('05-03-2014', 'dd-mm-yyyy'), 2, 9295, to_date('07-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221001309, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 2, 8142, to_date('06-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010420001310, to_date('20-04-2001', 'dd-mm-yyyy'), to_date('04-05-2001', 'dd-mm-yyyy'), 7, 1271, to_date('27-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010516001311, to_date('16-05-2001', 'dd-mm-yyyy'), to_date('30-05-2001', 'dd-mm-yyyy'), 6, 3579, to_date('18-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051223001312, to_date('23-12-2005', 'dd-mm-yyyy'), to_date('06-01-2006', 'dd-mm-yyyy'), 9, 4190, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040415001313, to_date('15-04-2004', 'dd-mm-yyyy'), to_date('29-04-2004', 'dd-mm-yyyy'), 10, 5138, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080328001314, to_date('28-03-2008', 'dd-mm-yyyy'), to_date('11-04-2008', 'dd-mm-yyyy'), 8, 5103, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080719001315, to_date('19-07-2008', 'dd-mm-yyyy'), to_date('02-08-2008', 'dd-mm-yyyy'), 3, 6463, to_date('22-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030305001316, to_date('05-03-2003', 'dd-mm-yyyy'), to_date('19-03-2003', 'dd-mm-yyyy'), 7, 3071, to_date('11-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130215001317, to_date('15-02-2013', 'dd-mm-yyyy'), to_date('01-03-2013', 'dd-mm-yyyy'), 10, 9861, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000812001318, to_date('12-08-2000', 'dd-mm-yyyy'), to_date('26-08-2000', 'dd-mm-yyyy'), 11, 1604, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912001319, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 3, 6015, to_date('30-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080215001320, to_date('15-02-2008', 'dd-mm-yyyy'), to_date('29-02-2008', 'dd-mm-yyyy'), 12, 5153, to_date('02-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030829001321, to_date('29-08-2003', 'dd-mm-yyyy'), to_date('12-09-2003', 'dd-mm-yyyy'), 12, 2987, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130515001322, to_date('15-05-2013', 'dd-mm-yyyy'), to_date('29-05-2013', 'dd-mm-yyyy'), 5, 12418, to_date('19-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000922001323, to_date('22-09-2000', 'dd-mm-yyyy'), to_date('06-10-2000', 'dd-mm-yyyy'), 8, 2567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091123001324, to_date('23-11-2009', 'dd-mm-yyyy'), to_date('07-12-2009', 'dd-mm-yyyy'), 6, 7954, to_date('08-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091014001325, to_date('14-10-2009', 'dd-mm-yyyy'), to_date('28-10-2009', 'dd-mm-yyyy'), 9, 6481, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000707001326, to_date('07-07-2000', 'dd-mm-yyyy'), to_date('21-07-2000', 'dd-mm-yyyy'), 2, 1003, to_date('26-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090106001327, to_date('06-01-2009', 'dd-mm-yyyy'), to_date('20-01-2009', 'dd-mm-yyyy'), 11, 7587, to_date('22-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080915001328, to_date('15-09-2008', 'dd-mm-yyyy'), to_date('29-09-2008', 'dd-mm-yyyy'), 6, 6189, to_date('17-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903001329, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 6, 5530, to_date('20-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926001330, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 8, 9015, to_date('14-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100912001331, to_date('12-09-2010', 'dd-mm-yyyy'), to_date('26-09-2010', 'dd-mm-yyyy'), 9, 8084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030126001332, to_date('26-01-2003', 'dd-mm-yyyy'), to_date('09-02-2003', 'dd-mm-yyyy'), 12, 2063, to_date('07-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009001333, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 6, 1358, to_date('19-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030506001334, to_date('06-05-2003', 'dd-mm-yyyy'), to_date('20-05-2003', 'dd-mm-yyyy'), 3, 5108, to_date('13-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110001335, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 3, 5590, to_date('15-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071230001336, to_date('30-12-2007', 'dd-mm-yyyy'), to_date('13-01-2008', 'dd-mm-yyyy'), 7, 4853, to_date('10-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410001337, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 2, 5787, to_date('13-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080208001338, to_date('08-02-2008', 'dd-mm-yyyy'), to_date('22-02-2008', 'dd-mm-yyyy'), 5, 6874, to_date('23-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050508001339, to_date('08-05-2005', 'dd-mm-yyyy'), to_date('22-05-2005', 'dd-mm-yyyy'), 4, 3428, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212001340, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 6, 4103, to_date('15-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121107001341, to_date('07-11-2012', 'dd-mm-yyyy'), to_date('21-11-2012', 'dd-mm-yyyy'), 6, 8721, to_date('15-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011107001342, to_date('07-11-2001', 'dd-mm-yyyy'), to_date('21-11-2001', 'dd-mm-yyyy'), 7, 3335, to_date('10-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041127001343, to_date('27-11-2004', 'dd-mm-yyyy'), to_date('11-12-2004', 'dd-mm-yyyy'), 11, 3521, to_date('05-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071203001344, to_date('03-12-2007', 'dd-mm-yyyy'), to_date('17-12-2007', 'dd-mm-yyyy'), 3, 5574, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040121001345, to_date('21-01-2004', 'dd-mm-yyyy'), to_date('04-02-2004', 'dd-mm-yyyy'), 4, 3505, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040312001346, to_date('12-03-2004', 'dd-mm-yyyy'), to_date('26-03-2004', 'dd-mm-yyyy'), 8, 2456, to_date('24-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129001347, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 11, 4408, to_date('07-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020403001348, to_date('03-04-2002', 'dd-mm-yyyy'), to_date('17-04-2002', 'dd-mm-yyyy'), 11, 3090, to_date('13-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100124001349, to_date('24-01-2010', 'dd-mm-yyyy'), to_date('07-02-2010', 'dd-mm-yyyy'), 10, 7901, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030422001350, to_date('22-04-2003', 'dd-mm-yyyy'), to_date('06-05-2003', 'dd-mm-yyyy'), 9, 2851, to_date('12-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100619001351, to_date('19-06-2010', 'dd-mm-yyyy'), to_date('03-07-2010', 'dd-mm-yyyy'), 4, 5962, to_date('25-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405001352, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 8, 2879, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110903001353, to_date('03-09-2011', 'dd-mm-yyyy'), to_date('17-09-2011', 'dd-mm-yyyy'), 12, 6294, to_date('13-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071102001354, to_date('02-11-2007', 'dd-mm-yyyy'), to_date('16-11-2007', 'dd-mm-yyyy'), 11, 4741, to_date('11-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140305001355, to_date('05-03-2014', 'dd-mm-yyyy'), to_date('19-03-2014', 'dd-mm-yyyy'), 11, 11093, to_date('07-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020227001356, to_date('27-02-2002', 'dd-mm-yyyy'), to_date('13-03-2002', 'dd-mm-yyyy'), 9, 3792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091110001357, to_date('10-11-2009', 'dd-mm-yyyy'), to_date('24-11-2009', 'dd-mm-yyyy'), 3, 4871, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110102001358, to_date('02-01-2011', 'dd-mm-yyyy'), to_date('16-01-2011', 'dd-mm-yyyy'), 6, 7029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120912001359, to_date('12-09-2012', 'dd-mm-yyyy'), to_date('26-09-2012', 'dd-mm-yyyy'), 5, 7499, to_date('24-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130907001360, to_date('07-09-2013', 'dd-mm-yyyy'), to_date('21-09-2013', 'dd-mm-yyyy'), 7, 10357, to_date('27-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140509001361, to_date('09-05-2014', 'dd-mm-yyyy'), to_date('23-05-2014', 'dd-mm-yyyy'), 2, 9012, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140217001362, to_date('17-02-2014', 'dd-mm-yyyy'), to_date('03-03-2014', 'dd-mm-yyyy'), 4, 10808, to_date('24-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050104001363, to_date('04-01-2005', 'dd-mm-yyyy'), to_date('18-01-2005', 'dd-mm-yyyy'), 3, 4865, to_date('14-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030228001364, to_date('28-02-2003', 'dd-mm-yyyy'), to_date('14-03-2003', 'dd-mm-yyyy'), 3, 3584, to_date('15-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120609001365, to_date('09-06-2012', 'dd-mm-yyyy'), to_date('23-06-2012', 'dd-mm-yyyy'), 6, 7935, to_date('28-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090829001366, to_date('29-08-2009', 'dd-mm-yyyy'), to_date('12-09-2009', 'dd-mm-yyyy'), 8, 7056, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081009001367, to_date('09-10-2008', 'dd-mm-yyyy'), to_date('23-10-2008', 'dd-mm-yyyy'), 7, 5478, to_date('25-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100117001368, to_date('17-01-2010', 'dd-mm-yyyy'), to_date('31-01-2010', 'dd-mm-yyyy'), 6, 5685, to_date('29-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909001369, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 3, 6652, to_date('18-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071219001370, to_date('19-12-2007', 'dd-mm-yyyy'), to_date('02-01-2008', 'dd-mm-yyyy'), 1, 4914, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723001371, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 1, 2377, to_date('28-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410001372, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 2, 5706, to_date('15-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100622001373, to_date('22-06-2010', 'dd-mm-yyyy'), to_date('06-07-2010', 'dd-mm-yyyy'), 8, 7043, to_date('29-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028001374, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 11, 6143, to_date('14-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110412003678, to_date('12-04-2011', 'dd-mm-yyyy'), to_date('26-04-2011', 'dd-mm-yyyy'), 9, 6262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040226003679, to_date('26-02-2004', 'dd-mm-yyyy'), to_date('11-03-2004', 'dd-mm-yyyy'), 6, 5663, to_date('08-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304003680, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 2, 1555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010409003681, to_date('09-04-2001', 'dd-mm-yyyy'), to_date('23-04-2001', 'dd-mm-yyyy'), 2, 1811, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413003682, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 8, 7643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140304003683, to_date('04-03-2014', 'dd-mm-yyyy'), to_date('18-03-2014', 'dd-mm-yyyy'), 6, 8667, to_date('07-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040106003684, to_date('06-01-2004', 'dd-mm-yyyy'), to_date('20-01-2004', 'dd-mm-yyyy'), 6, 3446, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010909003685, to_date('09-09-2001', 'dd-mm-yyyy'), to_date('23-09-2001', 'dd-mm-yyyy'), 6, 2862, to_date('24-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507003686, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 8, 1831, to_date('19-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060514003687, to_date('14-05-2006', 'dd-mm-yyyy'), to_date('28-05-2006', 'dd-mm-yyyy'), 3, 3603, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140419003688, to_date('19-04-2014', 'dd-mm-yyyy'), to_date('03-05-2014', 'dd-mm-yyyy'), 8, 7957, to_date('27-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127003689, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 11, 6446, to_date('07-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130613003690, to_date('13-06-2013', 'dd-mm-yyyy'), to_date('27-06-2013', 'dd-mm-yyyy'), 7, 5473, to_date('29-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723003691, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 3, 8251, to_date('07-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421003692, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 10, 3652, to_date('08-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110908003693, to_date('08-09-2011', 'dd-mm-yyyy'), to_date('22-09-2011', 'dd-mm-yyyy'), 5, 7914, to_date('24-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714003694, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 10, 1801, to_date('21-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122003695, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 7, 6034, to_date('24-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120520003696, to_date('20-05-2012', 'dd-mm-yyyy'), to_date('03-06-2012', 'dd-mm-yyyy'), 1, 9079, to_date('30-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060622003697, to_date('22-06-2006', 'dd-mm-yyyy'), to_date('06-07-2006', 'dd-mm-yyyy'), 2, 4936, to_date('06-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111003698, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 1, 7429, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011111003699, to_date('11-11-2001', 'dd-mm-yyyy'), to_date('25-11-2001', 'dd-mm-yyyy'), 11, 2062, to_date('20-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316003700, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 8, 4828, to_date('23-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090904003701, to_date('04-09-2009', 'dd-mm-yyyy'), to_date('18-09-2009', 'dd-mm-yyyy'), 11, 6669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120103003702, to_date('03-01-2012', 'dd-mm-yyyy'), to_date('17-01-2012', 'dd-mm-yyyy'), 4, 9898, to_date('22-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050203003703, to_date('03-02-2005', 'dd-mm-yyyy'), to_date('17-02-2005', 'dd-mm-yyyy'), 4, 4757, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031005003704, to_date('05-10-2003', 'dd-mm-yyyy'), to_date('19-10-2003', 'dd-mm-yyyy'), 3, 2187, to_date('12-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020414003705, to_date('14-04-2002', 'dd-mm-yyyy'), to_date('28-04-2002', 'dd-mm-yyyy'), 3, 2616, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060727003706, to_date('27-07-2006', 'dd-mm-yyyy'), to_date('10-08-2006', 'dd-mm-yyyy'), 5, 5094, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105003707, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 4, 9061, to_date('22-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703003708, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 6, 2025, to_date('19-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140128003709, to_date('28-01-2014', 'dd-mm-yyyy'), to_date('11-02-2014', 'dd-mm-yyyy'), 10, 7996, to_date('17-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516003710, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 12, 4881, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080227003711, to_date('27-02-2008', 'dd-mm-yyyy'), to_date('12-03-2008', 'dd-mm-yyyy'), 3, 6085, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110727003712, to_date('27-07-2011', 'dd-mm-yyyy'), to_date('10-08-2011', 'dd-mm-yyyy'), 12, 6712, to_date('29-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000406003713, to_date('06-04-2000', 'dd-mm-yyyy'), to_date('20-04-2000', 'dd-mm-yyyy'), 11, 1090, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513003714, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 8, 6985, to_date('29-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070713003715, to_date('13-07-2007', 'dd-mm-yyyy'), to_date('27-07-2007', 'dd-mm-yyyy'), 9, 4923, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830003716, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 6, 8303, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210003717, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 5, 4405, to_date('16-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912003718, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 12, 1892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091008003719, to_date('08-10-2009', 'dd-mm-yyyy'), to_date('22-10-2009', 'dd-mm-yyyy'), 6, 6901, to_date('23-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080802003720, to_date('02-08-2008', 'dd-mm-yyyy'), to_date('16-08-2008', 'dd-mm-yyyy'), 11, 6669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101112003721, to_date('12-11-2010', 'dd-mm-yyyy'), to_date('26-11-2010', 'dd-mm-yyyy'), 2, 5567, to_date('21-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815003722, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 7, 2715, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923003723, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 12, 913, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131022003724, to_date('22-10-2013', 'dd-mm-yyyy'), to_date('05-11-2013', 'dd-mm-yyyy'), 8, 8629, to_date('25-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030928003725, to_date('28-09-2003', 'dd-mm-yyyy'), to_date('12-10-2003', 'dd-mm-yyyy'), 2, 2654, to_date('30-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000730003726, to_date('30-07-2000', 'dd-mm-yyyy'), to_date('13-08-2000', 'dd-mm-yyyy'), 11, 728, to_date('17-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011020003727, to_date('20-10-2001', 'dd-mm-yyyy'), to_date('03-11-2001', 'dd-mm-yyyy'), 8, 1762, to_date('08-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402003728, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 11, 6256, to_date('16-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410003729, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 4, 4822, to_date('22-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101207003730, to_date('07-12-2010', 'dd-mm-yyyy'), to_date('21-12-2010', 'dd-mm-yyyy'), 6, 10602, to_date('13-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030205003731, to_date('05-02-2003', 'dd-mm-yyyy'), to_date('19-02-2003', 'dd-mm-yyyy'), 9, 2510, to_date('21-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102003732, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 1, 3059, to_date('13-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090327003733, to_date('27-03-2009', 'dd-mm-yyyy'), to_date('10-04-2009', 'dd-mm-yyyy'), 7, 7020, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050430003734, to_date('30-04-2005', 'dd-mm-yyyy'), to_date('14-05-2005', 'dd-mm-yyyy'), 8, 6315, to_date('02-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021222003735, to_date('22-12-2002', 'dd-mm-yyyy'), to_date('05-01-2003', 'dd-mm-yyyy'), 5, 1750, to_date('01-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010615003736, to_date('15-06-2001', 'dd-mm-yyyy'), to_date('29-06-2001', 'dd-mm-yyyy'), 4, 1169, to_date('18-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111003737, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 12, 6571, to_date('15-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020425003738, to_date('25-04-2002', 'dd-mm-yyyy'), to_date('09-05-2002', 'dd-mm-yyyy'), 3, 3497, to_date('09-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100721003739, to_date('21-07-2010', 'dd-mm-yyyy'), to_date('04-08-2010', 'dd-mm-yyyy'), 10, 6799, to_date('08-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131125003740, to_date('25-11-2013', 'dd-mm-yyyy'), to_date('09-12-2013', 'dd-mm-yyyy'), 11, 8204, to_date('08-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111022003741, to_date('22-10-2011', 'dd-mm-yyyy'), to_date('05-11-2011', 'dd-mm-yyyy'), 9, 4780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302003742, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 3, 2244, to_date('09-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070904003743, to_date('04-09-2007', 'dd-mm-yyyy'), to_date('18-09-2007', 'dd-mm-yyyy'), 6, 6985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120812003744, to_date('12-08-2012', 'dd-mm-yyyy'), to_date('26-08-2012', 'dd-mm-yyyy'), 10, 10971, to_date('15-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121117003745, to_date('17-11-2012', 'dd-mm-yyyy'), to_date('01-12-2012', 'dd-mm-yyyy'), 7, 8203, to_date('24-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319003746, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 6, 2500, to_date('21-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110003747, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 4, 8473, to_date('20-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100422003748, to_date('22-04-2010', 'dd-mm-yyyy'), to_date('06-05-2010', 'dd-mm-yyyy'), 1, 6556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070625003749, to_date('25-06-2007', 'dd-mm-yyyy'), to_date('09-07-2007', 'dd-mm-yyyy'), 9, 5398, to_date('03-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202003750, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 9, 6794, to_date('10-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030710003751, to_date('10-07-2003', 'dd-mm-yyyy'), to_date('24-07-2003', 'dd-mm-yyyy'), 9, 3602, to_date('18-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010217003752, to_date('17-02-2001', 'dd-mm-yyyy'), to_date('03-03-2001', 'dd-mm-yyyy'), 11, 3489, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204003753, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 8, 2607, to_date('07-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050716003754, to_date('16-07-2005', 'dd-mm-yyyy'), to_date('30-07-2005', 'dd-mm-yyyy'), 4, 6947, to_date('28-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130917003755, to_date('17-09-2013', 'dd-mm-yyyy'), to_date('01-10-2013', 'dd-mm-yyyy'), 9, 9343, to_date('22-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130826003756, to_date('26-08-2013', 'dd-mm-yyyy'), to_date('09-09-2013', 'dd-mm-yyyy'), 12, 4949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523003757, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 8, 3821, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120124003758, to_date('24-01-2012', 'dd-mm-yyyy'), to_date('07-02-2012', 'dd-mm-yyyy'), 9, 7159, to_date('08-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121023003759, to_date('23-10-2012', 'dd-mm-yyyy'), to_date('06-11-2012', 'dd-mm-yyyy'), 9, 9589, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030327003760, to_date('27-03-2003', 'dd-mm-yyyy'), to_date('10-04-2003', 'dd-mm-yyyy'), 3, 3121, to_date('29-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225003761, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 5, 5070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131101003762, to_date('01-11-2013', 'dd-mm-yyyy'), to_date('15-11-2013', 'dd-mm-yyyy'), 10, 9232, to_date('12-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812003763, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 5, 7144, to_date('28-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060429003764, to_date('29-04-2006', 'dd-mm-yyyy'), to_date('13-05-2006', 'dd-mm-yyyy'), 5, 4411, to_date('16-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100412003765, to_date('12-04-2010', 'dd-mm-yyyy'), to_date('26-04-2010', 'dd-mm-yyyy'), 5, 8146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004003766, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 11, 7462, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011104003767, to_date('04-11-2001', 'dd-mm-yyyy'), to_date('18-11-2001', 'dd-mm-yyyy'), 3, 2881, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830003768, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 2, 3742, to_date('16-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009003769, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 8, 8943, to_date('16-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213003770, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 8, 5633, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100811003771, to_date('11-08-2010', 'dd-mm-yyyy'), to_date('25-08-2010', 'dd-mm-yyyy'), 4, 8347, to_date('18-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010523003772, to_date('23-05-2001', 'dd-mm-yyyy'), to_date('06-06-2001', 'dd-mm-yyyy'), 10, 634, to_date('03-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208003773, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 6, 8598, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010116003774, to_date('16-01-2001', 'dd-mm-yyyy'), to_date('30-01-2001', 'dd-mm-yyyy'), 11, 1822, to_date('30-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020913003775, to_date('13-09-2002', 'dd-mm-yyyy'), to_date('27-09-2002', 'dd-mm-yyyy'), 1, 2887, to_date('21-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040222003776, to_date('22-02-2004', 'dd-mm-yyyy'), to_date('07-03-2004', 'dd-mm-yyyy'), 10, 3021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060517003777, to_date('17-05-2006', 'dd-mm-yyyy'), to_date('31-05-2006', 'dd-mm-yyyy'), 3, 5835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070815003778, to_date('15-08-2007', 'dd-mm-yyyy'), to_date('29-08-2007', 'dd-mm-yyyy'), 11, 6215, to_date('26-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024003779, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 9, 8049, to_date('12-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120109003780, to_date('09-01-2012', 'dd-mm-yyyy'), to_date('23-01-2012', 'dd-mm-yyyy'), 6, 8361, to_date('12-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051203003781, to_date('03-12-2005', 'dd-mm-yyyy'), to_date('17-12-2005', 'dd-mm-yyyy'), 3, 3275, to_date('16-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070102003782, to_date('02-01-2007', 'dd-mm-yyyy'), to_date('16-01-2007', 'dd-mm-yyyy'), 11, 4101, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060524003783, to_date('24-05-2006', 'dd-mm-yyyy'), to_date('07-06-2006', 'dd-mm-yyyy'), 6, 5825, to_date('11-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104003784, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 7, 6019, to_date('17-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041011003785, to_date('11-10-2004', 'dd-mm-yyyy'), to_date('25-10-2004', 'dd-mm-yyyy'), 3, 3999, to_date('19-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050604003786, to_date('04-06-2005', 'dd-mm-yyyy'), to_date('18-06-2005', 'dd-mm-yyyy'), 6, 4706, to_date('19-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000904003787, to_date('04-09-2000', 'dd-mm-yyyy'), to_date('18-09-2000', 'dd-mm-yyyy'), 7, 1181, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050723003788, to_date('23-07-2005', 'dd-mm-yyyy'), to_date('06-08-2005', 'dd-mm-yyyy'), 8, 3432, to_date('30-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924003789, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 6, 2346, to_date('09-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051014003790, to_date('14-10-2005', 'dd-mm-yyyy'), to_date('28-10-2005', 'dd-mm-yyyy'), 9, 5140, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121219003791, to_date('19-12-2012', 'dd-mm-yyyy'), to_date('02-01-2013', 'dd-mm-yyyy'), 6, 8499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040305003792, to_date('05-03-2004', 'dd-mm-yyyy'), to_date('19-03-2004', 'dd-mm-yyyy'), 9, 6802, to_date('13-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051207003793, to_date('07-12-2005', 'dd-mm-yyyy'), to_date('21-12-2005', 'dd-mm-yyyy'), 9, 3567, to_date('21-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110801003794, to_date('01-08-2011', 'dd-mm-yyyy'), to_date('15-08-2011', 'dd-mm-yyyy'), 8, 8786, to_date('11-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201003795, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 10, 5659, to_date('21-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140415003796, to_date('15-04-2014', 'dd-mm-yyyy'), to_date('29-04-2014', 'dd-mm-yyyy'), 10, 8258, to_date('21-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080110003797, to_date('10-01-2008', 'dd-mm-yyyy'), to_date('24-01-2008', 'dd-mm-yyyy'), 6, 6431, to_date('21-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050820003798, to_date('20-08-2005', 'dd-mm-yyyy'), to_date('03-09-2005', 'dd-mm-yyyy'), 8, 5279, to_date('08-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505003799, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 3, 5524, to_date('22-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070517003800, to_date('17-05-2007', 'dd-mm-yyyy'), to_date('31-05-2007', 'dd-mm-yyyy'), 8, 6867, to_date('04-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060314003801, to_date('14-03-2006', 'dd-mm-yyyy'), to_date('28-03-2006', 'dd-mm-yyyy'), 4, 4482, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020926003802, to_date('26-09-2002', 'dd-mm-yyyy'), to_date('10-10-2002', 'dd-mm-yyyy'), 5, 1568, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409003803, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 1, 5920, to_date('12-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408003804, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 2, 9133, to_date('18-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061201003805, to_date('01-12-2006', 'dd-mm-yyyy'), to_date('15-12-2006', 'dd-mm-yyyy'), 7, 3380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090330003806, to_date('30-03-2009', 'dd-mm-yyyy'), to_date('13-04-2009', 'dd-mm-yyyy'), 8, 6515, to_date('06-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010603003807, to_date('03-06-2001', 'dd-mm-yyyy'), to_date('17-06-2001', 'dd-mm-yyyy'), 1, 2810, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020825003808, to_date('25-08-2002', 'dd-mm-yyyy'), to_date('08-09-2002', 'dd-mm-yyyy'), 11, 2705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120215003809, to_date('15-02-2012', 'dd-mm-yyyy'), to_date('29-02-2012', 'dd-mm-yyyy'), 10, 9751, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020726003810, to_date('26-07-2002', 'dd-mm-yyyy'), to_date('09-08-2002', 'dd-mm-yyyy'), 5, 3246, to_date('29-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050218003811, to_date('18-02-2005', 'dd-mm-yyyy'), to_date('04-03-2005', 'dd-mm-yyyy'), 7, 4658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120214003812, to_date('14-02-2012', 'dd-mm-yyyy'), to_date('28-02-2012', 'dd-mm-yyyy'), 8, 7340, to_date('22-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010927003813, to_date('27-09-2001', 'dd-mm-yyyy'), to_date('11-10-2001', 'dd-mm-yyyy'), 4, 1315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118003814, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 8, 3281, to_date('20-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100427003815, to_date('27-04-2010', 'dd-mm-yyyy'), to_date('11-05-2010', 'dd-mm-yyyy'), 4, 7470, to_date('02-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110130003816, to_date('30-01-2011', 'dd-mm-yyyy'), to_date('13-02-2011', 'dd-mm-yyyy'), 9, 8813, to_date('03-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080926003817, to_date('26-09-2008', 'dd-mm-yyyy'), to_date('10-10-2008', 'dd-mm-yyyy'), 3, 6712, to_date('28-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040110003818, to_date('10-01-2004', 'dd-mm-yyyy'), to_date('24-01-2004', 'dd-mm-yyyy'), 10, 5008, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620003819, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 9, 7747, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030602003820, to_date('02-06-2003', 'dd-mm-yyyy'), to_date('16-06-2003', 'dd-mm-yyyy'), 3, 4286, to_date('15-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140119003821, to_date('19-01-2014', 'dd-mm-yyyy'), to_date('02-02-2014', 'dd-mm-yyyy'), 8, 10487, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011015003822, to_date('15-10-2001', 'dd-mm-yyyy'), to_date('29-10-2001', 'dd-mm-yyyy'), 8, 2063, to_date('22-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060108003823, to_date('08-01-2006', 'dd-mm-yyyy'), to_date('22-01-2006', 'dd-mm-yyyy'), 5, 4491, to_date('24-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031121003824, to_date('21-11-2003', 'dd-mm-yyyy'), to_date('05-12-2003', 'dd-mm-yyyy'), 11, 4548, to_date('01-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000502003825, to_date('02-05-2000', 'dd-mm-yyyy'), to_date('16-05-2000', 'dd-mm-yyyy'), 3, 2489, to_date('05-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070114003826, to_date('14-01-2007', 'dd-mm-yyyy'), to_date('28-01-2007', 'dd-mm-yyyy'), 9, 6630, to_date('01-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121003827, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 8, 6581, to_date('29-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023003828, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 4, 4838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040524003829, to_date('24-05-2004', 'dd-mm-yyyy'), to_date('07-06-2004', 'dd-mm-yyyy'), 6, 2058, to_date('04-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091015003830, to_date('15-10-2009', 'dd-mm-yyyy'), to_date('29-10-2009', 'dd-mm-yyyy'), 2, 7069, to_date('19-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130616005968, to_date('16-06-2013', 'dd-mm-yyyy'), to_date('30-06-2013', 'dd-mm-yyyy'), 10, 9496, to_date('03-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080928005969, to_date('28-09-2008', 'dd-mm-yyyy'), to_date('12-10-2008', 'dd-mm-yyyy'), 6, 8266, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120321005970, to_date('21-03-2012', 'dd-mm-yyyy'), to_date('04-04-2012', 'dd-mm-yyyy'), 1, 9339, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208005971, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 8, 5937, to_date('13-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030227005972, to_date('27-02-2003', 'dd-mm-yyyy'), to_date('13-03-2003', 'dd-mm-yyyy'), 12, 4090, to_date('04-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728005973, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 11, 5557, to_date('02-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110703005974, to_date('03-07-2011', 'dd-mm-yyyy'), to_date('17-07-2011', 'dd-mm-yyyy'), 5, 7354, to_date('16-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722005975, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 5, 9126, to_date('25-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031108005976, to_date('08-11-2003', 'dd-mm-yyyy'), to_date('22-11-2003', 'dd-mm-yyyy'), 9, 3146, to_date('27-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070106005977, to_date('06-01-2007', 'dd-mm-yyyy'), to_date('20-01-2007', 'dd-mm-yyyy'), 3, 4948, to_date('19-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070909005978, to_date('09-09-2007', 'dd-mm-yyyy'), to_date('23-09-2007', 'dd-mm-yyyy'), 10, 4183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100729005979, to_date('29-07-2010', 'dd-mm-yyyy'), to_date('12-08-2010', 'dd-mm-yyyy'), 7, 8446, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040728005980, to_date('28-07-2004', 'dd-mm-yyyy'), to_date('11-08-2004', 'dd-mm-yyyy'), 6, 3694, to_date('31-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811005981, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 10, 2060, to_date('25-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020216005982, to_date('16-02-2002', 'dd-mm-yyyy'), to_date('02-03-2002', 'dd-mm-yyyy'), 3, 3749, to_date('22-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802005983, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 2, 7086, to_date('12-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921005984, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 6, 5613, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512005985, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 10, 3058, to_date('24-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130210005986, to_date('10-02-2013', 'dd-mm-yyyy'), to_date('24-02-2013', 'dd-mm-yyyy'), 5, 12068, to_date('15-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011027005987, to_date('27-10-2001', 'dd-mm-yyyy'), to_date('10-11-2001', 'dd-mm-yyyy'), 5, 1262, to_date('29-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060305005988, to_date('05-03-2006', 'dd-mm-yyyy'), to_date('19-03-2006', 'dd-mm-yyyy'), 6, 6831, to_date('09-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711005989, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 5, 7280, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081108005990, to_date('08-11-2008', 'dd-mm-yyyy'), to_date('22-11-2008', 'dd-mm-yyyy'), 11, 6855, to_date('26-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061024005991, to_date('24-10-2006', 'dd-mm-yyyy'), to_date('07-11-2006', 'dd-mm-yyyy'), 8, 6052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020714005992, to_date('14-07-2002', 'dd-mm-yyyy'), to_date('28-07-2002', 'dd-mm-yyyy'), 11, 3996, to_date('25-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030612005993, to_date('12-06-2003', 'dd-mm-yyyy'), to_date('26-06-2003', 'dd-mm-yyyy'), 12, 3683, to_date('18-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331005994, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 4, 8493, to_date('12-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714005995, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 2, 7445, to_date('25-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120916005996, to_date('16-09-2012', 'dd-mm-yyyy'), to_date('30-09-2012', 'dd-mm-yyyy'), 4, 7851, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020530005997, to_date('30-05-2002', 'dd-mm-yyyy'), to_date('13-06-2002', 'dd-mm-yyyy'), 2, 3580, to_date('05-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008005998, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 5, 2747, to_date('25-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030709005999, to_date('09-07-2003', 'dd-mm-yyyy'), to_date('23-07-2003', 'dd-mm-yyyy'), 6, 3998, to_date('10-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030905006000, to_date('05-09-2003', 'dd-mm-yyyy'), to_date('19-09-2003', 'dd-mm-yyyy'), 3, 2510, to_date('20-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729006001, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 8, 9587, to_date('03-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003006002, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 4, 2591, to_date('10-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061115006003, to_date('15-11-2006', 'dd-mm-yyyy'), to_date('29-11-2006', 'dd-mm-yyyy'), 1, 7382, to_date('28-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413006004, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 1, 9724, to_date('23-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130427006005, to_date('27-04-2013', 'dd-mm-yyyy'), to_date('11-05-2013', 'dd-mm-yyyy'), 5, 11755, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110118006006, to_date('18-01-2011', 'dd-mm-yyyy'), to_date('01-02-2011', 'dd-mm-yyyy'), 10, 8937, to_date('23-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712006007, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 2, 5425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050923006008, to_date('23-09-2005', 'dd-mm-yyyy'), to_date('07-10-2005', 'dd-mm-yyyy'), 5, 4145, to_date('30-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110828006009, to_date('28-08-2011', 'dd-mm-yyyy'), to_date('11-09-2011', 'dd-mm-yyyy'), 6, 7843, to_date('11-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090907006010, to_date('07-09-2009', 'dd-mm-yyyy'), to_date('21-09-2009', 'dd-mm-yyyy'), 10, 6711, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020402006011, to_date('02-04-2002', 'dd-mm-yyyy'), to_date('16-04-2002', 'dd-mm-yyyy'), 6, 3771, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604006012, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 7, 6643, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040310006013, to_date('10-03-2004', 'dd-mm-yyyy'), to_date('24-03-2004', 'dd-mm-yyyy'), 7, 3117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030502006014, to_date('02-05-2003', 'dd-mm-yyyy'), to_date('16-05-2003', 'dd-mm-yyyy'), 7, 2991, to_date('10-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080410006015, to_date('10-04-2008', 'dd-mm-yyyy'), to_date('24-04-2008', 'dd-mm-yyyy'), 10, 5889, to_date('19-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030525006016, to_date('25-05-2003', 'dd-mm-yyyy'), to_date('08-06-2003', 'dd-mm-yyyy'), 11, 1968, to_date('04-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001219006017, to_date('19-12-2000', 'dd-mm-yyyy'), to_date('02-01-2001', 'dd-mm-yyyy'), 9, 1733, to_date('21-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120425006018, to_date('25-04-2012', 'dd-mm-yyyy'), to_date('09-05-2012', 'dd-mm-yyyy'), 7, 7461, to_date('09-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001006019, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 2, 6185, to_date('19-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122006020, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 1, 4798, to_date('03-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070506006021, to_date('06-05-2007', 'dd-mm-yyyy'), to_date('20-05-2007', 'dd-mm-yyyy'), 5, 5885, to_date('21-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010703006022, to_date('03-07-2001', 'dd-mm-yyyy'), to_date('17-07-2001', 'dd-mm-yyyy'), 10, 771, to_date('08-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019006023, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 9, 7397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130208006024, to_date('08-02-2013', 'dd-mm-yyyy'), to_date('22-02-2013', 'dd-mm-yyyy'), 2, 6935, to_date('09-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080726006025, to_date('26-07-2008', 'dd-mm-yyyy'), to_date('09-08-2008', 'dd-mm-yyyy'), 4, 5621, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829006026, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 5, 4990, to_date('12-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517006027, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 7, 6603, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020110006028, to_date('10-01-2002', 'dd-mm-yyyy'), to_date('24-01-2002', 'dd-mm-yyyy'), 2, 2069, to_date('16-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215006029, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 10, 6664, to_date('25-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110826006030, to_date('26-08-2011', 'dd-mm-yyyy'), to_date('09-09-2011', 'dd-mm-yyyy'), 2, 7214, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100822006031, to_date('22-08-2010', 'dd-mm-yyyy'), to_date('05-09-2010', 'dd-mm-yyyy'), 11, 8525, to_date('27-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010522006032, to_date('22-05-2001', 'dd-mm-yyyy'), to_date('05-06-2001', 'dd-mm-yyyy'), 12, 1917, to_date('04-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080116006033, to_date('16-01-2008', 'dd-mm-yyyy'), to_date('30-01-2008', 'dd-mm-yyyy'), 1, 4579, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080122006034, to_date('22-01-2008', 'dd-mm-yyyy'), to_date('05-02-2008', 'dd-mm-yyyy'), 2, 7693, to_date('06-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081127006035, to_date('27-11-2008', 'dd-mm-yyyy'), to_date('11-12-2008', 'dd-mm-yyyy'), 11, 7117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020221006036, to_date('21-02-2002', 'dd-mm-yyyy'), to_date('07-03-2002', 'dd-mm-yyyy'), 8, 1642, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010315006037, to_date('15-03-2001', 'dd-mm-yyyy'), to_date('29-03-2001', 'dd-mm-yyyy'), 6, 2591, to_date('20-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028006038, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 2, 7015, to_date('17-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130721006039, to_date('21-07-2013', 'dd-mm-yyyy'), to_date('04-08-2013', 'dd-mm-yyyy'), 8, 8882, to_date('03-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000720006040, to_date('20-07-2000', 'dd-mm-yyyy'), to_date('03-08-2000', 'dd-mm-yyyy'), 9, 2348, to_date('05-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120821006041, to_date('21-08-2012', 'dd-mm-yyyy'), to_date('04-09-2012', 'dd-mm-yyyy'), 4, 8663, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010930006042, to_date('30-09-2001', 'dd-mm-yyyy'), to_date('14-10-2001', 'dd-mm-yyyy'), 5, 2050, to_date('10-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070507006043, to_date('07-05-2007', 'dd-mm-yyyy'), to_date('21-05-2007', 'dd-mm-yyyy'), 9, 5137, to_date('21-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080109006044, to_date('09-01-2008', 'dd-mm-yyyy'), to_date('23-01-2008', 'dd-mm-yyyy'), 11, 5119, to_date('15-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923006045, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 3, 4797, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081128006046, to_date('28-11-2008', 'dd-mm-yyyy'), to_date('12-12-2008', 'dd-mm-yyyy'), 8, 5553, to_date('17-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100327006047, to_date('27-03-2010', 'dd-mm-yyyy'), to_date('10-04-2010', 'dd-mm-yyyy'), 3, 6430, to_date('12-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130221006048, to_date('21-02-2013', 'dd-mm-yyyy'), to_date('07-03-2013', 'dd-mm-yyyy'), 1, 7389, to_date('06-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090929006049, to_date('29-09-2009', 'dd-mm-yyyy'), to_date('13-10-2009', 'dd-mm-yyyy'), 6, 7687, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061006006050, to_date('06-10-2006', 'dd-mm-yyyy'), to_date('20-10-2006', 'dd-mm-yyyy'), 2, 5336, to_date('07-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120402006051, to_date('02-04-2012', 'dd-mm-yyyy'), to_date('16-04-2012', 'dd-mm-yyyy'), 2, 8077, to_date('06-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214006052, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 1, 2343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130006053, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 10, 3010, to_date('04-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060705006054, to_date('05-07-2006', 'dd-mm-yyyy'), to_date('19-07-2006', 'dd-mm-yyyy'), 2, 6723, to_date('10-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020214006055, to_date('14-02-2002', 'dd-mm-yyyy'), to_date('28-02-2002', 'dd-mm-yyyy'), 2, 4126, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050528006056, to_date('28-05-2005', 'dd-mm-yyyy'), to_date('11-06-2005', 'dd-mm-yyyy'), 11, 4739, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613006057, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 11, 1510, to_date('16-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000102006058, to_date('02-01-2000', 'dd-mm-yyyy'), to_date('16-01-2000', 'dd-mm-yyyy'), 4, 2756, to_date('19-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607006059, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 6, 4913, to_date('20-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030823006060, to_date('23-08-2003', 'dd-mm-yyyy'), to_date('06-09-2003', 'dd-mm-yyyy'), 6, 3580, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011010006061, to_date('10-10-2001', 'dd-mm-yyyy'), to_date('24-10-2001', 'dd-mm-yyyy'), 8, 2580, to_date('14-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060108006062, to_date('08-01-2006', 'dd-mm-yyyy'), to_date('22-01-2006', 'dd-mm-yyyy'), 8, 4347, to_date('25-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706006063, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 5, 1350, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100221006064, to_date('21-02-2010', 'dd-mm-yyyy'), to_date('07-03-2010', 'dd-mm-yyyy'), 3, 7878, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926006065, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 7, 7473, to_date('11-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060820006066, to_date('20-08-2006', 'dd-mm-yyyy'), to_date('03-09-2006', 'dd-mm-yyyy'), 9, 6697, to_date('25-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061110006067, to_date('10-11-2006', 'dd-mm-yyyy'), to_date('24-11-2006', 'dd-mm-yyyy'), 6, 5124, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323006068, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 5, 8826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101210006069, to_date('10-12-2010', 'dd-mm-yyyy'), to_date('24-12-2010', 'dd-mm-yyyy'), 10, 8036, to_date('24-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000915006070, to_date('15-09-2000', 'dd-mm-yyyy'), to_date('29-09-2000', 'dd-mm-yyyy'), 5, 2114, to_date('27-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040319006071, to_date('19-03-2004', 'dd-mm-yyyy'), to_date('02-04-2004', 'dd-mm-yyyy'), 10, 4928, to_date('04-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021017006072, to_date('17-10-2002', 'dd-mm-yyyy'), to_date('31-10-2002', 'dd-mm-yyyy'), 8, 2286, to_date('28-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000207006073, to_date('07-02-2000', 'dd-mm-yyyy'), to_date('21-02-2000', 'dd-mm-yyyy'), 10, 1525, to_date('18-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100515006074, to_date('15-05-2010', 'dd-mm-yyyy'), to_date('29-05-2010', 'dd-mm-yyyy'), 5, 6968, to_date('18-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923006075, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 7, 2769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916006076, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 8, 9280, to_date('18-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060218006077, to_date('18-02-2006', 'dd-mm-yyyy'), to_date('04-03-2006', 'dd-mm-yyyy'), 9, 6039, to_date('26-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001024006078, to_date('24-10-2000', 'dd-mm-yyyy'), to_date('07-11-2000', 'dd-mm-yyyy'), 11, 588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081107006079, to_date('07-11-2008', 'dd-mm-yyyy'), to_date('21-11-2008', 'dd-mm-yyyy'), 9, 5889, to_date('17-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070608006080, to_date('08-06-2007', 'dd-mm-yyyy'), to_date('22-06-2007', 'dd-mm-yyyy'), 7, 7379, to_date('16-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050331006081, to_date('31-03-2005', 'dd-mm-yyyy'), to_date('14-04-2005', 'dd-mm-yyyy'), 1, 4975, to_date('11-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030328006082, to_date('28-03-2003', 'dd-mm-yyyy'), to_date('11-04-2003', 'dd-mm-yyyy'), 6, 2172, to_date('15-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071211006083, to_date('11-12-2007', 'dd-mm-yyyy'), to_date('25-12-2007', 'dd-mm-yyyy'), 10, 4816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902006084, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 2, 1717, to_date('19-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010128006085, to_date('28-01-2001', 'dd-mm-yyyy'), to_date('11-02-2001', 'dd-mm-yyyy'), 11, 1861, to_date('06-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120613006086, to_date('13-06-2012', 'dd-mm-yyyy'), to_date('27-06-2012', 'dd-mm-yyyy'), 2, 9386, to_date('18-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020401006087, to_date('01-04-2002', 'dd-mm-yyyy'), to_date('15-04-2002', 'dd-mm-yyyy'), 6, 5889, to_date('17-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070826006088, to_date('26-08-2007', 'dd-mm-yyyy'), to_date('09-09-2007', 'dd-mm-yyyy'), 6, 6759, to_date('03-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050119006089, to_date('19-01-2005', 'dd-mm-yyyy'), to_date('02-02-2005', 'dd-mm-yyyy'), 12, 2954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020405006090, to_date('05-04-2002', 'dd-mm-yyyy'), to_date('19-04-2002', 'dd-mm-yyyy'), 7, 2020, to_date('16-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060128006091, to_date('28-01-2006', 'dd-mm-yyyy'), to_date('11-02-2006', 'dd-mm-yyyy'), 9, 4317, to_date('17-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116006092, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 3, 4820, to_date('27-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001129006093, to_date('29-11-2000', 'dd-mm-yyyy'), to_date('13-12-2000', 'dd-mm-yyyy'), 3, 2327, to_date('13-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000619006094, to_date('19-06-2000', 'dd-mm-yyyy'), to_date('03-07-2000', 'dd-mm-yyyy'), 3, 3102, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010313006095, to_date('13-03-2001', 'dd-mm-yyyy'), to_date('27-03-2001', 'dd-mm-yyyy'), 3, 3632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715006096, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 7, 1873, to_date('23-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121209006097, to_date('09-12-2012', 'dd-mm-yyyy'), to_date('23-12-2012', 'dd-mm-yyyy'), 3, 7913, to_date('13-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131210006098, to_date('10-12-2013', 'dd-mm-yyyy'), to_date('24-12-2013', 'dd-mm-yyyy'), 11, 8459, to_date('20-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071219006099, to_date('19-12-2007', 'dd-mm-yyyy'), to_date('02-01-2008', 'dd-mm-yyyy'), 3, 8259, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806006100, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 11, 2215, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601006101, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 5, 5766, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080207006102, to_date('07-02-2008', 'dd-mm-yyyy'), to_date('21-02-2008', 'dd-mm-yyyy'), 11, 6062, to_date('08-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101001006103, to_date('01-10-2010', 'dd-mm-yyyy'), to_date('15-10-2010', 'dd-mm-yyyy'), 2, 9543, to_date('04-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120308006104, to_date('08-03-2012', 'dd-mm-yyyy'), to_date('22-03-2012', 'dd-mm-yyyy'), 10, 8451, to_date('23-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131203006105, to_date('03-12-2013', 'dd-mm-yyyy'), to_date('17-12-2013', 'dd-mm-yyyy'), 8, 7571, to_date('12-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100616006106, to_date('16-06-2010', 'dd-mm-yyyy'), to_date('30-06-2010', 'dd-mm-yyyy'), 8, 6566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060825006107, to_date('25-08-2006', 'dd-mm-yyyy'), to_date('08-09-2006', 'dd-mm-yyyy'), 7, 2221, to_date('10-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208006108, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 10, 3747, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071116006109, to_date('16-11-2007', 'dd-mm-yyyy'), to_date('30-11-2007', 'dd-mm-yyyy'), 6, 5444, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040404006110, to_date('04-04-2004', 'dd-mm-yyyy'), to_date('18-04-2004', 'dd-mm-yyyy'), 2, 5735, to_date('12-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000509006111, to_date('09-05-2000', 'dd-mm-yyyy'), to_date('23-05-2000', 'dd-mm-yyyy'), 7, 584, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060413006112, to_date('13-04-2006', 'dd-mm-yyyy'), to_date('27-04-2006', 'dd-mm-yyyy'), 7, 7107, to_date('19-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421006113, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 3, 9012, to_date('09-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918006114, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 11, 3102, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112006115, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 9, 9888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010728006116, to_date('28-07-2001', 'dd-mm-yyyy'), to_date('11-08-2001', 'dd-mm-yyyy'), 7, 1680, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050419006117, to_date('19-04-2005', 'dd-mm-yyyy'), to_date('03-05-2005', 'dd-mm-yyyy'), 2, 3608, to_date('27-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420006118, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 3, 3143, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090701006119, to_date('01-07-2009', 'dd-mm-yyyy'), to_date('15-07-2009', 'dd-mm-yyyy'), 12, 8567, to_date('12-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040318008111, to_date('18-03-2004', 'dd-mm-yyyy'), to_date('01-04-2004', 'dd-mm-yyyy'), 9, 3445, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000810008112, to_date('10-08-2000', 'dd-mm-yyyy'), to_date('24-08-2000', 'dd-mm-yyyy'), 11, 2838, to_date('19-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101130008113, to_date('30-11-2010', 'dd-mm-yyyy'), to_date('14-12-2010', 'dd-mm-yyyy'), 10, 7514, to_date('17-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070206008114, to_date('06-02-2007', 'dd-mm-yyyy'), to_date('20-02-2007', 'dd-mm-yyyy'), 5, 3609, to_date('19-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020103008115, to_date('03-01-2002', 'dd-mm-yyyy'), to_date('17-01-2002', 'dd-mm-yyyy'), 3, 2969, to_date('05-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329008116, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 11, 7360, to_date('31-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100801008117, to_date('01-08-2010', 'dd-mm-yyyy'), to_date('15-08-2010', 'dd-mm-yyyy'), 10, 6322, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081203008118, to_date('03-12-2008', 'dd-mm-yyyy'), to_date('17-12-2008', 'dd-mm-yyyy'), 4, 7840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031222008119, to_date('22-12-2003', 'dd-mm-yyyy'), to_date('05-01-2004', 'dd-mm-yyyy'), 5, 3066, to_date('09-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031028008120, to_date('28-10-2003', 'dd-mm-yyyy'), to_date('11-11-2003', 'dd-mm-yyyy'), 8, 2443, to_date('14-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090513008121, to_date('13-05-2009', 'dd-mm-yyyy'), to_date('27-05-2009', 'dd-mm-yyyy'), 7, 6262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071224008122, to_date('24-12-2007', 'dd-mm-yyyy'), to_date('07-01-2008', 'dd-mm-yyyy'), 7, 5111, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416008123, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 7, 6925, to_date('28-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041029008124, to_date('29-10-2004', 'dd-mm-yyyy'), to_date('12-11-2004', 'dd-mm-yyyy'), 3, 4518, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100617008125, to_date('17-06-2010', 'dd-mm-yyyy'), to_date('01-07-2010', 'dd-mm-yyyy'), 12, 6867, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090129008126, to_date('29-01-2009', 'dd-mm-yyyy'), to_date('12-02-2009', 'dd-mm-yyyy'), 7, 6047, to_date('15-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080617008127, to_date('17-06-2008', 'dd-mm-yyyy'), to_date('01-07-2008', 'dd-mm-yyyy'), 5, 6122, to_date('23-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130413008128, to_date('13-04-2013', 'dd-mm-yyyy'), to_date('27-04-2013', 'dd-mm-yyyy'), 4, 9069, to_date('18-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040902008129, to_date('02-09-2004', 'dd-mm-yyyy'), to_date('16-09-2004', 'dd-mm-yyyy'), 5, 3118, to_date('05-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121206008130, to_date('06-12-2012', 'dd-mm-yyyy'), to_date('20-12-2012', 'dd-mm-yyyy'), 10, 7252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110303008131, to_date('03-03-2011', 'dd-mm-yyyy'), to_date('17-03-2011', 'dd-mm-yyyy'), 10, 6987, to_date('15-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070805008132, to_date('05-08-2007', 'dd-mm-yyyy'), to_date('19-08-2007', 'dd-mm-yyyy'), 3, 4222, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911008133, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 12, 9540, to_date('25-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091207008134, to_date('07-12-2009', 'dd-mm-yyyy'), to_date('21-12-2009', 'dd-mm-yyyy'), 6, 8254, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131024008135, to_date('24-10-2013', 'dd-mm-yyyy'), to_date('07-11-2013', 'dd-mm-yyyy'), 2, 8278, to_date('29-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110103008136, to_date('03-01-2011', 'dd-mm-yyyy'), to_date('17-01-2011', 'dd-mm-yyyy'), 2, 7591, to_date('13-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041123008137, to_date('23-11-2004', 'dd-mm-yyyy'), to_date('07-12-2004', 'dd-mm-yyyy'), 2, 4675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130902008138, to_date('02-09-2013', 'dd-mm-yyyy'), to_date('16-09-2013', 'dd-mm-yyyy'), 4, 7909, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020831008139, to_date('31-08-2002', 'dd-mm-yyyy'), to_date('14-09-2002', 'dd-mm-yyyy'), 5, 2796, to_date('18-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000924008140, to_date('24-09-2000', 'dd-mm-yyyy'), to_date('08-10-2000', 'dd-mm-yyyy'), 4, 2196, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120404008141, to_date('04-04-2012', 'dd-mm-yyyy'), to_date('18-04-2012', 'dd-mm-yyyy'), 2, 7624, to_date('14-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030117008142, to_date('17-01-2003', 'dd-mm-yyyy'), to_date('31-01-2003', 'dd-mm-yyyy'), 3, 3558, to_date('31-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604008143, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 4, 10088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101210008144, to_date('10-12-2010', 'dd-mm-yyyy'), to_date('24-12-2010', 'dd-mm-yyyy'), 10, 8239, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516008145, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 2, 4956, to_date('04-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130608008146, to_date('08-06-2013', 'dd-mm-yyyy'), to_date('22-06-2013', 'dd-mm-yyyy'), 5, 10846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050619008147, to_date('19-06-2005', 'dd-mm-yyyy'), to_date('03-07-2005', 'dd-mm-yyyy'), 5, 4679, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040122008148, to_date('22-01-2004', 'dd-mm-yyyy'), to_date('05-02-2004', 'dd-mm-yyyy'), 4, 4860, to_date('01-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080510008149, to_date('10-05-2008', 'dd-mm-yyyy'), to_date('24-05-2008', 'dd-mm-yyyy'), 7, 7002, to_date('23-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528008150, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 1, 4518, to_date('03-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000301008151, to_date('01-03-2000', 'dd-mm-yyyy'), to_date('15-03-2000', 'dd-mm-yyyy'), 6, 1475, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000925008152, to_date('25-09-2000', 'dd-mm-yyyy'), to_date('09-10-2000', 'dd-mm-yyyy'), 5, 1147, to_date('29-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050708008153, to_date('08-07-2005', 'dd-mm-yyyy'), to_date('22-07-2005', 'dd-mm-yyyy'), 8, 5699, to_date('22-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050610008154, to_date('10-06-2005', 'dd-mm-yyyy'), to_date('24-06-2005', 'dd-mm-yyyy'), 4, 4905, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140416008155, to_date('16-04-2014', 'dd-mm-yyyy'), to_date('30-04-2014', 'dd-mm-yyyy'), 11, 11134, to_date('02-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060625008156, to_date('25-06-2006', 'dd-mm-yyyy'), to_date('09-07-2006', 'dd-mm-yyyy'), 8, 3889, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111219008157, to_date('19-12-2011', 'dd-mm-yyyy'), to_date('02-01-2012', 'dd-mm-yyyy'), 11, 9200, to_date('08-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110414008158, to_date('14-04-2011', 'dd-mm-yyyy'), to_date('28-04-2011', 'dd-mm-yyyy'), 4, 7925, to_date('28-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112008159, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 6, 5429, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031110008160, to_date('10-11-2003', 'dd-mm-yyyy'), to_date('24-11-2003', 'dd-mm-yyyy'), 5, 2902, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030622008161, to_date('22-06-2003', 'dd-mm-yyyy'), to_date('06-07-2003', 'dd-mm-yyyy'), 6, 2171, to_date('08-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050216008162, to_date('16-02-2005', 'dd-mm-yyyy'), to_date('02-03-2005', 'dd-mm-yyyy'), 7, 4010, to_date('03-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060825008163, to_date('25-08-2006', 'dd-mm-yyyy'), to_date('08-09-2006', 'dd-mm-yyyy'), 12, 3077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614008164, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 11, 6127, to_date('23-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010922008165, to_date('22-09-2001', 'dd-mm-yyyy'), to_date('06-10-2001', 'dd-mm-yyyy'), 9, 1521, to_date('30-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051009008166, to_date('09-10-2005', 'dd-mm-yyyy'), to_date('23-10-2005', 'dd-mm-yyyy'), 10, 5883, to_date('15-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010830008167, to_date('30-08-2001', 'dd-mm-yyyy'), to_date('13-09-2001', 'dd-mm-yyyy'), 10, 1991, to_date('12-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010623008168, to_date('23-06-2001', 'dd-mm-yyyy'), to_date('07-07-2001', 'dd-mm-yyyy'), 11, 880, to_date('27-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090713008169, to_date('13-07-2009', 'dd-mm-yyyy'), to_date('27-07-2009', 'dd-mm-yyyy'), 8, 6791, to_date('21-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401008170, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 5, 5168, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702008171, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 10, 4283, to_date('10-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041221008172, to_date('21-12-2004', 'dd-mm-yyyy'), to_date('04-01-2005', 'dd-mm-yyyy'), 11, 4873, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080225008173, to_date('25-02-2008', 'dd-mm-yyyy'), to_date('10-03-2008', 'dd-mm-yyyy'), 8, 6896, to_date('29-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026008174, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 11, 3461, to_date('08-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021123008175, to_date('23-11-2002', 'dd-mm-yyyy'), to_date('07-12-2002', 'dd-mm-yyyy'), 3, 3132, to_date('09-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060806008176, to_date('06-08-2006', 'dd-mm-yyyy'), to_date('20-08-2006', 'dd-mm-yyyy'), 8, 3781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060320008177, to_date('20-03-2006', 'dd-mm-yyyy'), to_date('03-04-2006', 'dd-mm-yyyy'), 11, 4932, to_date('07-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091005008178, to_date('05-10-2009', 'dd-mm-yyyy'), to_date('19-10-2009', 'dd-mm-yyyy'), 10, 7088, to_date('22-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130209008179, to_date('09-02-2013', 'dd-mm-yyyy'), to_date('23-02-2013', 'dd-mm-yyyy'), 12, 7757, to_date('27-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110508008180, to_date('08-05-2011', 'dd-mm-yyyy'), to_date('22-05-2011', 'dd-mm-yyyy'), 4, 7306, to_date('17-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070914008181, to_date('14-09-2007', 'dd-mm-yyyy'), to_date('28-09-2007', 'dd-mm-yyyy'), 7, 4192, to_date('02-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070812008182, to_date('12-08-2007', 'dd-mm-yyyy'), to_date('26-08-2007', 'dd-mm-yyyy'), 2, 8369, to_date('26-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129008183, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 5, 8626, to_date('04-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140419008184, to_date('19-04-2014', 'dd-mm-yyyy'), to_date('03-05-2014', 'dd-mm-yyyy'), 6, 8761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801008185, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 6, 4302, to_date('12-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071002008186, to_date('02-10-2007', 'dd-mm-yyyy'), to_date('16-10-2007', 'dd-mm-yyyy'), 4, 6304, to_date('10-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060130008187, to_date('30-01-2006', 'dd-mm-yyyy'), to_date('13-02-2006', 'dd-mm-yyyy'), 3, 5673, to_date('10-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001214008188, to_date('14-12-2000', 'dd-mm-yyyy'), to_date('28-12-2000', 'dd-mm-yyyy'), 7, 1958, to_date('20-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021214008189, to_date('14-12-2002', 'dd-mm-yyyy'), to_date('28-12-2002', 'dd-mm-yyyy'), 5, 3925, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111126008190, to_date('26-11-2011', 'dd-mm-yyyy'), to_date('10-12-2011', 'dd-mm-yyyy'), 9, 8551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071230008191, to_date('30-12-2007', 'dd-mm-yyyy'), to_date('13-01-2008', 'dd-mm-yyyy'), 7, 5070, to_date('14-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519008192, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 10, 6185, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101125008193, to_date('25-11-2010', 'dd-mm-yyyy'), to_date('09-12-2010', 'dd-mm-yyyy'), 5, 3985, to_date('29-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509008194, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 7, 4798, to_date('14-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021219008195, to_date('19-12-2002', 'dd-mm-yyyy'), to_date('02-01-2003', 'dd-mm-yyyy'), 7, 3620, to_date('05-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140403008196, to_date('03-04-2014', 'dd-mm-yyyy'), to_date('17-04-2014', 'dd-mm-yyyy'), 11, 11186, to_date('12-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080816008197, to_date('16-08-2008', 'dd-mm-yyyy'), to_date('30-08-2008', 'dd-mm-yyyy'), 9, 6028, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121225008198, to_date('25-12-2012', 'dd-mm-yyyy'), to_date('08-01-2013', 'dd-mm-yyyy'), 12, 7520, to_date('30-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929008199, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 11, 6057, to_date('12-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070817008200, to_date('17-08-2007', 'dd-mm-yyyy'), to_date('31-08-2007', 'dd-mm-yyyy'), 6, 7823, to_date('02-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121121008201, to_date('21-11-2012', 'dd-mm-yyyy'), to_date('05-12-2012', 'dd-mm-yyyy'), 3, 8298, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040525008202, to_date('25-05-2004', 'dd-mm-yyyy'), to_date('08-06-2004', 'dd-mm-yyyy'), 11, 3137, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101130008203, to_date('30-11-2010', 'dd-mm-yyyy'), to_date('14-12-2010', 'dd-mm-yyyy'), 2, 6609, to_date('04-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130406008204, to_date('06-04-2013', 'dd-mm-yyyy'), to_date('20-04-2013', 'dd-mm-yyyy'), 5, 9926, to_date('25-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507008205, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 7, 1402, to_date('16-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040206008206, to_date('06-02-2004', 'dd-mm-yyyy'), to_date('20-02-2004', 'dd-mm-yyyy'), 5, 4889, to_date('17-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020121008207, to_date('21-01-2002', 'dd-mm-yyyy'), to_date('04-02-2002', 'dd-mm-yyyy'), 6, 3543, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000409008208, to_date('09-04-2000', 'dd-mm-yyyy'), to_date('23-04-2000', 'dd-mm-yyyy'), 8, 1058, to_date('26-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060107008209, to_date('07-01-2006', 'dd-mm-yyyy'), to_date('21-01-2006', 'dd-mm-yyyy'), 11, 5015, to_date('17-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050317008210, to_date('17-03-2005', 'dd-mm-yyyy'), to_date('31-03-2005', 'dd-mm-yyyy'), 12, 3150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100201008211, to_date('01-02-2010', 'dd-mm-yyyy'), to_date('15-02-2010', 'dd-mm-yyyy'), 2, 8775, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205008212, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 7, 3965, to_date('11-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319008213, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 3, 5937, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031222008214, to_date('22-12-2003', 'dd-mm-yyyy'), to_date('05-01-2004', 'dd-mm-yyyy'), 9, 3744, to_date('24-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020119008215, to_date('19-01-2002', 'dd-mm-yyyy'), to_date('02-02-2002', 'dd-mm-yyyy'), 4, 2798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020731008216, to_date('31-07-2002', 'dd-mm-yyyy'), to_date('14-08-2002', 'dd-mm-yyyy'), 2, 5601, to_date('04-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000728008217, to_date('28-07-2000', 'dd-mm-yyyy'), to_date('11-08-2000', 'dd-mm-yyyy'), 11, 1368, to_date('09-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723008218, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 11, 8098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111206008219, to_date('06-12-2011', 'dd-mm-yyyy'), to_date('20-12-2011', 'dd-mm-yyyy'), 10, 9088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020405008220, to_date('05-04-2002', 'dd-mm-yyyy'), to_date('19-04-2002', 'dd-mm-yyyy'), 5, 4741, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402008221, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 7, 2359, to_date('17-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090304008222, to_date('04-03-2009', 'dd-mm-yyyy'), to_date('18-03-2009', 'dd-mm-yyyy'), 10, 7101, to_date('21-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110407008223, to_date('07-04-2011', 'dd-mm-yyyy'), to_date('21-04-2011', 'dd-mm-yyyy'), 10, 7420, to_date('22-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100620008224, to_date('20-06-2010', 'dd-mm-yyyy'), to_date('04-07-2010', 'dd-mm-yyyy'), 6, 5281, to_date('03-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203008225, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 6, 2064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090115008226, to_date('15-01-2009', 'dd-mm-yyyy'), to_date('29-01-2009', 'dd-mm-yyyy'), 2, 5442, to_date('20-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081020008227, to_date('20-10-2008', 'dd-mm-yyyy'), to_date('03-11-2008', 'dd-mm-yyyy'), 5, 5241, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121127008228, to_date('27-11-2012', 'dd-mm-yyyy'), to_date('11-12-2012', 'dd-mm-yyyy'), 2, 7807, to_date('09-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130527008229, to_date('27-05-2013', 'dd-mm-yyyy'), to_date('10-06-2013', 'dd-mm-yyyy'), 2, 9191, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120612008230, to_date('12-06-2012', 'dd-mm-yyyy'), to_date('26-06-2012', 'dd-mm-yyyy'), 8, 8093, to_date('19-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090321008231, to_date('21-03-2009', 'dd-mm-yyyy'), to_date('04-04-2009', 'dd-mm-yyyy'), 10, 6526, to_date('09-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071226008232, to_date('26-12-2007', 'dd-mm-yyyy'), to_date('09-01-2008', 'dd-mm-yyyy'), 6, 7377, to_date('05-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130715008233, to_date('15-07-2013', 'dd-mm-yyyy'), to_date('29-07-2013', 'dd-mm-yyyy'), 5, 5827, to_date('29-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061030008234, to_date('30-10-2006', 'dd-mm-yyyy'), to_date('13-11-2006', 'dd-mm-yyyy'), 5, 5680, to_date('14-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040417008235, to_date('17-04-2004', 'dd-mm-yyyy'), to_date('01-05-2004', 'dd-mm-yyyy'), 5, 3627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930008236, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 2, 2313, to_date('16-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021117008237, to_date('17-11-2002', 'dd-mm-yyyy'), to_date('01-12-2002', 'dd-mm-yyyy'), 7, 2304, to_date('23-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000108008238, to_date('08-01-2000', 'dd-mm-yyyy'), to_date('22-01-2000', 'dd-mm-yyyy'), 5, 1176, to_date('17-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041212008239, to_date('12-12-2004', 'dd-mm-yyyy'), to_date('26-12-2004', 'dd-mm-yyyy'), 4, 3295, to_date('22-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070129008240, to_date('29-01-2007', 'dd-mm-yyyy'), to_date('12-02-2007', 'dd-mm-yyyy'), 11, 2558, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030318008241, to_date('18-03-2003', 'dd-mm-yyyy'), to_date('01-04-2003', 'dd-mm-yyyy'), 1, 2807, to_date('27-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110423008242, to_date('23-04-2011', 'dd-mm-yyyy'), to_date('07-05-2011', 'dd-mm-yyyy'), 7, 7029, to_date('07-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130008243, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 8, 4380, to_date('13-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020316008244, to_date('16-03-2002', 'dd-mm-yyyy'), to_date('30-03-2002', 'dd-mm-yyyy'), 3, 4556, to_date('21-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110614008245, to_date('14-06-2011', 'dd-mm-yyyy'), to_date('28-06-2011', 'dd-mm-yyyy'), 7, 9428, to_date('22-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070716008246, to_date('16-07-2007', 'dd-mm-yyyy'), to_date('30-07-2007', 'dd-mm-yyyy'), 8, 5954, to_date('01-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090912008247, to_date('12-09-2009', 'dd-mm-yyyy'), to_date('26-09-2009', 'dd-mm-yyyy'), 4, 5693, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120522008248, to_date('22-05-2012', 'dd-mm-yyyy'), to_date('05-06-2012', 'dd-mm-yyyy'), 10, 4985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219008249, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 3, 2452, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615008250, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 4, 9245, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041113008251, to_date('13-11-2004', 'dd-mm-yyyy'), to_date('27-11-2004', 'dd-mm-yyyy'), 1, 4053, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100910008252, to_date('10-09-2010', 'dd-mm-yyyy'), to_date('24-09-2010', 'dd-mm-yyyy'), 4, 7843, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090424008253, to_date('24-04-2009', 'dd-mm-yyyy'), to_date('08-05-2009', 'dd-mm-yyyy'), 4, 6406, to_date('07-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020630008254, to_date('30-06-2002', 'dd-mm-yyyy'), to_date('14-07-2002', 'dd-mm-yyyy'), 10, 4596, to_date('02-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100716008255, to_date('16-07-2010', 'dd-mm-yyyy'), to_date('30-07-2010', 'dd-mm-yyyy'), 6, 9769, to_date('02-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513008256, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 2, 7122, to_date('29-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070110008257, to_date('10-01-2007', 'dd-mm-yyyy'), to_date('24-01-2007', 'dd-mm-yyyy'), 9, 5426, to_date('27-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030601008258, to_date('01-06-2003', 'dd-mm-yyyy'), to_date('15-06-2003', 'dd-mm-yyyy'), 4, 5823, to_date('09-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080406008259, to_date('06-04-2008', 'dd-mm-yyyy'), to_date('20-04-2008', 'dd-mm-yyyy'), 9, 4914, to_date('14-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041114008260, to_date('14-11-2004', 'dd-mm-yyyy'), to_date('28-11-2004', 'dd-mm-yyyy'), 2, 4577, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026008261, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 9, 4477, to_date('05-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021224008262, to_date('24-12-2002', 'dd-mm-yyyy'), to_date('07-01-2003', 'dd-mm-yyyy'), 4, 2915, to_date('05-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090408008263, to_date('08-04-2009', 'dd-mm-yyyy'), to_date('22-04-2009', 'dd-mm-yyyy'), 6, 7468, to_date('12-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041121001375, to_date('21-11-2004', 'dd-mm-yyyy'), to_date('05-12-2004', 'dd-mm-yyyy'), 2, 2467, to_date('30-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090514001376, to_date('14-05-2009', 'dd-mm-yyyy'), to_date('28-05-2009', 'dd-mm-yyyy'), 9, 9244, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060801001377, to_date('01-08-2006', 'dd-mm-yyyy'), to_date('15-08-2006', 'dd-mm-yyyy'), 2, 5775, to_date('09-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100615001378, to_date('15-06-2010', 'dd-mm-yyyy'), to_date('29-06-2010', 'dd-mm-yyyy'), 6, 9163, to_date('04-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040112001379, to_date('12-01-2004', 'dd-mm-yyyy'), to_date('26-01-2004', 'dd-mm-yyyy'), 10, 4072, to_date('28-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110515001380, to_date('15-05-2011', 'dd-mm-yyyy'), to_date('29-05-2011', 'dd-mm-yyyy'), 5, 9487, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041111001381, to_date('11-11-2004', 'dd-mm-yyyy'), to_date('25-11-2004', 'dd-mm-yyyy'), 3, 5050, to_date('21-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040928001382, to_date('28-09-2004', 'dd-mm-yyyy'), to_date('12-10-2004', 'dd-mm-yyyy'), 6, 3370, to_date('30-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070206001383, to_date('06-02-2007', 'dd-mm-yyyy'), to_date('20-02-2007', 'dd-mm-yyyy'), 4, 5098, to_date('22-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515001384, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 6, 1063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912001385, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 3, 1240, to_date('29-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010303001386, to_date('03-03-2001', 'dd-mm-yyyy'), to_date('17-03-2001', 'dd-mm-yyyy'), 6, 2320, to_date('17-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070428001387, to_date('28-04-2007', 'dd-mm-yyyy'), to_date('12-05-2007', 'dd-mm-yyyy'), 10, 6181, to_date('10-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070609001388, to_date('09-06-2007', 'dd-mm-yyyy'), to_date('23-06-2007', 'dd-mm-yyyy'), 7, 4596, to_date('18-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121126001389, to_date('26-11-2012', 'dd-mm-yyyy'), to_date('10-12-2012', 'dd-mm-yyyy'), 2, 8249, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080204001390, to_date('04-02-2008', 'dd-mm-yyyy'), to_date('18-02-2008', 'dd-mm-yyyy'), 11, 7676, to_date('22-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509001391, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 3, 5434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070517001392, to_date('17-05-2007', 'dd-mm-yyyy'), to_date('31-05-2007', 'dd-mm-yyyy'), 3, 3463, to_date('30-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101001393, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 5, 4264, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070715001394, to_date('15-07-2007', 'dd-mm-yyyy'), to_date('29-07-2007', 'dd-mm-yyyy'), 8, 5843, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000928001395, to_date('28-09-2000', 'dd-mm-yyyy'), to_date('12-10-2000', 'dd-mm-yyyy'), 5, 723, to_date('13-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020803001396, to_date('03-08-2002', 'dd-mm-yyyy'), to_date('17-08-2002', 'dd-mm-yyyy'), 2, 1963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050510001397, to_date('10-05-2005', 'dd-mm-yyyy'), to_date('24-05-2005', 'dd-mm-yyyy'), 9, 5878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051119001398, to_date('19-11-2005', 'dd-mm-yyyy'), to_date('03-12-2005', 'dd-mm-yyyy'), 6, 5976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130623001399, to_date('23-06-2013', 'dd-mm-yyyy'), to_date('07-07-2013', 'dd-mm-yyyy'), 10, 9557, to_date('30-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001021001400, to_date('21-10-2000', 'dd-mm-yyyy'), to_date('04-11-2000', 'dd-mm-yyyy'), 12, 936, to_date('30-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110306001401, to_date('06-03-2011', 'dd-mm-yyyy'), to_date('20-03-2011', 'dd-mm-yyyy'), 4, 4996, to_date('26-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111027001402, to_date('27-10-2011', 'dd-mm-yyyy'), to_date('10-11-2011', 'dd-mm-yyyy'), 11, 8104, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030102001403, to_date('02-01-2003', 'dd-mm-yyyy'), to_date('16-01-2003', 'dd-mm-yyyy'), 10, 2496, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105001404, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 2, 3362, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071004001405, to_date('04-10-2007', 'dd-mm-yyyy'), to_date('18-10-2007', 'dd-mm-yyyy'), 1, 6641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601001406, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 5, 6795, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131105001407, to_date('05-11-2013', 'dd-mm-yyyy'), to_date('19-11-2013', 'dd-mm-yyyy'), 11, 10060, to_date('10-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070810001408, to_date('10-08-2007', 'dd-mm-yyyy'), to_date('24-08-2007', 'dd-mm-yyyy'), 4, 5174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915001409, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 8, 9001, to_date('22-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100512001410, to_date('12-05-2010', 'dd-mm-yyyy'), to_date('26-05-2010', 'dd-mm-yyyy'), 5, 7116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020418001411, to_date('18-04-2002', 'dd-mm-yyyy'), to_date('02-05-2002', 'dd-mm-yyyy'), 4, 1443, to_date('20-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601001412, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 2, 7460, to_date('19-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306001413, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 9, 4747, to_date('10-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050907001414, to_date('07-09-2005', 'dd-mm-yyyy'), to_date('21-09-2005', 'dd-mm-yyyy'), 12, 5189, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214001415, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 11, 2753, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130206001416, to_date('06-02-2013', 'dd-mm-yyyy'), to_date('20-02-2013', 'dd-mm-yyyy'), 3, 8521, to_date('15-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051208001417, to_date('08-12-2005', 'dd-mm-yyyy'), to_date('22-12-2005', 'dd-mm-yyyy'), 9, 4878, to_date('18-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041107001418, to_date('07-11-2004', 'dd-mm-yyyy'), to_date('21-11-2004', 'dd-mm-yyyy'), 7, 3639, to_date('16-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120712001419, to_date('12-07-2012', 'dd-mm-yyyy'), to_date('26-07-2012', 'dd-mm-yyyy'), 6, 7952, to_date('28-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020605001420, to_date('05-06-2002', 'dd-mm-yyyy'), to_date('19-06-2002', 'dd-mm-yyyy'), 2, 3408, to_date('15-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130331001421, to_date('31-03-2013', 'dd-mm-yyyy'), to_date('14-04-2013', 'dd-mm-yyyy'), 10, 8336, to_date('02-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125001422, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 8, 2633, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001218001423, to_date('18-12-2000', 'dd-mm-yyyy'), to_date('01-01-2001', 'dd-mm-yyyy'), 3, 582, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130516001424, to_date('16-05-2013', 'dd-mm-yyyy'), to_date('30-05-2013', 'dd-mm-yyyy'), 1, 8351, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120330001425, to_date('30-03-2012', 'dd-mm-yyyy'), to_date('13-04-2012', 'dd-mm-yyyy'), 6, 7453, to_date('07-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040514001426, to_date('14-05-2004', 'dd-mm-yyyy'), to_date('28-05-2004', 'dd-mm-yyyy'), 4, 1186, to_date('29-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525001427, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 3, 8437, to_date('05-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140416001428, to_date('16-04-2014', 'dd-mm-yyyy'), to_date('30-04-2014', 'dd-mm-yyyy'), 4, 9344, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120118001429, to_date('18-01-2012', 'dd-mm-yyyy'), to_date('01-02-2012', 'dd-mm-yyyy'), 4, 6833, to_date('30-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071020001430, to_date('20-10-2007', 'dd-mm-yyyy'), to_date('03-11-2007', 'dd-mm-yyyy'), 2, 7442, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080226001431, to_date('26-02-2008', 'dd-mm-yyyy'), to_date('11-03-2008', 'dd-mm-yyyy'), 3, 4745, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030819001432, to_date('19-08-2003', 'dd-mm-yyyy'), to_date('02-09-2003', 'dd-mm-yyyy'), 7, 3749, to_date('06-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030208001433, to_date('08-02-2003', 'dd-mm-yyyy'), to_date('22-02-2003', 'dd-mm-yyyy'), 8, 2907, to_date('13-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090124001434, to_date('24-01-2009', 'dd-mm-yyyy'), to_date('07-02-2009', 'dd-mm-yyyy'), 12, 7594, to_date('10-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030328001435, to_date('28-03-2003', 'dd-mm-yyyy'), to_date('11-04-2003', 'dd-mm-yyyy'), 1, 3341, to_date('05-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070320001436, to_date('20-03-2007', 'dd-mm-yyyy'), to_date('03-04-2007', 'dd-mm-yyyy'), 5, 5929, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100211001437, to_date('11-02-2010', 'dd-mm-yyyy'), to_date('25-02-2010', 'dd-mm-yyyy'), 9, 4322, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101106001438, to_date('06-11-2010', 'dd-mm-yyyy'), to_date('20-11-2010', 'dd-mm-yyyy'), 4, 7324, to_date('19-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030626001439, to_date('26-06-2003', 'dd-mm-yyyy'), to_date('10-07-2003', 'dd-mm-yyyy'), 3, 2665, to_date('16-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601001440, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 10, 5651, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120122001441, to_date('22-01-2012', 'dd-mm-yyyy'), to_date('05-02-2012', 'dd-mm-yyyy'), 6, 5849, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040710001442, to_date('10-07-2004', 'dd-mm-yyyy'), to_date('24-07-2004', 'dd-mm-yyyy'), 9, 5026, to_date('27-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007001443, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 8, 5045, to_date('15-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130207001444, to_date('07-02-2013', 'dd-mm-yyyy'), to_date('21-02-2013', 'dd-mm-yyyy'), 5, 8547, to_date('23-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130401001445, to_date('01-04-2013', 'dd-mm-yyyy'), to_date('15-04-2013', 'dd-mm-yyyy'), 2, 9820, to_date('06-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060624001446, to_date('24-06-2006', 'dd-mm-yyyy'), to_date('08-07-2006', 'dd-mm-yyyy'), 4, 4495, to_date('06-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130816001447, to_date('16-08-2013', 'dd-mm-yyyy'), to_date('30-08-2013', 'dd-mm-yyyy'), 10, 6887, to_date('28-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090506001448, to_date('06-05-2009', 'dd-mm-yyyy'), to_date('20-05-2009', 'dd-mm-yyyy'), 6, 5414, to_date('16-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070109001449, to_date('09-01-2007', 'dd-mm-yyyy'), to_date('23-01-2007', 'dd-mm-yyyy'), 2, 4853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000730001450, to_date('30-07-2000', 'dd-mm-yyyy'), to_date('13-08-2000', 'dd-mm-yyyy'), 2, 1937, to_date('14-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118001451, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 8, 1012, to_date('23-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080910001452, to_date('10-09-2008', 'dd-mm-yyyy'), to_date('24-09-2008', 'dd-mm-yyyy'), 11, 7108, to_date('15-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130205001453, to_date('05-02-2013', 'dd-mm-yyyy'), to_date('19-02-2013', 'dd-mm-yyyy'), 10, 9943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110220001454, to_date('20-02-2011', 'dd-mm-yyyy'), to_date('06-03-2011', 'dd-mm-yyyy'), 7, 8832, to_date('03-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030604001455, to_date('04-06-2003', 'dd-mm-yyyy'), to_date('18-06-2003', 'dd-mm-yyyy'), 3, 4422, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110217001456, to_date('17-02-2011', 'dd-mm-yyyy'), to_date('03-03-2011', 'dd-mm-yyyy'), 11, 9311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901001457, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 5, 3694, to_date('11-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090628001458, to_date('28-06-2009', 'dd-mm-yyyy'), to_date('12-07-2009', 'dd-mm-yyyy'), 8, 6730, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050604001459, to_date('04-06-2005', 'dd-mm-yyyy'), to_date('18-06-2005', 'dd-mm-yyyy'), 5, 3620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001125001460, to_date('25-11-2000', 'dd-mm-yyyy'), to_date('09-12-2000', 'dd-mm-yyyy'), 11, 1383, to_date('07-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331001461, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 3, 8589, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070524001462, to_date('24-05-2007', 'dd-mm-yyyy'), to_date('07-06-2007', 'dd-mm-yyyy'), 8, 6504, to_date('03-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051104001463, to_date('04-11-2005', 'dd-mm-yyyy'), to_date('18-11-2005', 'dd-mm-yyyy'), 6, 3481, to_date('23-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040103001464, to_date('03-01-2004', 'dd-mm-yyyy'), to_date('17-01-2004', 'dd-mm-yyyy'), 12, 4416, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131130001465, to_date('30-11-2013', 'dd-mm-yyyy'), to_date('14-12-2013', 'dd-mm-yyyy'), 6, 8142, to_date('07-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091211001466, to_date('11-12-2009', 'dd-mm-yyyy'), to_date('25-12-2009', 'dd-mm-yyyy'), 9, 5251, to_date('12-12-2009', 'dd-mm-yyyy'));
commit;
prompt 3000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609001467, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 5, 6603, to_date('10-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221001468, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 7, 3459, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050302001469, to_date('02-03-2005', 'dd-mm-yyyy'), to_date('16-03-2005', 'dd-mm-yyyy'), 2, 4906, to_date('04-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041208001470, to_date('08-12-2004', 'dd-mm-yyyy'), to_date('22-12-2004', 'dd-mm-yyyy'), 8, 4609, to_date('10-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050629001471, to_date('29-06-2005', 'dd-mm-yyyy'), to_date('13-07-2005', 'dd-mm-yyyy'), 6, 2596, to_date('17-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071125001472, to_date('25-11-2007', 'dd-mm-yyyy'), to_date('09-12-2007', 'dd-mm-yyyy'), 7, 8207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140104001473, to_date('04-01-2014', 'dd-mm-yyyy'), to_date('18-01-2014', 'dd-mm-yyyy'), 3, 9324, to_date('20-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111014001474, to_date('14-10-2011', 'dd-mm-yyyy'), to_date('28-10-2011', 'dd-mm-yyyy'), 6, 8562, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010716001475, to_date('16-07-2001', 'dd-mm-yyyy'), to_date('30-07-2001', 'dd-mm-yyyy'), 7, 2785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070620001476, to_date('20-06-2007', 'dd-mm-yyyy'), to_date('04-07-2007', 'dd-mm-yyyy'), 10, 7536, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041120001477, to_date('20-11-2004', 'dd-mm-yyyy'), to_date('04-12-2004', 'dd-mm-yyyy'), 11, 5753, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140128001478, to_date('28-01-2014', 'dd-mm-yyyy'), to_date('11-02-2014', 'dd-mm-yyyy'), 9, 9698, to_date('29-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100508001479, to_date('08-05-2010', 'dd-mm-yyyy'), to_date('22-05-2010', 'dd-mm-yyyy'), 3, 7239, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130210001480, to_date('10-02-2013', 'dd-mm-yyyy'), to_date('24-02-2013', 'dd-mm-yyyy'), 11, 7221, to_date('23-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040903001481, to_date('03-09-2004', 'dd-mm-yyyy'), to_date('17-09-2004', 'dd-mm-yyyy'), 7, 3096, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010406001482, to_date('06-04-2001', 'dd-mm-yyyy'), to_date('20-04-2001', 'dd-mm-yyyy'), 12, 1977, to_date('10-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090715001483, to_date('15-07-2009', 'dd-mm-yyyy'), to_date('29-07-2009', 'dd-mm-yyyy'), 7, 5692, to_date('24-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070713001484, to_date('13-07-2007', 'dd-mm-yyyy'), to_date('27-07-2007', 'dd-mm-yyyy'), 4, 6139, to_date('31-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040124001485, to_date('24-01-2004', 'dd-mm-yyyy'), to_date('07-02-2004', 'dd-mm-yyyy'), 9, 3643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070113001486, to_date('13-01-2007', 'dd-mm-yyyy'), to_date('27-01-2007', 'dd-mm-yyyy'), 9, 4384, to_date('29-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100611001487, to_date('11-06-2010', 'dd-mm-yyyy'), to_date('25-06-2010', 'dd-mm-yyyy'), 5, 7112, to_date('20-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090822001488, to_date('22-08-2009', 'dd-mm-yyyy'), to_date('05-09-2009', 'dd-mm-yyyy'), 3, 6172, to_date('02-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071002001489, to_date('02-10-2007', 'dd-mm-yyyy'), to_date('16-10-2007', 'dd-mm-yyyy'), 3, 5218, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010823001490, to_date('23-08-2001', 'dd-mm-yyyy'), to_date('06-09-2001', 'dd-mm-yyyy'), 11, 1253, to_date('31-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218001491, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 10, 5702, to_date('06-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620001492, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 11, 3612, to_date('05-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040402001493, to_date('02-04-2004', 'dd-mm-yyyy'), to_date('16-04-2004', 'dd-mm-yyyy'), 2, 3827, to_date('07-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121231001494, to_date('31-12-2012', 'dd-mm-yyyy'), to_date('14-01-2013', 'dd-mm-yyyy'), 2, 5832, to_date('18-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110929001495, to_date('29-09-2011', 'dd-mm-yyyy'), to_date('13-10-2011', 'dd-mm-yyyy'), 8, 8941, to_date('10-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100524001496, to_date('24-05-2010', 'dd-mm-yyyy'), to_date('07-06-2010', 'dd-mm-yyyy'), 5, 6245, to_date('30-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120915001497, to_date('15-09-2012', 'dd-mm-yyyy'), to_date('29-09-2012', 'dd-mm-yyyy'), 6, 6906, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050727001498, to_date('27-07-2005', 'dd-mm-yyyy'), to_date('10-08-2005', 'dd-mm-yyyy'), 4, 3848, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131006001499, to_date('06-10-2013', 'dd-mm-yyyy'), to_date('20-10-2013', 'dd-mm-yyyy'), 8, 8259, to_date('07-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101222001500, to_date('22-12-2010', 'dd-mm-yyyy'), to_date('05-01-2011', 'dd-mm-yyyy'), 12, 5246, to_date('05-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121107001501, to_date('07-11-2012', 'dd-mm-yyyy'), to_date('21-11-2012', 'dd-mm-yyyy'), 11, 9136, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225001502, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 10, 4592, to_date('30-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829001503, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 5, 3620, to_date('05-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101001504, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 9, 5625, to_date('18-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050226001505, to_date('26-02-2005', 'dd-mm-yyyy'), to_date('12-03-2005', 'dd-mm-yyyy'), 5, 3981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081221001506, to_date('21-12-2008', 'dd-mm-yyyy'), to_date('04-01-2009', 'dd-mm-yyyy'), 8, 6274, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011004001507, to_date('04-10-2001', 'dd-mm-yyyy'), to_date('18-10-2001', 'dd-mm-yyyy'), 10, 4033, to_date('10-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021117001508, to_date('17-11-2002', 'dd-mm-yyyy'), to_date('01-12-2002', 'dd-mm-yyyy'), 11, 3640, to_date('06-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041117001509, to_date('17-11-2004', 'dd-mm-yyyy'), to_date('01-12-2004', 'dd-mm-yyyy'), 12, 2794, to_date('28-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127001510, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 4, 894, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050516001511, to_date('16-05-2005', 'dd-mm-yyyy'), to_date('30-05-2005', 'dd-mm-yyyy'), 6, 6777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726001512, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 8, 4569, to_date('13-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204001513, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 2, 8312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031206001514, to_date('06-12-2003', 'dd-mm-yyyy'), to_date('20-12-2003', 'dd-mm-yyyy'), 7, 4479, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121014001515, to_date('14-10-2012', 'dd-mm-yyyy'), to_date('28-10-2012', 'dd-mm-yyyy'), 3, 6321, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511001516, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 3, 3182, to_date('16-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020415001517, to_date('15-04-2002', 'dd-mm-yyyy'), to_date('29-04-2002', 'dd-mm-yyyy'), 12, 3745, to_date('28-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030819001518, to_date('19-08-2003', 'dd-mm-yyyy'), to_date('02-09-2003', 'dd-mm-yyyy'), 4, 4519, to_date('28-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100519001519, to_date('19-05-2010', 'dd-mm-yyyy'), to_date('02-06-2010', 'dd-mm-yyyy'), 10, 6685, to_date('23-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050526001520, to_date('26-05-2005', 'dd-mm-yyyy'), to_date('09-06-2005', 'dd-mm-yyyy'), 3, 4386, to_date('04-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121112001521, to_date('12-11-2012', 'dd-mm-yyyy'), to_date('26-11-2012', 'dd-mm-yyyy'), 2, 9841, to_date('18-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051108001522, to_date('08-11-2005', 'dd-mm-yyyy'), to_date('22-11-2005', 'dd-mm-yyyy'), 3, 3207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051217001523, to_date('17-12-2005', 'dd-mm-yyyy'), to_date('31-12-2005', 'dd-mm-yyyy'), 9, 3719, to_date('25-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612001524, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 8, 6381, to_date('17-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120302001525, to_date('02-03-2012', 'dd-mm-yyyy'), to_date('16-03-2012', 'dd-mm-yyyy'), 10, 7972, to_date('06-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917001526, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 8, 4078, to_date('25-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031123001527, to_date('23-11-2003', 'dd-mm-yyyy'), to_date('07-12-2003', 'dd-mm-yyyy'), 2, 1168, to_date('30-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913001528, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 5, 3901, to_date('01-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071105003831, to_date('05-11-2007', 'dd-mm-yyyy'), to_date('19-11-2007', 'dd-mm-yyyy'), 11, 5804, to_date('15-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224003832, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 8, 9248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111231003833, to_date('31-12-2011', 'dd-mm-yyyy'), to_date('14-01-2012', 'dd-mm-yyyy'), 11, 8666, to_date('06-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030811003834, to_date('11-08-2003', 'dd-mm-yyyy'), to_date('25-08-2003', 'dd-mm-yyyy'), 11, 2194, to_date('26-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071011003835, to_date('11-10-2007', 'dd-mm-yyyy'), to_date('25-10-2007', 'dd-mm-yyyy'), 9, 6492, to_date('21-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050531003836, to_date('31-05-2005', 'dd-mm-yyyy'), to_date('14-06-2005', 'dd-mm-yyyy'), 11, 4009, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101005003837, to_date('05-10-2010', 'dd-mm-yyyy'), to_date('19-10-2010', 'dd-mm-yyyy'), 6, 6103, to_date('23-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070507003838, to_date('07-05-2007', 'dd-mm-yyyy'), to_date('21-05-2007', 'dd-mm-yyyy'), 10, 5156, to_date('19-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115003839, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 11, 8665, to_date('01-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326003840, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 5, 3483, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408003841, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 1, 3033, to_date('19-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000730003842, to_date('30-07-2000', 'dd-mm-yyyy'), to_date('13-08-2000', 'dd-mm-yyyy'), 6, 916, to_date('12-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120801003843, to_date('01-08-2012', 'dd-mm-yyyy'), to_date('15-08-2012', 'dd-mm-yyyy'), 6, 9947, to_date('17-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226003844, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 12, 1188, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010729003845, to_date('29-07-2001', 'dd-mm-yyyy'), to_date('12-08-2001', 'dd-mm-yyyy'), 3, 3537, to_date('17-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121003846, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 8, 2243, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090507003847, to_date('07-05-2009', 'dd-mm-yyyy'), to_date('21-05-2009', 'dd-mm-yyyy'), 6, 7550, to_date('08-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120709003848, to_date('09-07-2012', 'dd-mm-yyyy'), to_date('23-07-2012', 'dd-mm-yyyy'), 11, 7910, to_date('17-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000702003849, to_date('02-07-2000', 'dd-mm-yyyy'), to_date('16-07-2000', 'dd-mm-yyyy'), 9, 2530, to_date('06-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710003850, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 7, 2782, to_date('26-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100322003851, to_date('22-03-2010', 'dd-mm-yyyy'), to_date('05-04-2010', 'dd-mm-yyyy'), 3, 6111, to_date('27-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912003852, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 11, 5928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010309003853, to_date('09-03-2001', 'dd-mm-yyyy'), to_date('23-03-2001', 'dd-mm-yyyy'), 4, 2139, to_date('14-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110220003854, to_date('20-02-2011', 'dd-mm-yyyy'), to_date('06-03-2011', 'dd-mm-yyyy'), 3, 11099, to_date('02-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101102003855, to_date('02-11-2010', 'dd-mm-yyyy'), to_date('16-11-2010', 'dd-mm-yyyy'), 2, 7416, to_date('16-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703003856, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 8, 6190, to_date('08-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140415003857, to_date('15-04-2014', 'dd-mm-yyyy'), to_date('29-04-2014', 'dd-mm-yyyy'), 5, 10873, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111224003858, to_date('24-12-2011', 'dd-mm-yyyy'), to_date('07-01-2012', 'dd-mm-yyyy'), 6, 6251, to_date('05-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716003859, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 12, 4383, to_date('18-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100823003860, to_date('23-08-2010', 'dd-mm-yyyy'), to_date('06-09-2010', 'dd-mm-yyyy'), 9, 7271, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021106003861, to_date('06-11-2002', 'dd-mm-yyyy'), to_date('20-11-2002', 'dd-mm-yyyy'), 9, 3557, to_date('08-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603003862, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 11, 6100, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010320003863, to_date('20-03-2001', 'dd-mm-yyyy'), to_date('03-04-2001', 'dd-mm-yyyy'), 4, 2781, to_date('08-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000315003864, to_date('15-03-2000', 'dd-mm-yyyy'), to_date('29-03-2000', 'dd-mm-yyyy'), 11, 1087, to_date('23-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514003865, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 6, 8801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140313003866, to_date('13-03-2014', 'dd-mm-yyyy'), to_date('27-03-2014', 'dd-mm-yyyy'), 7, 12719, to_date('28-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010613003867, to_date('13-06-2001', 'dd-mm-yyyy'), to_date('27-06-2001', 'dd-mm-yyyy'), 3, 1647, to_date('25-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000722003868, to_date('22-07-2000', 'dd-mm-yyyy'), to_date('05-08-2000', 'dd-mm-yyyy'), 3, 3740, to_date('30-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130614003869, to_date('14-06-2013', 'dd-mm-yyyy'), to_date('28-06-2013', 'dd-mm-yyyy'), 11, 7855, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000405003870, to_date('05-04-2000', 'dd-mm-yyyy'), to_date('19-04-2000', 'dd-mm-yyyy'), 6, 2712, to_date('12-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061202003871, to_date('02-12-2006', 'dd-mm-yyyy'), to_date('16-12-2006', 'dd-mm-yyyy'), 10, 5248, to_date('07-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110903003872, to_date('03-09-2011', 'dd-mm-yyyy'), to_date('17-09-2011', 'dd-mm-yyyy'), 9, 6324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131114003873, to_date('14-11-2013', 'dd-mm-yyyy'), to_date('28-11-2013', 'dd-mm-yyyy'), 2, 8438, to_date('03-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003003874, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 12, 8414, to_date('07-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080915003875, to_date('15-09-2008', 'dd-mm-yyyy'), to_date('29-09-2008', 'dd-mm-yyyy'), 1, 9077, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418003876, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 4, 741, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080419003877, to_date('19-04-2008', 'dd-mm-yyyy'), to_date('03-05-2008', 'dd-mm-yyyy'), 9, 6082, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060708003878, to_date('08-07-2006', 'dd-mm-yyyy'), to_date('22-07-2006', 'dd-mm-yyyy'), 1, 5387, to_date('13-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071127003879, to_date('27-11-2007', 'dd-mm-yyyy'), to_date('11-12-2007', 'dd-mm-yyyy'), 10, 4722, to_date('14-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305003880, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 9, 7991, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217003881, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 5, 5257, to_date('27-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071101003882, to_date('01-11-2007', 'dd-mm-yyyy'), to_date('15-11-2007', 'dd-mm-yyyy'), 9, 5143, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050524003883, to_date('24-05-2005', 'dd-mm-yyyy'), to_date('07-06-2005', 'dd-mm-yyyy'), 6, 3238, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041117003884, to_date('17-11-2004', 'dd-mm-yyyy'), to_date('01-12-2004', 'dd-mm-yyyy'), 5, 3868, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031127003885, to_date('27-11-2003', 'dd-mm-yyyy'), to_date('11-12-2003', 'dd-mm-yyyy'), 11, 2645, to_date('30-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081003003886, to_date('03-10-2008', 'dd-mm-yyyy'), to_date('17-10-2008', 'dd-mm-yyyy'), 7, 4767, to_date('12-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010623003887, to_date('23-06-2001', 'dd-mm-yyyy'), to_date('07-07-2001', 'dd-mm-yyyy'), 6, 1165, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030828003888, to_date('28-08-2003', 'dd-mm-yyyy'), to_date('11-09-2003', 'dd-mm-yyyy'), 12, 3321, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020503003889, to_date('03-05-2002', 'dd-mm-yyyy'), to_date('17-05-2002', 'dd-mm-yyyy'), 4, 2157, to_date('21-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140302003890, to_date('02-03-2014', 'dd-mm-yyyy'), to_date('16-03-2014', 'dd-mm-yyyy'), 5, 8837, to_date('09-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090927003891, to_date('27-09-2009', 'dd-mm-yyyy'), to_date('11-10-2009', 'dd-mm-yyyy'), 4, 5153, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021009003892, to_date('09-10-2002', 'dd-mm-yyyy'), to_date('23-10-2002', 'dd-mm-yyyy'), 5, 1561, to_date('16-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021030003893, to_date('30-10-2002', 'dd-mm-yyyy'), to_date('13-11-2002', 'dd-mm-yyyy'), 3, 3850, to_date('07-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010719003894, to_date('19-07-2001', 'dd-mm-yyyy'), to_date('02-08-2001', 'dd-mm-yyyy'), 4, 2089, to_date('26-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130425003895, to_date('25-04-2013', 'dd-mm-yyyy'), to_date('09-05-2013', 'dd-mm-yyyy'), 3, 11161, to_date('27-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000423003896, to_date('23-04-2000', 'dd-mm-yyyy'), to_date('07-05-2000', 'dd-mm-yyyy'), 8, 2083, to_date('02-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080909003897, to_date('09-09-2008', 'dd-mm-yyyy'), to_date('23-09-2008', 'dd-mm-yyyy'), 12, 5979, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040329003898, to_date('29-03-2004', 'dd-mm-yyyy'), to_date('12-04-2004', 'dd-mm-yyyy'), 12, 4881, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423003899, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 4, 4844, to_date('10-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020410003900, to_date('10-04-2002', 'dd-mm-yyyy'), to_date('24-04-2002', 'dd-mm-yyyy'), 7, 2138, to_date('17-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100322003901, to_date('22-03-2010', 'dd-mm-yyyy'), to_date('05-04-2010', 'dd-mm-yyyy'), 4, 6409, to_date('08-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001021003902, to_date('21-10-2000', 'dd-mm-yyyy'), to_date('04-11-2000', 'dd-mm-yyyy'), 1, 3286, to_date('24-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120421003903, to_date('21-04-2012', 'dd-mm-yyyy'), to_date('05-05-2012', 'dd-mm-yyyy'), 5, 6743, to_date('03-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121003904, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 9, 973, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070606003905, to_date('06-06-2007', 'dd-mm-yyyy'), to_date('20-06-2007', 'dd-mm-yyyy'), 7, 6418, to_date('21-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130213003906, to_date('13-02-2013', 'dd-mm-yyyy'), to_date('27-02-2013', 'dd-mm-yyyy'), 6, 10022, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080421003907, to_date('21-04-2008', 'dd-mm-yyyy'), to_date('05-05-2008', 'dd-mm-yyyy'), 4, 5949, to_date('11-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080223003908, to_date('23-02-2008', 'dd-mm-yyyy'), to_date('08-03-2008', 'dd-mm-yyyy'), 9, 6757, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215003909, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 8, 7635, to_date('27-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000311003910, to_date('11-03-2000', 'dd-mm-yyyy'), to_date('25-03-2000', 'dd-mm-yyyy'), 7, 2660, to_date('30-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030111003911, to_date('11-01-2003', 'dd-mm-yyyy'), to_date('25-01-2003', 'dd-mm-yyyy'), 2, 4084, to_date('25-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514003912, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 10, 9203, to_date('22-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603003913, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 2, 8001, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120112003914, to_date('12-01-2012', 'dd-mm-yyyy'), to_date('26-01-2012', 'dd-mm-yyyy'), 7, 9197, to_date('22-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716003915, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 3, 6937, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000405003916, to_date('05-04-2000', 'dd-mm-yyyy'), to_date('19-04-2000', 'dd-mm-yyyy'), 2, 2760, to_date('06-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101007003917, to_date('07-10-2010', 'dd-mm-yyyy'), to_date('21-10-2010', 'dd-mm-yyyy'), 12, 6073, to_date('08-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101004003918, to_date('04-10-2010', 'dd-mm-yyyy'), to_date('18-10-2010', 'dd-mm-yyyy'), 9, 7316, to_date('19-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725003919, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 10, 7867, to_date('09-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011101003920, to_date('01-11-2001', 'dd-mm-yyyy'), to_date('15-11-2001', 'dd-mm-yyyy'), 9, 3119, to_date('11-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220003921, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 8, 5915, to_date('08-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010720003922, to_date('20-07-2001', 'dd-mm-yyyy'), to_date('03-08-2001', 'dd-mm-yyyy'), 5, 1522, to_date('31-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120102003923, to_date('02-01-2012', 'dd-mm-yyyy'), to_date('16-01-2012', 'dd-mm-yyyy'), 9, 5077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020724003924, to_date('24-07-2002', 'dd-mm-yyyy'), to_date('07-08-2002', 'dd-mm-yyyy'), 12, 3078, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325003925, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 8, 4124, to_date('28-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121002003926, to_date('02-10-2012', 'dd-mm-yyyy'), to_date('16-10-2012', 'dd-mm-yyyy'), 4, 10585, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050809003927, to_date('09-08-2005', 'dd-mm-yyyy'), to_date('23-08-2005', 'dd-mm-yyyy'), 7, 3611, to_date('24-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120213003928, to_date('13-02-2012', 'dd-mm-yyyy'), to_date('27-02-2012', 'dd-mm-yyyy'), 3, 5805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815003929, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 3, 7398, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041108003930, to_date('08-11-2004', 'dd-mm-yyyy'), to_date('22-11-2004', 'dd-mm-yyyy'), 10, 3272, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040117003931, to_date('17-01-2004', 'dd-mm-yyyy'), to_date('31-01-2004', 'dd-mm-yyyy'), 10, 3952, to_date('31-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091104003932, to_date('04-11-2009', 'dd-mm-yyyy'), to_date('18-11-2009', 'dd-mm-yyyy'), 10, 7803, to_date('09-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050414003933, to_date('14-04-2005', 'dd-mm-yyyy'), to_date('28-04-2005', 'dd-mm-yyyy'), 7, 4689, to_date('30-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121123003934, to_date('23-11-2012', 'dd-mm-yyyy'), to_date('07-12-2012', 'dd-mm-yyyy'), 3, 11403, to_date('06-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011003935, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 9, 3221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110810003936, to_date('10-08-2011', 'dd-mm-yyyy'), to_date('24-08-2011', 'dd-mm-yyyy'), 11, 9038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100625003937, to_date('25-06-2010', 'dd-mm-yyyy'), to_date('09-07-2010', 'dd-mm-yyyy'), 3, 8215, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050826003938, to_date('26-08-2005', 'dd-mm-yyyy'), to_date('09-09-2005', 'dd-mm-yyyy'), 6, 4338, to_date('15-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110712003939, to_date('12-07-2011', 'dd-mm-yyyy'), to_date('26-07-2011', 'dd-mm-yyyy'), 3, 10068, to_date('19-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080522003940, to_date('22-05-2008', 'dd-mm-yyyy'), to_date('05-06-2008', 'dd-mm-yyyy'), 10, 5775, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090910003941, to_date('10-09-2009', 'dd-mm-yyyy'), to_date('24-09-2009', 'dd-mm-yyyy'), 9, 8214, to_date('21-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110912003942, to_date('12-09-2011', 'dd-mm-yyyy'), to_date('26-09-2011', 'dd-mm-yyyy'), 7, 9966, to_date('24-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227003943, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 4, 4355, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030806003944, to_date('06-08-2003', 'dd-mm-yyyy'), to_date('20-08-2003', 'dd-mm-yyyy'), 11, 4304, to_date('23-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030527003945, to_date('27-05-2003', 'dd-mm-yyyy'), to_date('10-06-2003', 'dd-mm-yyyy'), 2, 4814, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908003946, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 9, 8512, to_date('20-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101014003947, to_date('14-10-2010', 'dd-mm-yyyy'), to_date('28-10-2010', 'dd-mm-yyyy'), 11, 9349, to_date('21-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906003948, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 7, 2478, to_date('20-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061015003949, to_date('15-10-2006', 'dd-mm-yyyy'), to_date('29-10-2006', 'dd-mm-yyyy'), 8, 7390, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020718003950, to_date('18-07-2002', 'dd-mm-yyyy'), to_date('01-08-2002', 'dd-mm-yyyy'), 11, 1807, to_date('26-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517003951, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 10, 8516, to_date('24-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010716003952, to_date('16-07-2001', 'dd-mm-yyyy'), to_date('30-07-2001', 'dd-mm-yyyy'), 4, 1986, to_date('27-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041128003953, to_date('28-11-2004', 'dd-mm-yyyy'), to_date('12-12-2004', 'dd-mm-yyyy'), 4, 3632, to_date('03-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000828003954, to_date('28-08-2000', 'dd-mm-yyyy'), to_date('11-09-2000', 'dd-mm-yyyy'), 4, 3387, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060917003955, to_date('17-09-2006', 'dd-mm-yyyy'), to_date('01-10-2006', 'dd-mm-yyyy'), 9, 4878, to_date('23-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140321003956, to_date('21-03-2014', 'dd-mm-yyyy'), to_date('04-04-2014', 'dd-mm-yyyy'), 1, 10302, to_date('24-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601003957, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 6, 4229, to_date('03-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001129003958, to_date('29-11-2000', 'dd-mm-yyyy'), to_date('13-12-2000', 'dd-mm-yyyy'), 10, 3831, to_date('14-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131127003959, to_date('27-11-2013', 'dd-mm-yyyy'), to_date('11-12-2013', 'dd-mm-yyyy'), 2, 10075, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126003960, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 10, 5425, to_date('13-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050715003961, to_date('15-07-2005', 'dd-mm-yyyy'), to_date('29-07-2005', 'dd-mm-yyyy'), 8, 4625, to_date('25-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111011003962, to_date('11-10-2011', 'dd-mm-yyyy'), to_date('25-10-2011', 'dd-mm-yyyy'), 10, 6039, to_date('22-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127003963, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 2, 2009, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080822003964, to_date('22-08-2008', 'dd-mm-yyyy'), to_date('05-09-2008', 'dd-mm-yyyy'), 9, 5942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040523003965, to_date('23-05-2004', 'dd-mm-yyyy'), to_date('06-06-2004', 'dd-mm-yyyy'), 4, 4275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307003966, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 12, 4827, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030823003967, to_date('23-08-2003', 'dd-mm-yyyy'), to_date('06-09-2003', 'dd-mm-yyyy'), 9, 4252, to_date('01-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317003968, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 11, 3922, to_date('27-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060129003969, to_date('29-01-2006', 'dd-mm-yyyy'), to_date('12-02-2006', 'dd-mm-yyyy'), 3, 4268, to_date('14-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030723003970, to_date('23-07-2003', 'dd-mm-yyyy'), to_date('06-08-2003', 'dd-mm-yyyy'), 2, 3032, to_date('28-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130118003971, to_date('18-01-2013', 'dd-mm-yyyy'), to_date('01-02-2013', 'dd-mm-yyyy'), 2, 9270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061019003972, to_date('19-10-2006', 'dd-mm-yyyy'), to_date('02-11-2006', 'dd-mm-yyyy'), 10, 5369, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080317003973, to_date('17-03-2008', 'dd-mm-yyyy'), to_date('31-03-2008', 'dd-mm-yyyy'), 8, 4943, to_date('05-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030929003974, to_date('29-09-2003', 'dd-mm-yyyy'), to_date('13-10-2003', 'dd-mm-yyyy'), 7, 2892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060613003975, to_date('13-06-2006', 'dd-mm-yyyy'), to_date('27-06-2006', 'dd-mm-yyyy'), 9, 5098, to_date('01-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101225003976, to_date('25-12-2010', 'dd-mm-yyyy'), to_date('08-01-2011', 'dd-mm-yyyy'), 4, 5847, to_date('13-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030502003977, to_date('02-05-2003', 'dd-mm-yyyy'), to_date('16-05-2003', 'dd-mm-yyyy'), 1, 3481, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923003978, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 9, 6822, to_date('11-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110918003979, to_date('18-09-2011', 'dd-mm-yyyy'), to_date('02-10-2011', 'dd-mm-yyyy'), 11, 8582, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120930003980, to_date('30-09-2012', 'dd-mm-yyyy'), to_date('14-10-2012', 'dd-mm-yyyy'), 8, 8252, to_date('07-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011012003981, to_date('12-10-2001', 'dd-mm-yyyy'), to_date('26-10-2001', 'dd-mm-yyyy'), 5, 1531, to_date('23-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409003982, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 3, 4893, to_date('19-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010829003983, to_date('29-08-2001', 'dd-mm-yyyy'), to_date('12-09-2001', 'dd-mm-yyyy'), 11, 1860, to_date('09-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080902006120, to_date('02-09-2008', 'dd-mm-yyyy'), to_date('16-09-2008', 'dd-mm-yyyy'), 4, 6231, to_date('05-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090515006121, to_date('15-05-2009', 'dd-mm-yyyy'), to_date('29-05-2009', 'dd-mm-yyyy'), 3, 5829, to_date('25-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022006122, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 10, 4889, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040810006123, to_date('10-08-2004', 'dd-mm-yyyy'), to_date('24-08-2004', 'dd-mm-yyyy'), 9, 4768, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030505006124, to_date('05-05-2003', 'dd-mm-yyyy'), to_date('19-05-2003', 'dd-mm-yyyy'), 7, 2343, to_date('14-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060315006125, to_date('15-03-2006', 'dd-mm-yyyy'), to_date('29-03-2006', 'dd-mm-yyyy'), 2, 4461, to_date('01-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101113006126, to_date('13-11-2010', 'dd-mm-yyyy'), to_date('27-11-2010', 'dd-mm-yyyy'), 4, 7922, to_date('24-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020422006127, to_date('22-04-2002', 'dd-mm-yyyy'), to_date('06-05-2002', 'dd-mm-yyyy'), 8, 2863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901006128, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 11, 9126, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216006129, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 2, 4420, to_date('22-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030713006130, to_date('13-07-2003', 'dd-mm-yyyy'), to_date('27-07-2003', 'dd-mm-yyyy'), 4, 4250, to_date('21-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623006131, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 7, 3791, to_date('27-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731006132, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 10, 6102, to_date('15-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050217006133, to_date('17-02-2005', 'dd-mm-yyyy'), to_date('03-03-2005', 'dd-mm-yyyy'), 8, 3665, to_date('26-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050407006134, to_date('07-04-2005', 'dd-mm-yyyy'), to_date('21-04-2005', 'dd-mm-yyyy'), 4, 5867, to_date('13-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010711006135, to_date('11-07-2001', 'dd-mm-yyyy'), to_date('25-07-2001', 'dd-mm-yyyy'), 8, 696, to_date('24-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502006136, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 6, 6673, to_date('04-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902006137, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 9, 1175, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070110006138, to_date('10-01-2007', 'dd-mm-yyyy'), to_date('24-01-2007', 'dd-mm-yyyy'), 9, 3910, to_date('11-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020907006139, to_date('07-09-2002', 'dd-mm-yyyy'), to_date('21-09-2002', 'dd-mm-yyyy'), 11, 1933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040717006140, to_date('17-07-2004', 'dd-mm-yyyy'), to_date('31-07-2004', 'dd-mm-yyyy'), 9, 5193, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060206006141, to_date('06-02-2006', 'dd-mm-yyyy'), to_date('20-02-2006', 'dd-mm-yyyy'), 1, 4297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515006142, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 8, 6489, to_date('17-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080330006143, to_date('30-03-2008', 'dd-mm-yyyy'), to_date('13-04-2008', 'dd-mm-yyyy'), 4, 7460, to_date('06-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115006144, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 9, 2745, to_date('04-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507006145, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 6, 2265, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080706006146, to_date('06-07-2008', 'dd-mm-yyyy'), to_date('20-07-2008', 'dd-mm-yyyy'), 1, 6373, to_date('18-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020122006147, to_date('22-01-2002', 'dd-mm-yyyy'), to_date('05-02-2002', 'dd-mm-yyyy'), 3, 1282, to_date('04-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100508006148, to_date('08-05-2010', 'dd-mm-yyyy'), to_date('22-05-2010', 'dd-mm-yyyy'), 6, 10210, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229006149, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 5, 2941, to_date('04-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020927006150, to_date('27-09-2002', 'dd-mm-yyyy'), to_date('11-10-2002', 'dd-mm-yyyy'), 10, 3123, to_date('02-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040216006151, to_date('16-02-2004', 'dd-mm-yyyy'), to_date('01-03-2004', 'dd-mm-yyyy'), 2, 4309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051122006152, to_date('22-11-2005', 'dd-mm-yyyy'), to_date('06-12-2005', 'dd-mm-yyyy'), 2, 3796, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020707006153, to_date('07-07-2002', 'dd-mm-yyyy'), to_date('21-07-2002', 'dd-mm-yyyy'), 7, 2918, to_date('19-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040316006154, to_date('16-03-2004', 'dd-mm-yyyy'), to_date('30-03-2004', 'dd-mm-yyyy'), 6, 4546, to_date('28-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614006155, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 10, 6883, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140331006156, to_date('31-03-2014', 'dd-mm-yyyy'), to_date('14-04-2014', 'dd-mm-yyyy'), 11, 10400, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111230006157, to_date('30-12-2011', 'dd-mm-yyyy'), to_date('13-01-2012', 'dd-mm-yyyy'), 10, 9376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060613006158, to_date('13-06-2006', 'dd-mm-yyyy'), to_date('27-06-2006', 'dd-mm-yyyy'), 8, 5140, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060907006159, to_date('07-09-2006', 'dd-mm-yyyy'), to_date('21-09-2006', 'dd-mm-yyyy'), 10, 5079, to_date('19-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020530006160, to_date('30-05-2002', 'dd-mm-yyyy'), to_date('13-06-2002', 'dd-mm-yyyy'), 8, 3621, to_date('08-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050609006161, to_date('09-06-2005', 'dd-mm-yyyy'), to_date('23-06-2005', 'dd-mm-yyyy'), 11, 3042, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020513006162, to_date('13-05-2002', 'dd-mm-yyyy'), to_date('27-05-2002', 'dd-mm-yyyy'), 3, 2822, to_date('26-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041116006163, to_date('16-11-2004', 'dd-mm-yyyy'), to_date('30-11-2004', 'dd-mm-yyyy'), 7, 3735, to_date('02-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000408006164, to_date('08-04-2000', 'dd-mm-yyyy'), to_date('22-04-2000', 'dd-mm-yyyy'), 2, 1153, to_date('27-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120920006165, to_date('20-09-2012', 'dd-mm-yyyy'), to_date('04-10-2012', 'dd-mm-yyyy'), 7, 9710, to_date('03-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422006166, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 4, 5885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080428006167, to_date('28-04-2008', 'dd-mm-yyyy'), to_date('12-05-2008', 'dd-mm-yyyy'), 7, 3899, to_date('11-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121108006168, to_date('08-11-2012', 'dd-mm-yyyy'), to_date('22-11-2012', 'dd-mm-yyyy'), 6, 7139, to_date('09-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120418006169, to_date('18-04-2012', 'dd-mm-yyyy'), to_date('02-05-2012', 'dd-mm-yyyy'), 5, 9223, to_date('05-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090408006170, to_date('08-04-2009', 'dd-mm-yyyy'), to_date('22-04-2009', 'dd-mm-yyyy'), 7, 5233, to_date('27-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403006171, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 12, 9315, to_date('06-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050930006172, to_date('30-09-2005', 'dd-mm-yyyy'), to_date('14-10-2005', 'dd-mm-yyyy'), 5, 3615, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618006173, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 7, 7237, to_date('08-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021019006174, to_date('19-10-2002', 'dd-mm-yyyy'), to_date('02-11-2002', 'dd-mm-yyyy'), 10, 3914, to_date('05-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081231006175, to_date('31-12-2008', 'dd-mm-yyyy'), to_date('14-01-2009', 'dd-mm-yyyy'), 11, 7699, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000831006176, to_date('31-08-2000', 'dd-mm-yyyy'), to_date('14-09-2000', 'dd-mm-yyyy'), 2, 2033, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021216006177, to_date('16-12-2002', 'dd-mm-yyyy'), to_date('30-12-2002', 'dd-mm-yyyy'), 4, 3909, to_date('31-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121007006178, to_date('07-10-2012', 'dd-mm-yyyy'), to_date('21-10-2012', 'dd-mm-yyyy'), 8, 7805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140130006179, to_date('30-01-2014', 'dd-mm-yyyy'), to_date('13-02-2014', 'dd-mm-yyyy'), 2, 9785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111216006180, to_date('16-12-2011', 'dd-mm-yyyy'), to_date('30-12-2011', 'dd-mm-yyyy'), 3, 9013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100409006181, to_date('09-04-2010', 'dd-mm-yyyy'), to_date('23-04-2010', 'dd-mm-yyyy'), 8, 5633, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090930006182, to_date('30-09-2009', 'dd-mm-yyyy'), to_date('14-10-2009', 'dd-mm-yyyy'), 2, 7468, to_date('17-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060404006183, to_date('04-04-2006', 'dd-mm-yyyy'), to_date('18-04-2006', 'dd-mm-yyyy'), 3, 5859, to_date('07-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231006184, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 2, 7227, to_date('19-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120223006185, to_date('23-02-2012', 'dd-mm-yyyy'), to_date('08-03-2012', 'dd-mm-yyyy'), 9, 4671, to_date('12-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011113006186, to_date('13-11-2001', 'dd-mm-yyyy'), to_date('27-11-2001', 'dd-mm-yyyy'), 9, 3135, to_date('24-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071218006187, to_date('18-12-2007', 'dd-mm-yyyy'), to_date('01-01-2008', 'dd-mm-yyyy'), 5, 6146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119006188, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 9, 1921, to_date('31-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629006189, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 7, 3813, to_date('08-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050721006190, to_date('21-07-2005', 'dd-mm-yyyy'), to_date('04-08-2005', 'dd-mm-yyyy'), 11, 3814, to_date('28-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100515006191, to_date('15-05-2010', 'dd-mm-yyyy'), to_date('29-05-2010', 'dd-mm-yyyy'), 4, 7943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140427006192, to_date('27-04-2014', 'dd-mm-yyyy'), to_date('11-05-2014', 'dd-mm-yyyy'), 9, 10831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050403006193, to_date('03-04-2005', 'dd-mm-yyyy'), to_date('17-04-2005', 'dd-mm-yyyy'), 4, 4131, to_date('15-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010818006194, to_date('18-08-2001', 'dd-mm-yyyy'), to_date('01-09-2001', 'dd-mm-yyyy'), 12, 1029, to_date('01-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040911006195, to_date('11-09-2004', 'dd-mm-yyyy'), to_date('25-09-2004', 'dd-mm-yyyy'), 6, 4768, to_date('24-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510006196, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 3, 1432, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526006197, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 7, 8080, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010831006198, to_date('31-08-2001', 'dd-mm-yyyy'), to_date('14-09-2001', 'dd-mm-yyyy'), 9, 2848, to_date('17-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090602006199, to_date('02-06-2009', 'dd-mm-yyyy'), to_date('16-06-2009', 'dd-mm-yyyy'), 7, 7172, to_date('10-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100502006200, to_date('02-05-2010', 'dd-mm-yyyy'), to_date('16-05-2010', 'dd-mm-yyyy'), 9, 8035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050718006201, to_date('18-07-2005', 'dd-mm-yyyy'), to_date('01-08-2005', 'dd-mm-yyyy'), 2, 6339, to_date('03-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020211006202, to_date('11-02-2002', 'dd-mm-yyyy'), to_date('25-02-2002', 'dd-mm-yyyy'), 8, 4371, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050330006203, to_date('30-03-2005', 'dd-mm-yyyy'), to_date('13-04-2005', 'dd-mm-yyyy'), 12, 3026, to_date('17-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808006204, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 4, 3074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110106006205, to_date('06-01-2011', 'dd-mm-yyyy'), to_date('20-01-2011', 'dd-mm-yyyy'), 5, 7457, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001215006206, to_date('15-12-2000', 'dd-mm-yyyy'), to_date('29-12-2000', 'dd-mm-yyyy'), 7, 1815, to_date('20-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000831006207, to_date('31-08-2000', 'dd-mm-yyyy'), to_date('14-09-2000', 'dd-mm-yyyy'), 10, 1396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070524006208, to_date('24-05-2007', 'dd-mm-yyyy'), to_date('07-06-2007', 'dd-mm-yyyy'), 9, 6026, to_date('25-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050518006209, to_date('18-05-2005', 'dd-mm-yyyy'), to_date('01-06-2005', 'dd-mm-yyyy'), 3, 5753, to_date('05-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020830006210, to_date('30-08-2002', 'dd-mm-yyyy'), to_date('13-09-2002', 'dd-mm-yyyy'), 2, 1713, to_date('13-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060402006211, to_date('02-04-2006', 'dd-mm-yyyy'), to_date('16-04-2006', 'dd-mm-yyyy'), 11, 6068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140223006212, to_date('23-02-2014', 'dd-mm-yyyy'), to_date('09-03-2014', 'dd-mm-yyyy'), 1, 13934, to_date('11-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401006213, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 1, 6650, to_date('09-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523006214, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 11, 3402, to_date('30-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070609006215, to_date('09-06-2007', 'dd-mm-yyyy'), to_date('23-06-2007', 'dd-mm-yyyy'), 9, 4526, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041217006216, to_date('17-12-2004', 'dd-mm-yyyy'), to_date('31-12-2004', 'dd-mm-yyyy'), 1, 4282, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130616006217, to_date('16-06-2013', 'dd-mm-yyyy'), to_date('30-06-2013', 'dd-mm-yyyy'), 4, 8902, to_date('01-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121208006218, to_date('08-12-2012', 'dd-mm-yyyy'), to_date('22-12-2012', 'dd-mm-yyyy'), 3, 7030, to_date('15-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609006219, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 10, 7884, to_date('25-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120902006220, to_date('02-09-2012', 'dd-mm-yyyy'), to_date('16-09-2012', 'dd-mm-yyyy'), 10, 8961, to_date('18-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090503006221, to_date('03-05-2009', 'dd-mm-yyyy'), to_date('17-05-2009', 'dd-mm-yyyy'), 3, 6328, to_date('05-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810006222, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 9, 2578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080701006223, to_date('01-07-2008', 'dd-mm-yyyy'), to_date('15-07-2008', 'dd-mm-yyyy'), 9, 5878, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060606006224, to_date('06-06-2006', 'dd-mm-yyyy'), to_date('20-06-2006', 'dd-mm-yyyy'), 9, 3256, to_date('13-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401006225, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 11, 8242, to_date('07-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220006226, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 2, 7590, to_date('22-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231006227, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 3, 7833, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824006228, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 2, 4227, to_date('25-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040511006229, to_date('11-05-2004', 'dd-mm-yyyy'), to_date('25-05-2004', 'dd-mm-yyyy'), 11, 6521, to_date('21-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130926006230, to_date('26-09-2013', 'dd-mm-yyyy'), to_date('10-10-2013', 'dd-mm-yyyy'), 9, 10484, to_date('07-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024006231, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 10, 6112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081129006232, to_date('29-11-2008', 'dd-mm-yyyy'), to_date('13-12-2008', 'dd-mm-yyyy'), 7, 6293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029006233, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 3, 4581, to_date('12-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011125006234, to_date('25-11-2001', 'dd-mm-yyyy'), to_date('09-12-2001', 'dd-mm-yyyy'), 4, 3448, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050507006235, to_date('07-05-2005', 'dd-mm-yyyy'), to_date('21-05-2005', 'dd-mm-yyyy'), 4, 4552, to_date('09-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028006236, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 11, 8960, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913006237, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 8, 4254, to_date('17-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120407006238, to_date('07-04-2012', 'dd-mm-yyyy'), to_date('21-04-2012', 'dd-mm-yyyy'), 3, 5833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108006239, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 11, 2152, to_date('17-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030811006240, to_date('11-08-2003', 'dd-mm-yyyy'), to_date('25-08-2003', 'dd-mm-yyyy'), 5, 2078, to_date('20-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090408006241, to_date('08-04-2009', 'dd-mm-yyyy'), to_date('22-04-2009', 'dd-mm-yyyy'), 4, 6477, to_date('12-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120219006242, to_date('19-02-2012', 'dd-mm-yyyy'), to_date('04-03-2012', 'dd-mm-yyyy'), 11, 7383, to_date('08-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208006243, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 5, 5800, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101118006244, to_date('18-11-2010', 'dd-mm-yyyy'), to_date('02-12-2010', 'dd-mm-yyyy'), 8, 7723, to_date('23-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729006245, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 4, 8999, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126006246, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 8, 5329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000916006247, to_date('16-09-2000', 'dd-mm-yyyy'), to_date('30-09-2000', 'dd-mm-yyyy'), 4, 1956, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050725006248, to_date('25-07-2005', 'dd-mm-yyyy'), to_date('08-08-2005', 'dd-mm-yyyy'), 2, 3526, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100101006249, to_date('01-01-2010', 'dd-mm-yyyy'), to_date('15-01-2010', 'dd-mm-yyyy'), 1, 6496, to_date('05-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000614006250, to_date('14-06-2000', 'dd-mm-yyyy'), to_date('28-06-2000', 'dd-mm-yyyy'), 2, 2240, to_date('22-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120201006251, to_date('01-02-2012', 'dd-mm-yyyy'), to_date('15-02-2012', 'dd-mm-yyyy'), 9, 8591, to_date('13-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040911006252, to_date('11-09-2004', 'dd-mm-yyyy'), to_date('25-09-2004', 'dd-mm-yyyy'), 4, 5456, to_date('14-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000130006253, to_date('30-01-2000', 'dd-mm-yyyy'), to_date('13-02-2000', 'dd-mm-yyyy'), 6, 2312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090217006254, to_date('17-02-2009', 'dd-mm-yyyy'), to_date('03-03-2009', 'dd-mm-yyyy'), 5, 7679, to_date('19-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302006255, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 2, 5848, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001118006256, to_date('18-11-2000', 'dd-mm-yyyy'), to_date('02-12-2000', 'dd-mm-yyyy'), 8, 2898, to_date('26-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091109006257, to_date('09-11-2009', 'dd-mm-yyyy'), to_date('23-11-2009', 'dd-mm-yyyy'), 6, 8295, to_date('26-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081028006258, to_date('28-10-2008', 'dd-mm-yyyy'), to_date('11-11-2008', 'dd-mm-yyyy'), 6, 5703, to_date('10-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140309006259, to_date('09-03-2014', 'dd-mm-yyyy'), to_date('23-03-2014', 'dd-mm-yyyy'), 4, 9086, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110930006260, to_date('30-09-2011', 'dd-mm-yyyy'), to_date('14-10-2011', 'dd-mm-yyyy'), 7, 8699, to_date('09-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120721006261, to_date('21-07-2012', 'dd-mm-yyyy'), to_date('04-08-2012', 'dd-mm-yyyy'), 10, 8408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070531006262, to_date('31-05-2007', 'dd-mm-yyyy'), to_date('14-06-2007', 'dd-mm-yyyy'), 4, 5579, to_date('05-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020607006263, to_date('07-06-2002', 'dd-mm-yyyy'), to_date('21-06-2002', 'dd-mm-yyyy'), 4, 2357, to_date('10-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000303006264, to_date('03-03-2000', 'dd-mm-yyyy'), to_date('17-03-2000', 'dd-mm-yyyy'), 11, 1334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811006265, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 4, 4935, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030328006266, to_date('28-03-2003', 'dd-mm-yyyy'), to_date('11-04-2003', 'dd-mm-yyyy'), 4, 4441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001108006267, to_date('08-11-2000', 'dd-mm-yyyy'), to_date('22-11-2000', 'dd-mm-yyyy'), 2, 2928, to_date('14-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101214006268, to_date('14-12-2010', 'dd-mm-yyyy'), to_date('28-12-2010', 'dd-mm-yyyy'), 8, 5893, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090930006269, to_date('30-09-2009', 'dd-mm-yyyy'), to_date('14-10-2009', 'dd-mm-yyyy'), 8, 8305, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001113006270, to_date('13-11-2000', 'dd-mm-yyyy'), to_date('27-11-2000', 'dd-mm-yyyy'), 10, 1398, to_date('29-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813006271, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 7, 7001, to_date('19-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000622006272, to_date('22-06-2000', 'dd-mm-yyyy'), to_date('06-07-2000', 'dd-mm-yyyy'), 4, 464, to_date('25-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630006273, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 10, 5778, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206008416, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 9, 6372, to_date('22-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408008417, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 3, 7210, to_date('11-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518008418, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 10, 4726, to_date('31-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130911008419, to_date('11-09-2013', 'dd-mm-yyyy'), to_date('25-09-2013', 'dd-mm-yyyy'), 5, 10759, to_date('20-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080308008420, to_date('08-03-2008', 'dd-mm-yyyy'), to_date('22-03-2008', 'dd-mm-yyyy'), 8, 6730, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219008421, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 6, 4643, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130214008422, to_date('14-02-2013', 'dd-mm-yyyy'), to_date('28-02-2013', 'dd-mm-yyyy'), 10, 8166, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110709008423, to_date('09-07-2011', 'dd-mm-yyyy'), to_date('23-07-2011', 'dd-mm-yyyy'), 7, 11476, to_date('17-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130618008424, to_date('18-06-2013', 'dd-mm-yyyy'), to_date('02-07-2013', 'dd-mm-yyyy'), 2, 5941, to_date('01-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070611008425, to_date('11-06-2007', 'dd-mm-yyyy'), to_date('25-06-2007', 'dd-mm-yyyy'), 3, 8013, to_date('12-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011004008426, to_date('04-10-2001', 'dd-mm-yyyy'), to_date('18-10-2001', 'dd-mm-yyyy'), 12, 3764, to_date('08-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110702008427, to_date('02-07-2011', 'dd-mm-yyyy'), to_date('16-07-2011', 'dd-mm-yyyy'), 5, 6034, to_date('16-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216008428, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 6, 4823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021002008429, to_date('02-10-2002', 'dd-mm-yyyy'), to_date('16-10-2002', 'dd-mm-yyyy'), 11, 4177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110309008430, to_date('09-03-2011', 'dd-mm-yyyy'), to_date('23-03-2011', 'dd-mm-yyyy'), 9, 8255, to_date('11-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020310008431, to_date('10-03-2002', 'dd-mm-yyyy'), to_date('24-03-2002', 'dd-mm-yyyy'), 2, 3796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518008432, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 3, 6152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010625008433, to_date('25-06-2001', 'dd-mm-yyyy'), to_date('09-07-2001', 'dd-mm-yyyy'), 10, 3313, to_date('30-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021206008434, to_date('06-12-2002', 'dd-mm-yyyy'), to_date('20-12-2002', 'dd-mm-yyyy'), 6, 3517, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061108008435, to_date('08-11-2006', 'dd-mm-yyyy'), to_date('22-11-2006', 'dd-mm-yyyy'), 4, 3948, to_date('26-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111018008436, to_date('18-10-2011', 'dd-mm-yyyy'), to_date('01-11-2011', 'dd-mm-yyyy'), 8, 7761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100307008437, to_date('07-03-2010', 'dd-mm-yyyy'), to_date('21-03-2010', 'dd-mm-yyyy'), 10, 4853, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071212008438, to_date('12-12-2007', 'dd-mm-yyyy'), to_date('26-12-2007', 'dd-mm-yyyy'), 5, 7628, to_date('01-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713008439, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 10, 7890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102008440, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 6, 4764, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218008441, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 10, 2997, to_date('23-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204008442, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 2, 11928, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050822008443, to_date('22-08-2005', 'dd-mm-yyyy'), to_date('05-09-2005', 'dd-mm-yyyy'), 9, 5052, to_date('08-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030521008444, to_date('21-05-2003', 'dd-mm-yyyy'), to_date('04-06-2003', 'dd-mm-yyyy'), 2, 3708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101008008445, to_date('08-10-2010', 'dd-mm-yyyy'), to_date('22-10-2010', 'dd-mm-yyyy'), 7, 7077, to_date('20-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060130008446, to_date('30-01-2006', 'dd-mm-yyyy'), to_date('13-02-2006', 'dd-mm-yyyy'), 9, 6379, to_date('03-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120613008447, to_date('13-06-2012', 'dd-mm-yyyy'), to_date('27-06-2012', 'dd-mm-yyyy'), 10, 9649, to_date('21-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204008448, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 2, 6846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050428008449, to_date('28-04-2005', 'dd-mm-yyyy'), to_date('12-05-2005', 'dd-mm-yyyy'), 9, 5048, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901008450, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 5, 3574, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725008451, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 5, 4247, to_date('30-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030610008452, to_date('10-06-2003', 'dd-mm-yyyy'), to_date('24-06-2003', 'dd-mm-yyyy'), 3, 1819, to_date('19-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070722008453, to_date('22-07-2007', 'dd-mm-yyyy'), to_date('05-08-2007', 'dd-mm-yyyy'), 8, 8296, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070522008454, to_date('22-05-2007', 'dd-mm-yyyy'), to_date('05-06-2007', 'dd-mm-yyyy'), 2, 3948, to_date('04-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000708008455, to_date('08-07-2000', 'dd-mm-yyyy'), to_date('22-07-2000', 'dd-mm-yyyy'), 2, 1690, to_date('24-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080604008456, to_date('04-06-2008', 'dd-mm-yyyy'), to_date('18-06-2008', 'dd-mm-yyyy'), 1, 6170, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213008457, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 6, 7250, to_date('25-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040101008458, to_date('01-01-2004', 'dd-mm-yyyy'), to_date('15-01-2004', 'dd-mm-yyyy'), 7, 5511, to_date('13-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071006008459, to_date('06-10-2007', 'dd-mm-yyyy'), to_date('20-10-2007', 'dd-mm-yyyy'), 6, 5628, to_date('25-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100607008460, to_date('07-06-2010', 'dd-mm-yyyy'), to_date('21-06-2010', 'dd-mm-yyyy'), 12, 6755, to_date('27-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100827008461, to_date('27-08-2010', 'dd-mm-yyyy'), to_date('10-09-2010', 'dd-mm-yyyy'), 9, 7896, to_date('13-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061204008462, to_date('04-12-2006', 'dd-mm-yyyy'), to_date('18-12-2006', 'dd-mm-yyyy'), 9, 5017, to_date('14-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011008008463, to_date('08-10-2001', 'dd-mm-yyyy'), to_date('22-10-2001', 'dd-mm-yyyy'), 3, 3421, to_date('26-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081128008464, to_date('28-11-2008', 'dd-mm-yyyy'), to_date('12-12-2008', 'dd-mm-yyyy'), 5, 6239, to_date('30-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011217008465, to_date('17-12-2001', 'dd-mm-yyyy'), to_date('31-12-2001', 'dd-mm-yyyy'), 7, 1432, to_date('26-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030402008466, to_date('02-04-2003', 'dd-mm-yyyy'), to_date('16-04-2003', 'dd-mm-yyyy'), 11, 2395, to_date('08-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110328008467, to_date('28-03-2011', 'dd-mm-yyyy'), to_date('11-04-2011', 'dd-mm-yyyy'), 8, 8884, to_date('06-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040930008468, to_date('30-09-2004', 'dd-mm-yyyy'), to_date('14-10-2004', 'dd-mm-yyyy'), 2, 3198, to_date('13-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020411008469, to_date('11-04-2002', 'dd-mm-yyyy'), to_date('25-04-2002', 'dd-mm-yyyy'), 6, 1980, to_date('28-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021105008470, to_date('05-11-2002', 'dd-mm-yyyy'), to_date('19-11-2002', 'dd-mm-yyyy'), 3, 3190, to_date('19-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309008471, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 2, 6043, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121127008472, to_date('27-11-2012', 'dd-mm-yyyy'), to_date('11-12-2012', 'dd-mm-yyyy'), 3, 7572, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041010008473, to_date('10-10-2004', 'dd-mm-yyyy'), to_date('24-10-2004', 'dd-mm-yyyy'), 10, 2636, to_date('15-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050623008474, to_date('23-06-2005', 'dd-mm-yyyy'), to_date('07-07-2005', 'dd-mm-yyyy'), 4, 4366, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050905008475, to_date('05-09-2005', 'dd-mm-yyyy'), to_date('19-09-2005', 'dd-mm-yyyy'), 10, 4002, to_date('14-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070406008476, to_date('06-04-2007', 'dd-mm-yyyy'), to_date('20-04-2007', 'dd-mm-yyyy'), 4, 5373, to_date('14-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130505008477, to_date('05-05-2013', 'dd-mm-yyyy'), to_date('19-05-2013', 'dd-mm-yyyy'), 7, 10381, to_date('11-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000925008478, to_date('25-09-2000', 'dd-mm-yyyy'), to_date('09-10-2000', 'dd-mm-yyyy'), 6, 799, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204008479, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 2, 7735, to_date('15-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001029008480, to_date('29-10-2000', 'dd-mm-yyyy'), to_date('12-11-2000', 'dd-mm-yyyy'), 9, 4074, to_date('15-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081014008481, to_date('14-10-2008', 'dd-mm-yyyy'), to_date('28-10-2008', 'dd-mm-yyyy'), 4, 6459, to_date('23-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529008482, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 1, 5413, to_date('10-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604008483, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 9, 6464, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120301008484, to_date('01-03-2012', 'dd-mm-yyyy'), to_date('15-03-2012', 'dd-mm-yyyy'), 6, 10960, to_date('07-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901008485, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 2, 7046, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801008486, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 12, 4410, to_date('08-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050125008487, to_date('25-01-2005', 'dd-mm-yyyy'), to_date('08-02-2005', 'dd-mm-yyyy'), 3, 4545, to_date('31-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100203008488, to_date('03-02-2010', 'dd-mm-yyyy'), to_date('17-02-2010', 'dd-mm-yyyy'), 11, 6190, to_date('07-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110718008489, to_date('18-07-2011', 'dd-mm-yyyy'), to_date('01-08-2011', 'dd-mm-yyyy'), 4, 8317, to_date('03-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110413008490, to_date('13-04-2011', 'dd-mm-yyyy'), to_date('27-04-2011', 'dd-mm-yyyy'), 11, 7044, to_date('17-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121120008491, to_date('20-11-2012', 'dd-mm-yyyy'), to_date('04-12-2012', 'dd-mm-yyyy'), 5, 8826, to_date('29-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010410008492, to_date('10-04-2001', 'dd-mm-yyyy'), to_date('24-04-2001', 'dd-mm-yyyy'), 7, 1761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030817008493, to_date('17-08-2003', 'dd-mm-yyyy'), to_date('31-08-2003', 'dd-mm-yyyy'), 11, 2170, to_date('24-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051211008494, to_date('11-12-2005', 'dd-mm-yyyy'), to_date('25-12-2005', 'dd-mm-yyyy'), 9, 6130, to_date('28-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403008495, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 9, 5717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021029008496, to_date('29-10-2002', 'dd-mm-yyyy'), to_date('12-11-2002', 'dd-mm-yyyy'), 4, 2116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101008497, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 1, 5466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120518008498, to_date('18-05-2012', 'dd-mm-yyyy'), to_date('01-06-2012', 'dd-mm-yyyy'), 2, 6755, to_date('05-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070630008499, to_date('30-06-2007', 'dd-mm-yyyy'), to_date('14-07-2007', 'dd-mm-yyyy'), 3, 6659, to_date('19-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071221008500, to_date('21-12-2007', 'dd-mm-yyyy'), to_date('04-01-2008', 'dd-mm-yyyy'), 4, 7535, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090218008501, to_date('18-02-2009', 'dd-mm-yyyy'), to_date('04-03-2009', 'dd-mm-yyyy'), 6, 8858, to_date('22-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413008502, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 2, 11471, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070619008503, to_date('19-06-2007', 'dd-mm-yyyy'), to_date('03-07-2007', 'dd-mm-yyyy'), 9, 5613, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030114008504, to_date('14-01-2003', 'dd-mm-yyyy'), to_date('28-01-2003', 'dd-mm-yyyy'), 6, 2887, to_date('19-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050111008505, to_date('11-01-2005', 'dd-mm-yyyy'), to_date('25-01-2005', 'dd-mm-yyyy'), 10, 5275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108008506, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 2, 6046, to_date('22-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060226008507, to_date('26-02-2006', 'dd-mm-yyyy'), to_date('12-03-2006', 'dd-mm-yyyy'), 2, 5276, to_date('05-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827008508, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 10, 3595, to_date('29-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070514008509, to_date('14-05-2007', 'dd-mm-yyyy'), to_date('28-05-2007', 'dd-mm-yyyy'), 5, 4563, to_date('19-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090227008510, to_date('27-02-2009', 'dd-mm-yyyy'), to_date('13-03-2009', 'dd-mm-yyyy'), 4, 6408, to_date('19-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000705008511, to_date('05-07-2000', 'dd-mm-yyyy'), to_date('19-07-2000', 'dd-mm-yyyy'), 9, 1837, to_date('08-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130531008512, to_date('31-05-2013', 'dd-mm-yyyy'), to_date('14-06-2013', 'dd-mm-yyyy'), 2, 9914, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050719008513, to_date('19-07-2005', 'dd-mm-yyyy'), to_date('02-08-2005', 'dd-mm-yyyy'), 11, 5482, to_date('29-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011015008514, to_date('15-10-2001', 'dd-mm-yyyy'), to_date('29-10-2001', 'dd-mm-yyyy'), 6, 1219, to_date('31-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131211008515, to_date('11-12-2013', 'dd-mm-yyyy'), to_date('25-12-2013', 'dd-mm-yyyy'), 10, 6995, to_date('24-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110612008516, to_date('12-06-2011', 'dd-mm-yyyy'), to_date('26-06-2011', 'dd-mm-yyyy'), 5, 6061, to_date('15-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311008517, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 3, 5463, to_date('13-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011129008518, to_date('29-11-2001', 'dd-mm-yyyy'), to_date('13-12-2001', 'dd-mm-yyyy'), 3, 2434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061112008519, to_date('12-11-2006', 'dd-mm-yyyy'), to_date('26-11-2006', 'dd-mm-yyyy'), 6, 5176, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228008520, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 2, 6882, to_date('07-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020502008521, to_date('02-05-2002', 'dd-mm-yyyy'), to_date('16-05-2002', 'dd-mm-yyyy'), 9, 1141, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000521008522, to_date('21-05-2000', 'dd-mm-yyyy'), to_date('04-06-2000', 'dd-mm-yyyy'), 7, 2076, to_date('26-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421008523, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 12, 8421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140307008524, to_date('07-03-2014', 'dd-mm-yyyy'), to_date('21-03-2014', 'dd-mm-yyyy'), 4, 10985, to_date('16-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110525008525, to_date('25-05-2011', 'dd-mm-yyyy'), to_date('08-06-2011', 'dd-mm-yyyy'), 4, 5775, to_date('28-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011001008526, to_date('01-10-2001', 'dd-mm-yyyy'), to_date('15-10-2001', 'dd-mm-yyyy'), 7, 2642, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010423008527, to_date('23-04-2001', 'dd-mm-yyyy'), to_date('07-05-2001', 'dd-mm-yyyy'), 11, 3219, to_date('11-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041217008528, to_date('17-12-2004', 'dd-mm-yyyy'), to_date('31-12-2004', 'dd-mm-yyyy'), 10, 2682, to_date('24-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050914008529, to_date('14-09-2005', 'dd-mm-yyyy'), to_date('28-09-2005', 'dd-mm-yyyy'), 2, 6566, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030325008530, to_date('25-03-2003', 'dd-mm-yyyy'), to_date('08-04-2003', 'dd-mm-yyyy'), 12, 2716, to_date('13-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726008531, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 4, 3870, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000914008532, to_date('14-09-2000', 'dd-mm-yyyy'), to_date('28-09-2000', 'dd-mm-yyyy'), 3, 3359, to_date('21-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110428008533, to_date('28-04-2011', 'dd-mm-yyyy'), to_date('12-05-2011', 'dd-mm-yyyy'), 5, 7598, to_date('14-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708008534, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 11, 2466, to_date('14-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040420008535, to_date('20-04-2004', 'dd-mm-yyyy'), to_date('04-05-2004', 'dd-mm-yyyy'), 6, 2286, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419008536, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 2, 3473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223008537, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 4, 6957, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041013008538, to_date('13-10-2004', 'dd-mm-yyyy'), to_date('27-10-2004', 'dd-mm-yyyy'), 11, 3473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010824008539, to_date('24-08-2001', 'dd-mm-yyyy'), to_date('07-09-2001', 'dd-mm-yyyy'), 10, 1803, to_date('11-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050618008540, to_date('18-06-2005', 'dd-mm-yyyy'), to_date('02-07-2005', 'dd-mm-yyyy'), 4, 5639, to_date('25-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821008541, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 1, 6363, to_date('24-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030614008542, to_date('14-06-2003', 'dd-mm-yyyy'), to_date('28-06-2003', 'dd-mm-yyyy'), 5, 2964, to_date('30-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225008543, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 6, 5805, to_date('13-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090423008544, to_date('23-04-2009', 'dd-mm-yyyy'), to_date('07-05-2009', 'dd-mm-yyyy'), 1, 6962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070512008545, to_date('12-05-2007', 'dd-mm-yyyy'), to_date('26-05-2007', 'dd-mm-yyyy'), 9, 4823, to_date('24-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513008546, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 11, 5891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010105008547, to_date('05-01-2001', 'dd-mm-yyyy'), to_date('19-01-2001', 'dd-mm-yyyy'), 11, 1973, to_date('18-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040704008548, to_date('04-07-2004', 'dd-mm-yyyy'), to_date('18-07-2004', 'dd-mm-yyyy'), 4, 2730, to_date('10-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140211008549, to_date('11-02-2014', 'dd-mm-yyyy'), to_date('25-02-2014', 'dd-mm-yyyy'), 4, 10072, to_date('28-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040602008550, to_date('02-06-2004', 'dd-mm-yyyy'), to_date('16-06-2004', 'dd-mm-yyyy'), 4, 3439, to_date('04-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101101008551, to_date('01-11-2010', 'dd-mm-yyyy'), to_date('15-11-2010', 'dd-mm-yyyy'), 11, 6810, to_date('08-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010803008552, to_date('03-08-2001', 'dd-mm-yyyy'), to_date('17-08-2001', 'dd-mm-yyyy'), 2, 2958, to_date('10-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121020008553, to_date('20-10-2012', 'dd-mm-yyyy'), to_date('03-11-2012', 'dd-mm-yyyy'), 9, 6769, to_date('08-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070404008554, to_date('04-04-2007', 'dd-mm-yyyy'), to_date('18-04-2007', 'dd-mm-yyyy'), 2, 5787, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090605008555, to_date('05-06-2009', 'dd-mm-yyyy'), to_date('19-06-2009', 'dd-mm-yyyy'), 9, 5632, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202008556, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 3, 3870, to_date('19-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070919008557, to_date('19-09-2007', 'dd-mm-yyyy'), to_date('03-10-2007', 'dd-mm-yyyy'), 2, 5214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080406008558, to_date('06-04-2008', 'dd-mm-yyyy'), to_date('20-04-2008', 'dd-mm-yyyy'), 1, 6761, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010810008559, to_date('10-08-2001', 'dd-mm-yyyy'), to_date('24-08-2001', 'dd-mm-yyyy'), 7, 1576, to_date('20-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051102008560, to_date('02-11-2005', 'dd-mm-yyyy'), to_date('16-11-2005', 'dd-mm-yyyy'), 10, 3931, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824008561, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 10, 5187, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060626008562, to_date('26-06-2006', 'dd-mm-yyyy'), to_date('10-07-2006', 'dd-mm-yyyy'), 5, 3516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010710008563, to_date('10-07-2001', 'dd-mm-yyyy'), to_date('24-07-2001', 'dd-mm-yyyy'), 10, 3283, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000303008564, to_date('03-03-2000', 'dd-mm-yyyy'), to_date('17-03-2000', 'dd-mm-yyyy'), 9, 2675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601008565, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 11, 5488, to_date('03-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051127008566, to_date('27-11-2005', 'dd-mm-yyyy'), to_date('11-12-2005', 'dd-mm-yyyy'), 9, 4297, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120118008567, to_date('18-01-2012', 'dd-mm-yyyy'), to_date('01-02-2012', 'dd-mm-yyyy'), 7, 10116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010207001529, to_date('07-02-2001', 'dd-mm-yyyy'), to_date('21-02-2001', 'dd-mm-yyyy'), 3, 3140, to_date('15-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429001530, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 6, 2596, to_date('15-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090814001531, to_date('14-08-2009', 'dd-mm-yyyy'), to_date('28-08-2009', 'dd-mm-yyyy'), 2, 7336, to_date('19-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912001532, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 6, 4591, to_date('24-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040221001533, to_date('21-02-2004', 'dd-mm-yyyy'), to_date('06-03-2004', 'dd-mm-yyyy'), 7, 2422, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090227001534, to_date('27-02-2009', 'dd-mm-yyyy'), to_date('13-03-2009', 'dd-mm-yyyy'), 9, 4096, to_date('13-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001108001535, to_date('08-11-2000', 'dd-mm-yyyy'), to_date('22-11-2000', 'dd-mm-yyyy'), 6, 1722, to_date('25-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060804001536, to_date('04-08-2006', 'dd-mm-yyyy'), to_date('18-08-2006', 'dd-mm-yyyy'), 8, 5133, to_date('19-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329001537, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 5, 6735, to_date('01-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051129001538, to_date('29-11-2005', 'dd-mm-yyyy'), to_date('13-12-2005', 'dd-mm-yyyy'), 3, 2915, to_date('18-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010917001539, to_date('17-09-2001', 'dd-mm-yyyy'), to_date('01-10-2001', 'dd-mm-yyyy'), 3, 3740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111023001540, to_date('23-10-2011', 'dd-mm-yyyy'), to_date('06-11-2011', 'dd-mm-yyyy'), 6, 4944, to_date('06-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080415001541, to_date('15-04-2008', 'dd-mm-yyyy'), to_date('29-04-2008', 'dd-mm-yyyy'), 9, 6733, to_date('18-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125001542, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 11, 7091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917001543, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 5, 4907, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080328001544, to_date('28-03-2008', 'dd-mm-yyyy'), to_date('11-04-2008', 'dd-mm-yyyy'), 12, 7508, to_date('01-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120223001545, to_date('23-02-2012', 'dd-mm-yyyy'), to_date('08-03-2012', 'dd-mm-yyyy'), 8, 10848, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010806001546, to_date('06-08-2001', 'dd-mm-yyyy'), to_date('20-08-2001', 'dd-mm-yyyy'), 8, 2282, to_date('07-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912001547, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 9, 4281, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060707001548, to_date('07-07-2006', 'dd-mm-yyyy'), to_date('21-07-2006', 'dd-mm-yyyy'), 11, 2197, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100916001549, to_date('16-09-2010', 'dd-mm-yyyy'), to_date('30-09-2010', 'dd-mm-yyyy'), 2, 7508, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021017001550, to_date('17-10-2002', 'dd-mm-yyyy'), to_date('31-10-2002', 'dd-mm-yyyy'), 7, 2072, to_date('28-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131121001551, to_date('21-11-2013', 'dd-mm-yyyy'), to_date('05-12-2013', 'dd-mm-yyyy'), 4, 8634, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091118001552, to_date('18-11-2009', 'dd-mm-yyyy'), to_date('02-12-2009', 'dd-mm-yyyy'), 5, 6689, to_date('28-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080124001553, to_date('24-01-2008', 'dd-mm-yyyy'), to_date('07-02-2008', 'dd-mm-yyyy'), 6, 4343, to_date('04-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010327001554, to_date('27-03-2001', 'dd-mm-yyyy'), to_date('10-04-2001', 'dd-mm-yyyy'), 5, 4277, to_date('12-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726001555, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 4, 2983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050401001556, to_date('01-04-2005', 'dd-mm-yyyy'), to_date('15-04-2005', 'dd-mm-yyyy'), 7, 4737, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100421001557, to_date('21-04-2010', 'dd-mm-yyyy'), to_date('05-05-2010', 'dd-mm-yyyy'), 10, 8910, to_date('09-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010516001558, to_date('16-05-2001', 'dd-mm-yyyy'), to_date('30-05-2001', 'dd-mm-yyyy'), 11, 1707, to_date('20-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110731001559, to_date('31-07-2011', 'dd-mm-yyyy'), to_date('14-08-2011', 'dd-mm-yyyy'), 7, 6910, to_date('07-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030701001560, to_date('01-07-2003', 'dd-mm-yyyy'), to_date('15-07-2003', 'dd-mm-yyyy'), 10, 2617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011126001561, to_date('26-11-2001', 'dd-mm-yyyy'), to_date('10-12-2001', 'dd-mm-yyyy'), 10, 1816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729001562, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 9, 7585, to_date('31-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140410001563, to_date('10-04-2014', 'dd-mm-yyyy'), to_date('24-04-2014', 'dd-mm-yyyy'), 6, 9691, to_date('22-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919001564, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 5, 7098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401001565, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 1, 8151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080616001566, to_date('16-06-2008', 'dd-mm-yyyy'), to_date('30-06-2008', 'dd-mm-yyyy'), 1, 4127, to_date('29-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101110001567, to_date('10-11-2010', 'dd-mm-yyyy'), to_date('24-11-2010', 'dd-mm-yyyy'), 6, 7416, to_date('14-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130316001568, to_date('16-03-2013', 'dd-mm-yyyy'), to_date('30-03-2013', 'dd-mm-yyyy'), 10, 11248, to_date('23-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091107001569, to_date('07-11-2009', 'dd-mm-yyyy'), to_date('21-11-2009', 'dd-mm-yyyy'), 1, 5038, to_date('16-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104001570, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 4, 4581, to_date('23-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425001571, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 10, 7583, to_date('01-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222001572, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 6, 6436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111001573, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 11, 1371, to_date('13-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627001574, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 10, 5323, to_date('03-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021208001575, to_date('08-12-2002', 'dd-mm-yyyy'), to_date('22-12-2002', 'dd-mm-yyyy'), 7, 2399, to_date('13-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041005001576, to_date('05-10-2004', 'dd-mm-yyyy'), to_date('19-10-2004', 'dd-mm-yyyy'), 4, 3733, to_date('23-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531001577, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 8, 2235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101225001578, to_date('25-12-2010', 'dd-mm-yyyy'), to_date('08-01-2011', 'dd-mm-yyyy'), 2, 6078, to_date('04-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061218001579, to_date('18-12-2006', 'dd-mm-yyyy'), to_date('01-01-2007', 'dd-mm-yyyy'), 2, 6429, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051225001580, to_date('25-12-2005', 'dd-mm-yyyy'), to_date('08-01-2006', 'dd-mm-yyyy'), 9, 2888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030729001581, to_date('29-07-2003', 'dd-mm-yyyy'), to_date('12-08-2003', 'dd-mm-yyyy'), 6, 3617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121001582, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 10, 11680, to_date('23-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100125001583, to_date('25-01-2010', 'dd-mm-yyyy'), to_date('08-02-2010', 'dd-mm-yyyy'), 11, 7297, to_date('03-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010105001584, to_date('05-01-2001', 'dd-mm-yyyy'), to_date('19-01-2001', 'dd-mm-yyyy'), 11, 2741, to_date('14-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061112001585, to_date('12-11-2006', 'dd-mm-yyyy'), to_date('26-11-2006', 'dd-mm-yyyy'), 4, 5942, to_date('30-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041119001586, to_date('19-11-2004', 'dd-mm-yyyy'), to_date('03-12-2004', 'dd-mm-yyyy'), 3, 2305, to_date('28-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111209001587, to_date('09-12-2011', 'dd-mm-yyyy'), to_date('23-12-2011', 'dd-mm-yyyy'), 7, 10073, to_date('11-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020820001588, to_date('20-08-2002', 'dd-mm-yyyy'), to_date('03-09-2002', 'dd-mm-yyyy'), 3, 3709, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060810001589, to_date('10-08-2006', 'dd-mm-yyyy'), to_date('24-08-2006', 'dd-mm-yyyy'), 4, 4702, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305001590, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 4, 8771, to_date('08-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031009001591, to_date('09-10-2003', 'dd-mm-yyyy'), to_date('23-10-2003', 'dd-mm-yyyy'), 1, 3150, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429001592, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 10, 6435, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921001593, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 11, 7485, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010222001594, to_date('22-02-2001', 'dd-mm-yyyy'), to_date('08-03-2001', 'dd-mm-yyyy'), 9, 2357, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090918001595, to_date('18-09-2009', 'dd-mm-yyyy'), to_date('02-10-2009', 'dd-mm-yyyy'), 6, 6392, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000117001596, to_date('17-01-2000', 'dd-mm-yyyy'), to_date('31-01-2000', 'dd-mm-yyyy'), 6, 1111, to_date('23-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091003001597, to_date('03-10-2009', 'dd-mm-yyyy'), to_date('17-10-2009', 'dd-mm-yyyy'), 7, 4697, to_date('22-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050404001598, to_date('04-04-2005', 'dd-mm-yyyy'), to_date('18-04-2005', 'dd-mm-yyyy'), 6, 5634, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060619001599, to_date('19-06-2006', 'dd-mm-yyyy'), to_date('03-07-2006', 'dd-mm-yyyy'), 9, 4082, to_date('09-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100822001600, to_date('22-08-2010', 'dd-mm-yyyy'), to_date('05-09-2010', 'dd-mm-yyyy'), 12, 7631, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100529001601, to_date('29-05-2010', 'dd-mm-yyyy'), to_date('12-06-2010', 'dd-mm-yyyy'), 4, 5511, to_date('31-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110515001602, to_date('15-05-2011', 'dd-mm-yyyy'), to_date('29-05-2011', 'dd-mm-yyyy'), 10, 8179, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124001603, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 4, 2747, to_date('30-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010312001604, to_date('12-03-2001', 'dd-mm-yyyy'), to_date('26-03-2001', 'dd-mm-yyyy'), 2, 3714, to_date('16-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050319001605, to_date('19-03-2005', 'dd-mm-yyyy'), to_date('02-04-2005', 'dd-mm-yyyy'), 2, 4914, to_date('22-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000201001606, to_date('01-02-2000', 'dd-mm-yyyy'), to_date('15-02-2000', 'dd-mm-yyyy'), 10, 2202, to_date('12-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504001607, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 2, 1903, to_date('08-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000709001608, to_date('09-07-2000', 'dd-mm-yyyy'), to_date('23-07-2000', 'dd-mm-yyyy'), 6, 1872, to_date('16-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101010001609, to_date('10-10-2010', 'dd-mm-yyyy'), to_date('24-10-2010', 'dd-mm-yyyy'), 5, 6277, to_date('22-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111010001610, to_date('10-10-2011', 'dd-mm-yyyy'), to_date('24-10-2011', 'dd-mm-yyyy'), 8, 7418, to_date('22-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407001611, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 4, 10729, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070916001612, to_date('16-09-2007', 'dd-mm-yyyy'), to_date('30-09-2007', 'dd-mm-yyyy'), 1, 5566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140427001613, to_date('27-04-2014', 'dd-mm-yyyy'), to_date('11-05-2014', 'dd-mm-yyyy'), 5, 10592, to_date('11-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024001614, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 4, 8236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010808001615, to_date('08-08-2001', 'dd-mm-yyyy'), to_date('22-08-2001', 'dd-mm-yyyy'), 1, 2583, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080717001616, to_date('17-07-2008', 'dd-mm-yyyy'), to_date('31-07-2008', 'dd-mm-yyyy'), 3, 5976, to_date('31-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080805001617, to_date('05-08-2008', 'dd-mm-yyyy'), to_date('19-08-2008', 'dd-mm-yyyy'), 12, 7253, to_date('08-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130112001618, to_date('12-01-2013', 'dd-mm-yyyy'), to_date('26-01-2013', 'dd-mm-yyyy'), 2, 8766, to_date('30-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070128001619, to_date('28-01-2007', 'dd-mm-yyyy'), to_date('11-02-2007', 'dd-mm-yyyy'), 6, 5525, to_date('31-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328001620, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 1, 6324, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030824001621, to_date('24-08-2003', 'dd-mm-yyyy'), to_date('07-09-2003', 'dd-mm-yyyy'), 6, 2179, to_date('03-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091029001622, to_date('29-10-2009', 'dd-mm-yyyy'), to_date('12-11-2009', 'dd-mm-yyyy'), 9, 9757, to_date('13-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100304001623, to_date('04-03-2010', 'dd-mm-yyyy'), to_date('18-03-2010', 'dd-mm-yyyy'), 1, 6976, to_date('15-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209001624, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 10, 4229, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110526001625, to_date('26-05-2011', 'dd-mm-yyyy'), to_date('09-06-2011', 'dd-mm-yyyy'), 3, 4125, to_date('12-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090107001626, to_date('07-01-2009', 'dd-mm-yyyy'), to_date('21-01-2009', 'dd-mm-yyyy'), 5, 6448, to_date('23-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430001627, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 3, 8260, to_date('06-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110426001628, to_date('26-04-2011', 'dd-mm-yyyy'), to_date('10-05-2011', 'dd-mm-yyyy'), 3, 7866, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120408001629, to_date('08-04-2012', 'dd-mm-yyyy'), to_date('22-04-2012', 'dd-mm-yyyy'), 7, 9457, to_date('15-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010823001630, to_date('23-08-2001', 'dd-mm-yyyy'), to_date('06-09-2001', 'dd-mm-yyyy'), 9, 2308, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070909001631, to_date('09-09-2007', 'dd-mm-yyyy'), to_date('23-09-2007', 'dd-mm-yyyy'), 3, 5586, to_date('14-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061109001632, to_date('09-11-2006', 'dd-mm-yyyy'), to_date('23-11-2006', 'dd-mm-yyyy'), 3, 2831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090403001633, to_date('03-04-2009', 'dd-mm-yyyy'), to_date('17-04-2009', 'dd-mm-yyyy'), 4, 7768, to_date('11-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100122001634, to_date('22-01-2010', 'dd-mm-yyyy'), to_date('05-02-2010', 'dd-mm-yyyy'), 7, 6847, to_date('06-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823001635, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 12, 9321, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050219001636, to_date('19-02-2005', 'dd-mm-yyyy'), to_date('05-03-2005', 'dd-mm-yyyy'), 9, 3927, to_date('04-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081211001637, to_date('11-12-2008', 'dd-mm-yyyy'), to_date('25-12-2008', 'dd-mm-yyyy'), 8, 4848, to_date('31-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110610001638, to_date('10-06-2011', 'dd-mm-yyyy'), to_date('24-06-2011', 'dd-mm-yyyy'), 7, 10496, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021014001639, to_date('14-10-2002', 'dd-mm-yyyy'), to_date('28-10-2002', 'dd-mm-yyyy'), 9, 3891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081028001640, to_date('28-10-2008', 'dd-mm-yyyy'), to_date('11-11-2008', 'dd-mm-yyyy'), 3, 4460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051127001641, to_date('27-11-2005', 'dd-mm-yyyy'), to_date('11-12-2005', 'dd-mm-yyyy'), 6, 4784, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110114001642, to_date('14-01-2011', 'dd-mm-yyyy'), to_date('28-01-2011', 'dd-mm-yyyy'), 2, 7608, to_date('02-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615001643, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 1, 5987, to_date('24-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110422001644, to_date('22-04-2011', 'dd-mm-yyyy'), to_date('06-05-2011', 'dd-mm-yyyy'), 11, 7608, to_date('06-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930001645, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 6, 2181, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926001646, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 8, 6910, to_date('29-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009001647, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 11, 6714, to_date('14-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140118001648, to_date('18-01-2014', 'dd-mm-yyyy'), to_date('01-02-2014', 'dd-mm-yyyy'), 8, 8677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000424001649, to_date('24-04-2000', 'dd-mm-yyyy'), to_date('08-05-2000', 'dd-mm-yyyy'), 11, 1440, to_date('09-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040825001650, to_date('25-08-2004', 'dd-mm-yyyy'), to_date('08-09-2004', 'dd-mm-yyyy'), 12, 4170, to_date('03-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070101001651, to_date('01-01-2007', 'dd-mm-yyyy'), to_date('15-01-2007', 'dd-mm-yyyy'), 2, 4911, to_date('03-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031003001652, to_date('03-10-2003', 'dd-mm-yyyy'), to_date('17-10-2003', 'dd-mm-yyyy'), 6, 5253, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080421001653, to_date('21-04-2008', 'dd-mm-yyyy'), to_date('05-05-2008', 'dd-mm-yyyy'), 4, 6619, to_date('04-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041022001654, to_date('22-10-2004', 'dd-mm-yyyy'), to_date('05-11-2004', 'dd-mm-yyyy'), 3, 4823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060109001655, to_date('09-01-2006', 'dd-mm-yyyy'), to_date('23-01-2006', 'dd-mm-yyyy'), 3, 5662, to_date('13-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050117001656, to_date('17-01-2005', 'dd-mm-yyyy'), to_date('31-01-2005', 'dd-mm-yyyy'), 1, 5291, to_date('23-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060622001657, to_date('22-06-2006', 'dd-mm-yyyy'), to_date('06-07-2006', 'dd-mm-yyyy'), 2, 5093, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080509001658, to_date('09-05-2008', 'dd-mm-yyyy'), to_date('23-05-2008', 'dd-mm-yyyy'), 2, 5956, to_date('17-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121210001659, to_date('10-12-2012', 'dd-mm-yyyy'), to_date('24-12-2012', 'dd-mm-yyyy'), 6, 8683, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112001660, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 10, 8051, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040113001661, to_date('13-01-2004', 'dd-mm-yyyy'), to_date('27-01-2004', 'dd-mm-yyyy'), 5, 2855, to_date('22-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120910001662, to_date('10-09-2012', 'dd-mm-yyyy'), to_date('24-09-2012', 'dd-mm-yyyy'), 6, 7298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061017001663, to_date('17-10-2006', 'dd-mm-yyyy'), to_date('31-10-2006', 'dd-mm-yyyy'), 3, 6029, to_date('18-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110126001664, to_date('26-01-2011', 'dd-mm-yyyy'), to_date('09-02-2011', 'dd-mm-yyyy'), 6, 8308, to_date('28-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000209001665, to_date('09-02-2000', 'dd-mm-yyyy'), to_date('23-02-2000', 'dd-mm-yyyy'), 3, 2486, to_date('13-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100623001666, to_date('23-06-2010', 'dd-mm-yyyy'), to_date('07-07-2010', 'dd-mm-yyyy'), 11, 7387, to_date('08-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080706001667, to_date('06-07-2008', 'dd-mm-yyyy'), to_date('20-07-2008', 'dd-mm-yyyy'), 3, 8193, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225001668, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 4, 5451, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070528001669, to_date('28-05-2007', 'dd-mm-yyyy'), to_date('11-06-2007', 'dd-mm-yyyy'), 4, 4660, to_date('13-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040115001670, to_date('15-01-2004', 'dd-mm-yyyy'), to_date('29-01-2004', 'dd-mm-yyyy'), 4, 5645, to_date('30-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323001671, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 7, 4101, to_date('08-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081128001672, to_date('28-11-2008', 'dd-mm-yyyy'), to_date('12-12-2008', 'dd-mm-yyyy'), 2, 6803, to_date('01-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030504001673, to_date('04-05-2003', 'dd-mm-yyyy'), to_date('18-05-2003', 'dd-mm-yyyy'), 9, 3390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040415001674, to_date('15-04-2004', 'dd-mm-yyyy'), to_date('29-04-2004', 'dd-mm-yyyy'), 4, 3853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813001675, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 7, 3798, to_date('30-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140118001676, to_date('18-01-2014', 'dd-mm-yyyy'), to_date('01-02-2014', 'dd-mm-yyyy'), 8, 5638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020702001677, to_date('02-07-2002', 'dd-mm-yyyy'), to_date('16-07-2002', 'dd-mm-yyyy'), 12, 2759, to_date('06-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815001678, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 7, 5919, to_date('17-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101117001679, to_date('17-11-2010', 'dd-mm-yyyy'), to_date('01-12-2010', 'dd-mm-yyyy'), 12, 6984, to_date('01-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070109001680, to_date('09-01-2007', 'dd-mm-yyyy'), to_date('23-01-2007', 'dd-mm-yyyy'), 3, 5508, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140128001681, to_date('28-01-2014', 'dd-mm-yyyy'), to_date('11-02-2014', 'dd-mm-yyyy'), 1, 11266, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325001682, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 7, 5057, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130326003984, to_date('26-03-2013', 'dd-mm-yyyy'), to_date('09-04-2013', 'dd-mm-yyyy'), 7, 8348, to_date('30-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430003985, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 5, 5672, to_date('13-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027003986, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 4, 6285, to_date('16-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050305003987, to_date('05-03-2005', 'dd-mm-yyyy'), to_date('19-03-2005', 'dd-mm-yyyy'), 5, 5775, to_date('09-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100915003988, to_date('15-09-2010', 'dd-mm-yyyy'), to_date('29-09-2010', 'dd-mm-yyyy'), 8, 5331, to_date('04-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100301003989, to_date('01-03-2010', 'dd-mm-yyyy'), to_date('15-03-2010', 'dd-mm-yyyy'), 2, 6841, to_date('14-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040628003990, to_date('28-06-2004', 'dd-mm-yyyy'), to_date('12-07-2004', 'dd-mm-yyyy'), 6, 2209, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090715003991, to_date('15-07-2009', 'dd-mm-yyyy'), to_date('29-07-2009', 'dd-mm-yyyy'), 5, 4617, to_date('23-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110204003992, to_date('04-02-2011', 'dd-mm-yyyy'), to_date('18-02-2011', 'dd-mm-yyyy'), 2, 10658, to_date('09-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921003993, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 2, 3784, to_date('26-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119003994, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 8, 3042, to_date('29-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100906003995, to_date('06-09-2010', 'dd-mm-yyyy'), to_date('20-09-2010', 'dd-mm-yyyy'), 11, 9471, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210003996, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 5, 2614, to_date('28-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060804003997, to_date('04-08-2006', 'dd-mm-yyyy'), to_date('18-08-2006', 'dd-mm-yyyy'), 9, 5282, to_date('11-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031107003998, to_date('07-11-2003', 'dd-mm-yyyy'), to_date('21-11-2003', 'dd-mm-yyyy'), 3, 3624, to_date('08-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090313003999, to_date('13-03-2009', 'dd-mm-yyyy'), to_date('27-03-2009', 'dd-mm-yyyy'), 2, 5866, to_date('18-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101004000, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 11, 1458, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070214004001, to_date('14-02-2007', 'dd-mm-yyyy'), to_date('28-02-2007', 'dd-mm-yyyy'), 10, 5675, to_date('04-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121207004002, to_date('07-12-2012', 'dd-mm-yyyy'), to_date('21-12-2012', 'dd-mm-yyyy'), 9, 9049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521004003, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 5, 2068, to_date('27-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090727004004, to_date('27-07-2009', 'dd-mm-yyyy'), to_date('10-08-2009', 'dd-mm-yyyy'), 3, 5400, to_date('06-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121229004005, to_date('29-12-2012', 'dd-mm-yyyy'), to_date('12-01-2013', 'dd-mm-yyyy'), 3, 6861, to_date('18-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100810004006, to_date('10-08-2010', 'dd-mm-yyyy'), to_date('24-08-2010', 'dd-mm-yyyy'), 3, 9156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501004007, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 4, 992, to_date('03-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091106004008, to_date('06-11-2009', 'dd-mm-yyyy'), to_date('20-11-2009', 'dd-mm-yyyy'), 9, 6895, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090422004009, to_date('22-04-2009', 'dd-mm-yyyy'), to_date('06-05-2009', 'dd-mm-yyyy'), 2, 10276, to_date('10-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621004010, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 2, 2476, to_date('07-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717004011, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 7, 6640, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061114004012, to_date('14-11-2006', 'dd-mm-yyyy'), to_date('28-11-2006', 'dd-mm-yyyy'), 3, 3747, to_date('17-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000905004013, to_date('05-09-2000', 'dd-mm-yyyy'), to_date('19-09-2000', 'dd-mm-yyyy'), 5, 2272, to_date('18-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112004014, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 2, 6931, to_date('22-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090130004015, to_date('30-01-2009', 'dd-mm-yyyy'), to_date('13-02-2009', 'dd-mm-yyyy'), 6, 5958, to_date('16-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120627004016, to_date('27-06-2012', 'dd-mm-yyyy'), to_date('11-07-2012', 'dd-mm-yyyy'), 3, 7408, to_date('14-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130211004017, to_date('11-02-2013', 'dd-mm-yyyy'), to_date('25-02-2013', 'dd-mm-yyyy'), 3, 8822, to_date('22-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021031004018, to_date('31-10-2002', 'dd-mm-yyyy'), to_date('14-11-2002', 'dd-mm-yyyy'), 11, 3040, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110727004019, to_date('27-07-2011', 'dd-mm-yyyy'), to_date('10-08-2011', 'dd-mm-yyyy'), 8, 9101, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608004020, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 1, 8430, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120902004021, to_date('02-09-2012', 'dd-mm-yyyy'), to_date('16-09-2012', 'dd-mm-yyyy'), 8, 11447, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409004022, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 3, 6228, to_date('22-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120412004023, to_date('12-04-2012', 'dd-mm-yyyy'), to_date('26-04-2012', 'dd-mm-yyyy'), 2, 8267, to_date('25-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060426004024, to_date('26-04-2006', 'dd-mm-yyyy'), to_date('10-05-2006', 'dd-mm-yyyy'), 9, 3068, to_date('15-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813004025, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 3, 7074, to_date('30-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104004026, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 7, 6275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050808004027, to_date('08-08-2005', 'dd-mm-yyyy'), to_date('22-08-2005', 'dd-mm-yyyy'), 1, 6382, to_date('17-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706004028, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 11, 4112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070627004029, to_date('27-06-2007', 'dd-mm-yyyy'), to_date('11-07-2007', 'dd-mm-yyyy'), 3, 6171, to_date('14-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108004030, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 9, 5507, to_date('13-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110104004031, to_date('04-01-2011', 'dd-mm-yyyy'), to_date('18-01-2011', 'dd-mm-yyyy'), 4, 9554, to_date('23-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110817004032, to_date('17-08-2011', 'dd-mm-yyyy'), to_date('31-08-2011', 'dd-mm-yyyy'), 10, 8110, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061211004033, to_date('11-12-2006', 'dd-mm-yyyy'), to_date('25-12-2006', 'dd-mm-yyyy'), 5, 4480, to_date('16-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108004034, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 10, 6071, to_date('22-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090224004035, to_date('24-02-2009', 'dd-mm-yyyy'), to_date('10-03-2009', 'dd-mm-yyyy'), 12, 5919, to_date('15-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123004036, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 3, 6829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061224004037, to_date('24-12-2006', 'dd-mm-yyyy'), to_date('07-01-2007', 'dd-mm-yyyy'), 6, 5943, to_date('27-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509004038, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 9, 7219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090513004039, to_date('13-05-2009', 'dd-mm-yyyy'), to_date('27-05-2009', 'dd-mm-yyyy'), 2, 6809, to_date('22-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112004040, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 12, 6861, to_date('22-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070615004041, to_date('15-06-2007', 'dd-mm-yyyy'), to_date('29-06-2007', 'dd-mm-yyyy'), 11, 4548, to_date('19-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020211004042, to_date('11-02-2002', 'dd-mm-yyyy'), to_date('25-02-2002', 'dd-mm-yyyy'), 8, 3892, to_date('26-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411004043, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 9, 8791, to_date('20-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060331004044, to_date('31-03-2006', 'dd-mm-yyyy'), to_date('14-04-2006', 'dd-mm-yyyy'), 2, 4656, to_date('20-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090414004045, to_date('14-04-2009', 'dd-mm-yyyy'), to_date('28-04-2009', 'dd-mm-yyyy'), 9, 5910, to_date('29-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140109004046, to_date('09-01-2014', 'dd-mm-yyyy'), to_date('23-01-2014', 'dd-mm-yyyy'), 3, 8240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712004047, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 4, 3954, to_date('19-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000608004048, to_date('08-06-2000', 'dd-mm-yyyy'), to_date('22-06-2000', 'dd-mm-yyyy'), 7, 619, to_date('20-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000716004049, to_date('16-07-2000', 'dd-mm-yyyy'), to_date('30-07-2000', 'dd-mm-yyyy'), 8, 2366, to_date('24-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202004050, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 3, 7179, to_date('11-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211004051, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 6, 2368, to_date('26-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090926004052, to_date('26-09-2009', 'dd-mm-yyyy'), to_date('10-10-2009', 'dd-mm-yyyy'), 10, 7935, to_date('14-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000507004053, to_date('07-05-2000', 'dd-mm-yyyy'), to_date('21-05-2000', 'dd-mm-yyyy'), 10, 2845, to_date('24-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110506004054, to_date('06-05-2011', 'dd-mm-yyyy'), to_date('20-05-2011', 'dd-mm-yyyy'), 3, 6769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071013004055, to_date('13-10-2007', 'dd-mm-yyyy'), to_date('27-10-2007', 'dd-mm-yyyy'), 11, 5517, to_date('28-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080930004056, to_date('30-09-2008', 'dd-mm-yyyy'), to_date('14-10-2008', 'dd-mm-yyyy'), 8, 5800, to_date('10-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100903004057, to_date('03-09-2010', 'dd-mm-yyyy'), to_date('17-09-2010', 'dd-mm-yyyy'), 5, 4828, to_date('18-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040526004058, to_date('26-05-2004', 'dd-mm-yyyy'), to_date('09-06-2004', 'dd-mm-yyyy'), 12, 4963, to_date('10-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413004059, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 12, 10695, to_date('02-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090802004060, to_date('02-08-2009', 'dd-mm-yyyy'), to_date('16-08-2009', 'dd-mm-yyyy'), 10, 6317, to_date('08-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011216004061, to_date('16-12-2001', 'dd-mm-yyyy'), to_date('30-12-2001', 'dd-mm-yyyy'), 9, 2145, to_date('27-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912004062, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 11, 2718, to_date('20-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417004063, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 6, 4364, to_date('22-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020314004064, to_date('14-03-2002', 'dd-mm-yyyy'), to_date('28-03-2002', 'dd-mm-yyyy'), 3, 3945, to_date('22-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011104004065, to_date('04-11-2001', 'dd-mm-yyyy'), to_date('18-11-2001', 'dd-mm-yyyy'), 9, 3066, to_date('07-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050514004066, to_date('14-05-2005', 'dd-mm-yyyy'), to_date('28-05-2005', 'dd-mm-yyyy'), 11, 3286, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070618004067, to_date('18-06-2007', 'dd-mm-yyyy'), to_date('02-07-2007', 'dd-mm-yyyy'), 6, 4945, to_date('03-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203004068, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 5, 2922, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030701004069, to_date('01-07-2003', 'dd-mm-yyyy'), to_date('15-07-2003', 'dd-mm-yyyy'), 5, 2123, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010128004070, to_date('28-01-2001', 'dd-mm-yyyy'), to_date('11-02-2001', 'dd-mm-yyyy'), 6, 2956, to_date('06-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131230004071, to_date('30-12-2013', 'dd-mm-yyyy'), to_date('13-01-2014', 'dd-mm-yyyy'), 10, 8194, to_date('01-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725004072, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 9, 10999, to_date('01-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040720004073, to_date('20-07-2004', 'dd-mm-yyyy'), to_date('03-08-2004', 'dd-mm-yyyy'), 1, 5430, to_date('01-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122004074, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 8, 2878, to_date('09-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080520004075, to_date('20-05-2008', 'dd-mm-yyyy'), to_date('03-06-2008', 'dd-mm-yyyy'), 2, 5566, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329004076, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 5, 6286, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100725004077, to_date('25-07-2010', 'dd-mm-yyyy'), to_date('08-08-2010', 'dd-mm-yyyy'), 9, 6405, to_date('08-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411004078, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 4, 5293, to_date('25-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030908004079, to_date('08-09-2003', 'dd-mm-yyyy'), to_date('22-09-2003', 'dd-mm-yyyy'), 2, 2395, to_date('17-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100401004080, to_date('01-04-2010', 'dd-mm-yyyy'), to_date('15-04-2010', 'dd-mm-yyyy'), 4, 7792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080111004081, to_date('11-01-2008', 'dd-mm-yyyy'), to_date('25-01-2008', 'dd-mm-yyyy'), 1, 7000, to_date('13-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070108004082, to_date('08-01-2007', 'dd-mm-yyyy'), to_date('22-01-2007', 'dd-mm-yyyy'), 11, 5674, to_date('27-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140206004083, to_date('06-02-2014', 'dd-mm-yyyy'), to_date('20-02-2014', 'dd-mm-yyyy'), 11, 9158, to_date('21-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031022004084, to_date('22-10-2003', 'dd-mm-yyyy'), to_date('05-11-2003', 'dd-mm-yyyy'), 7, 2922, to_date('02-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903004085, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 3, 2111, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130426004086, to_date('26-04-2013', 'dd-mm-yyyy'), to_date('10-05-2013', 'dd-mm-yyyy'), 7, 8285, to_date('28-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110628004087, to_date('28-06-2011', 'dd-mm-yyyy'), to_date('12-07-2011', 'dd-mm-yyyy'), 9, 6395, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504004088, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 4, 9810, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915004089, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 10, 9313, to_date('16-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020818004090, to_date('18-08-2002', 'dd-mm-yyyy'), to_date('01-09-2002', 'dd-mm-yyyy'), 6, 2747, to_date('05-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202004091, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 4, 6075, to_date('13-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100516004092, to_date('16-05-2010', 'dd-mm-yyyy'), to_date('30-05-2010', 'dd-mm-yyyy'), 10, 6392, to_date('05-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421004093, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 3, 4119, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426004094, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 11, 3815, to_date('28-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060503004095, to_date('03-05-2006', 'dd-mm-yyyy'), to_date('17-05-2006', 'dd-mm-yyyy'), 6, 4523, to_date('07-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100902004096, to_date('02-09-2010', 'dd-mm-yyyy'), to_date('16-09-2010', 'dd-mm-yyyy'), 12, 6052, to_date('15-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100218004097, to_date('18-02-2010', 'dd-mm-yyyy'), to_date('04-03-2010', 'dd-mm-yyyy'), 5, 6444, to_date('22-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010616004098, to_date('16-06-2001', 'dd-mm-yyyy'), to_date('30-06-2001', 'dd-mm-yyyy'), 6, 3243, to_date('24-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820004099, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 10, 2662, to_date('08-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051128004100, to_date('28-11-2005', 'dd-mm-yyyy'), to_date('12-12-2005', 'dd-mm-yyyy'), 2, 5258, to_date('16-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120328004101, to_date('28-03-2012', 'dd-mm-yyyy'), to_date('11-04-2012', 'dd-mm-yyyy'), 10, 8535, to_date('11-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612004102, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 10, 2877, to_date('25-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031107004103, to_date('07-11-2003', 'dd-mm-yyyy'), to_date('21-11-2003', 'dd-mm-yyyy'), 12, 5892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020227004104, to_date('27-02-2002', 'dd-mm-yyyy'), to_date('13-03-2002', 'dd-mm-yyyy'), 1, 4042, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070126004105, to_date('26-01-2007', 'dd-mm-yyyy'), to_date('09-02-2007', 'dd-mm-yyyy'), 3, 6839, to_date('09-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130102004106, to_date('02-01-2013', 'dd-mm-yyyy'), to_date('16-01-2013', 'dd-mm-yyyy'), 2, 7303, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011002004107, to_date('02-10-2001', 'dd-mm-yyyy'), to_date('16-10-2001', 'dd-mm-yyyy'), 10, 1210, to_date('06-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001029004108, to_date('29-10-2000', 'dd-mm-yyyy'), to_date('12-11-2000', 'dd-mm-yyyy'), 3, 1869, to_date('07-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011008004109, to_date('08-10-2001', 'dd-mm-yyyy'), to_date('22-10-2001', 'dd-mm-yyyy'), 11, 2224, to_date('24-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010916004110, to_date('16-09-2001', 'dd-mm-yyyy'), to_date('30-09-2001', 'dd-mm-yyyy'), 6, 3128, to_date('20-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060702004111, to_date('02-07-2006', 'dd-mm-yyyy'), to_date('16-07-2006', 'dd-mm-yyyy'), 8, 8900, to_date('08-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408004112, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 10, 6924, to_date('21-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000605004113, to_date('05-06-2000', 'dd-mm-yyyy'), to_date('19-06-2000', 'dd-mm-yyyy'), 4, 223, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120718004114, to_date('18-07-2012', 'dd-mm-yyyy'), to_date('01-08-2012', 'dd-mm-yyyy'), 4, 5895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203004115, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 8, 4274, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130224004116, to_date('24-02-2013', 'dd-mm-yyyy'), to_date('10-03-2013', 'dd-mm-yyyy'), 11, 7472, to_date('10-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007004117, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 11, 3755, to_date('24-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070122004118, to_date('22-01-2007', 'dd-mm-yyyy'), to_date('05-02-2007', 'dd-mm-yyyy'), 10, 8315, to_date('07-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010326004119, to_date('26-03-2001', 'dd-mm-yyyy'), to_date('09-04-2001', 'dd-mm-yyyy'), 9, 2887, to_date('03-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406004120, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 3, 4934, to_date('17-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090807004121, to_date('07-08-2009', 'dd-mm-yyyy'), to_date('21-08-2009', 'dd-mm-yyyy'), 5, 6474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111212004122, to_date('12-12-2011', 'dd-mm-yyyy'), to_date('26-12-2011', 'dd-mm-yyyy'), 3, 6549, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080107004123, to_date('07-01-2008', 'dd-mm-yyyy'), to_date('21-01-2008', 'dd-mm-yyyy'), 2, 3857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010725004124, to_date('25-07-2001', 'dd-mm-yyyy'), to_date('08-08-2001', 'dd-mm-yyyy'), 3, 2573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131220004125, to_date('20-12-2013', 'dd-mm-yyyy'), to_date('03-01-2014', 'dd-mm-yyyy'), 11, 9551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070930004126, to_date('30-09-2007', 'dd-mm-yyyy'), to_date('14-10-2007', 'dd-mm-yyyy'), 7, 7232, to_date('01-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040227004127, to_date('27-02-2004', 'dd-mm-yyyy'), to_date('12-03-2004', 'dd-mm-yyyy'), 6, 5789, to_date('02-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302004128, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 2, 3380, to_date('16-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050812004129, to_date('12-08-2005', 'dd-mm-yyyy'), to_date('26-08-2005', 'dd-mm-yyyy'), 12, 3685, to_date('30-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040504004130, to_date('04-05-2004', 'dd-mm-yyyy'), to_date('18-05-2004', 'dd-mm-yyyy'), 7, 3440, to_date('16-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080809004131, to_date('09-08-2008', 'dd-mm-yyyy'), to_date('23-08-2008', 'dd-mm-yyyy'), 10, 5905, to_date('14-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010122004132, to_date('22-01-2001', 'dd-mm-yyyy'), to_date('05-02-2001', 'dd-mm-yyyy'), 10, 2577, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070624004133, to_date('24-06-2007', 'dd-mm-yyyy'), to_date('08-07-2007', 'dd-mm-yyyy'), 7, 3604, to_date('11-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040921004134, to_date('21-09-2004', 'dd-mm-yyyy'), to_date('05-10-2004', 'dd-mm-yyyy'), 8, 4153, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110430006274, to_date('30-04-2011', 'dd-mm-yyyy'), to_date('14-05-2011', 'dd-mm-yyyy'), 9, 6915, to_date('06-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090212006275, to_date('12-02-2009', 'dd-mm-yyyy'), to_date('26-02-2009', 'dd-mm-yyyy'), 6, 7453, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100115006276, to_date('15-01-2010', 'dd-mm-yyyy'), to_date('29-01-2010', 'dd-mm-yyyy'), 3, 5580, to_date('27-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090108006277, to_date('08-01-2009', 'dd-mm-yyyy'), to_date('22-01-2009', 'dd-mm-yyyy'), 11, 7275, to_date('14-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022006278, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 11, 4615, to_date('25-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140401006279, to_date('01-04-2014', 'dd-mm-yyyy'), to_date('15-04-2014', 'dd-mm-yyyy'), 3, 12154, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010403006280, to_date('03-04-2001', 'dd-mm-yyyy'), to_date('17-04-2001', 'dd-mm-yyyy'), 11, 1652, to_date('17-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070515006281, to_date('15-05-2007', 'dd-mm-yyyy'), to_date('29-05-2007', 'dd-mm-yyyy'), 8, 5743, to_date('23-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091120006282, to_date('20-11-2009', 'dd-mm-yyyy'), to_date('04-12-2009', 'dd-mm-yyyy'), 4, 5433, to_date('08-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131103006283, to_date('03-11-2013', 'dd-mm-yyyy'), to_date('17-11-2013', 'dd-mm-yyyy'), 6, 9811, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825006284, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 6, 7828, to_date('28-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011212006285, to_date('12-12-2001', 'dd-mm-yyyy'), to_date('26-12-2001', 'dd-mm-yyyy'), 9, 2108, to_date('27-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050216006286, to_date('16-02-2005', 'dd-mm-yyyy'), to_date('02-03-2005', 'dd-mm-yyyy'), 3, 3439, to_date('21-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002006287, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 10, 2973, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010829006288, to_date('29-08-2001', 'dd-mm-yyyy'), to_date('12-09-2001', 'dd-mm-yyyy'), 5, 2661, to_date('02-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110630006289, to_date('30-06-2011', 'dd-mm-yyyy'), to_date('14-07-2011', 'dd-mm-yyyy'), 9, 9552, to_date('06-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809006290, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 6, 3624, to_date('22-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001213006291, to_date('13-12-2000', 'dd-mm-yyyy'), to_date('27-12-2000', 'dd-mm-yyyy'), 5, 2910, to_date('16-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010715006292, to_date('15-07-2001', 'dd-mm-yyyy'), to_date('29-07-2001', 'dd-mm-yyyy'), 7, 2618, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107006293, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 9, 5612, to_date('24-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020602006294, to_date('02-06-2002', 'dd-mm-yyyy'), to_date('16-06-2002', 'dd-mm-yyyy'), 12, 2538, to_date('19-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227006295, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 6, 8309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101027006296, to_date('27-10-2010', 'dd-mm-yyyy'), to_date('10-11-2010', 'dd-mm-yyyy'), 6, 8503, to_date('13-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031118006297, to_date('18-11-2003', 'dd-mm-yyyy'), to_date('02-12-2003', 'dd-mm-yyyy'), 12, 3527, to_date('01-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109006298, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 11, 7438, to_date('27-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131128006299, to_date('28-11-2013', 'dd-mm-yyyy'), to_date('12-12-2013', 'dd-mm-yyyy'), 12, 9318, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001114006300, to_date('14-11-2000', 'dd-mm-yyyy'), to_date('28-11-2000', 'dd-mm-yyyy'), 4, 1636, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329006301, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 6, 1901, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010228006302, to_date('28-02-2001', 'dd-mm-yyyy'), to_date('14-03-2001', 'dd-mm-yyyy'), 1, 3414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061117006303, to_date('17-11-2006', 'dd-mm-yyyy'), to_date('01-12-2006', 'dd-mm-yyyy'), 3, 6002, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120124006304, to_date('24-01-2012', 'dd-mm-yyyy'), to_date('07-02-2012', 'dd-mm-yyyy'), 7, 8353, to_date('26-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617006305, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 6, 3297, to_date('01-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070502006306, to_date('02-05-2007', 'dd-mm-yyyy'), to_date('16-05-2007', 'dd-mm-yyyy'), 12, 7758, to_date('20-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120407006307, to_date('07-04-2012', 'dd-mm-yyyy'), to_date('21-04-2012', 'dd-mm-yyyy'), 3, 7667, to_date('13-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822006308, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 3, 9622, to_date('29-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111008006309, to_date('08-10-2011', 'dd-mm-yyyy'), to_date('22-10-2011', 'dd-mm-yyyy'), 4, 6609, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140503006310, to_date('03-05-2014', 'dd-mm-yyyy'), to_date('17-05-2014', 'dd-mm-yyyy'), 11, 11755, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130403006311, to_date('03-04-2013', 'dd-mm-yyyy'), to_date('17-04-2013', 'dd-mm-yyyy'), 4, 7003, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040307006312, to_date('07-03-2004', 'dd-mm-yyyy'), to_date('21-03-2004', 'dd-mm-yyyy'), 3, 3748, to_date('12-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061222006313, to_date('22-12-2006', 'dd-mm-yyyy'), to_date('05-01-2007', 'dd-mm-yyyy'), 1, 6341, to_date('10-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031029006314, to_date('29-10-2003', 'dd-mm-yyyy'), to_date('12-11-2003', 'dd-mm-yyyy'), 1, 4839, to_date('17-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000203006315, to_date('03-02-2000', 'dd-mm-yyyy'), to_date('17-02-2000', 'dd-mm-yyyy'), 10, 633, to_date('22-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080222006316, to_date('22-02-2008', 'dd-mm-yyyy'), to_date('07-03-2008', 'dd-mm-yyyy'), 4, 5993, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060904006317, to_date('04-09-2006', 'dd-mm-yyyy'), to_date('18-09-2006', 'dd-mm-yyyy'), 2, 6454, to_date('17-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040808006318, to_date('08-08-2004', 'dd-mm-yyyy'), to_date('22-08-2004', 'dd-mm-yyyy'), 10, 3411, to_date('10-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100105006319, to_date('05-01-2010', 'dd-mm-yyyy'), to_date('19-01-2010', 'dd-mm-yyyy'), 7, 9029, to_date('19-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210006320, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 11, 3738, to_date('11-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413006321, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 7, 9479, to_date('21-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308006322, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 12, 1558, to_date('18-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001127006323, to_date('27-11-2000', 'dd-mm-yyyy'), to_date('11-12-2000', 'dd-mm-yyyy'), 2, 1026, to_date('11-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725006324, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 4, 11769, to_date('27-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111004006325, to_date('04-10-2011', 'dd-mm-yyyy'), to_date('18-10-2011', 'dd-mm-yyyy'), 3, 8291, to_date('15-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100118006326, to_date('18-01-2010', 'dd-mm-yyyy'), to_date('01-02-2010', 'dd-mm-yyyy'), 5, 9950, to_date('27-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821006327, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 7, 5612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040128006328, to_date('28-01-2004', 'dd-mm-yyyy'), to_date('11-02-2004', 'dd-mm-yyyy'), 7, 3459, to_date('15-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020715006329, to_date('15-07-2002', 'dd-mm-yyyy'), to_date('29-07-2002', 'dd-mm-yyyy'), 3, 3692, to_date('22-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130310006330, to_date('10-03-2013', 'dd-mm-yyyy'), to_date('24-03-2013', 'dd-mm-yyyy'), 6, 9071, to_date('13-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010406006331, to_date('06-04-2001', 'dd-mm-yyyy'), to_date('20-04-2001', 'dd-mm-yyyy'), 2, 3038, to_date('25-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000131006332, to_date('31-01-2000', 'dd-mm-yyyy'), to_date('14-02-2000', 'dd-mm-yyyy'), 10, 2264, to_date('03-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710006333, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 11, 5778, to_date('13-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702006334, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 9, 117, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120501006335, to_date('01-05-2012', 'dd-mm-yyyy'), to_date('15-05-2012', 'dd-mm-yyyy'), 6, 7425, to_date('21-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000408006336, to_date('08-04-2000', 'dd-mm-yyyy'), to_date('22-04-2000', 'dd-mm-yyyy'), 11, 974, to_date('11-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011226006337, to_date('26-12-2001', 'dd-mm-yyyy'), to_date('09-01-2002', 'dd-mm-yyyy'), 9, 2646, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051015006338, to_date('15-10-2005', 'dd-mm-yyyy'), to_date('29-10-2005', 'dd-mm-yyyy'), 3, 3339, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000407006339, to_date('07-04-2000', 'dd-mm-yyyy'), to_date('21-04-2000', 'dd-mm-yyyy'), 9, 667, to_date('15-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010210006340, to_date('10-02-2001', 'dd-mm-yyyy'), to_date('24-02-2001', 'dd-mm-yyyy'), 8, 2982, to_date('21-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000604006341, to_date('04-06-2000', 'dd-mm-yyyy'), to_date('18-06-2000', 'dd-mm-yyyy'), 11, 1739, to_date('20-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011123006342, to_date('23-11-2001', 'dd-mm-yyyy'), to_date('07-12-2001', 'dd-mm-yyyy'), 4, 1610, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000615006343, to_date('15-06-2000', 'dd-mm-yyyy'), to_date('29-06-2000', 'dd-mm-yyyy'), 6, 1018, to_date('23-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050617006344, to_date('17-06-2005', 'dd-mm-yyyy'), to_date('01-07-2005', 'dd-mm-yyyy'), 5, 5240, to_date('05-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203006345, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 2, 9596, to_date('10-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010213006346, to_date('13-02-2001', 'dd-mm-yyyy'), to_date('27-02-2001', 'dd-mm-yyyy'), 5, 2260, to_date('15-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130420006347, to_date('20-04-2013', 'dd-mm-yyyy'), to_date('04-05-2013', 'dd-mm-yyyy'), 9, 10923, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002006348, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 3, 5133, to_date('13-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071122006349, to_date('22-11-2007', 'dd-mm-yyyy'), to_date('06-12-2007', 'dd-mm-yyyy'), 1, 4640, to_date('05-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120726006350, to_date('26-07-2012', 'dd-mm-yyyy'), to_date('09-08-2012', 'dd-mm-yyyy'), 10, 7649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060922006351, to_date('22-09-2006', 'dd-mm-yyyy'), to_date('06-10-2006', 'dd-mm-yyyy'), 8, 4834, to_date('30-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140110006352, to_date('10-01-2014', 'dd-mm-yyyy'), to_date('24-01-2014', 'dd-mm-yyyy'), 7, 8766, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020220006353, to_date('20-02-2002', 'dd-mm-yyyy'), to_date('06-03-2002', 'dd-mm-yyyy'), 4, 1449, to_date('08-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081218006354, to_date('18-12-2008', 'dd-mm-yyyy'), to_date('01-01-2009', 'dd-mm-yyyy'), 2, 5167, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000622006355, to_date('22-06-2000', 'dd-mm-yyyy'), to_date('06-07-2000', 'dd-mm-yyyy'), 2, 1223, to_date('29-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080917006356, to_date('17-09-2008', 'dd-mm-yyyy'), to_date('01-10-2008', 'dd-mm-yyyy'), 10, 7814, to_date('21-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070424006357, to_date('24-04-2007', 'dd-mm-yyyy'), to_date('08-05-2007', 'dd-mm-yyyy'), 4, 4283, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020530006358, to_date('30-05-2002', 'dd-mm-yyyy'), to_date('13-06-2002', 'dd-mm-yyyy'), 7, 1653, to_date('01-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030410006359, to_date('10-04-2003', 'dd-mm-yyyy'), to_date('24-04-2003', 'dd-mm-yyyy'), 1, 4105, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050421006360, to_date('21-04-2005', 'dd-mm-yyyy'), to_date('05-05-2005', 'dd-mm-yyyy'), 4, 5207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091227006361, to_date('27-12-2009', 'dd-mm-yyyy'), to_date('10-01-2010', 'dd-mm-yyyy'), 2, 10546, to_date('12-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050228006362, to_date('28-02-2005', 'dd-mm-yyyy'), to_date('14-03-2005', 'dd-mm-yyyy'), 6, 5725, to_date('13-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070516006363, to_date('16-05-2007', 'dd-mm-yyyy'), to_date('30-05-2007', 'dd-mm-yyyy'), 9, 6261, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050329006364, to_date('29-03-2005', 'dd-mm-yyyy'), to_date('12-04-2005', 'dd-mm-yyyy'), 1, 6370, to_date('03-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825006365, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 8, 7168, to_date('14-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100317006366, to_date('17-03-2010', 'dd-mm-yyyy'), to_date('31-03-2010', 'dd-mm-yyyy'), 9, 6752, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010707006367, to_date('07-07-2001', 'dd-mm-yyyy'), to_date('21-07-2001', 'dd-mm-yyyy'), 4, 2567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011007006368, to_date('07-10-2001', 'dd-mm-yyyy'), to_date('21-10-2001', 'dd-mm-yyyy'), 11, 2906, to_date('16-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131225006369, to_date('25-12-2013', 'dd-mm-yyyy'), to_date('08-01-2014', 'dd-mm-yyyy'), 10, 7327, to_date('30-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070626006370, to_date('26-06-2007', 'dd-mm-yyyy'), to_date('10-07-2007', 'dd-mm-yyyy'), 2, 5245, to_date('15-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319006371, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 5, 6256, to_date('25-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070308006372, to_date('08-03-2007', 'dd-mm-yyyy'), to_date('22-03-2007', 'dd-mm-yyyy'), 5, 5174, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120818006373, to_date('18-08-2012', 'dd-mm-yyyy'), to_date('01-09-2012', 'dd-mm-yyyy'), 9, 7218, to_date('30-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630006374, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 5, 11042, to_date('13-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080409006375, to_date('09-04-2008', 'dd-mm-yyyy'), to_date('23-04-2008', 'dd-mm-yyyy'), 6, 7549, to_date('17-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140315006376, to_date('15-03-2014', 'dd-mm-yyyy'), to_date('29-03-2014', 'dd-mm-yyyy'), 10, 8782, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090721006377, to_date('21-07-2009', 'dd-mm-yyyy'), to_date('04-08-2009', 'dd-mm-yyyy'), 3, 4913, to_date('06-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040323006378, to_date('23-03-2004', 'dd-mm-yyyy'), to_date('06-04-2004', 'dd-mm-yyyy'), 6, 3942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050813006379, to_date('13-08-2005', 'dd-mm-yyyy'), to_date('27-08-2005', 'dd-mm-yyyy'), 9, 4501, to_date('31-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100504006380, to_date('04-05-2010', 'dd-mm-yyyy'), to_date('18-05-2010', 'dd-mm-yyyy'), 4, 9755, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607006381, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 7, 6094, to_date('24-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108006382, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 3, 3252, to_date('25-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110625006383, to_date('25-06-2011', 'dd-mm-yyyy'), to_date('09-07-2011', 'dd-mm-yyyy'), 10, 6545, to_date('28-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000302006384, to_date('02-03-2000', 'dd-mm-yyyy'), to_date('16-03-2000', 'dd-mm-yyyy'), 7, 2135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227006385, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 10, 3550, to_date('29-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040403006386, to_date('03-04-2004', 'dd-mm-yyyy'), to_date('17-04-2004', 'dd-mm-yyyy'), 2, 1923, to_date('18-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120624006387, to_date('24-06-2012', 'dd-mm-yyyy'), to_date('08-07-2012', 'dd-mm-yyyy'), 7, 6215, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080529006388, to_date('29-05-2008', 'dd-mm-yyyy'), to_date('12-06-2008', 'dd-mm-yyyy'), 10, 6120, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000522006389, to_date('22-05-2000', 'dd-mm-yyyy'), to_date('05-06-2000', 'dd-mm-yyyy'), 6, 1436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070804006390, to_date('04-08-2007', 'dd-mm-yyyy'), to_date('18-08-2007', 'dd-mm-yyyy'), 11, 5681, to_date('12-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081017006391, to_date('17-10-2008', 'dd-mm-yyyy'), to_date('31-10-2008', 'dd-mm-yyyy'), 9, 7706, to_date('24-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030708006392, to_date('08-07-2003', 'dd-mm-yyyy'), to_date('22-07-2003', 'dd-mm-yyyy'), 10, 2120, to_date('22-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070523006393, to_date('23-05-2007', 'dd-mm-yyyy'), to_date('06-06-2007', 'dd-mm-yyyy'), 8, 4180, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728006394, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 9, 7578, to_date('09-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409006395, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 7, 6113, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002006396, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 5, 2384, to_date('18-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615006397, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 4, 9044, to_date('29-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041105006398, to_date('05-11-2004', 'dd-mm-yyyy'), to_date('19-11-2004', 'dd-mm-yyyy'), 4, 3432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070724006399, to_date('24-07-2007', 'dd-mm-yyyy'), to_date('07-08-2007', 'dd-mm-yyyy'), 8, 7160, to_date('27-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021115006400, to_date('15-11-2002', 'dd-mm-yyyy'), to_date('29-11-2002', 'dd-mm-yyyy'), 10, 3495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020403006401, to_date('03-04-2002', 'dd-mm-yyyy'), to_date('17-04-2002', 'dd-mm-yyyy'), 9, 1244, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110415006402, to_date('15-04-2011', 'dd-mm-yyyy'), to_date('29-04-2011', 'dd-mm-yyyy'), 7, 8160, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060117006403, to_date('17-01-2006', 'dd-mm-yyyy'), to_date('31-01-2006', 'dd-mm-yyyy'), 4, 5632, to_date('25-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050612006404, to_date('12-06-2005', 'dd-mm-yyyy'), to_date('26-06-2005', 'dd-mm-yyyy'), 10, 5143, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070213006405, to_date('13-02-2007', 'dd-mm-yyyy'), to_date('27-02-2007', 'dd-mm-yyyy'), 5, 6551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116006406, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 10, 6559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090213006407, to_date('13-02-2009', 'dd-mm-yyyy'), to_date('27-02-2009', 'dd-mm-yyyy'), 3, 4999, to_date('05-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603006408, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 6, 10010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080412006409, to_date('12-04-2008', 'dd-mm-yyyy'), to_date('26-04-2008', 'dd-mm-yyyy'), 10, 6499, to_date('23-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091027006410, to_date('27-10-2009', 'dd-mm-yyyy'), to_date('10-11-2009', 'dd-mm-yyyy'), 7, 7053, to_date('03-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121105006411, to_date('05-11-2012', 'dd-mm-yyyy'), to_date('19-11-2012', 'dd-mm-yyyy'), 10, 7061, to_date('13-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100101006412, to_date('01-01-2010', 'dd-mm-yyyy'), to_date('15-01-2010', 'dd-mm-yyyy'), 9, 8005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041216006413, to_date('16-12-2004', 'dd-mm-yyyy'), to_date('30-12-2004', 'dd-mm-yyyy'), 9, 2906, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110924006414, to_date('24-09-2011', 'dd-mm-yyyy'), to_date('08-10-2011', 'dd-mm-yyyy'), 8, 5464, to_date('07-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030820006415, to_date('20-08-2003', 'dd-mm-yyyy'), to_date('03-09-2003', 'dd-mm-yyyy'), 3, 5648, to_date('22-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070808006416, to_date('08-08-2007', 'dd-mm-yyyy'), to_date('22-08-2007', 'dd-mm-yyyy'), 12, 6464, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000704006417, to_date('04-07-2000', 'dd-mm-yyyy'), to_date('18-07-2000', 'dd-mm-yyyy'), 5, 332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030617006418, to_date('17-06-2003', 'dd-mm-yyyy'), to_date('01-07-2003', 'dd-mm-yyyy'), 7, 2697, to_date('26-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010526006419, to_date('26-05-2001', 'dd-mm-yyyy'), to_date('09-06-2001', 'dd-mm-yyyy'), 6, 1380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050210006420, to_date('10-02-2005', 'dd-mm-yyyy'), to_date('24-02-2005', 'dd-mm-yyyy'), 10, 5737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027006421, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 10, 3610, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011229006422, to_date('29-12-2001', 'dd-mm-yyyy'), to_date('12-01-2002', 'dd-mm-yyyy'), 5, 2443, to_date('05-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101113006423, to_date('13-11-2010', 'dd-mm-yyyy'), to_date('27-11-2010', 'dd-mm-yyyy'), 6, 5401, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050324006424, to_date('24-03-2005', 'dd-mm-yyyy'), to_date('07-04-2005', 'dd-mm-yyyy'), 10, 4805, to_date('09-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120527006425, to_date('27-05-2012', 'dd-mm-yyyy'), to_date('10-06-2012', 'dd-mm-yyyy'), 2, 7148, to_date('03-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101121006426, to_date('21-11-2010', 'dd-mm-yyyy'), to_date('05-12-2010', 'dd-mm-yyyy'), 2, 6433, to_date('30-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010720006427, to_date('20-07-2001', 'dd-mm-yyyy'), to_date('03-08-2001', 'dd-mm-yyyy'), 6, 3334, to_date('21-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131008872, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 2, 4126, to_date('06-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040515008873, to_date('15-05-2004', 'dd-mm-yyyy'), to_date('29-05-2004', 'dd-mm-yyyy'), 4, 3770, to_date('23-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002008874, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 6, 2894, to_date('15-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113008875, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 12, 8390, to_date('01-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090218008876, to_date('18-02-2009', 'dd-mm-yyyy'), to_date('04-03-2009', 'dd-mm-yyyy'), 7, 3823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424008877, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 3, 7519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030305008878, to_date('05-03-2003', 'dd-mm-yyyy'), to_date('19-03-2003', 'dd-mm-yyyy'), 2, 4563, to_date('06-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901008879, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 5, 2123, to_date('03-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041020008880, to_date('20-10-2004', 'dd-mm-yyyy'), to_date('03-11-2004', 'dd-mm-yyyy'), 7, 3992, to_date('08-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040416008881, to_date('16-04-2004', 'dd-mm-yyyy'), to_date('30-04-2004', 'dd-mm-yyyy'), 11, 3156, to_date('20-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111011008882, to_date('11-10-2011', 'dd-mm-yyyy'), to_date('25-10-2011', 'dd-mm-yyyy'), 5, 7092, to_date('30-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100616008883, to_date('16-06-2010', 'dd-mm-yyyy'), to_date('30-06-2010', 'dd-mm-yyyy'), 8, 7732, to_date('27-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030831008884, to_date('31-08-2003', 'dd-mm-yyyy'), to_date('14-09-2003', 'dd-mm-yyyy'), 3, 5455, to_date('04-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031229008885, to_date('29-12-2003', 'dd-mm-yyyy'), to_date('12-01-2004', 'dd-mm-yyyy'), 7, 1500, to_date('16-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080522008886, to_date('22-05-2008', 'dd-mm-yyyy'), to_date('05-06-2008', 'dd-mm-yyyy'), 12, 4495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214008887, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 5, 3716, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010124008888, to_date('24-01-2001', 'dd-mm-yyyy'), to_date('07-02-2001', 'dd-mm-yyyy'), 12, 1406, to_date('27-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080416008889, to_date('16-04-2008', 'dd-mm-yyyy'), to_date('30-04-2008', 'dd-mm-yyyy'), 8, 6637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100826008890, to_date('26-08-2010', 'dd-mm-yyyy'), to_date('09-09-2010', 'dd-mm-yyyy'), 9, 10359, to_date('10-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009008891, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 7, 7691, null);
commit;
prompt 4000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000108008892, to_date('08-01-2000', 'dd-mm-yyyy'), to_date('22-01-2000', 'dd-mm-yyyy'), 3, 1917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209008893, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 1, 11750, to_date('12-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060831008894, to_date('31-08-2006', 'dd-mm-yyyy'), to_date('14-09-2006', 'dd-mm-yyyy'), 2, 4233, to_date('12-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020511008895, to_date('11-05-2002', 'dd-mm-yyyy'), to_date('25-05-2002', 'dd-mm-yyyy'), 4, 3821, to_date('15-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713008896, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 12, 2373, to_date('23-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120720008897, to_date('20-07-2012', 'dd-mm-yyyy'), to_date('03-08-2012', 'dd-mm-yyyy'), 2, 8614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130118008898, to_date('18-01-2013', 'dd-mm-yyyy'), to_date('01-02-2013', 'dd-mm-yyyy'), 1, 7221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009008899, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 5, 4954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813008900, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 8, 6619, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030812008901, to_date('12-08-2003', 'dd-mm-yyyy'), to_date('26-08-2003', 'dd-mm-yyyy'), 9, 2867, to_date('24-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000331008902, to_date('31-03-2000', 'dd-mm-yyyy'), to_date('14-04-2000', 'dd-mm-yyyy'), 3, 1832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001008903, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 1, 2505, to_date('13-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090205008904, to_date('05-02-2009', 'dd-mm-yyyy'), to_date('19-02-2009', 'dd-mm-yyyy'), 10, 6086, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000922008905, to_date('22-09-2000', 'dd-mm-yyyy'), to_date('06-10-2000', 'dd-mm-yyyy'), 10, 2240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413008906, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 7, 10666, to_date('20-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090509008907, to_date('09-05-2009', 'dd-mm-yyyy'), to_date('23-05-2009', 'dd-mm-yyyy'), 2, 8006, to_date('17-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000519008908, to_date('19-05-2000', 'dd-mm-yyyy'), to_date('02-06-2000', 'dd-mm-yyyy'), 1, 3072, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070530008909, to_date('30-05-2007', 'dd-mm-yyyy'), to_date('13-06-2007', 'dd-mm-yyyy'), 8, 5929, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080610008910, to_date('10-06-2008', 'dd-mm-yyyy'), to_date('24-06-2008', 'dd-mm-yyyy'), 6, 6255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050115008911, to_date('15-01-2005', 'dd-mm-yyyy'), to_date('29-01-2005', 'dd-mm-yyyy'), 3, 3644, to_date('18-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010114008912, to_date('14-01-2001', 'dd-mm-yyyy'), to_date('28-01-2001', 'dd-mm-yyyy'), 8, 1416, to_date('23-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040919008913, to_date('19-09-2004', 'dd-mm-yyyy'), to_date('03-10-2004', 'dd-mm-yyyy'), 3, 3720, to_date('07-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926008914, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 9, 6693, to_date('28-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110624008915, to_date('24-06-2011', 'dd-mm-yyyy'), to_date('08-07-2011', 'dd-mm-yyyy'), 8, 8375, to_date('12-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090103008916, to_date('03-01-2009', 'dd-mm-yyyy'), to_date('17-01-2009', 'dd-mm-yyyy'), 11, 5035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080216008917, to_date('16-02-2008', 'dd-mm-yyyy'), to_date('01-03-2008', 'dd-mm-yyyy'), 2, 7423, to_date('02-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120101008918, to_date('01-01-2012', 'dd-mm-yyyy'), to_date('15-01-2012', 'dd-mm-yyyy'), 6, 7147, to_date('16-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041231008919, to_date('31-12-2004', 'dd-mm-yyyy'), to_date('14-01-2005', 'dd-mm-yyyy'), 8, 3122, to_date('04-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070831008920, to_date('31-08-2007', 'dd-mm-yyyy'), to_date('14-09-2007', 'dd-mm-yyyy'), 11, 5075, to_date('06-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060921008921, to_date('21-09-2006', 'dd-mm-yyyy'), to_date('05-10-2006', 'dd-mm-yyyy'), 8, 6167, to_date('03-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050321008922, to_date('21-03-2005', 'dd-mm-yyyy'), to_date('04-04-2005', 'dd-mm-yyyy'), 10, 4041, to_date('24-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091119008923, to_date('19-11-2009', 'dd-mm-yyyy'), to_date('03-12-2009', 'dd-mm-yyyy'), 9, 7907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111030008924, to_date('30-10-2011', 'dd-mm-yyyy'), to_date('13-11-2011', 'dd-mm-yyyy'), 5, 6215, to_date('06-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131024008925, to_date('24-10-2013', 'dd-mm-yyyy'), to_date('07-11-2013', 'dd-mm-yyyy'), 4, 11279, to_date('30-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317008926, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 5, 2025, to_date('29-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071109008927, to_date('09-11-2007', 'dd-mm-yyyy'), to_date('23-11-2007', 'dd-mm-yyyy'), 11, 4452, to_date('12-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530008928, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 2, 590, to_date('19-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011016008929, to_date('16-10-2001', 'dd-mm-yyyy'), to_date('30-10-2001', 'dd-mm-yyyy'), 8, 3098, to_date('26-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020513008930, to_date('13-05-2002', 'dd-mm-yyyy'), to_date('27-05-2002', 'dd-mm-yyyy'), 6, 2878, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519008931, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 5, 9063, to_date('07-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220008932, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 3, 5798, to_date('23-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121023008933, to_date('23-10-2012', 'dd-mm-yyyy'), to_date('06-11-2012', 'dd-mm-yyyy'), 3, 7815, to_date('28-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121225008934, to_date('25-12-2012', 'dd-mm-yyyy'), to_date('08-01-2013', 'dd-mm-yyyy'), 8, 7691, to_date('09-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601008935, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 10, 4965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090506008936, to_date('06-05-2009', 'dd-mm-yyyy'), to_date('20-05-2009', 'dd-mm-yyyy'), 6, 7879, to_date('14-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120503008937, to_date('03-05-2012', 'dd-mm-yyyy'), to_date('17-05-2012', 'dd-mm-yyyy'), 11, 8951, to_date('12-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418008938, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 4, 10221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105008939, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 12, 7026, to_date('11-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111220008940, to_date('20-12-2011', 'dd-mm-yyyy'), to_date('03-01-2012', 'dd-mm-yyyy'), 4, 6698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618008941, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 10, 9420, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126008942, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 10, 4927, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031115008943, to_date('15-11-2003', 'dd-mm-yyyy'), to_date('29-11-2003', 'dd-mm-yyyy'), 11, 3074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120917008944, to_date('17-09-2012', 'dd-mm-yyyy'), to_date('01-10-2012', 'dd-mm-yyyy'), 2, 4185, to_date('29-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020910008945, to_date('10-09-2002', 'dd-mm-yyyy'), to_date('24-09-2002', 'dd-mm-yyyy'), 4, 3438, to_date('28-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081028008946, to_date('28-10-2008', 'dd-mm-yyyy'), to_date('11-11-2008', 'dd-mm-yyyy'), 4, 6261, to_date('06-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930008947, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 9, 746, to_date('07-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130327008948, to_date('27-03-2013', 'dd-mm-yyyy'), to_date('10-04-2013', 'dd-mm-yyyy'), 2, 8934, to_date('15-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061220008949, to_date('20-12-2006', 'dd-mm-yyyy'), to_date('03-01-2007', 'dd-mm-yyyy'), 7, 4722, to_date('05-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405008950, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 6, 7460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091224008951, to_date('24-12-2009', 'dd-mm-yyyy'), to_date('07-01-2010', 'dd-mm-yyyy'), 10, 5770, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630008952, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 7, 3331, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020425008953, to_date('25-04-2002', 'dd-mm-yyyy'), to_date('09-05-2002', 'dd-mm-yyyy'), 7, 2969, to_date('11-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050929008954, to_date('29-09-2005', 'dd-mm-yyyy'), to_date('13-10-2005', 'dd-mm-yyyy'), 6, 3216, to_date('03-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110913008955, to_date('13-09-2011', 'dd-mm-yyyy'), to_date('27-09-2011', 'dd-mm-yyyy'), 3, 7625, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070622008956, to_date('22-06-2007', 'dd-mm-yyyy'), to_date('06-07-2007', 'dd-mm-yyyy'), 1, 5721, to_date('05-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001215008957, to_date('15-12-2000', 'dd-mm-yyyy'), to_date('29-12-2000', 'dd-mm-yyyy'), 7, 2524, to_date('25-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020620008958, to_date('20-06-2002', 'dd-mm-yyyy'), to_date('04-07-2002', 'dd-mm-yyyy'), 4, 3600, to_date('27-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100406008959, to_date('06-04-2010', 'dd-mm-yyyy'), to_date('20-04-2010', 'dd-mm-yyyy'), 1, 6867, to_date('18-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060312008960, to_date('12-03-2006', 'dd-mm-yyyy'), to_date('26-03-2006', 'dd-mm-yyyy'), 10, 4616, to_date('15-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825008961, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 5, 826, to_date('12-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030610008962, to_date('10-06-2003', 'dd-mm-yyyy'), to_date('24-06-2003', 'dd-mm-yyyy'), 5, 2781, to_date('13-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522008963, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 8, 4666, to_date('29-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060822008964, to_date('22-08-2006', 'dd-mm-yyyy'), to_date('05-09-2006', 'dd-mm-yyyy'), 6, 3490, to_date('23-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040126008965, to_date('26-01-2004', 'dd-mm-yyyy'), to_date('09-02-2004', 'dd-mm-yyyy'), 6, 1851, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070205008966, to_date('05-02-2007', 'dd-mm-yyyy'), to_date('19-02-2007', 'dd-mm-yyyy'), 8, 4748, to_date('06-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050307008967, to_date('07-03-2005', 'dd-mm-yyyy'), to_date('21-03-2005', 'dd-mm-yyyy'), 3, 6004, to_date('10-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120506008968, to_date('06-05-2012', 'dd-mm-yyyy'), to_date('20-05-2012', 'dd-mm-yyyy'), 5, 5982, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329008969, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 3, 7599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071110008970, to_date('10-11-2007', 'dd-mm-yyyy'), to_date('24-11-2007', 'dd-mm-yyyy'), 3, 7452, to_date('22-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130721008971, to_date('21-07-2013', 'dd-mm-yyyy'), to_date('04-08-2013', 'dd-mm-yyyy'), 3, 10769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061110008972, to_date('10-11-2006', 'dd-mm-yyyy'), to_date('24-11-2006', 'dd-mm-yyyy'), 9, 8300, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208008973, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 2, 4333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010115008974, to_date('15-01-2001', 'dd-mm-yyyy'), to_date('29-01-2001', 'dd-mm-yyyy'), 9, 957, to_date('22-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080409008975, to_date('09-04-2008', 'dd-mm-yyyy'), to_date('23-04-2008', 'dd-mm-yyyy'), 9, 4177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020320008976, to_date('20-03-2002', 'dd-mm-yyyy'), to_date('03-04-2002', 'dd-mm-yyyy'), 4, 2794, to_date('09-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130103008977, to_date('03-01-2013', 'dd-mm-yyyy'), to_date('17-01-2013', 'dd-mm-yyyy'), 7, 9122, to_date('17-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428008978, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 5, 2545, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020708008979, to_date('08-07-2002', 'dd-mm-yyyy'), to_date('22-07-2002', 'dd-mm-yyyy'), 4, 1950, to_date('11-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206008980, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 4, 7201, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060618008981, to_date('18-06-2006', 'dd-mm-yyyy'), to_date('02-07-2006', 'dd-mm-yyyy'), 10, 4134, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040508008982, to_date('08-05-2004', 'dd-mm-yyyy'), to_date('22-05-2004', 'dd-mm-yyyy'), 3, 3060, to_date('25-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801008983, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 11, 2355, to_date('09-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101121008984, to_date('21-11-2010', 'dd-mm-yyyy'), to_date('05-12-2010', 'dd-mm-yyyy'), 1, 4799, to_date('26-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060324008985, to_date('24-03-2006', 'dd-mm-yyyy'), to_date('07-04-2006', 'dd-mm-yyyy'), 11, 5498, to_date('13-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021009008986, to_date('09-10-2002', 'dd-mm-yyyy'), to_date('23-10-2002', 'dd-mm-yyyy'), 4, 3763, to_date('23-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120130008987, to_date('30-01-2012', 'dd-mm-yyyy'), to_date('13-02-2012', 'dd-mm-yyyy'), 8, 7343, to_date('17-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040309008988, to_date('09-03-2004', 'dd-mm-yyyy'), to_date('23-03-2004', 'dd-mm-yyyy'), 2, 4368, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070719008989, to_date('19-07-2007', 'dd-mm-yyyy'), to_date('02-08-2007', 'dd-mm-yyyy'), 2, 4890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130904008990, to_date('04-09-2013', 'dd-mm-yyyy'), to_date('18-09-2013', 'dd-mm-yyyy'), 6, 9985, to_date('14-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040925008991, to_date('25-09-2004', 'dd-mm-yyyy'), to_date('09-10-2004', 'dd-mm-yyyy'), 9, 2550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121121008992, to_date('21-11-2012', 'dd-mm-yyyy'), to_date('05-12-2012', 'dd-mm-yyyy'), 2, 7591, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512008993, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 8, 2863, to_date('31-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060225008994, to_date('25-02-2006', 'dd-mm-yyyy'), to_date('11-03-2006', 'dd-mm-yyyy'), 4, 4356, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060205008995, to_date('05-02-2006', 'dd-mm-yyyy'), to_date('19-02-2006', 'dd-mm-yyyy'), 6, 4677, to_date('18-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110406008996, to_date('06-04-2011', 'dd-mm-yyyy'), to_date('20-04-2011', 'dd-mm-yyyy'), 10, 9838, to_date('12-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226008997, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 7, 5412, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110817008998, to_date('17-08-2011', 'dd-mm-yyyy'), to_date('31-08-2011', 'dd-mm-yyyy'), 5, 6170, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140321008999, to_date('21-03-2014', 'dd-mm-yyyy'), to_date('04-04-2014', 'dd-mm-yyyy'), 3, 9199, to_date('28-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120202009000, to_date('02-02-2012', 'dd-mm-yyyy'), to_date('16-02-2012', 'dd-mm-yyyy'), 2, 7902, to_date('14-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030320009001, to_date('20-03-2003', 'dd-mm-yyyy'), to_date('03-04-2003', 'dd-mm-yyyy'), 5, 2859, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090519009002, to_date('19-05-2009', 'dd-mm-yyyy'), to_date('02-06-2009', 'dd-mm-yyyy'), 9, 4966, to_date('06-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417009003, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 10, 3138, to_date('03-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603009004, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 5, 1927, to_date('05-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020727009005, to_date('27-07-2002', 'dd-mm-yyyy'), to_date('10-08-2002', 'dd-mm-yyyy'), 5, 4343, to_date('05-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120718009006, to_date('18-07-2012', 'dd-mm-yyyy'), to_date('01-08-2012', 'dd-mm-yyyy'), 2, 8298, to_date('26-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525009007, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 10, 10733, to_date('05-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730009008, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 12, 4820, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050602009009, to_date('02-06-2005', 'dd-mm-yyyy'), to_date('16-06-2005', 'dd-mm-yyyy'), 7, 3455, to_date('05-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603009010, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 6, 3270, to_date('10-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020211009011, to_date('11-02-2002', 'dd-mm-yyyy'), to_date('25-02-2002', 'dd-mm-yyyy'), 5, 2846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130703009012, to_date('03-07-2013', 'dd-mm-yyyy'), to_date('17-07-2013', 'dd-mm-yyyy'), 5, 9732, to_date('15-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060920009013, to_date('20-09-2006', 'dd-mm-yyyy'), to_date('04-10-2006', 'dd-mm-yyyy'), 5, 4150, to_date('26-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101218009014, to_date('18-12-2010', 'dd-mm-yyyy'), to_date('01-01-2011', 'dd-mm-yyyy'), 12, 6965, to_date('26-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070902009015, to_date('02-09-2007', 'dd-mm-yyyy'), to_date('16-09-2007', 'dd-mm-yyyy'), 9, 7833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712009016, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 7, 2960, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071216009017, to_date('16-12-2007', 'dd-mm-yyyy'), to_date('30-12-2007', 'dd-mm-yyyy'), 8, 5588, to_date('17-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060704009018, to_date('04-07-2006', 'dd-mm-yyyy'), to_date('18-07-2006', 'dd-mm-yyyy'), 6, 4530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080627009019, to_date('27-06-2008', 'dd-mm-yyyy'), to_date('11-07-2008', 'dd-mm-yyyy'), 7, 5247, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091130009020, to_date('30-11-2009', 'dd-mm-yyyy'), to_date('14-12-2009', 'dd-mm-yyyy'), 1, 8012, to_date('17-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040625009021, to_date('25-06-2004', 'dd-mm-yyyy'), to_date('09-07-2004', 'dd-mm-yyyy'), 5, 5002, to_date('07-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020111009022, to_date('11-01-2002', 'dd-mm-yyyy'), to_date('25-01-2002', 'dd-mm-yyyy'), 4, 3398, to_date('21-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021231009023, to_date('31-12-2002', 'dd-mm-yyyy'), to_date('14-01-2003', 'dd-mm-yyyy'), 2, 3207, to_date('17-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411009024, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 4, 8261, to_date('12-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091108001683, to_date('08-11-2009', 'dd-mm-yyyy'), to_date('22-11-2009', 'dd-mm-yyyy'), 5, 9000, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050707001684, to_date('07-07-2005', 'dd-mm-yyyy'), to_date('21-07-2005', 'dd-mm-yyyy'), 4, 3682, to_date('17-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021222001685, to_date('22-12-2002', 'dd-mm-yyyy'), to_date('05-01-2003', 'dd-mm-yyyy'), 12, 3822, to_date('04-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202001686, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 6, 6425, to_date('08-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725001687, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 4, 6946, to_date('07-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080504001688, to_date('04-05-2008', 'dd-mm-yyyy'), to_date('18-05-2008', 'dd-mm-yyyy'), 5, 7121, to_date('07-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119001689, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 9, 7780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128001690, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 7, 8024, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110905001691, to_date('05-09-2011', 'dd-mm-yyyy'), to_date('19-09-2011', 'dd-mm-yyyy'), 10, 11622, to_date('24-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061107001692, to_date('07-11-2006', 'dd-mm-yyyy'), to_date('21-11-2006', 'dd-mm-yyyy'), 7, 4859, to_date('11-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051028001693, to_date('28-10-2005', 'dd-mm-yyyy'), to_date('11-11-2005', 'dd-mm-yyyy'), 7, 4766, to_date('03-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128001694, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 2, 11324, to_date('02-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100215001695, to_date('15-02-2010', 'dd-mm-yyyy'), to_date('01-03-2010', 'dd-mm-yyyy'), 1, 4729, to_date('01-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203001696, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 1, 2306, to_date('07-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120507001697, to_date('07-05-2012', 'dd-mm-yyyy'), to_date('21-05-2012', 'dd-mm-yyyy'), 6, 8414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723001698, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 8, 6624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000113001699, to_date('13-01-2000', 'dd-mm-yyyy'), to_date('27-01-2000', 'dd-mm-yyyy'), 5, 2406, to_date('01-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080215001700, to_date('15-02-2008', 'dd-mm-yyyy'), to_date('29-02-2008', 'dd-mm-yyyy'), 6, 5715, to_date('23-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000624001701, to_date('24-06-2000', 'dd-mm-yyyy'), to_date('08-07-2000', 'dd-mm-yyyy'), 1, 1662, to_date('01-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070424001702, to_date('24-04-2007', 'dd-mm-yyyy'), to_date('08-05-2007', 'dd-mm-yyyy'), 7, 6204, to_date('02-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030730001703, to_date('30-07-2003', 'dd-mm-yyyy'), to_date('13-08-2003', 'dd-mm-yyyy'), 8, 4768, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100827001704, to_date('27-08-2010', 'dd-mm-yyyy'), to_date('10-09-2010', 'dd-mm-yyyy'), 10, 6748, to_date('30-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606001705, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 9, 3942, to_date('26-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060304001706, to_date('04-03-2006', 'dd-mm-yyyy'), to_date('18-03-2006', 'dd-mm-yyyy'), 3, 5464, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011210001707, to_date('10-12-2001', 'dd-mm-yyyy'), to_date('24-12-2001', 'dd-mm-yyyy'), 1, 1044, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110226001708, to_date('26-02-2011', 'dd-mm-yyyy'), to_date('12-03-2011', 'dd-mm-yyyy'), 3, 10769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030828001709, to_date('28-08-2003', 'dd-mm-yyyy'), to_date('11-09-2003', 'dd-mm-yyyy'), 9, 3527, to_date('02-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040917001710, to_date('17-09-2004', 'dd-mm-yyyy'), to_date('01-10-2004', 'dd-mm-yyyy'), 4, 3988, to_date('02-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110303001711, to_date('03-03-2011', 'dd-mm-yyyy'), to_date('17-03-2011', 'dd-mm-yyyy'), 9, 5796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090120001712, to_date('20-01-2009', 'dd-mm-yyyy'), to_date('03-02-2009', 'dd-mm-yyyy'), 3, 5157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623001713, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 7, 4275, to_date('25-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080608001714, to_date('08-06-2008', 'dd-mm-yyyy'), to_date('22-06-2008', 'dd-mm-yyyy'), 1, 4241, to_date('13-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130921001715, to_date('21-09-2013', 'dd-mm-yyyy'), to_date('05-10-2013', 'dd-mm-yyyy'), 6, 10463, to_date('23-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101010001716, to_date('10-10-2010', 'dd-mm-yyyy'), to_date('24-10-2010', 'dd-mm-yyyy'), 4, 8917, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504001717, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 2, 2686, to_date('08-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030412001718, to_date('12-04-2003', 'dd-mm-yyyy'), to_date('26-04-2003', 'dd-mm-yyyy'), 1, 2469, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041127001719, to_date('27-11-2004', 'dd-mm-yyyy'), to_date('11-12-2004', 'dd-mm-yyyy'), 11, 6557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050818001720, to_date('18-08-2005', 'dd-mm-yyyy'), to_date('01-09-2005', 'dd-mm-yyyy'), 4, 7028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201001721, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 9, 7650, to_date('13-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030303001722, to_date('03-03-2003', 'dd-mm-yyyy'), to_date('17-03-2003', 'dd-mm-yyyy'), 10, 3261, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080619001723, to_date('19-06-2008', 'dd-mm-yyyy'), to_date('03-07-2008', 'dd-mm-yyyy'), 5, 7300, to_date('08-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081128001724, to_date('28-11-2008', 'dd-mm-yyyy'), to_date('12-12-2008', 'dd-mm-yyyy'), 3, 6378, to_date('17-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120331001725, to_date('31-03-2012', 'dd-mm-yyyy'), to_date('14-04-2012', 'dd-mm-yyyy'), 1, 8503, to_date('19-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216001726, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 10, 3931, to_date('31-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140107001727, to_date('07-01-2014', 'dd-mm-yyyy'), to_date('21-01-2014', 'dd-mm-yyyy'), 2, 9571, to_date('10-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130611001728, to_date('11-06-2013', 'dd-mm-yyyy'), to_date('25-06-2013', 'dd-mm-yyyy'), 2, 7758, to_date('28-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030808001729, to_date('08-08-2003', 'dd-mm-yyyy'), to_date('22-08-2003', 'dd-mm-yyyy'), 8, 4792, to_date('12-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203001730, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 4, 4894, to_date('06-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021122001731, to_date('22-11-2002', 'dd-mm-yyyy'), to_date('06-12-2002', 'dd-mm-yyyy'), 11, 3035, to_date('29-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130326001732, to_date('26-03-2013', 'dd-mm-yyyy'), to_date('09-04-2013', 'dd-mm-yyyy'), 8, 10856, to_date('14-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040324001733, to_date('24-03-2004', 'dd-mm-yyyy'), to_date('07-04-2004', 'dd-mm-yyyy'), 3, 3525, to_date('01-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000516001734, to_date('16-05-2000', 'dd-mm-yyyy'), to_date('30-05-2000', 'dd-mm-yyyy'), 6, 1397, to_date('22-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050627001735, to_date('27-06-2005', 'dd-mm-yyyy'), to_date('11-07-2005', 'dd-mm-yyyy'), 6, 3563, to_date('03-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120610001736, to_date('10-06-2012', 'dd-mm-yyyy'), to_date('24-06-2012', 'dd-mm-yyyy'), 1, 6163, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020919001737, to_date('19-09-2002', 'dd-mm-yyyy'), to_date('03-10-2002', 'dd-mm-yyyy'), 2, 3755, to_date('26-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071028001738, to_date('28-10-2007', 'dd-mm-yyyy'), to_date('11-11-2007', 'dd-mm-yyyy'), 7, 5608, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719001739, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 9, 4502, to_date('28-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715001740, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 2, 2189, to_date('29-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010731001741, to_date('31-07-2001', 'dd-mm-yyyy'), to_date('14-08-2001', 'dd-mm-yyyy'), 6, 1126, to_date('07-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213001742, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 1, 9110, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100626001743, to_date('26-06-2010', 'dd-mm-yyyy'), to_date('10-07-2010', 'dd-mm-yyyy'), 2, 6446, to_date('06-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026001744, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 7, 3924, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050621001745, to_date('21-06-2005', 'dd-mm-yyyy'), to_date('05-07-2005', 'dd-mm-yyyy'), 4, 4123, to_date('03-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060703001746, to_date('03-07-2006', 'dd-mm-yyyy'), to_date('17-07-2006', 'dd-mm-yyyy'), 1, 3309, to_date('23-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620001747, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 8, 7080, to_date('30-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080130001748, to_date('30-01-2008', 'dd-mm-yyyy'), to_date('13-02-2008', 'dd-mm-yyyy'), 4, 6734, to_date('16-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071002001749, to_date('02-10-2007', 'dd-mm-yyyy'), to_date('16-10-2007', 'dd-mm-yyyy'), 8, 8358, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121025001750, to_date('25-10-2012', 'dd-mm-yyyy'), to_date('08-11-2012', 'dd-mm-yyyy'), 6, 6264, to_date('12-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080729001751, to_date('29-07-2008', 'dd-mm-yyyy'), to_date('12-08-2008', 'dd-mm-yyyy'), 9, 5647, to_date('18-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406001752, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 10, 4247, to_date('15-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080810001753, to_date('10-08-2008', 'dd-mm-yyyy'), to_date('24-08-2008', 'dd-mm-yyyy'), 3, 7856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081221001754, to_date('21-12-2008', 'dd-mm-yyyy'), to_date('04-01-2009', 'dd-mm-yyyy'), 11, 5816, to_date('24-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100511001755, to_date('11-05-2010', 'dd-mm-yyyy'), to_date('25-05-2010', 'dd-mm-yyyy'), 12, 5672, to_date('23-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040119001756, to_date('19-01-2004', 'dd-mm-yyyy'), to_date('02-02-2004', 'dd-mm-yyyy'), 10, 5377, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009001757, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 12, 5344, to_date('22-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120628001758, to_date('28-06-2012', 'dd-mm-yyyy'), to_date('12-07-2012', 'dd-mm-yyyy'), 8, 8016, to_date('17-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210001759, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 7, 6988, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010212001760, to_date('12-02-2001', 'dd-mm-yyyy'), to_date('26-02-2001', 'dd-mm-yyyy'), 8, 1324, to_date('21-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081107001761, to_date('07-11-2008', 'dd-mm-yyyy'), to_date('21-11-2008', 'dd-mm-yyyy'), 2, 5097, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000812001762, to_date('12-08-2000', 'dd-mm-yyyy'), to_date('26-08-2000', 'dd-mm-yyyy'), 1, 1062, to_date('27-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007001763, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 6, 2002, to_date('17-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050201001764, to_date('01-02-2005', 'dd-mm-yyyy'), to_date('15-02-2005', 'dd-mm-yyyy'), 11, 5207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050705001765, to_date('05-07-2005', 'dd-mm-yyyy'), to_date('19-07-2005', 'dd-mm-yyyy'), 1, 6021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311001766, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 1, 6729, to_date('15-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081009001767, to_date('09-10-2008', 'dd-mm-yyyy'), to_date('23-10-2008', 'dd-mm-yyyy'), 8, 5203, to_date('10-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302001768, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 12, 3284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030823001769, to_date('23-08-2003', 'dd-mm-yyyy'), to_date('06-09-2003', 'dd-mm-yyyy'), 3, 2412, to_date('26-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220001770, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 7, 4475, to_date('07-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040917001771, to_date('17-09-2004', 'dd-mm-yyyy'), to_date('01-10-2004', 'dd-mm-yyyy'), 1, 4216, to_date('04-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103001772, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 4, 7524, to_date('22-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080524001773, to_date('24-05-2008', 'dd-mm-yyyy'), to_date('07-06-2008', 'dd-mm-yyyy'), 6, 4452, to_date('25-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001010001774, to_date('10-10-2000', 'dd-mm-yyyy'), to_date('24-10-2000', 'dd-mm-yyyy'), 5, 1616, to_date('29-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090724001775, to_date('24-07-2009', 'dd-mm-yyyy'), to_date('07-08-2009', 'dd-mm-yyyy'), 12, 7899, to_date('31-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908001776, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 8, 8062, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011109001777, to_date('09-11-2001', 'dd-mm-yyyy'), to_date('23-11-2001', 'dd-mm-yyyy'), 8, 2132, to_date('26-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010103001778, to_date('03-01-2001', 'dd-mm-yyyy'), to_date('17-01-2001', 'dd-mm-yyyy'), 3, 2784, to_date('12-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000824001779, to_date('24-08-2000', 'dd-mm-yyyy'), to_date('07-09-2000', 'dd-mm-yyyy'), 5, 1065, to_date('11-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120310001780, to_date('10-03-2012', 'dd-mm-yyyy'), to_date('24-03-2012', 'dd-mm-yyyy'), 8, 7940, to_date('12-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101001781, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 6, 5712, to_date('03-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060707001782, to_date('07-07-2006', 'dd-mm-yyyy'), to_date('21-07-2006', 'dd-mm-yyyy'), 5, 6913, to_date('09-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090928001783, to_date('28-09-2009', 'dd-mm-yyyy'), to_date('12-10-2009', 'dd-mm-yyyy'), 5, 6514, to_date('06-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218001784, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 9, 6620, to_date('20-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001005001785, to_date('05-10-2000', 'dd-mm-yyyy'), to_date('19-10-2000', 'dd-mm-yyyy'), 9, 2098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120913001786, to_date('13-09-2012', 'dd-mm-yyyy'), to_date('27-09-2012', 'dd-mm-yyyy'), 6, 9376, to_date('24-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319001787, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 4, 1734, to_date('27-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020814001788, to_date('14-08-2002', 'dd-mm-yyyy'), to_date('28-08-2002', 'dd-mm-yyyy'), 7, 2958, to_date('18-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060607001789, to_date('07-06-2006', 'dd-mm-yyyy'), to_date('21-06-2006', 'dd-mm-yyyy'), 10, 4212, to_date('15-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040626001790, to_date('26-06-2004', 'dd-mm-yyyy'), to_date('10-07-2004', 'dd-mm-yyyy'), 9, 3007, to_date('15-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090613001791, to_date('13-06-2009', 'dd-mm-yyyy'), to_date('27-06-2009', 'dd-mm-yyyy'), 2, 7420, to_date('20-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110625001792, to_date('25-06-2011', 'dd-mm-yyyy'), to_date('09-07-2011', 'dd-mm-yyyy'), 11, 8104, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111228001793, to_date('28-12-2011', 'dd-mm-yyyy'), to_date('11-01-2012', 'dd-mm-yyyy'), 10, 7389, to_date('05-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000226001794, to_date('26-02-2000', 'dd-mm-yyyy'), to_date('11-03-2000', 'dd-mm-yyyy'), 5, 1908, to_date('04-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030612001795, to_date('12-06-2003', 'dd-mm-yyyy'), to_date('26-06-2003', 'dd-mm-yyyy'), 7, 3074, to_date('30-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110525001796, to_date('25-05-2011', 'dd-mm-yyyy'), to_date('08-06-2011', 'dd-mm-yyyy'), 2, 6811, to_date('07-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000502001797, to_date('02-05-2000', 'dd-mm-yyyy'), to_date('16-05-2000', 'dd-mm-yyyy'), 11, 1641, to_date('04-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130520001798, to_date('20-05-2013', 'dd-mm-yyyy'), to_date('03-06-2013', 'dd-mm-yyyy'), 4, 7944, to_date('08-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090721001799, to_date('21-07-2009', 'dd-mm-yyyy'), to_date('04-08-2009', 'dd-mm-yyyy'), 6, 7767, to_date('27-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628001800, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 1, 2639, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040502001801, to_date('02-05-2004', 'dd-mm-yyyy'), to_date('16-05-2004', 'dd-mm-yyyy'), 3, 4731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630001802, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 7, 4235, to_date('05-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091128001803, to_date('28-11-2009', 'dd-mm-yyyy'), to_date('12-12-2009', 'dd-mm-yyyy'), 9, 8128, to_date('30-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100929001804, to_date('29-09-2010', 'dd-mm-yyyy'), to_date('13-10-2010', 'dd-mm-yyyy'), 11, 5340, to_date('30-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100927001805, to_date('27-09-2010', 'dd-mm-yyyy'), to_date('11-10-2010', 'dd-mm-yyyy'), 3, 7456, to_date('10-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120216001806, to_date('16-02-2012', 'dd-mm-yyyy'), to_date('01-03-2012', 'dd-mm-yyyy'), 5, 9880, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109001807, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 8, 2868, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090904001808, to_date('04-09-2009', 'dd-mm-yyyy'), to_date('18-09-2009', 'dd-mm-yyyy'), 1, 7922, to_date('17-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050506001809, to_date('06-05-2005', 'dd-mm-yyyy'), to_date('20-05-2005', 'dd-mm-yyyy'), 3, 6018, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090429001810, to_date('29-04-2009', 'dd-mm-yyyy'), to_date('13-05-2009', 'dd-mm-yyyy'), 9, 8773, to_date('02-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100610001811, to_date('10-06-2010', 'dd-mm-yyyy'), to_date('24-06-2010', 'dd-mm-yyyy'), 5, 7391, to_date('18-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110414001812, to_date('14-04-2011', 'dd-mm-yyyy'), to_date('28-04-2011', 'dd-mm-yyyy'), 11, 8037, to_date('17-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100613001813, to_date('13-06-2010', 'dd-mm-yyyy'), to_date('27-06-2010', 'dd-mm-yyyy'), 1, 7203, to_date('02-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080529001814, to_date('29-05-2008', 'dd-mm-yyyy'), to_date('12-06-2008', 'dd-mm-yyyy'), 3, 5225, to_date('14-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130902001815, to_date('02-09-2013', 'dd-mm-yyyy'), to_date('16-09-2013', 'dd-mm-yyyy'), 9, 9367, to_date('03-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021026001816, to_date('26-10-2002', 'dd-mm-yyyy'), to_date('09-11-2002', 'dd-mm-yyyy'), 11, 2874, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101025001817, to_date('25-10-2010', 'dd-mm-yyyy'), to_date('08-11-2010', 'dd-mm-yyyy'), 8, 6581, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020509001818, to_date('09-05-2002', 'dd-mm-yyyy'), to_date('23-05-2002', 'dd-mm-yyyy'), 7, 2239, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091103001819, to_date('03-11-2009', 'dd-mm-yyyy'), to_date('17-11-2009', 'dd-mm-yyyy'), 3, 6272, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050225001820, to_date('25-02-2005', 'dd-mm-yyyy'), to_date('11-03-2005', 'dd-mm-yyyy'), 10, 2402, to_date('10-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070608001821, to_date('08-06-2007', 'dd-mm-yyyy'), to_date('22-06-2007', 'dd-mm-yyyy'), 10, 5597, to_date('27-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131002001822, to_date('02-10-2013', 'dd-mm-yyyy'), to_date('16-10-2013', 'dd-mm-yyyy'), 3, 6717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050707001823, to_date('07-07-2005', 'dd-mm-yyyy'), to_date('21-07-2005', 'dd-mm-yyyy'), 2, 4547, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130214001824, to_date('14-02-2013', 'dd-mm-yyyy'), to_date('28-02-2013', 'dd-mm-yyyy'), 7, 10285, to_date('27-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040501001825, to_date('01-05-2004', 'dd-mm-yyyy'), to_date('15-05-2004', 'dd-mm-yyyy'), 10, 4474, to_date('16-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080403001826, to_date('03-04-2008', 'dd-mm-yyyy'), to_date('17-04-2008', 'dd-mm-yyyy'), 11, 8843, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204001827, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 5, 3715, to_date('06-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911001828, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 4, 8498, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113001829, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 9, 3887, to_date('01-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504001830, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 3, 6703, to_date('15-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130508001831, to_date('08-05-2013', 'dd-mm-yyyy'), to_date('22-05-2013', 'dd-mm-yyyy'), 3, 9467, to_date('16-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901001832, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 8, 2690, to_date('07-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101128001833, to_date('28-11-2010', 'dd-mm-yyyy'), to_date('12-12-2010', 'dd-mm-yyyy'), 10, 9358, to_date('04-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020108001834, to_date('08-01-2002', 'dd-mm-yyyy'), to_date('22-01-2002', 'dd-mm-yyyy'), 11, 3845, to_date('27-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050204001835, to_date('04-02-2005', 'dd-mm-yyyy'), to_date('18-02-2005', 'dd-mm-yyyy'), 11, 5469, to_date('11-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100115004135, to_date('15-01-2010', 'dd-mm-yyyy'), to_date('29-01-2010', 'dd-mm-yyyy'), 1, 9100, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010930004136, to_date('30-09-2001', 'dd-mm-yyyy'), to_date('14-10-2001', 'dd-mm-yyyy'), 6, 2411, to_date('13-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070428004137, to_date('28-04-2007', 'dd-mm-yyyy'), to_date('12-05-2007', 'dd-mm-yyyy'), 3, 4080, to_date('17-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130122004138, to_date('22-01-2013', 'dd-mm-yyyy'), to_date('05-02-2013', 'dd-mm-yyyy'), 10, 8975, to_date('06-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090623004139, to_date('23-06-2009', 'dd-mm-yyyy'), to_date('07-07-2009', 'dd-mm-yyyy'), 10, 6326, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070122004140, to_date('22-01-2007', 'dd-mm-yyyy'), to_date('05-02-2007', 'dd-mm-yyyy'), 12, 4136, to_date('29-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827004141, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 5, 3184, to_date('08-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130824004142, to_date('24-08-2013', 'dd-mm-yyyy'), to_date('07-09-2013', 'dd-mm-yyyy'), 9, 8334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070606004143, to_date('06-06-2007', 'dd-mm-yyyy'), to_date('20-06-2007', 'dd-mm-yyyy'), 12, 2957, to_date('08-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030728004144, to_date('28-07-2003', 'dd-mm-yyyy'), to_date('11-08-2003', 'dd-mm-yyyy'), 4, 3659, to_date('10-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070323004145, to_date('23-03-2007', 'dd-mm-yyyy'), to_date('06-04-2007', 'dd-mm-yyyy'), 5, 6179, to_date('02-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513004146, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 11, 5164, to_date('23-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101004147, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 6, 5777, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090212004148, to_date('12-02-2009', 'dd-mm-yyyy'), to_date('26-02-2009', 'dd-mm-yyyy'), 4, 6328, to_date('25-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020607004149, to_date('07-06-2002', 'dd-mm-yyyy'), to_date('21-06-2002', 'dd-mm-yyyy'), 9, 2479, to_date('20-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313004150, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 7, 5987, to_date('23-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020826004151, to_date('26-08-2002', 'dd-mm-yyyy'), to_date('09-09-2002', 'dd-mm-yyyy'), 1, 3079, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040706004152, to_date('06-07-2004', 'dd-mm-yyyy'), to_date('20-07-2004', 'dd-mm-yyyy'), 3, 3049, to_date('11-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010907004153, to_date('07-09-2001', 'dd-mm-yyyy'), to_date('21-09-2001', 'dd-mm-yyyy'), 3, 1606, to_date('12-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031108004154, to_date('08-11-2003', 'dd-mm-yyyy'), to_date('22-11-2003', 'dd-mm-yyyy'), 2, 3514, to_date('09-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120516004155, to_date('16-05-2012', 'dd-mm-yyyy'), to_date('30-05-2012', 'dd-mm-yyyy'), 8, 8307, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030615004156, to_date('15-06-2003', 'dd-mm-yyyy'), to_date('29-06-2003', 'dd-mm-yyyy'), 7, 4915, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061118004157, to_date('18-11-2006', 'dd-mm-yyyy'), to_date('02-12-2006', 'dd-mm-yyyy'), 11, 6139, to_date('22-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214004158, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 10, 9412, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060413004159, to_date('13-04-2006', 'dd-mm-yyyy'), to_date('27-04-2006', 'dd-mm-yyyy'), 1, 5444, to_date('15-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011009004160, to_date('09-10-2001', 'dd-mm-yyyy'), to_date('23-10-2001', 'dd-mm-yyyy'), 5, 2812, to_date('19-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010206004161, to_date('06-02-2001', 'dd-mm-yyyy'), to_date('20-02-2001', 'dd-mm-yyyy'), 9, 871, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403004162, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 10, 6492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916004163, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 5, 4364, to_date('30-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030426004164, to_date('26-04-2003', 'dd-mm-yyyy'), to_date('10-05-2003', 'dd-mm-yyyy'), 5, 3930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110004165, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 11, 1116, to_date('29-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121225004166, to_date('25-12-2012', 'dd-mm-yyyy'), to_date('08-01-2013', 'dd-mm-yyyy'), 9, 7834, to_date('02-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111004167, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 7, 2981, to_date('22-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140304004168, to_date('04-03-2014', 'dd-mm-yyyy'), to_date('18-03-2014', 'dd-mm-yyyy'), 4, 9923, to_date('19-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030608004169, to_date('08-06-2003', 'dd-mm-yyyy'), to_date('22-06-2003', 'dd-mm-yyyy'), 4, 2937, to_date('21-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131027004170, to_date('27-10-2013', 'dd-mm-yyyy'), to_date('10-11-2013', 'dd-mm-yyyy'), 3, 8291, to_date('28-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140306004171, to_date('06-03-2014', 'dd-mm-yyyy'), to_date('20-03-2014', 'dd-mm-yyyy'), 7, 8050, to_date('17-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131013004172, to_date('13-10-2013', 'dd-mm-yyyy'), to_date('27-10-2013', 'dd-mm-yyyy'), 11, 9156, to_date('24-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061204004173, to_date('04-12-2006', 'dd-mm-yyyy'), to_date('18-12-2006', 'dd-mm-yyyy'), 5, 4903, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041004004174, to_date('04-10-2004', 'dd-mm-yyyy'), to_date('18-10-2004', 'dd-mm-yyyy'), 3, 3265, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030107004175, to_date('07-01-2003', 'dd-mm-yyyy'), to_date('21-01-2003', 'dd-mm-yyyy'), 8, 3081, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110613004176, to_date('13-06-2011', 'dd-mm-yyyy'), to_date('27-06-2011', 'dd-mm-yyyy'), 11, 5749, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091207004177, to_date('07-12-2009', 'dd-mm-yyyy'), to_date('21-12-2009', 'dd-mm-yyyy'), 7, 8158, to_date('13-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041117004178, to_date('17-11-2004', 'dd-mm-yyyy'), to_date('01-12-2004', 'dd-mm-yyyy'), 10, 4515, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030727004179, to_date('27-07-2003', 'dd-mm-yyyy'), to_date('10-08-2003', 'dd-mm-yyyy'), 5, 4623, to_date('30-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090905004180, to_date('05-09-2009', 'dd-mm-yyyy'), to_date('19-09-2009', 'dd-mm-yyyy'), 5, 6383, to_date('16-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406004181, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 5, 7146, to_date('11-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106004182, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 6, 9095, to_date('23-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050420004183, to_date('20-04-2005', 'dd-mm-yyyy'), to_date('04-05-2005', 'dd-mm-yyyy'), 3, 2525, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100225004184, to_date('25-02-2010', 'dd-mm-yyyy'), to_date('11-03-2010', 'dd-mm-yyyy'), 9, 6877, to_date('05-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040914004185, to_date('14-09-2004', 'dd-mm-yyyy'), to_date('28-09-2004', 'dd-mm-yyyy'), 10, 3424, to_date('29-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050303004186, to_date('03-03-2005', 'dd-mm-yyyy'), to_date('17-03-2005', 'dd-mm-yyyy'), 9, 5032, to_date('19-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100328004187, to_date('28-03-2010', 'dd-mm-yyyy'), to_date('11-04-2010', 'dd-mm-yyyy'), 3, 5702, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010805004188, to_date('05-08-2001', 'dd-mm-yyyy'), to_date('19-08-2001', 'dd-mm-yyyy'), 7, 4017, to_date('23-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060803004189, to_date('03-08-2006', 'dd-mm-yyyy'), to_date('17-08-2006', 'dd-mm-yyyy'), 7, 5375, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071020004190, to_date('20-10-2007', 'dd-mm-yyyy'), to_date('03-11-2007', 'dd-mm-yyyy'), 11, 6391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120111004191, to_date('11-01-2012', 'dd-mm-yyyy'), to_date('25-01-2012', 'dd-mm-yyyy'), 9, 9654, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090611004192, to_date('11-06-2009', 'dd-mm-yyyy'), to_date('25-06-2009', 'dd-mm-yyyy'), 11, 4536, to_date('20-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202004193, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 8, 6386, to_date('16-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427004194, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 9, 5075, to_date('10-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070627004195, to_date('27-06-2007', 'dd-mm-yyyy'), to_date('11-07-2007', 'dd-mm-yyyy'), 8, 4030, to_date('02-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090127004196, to_date('27-01-2009', 'dd-mm-yyyy'), to_date('10-02-2009', 'dd-mm-yyyy'), 2, 8133, to_date('29-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080618004197, to_date('18-06-2008', 'dd-mm-yyyy'), to_date('02-07-2008', 'dd-mm-yyyy'), 9, 7003, to_date('03-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021217004198, to_date('17-12-2002', 'dd-mm-yyyy'), to_date('31-12-2002', 'dd-mm-yyyy'), 7, 2717, to_date('30-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050603004199, to_date('03-06-2005', 'dd-mm-yyyy'), to_date('17-06-2005', 'dd-mm-yyyy'), 3, 3540, to_date('20-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408004200, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 7, 3258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207004201, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 4, 7255, to_date('09-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040508004202, to_date('08-05-2004', 'dd-mm-yyyy'), to_date('22-05-2004', 'dd-mm-yyyy'), 11, 5573, to_date('13-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214004203, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 1, 2910, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050325004204, to_date('25-03-2005', 'dd-mm-yyyy'), to_date('08-04-2005', 'dd-mm-yyyy'), 9, 3393, to_date('01-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041003004205, to_date('03-10-2004', 'dd-mm-yyyy'), to_date('17-10-2004', 'dd-mm-yyyy'), 5, 4675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121031004206, to_date('31-10-2012', 'dd-mm-yyyy'), to_date('14-11-2012', 'dd-mm-yyyy'), 12, 7969, to_date('05-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130211004207, to_date('11-02-2013', 'dd-mm-yyyy'), to_date('25-02-2013', 'dd-mm-yyyy'), 8, 8995, to_date('23-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080101004208, to_date('01-01-2008', 'dd-mm-yyyy'), to_date('15-01-2008', 'dd-mm-yyyy'), 4, 4786, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060510004209, to_date('10-05-2006', 'dd-mm-yyyy'), to_date('24-05-2006', 'dd-mm-yyyy'), 3, 4600, to_date('25-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906004210, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 10, 6361, to_date('13-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426004211, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 8, 3485, to_date('04-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110115004212, to_date('15-01-2011', 'dd-mm-yyyy'), to_date('29-01-2011', 'dd-mm-yyyy'), 3, 6848, to_date('18-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040523004213, to_date('23-05-2004', 'dd-mm-yyyy'), to_date('06-06-2004', 'dd-mm-yyyy'), 2, 3604, to_date('02-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130708004214, to_date('08-07-2013', 'dd-mm-yyyy'), to_date('22-07-2013', 'dd-mm-yyyy'), 6, 10821, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110506004215, to_date('06-05-2011', 'dd-mm-yyyy'), to_date('20-05-2011', 'dd-mm-yyyy'), 8, 8311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040928004216, to_date('28-09-2004', 'dd-mm-yyyy'), to_date('12-10-2004', 'dd-mm-yyyy'), 2, 5645, to_date('11-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080508004217, to_date('08-05-2008', 'dd-mm-yyyy'), to_date('22-05-2008', 'dd-mm-yyyy'), 3, 7614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120527004218, to_date('27-05-2012', 'dd-mm-yyyy'), to_date('10-06-2012', 'dd-mm-yyyy'), 12, 8048, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050822004219, to_date('22-08-2005', 'dd-mm-yyyy'), to_date('05-09-2005', 'dd-mm-yyyy'), 9, 5584, to_date('24-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080726004220, to_date('26-07-2008', 'dd-mm-yyyy'), to_date('09-08-2008', 'dd-mm-yyyy'), 4, 5748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815004221, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 7, 4183, to_date('25-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040915004222, to_date('15-09-2004', 'dd-mm-yyyy'), to_date('29-09-2004', 'dd-mm-yyyy'), 2, 5568, to_date('05-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315004223, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 5, 7705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070312004224, to_date('12-03-2007', 'dd-mm-yyyy'), to_date('26-03-2007', 'dd-mm-yyyy'), 5, 6375, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009004225, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 2, 6585, to_date('24-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030309004226, to_date('09-03-2003', 'dd-mm-yyyy'), to_date('23-03-2003', 'dd-mm-yyyy'), 5, 3343, to_date('21-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080727004227, to_date('27-07-2008', 'dd-mm-yyyy'), to_date('10-08-2008', 'dd-mm-yyyy'), 2, 7291, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001019004228, to_date('19-10-2000', 'dd-mm-yyyy'), to_date('02-11-2000', 'dd-mm-yyyy'), 10, 2568, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130309004229, to_date('09-03-2013', 'dd-mm-yyyy'), to_date('23-03-2013', 'dd-mm-yyyy'), 8, 8493, to_date('18-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000606004230, to_date('06-06-2000', 'dd-mm-yyyy'), to_date('20-06-2000', 'dd-mm-yyyy'), 11, 1952, to_date('09-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140330004231, to_date('30-03-2014', 'dd-mm-yyyy'), to_date('13-04-2014', 'dd-mm-yyyy'), 2, 8900, to_date('09-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208004232, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 11, 1304, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120107004233, to_date('07-01-2012', 'dd-mm-yyyy'), to_date('21-01-2012', 'dd-mm-yyyy'), 7, 7233, to_date('15-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140309004234, to_date('09-03-2014', 'dd-mm-yyyy'), to_date('23-03-2014', 'dd-mm-yyyy'), 5, 12524, to_date('12-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080810004235, to_date('10-08-2008', 'dd-mm-yyyy'), to_date('24-08-2008', 'dd-mm-yyyy'), 10, 5444, to_date('19-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021231004236, to_date('31-12-2002', 'dd-mm-yyyy'), to_date('14-01-2003', 'dd-mm-yyyy'), 3, 2860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902004237, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 10, 1729, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100416004238, to_date('16-04-2010', 'dd-mm-yyyy'), to_date('30-04-2010', 'dd-mm-yyyy'), 4, 7661, to_date('20-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000215004239, to_date('15-02-2000', 'dd-mm-yyyy'), to_date('29-02-2000', 'dd-mm-yyyy'), 11, 743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110916004240, to_date('16-09-2011', 'dd-mm-yyyy'), to_date('30-09-2011', 'dd-mm-yyyy'), 3, 8564, to_date('06-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050208004241, to_date('08-02-2005', 'dd-mm-yyyy'), to_date('22-02-2005', 'dd-mm-yyyy'), 10, 3736, to_date('12-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010917004242, to_date('17-09-2001', 'dd-mm-yyyy'), to_date('01-10-2001', 'dd-mm-yyyy'), 7, 3352, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060426004243, to_date('26-04-2006', 'dd-mm-yyyy'), to_date('10-05-2006', 'dd-mm-yyyy'), 12, 4904, to_date('07-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120909004244, to_date('09-09-2012', 'dd-mm-yyyy'), to_date('23-09-2012', 'dd-mm-yyyy'), 11, 7308, to_date('15-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029004245, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 11, 4780, to_date('31-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100127004246, to_date('27-01-2010', 'dd-mm-yyyy'), to_date('10-02-2010', 'dd-mm-yyyy'), 5, 9037, to_date('09-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130407004247, to_date('07-04-2013', 'dd-mm-yyyy'), to_date('21-04-2013', 'dd-mm-yyyy'), 2, 8100, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411004248, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 3, 5567, to_date('16-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319004249, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 12, 3717, to_date('23-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114004250, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 11, 2257, to_date('23-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140106004251, to_date('06-01-2014', 'dd-mm-yyyy'), to_date('20-01-2014', 'dd-mm-yyyy'), 6, 9051, to_date('22-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120202004252, to_date('02-02-2012', 'dd-mm-yyyy'), to_date('16-02-2012', 'dd-mm-yyyy'), 5, 6365, to_date('16-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231004253, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 1, 4951, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040307004254, to_date('07-03-2004', 'dd-mm-yyyy'), to_date('21-03-2004', 'dd-mm-yyyy'), 5, 3458, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080724004255, to_date('24-07-2008', 'dd-mm-yyyy'), to_date('07-08-2008', 'dd-mm-yyyy'), 7, 6494, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040414004256, to_date('14-04-2004', 'dd-mm-yyyy'), to_date('28-04-2004', 'dd-mm-yyyy'), 2, 4274, to_date('26-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130604004257, to_date('04-06-2013', 'dd-mm-yyyy'), to_date('18-06-2013', 'dd-mm-yyyy'), 2, 10139, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422004258, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 1, 3168, to_date('01-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050626004259, to_date('26-06-2005', 'dd-mm-yyyy'), to_date('10-07-2005', 'dd-mm-yyyy'), 7, 4267, to_date('02-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061111004260, to_date('11-11-2006', 'dd-mm-yyyy'), to_date('25-11-2006', 'dd-mm-yyyy'), 2, 6059, to_date('19-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060310004261, to_date('10-03-2006', 'dd-mm-yyyy'), to_date('24-03-2006', 'dd-mm-yyyy'), 3, 5112, to_date('24-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040407004262, to_date('07-04-2004', 'dd-mm-yyyy'), to_date('21-04-2004', 'dd-mm-yyyy'), 9, 3843, to_date('21-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710004263, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 7, 1607, to_date('30-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206004264, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 1, 3977, to_date('25-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916004265, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 5, 2129, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010213004266, to_date('13-02-2001', 'dd-mm-yyyy'), to_date('27-02-2001', 'dd-mm-yyyy'), 12, 2642, to_date('04-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902004267, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 4, 2190, to_date('14-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120205004268, to_date('05-02-2012', 'dd-mm-yyyy'), to_date('19-02-2012', 'dd-mm-yyyy'), 2, 8208, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121214004269, to_date('14-12-2012', 'dd-mm-yyyy'), to_date('28-12-2012', 'dd-mm-yyyy'), 10, 10224, to_date('22-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120325004270, to_date('25-03-2012', 'dd-mm-yyyy'), to_date('08-04-2012', 'dd-mm-yyyy'), 7, 11327, to_date('09-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030925004271, to_date('25-09-2003', 'dd-mm-yyyy'), to_date('09-10-2003', 'dd-mm-yyyy'), 6, 4187, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119004272, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 5, 1802, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111004273, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 5, 5216, to_date('16-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226004274, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 4, 7244, to_date('27-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120123004275, to_date('23-01-2012', 'dd-mm-yyyy'), to_date('06-02-2012', 'dd-mm-yyyy'), 5, 7656, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090523004276, to_date('23-05-2009', 'dd-mm-yyyy'), to_date('06-06-2009', 'dd-mm-yyyy'), 3, 5365, to_date('04-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120421004277, to_date('21-04-2012', 'dd-mm-yyyy'), to_date('05-05-2012', 'dd-mm-yyyy'), 3, 7871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020722004278, to_date('22-07-2002', 'dd-mm-yyyy'), to_date('05-08-2002', 'dd-mm-yyyy'), 2, 3274, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318004279, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 10, 6902, to_date('25-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121231004280, to_date('31-12-2012', 'dd-mm-yyyy'), to_date('14-01-2013', 'dd-mm-yyyy'), 5, 7608, to_date('15-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121102004281, to_date('02-11-2012', 'dd-mm-yyyy'), to_date('16-11-2012', 'dd-mm-yyyy'), 11, 7042, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113004282, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 2, 3604, to_date('20-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010517004283, to_date('17-05-2001', 'dd-mm-yyyy'), to_date('31-05-2001', 'dd-mm-yyyy'), 10, 2091, to_date('20-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120429004284, to_date('29-04-2012', 'dd-mm-yyyy'), to_date('13-05-2012', 'dd-mm-yyyy'), 3, 9252, to_date('13-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080308004285, to_date('08-03-2008', 'dd-mm-yyyy'), to_date('22-03-2008', 'dd-mm-yyyy'), 1, 6830, to_date('13-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080508004286, to_date('08-05-2008', 'dd-mm-yyyy'), to_date('22-05-2008', 'dd-mm-yyyy'), 8, 9322, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080522004287, to_date('22-05-2008', 'dd-mm-yyyy'), to_date('05-06-2008', 'dd-mm-yyyy'), 3, 5913, to_date('02-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130904006428, to_date('04-09-2013', 'dd-mm-yyyy'), to_date('18-09-2013', 'dd-mm-yyyy'), 5, 11565, to_date('10-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080408006429, to_date('08-04-2008', 'dd-mm-yyyy'), to_date('22-04-2008', 'dd-mm-yyyy'), 11, 6332, to_date('14-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628006430, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 6, 3882, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080709006431, to_date('09-07-2008', 'dd-mm-yyyy'), to_date('23-07-2008', 'dd-mm-yyyy'), 7, 4843, to_date('21-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111224006432, to_date('24-12-2011', 'dd-mm-yyyy'), to_date('07-01-2012', 'dd-mm-yyyy'), 8, 7123, to_date('12-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130829006433, to_date('29-08-2013', 'dd-mm-yyyy'), to_date('12-09-2013', 'dd-mm-yyyy'), 3, 7709, to_date('14-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030624006434, to_date('24-06-2003', 'dd-mm-yyyy'), to_date('08-07-2003', 'dd-mm-yyyy'), 9, 4498, to_date('29-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001006435, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 5, 2671, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421006436, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 4, 6226, to_date('10-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090623006437, to_date('23-06-2009', 'dd-mm-yyyy'), to_date('07-07-2009', 'dd-mm-yyyy'), 4, 7484, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213006438, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 6, 1678, to_date('30-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010918006439, to_date('18-09-2001', 'dd-mm-yyyy'), to_date('02-10-2001', 'dd-mm-yyyy'), 3, 3040, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010729006440, to_date('29-07-2001', 'dd-mm-yyyy'), to_date('12-08-2001', 'dd-mm-yyyy'), 7, 2785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206006441, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 2, 5332, to_date('25-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020329006442, to_date('29-03-2002', 'dd-mm-yyyy'), to_date('12-04-2002', 'dd-mm-yyyy'), 3, 2133, to_date('04-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080408006443, to_date('08-04-2008', 'dd-mm-yyyy'), to_date('22-04-2008', 'dd-mm-yyyy'), 11, 4936, to_date('16-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070719006444, to_date('19-07-2007', 'dd-mm-yyyy'), to_date('02-08-2007', 'dd-mm-yyyy'), 7, 7334, to_date('28-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130510006445, to_date('10-05-2013', 'dd-mm-yyyy'), to_date('24-05-2013', 'dd-mm-yyyy'), 2, 7756, to_date('16-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130623006446, to_date('23-06-2013', 'dd-mm-yyyy'), to_date('07-07-2013', 'dd-mm-yyyy'), 9, 7434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050222006447, to_date('22-02-2005', 'dd-mm-yyyy'), to_date('08-03-2005', 'dd-mm-yyyy'), 4, 4753, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120206006448, to_date('06-02-2012', 'dd-mm-yyyy'), to_date('20-02-2012', 'dd-mm-yyyy'), 6, 8012, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100126006449, to_date('26-01-2010', 'dd-mm-yyyy'), to_date('09-02-2010', 'dd-mm-yyyy'), 5, 7232, to_date('14-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919006450, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 12, 9723, to_date('30-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091118006451, to_date('18-11-2009', 'dd-mm-yyyy'), to_date('02-12-2009', 'dd-mm-yyyy'), 4, 6661, to_date('06-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010222006452, to_date('22-02-2001', 'dd-mm-yyyy'), to_date('08-03-2001', 'dd-mm-yyyy'), 10, 2553, to_date('26-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219006453, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 9, 2725, to_date('29-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070102006454, to_date('02-01-2007', 'dd-mm-yyyy'), to_date('16-01-2007', 'dd-mm-yyyy'), 3, 7183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100422006455, to_date('22-04-2010', 'dd-mm-yyyy'), to_date('06-05-2010', 'dd-mm-yyyy'), 10, 8955, to_date('23-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021203006456, to_date('03-12-2002', 'dd-mm-yyyy'), to_date('17-12-2002', 'dd-mm-yyyy'), 5, 3041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120203006457, to_date('03-02-2012', 'dd-mm-yyyy'), to_date('17-02-2012', 'dd-mm-yyyy'), 7, 7037, to_date('09-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030412006458, to_date('12-04-2003', 'dd-mm-yyyy'), to_date('26-04-2003', 'dd-mm-yyyy'), 4, 4666, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100130006459, to_date('30-01-2010', 'dd-mm-yyyy'), to_date('13-02-2010', 'dd-mm-yyyy'), 3, 8940, to_date('15-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010711006460, to_date('11-07-2001', 'dd-mm-yyyy'), to_date('25-07-2001', 'dd-mm-yyyy'), 8, 1454, to_date('22-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111203006461, to_date('03-12-2011', 'dd-mm-yyyy'), to_date('17-12-2011', 'dd-mm-yyyy'), 7, 9568, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606006462, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 11, 2934, to_date('18-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110204006463, to_date('04-02-2011', 'dd-mm-yyyy'), to_date('18-02-2011', 'dd-mm-yyyy'), 8, 9600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120427006464, to_date('27-04-2012', 'dd-mm-yyyy'), to_date('11-05-2012', 'dd-mm-yyyy'), 4, 8581, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041006006465, to_date('06-10-2004', 'dd-mm-yyyy'), to_date('20-10-2004', 'dd-mm-yyyy'), 3, 3506, to_date('18-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050520006466, to_date('20-05-2005', 'dd-mm-yyyy'), to_date('03-06-2005', 'dd-mm-yyyy'), 4, 3601, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420006467, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 8, 4125, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001007006468, to_date('07-10-2000', 'dd-mm-yyyy'), to_date('21-10-2000', 'dd-mm-yyyy'), 4, 1916, to_date('26-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218006469, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 4, 9823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021222006470, to_date('22-12-2002', 'dd-mm-yyyy'), to_date('05-01-2003', 'dd-mm-yyyy'), 4, 3258, to_date('29-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110318006471, to_date('18-03-2011', 'dd-mm-yyyy'), to_date('01-04-2011', 'dd-mm-yyyy'), 11, 6555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408006472, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 7, 1819, to_date('18-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106006473, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 5, 6602, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101230006474, to_date('30-12-2010', 'dd-mm-yyyy'), to_date('13-01-2011', 'dd-mm-yyyy'), 7, 8798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120204006475, to_date('04-02-2012', 'dd-mm-yyyy'), to_date('18-02-2012', 'dd-mm-yyyy'), 10, 6711, to_date('19-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010104006476, to_date('04-01-2001', 'dd-mm-yyyy'), to_date('18-01-2001', 'dd-mm-yyyy'), 6, 3388, to_date('15-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825006477, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 5, 1044, to_date('12-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603006478, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 10, 1746, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060104006479, to_date('04-01-2006', 'dd-mm-yyyy'), to_date('18-01-2006', 'dd-mm-yyyy'), 8, 5302, to_date('15-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817006480, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 3, 10816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127006481, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 6, 6675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040128006482, to_date('28-01-2004', 'dd-mm-yyyy'), to_date('11-02-2004', 'dd-mm-yyyy'), 4, 5563, to_date('13-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323006483, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 9, 8601, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120225006484, to_date('25-02-2012', 'dd-mm-yyyy'), to_date('10-03-2012', 'dd-mm-yyyy'), 10, 10042, to_date('09-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060703006485, to_date('03-07-2006', 'dd-mm-yyyy'), to_date('17-07-2006', 'dd-mm-yyyy'), 11, 3896, to_date('05-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111203006486, to_date('03-12-2011', 'dd-mm-yyyy'), to_date('17-12-2011', 'dd-mm-yyyy'), 9, 7454, to_date('14-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731006487, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 5, 6727, to_date('10-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802006488, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 9, 7705, to_date('04-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020515006489, to_date('15-05-2002', 'dd-mm-yyyy'), to_date('29-05-2002', 'dd-mm-yyyy'), 5, 3187, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030322006490, to_date('22-03-2003', 'dd-mm-yyyy'), to_date('05-04-2003', 'dd-mm-yyyy'), 3, 3591, to_date('09-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130209006491, to_date('09-02-2013', 'dd-mm-yyyy'), to_date('23-02-2013', 'dd-mm-yyyy'), 5, 6304, to_date('26-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110319006492, to_date('19-03-2011', 'dd-mm-yyyy'), to_date('02-04-2011', 'dd-mm-yyyy'), 12, 7391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040625006493, to_date('25-06-2004', 'dd-mm-yyyy'), to_date('09-07-2004', 'dd-mm-yyyy'), 11, 2695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060105006494, to_date('05-01-2006', 'dd-mm-yyyy'), to_date('19-01-2006', 'dd-mm-yyyy'), 9, 5492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120821006495, to_date('21-08-2012', 'dd-mm-yyyy'), to_date('04-09-2012', 'dd-mm-yyyy'), 9, 8310, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130806006496, to_date('06-08-2013', 'dd-mm-yyyy'), to_date('20-08-2013', 'dd-mm-yyyy'), 2, 9174, to_date('26-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613006497, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 8, 2573, to_date('26-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040212006498, to_date('12-02-2004', 'dd-mm-yyyy'), to_date('26-02-2004', 'dd-mm-yyyy'), 4, 3520, to_date('14-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050625006499, to_date('25-06-2005', 'dd-mm-yyyy'), to_date('09-07-2005', 'dd-mm-yyyy'), 10, 3688, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120412006500, to_date('12-04-2012', 'dd-mm-yyyy'), to_date('26-04-2012', 'dd-mm-yyyy'), 8, 6298, to_date('21-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031120006501, to_date('20-11-2003', 'dd-mm-yyyy'), to_date('04-12-2003', 'dd-mm-yyyy'), 3, 2892, to_date('28-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000918006502, to_date('18-09-2000', 'dd-mm-yyyy'), to_date('02-10-2000', 'dd-mm-yyyy'), 9, 3000, to_date('24-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328006503, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 8, 6666, to_date('29-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001021006504, to_date('21-10-2000', 'dd-mm-yyyy'), to_date('04-11-2000', 'dd-mm-yyyy'), 8, 762, to_date('25-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000909006505, to_date('09-09-2000', 'dd-mm-yyyy'), to_date('23-09-2000', 'dd-mm-yyyy'), 6, 1676, to_date('15-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725006506, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 2, 6874, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000207006507, to_date('07-02-2000', 'dd-mm-yyyy'), to_date('21-02-2000', 'dd-mm-yyyy'), 7, 2235, to_date('21-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090616006508, to_date('16-06-2009', 'dd-mm-yyyy'), to_date('30-06-2009', 'dd-mm-yyyy'), 5, 8580, to_date('21-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120911006509, to_date('11-09-2012', 'dd-mm-yyyy'), to_date('25-09-2012', 'dd-mm-yyyy'), 9, 7855, to_date('16-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926006510, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 8, 9642, to_date('02-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101006511, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 11, 1880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091127006512, to_date('27-11-2009', 'dd-mm-yyyy'), to_date('11-12-2009', 'dd-mm-yyyy'), 4, 6023, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031130006513, to_date('30-11-2003', 'dd-mm-yyyy'), to_date('14-12-2003', 'dd-mm-yyyy'), 5, 4863, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110308006514, to_date('08-03-2011', 'dd-mm-yyyy'), to_date('22-03-2011', 'dd-mm-yyyy'), 2, 7413, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416006515, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 10, 3630, to_date('28-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040502006516, to_date('02-05-2004', 'dd-mm-yyyy'), to_date('16-05-2004', 'dd-mm-yyyy'), 9, 4041, to_date('17-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060121006517, to_date('21-01-2006', 'dd-mm-yyyy'), to_date('04-02-2006', 'dd-mm-yyyy'), 5, 4606, to_date('25-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051026006518, to_date('26-10-2005', 'dd-mm-yyyy'), to_date('09-11-2005', 'dd-mm-yyyy'), 2, 4028, to_date('31-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210006519, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 5, 5804, to_date('15-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040501006520, to_date('01-05-2004', 'dd-mm-yyyy'), to_date('15-05-2004', 'dd-mm-yyyy'), 7, 7414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120504006521, to_date('04-05-2012', 'dd-mm-yyyy'), to_date('18-05-2012', 'dd-mm-yyyy'), 8, 8761, to_date('22-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107006522, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 4, 5011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123006523, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 8, 1956, to_date('05-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060116006524, to_date('16-01-2006', 'dd-mm-yyyy'), to_date('30-01-2006', 'dd-mm-yyyy'), 10, 5595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060822006525, to_date('22-08-2006', 'dd-mm-yyyy'), to_date('05-09-2006', 'dd-mm-yyyy'), 2, 4884, to_date('08-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040625006526, to_date('25-06-2004', 'dd-mm-yyyy'), to_date('09-07-2004', 'dd-mm-yyyy'), 2, 2592, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000716006527, to_date('16-07-2000', 'dd-mm-yyyy'), to_date('30-07-2000', 'dd-mm-yyyy'), 5, 870, to_date('30-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140109006528, to_date('09-01-2014', 'dd-mm-yyyy'), to_date('23-01-2014', 'dd-mm-yyyy'), 9, 9374, to_date('13-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070126006529, to_date('26-01-2007', 'dd-mm-yyyy'), to_date('09-02-2007', 'dd-mm-yyyy'), 10, 6393, to_date('06-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070522006530, to_date('22-05-2007', 'dd-mm-yyyy'), to_date('05-06-2007', 'dd-mm-yyyy'), 10, 4839, to_date('29-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030922006531, to_date('22-09-2003', 'dd-mm-yyyy'), to_date('06-10-2003', 'dd-mm-yyyy'), 11, 3647, to_date('10-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080928006532, to_date('28-09-2008', 'dd-mm-yyyy'), to_date('12-10-2008', 'dd-mm-yyyy'), 2, 6228, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040817006533, to_date('17-08-2004', 'dd-mm-yyyy'), to_date('31-08-2004', 'dd-mm-yyyy'), 6, 6185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130223006534, to_date('23-02-2013', 'dd-mm-yyyy'), to_date('09-03-2013', 'dd-mm-yyyy'), 5, 8406, to_date('02-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030510006535, to_date('10-05-2003', 'dd-mm-yyyy'), to_date('24-05-2003', 'dd-mm-yyyy'), 6, 4606, to_date('14-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023006536, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 9, 3580, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130006537, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 6, 4270, to_date('08-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922006538, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 4, 7409, to_date('29-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031209006539, to_date('09-12-2003', 'dd-mm-yyyy'), to_date('23-12-2003', 'dd-mm-yyyy'), 9, 1909, to_date('12-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827006540, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 11, 2258, to_date('15-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040229006541, to_date('29-02-2004', 'dd-mm-yyyy'), to_date('14-03-2004', 'dd-mm-yyyy'), 3, 4214, to_date('12-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040403006542, to_date('03-04-2004', 'dd-mm-yyyy'), to_date('17-04-2004', 'dd-mm-yyyy'), 7, 2949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080212006543, to_date('12-02-2008', 'dd-mm-yyyy'), to_date('26-02-2008', 'dd-mm-yyyy'), 5, 10087, to_date('27-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313006544, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 5, 8743, to_date('26-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040729006545, to_date('29-07-2004', 'dd-mm-yyyy'), to_date('12-08-2004', 'dd-mm-yyyy'), 7, 3595, to_date('01-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070423006546, to_date('23-04-2007', 'dd-mm-yyyy'), to_date('07-05-2007', 'dd-mm-yyyy'), 2, 5236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070622006547, to_date('22-06-2007', 'dd-mm-yyyy'), to_date('06-07-2007', 'dd-mm-yyyy'), 4, 4793, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917006548, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 4, 6627, to_date('19-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081120006549, to_date('20-11-2008', 'dd-mm-yyyy'), to_date('04-12-2008', 'dd-mm-yyyy'), 10, 6374, to_date('05-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090726006550, to_date('26-07-2009', 'dd-mm-yyyy'), to_date('09-08-2009', 'dd-mm-yyyy'), 3, 6817, to_date('10-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110516006551, to_date('16-05-2011', 'dd-mm-yyyy'), to_date('30-05-2011', 'dd-mm-yyyy'), 12, 6002, to_date('24-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507006552, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 7, 6282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060824006553, to_date('24-08-2006', 'dd-mm-yyyy'), to_date('07-09-2006', 'dd-mm-yyyy'), 1, 4266, to_date('30-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050310006554, to_date('10-03-2005', 'dd-mm-yyyy'), to_date('24-03-2005', 'dd-mm-yyyy'), 7, 3054, to_date('18-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513006555, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 12, 3010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021127006556, to_date('27-11-2002', 'dd-mm-yyyy'), to_date('11-12-2002', 'dd-mm-yyyy'), 3, 3297, to_date('11-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110227006557, to_date('27-02-2011', 'dd-mm-yyyy'), to_date('13-03-2011', 'dd-mm-yyyy'), 2, 8966, to_date('28-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030615006558, to_date('15-06-2003', 'dd-mm-yyyy'), to_date('29-06-2003', 'dd-mm-yyyy'), 6, 3269, to_date('19-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130204006559, to_date('04-02-2013', 'dd-mm-yyyy'), to_date('18-02-2013', 'dd-mm-yyyy'), 3, 6256, to_date('20-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120113006560, to_date('13-01-2012', 'dd-mm-yyyy'), to_date('27-01-2012', 'dd-mm-yyyy'), 4, 5416, to_date('31-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050914006561, to_date('14-09-2005', 'dd-mm-yyyy'), to_date('28-09-2005', 'dd-mm-yyyy'), 8, 4617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090110006562, to_date('10-01-2009', 'dd-mm-yyyy'), to_date('24-01-2009', 'dd-mm-yyyy'), 9, 5783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080325006563, to_date('25-03-2008', 'dd-mm-yyyy'), to_date('08-04-2008', 'dd-mm-yyyy'), 11, 7265, to_date('28-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824006564, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 4, 3973, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103006565, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 6, 6007, to_date('09-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301006566, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 9, 4220, to_date('17-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021121006567, to_date('21-11-2002', 'dd-mm-yyyy'), to_date('05-12-2002', 'dd-mm-yyyy'), 6, 4363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011206006568, to_date('06-12-2001', 'dd-mm-yyyy'), to_date('20-12-2001', 'dd-mm-yyyy'), 6, 2866, to_date('24-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110006569, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 3, 4014, to_date('23-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130906006570, to_date('06-09-2013', 'dd-mm-yyyy'), to_date('20-09-2013', 'dd-mm-yyyy'), 1, 8512, to_date('19-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140422006571, to_date('22-04-2014', 'dd-mm-yyyy'), to_date('06-05-2014', 'dd-mm-yyyy'), 3, 10157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020414006572, to_date('14-04-2002', 'dd-mm-yyyy'), to_date('28-04-2002', 'dd-mm-yyyy'), 4, 3102, to_date('18-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061231006573, to_date('31-12-2006', 'dd-mm-yyyy'), to_date('14-01-2007', 'dd-mm-yyyy'), 6, 5504, to_date('14-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090527006574, to_date('27-05-2009', 'dd-mm-yyyy'), to_date('10-06-2009', 'dd-mm-yyyy'), 1, 6789, to_date('03-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100723006575, to_date('23-07-2010', 'dd-mm-yyyy'), to_date('06-08-2010', 'dd-mm-yyyy'), 10, 7073, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011111006576, to_date('11-11-2001', 'dd-mm-yyyy'), to_date('25-11-2001', 'dd-mm-yyyy'), 5, 1465, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040802006577, to_date('02-08-2004', 'dd-mm-yyyy'), to_date('16-08-2004', 'dd-mm-yyyy'), 2, 4267, to_date('14-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423006578, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 3, 7922, to_date('04-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529006579, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 6, 3905, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040808006580, to_date('08-08-2004', 'dd-mm-yyyy'), to_date('22-08-2004', 'dd-mm-yyyy'), 8, 6223, to_date('17-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414006581, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 6, 6069, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924008264, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 6, 7982, to_date('10-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010728008265, to_date('28-07-2001', 'dd-mm-yyyy'), to_date('11-08-2001', 'dd-mm-yyyy'), 6, 2987, to_date('16-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051224008266, to_date('24-12-2005', 'dd-mm-yyyy'), to_date('07-01-2006', 'dd-mm-yyyy'), 12, 6422, to_date('02-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108008267, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 7, 2093, to_date('18-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726008268, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 8, 2516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503008269, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 5, 7117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041213008270, to_date('13-12-2004', 'dd-mm-yyyy'), to_date('27-12-2004', 'dd-mm-yyyy'), 10, 3631, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081210008271, to_date('10-12-2008', 'dd-mm-yyyy'), to_date('24-12-2008', 'dd-mm-yyyy'), 9, 7024, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021124008272, to_date('24-11-2002', 'dd-mm-yyyy'), to_date('08-12-2002', 'dd-mm-yyyy'), 4, 3153, to_date('04-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401008273, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 3, 6400, to_date('20-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205008274, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 4, 4832, to_date('13-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020516008275, to_date('16-05-2002', 'dd-mm-yyyy'), to_date('30-05-2002', 'dd-mm-yyyy'), 6, 1739, to_date('26-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100507008276, to_date('07-05-2010', 'dd-mm-yyyy'), to_date('21-05-2010', 'dd-mm-yyyy'), 10, 5614, to_date('11-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010405008277, to_date('05-04-2001', 'dd-mm-yyyy'), to_date('19-04-2001', 'dd-mm-yyyy'), 1, 2615, to_date('24-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021019008278, to_date('19-10-2002', 'dd-mm-yyyy'), to_date('02-11-2002', 'dd-mm-yyyy'), 8, 3459, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090627008279, to_date('27-06-2009', 'dd-mm-yyyy'), to_date('11-07-2009', 'dd-mm-yyyy'), 6, 6015, to_date('29-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080510008280, to_date('10-05-2008', 'dd-mm-yyyy'), to_date('24-05-2008', 'dd-mm-yyyy'), 9, 5545, to_date('19-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130929008281, to_date('29-09-2013', 'dd-mm-yyyy'), to_date('13-10-2013', 'dd-mm-yyyy'), 6, 10115, to_date('06-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000122008282, to_date('22-01-2000', 'dd-mm-yyyy'), to_date('05-02-2000', 'dd-mm-yyyy'), 10, 1534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050725008283, to_date('25-07-2005', 'dd-mm-yyyy'), to_date('08-08-2005', 'dd-mm-yyyy'), 5, 7513, to_date('26-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090516008284, to_date('16-05-2009', 'dd-mm-yyyy'), to_date('30-05-2009', 'dd-mm-yyyy'), 8, 6507, to_date('24-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226008285, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 10, 1864, to_date('12-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101217008286, to_date('17-12-2010', 'dd-mm-yyyy'), to_date('31-12-2010', 'dd-mm-yyyy'), 2, 6584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061028008287, to_date('28-10-2006', 'dd-mm-yyyy'), to_date('11-11-2006', 'dd-mm-yyyy'), 2, 5866, to_date('13-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060311008288, to_date('11-03-2006', 'dd-mm-yyyy'), to_date('25-03-2006', 'dd-mm-yyyy'), 10, 6071, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117008289, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 12, 11497, to_date('26-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130008290, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 4, 4274, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010924008291, to_date('24-09-2001', 'dd-mm-yyyy'), to_date('08-10-2001', 'dd-mm-yyyy'), 12, 2612, to_date('07-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423008292, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 6, 2297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130118008293, to_date('18-01-2013', 'dd-mm-yyyy'), to_date('01-02-2013', 'dd-mm-yyyy'), 7, 8427, to_date('26-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111216008294, to_date('16-12-2011', 'dd-mm-yyyy'), to_date('30-12-2011', 'dd-mm-yyyy'), 5, 8767, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130405008295, to_date('05-04-2013', 'dd-mm-yyyy'), to_date('19-04-2013', 'dd-mm-yyyy'), 2, 8700, to_date('18-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010928008296, to_date('28-09-2001', 'dd-mm-yyyy'), to_date('12-10-2001', 'dd-mm-yyyy'), 10, 2444, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041005008297, to_date('05-10-2004', 'dd-mm-yyyy'), to_date('19-10-2004', 'dd-mm-yyyy'), 6, 4933, to_date('13-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100416008298, to_date('16-04-2010', 'dd-mm-yyyy'), to_date('30-04-2010', 'dd-mm-yyyy'), 8, 5776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040803008299, to_date('03-08-2004', 'dd-mm-yyyy'), to_date('17-08-2004', 'dd-mm-yyyy'), 11, 5961, to_date('15-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130218008300, to_date('18-02-2013', 'dd-mm-yyyy'), to_date('04-03-2013', 'dd-mm-yyyy'), 9, 9783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060729008301, to_date('29-07-2006', 'dd-mm-yyyy'), to_date('12-08-2006', 'dd-mm-yyyy'), 7, 4745, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131008302, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 5, 5692, to_date('19-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101106008303, to_date('06-11-2010', 'dd-mm-yyyy'), to_date('20-11-2010', 'dd-mm-yyyy'), 10, 5960, to_date('20-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030111008304, to_date('11-01-2003', 'dd-mm-yyyy'), to_date('25-01-2003', 'dd-mm-yyyy'), 9, 1928, to_date('12-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040809008305, to_date('09-08-2004', 'dd-mm-yyyy'), to_date('23-08-2004', 'dd-mm-yyyy'), 9, 3276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813008306, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 7, 7466, to_date('20-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625008307, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 8, 3355, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021012008308, to_date('12-10-2002', 'dd-mm-yyyy'), to_date('26-10-2002', 'dd-mm-yyyy'), 11, 3020, to_date('27-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091024008309, to_date('24-10-2009', 'dd-mm-yyyy'), to_date('07-11-2009', 'dd-mm-yyyy'), 5, 6623, to_date('07-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140425008310, to_date('25-04-2014', 'dd-mm-yyyy'), to_date('09-05-2014', 'dd-mm-yyyy'), 4, 10788, to_date('30-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802008311, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 11, 1764, to_date('20-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140328008312, to_date('28-03-2014', 'dd-mm-yyyy'), to_date('11-04-2014', 'dd-mm-yyyy'), 8, 9342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104008313, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 12, 6974, to_date('12-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618008314, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 9, 6899, to_date('30-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126008315, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 6, 7952, to_date('03-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509008316, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 2, 6630, to_date('20-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010203008317, to_date('03-02-2001', 'dd-mm-yyyy'), to_date('17-02-2001', 'dd-mm-yyyy'), 10, 4508, to_date('11-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130409008318, to_date('09-04-2013', 'dd-mm-yyyy'), to_date('23-04-2013', 'dd-mm-yyyy'), 7, 8410, to_date('23-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529008319, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 5, 5783, to_date('12-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416008320, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 7, 4129, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100227008321, to_date('27-02-2010', 'dd-mm-yyyy'), to_date('13-03-2010', 'dd-mm-yyyy'), 5, 7487, to_date('10-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020127008322, to_date('27-01-2002', 'dd-mm-yyyy'), to_date('10-02-2002', 'dd-mm-yyyy'), 2, 2755, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100823008323, to_date('23-08-2010', 'dd-mm-yyyy'), to_date('06-09-2010', 'dd-mm-yyyy'), 11, 5035, to_date('04-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051024008324, to_date('24-10-2005', 'dd-mm-yyyy'), to_date('07-11-2005', 'dd-mm-yyyy'), 9, 3094, to_date('06-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050421008325, to_date('21-04-2005', 'dd-mm-yyyy'), to_date('05-05-2005', 'dd-mm-yyyy'), 3, 3217, to_date('28-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110719008326, to_date('19-07-2011', 'dd-mm-yyyy'), to_date('02-08-2011', 'dd-mm-yyyy'), 5, 6576, to_date('27-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110912008327, to_date('12-09-2011', 'dd-mm-yyyy'), to_date('26-09-2011', 'dd-mm-yyyy'), 7, 7700, to_date('28-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000924008328, to_date('24-09-2000', 'dd-mm-yyyy'), to_date('08-10-2000', 'dd-mm-yyyy'), 5, 2326, to_date('03-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328008329, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 5, 2822, to_date('07-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100729008330, to_date('29-07-2010', 'dd-mm-yyyy'), to_date('12-08-2010', 'dd-mm-yyyy'), 8, 7090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070228008331, to_date('28-02-2007', 'dd-mm-yyyy'), to_date('14-03-2007', 'dd-mm-yyyy'), 1, 5311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120110008332, to_date('10-01-2012', 'dd-mm-yyyy'), to_date('24-01-2012', 'dd-mm-yyyy'), 3, 9411, to_date('26-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110912008333, to_date('12-09-2011', 'dd-mm-yyyy'), to_date('26-09-2011', 'dd-mm-yyyy'), 10, 7443, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020606008334, to_date('06-06-2002', 'dd-mm-yyyy'), to_date('20-06-2002', 'dd-mm-yyyy'), 10, 1833, to_date('14-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030904008335, to_date('04-09-2003', 'dd-mm-yyyy'), to_date('18-09-2003', 'dd-mm-yyyy'), 6, 3145, to_date('10-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050519008336, to_date('19-05-2005', 'dd-mm-yyyy'), to_date('02-06-2005', 'dd-mm-yyyy'), 5, 4153, to_date('29-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207008337, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 4, 6348, to_date('19-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120514008338, to_date('14-05-2012', 'dd-mm-yyyy'), to_date('28-05-2012', 'dd-mm-yyyy'), 11, 7184, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601008339, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 5, 8208, to_date('07-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030325008340, to_date('25-03-2003', 'dd-mm-yyyy'), to_date('08-04-2003', 'dd-mm-yyyy'), 5, 3011, to_date('02-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020421008341, to_date('21-04-2002', 'dd-mm-yyyy'), to_date('05-05-2002', 'dd-mm-yyyy'), 12, 1063, to_date('10-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050721008342, to_date('21-07-2005', 'dd-mm-yyyy'), to_date('04-08-2005', 'dd-mm-yyyy'), 9, 5660, to_date('31-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010405008343, to_date('05-04-2001', 'dd-mm-yyyy'), to_date('19-04-2001', 'dd-mm-yyyy'), 6, 2215, to_date('23-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081115008344, to_date('15-11-2008', 'dd-mm-yyyy'), to_date('29-11-2008', 'dd-mm-yyyy'), 10, 4698, to_date('28-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130810008345, to_date('10-08-2013', 'dd-mm-yyyy'), to_date('24-08-2013', 'dd-mm-yyyy'), 7, 8214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110503008346, to_date('03-05-2011', 'dd-mm-yyyy'), to_date('17-05-2011', 'dd-mm-yyyy'), 5, 6985, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128008347, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 1, 8439, to_date('02-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080719008348, to_date('19-07-2008', 'dd-mm-yyyy'), to_date('02-08-2008', 'dd-mm-yyyy'), 9, 6715, to_date('31-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070314008349, to_date('14-03-2007', 'dd-mm-yyyy'), to_date('28-03-2007', 'dd-mm-yyyy'), 6, 5899, to_date('27-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403008350, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 9, 6240, to_date('16-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022008351, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 4, 4867, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120707008352, to_date('07-07-2012', 'dd-mm-yyyy'), to_date('21-07-2012', 'dd-mm-yyyy'), 5, 8172, to_date('11-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723008353, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 10, 3706, to_date('04-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021203008354, to_date('03-12-2002', 'dd-mm-yyyy'), to_date('17-12-2002', 'dd-mm-yyyy'), 7, 1526, to_date('18-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018008355, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 3, 576, to_date('03-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030428008356, to_date('28-04-2003', 'dd-mm-yyyy'), to_date('12-05-2003', 'dd-mm-yyyy'), 2, 3818, to_date('06-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410008357, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 9, 4979, to_date('22-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209008358, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 7, 3162, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020410008359, to_date('10-04-2002', 'dd-mm-yyyy'), to_date('24-04-2002', 'dd-mm-yyyy'), 4, 1061, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070603008360, to_date('03-06-2007', 'dd-mm-yyyy'), to_date('17-06-2007', 'dd-mm-yyyy'), 11, 6057, to_date('05-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030128008361, to_date('28-01-2003', 'dd-mm-yyyy'), to_date('11-02-2003', 'dd-mm-yyyy'), 9, 2323, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110508008362, to_date('08-05-2011', 'dd-mm-yyyy'), to_date('22-05-2011', 'dd-mm-yyyy'), 12, 8109, to_date('22-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060523008363, to_date('23-05-2006', 'dd-mm-yyyy'), to_date('06-06-2006', 'dd-mm-yyyy'), 5, 5000, to_date('29-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030721008364, to_date('21-07-2003', 'dd-mm-yyyy'), to_date('04-08-2003', 'dd-mm-yyyy'), 4, 2172, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000108008365, to_date('08-01-2000', 'dd-mm-yyyy'), to_date('22-01-2000', 'dd-mm-yyyy'), 7, 3175, to_date('26-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021006008366, to_date('06-10-2002', 'dd-mm-yyyy'), to_date('20-10-2002', 'dd-mm-yyyy'), 8, 2619, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130505008367, to_date('05-05-2013', 'dd-mm-yyyy'), to_date('19-05-2013', 'dd-mm-yyyy'), 8, 10525, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000422008368, to_date('22-04-2000', 'dd-mm-yyyy'), to_date('06-05-2000', 'dd-mm-yyyy'), 5, 748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070210008369, to_date('10-02-2007', 'dd-mm-yyyy'), to_date('24-02-2007', 'dd-mm-yyyy'), 7, 6724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602008370, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 6, 5094, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130917008371, to_date('17-09-2013', 'dd-mm-yyyy'), to_date('01-10-2013', 'dd-mm-yyyy'), 7, 8942, to_date('25-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030506008372, to_date('06-05-2003', 'dd-mm-yyyy'), to_date('20-05-2003', 'dd-mm-yyyy'), 10, 6260, to_date('08-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031030008373, to_date('30-10-2003', 'dd-mm-yyyy'), to_date('13-11-2003', 'dd-mm-yyyy'), 9, 5511, to_date('03-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131223008374, to_date('23-12-2013', 'dd-mm-yyyy'), to_date('06-01-2014', 'dd-mm-yyyy'), 12, 8592, to_date('10-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131201008375, to_date('01-12-2013', 'dd-mm-yyyy'), to_date('15-12-2013', 'dd-mm-yyyy'), 3, 8172, to_date('18-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402008376, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 11, 2957, to_date('09-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906008377, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 5, 7110, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010709008378, to_date('09-07-2001', 'dd-mm-yyyy'), to_date('23-07-2001', 'dd-mm-yyyy'), 12, 3378, to_date('28-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918008379, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 11, 4703, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130614008380, to_date('14-06-2013', 'dd-mm-yyyy'), to_date('28-06-2013', 'dd-mm-yyyy'), 3, 8413, to_date('23-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100901008381, to_date('01-09-2010', 'dd-mm-yyyy'), to_date('15-09-2010', 'dd-mm-yyyy'), 2, 6972, to_date('08-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040918008382, to_date('18-09-2004', 'dd-mm-yyyy'), to_date('02-10-2004', 'dd-mm-yyyy'), 5, 4165, to_date('21-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060408008383, to_date('08-04-2006', 'dd-mm-yyyy'), to_date('22-04-2006', 'dd-mm-yyyy'), 2, 6826, to_date('10-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110314008384, to_date('14-03-2011', 'dd-mm-yyyy'), to_date('28-03-2011', 'dd-mm-yyyy'), 2, 6666, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091119008385, to_date('19-11-2009', 'dd-mm-yyyy'), to_date('03-12-2009', 'dd-mm-yyyy'), 3, 5967, to_date('26-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100420008386, to_date('20-04-2010', 'dd-mm-yyyy'), to_date('04-05-2010', 'dd-mm-yyyy'), 3, 7792, to_date('10-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050228008387, to_date('28-02-2005', 'dd-mm-yyyy'), to_date('14-03-2005', 'dd-mm-yyyy'), 4, 5100, to_date('17-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040314008388, to_date('14-03-2004', 'dd-mm-yyyy'), to_date('28-03-2004', 'dd-mm-yyyy'), 3, 2646, to_date('02-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011212008389, to_date('12-12-2001', 'dd-mm-yyyy'), to_date('26-12-2001', 'dd-mm-yyyy'), 3, 3031, to_date('14-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030124008390, to_date('24-01-2003', 'dd-mm-yyyy'), to_date('07-02-2003', 'dd-mm-yyyy'), 10, 4099, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000128008391, to_date('28-01-2000', 'dd-mm-yyyy'), to_date('11-02-2000', 'dd-mm-yyyy'), 4, 1364, to_date('10-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000701008392, to_date('01-07-2000', 'dd-mm-yyyy'), to_date('15-07-2000', 'dd-mm-yyyy'), 7, 2850, to_date('04-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090205008393, to_date('05-02-2009', 'dd-mm-yyyy'), to_date('19-02-2009', 'dd-mm-yyyy'), 6, 6398, to_date('06-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120208008394, to_date('08-02-2012', 'dd-mm-yyyy'), to_date('22-02-2012', 'dd-mm-yyyy'), 9, 6524, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070330008395, to_date('30-03-2007', 'dd-mm-yyyy'), to_date('13-04-2007', 'dd-mm-yyyy'), 3, 5964, to_date('15-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061013008396, to_date('13-10-2006', 'dd-mm-yyyy'), to_date('27-10-2006', 'dd-mm-yyyy'), 12, 5857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070729008397, to_date('29-07-2007', 'dd-mm-yyyy'), to_date('12-08-2007', 'dd-mm-yyyy'), 3, 8220, to_date('16-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010323008398, to_date('23-03-2001', 'dd-mm-yyyy'), to_date('06-04-2001', 'dd-mm-yyyy'), 7, 2673, to_date('04-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021126008399, to_date('26-11-2002', 'dd-mm-yyyy'), to_date('10-12-2002', 'dd-mm-yyyy'), 10, 1603, to_date('05-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070528008400, to_date('28-05-2007', 'dd-mm-yyyy'), to_date('11-06-2007', 'dd-mm-yyyy'), 8, 4758, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090919008401, to_date('19-09-2009', 'dd-mm-yyyy'), to_date('03-10-2009', 'dd-mm-yyyy'), 6, 6566, to_date('26-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713008402, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 3, 9176, to_date('01-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080905008403, to_date('05-09-2008', 'dd-mm-yyyy'), to_date('19-09-2008', 'dd-mm-yyyy'), 6, 5695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121127008404, to_date('27-11-2012', 'dd-mm-yyyy'), to_date('11-12-2012', 'dd-mm-yyyy'), 8, 10867, to_date('28-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220008405, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 8, 6972, to_date('05-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725008406, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 3, 8094, to_date('30-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060317008407, to_date('17-03-2006', 'dd-mm-yyyy'), to_date('31-03-2006', 'dd-mm-yyyy'), 5, 5004, to_date('27-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030604008408, to_date('04-06-2003', 'dd-mm-yyyy'), to_date('18-06-2003', 'dd-mm-yyyy'), 4, 3040, to_date('05-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020209008409, to_date('09-02-2002', 'dd-mm-yyyy'), to_date('23-02-2002', 'dd-mm-yyyy'), 10, 2107, to_date('15-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041204008410, to_date('04-12-2004', 'dd-mm-yyyy'), to_date('18-12-2004', 'dd-mm-yyyy'), 6, 4425, to_date('23-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020805008411, to_date('05-08-2002', 'dd-mm-yyyy'), to_date('19-08-2002', 'dd-mm-yyyy'), 10, 3318, to_date('19-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070713008412, to_date('13-07-2007', 'dd-mm-yyyy'), to_date('27-07-2007', 'dd-mm-yyyy'), 12, 6372, to_date('01-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120825008413, to_date('25-08-2012', 'dd-mm-yyyy'), to_date('08-09-2012', 'dd-mm-yyyy'), 4, 9436, to_date('31-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130520008414, to_date('20-05-2013', 'dd-mm-yyyy'), to_date('03-06-2013', 'dd-mm-yyyy'), 3, 9905, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060430008415, to_date('30-04-2006', 'dd-mm-yyyy'), to_date('14-05-2006', 'dd-mm-yyyy'), 2, 3347, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080722001836, to_date('22-07-2008', 'dd-mm-yyyy'), to_date('05-08-2008', 'dd-mm-yyyy'), 6, 5313, to_date('25-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031011001837, to_date('11-10-2003', 'dd-mm-yyyy'), to_date('25-10-2003', 'dd-mm-yyyy'), 7, 3617, to_date('22-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031220001838, to_date('20-12-2003', 'dd-mm-yyyy'), to_date('03-01-2004', 'dd-mm-yyyy'), 3, 5204, to_date('26-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222001839, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 5, 1947, to_date('25-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513001840, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 11, 4125, to_date('21-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080705001841, to_date('05-07-2008', 'dd-mm-yyyy'), to_date('19-07-2008', 'dd-mm-yyyy'), 2, 5524, to_date('13-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021022001842, to_date('22-10-2002', 'dd-mm-yyyy'), to_date('05-11-2002', 'dd-mm-yyyy'), 11, 3348, to_date('29-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040403001843, to_date('03-04-2004', 'dd-mm-yyyy'), to_date('17-04-2004', 'dd-mm-yyyy'), 6, 3707, to_date('13-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081105001844, to_date('05-11-2008', 'dd-mm-yyyy'), to_date('19-11-2008', 'dd-mm-yyyy'), 8, 6888, to_date('08-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222001845, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 5, 1414, to_date('30-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051029001846, to_date('29-10-2005', 'dd-mm-yyyy'), to_date('12-11-2005', 'dd-mm-yyyy'), 4, 8441, to_date('06-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000207001847, to_date('07-02-2000', 'dd-mm-yyyy'), to_date('21-02-2000', 'dd-mm-yyyy'), 4, 337, to_date('22-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060312001848, to_date('12-03-2006', 'dd-mm-yyyy'), to_date('26-03-2006', 'dd-mm-yyyy'), 5, 4387, to_date('30-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070405001849, to_date('05-04-2007', 'dd-mm-yyyy'), to_date('19-04-2007', 'dd-mm-yyyy'), 6, 4119, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030406001850, to_date('06-04-2003', 'dd-mm-yyyy'), to_date('20-04-2003', 'dd-mm-yyyy'), 11, 2491, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706001851, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 4, 1183, to_date('12-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070530001852, to_date('30-05-2007', 'dd-mm-yyyy'), to_date('13-06-2007', 'dd-mm-yyyy'), 2, 5887, to_date('05-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515001853, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 2, 1557, to_date('27-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041213001854, to_date('13-12-2004', 'dd-mm-yyyy'), to_date('27-12-2004', 'dd-mm-yyyy'), 10, 4155, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507001855, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 7, 10087, to_date('18-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050414001856, to_date('14-04-2005', 'dd-mm-yyyy'), to_date('28-04-2005', 'dd-mm-yyyy'), 2, 3526, to_date('27-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110131001857, to_date('31-01-2011', 'dd-mm-yyyy'), to_date('14-02-2011', 'dd-mm-yyyy'), 5, 7835, to_date('12-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120709001858, to_date('09-07-2012', 'dd-mm-yyyy'), to_date('23-07-2012', 'dd-mm-yyyy'), 7, 7819, to_date('12-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408001859, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 5, 5278, to_date('24-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070126001860, to_date('26-01-2007', 'dd-mm-yyyy'), to_date('09-02-2007', 'dd-mm-yyyy'), 2, 5989, to_date('11-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100413001861, to_date('13-04-2010', 'dd-mm-yyyy'), to_date('27-04-2010', 'dd-mm-yyyy'), 9, 5450, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227001862, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 5, 10207, to_date('29-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080831001863, to_date('31-08-2008', 'dd-mm-yyyy'), to_date('14-09-2008', 'dd-mm-yyyy'), 3, 7028, to_date('02-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050125001864, to_date('25-01-2005', 'dd-mm-yyyy'), to_date('08-02-2005', 'dd-mm-yyyy'), 5, 4825, to_date('06-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203001865, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 7, 4112, to_date('09-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217001866, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 5, 11516, to_date('02-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010611001867, to_date('11-06-2001', 'dd-mm-yyyy'), to_date('25-06-2001', 'dd-mm-yyyy'), 2, 2569, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100818001868, to_date('18-08-2010', 'dd-mm-yyyy'), to_date('01-09-2010', 'dd-mm-yyyy'), 2, 8597, to_date('26-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111001869, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 5, 6558, to_date('17-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306001870, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 10, 3065, to_date('26-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090827001871, to_date('27-08-2009', 'dd-mm-yyyy'), to_date('10-09-2009', 'dd-mm-yyyy'), 11, 8612, to_date('10-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020905001872, to_date('05-09-2002', 'dd-mm-yyyy'), to_date('19-09-2002', 'dd-mm-yyyy'), 4, 3290, to_date('23-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803001873, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 6, 9065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204001874, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 7, 4448, to_date('20-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010815001875, to_date('15-08-2001', 'dd-mm-yyyy'), to_date('29-08-2001', 'dd-mm-yyyy'), 2, 2776, to_date('28-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010113001876, to_date('13-01-2001', 'dd-mm-yyyy'), to_date('27-01-2001', 'dd-mm-yyyy'), 2, 2740, to_date('18-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031001877, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 9, 1694, to_date('13-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030717001878, to_date('17-07-2003', 'dd-mm-yyyy'), to_date('31-07-2003', 'dd-mm-yyyy'), 6, 2198, to_date('02-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001201001879, to_date('01-12-2000', 'dd-mm-yyyy'), to_date('15-12-2000', 'dd-mm-yyyy'), 4, 2187, to_date('13-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021001880, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 1, 6262, to_date('25-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713001881, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 3, 4705, to_date('30-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021001882, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 7, 2877, to_date('03-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001116001883, to_date('16-11-2000', 'dd-mm-yyyy'), to_date('30-11-2000', 'dd-mm-yyyy'), 11, 2309, to_date('21-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110711001884, to_date('11-07-2011', 'dd-mm-yyyy'), to_date('25-07-2011', 'dd-mm-yyyy'), 3, 7962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000925001885, to_date('25-09-2000', 'dd-mm-yyyy'), to_date('09-10-2000', 'dd-mm-yyyy'), 8, 2222, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628001886, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 11, 8548, to_date('06-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050816001887, to_date('16-08-2005', 'dd-mm-yyyy'), to_date('30-08-2005', 'dd-mm-yyyy'), 4, 5738, to_date('29-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030129001888, to_date('29-01-2003', 'dd-mm-yyyy'), to_date('12-02-2003', 'dd-mm-yyyy'), 2, 4908, to_date('09-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000325001889, to_date('25-03-2000', 'dd-mm-yyyy'), to_date('08-04-2000', 'dd-mm-yyyy'), 8, 1995, to_date('27-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041123001890, to_date('23-11-2004', 'dd-mm-yyyy'), to_date('07-12-2004', 'dd-mm-yyyy'), 3, 2780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217001891, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 11, 9233, to_date('25-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130001892, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 10, 3317, to_date('19-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041022001893, to_date('22-10-2004', 'dd-mm-yyyy'), to_date('05-11-2004', 'dd-mm-yyyy'), 4, 2885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030909001894, to_date('09-09-2003', 'dd-mm-yyyy'), to_date('23-09-2003', 'dd-mm-yyyy'), 12, 2383, to_date('25-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030806001895, to_date('06-08-2003', 'dd-mm-yyyy'), to_date('20-08-2003', 'dd-mm-yyyy'), 12, 2121, to_date('18-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101002001896, to_date('02-10-2010', 'dd-mm-yyyy'), to_date('16-10-2010', 'dd-mm-yyyy'), 5, 7527, to_date('06-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226001897, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 8, 5624, to_date('01-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525001898, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 10, 3736, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050517001899, to_date('17-05-2005', 'dd-mm-yyyy'), to_date('31-05-2005', 'dd-mm-yyyy'), 8, 5031, to_date('31-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040814001900, to_date('14-08-2004', 'dd-mm-yyyy'), to_date('28-08-2004', 'dd-mm-yyyy'), 8, 2748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120911001901, to_date('11-09-2012', 'dd-mm-yyyy'), to_date('25-09-2012', 'dd-mm-yyyy'), 7, 8066, to_date('18-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000517001902, to_date('17-05-2000', 'dd-mm-yyyy'), to_date('31-05-2000', 'dd-mm-yyyy'), 12, 1899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121125001903, to_date('25-11-2012', 'dd-mm-yyyy'), to_date('09-12-2012', 'dd-mm-yyyy'), 7, 8421, to_date('30-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010811001904, to_date('11-08-2001', 'dd-mm-yyyy'), to_date('25-08-2001', 'dd-mm-yyyy'), 7, 2230, to_date('23-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060602001905, to_date('02-06-2006', 'dd-mm-yyyy'), to_date('16-06-2006', 'dd-mm-yyyy'), 4, 5927, to_date('18-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090627001906, to_date('27-06-2009', 'dd-mm-yyyy'), to_date('11-07-2009', 'dd-mm-yyyy'), 10, 7753, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120402001907, to_date('02-04-2012', 'dd-mm-yyyy'), to_date('16-04-2012', 'dd-mm-yyyy'), 3, 7985, to_date('10-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000907001908, to_date('07-09-2000', 'dd-mm-yyyy'), to_date('21-09-2000', 'dd-mm-yyyy'), 2, 3090, to_date('17-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112001909, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 11, 4565, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120208001910, to_date('08-02-2012', 'dd-mm-yyyy'), to_date('22-02-2012', 'dd-mm-yyyy'), 3, 8144, to_date('23-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110916001911, to_date('16-09-2011', 'dd-mm-yyyy'), to_date('30-09-2011', 'dd-mm-yyyy'), 5, 8471, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030530001912, to_date('30-05-2003', 'dd-mm-yyyy'), to_date('13-06-2003', 'dd-mm-yyyy'), 3, 5512, to_date('07-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060413001913, to_date('13-04-2006', 'dd-mm-yyyy'), to_date('27-04-2006', 'dd-mm-yyyy'), 2, 3574, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327001914, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 1, 5477, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120904001915, to_date('04-09-2012', 'dd-mm-yyyy'), to_date('18-09-2012', 'dd-mm-yyyy'), 11, 6738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110703001916, to_date('03-07-2011', 'dd-mm-yyyy'), to_date('17-07-2011', 'dd-mm-yyyy'), 5, 6734, to_date('14-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314001917, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 3, 5321, to_date('20-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121222001918, to_date('22-12-2012', 'dd-mm-yyyy'), to_date('05-01-2013', 'dd-mm-yyyy'), 6, 8061, to_date('27-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623001919, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 5, 4629, to_date('04-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030823001920, to_date('23-08-2003', 'dd-mm-yyyy'), to_date('06-09-2003', 'dd-mm-yyyy'), 6, 1575, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727001921, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 5, 1475, to_date('31-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008001922, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 6, 4269, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020711001923, to_date('11-07-2002', 'dd-mm-yyyy'), to_date('25-07-2002', 'dd-mm-yyyy'), 8, 3633, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120102001924, to_date('02-01-2012', 'dd-mm-yyyy'), to_date('16-01-2012', 'dd-mm-yyyy'), 6, 8124, to_date('05-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060706001925, to_date('06-07-2006', 'dd-mm-yyyy'), to_date('20-07-2006', 'dd-mm-yyyy'), 8, 3459, to_date('11-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527001926, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 6, 6156, to_date('13-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070712001927, to_date('12-07-2007', 'dd-mm-yyyy'), to_date('26-07-2007', 'dd-mm-yyyy'), 4, 4406, to_date('26-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030620001928, to_date('20-06-2003', 'dd-mm-yyyy'), to_date('04-07-2003', 'dd-mm-yyyy'), 10, 1629, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100829001929, to_date('29-08-2010', 'dd-mm-yyyy'), to_date('12-09-2010', 'dd-mm-yyyy'), 1, 5297, to_date('04-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001211001930, to_date('11-12-2000', 'dd-mm-yyyy'), to_date('25-12-2000', 'dd-mm-yyyy'), 3, 2236, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031102001931, to_date('02-11-2003', 'dd-mm-yyyy'), to_date('16-11-2003', 'dd-mm-yyyy'), 9, 2850, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060715001932, to_date('15-07-2006', 'dd-mm-yyyy'), to_date('29-07-2006', 'dd-mm-yyyy'), 1, 4163, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050306001933, to_date('06-03-2005', 'dd-mm-yyyy'), to_date('20-03-2005', 'dd-mm-yyyy'), 8, 4972, to_date('16-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110907001934, to_date('07-09-2011', 'dd-mm-yyyy'), to_date('21-09-2011', 'dd-mm-yyyy'), 6, 6072, to_date('19-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121016001935, to_date('16-10-2012', 'dd-mm-yyyy'), to_date('30-10-2012', 'dd-mm-yyyy'), 6, 9188, to_date('23-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050604001936, to_date('04-06-2005', 'dd-mm-yyyy'), to_date('18-06-2005', 'dd-mm-yyyy'), 4, 5442, to_date('08-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213001937, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 4, 5245, to_date('25-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040127001938, to_date('27-01-2004', 'dd-mm-yyyy'), to_date('10-02-2004', 'dd-mm-yyyy'), 3, 3179, to_date('15-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080613001939, to_date('13-06-2008', 'dd-mm-yyyy'), to_date('27-06-2008', 'dd-mm-yyyy'), 3, 6048, to_date('03-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010802001940, to_date('02-08-2001', 'dd-mm-yyyy'), to_date('16-08-2001', 'dd-mm-yyyy'), 12, 1681, to_date('13-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050214001941, to_date('14-02-2005', 'dd-mm-yyyy'), to_date('28-02-2005', 'dd-mm-yyyy'), 7, 4143, to_date('22-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060311001942, to_date('11-03-2006', 'dd-mm-yyyy'), to_date('25-03-2006', 'dd-mm-yyyy'), 2, 5298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050309001943, to_date('09-03-2005', 'dd-mm-yyyy'), to_date('23-03-2005', 'dd-mm-yyyy'), 5, 4077, to_date('26-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612001944, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 3, 7623, to_date('19-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124001945, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 7, 4378, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100405001946, to_date('05-04-2010', 'dd-mm-yyyy'), to_date('19-04-2010', 'dd-mm-yyyy'), 3, 7924, to_date('10-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100223001947, to_date('23-02-2010', 'dd-mm-yyyy'), to_date('09-03-2010', 'dd-mm-yyyy'), 1, 10753, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010829001948, to_date('29-08-2001', 'dd-mm-yyyy'), to_date('12-09-2001', 'dd-mm-yyyy'), 7, 3273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070225001949, to_date('25-02-2007', 'dd-mm-yyyy'), to_date('11-03-2007', 'dd-mm-yyyy'), 11, 7748, to_date('10-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001017001950, to_date('17-10-2000', 'dd-mm-yyyy'), to_date('31-10-2000', 'dd-mm-yyyy'), 6, 1866, to_date('31-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011129001951, to_date('29-11-2001', 'dd-mm-yyyy'), to_date('13-12-2001', 'dd-mm-yyyy'), 5, 3592, to_date('12-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120309001952, to_date('09-03-2012', 'dd-mm-yyyy'), to_date('23-03-2012', 'dd-mm-yyyy'), 9, 7264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120511001953, to_date('11-05-2012', 'dd-mm-yyyy'), to_date('25-05-2012', 'dd-mm-yyyy'), 4, 7982, to_date('26-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527001954, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 10, 4133, to_date('31-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090507001955, to_date('07-05-2009', 'dd-mm-yyyy'), to_date('21-05-2009', 'dd-mm-yyyy'), 11, 7324, to_date('15-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101224001956, to_date('24-12-2010', 'dd-mm-yyyy'), to_date('07-01-2011', 'dd-mm-yyyy'), 11, 7323, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010112001957, to_date('12-01-2001', 'dd-mm-yyyy'), to_date('26-01-2001', 'dd-mm-yyyy'), 10, 1576, to_date('27-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001019001958, to_date('19-10-2000', 'dd-mm-yyyy'), to_date('02-11-2000', 'dd-mm-yyyy'), 7, 1758, to_date('02-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080808001959, to_date('08-08-2008', 'dd-mm-yyyy'), to_date('22-08-2008', 'dd-mm-yyyy'), 9, 4622, to_date('23-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030509001960, to_date('09-05-2003', 'dd-mm-yyyy'), to_date('23-05-2003', 'dd-mm-yyyy'), 11, 1789, to_date('27-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225001961, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 3, 11432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121004001962, to_date('04-10-2012', 'dd-mm-yyyy'), to_date('18-10-2012', 'dd-mm-yyyy'), 4, 10486, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090316001963, to_date('16-03-2009', 'dd-mm-yyyy'), to_date('30-03-2009', 'dd-mm-yyyy'), 6, 6434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070418001964, to_date('18-04-2007', 'dd-mm-yyyy'), to_date('02-05-2007', 'dd-mm-yyyy'), 5, 6200, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130126001965, to_date('26-01-2013', 'dd-mm-yyyy'), to_date('09-02-2013', 'dd-mm-yyyy'), 4, 11899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111225001966, to_date('25-12-2011', 'dd-mm-yyyy'), to_date('08-01-2012', 'dd-mm-yyyy'), 2, 8609, to_date('10-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030907001967, to_date('07-09-2003', 'dd-mm-yyyy'), to_date('21-09-2003', 'dd-mm-yyyy'), 2, 3742, to_date('15-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101004001968, to_date('04-10-2010', 'dd-mm-yyyy'), to_date('18-10-2010', 'dd-mm-yyyy'), 7, 6789, to_date('12-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050201001969, to_date('01-02-2005', 'dd-mm-yyyy'), to_date('15-02-2005', 'dd-mm-yyyy'), 4, 5863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080810001970, to_date('10-08-2008', 'dd-mm-yyyy'), to_date('24-08-2008', 'dd-mm-yyyy'), 7, 6962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050723001971, to_date('23-07-2005', 'dd-mm-yyyy'), to_date('06-08-2005', 'dd-mm-yyyy'), 3, 6543, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430001972, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 8, 5264, to_date('13-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000315001973, to_date('15-03-2000', 'dd-mm-yyyy'), to_date('29-03-2000', 'dd-mm-yyyy'), 9, 1967, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326001974, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 12, 7672, to_date('10-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030608001975, to_date('08-06-2003', 'dd-mm-yyyy'), to_date('22-06-2003', 'dd-mm-yyyy'), 6, 4436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820001976, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 9, 6308, to_date('22-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001223001977, to_date('23-12-2000', 'dd-mm-yyyy'), to_date('06-01-2001', 'dd-mm-yyyy'), 7, 1807, to_date('10-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131229001978, to_date('29-12-2013', 'dd-mm-yyyy'), to_date('12-01-2014', 'dd-mm-yyyy'), 3, 9809, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050109001979, to_date('09-01-2005', 'dd-mm-yyyy'), to_date('23-01-2005', 'dd-mm-yyyy'), 9, 2846, to_date('12-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080309001980, to_date('09-03-2008', 'dd-mm-yyyy'), to_date('23-03-2008', 'dd-mm-yyyy'), 4, 4397, to_date('11-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060104001981, to_date('04-01-2006', 'dd-mm-yyyy'), to_date('18-01-2006', 'dd-mm-yyyy'), 7, 2826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090516001982, to_date('16-05-2009', 'dd-mm-yyyy'), to_date('30-05-2009', 'dd-mm-yyyy'), 2, 4966, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313001983, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 3, 6048, to_date('15-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010417001984, to_date('17-04-2001', 'dd-mm-yyyy'), to_date('01-05-2001', 'dd-mm-yyyy'), 3, 1682, to_date('05-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703001985, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 8, 3723, to_date('21-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323001986, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 2, 5263, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001124001987, to_date('24-11-2000', 'dd-mm-yyyy'), to_date('08-12-2000', 'dd-mm-yyyy'), 7, 1194, to_date('10-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120825001988, to_date('25-08-2012', 'dd-mm-yyyy'), to_date('08-09-2012', 'dd-mm-yyyy'), 9, 8226, to_date('02-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121004288, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 9, 10957, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070628004289, to_date('28-06-2007', 'dd-mm-yyyy'), to_date('12-07-2007', 'dd-mm-yyyy'), 11, 3760, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050913004290, to_date('13-09-2005', 'dd-mm-yyyy'), to_date('27-09-2005', 'dd-mm-yyyy'), 7, 5396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040401004291, to_date('01-04-2004', 'dd-mm-yyyy'), to_date('15-04-2004', 'dd-mm-yyyy'), 8, 3351, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090516004292, to_date('16-05-2009', 'dd-mm-yyyy'), to_date('30-05-2009', 'dd-mm-yyyy'), 4, 6212, to_date('30-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010530004293, to_date('30-05-2001', 'dd-mm-yyyy'), to_date('13-06-2001', 'dd-mm-yyyy'), 7, 2181, to_date('18-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130921004294, to_date('21-09-2013', 'dd-mm-yyyy'), to_date('05-10-2013', 'dd-mm-yyyy'), 12, 7899, to_date('06-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080619004295, to_date('19-06-2008', 'dd-mm-yyyy'), to_date('03-07-2008', 'dd-mm-yyyy'), 10, 6263, to_date('29-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504004296, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 3, 3112, to_date('14-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823004297, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 3, 3781, to_date('05-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120127004298, to_date('27-01-2012', 'dd-mm-yyyy'), to_date('10-02-2012', 'dd-mm-yyyy'), 8, 7378, to_date('01-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207004299, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 12, 5965, to_date('13-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070603004300, to_date('03-06-2007', 'dd-mm-yyyy'), to_date('17-06-2007', 'dd-mm-yyyy'), 9, 6755, to_date('14-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090817004301, to_date('17-08-2009', 'dd-mm-yyyy'), to_date('31-08-2009', 'dd-mm-yyyy'), 8, 6699, to_date('20-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601004302, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 5, 5608, to_date('09-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108004303, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 11, 9869, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140421004304, to_date('21-04-2014', 'dd-mm-yyyy'), to_date('05-05-2014', 'dd-mm-yyyy'), 6, 10655, to_date('09-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040519004305, to_date('19-05-2004', 'dd-mm-yyyy'), to_date('02-06-2004', 'dd-mm-yyyy'), 3, 4490, to_date('01-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060729004306, to_date('29-07-2006', 'dd-mm-yyyy'), to_date('12-08-2006', 'dd-mm-yyyy'), 7, 4028, to_date('15-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070610004307, to_date('10-06-2007', 'dd-mm-yyyy'), to_date('24-06-2007', 'dd-mm-yyyy'), 5, 5500, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031102004308, to_date('02-11-2003', 'dd-mm-yyyy'), to_date('16-11-2003', 'dd-mm-yyyy'), 5, 2723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080910004309, to_date('10-09-2008', 'dd-mm-yyyy'), to_date('24-09-2008', 'dd-mm-yyyy'), 12, 6840, to_date('23-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040525004310, to_date('25-05-2004', 'dd-mm-yyyy'), to_date('08-06-2004', 'dd-mm-yyyy'), 2, 2242, to_date('13-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130320004311, to_date('20-03-2013', 'dd-mm-yyyy'), to_date('03-04-2013', 'dd-mm-yyyy'), 4, 7833, to_date('06-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031209004312, to_date('09-12-2003', 'dd-mm-yyyy'), to_date('23-12-2003', 'dd-mm-yyyy'), 8, 2602, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129004313, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 1, 5645, to_date('15-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130430004314, to_date('30-04-2013', 'dd-mm-yyyy'), to_date('14-05-2013', 'dd-mm-yyyy'), 7, 6998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001221004315, to_date('21-12-2000', 'dd-mm-yyyy'), to_date('04-01-2001', 'dd-mm-yyyy'), 2, 704, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609004316, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 6, 4510, to_date('25-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313004317, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 8, 2194, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101124004318, to_date('24-11-2010', 'dd-mm-yyyy'), to_date('08-12-2010', 'dd-mm-yyyy'), 4, 5474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703004319, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 3, 4480, to_date('23-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020630004320, to_date('30-06-2002', 'dd-mm-yyyy'), to_date('14-07-2002', 'dd-mm-yyyy'), 4, 3047, to_date('01-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090308004321, to_date('08-03-2009', 'dd-mm-yyyy'), to_date('22-03-2009', 'dd-mm-yyyy'), 3, 5403, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010210004322, to_date('10-02-2001', 'dd-mm-yyyy'), to_date('24-02-2001', 'dd-mm-yyyy'), 2, 977, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060805004323, to_date('05-08-2006', 'dd-mm-yyyy'), to_date('19-08-2006', 'dd-mm-yyyy'), 5, 5612, to_date('16-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120801004324, to_date('01-08-2012', 'dd-mm-yyyy'), to_date('15-08-2012', 'dd-mm-yyyy'), 10, 7516, to_date('06-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040923004325, to_date('23-09-2004', 'dd-mm-yyyy'), to_date('07-10-2004', 'dd-mm-yyyy'), 3, 3825, to_date('05-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010213004326, to_date('13-02-2001', 'dd-mm-yyyy'), to_date('27-02-2001', 'dd-mm-yyyy'), 4, 2223, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061202004327, to_date('02-12-2006', 'dd-mm-yyyy'), to_date('16-12-2006', 'dd-mm-yyyy'), 3, 5852, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010114004328, to_date('14-01-2001', 'dd-mm-yyyy'), to_date('28-01-2001', 'dd-mm-yyyy'), 7, 1694, to_date('30-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091018004329, to_date('18-10-2009', 'dd-mm-yyyy'), to_date('01-11-2009', 'dd-mm-yyyy'), 3, 5354, to_date('23-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140406004330, to_date('06-04-2014', 'dd-mm-yyyy'), to_date('20-04-2014', 'dd-mm-yyyy'), 11, 6681, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061031004331, to_date('31-10-2006', 'dd-mm-yyyy'), to_date('14-11-2006', 'dd-mm-yyyy'), 10, 3931, to_date('12-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101104004332, to_date('04-11-2010', 'dd-mm-yyyy'), to_date('18-11-2010', 'dd-mm-yyyy'), 9, 5948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210004333, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 3, 5307, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080118004334, to_date('18-01-2008', 'dd-mm-yyyy'), to_date('01-02-2008', 'dd-mm-yyyy'), 6, 4092, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121125004335, to_date('25-11-2012', 'dd-mm-yyyy'), to_date('09-12-2012', 'dd-mm-yyyy'), 9, 5757, to_date('28-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070304004336, to_date('04-03-2007', 'dd-mm-yyyy'), to_date('18-03-2007', 'dd-mm-yyyy'), 1, 4029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216004337, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 4, 3849, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829004338, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 11, 5012, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010709004339, to_date('09-07-2001', 'dd-mm-yyyy'), to_date('23-07-2001', 'dd-mm-yyyy'), 10, 1710, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210004340, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 9, 2442, to_date('24-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130618004341, to_date('18-06-2013', 'dd-mm-yyyy'), to_date('02-07-2013', 'dd-mm-yyyy'), 2, 9834, to_date('24-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000115004342, to_date('15-01-2000', 'dd-mm-yyyy'), to_date('29-01-2000', 'dd-mm-yyyy'), 12, 1457, to_date('27-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110614004343, to_date('14-06-2011', 'dd-mm-yyyy'), to_date('28-06-2011', 'dd-mm-yyyy'), 6, 7616, to_date('19-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103004344, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 8, 3702, to_date('13-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121025004345, to_date('25-10-2012', 'dd-mm-yyyy'), to_date('08-11-2012', 'dd-mm-yyyy'), 8, 8675, to_date('04-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031019004346, to_date('19-10-2003', 'dd-mm-yyyy'), to_date('02-11-2003', 'dd-mm-yyyy'), 9, 4388, to_date('23-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030729004347, to_date('29-07-2003', 'dd-mm-yyyy'), to_date('12-08-2003', 'dd-mm-yyyy'), 4, 3212, to_date('08-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326004348, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 3, 3334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624004349, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 1, 9020, to_date('12-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808004350, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 11, 8142, to_date('17-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130301004351, to_date('01-03-2013', 'dd-mm-yyyy'), to_date('15-03-2013', 'dd-mm-yyyy'), 9, 7516, to_date('10-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050807004352, to_date('07-08-2005', 'dd-mm-yyyy'), to_date('21-08-2005', 'dd-mm-yyyy'), 8, 4869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100131004353, to_date('31-01-2010', 'dd-mm-yyyy'), to_date('14-02-2010', 'dd-mm-yyyy'), 5, 6791, to_date('08-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040305004354, to_date('05-03-2004', 'dd-mm-yyyy'), to_date('19-03-2004', 'dd-mm-yyyy'), 10, 3245, to_date('07-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021030004355, to_date('30-10-2002', 'dd-mm-yyyy'), to_date('13-11-2002', 'dd-mm-yyyy'), 6, 2934, to_date('17-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090920004356, to_date('20-09-2009', 'dd-mm-yyyy'), to_date('04-10-2009', 'dd-mm-yyyy'), 5, 6954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922004357, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 8, 8331, to_date('30-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080724004358, to_date('24-07-2008', 'dd-mm-yyyy'), to_date('07-08-2008', 'dd-mm-yyyy'), 5, 5374, to_date('04-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020420004359, to_date('20-04-2002', 'dd-mm-yyyy'), to_date('04-05-2002', 'dd-mm-yyyy'), 2, 5090, to_date('25-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830004360, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 11, 5236, to_date('11-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703004361, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 3, 7063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010325004362, to_date('25-03-2001', 'dd-mm-yyyy'), to_date('08-04-2001', 'dd-mm-yyyy'), 5, 2150, to_date('05-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040823004363, to_date('23-08-2004', 'dd-mm-yyyy'), to_date('06-09-2004', 'dd-mm-yyyy'), 10, 3942, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011229004364, to_date('29-12-2001', 'dd-mm-yyyy'), to_date('12-01-2002', 'dd-mm-yyyy'), 7, 3819, to_date('13-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131223004365, to_date('23-12-2013', 'dd-mm-yyyy'), to_date('06-01-2014', 'dd-mm-yyyy'), 7, 9409, to_date('12-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021124004366, to_date('24-11-2002', 'dd-mm-yyyy'), to_date('08-12-2002', 'dd-mm-yyyy'), 4, 4508, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813004367, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 8, 6548, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040831004368, to_date('31-08-2004', 'dd-mm-yyyy'), to_date('14-09-2004', 'dd-mm-yyyy'), 5, 2857, to_date('18-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326004369, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 3, 5191, to_date('14-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070303004370, to_date('03-03-2007', 'dd-mm-yyyy'), to_date('17-03-2007', 'dd-mm-yyyy'), 5, 3967, to_date('15-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130707004371, to_date('07-07-2013', 'dd-mm-yyyy'), to_date('21-07-2013', 'dd-mm-yyyy'), 9, 8976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090415004372, to_date('15-04-2009', 'dd-mm-yyyy'), to_date('29-04-2009', 'dd-mm-yyyy'), 7, 7573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090514004373, to_date('14-05-2009', 'dd-mm-yyyy'), to_date('28-05-2009', 'dd-mm-yyyy'), 3, 4914, to_date('21-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030930004374, to_date('30-09-2003', 'dd-mm-yyyy'), to_date('14-10-2003', 'dd-mm-yyyy'), 6, 3803, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001025004375, to_date('25-10-2000', 'dd-mm-yyyy'), to_date('08-11-2000', 'dd-mm-yyyy'), 6, 1984, to_date('31-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100830004376, to_date('30-08-2010', 'dd-mm-yyyy'), to_date('13-09-2010', 'dd-mm-yyyy'), 3, 6724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220004377, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 6, 7105, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070924004378, to_date('24-09-2007', 'dd-mm-yyyy'), to_date('08-10-2007', 'dd-mm-yyyy'), 5, 4542, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922004379, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 2, 8988, to_date('01-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204004380, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 1, 3485, to_date('07-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021121004381, to_date('21-11-2002', 'dd-mm-yyyy'), to_date('05-12-2002', 'dd-mm-yyyy'), 11, 1521, to_date('23-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000828004382, to_date('28-08-2000', 'dd-mm-yyyy'), to_date('11-09-2000', 'dd-mm-yyyy'), 2, 1861, to_date('01-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815004383, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 4, 3736, to_date('27-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620004384, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 6, 5616, to_date('24-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910004385, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 4, 4825, to_date('22-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101230004386, to_date('30-12-2010', 'dd-mm-yyyy'), to_date('13-01-2011', 'dd-mm-yyyy'), 7, 8024, to_date('12-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020102004387, to_date('02-01-2002', 'dd-mm-yyyy'), to_date('16-01-2002', 'dd-mm-yyyy'), 7, 2138, to_date('12-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130330004388, to_date('30-03-2013', 'dd-mm-yyyy'), to_date('13-04-2013', 'dd-mm-yyyy'), 8, 9269, to_date('13-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111008004389, to_date('08-10-2011', 'dd-mm-yyyy'), to_date('22-10-2011', 'dd-mm-yyyy'), 8, 7441, null);
commit;
prompt 5000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519004390, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 6, 8362, to_date('28-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120908004391, to_date('08-09-2012', 'dd-mm-yyyy'), to_date('22-09-2012', 'dd-mm-yyyy'), 11, 6348, to_date('10-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120315004392, to_date('15-03-2012', 'dd-mm-yyyy'), to_date('29-03-2012', 'dd-mm-yyyy'), 6, 6769, to_date('02-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513004393, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 6, 4964, to_date('01-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060924004394, to_date('24-09-2006', 'dd-mm-yyyy'), to_date('08-10-2006', 'dd-mm-yyyy'), 7, 6619, to_date('01-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130324004395, to_date('24-03-2013', 'dd-mm-yyyy'), to_date('07-04-2013', 'dd-mm-yyyy'), 8, 6430, to_date('10-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016004396, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 7, 8121, to_date('01-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021130004397, to_date('30-11-2002', 'dd-mm-yyyy'), to_date('14-12-2002', 'dd-mm-yyyy'), 3, 3094, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429004398, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 9, 5662, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117004399, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 10, 9562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100524004400, to_date('24-05-2010', 'dd-mm-yyyy'), to_date('07-06-2010', 'dd-mm-yyyy'), 9, 6110, to_date('27-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070417004401, to_date('17-04-2007', 'dd-mm-yyyy'), to_date('01-05-2007', 'dd-mm-yyyy'), 12, 5575, to_date('01-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030203004402, to_date('03-02-2003', 'dd-mm-yyyy'), to_date('17-02-2003', 'dd-mm-yyyy'), 10, 2738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130503004403, to_date('03-05-2013', 'dd-mm-yyyy'), to_date('17-05-2013', 'dd-mm-yyyy'), 12, 7942, to_date('05-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011023004404, to_date('23-10-2001', 'dd-mm-yyyy'), to_date('06-11-2001', 'dd-mm-yyyy'), 11, 1139, to_date('29-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211004405, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 4, 4126, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010512004406, to_date('12-05-2001', 'dd-mm-yyyy'), to_date('26-05-2001', 'dd-mm-yyyy'), 3, 2051, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050704004407, to_date('04-07-2005', 'dd-mm-yyyy'), to_date('18-07-2005', 'dd-mm-yyyy'), 11, 3868, to_date('10-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120606004408, to_date('06-06-2012', 'dd-mm-yyyy'), to_date('20-06-2012', 'dd-mm-yyyy'), 4, 7512, to_date('14-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106004409, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 12, 5052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061016004410, to_date('16-10-2006', 'dd-mm-yyyy'), to_date('30-10-2006', 'dd-mm-yyyy'), 11, 5966, to_date('01-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080711004411, to_date('11-07-2008', 'dd-mm-yyyy'), to_date('25-07-2008', 'dd-mm-yyyy'), 7, 7930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105004412, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 1, 9704, to_date('13-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111029004413, to_date('29-10-2011', 'dd-mm-yyyy'), to_date('12-11-2011', 'dd-mm-yyyy'), 4, 8265, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110510004414, to_date('10-05-2011', 'dd-mm-yyyy'), to_date('24-05-2011', 'dd-mm-yyyy'), 1, 8847, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128004415, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 7, 6691, to_date('04-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020707004416, to_date('07-07-2002', 'dd-mm-yyyy'), to_date('21-07-2002', 'dd-mm-yyyy'), 8, 2584, to_date('15-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121203004417, to_date('03-12-2012', 'dd-mm-yyyy'), to_date('17-12-2012', 'dd-mm-yyyy'), 9, 6996, to_date('15-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110417004418, to_date('17-04-2011', 'dd-mm-yyyy'), to_date('01-05-2011', 'dd-mm-yyyy'), 11, 6925, to_date('02-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026004419, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 10, 4917, to_date('08-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919004420, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 3, 7478, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090429004421, to_date('29-04-2009', 'dd-mm-yyyy'), to_date('13-05-2009', 'dd-mm-yyyy'), 4, 8229, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060414004422, to_date('14-04-2006', 'dd-mm-yyyy'), to_date('28-04-2006', 'dd-mm-yyyy'), 4, 2460, to_date('15-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208004423, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 12, 5512, to_date('26-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100325004424, to_date('25-03-2010', 'dd-mm-yyyy'), to_date('08-04-2010', 'dd-mm-yyyy'), 3, 7168, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071104004425, to_date('04-11-2007', 'dd-mm-yyyy'), to_date('18-11-2007', 'dd-mm-yyyy'), 9, 6618, to_date('07-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427004426, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 5, 3461, to_date('15-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129004427, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 12, 3440, to_date('17-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110004428, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 2, 7016, to_date('26-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050320004429, to_date('20-03-2005', 'dd-mm-yyyy'), to_date('03-04-2005', 'dd-mm-yyyy'), 11, 3808, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050525004430, to_date('25-05-2005', 'dd-mm-yyyy'), to_date('08-06-2005', 'dd-mm-yyyy'), 5, 3763, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105004431, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 5, 6078, to_date('12-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030714004432, to_date('14-07-2003', 'dd-mm-yyyy'), to_date('28-07-2003', 'dd-mm-yyyy'), 8, 3282, to_date('16-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110523004433, to_date('23-05-2011', 'dd-mm-yyyy'), to_date('06-06-2011', 'dd-mm-yyyy'), 11, 8503, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050428004434, to_date('28-04-2005', 'dd-mm-yyyy'), to_date('12-05-2005', 'dd-mm-yyyy'), 6, 3473, to_date('29-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050521004435, to_date('21-05-2005', 'dd-mm-yyyy'), to_date('04-06-2005', 'dd-mm-yyyy'), 9, 3673, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091208004436, to_date('08-12-2009', 'dd-mm-yyyy'), to_date('22-12-2009', 'dd-mm-yyyy'), 10, 4132, to_date('11-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050321004437, to_date('21-03-2005', 'dd-mm-yyyy'), to_date('04-04-2005', 'dd-mm-yyyy'), 6, 2656, to_date('29-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113004438, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 7, 4243, to_date('27-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040701004439, to_date('01-07-2004', 'dd-mm-yyyy'), to_date('15-07-2004', 'dd-mm-yyyy'), 8, 3407, to_date('12-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061105004440, to_date('05-11-2006', 'dd-mm-yyyy'), to_date('19-11-2006', 'dd-mm-yyyy'), 5, 7604, to_date('12-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309006582, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 9, 5671, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050510006583, to_date('10-05-2005', 'dd-mm-yyyy'), to_date('24-05-2005', 'dd-mm-yyyy'), 9, 5893, to_date('11-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070508006584, to_date('08-05-2007', 'dd-mm-yyyy'), to_date('22-05-2007', 'dd-mm-yyyy'), 9, 5814, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225006585, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 12, 1899, to_date('03-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110922006586, to_date('22-09-2011', 'dd-mm-yyyy'), to_date('06-10-2011', 'dd-mm-yyyy'), 6, 8398, to_date('07-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101006587, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 2, 3008, to_date('06-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811006588, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 10, 8950, to_date('29-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215006589, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 10, 5028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051017006590, to_date('17-10-2005', 'dd-mm-yyyy'), to_date('31-10-2005', 'dd-mm-yyyy'), 6, 5295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021117006591, to_date('17-11-2002', 'dd-mm-yyyy'), to_date('01-12-2002', 'dd-mm-yyyy'), 8, 2672, to_date('21-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040215006592, to_date('15-02-2004', 'dd-mm-yyyy'), to_date('29-02-2004', 'dd-mm-yyyy'), 4, 4917, to_date('23-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060414006593, to_date('14-04-2006', 'dd-mm-yyyy'), to_date('28-04-2006', 'dd-mm-yyyy'), 5, 2796, to_date('23-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090801006594, to_date('01-08-2009', 'dd-mm-yyyy'), to_date('15-08-2009', 'dd-mm-yyyy'), 12, 4825, to_date('14-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080201006595, to_date('01-02-2008', 'dd-mm-yyyy'), to_date('15-02-2008', 'dd-mm-yyyy'), 11, 5637, to_date('13-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080721006596, to_date('21-07-2008', 'dd-mm-yyyy'), to_date('04-08-2008', 'dd-mm-yyyy'), 5, 5780, to_date('30-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041019006597, to_date('19-10-2004', 'dd-mm-yyyy'), to_date('02-11-2004', 'dd-mm-yyyy'), 9, 4509, to_date('02-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100616006598, to_date('16-06-2010', 'dd-mm-yyyy'), to_date('30-06-2010', 'dd-mm-yyyy'), 2, 9075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110606006599, to_date('06-06-2011', 'dd-mm-yyyy'), to_date('20-06-2011', 'dd-mm-yyyy'), 4, 8054, to_date('11-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722006600, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 9, 4166, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609006601, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 5, 3336, to_date('18-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041013006602, to_date('13-10-2004', 'dd-mm-yyyy'), to_date('27-10-2004', 'dd-mm-yyyy'), 9, 2530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416006603, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 2, 5060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081227006604, to_date('27-12-2008', 'dd-mm-yyyy'), to_date('10-01-2009', 'dd-mm-yyyy'), 11, 6648, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001207006605, to_date('07-12-2000', 'dd-mm-yyyy'), to_date('21-12-2000', 'dd-mm-yyyy'), 3, 1340, to_date('14-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011115006606, to_date('15-11-2001', 'dd-mm-yyyy'), to_date('29-11-2001', 'dd-mm-yyyy'), 9, 2424, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090826006607, to_date('26-08-2009', 'dd-mm-yyyy'), to_date('09-09-2009', 'dd-mm-yyyy'), 3, 5364, to_date('09-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081202006608, to_date('02-12-2008', 'dd-mm-yyyy'), to_date('16-12-2008', 'dd-mm-yyyy'), 9, 4619, to_date('07-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000817006609, to_date('17-08-2000', 'dd-mm-yyyy'), to_date('31-08-2000', 'dd-mm-yyyy'), 12, 1696, to_date('28-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140503006610, to_date('03-05-2014', 'dd-mm-yyyy'), to_date('17-05-2014', 'dd-mm-yyyy'), 3, 9918, to_date('05-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906006611, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 7, 6560, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051228006612, to_date('28-12-2005', 'dd-mm-yyyy'), to_date('11-01-2006', 'dd-mm-yyyy'), 9, 5562, to_date('10-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120206006613, to_date('06-02-2012', 'dd-mm-yyyy'), to_date('20-02-2012', 'dd-mm-yyyy'), 12, 8626, to_date('19-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030928006614, to_date('28-09-2003', 'dd-mm-yyyy'), to_date('12-10-2003', 'dd-mm-yyyy'), 2, 4323, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090615006615, to_date('15-06-2009', 'dd-mm-yyyy'), to_date('29-06-2009', 'dd-mm-yyyy'), 3, 3810, to_date('04-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510006616, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 11, 463, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129006617, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 5, 5589, to_date('11-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020515006618, to_date('15-05-2002', 'dd-mm-yyyy'), to_date('29-05-2002', 'dd-mm-yyyy'), 6, 4278, to_date('01-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130127006619, to_date('27-01-2013', 'dd-mm-yyyy'), to_date('10-02-2013', 'dd-mm-yyyy'), 6, 9170, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040801006620, to_date('01-08-2004', 'dd-mm-yyyy'), to_date('15-08-2004', 'dd-mm-yyyy'), 2, 3126, to_date('16-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070712006621, to_date('12-07-2007', 'dd-mm-yyyy'), to_date('26-07-2007', 'dd-mm-yyyy'), 5, 6250, to_date('01-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040520006622, to_date('20-05-2004', 'dd-mm-yyyy'), to_date('03-06-2004', 'dd-mm-yyyy'), 7, 3083, to_date('08-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060408006623, to_date('08-04-2006', 'dd-mm-yyyy'), to_date('22-04-2006', 'dd-mm-yyyy'), 10, 5117, to_date('22-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130208006624, to_date('08-02-2013', 'dd-mm-yyyy'), to_date('22-02-2013', 'dd-mm-yyyy'), 2, 9995, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512006625, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 9, 3633, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110502006626, to_date('02-05-2011', 'dd-mm-yyyy'), to_date('16-05-2011', 'dd-mm-yyyy'), 3, 10135, to_date('19-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120424006627, to_date('24-04-2012', 'dd-mm-yyyy'), to_date('08-05-2012', 'dd-mm-yyyy'), 9, 6957, to_date('08-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080329006628, to_date('29-03-2008', 'dd-mm-yyyy'), to_date('12-04-2008', 'dd-mm-yyyy'), 9, 4264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525006629, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 5, 7195, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805006630, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 2, 3840, to_date('09-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090202006631, to_date('02-02-2009', 'dd-mm-yyyy'), to_date('16-02-2009', 'dd-mm-yyyy'), 11, 7047, to_date('08-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530006632, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 6, 13694, to_date('12-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100114006633, to_date('14-01-2010', 'dd-mm-yyyy'), to_date('28-01-2010', 'dd-mm-yyyy'), 11, 5728, to_date('01-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121006006634, to_date('06-10-2012', 'dd-mm-yyyy'), to_date('20-10-2012', 'dd-mm-yyyy'), 10, 9771, to_date('08-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051006006635, to_date('06-10-2005', 'dd-mm-yyyy'), to_date('20-10-2005', 'dd-mm-yyyy'), 10, 3092, to_date('13-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821006636, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 8, 6765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130417006637, to_date('17-04-2013', 'dd-mm-yyyy'), to_date('01-05-2013', 'dd-mm-yyyy'), 3, 9170, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222006638, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 10, 2865, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020409006639, to_date('09-04-2002', 'dd-mm-yyyy'), to_date('23-04-2002', 'dd-mm-yyyy'), 3, 2870, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040413006640, to_date('13-04-2004', 'dd-mm-yyyy'), to_date('27-04-2004', 'dd-mm-yyyy'), 9, 1892, to_date('03-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000717006641, to_date('17-07-2000', 'dd-mm-yyyy'), to_date('31-07-2000', 'dd-mm-yyyy'), 3, 964, to_date('01-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110517006642, to_date('17-05-2011', 'dd-mm-yyyy'), to_date('31-05-2011', 'dd-mm-yyyy'), 5, 7393, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703006643, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 7, 4495, to_date('08-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000801006644, to_date('01-08-2000', 'dd-mm-yyyy'), to_date('15-08-2000', 'dd-mm-yyyy'), 4, 1477, to_date('03-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080417006645, to_date('17-04-2008', 'dd-mm-yyyy'), to_date('01-05-2008', 'dd-mm-yyyy'), 4, 5676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110803006646, to_date('03-08-2011', 'dd-mm-yyyy'), to_date('17-08-2011', 'dd-mm-yyyy'), 8, 10417, to_date('14-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100818006647, to_date('18-08-2010', 'dd-mm-yyyy'), to_date('01-09-2010', 'dd-mm-yyyy'), 1, 7971, to_date('26-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091126006648, to_date('26-11-2009', 'dd-mm-yyyy'), to_date('10-12-2009', 'dd-mm-yyyy'), 11, 8537, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041011006649, to_date('11-10-2004', 'dd-mm-yyyy'), to_date('25-10-2004', 'dd-mm-yyyy'), 7, 4505, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010706006650, to_date('06-07-2001', 'dd-mm-yyyy'), to_date('20-07-2001', 'dd-mm-yyyy'), 10, 3018, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130515006651, to_date('15-05-2013', 'dd-mm-yyyy'), to_date('29-05-2013', 'dd-mm-yyyy'), 11, 6417, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040810006652, to_date('10-08-2004', 'dd-mm-yyyy'), to_date('24-08-2004', 'dd-mm-yyyy'), 7, 5628, to_date('12-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111231006653, to_date('31-12-2011', 'dd-mm-yyyy'), to_date('14-01-2012', 'dd-mm-yyyy'), 7, 6660, to_date('08-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080522006654, to_date('22-05-2008', 'dd-mm-yyyy'), to_date('05-06-2008', 'dd-mm-yyyy'), 12, 5108, to_date('31-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021006655, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 4, 7206, to_date('04-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621006656, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 1, 8550, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080808006657, to_date('08-08-2008', 'dd-mm-yyyy'), to_date('22-08-2008', 'dd-mm-yyyy'), 9, 5427, to_date('14-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813006658, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 9, 6100, to_date('26-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130611006659, to_date('11-06-2013', 'dd-mm-yyyy'), to_date('25-06-2013', 'dd-mm-yyyy'), 4, 8854, to_date('23-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131112006660, to_date('12-11-2013', 'dd-mm-yyyy'), to_date('26-11-2013', 'dd-mm-yyyy'), 9, 8648, to_date('26-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617006661, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 9, 7549, to_date('28-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010914006662, to_date('14-09-2001', 'dd-mm-yyyy'), to_date('28-09-2001', 'dd-mm-yyyy'), 4, 1933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826006663, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 10, 7195, to_date('05-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070422006664, to_date('22-04-2007', 'dd-mm-yyyy'), to_date('06-05-2007', 'dd-mm-yyyy'), 5, 5109, to_date('26-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070927006665, to_date('27-09-2007', 'dd-mm-yyyy'), to_date('11-10-2007', 'dd-mm-yyyy'), 6, 6706, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731006666, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 3, 8754, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041107006667, to_date('07-11-2004', 'dd-mm-yyyy'), to_date('21-11-2004', 'dd-mm-yyyy'), 3, 5258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000616006668, to_date('16-06-2000', 'dd-mm-yyyy'), to_date('30-06-2000', 'dd-mm-yyyy'), 1, 1777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110325006669, to_date('25-03-2011', 'dd-mm-yyyy'), to_date('08-04-2011', 'dd-mm-yyyy'), 7, 9849, to_date('28-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821006670, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 7, 6443, to_date('30-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121211006671, to_date('11-12-2012', 'dd-mm-yyyy'), to_date('25-12-2012', 'dd-mm-yyyy'), 2, 7143, to_date('31-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090723006672, to_date('23-07-2009', 'dd-mm-yyyy'), to_date('06-08-2009', 'dd-mm-yyyy'), 3, 6455, to_date('08-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031020006673, to_date('20-10-2003', 'dd-mm-yyyy'), to_date('03-11-2003', 'dd-mm-yyyy'), 4, 5004, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726006674, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 3, 8262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060929006675, to_date('29-09-2006', 'dd-mm-yyyy'), to_date('13-10-2006', 'dd-mm-yyyy'), 9, 4795, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000620006676, to_date('20-06-2000', 'dd-mm-yyyy'), to_date('04-07-2000', 'dd-mm-yyyy'), 8, 1125, to_date('29-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030127006677, to_date('27-01-2003', 'dd-mm-yyyy'), to_date('10-02-2003', 'dd-mm-yyyy'), 12, 3798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050829006678, to_date('29-08-2005', 'dd-mm-yyyy'), to_date('12-09-2005', 'dd-mm-yyyy'), 10, 4265, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081207006679, to_date('07-12-2008', 'dd-mm-yyyy'), to_date('21-12-2008', 'dd-mm-yyyy'), 5, 6029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030701006680, to_date('01-07-2003', 'dd-mm-yyyy'), to_date('15-07-2003', 'dd-mm-yyyy'), 5, 6689, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010131006681, to_date('31-01-2001', 'dd-mm-yyyy'), to_date('14-02-2001', 'dd-mm-yyyy'), 3, 3805, to_date('14-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051113006682, to_date('13-11-2005', 'dd-mm-yyyy'), to_date('27-11-2005', 'dd-mm-yyyy'), 7, 5675, to_date('15-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026006683, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 3, 5741, to_date('10-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011227006684, to_date('27-12-2001', 'dd-mm-yyyy'), to_date('10-01-2002', 'dd-mm-yyyy'), 4, 3144, to_date('04-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223006685, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 11, 4447, to_date('06-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050120006686, to_date('20-01-2005', 'dd-mm-yyyy'), to_date('03-02-2005', 'dd-mm-yyyy'), 7, 2392, to_date('24-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120506006687, to_date('06-05-2012', 'dd-mm-yyyy'), to_date('20-05-2012', 'dd-mm-yyyy'), 8, 6594, to_date('08-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050421006688, to_date('21-04-2005', 'dd-mm-yyyy'), to_date('05-05-2005', 'dd-mm-yyyy'), 4, 3235, to_date('07-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626006689, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 9, 7277, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717006690, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 1, 9306, to_date('31-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060928006691, to_date('28-09-2006', 'dd-mm-yyyy'), to_date('12-10-2006', 'dd-mm-yyyy'), 1, 4644, to_date('13-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090707006692, to_date('07-07-2009', 'dd-mm-yyyy'), to_date('21-07-2009', 'dd-mm-yyyy'), 4, 5415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327006693, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 9, 2686, to_date('15-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031208006694, to_date('08-12-2003', 'dd-mm-yyyy'), to_date('22-12-2003', 'dd-mm-yyyy'), 11, 5219, to_date('15-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081115006695, to_date('15-11-2008', 'dd-mm-yyyy'), to_date('29-11-2008', 'dd-mm-yyyy'), 12, 4141, to_date('28-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511006696, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 2, 3377, to_date('15-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070411006697, to_date('11-04-2007', 'dd-mm-yyyy'), to_date('25-04-2007', 'dd-mm-yyyy'), 9, 5132, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130520006698, to_date('20-05-2013', 'dd-mm-yyyy'), to_date('03-06-2013', 'dd-mm-yyyy'), 10, 8088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080804006699, to_date('04-08-2008', 'dd-mm-yyyy'), to_date('18-08-2008', 'dd-mm-yyyy'), 8, 3998, to_date('12-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050603006700, to_date('03-06-2005', 'dd-mm-yyyy'), to_date('17-06-2005', 'dd-mm-yyyy'), 3, 3170, to_date('15-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001014006701, to_date('14-10-2000', 'dd-mm-yyyy'), to_date('28-10-2000', 'dd-mm-yyyy'), 3, 1347, to_date('30-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010930006702, to_date('30-09-2001', 'dd-mm-yyyy'), to_date('14-10-2001', 'dd-mm-yyyy'), 4, 2223, to_date('19-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020621006703, to_date('21-06-2002', 'dd-mm-yyyy'), to_date('05-07-2002', 'dd-mm-yyyy'), 3, 1222, to_date('06-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050719006704, to_date('19-07-2005', 'dd-mm-yyyy'), to_date('02-08-2005', 'dd-mm-yyyy'), 8, 6557, to_date('21-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020110006705, to_date('10-01-2002', 'dd-mm-yyyy'), to_date('24-01-2002', 'dd-mm-yyyy'), 10, 3722, to_date('14-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031211006706, to_date('11-12-2003', 'dd-mm-yyyy'), to_date('25-12-2003', 'dd-mm-yyyy'), 6, 3246, to_date('23-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110420006707, to_date('20-04-2011', 'dd-mm-yyyy'), to_date('04-05-2011', 'dd-mm-yyyy'), 6, 6753, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050502006708, to_date('02-05-2005', 'dd-mm-yyyy'), to_date('16-05-2005', 'dd-mm-yyyy'), 2, 6342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090108006709, to_date('08-01-2009', 'dd-mm-yyyy'), to_date('22-01-2009', 'dd-mm-yyyy'), 8, 5579, to_date('25-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070102006710, to_date('02-01-2007', 'dd-mm-yyyy'), to_date('16-01-2007', 'dd-mm-yyyy'), 9, 6058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130312006711, to_date('12-03-2013', 'dd-mm-yyyy'), to_date('26-03-2013', 'dd-mm-yyyy'), 4, 10152, to_date('21-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031111006712, to_date('11-11-2003', 'dd-mm-yyyy'), to_date('25-11-2003', 'dd-mm-yyyy'), 7, 4283, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101017006713, to_date('17-10-2010', 'dd-mm-yyyy'), to_date('31-10-2010', 'dd-mm-yyyy'), 6, 7867, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110709006714, to_date('09-07-2011', 'dd-mm-yyyy'), to_date('23-07-2011', 'dd-mm-yyyy'), 2, 7479, to_date('24-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110908006715, to_date('08-09-2011', 'dd-mm-yyyy'), to_date('22-09-2011', 'dd-mm-yyyy'), 8, 8495, to_date('13-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522006716, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 11, 7303, to_date('10-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040708006717, to_date('08-07-2004', 'dd-mm-yyyy'), to_date('22-07-2004', 'dd-mm-yyyy'), 11, 4421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050818006718, to_date('18-08-2005', 'dd-mm-yyyy'), to_date('01-09-2005', 'dd-mm-yyyy'), 1, 5527, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071114006719, to_date('14-11-2007', 'dd-mm-yyyy'), to_date('28-11-2007', 'dd-mm-yyyy'), 2, 5412, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409006720, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 10, 7124, to_date('21-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070724006721, to_date('24-07-2007', 'dd-mm-yyyy'), to_date('07-08-2007', 'dd-mm-yyyy'), 12, 6177, to_date('13-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100324006722, to_date('24-03-2010', 'dd-mm-yyyy'), to_date('07-04-2010', 'dd-mm-yyyy'), 4, 6441, to_date('08-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080808006723, to_date('08-08-2008', 'dd-mm-yyyy'), to_date('22-08-2008', 'dd-mm-yyyy'), 9, 5351, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090915006724, to_date('15-09-2009', 'dd-mm-yyyy'), to_date('29-09-2009', 'dd-mm-yyyy'), 6, 8262, to_date('05-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131007006725, to_date('07-10-2013', 'dd-mm-yyyy'), to_date('21-10-2013', 'dd-mm-yyyy'), 1, 9559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000219006726, to_date('19-02-2000', 'dd-mm-yyyy'), to_date('04-03-2000', 'dd-mm-yyyy'), 5, 1348, to_date('08-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121224006727, to_date('24-12-2012', 'dd-mm-yyyy'), to_date('07-01-2013', 'dd-mm-yyyy'), 9, 8249, to_date('09-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110702006728, to_date('02-07-2011', 'dd-mm-yyyy'), to_date('16-07-2011', 'dd-mm-yyyy'), 9, 6239, to_date('05-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071023006729, to_date('23-10-2007', 'dd-mm-yyyy'), to_date('06-11-2007', 'dd-mm-yyyy'), 3, 5853, to_date('10-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317006730, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 9, 2369, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100319006731, to_date('19-03-2010', 'dd-mm-yyyy'), to_date('02-04-2010', 'dd-mm-yyyy'), 9, 6227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030420006732, to_date('20-04-2003', 'dd-mm-yyyy'), to_date('04-05-2003', 'dd-mm-yyyy'), 11, 3895, to_date('27-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130916006733, to_date('16-09-2013', 'dd-mm-yyyy'), to_date('30-09-2013', 'dd-mm-yyyy'), 7, 7934, to_date('28-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121123006734, to_date('23-11-2012', 'dd-mm-yyyy'), to_date('07-12-2012', 'dd-mm-yyyy'), 3, 10587, to_date('03-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040731008568, to_date('31-07-2004', 'dd-mm-yyyy'), to_date('14-08-2004', 'dd-mm-yyyy'), 4, 3158, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120509008569, to_date('09-05-2012', 'dd-mm-yyyy'), to_date('23-05-2012', 'dd-mm-yyyy'), 10, 8177, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826008570, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 1, 3842, to_date('11-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030403008571, to_date('03-04-2003', 'dd-mm-yyyy'), to_date('17-04-2003', 'dd-mm-yyyy'), 10, 4308, to_date('05-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050423008572, to_date('23-04-2005', 'dd-mm-yyyy'), to_date('07-05-2005', 'dd-mm-yyyy'), 3, 2980, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140325008573, to_date('25-03-2014', 'dd-mm-yyyy'), to_date('08-04-2014', 'dd-mm-yyyy'), 3, 10204, to_date('07-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030920008574, to_date('20-09-2003', 'dd-mm-yyyy'), to_date('04-10-2003', 'dd-mm-yyyy'), 10, 3499, to_date('28-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110405008575, to_date('05-04-2011', 'dd-mm-yyyy'), to_date('19-04-2011', 'dd-mm-yyyy'), 7, 9295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000721008576, to_date('21-07-2000', 'dd-mm-yyyy'), to_date('04-08-2000', 'dd-mm-yyyy'), 8, 947, to_date('24-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080512008577, to_date('12-05-2008', 'dd-mm-yyyy'), to_date('26-05-2008', 'dd-mm-yyyy'), 8, 4856, to_date('01-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040712008578, to_date('12-07-2004', 'dd-mm-yyyy'), to_date('26-07-2004', 'dd-mm-yyyy'), 11, 3674, to_date('30-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010115008579, to_date('15-01-2001', 'dd-mm-yyyy'), to_date('29-01-2001', 'dd-mm-yyyy'), 3, 2597, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090405008580, to_date('05-04-2009', 'dd-mm-yyyy'), to_date('19-04-2009', 'dd-mm-yyyy'), 2, 7476, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129008581, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 11, 8504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130304008582, to_date('04-03-2013', 'dd-mm-yyyy'), to_date('18-03-2013', 'dd-mm-yyyy'), 6, 8722, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081203008583, to_date('03-12-2008', 'dd-mm-yyyy'), to_date('17-12-2008', 'dd-mm-yyyy'), 9, 6172, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130521008584, to_date('21-05-2013', 'dd-mm-yyyy'), to_date('04-06-2013', 'dd-mm-yyyy'), 9, 9482, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130621008585, to_date('21-06-2013', 'dd-mm-yyyy'), to_date('05-07-2013', 'dd-mm-yyyy'), 11, 8890, to_date('29-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070306008586, to_date('06-03-2007', 'dd-mm-yyyy'), to_date('20-03-2007', 'dd-mm-yyyy'), 1, 5831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000302008587, to_date('02-03-2000', 'dd-mm-yyyy'), to_date('16-03-2000', 'dd-mm-yyyy'), 11, 2800, to_date('06-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110119008588, to_date('19-01-2011', 'dd-mm-yyyy'), to_date('02-02-2011', 'dd-mm-yyyy'), 1, 7929, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060315008589, to_date('15-03-2006', 'dd-mm-yyyy'), to_date('29-03-2006', 'dd-mm-yyyy'), 4, 5122, to_date('19-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421008590, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 5, 6789, to_date('11-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080905008591, to_date('05-09-2008', 'dd-mm-yyyy'), to_date('19-09-2008', 'dd-mm-yyyy'), 9, 9144, to_date('21-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000111008592, to_date('11-01-2000', 'dd-mm-yyyy'), to_date('25-01-2000', 'dd-mm-yyyy'), 9, 1051, to_date('13-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090606008593, to_date('06-06-2009', 'dd-mm-yyyy'), to_date('20-06-2009', 'dd-mm-yyyy'), 11, 9247, to_date('09-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829008594, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 6, 4229, to_date('09-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020104008595, to_date('04-01-2002', 'dd-mm-yyyy'), to_date('18-01-2002', 'dd-mm-yyyy'), 2, 2621, to_date('17-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021209008596, to_date('09-12-2002', 'dd-mm-yyyy'), to_date('23-12-2002', 'dd-mm-yyyy'), 4, 2699, to_date('21-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100706008597, to_date('06-07-2010', 'dd-mm-yyyy'), to_date('20-07-2010', 'dd-mm-yyyy'), 5, 8759, to_date('23-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921008598, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 2, 3754, to_date('10-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030310008599, to_date('10-03-2003', 'dd-mm-yyyy'), to_date('24-03-2003', 'dd-mm-yyyy'), 6, 3259, to_date('14-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070723008600, to_date('23-07-2007', 'dd-mm-yyyy'), to_date('06-08-2007', 'dd-mm-yyyy'), 10, 5618, to_date('30-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140115008601, to_date('15-01-2014', 'dd-mm-yyyy'), to_date('29-01-2014', 'dd-mm-yyyy'), 4, 6579, to_date('03-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040717008602, to_date('17-07-2004', 'dd-mm-yyyy'), to_date('31-07-2004', 'dd-mm-yyyy'), 1, 6257, to_date('28-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030208008603, to_date('08-02-2003', 'dd-mm-yyyy'), to_date('22-02-2003', 'dd-mm-yyyy'), 8, 3054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021028008604, to_date('28-10-2002', 'dd-mm-yyyy'), to_date('11-11-2002', 'dd-mm-yyyy'), 8, 1585, to_date('02-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060911008605, to_date('11-09-2006', 'dd-mm-yyyy'), to_date('25-09-2006', 'dd-mm-yyyy'), 8, 5084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109008606, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 4, 2883, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030602008607, to_date('02-06-2003', 'dd-mm-yyyy'), to_date('16-06-2003', 'dd-mm-yyyy'), 6, 3305, to_date('04-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051001008608, to_date('01-10-2005', 'dd-mm-yyyy'), to_date('15-10-2005', 'dd-mm-yyyy'), 3, 5025, to_date('12-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130820008609, to_date('20-08-2013', 'dd-mm-yyyy'), to_date('03-09-2013', 'dd-mm-yyyy'), 8, 8744, to_date('24-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071221008610, to_date('21-12-2007', 'dd-mm-yyyy'), to_date('04-01-2008', 'dd-mm-yyyy'), 5, 4871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120812008611, to_date('12-08-2012', 'dd-mm-yyyy'), to_date('26-08-2012', 'dd-mm-yyyy'), 6, 8871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000831008612, to_date('31-08-2000', 'dd-mm-yyyy'), to_date('14-09-2000', 'dd-mm-yyyy'), 11, 3146, to_date('08-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080701008613, to_date('01-07-2008', 'dd-mm-yyyy'), to_date('15-07-2008', 'dd-mm-yyyy'), 5, 5896, to_date('04-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010512008614, to_date('12-05-2001', 'dd-mm-yyyy'), to_date('26-05-2001', 'dd-mm-yyyy'), 11, 2791, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100424008615, to_date('24-04-2010', 'dd-mm-yyyy'), to_date('08-05-2010', 'dd-mm-yyyy'), 2, 5383, to_date('07-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060125008616, to_date('25-01-2006', 'dd-mm-yyyy'), to_date('08-02-2006', 'dd-mm-yyyy'), 10, 5142, to_date('28-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100711008617, to_date('11-07-2010', 'dd-mm-yyyy'), to_date('25-07-2010', 'dd-mm-yyyy'), 12, 5217, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090717008618, to_date('17-07-2009', 'dd-mm-yyyy'), to_date('31-07-2009', 'dd-mm-yyyy'), 3, 5506, to_date('26-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010121008619, to_date('21-01-2001', 'dd-mm-yyyy'), to_date('04-02-2001', 'dd-mm-yyyy'), 9, 3319, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130821008620, to_date('21-08-2013', 'dd-mm-yyyy'), to_date('04-09-2013', 'dd-mm-yyyy'), 4, 9272, to_date('05-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080101008621, to_date('01-01-2008', 'dd-mm-yyyy'), to_date('15-01-2008', 'dd-mm-yyyy'), 9, 7237, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080530008622, to_date('30-05-2008', 'dd-mm-yyyy'), to_date('13-06-2008', 'dd-mm-yyyy'), 4, 6731, to_date('08-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001213008623, to_date('13-12-2000', 'dd-mm-yyyy'), to_date('27-12-2000', 'dd-mm-yyyy'), 11, 2114, to_date('23-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901008624, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 6, 1910, to_date('13-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130120008625, to_date('20-01-2013', 'dd-mm-yyyy'), to_date('03-02-2013', 'dd-mm-yyyy'), 2, 10551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140510008626, to_date('10-05-2014', 'dd-mm-yyyy'), to_date('24-05-2014', 'dd-mm-yyyy'), 5, 6423, to_date('23-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070618008627, to_date('18-06-2007', 'dd-mm-yyyy'), to_date('02-07-2007', 'dd-mm-yyyy'), 9, 5369, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120920008628, to_date('20-09-2012', 'dd-mm-yyyy'), to_date('04-10-2012', 'dd-mm-yyyy'), 5, 6464, to_date('02-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000416008629, to_date('16-04-2000', 'dd-mm-yyyy'), to_date('30-04-2000', 'dd-mm-yyyy'), 5, 3882, to_date('03-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080404008630, to_date('04-04-2008', 'dd-mm-yyyy'), to_date('18-04-2008', 'dd-mm-yyyy'), 10, 6687, to_date('11-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070101008631, to_date('01-01-2007', 'dd-mm-yyyy'), to_date('15-01-2007', 'dd-mm-yyyy'), 6, 5175, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140116008632, to_date('16-01-2014', 'dd-mm-yyyy'), to_date('30-01-2014', 'dd-mm-yyyy'), 5, 10686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130503008633, to_date('03-05-2013', 'dd-mm-yyyy'), to_date('17-05-2013', 'dd-mm-yyyy'), 9, 8909, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130814008634, to_date('14-08-2013', 'dd-mm-yyyy'), to_date('28-08-2013', 'dd-mm-yyyy'), 3, 11013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020722008635, to_date('22-07-2002', 'dd-mm-yyyy'), to_date('05-08-2002', 'dd-mm-yyyy'), 9, 1974, to_date('07-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091207008636, to_date('07-12-2009', 'dd-mm-yyyy'), to_date('21-12-2009', 'dd-mm-yyyy'), 6, 5393, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126008637, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 3, 5334, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061104008638, to_date('04-11-2006', 'dd-mm-yyyy'), to_date('18-11-2006', 'dd-mm-yyyy'), 2, 4562, to_date('11-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121002008639, to_date('02-10-2012', 'dd-mm-yyyy'), to_date('16-10-2012', 'dd-mm-yyyy'), 10, 6324, to_date('08-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090218008640, to_date('18-02-2009', 'dd-mm-yyyy'), to_date('04-03-2009', 'dd-mm-yyyy'), 3, 6539, to_date('21-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030618008641, to_date('18-06-2003', 'dd-mm-yyyy'), to_date('02-07-2003', 'dd-mm-yyyy'), 3, 2726, to_date('08-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020822008642, to_date('22-08-2002', 'dd-mm-yyyy'), to_date('05-09-2002', 'dd-mm-yyyy'), 12, 1436, to_date('07-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060506008643, to_date('06-05-2006', 'dd-mm-yyyy'), to_date('20-05-2006', 'dd-mm-yyyy'), 7, 4158, to_date('13-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051226008644, to_date('26-12-2005', 'dd-mm-yyyy'), to_date('09-01-2006', 'dd-mm-yyyy'), 3, 5398, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100328008645, to_date('28-03-2010', 'dd-mm-yyyy'), to_date('11-04-2010', 'dd-mm-yyyy'), 6, 8557, to_date('15-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070524008646, to_date('24-05-2007', 'dd-mm-yyyy'), to_date('07-06-2007', 'dd-mm-yyyy'), 4, 4826, to_date('27-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013008647, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 7, 3154, to_date('24-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707008648, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 10, 3433, to_date('14-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608008649, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 3, 7817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317008650, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 7, 4825, to_date('31-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021221008651, to_date('21-12-2002', 'dd-mm-yyyy'), to_date('04-01-2003', 'dd-mm-yyyy'), 9, 1969, to_date('31-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710008652, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 9, 1118, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020206008653, to_date('06-02-2002', 'dd-mm-yyyy'), to_date('20-02-2002', 'dd-mm-yyyy'), 6, 3118, to_date('25-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070301008654, to_date('01-03-2007', 'dd-mm-yyyy'), to_date('15-03-2007', 'dd-mm-yyyy'), 5, 5272, to_date('03-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806008655, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 10, 9766, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060608008656, to_date('08-06-2006', 'dd-mm-yyyy'), to_date('22-06-2006', 'dd-mm-yyyy'), 10, 3601, to_date('24-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000107008657, to_date('07-01-2000', 'dd-mm-yyyy'), to_date('21-01-2000', 'dd-mm-yyyy'), 12, 2551, to_date('10-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051208008658, to_date('08-12-2005', 'dd-mm-yyyy'), to_date('22-12-2005', 'dd-mm-yyyy'), 5, 6677, to_date('21-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111008659, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 3, 2969, to_date('27-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080217008660, to_date('17-02-2008', 'dd-mm-yyyy'), to_date('02-03-2008', 'dd-mm-yyyy'), 6, 3987, to_date('04-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070626008661, to_date('26-06-2007', 'dd-mm-yyyy'), to_date('10-07-2007', 'dd-mm-yyyy'), 7, 5374, to_date('08-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000317008662, to_date('17-03-2000', 'dd-mm-yyyy'), to_date('31-03-2000', 'dd-mm-yyyy'), 9, 2037, to_date('03-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408008663, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 9, 2684, to_date('10-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100228008664, to_date('28-02-2010', 'dd-mm-yyyy'), to_date('14-03-2010', 'dd-mm-yyyy'), 10, 5933, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001008665, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 2, 2346, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040403008666, to_date('03-04-2004', 'dd-mm-yyyy'), to_date('17-04-2004', 'dd-mm-yyyy'), 6, 4187, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050616008667, to_date('16-06-2005', 'dd-mm-yyyy'), to_date('30-06-2005', 'dd-mm-yyyy'), 10, 3002, to_date('20-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929008668, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 8, 5132, to_date('11-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071126008669, to_date('26-11-2007', 'dd-mm-yyyy'), to_date('10-12-2007', 'dd-mm-yyyy'), 6, 4325, to_date('11-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040104008670, to_date('04-01-2004', 'dd-mm-yyyy'), to_date('18-01-2004', 'dd-mm-yyyy'), 3, 2863, to_date('15-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313008671, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 4, 9872, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090406008672, to_date('06-04-2009', 'dd-mm-yyyy'), to_date('20-04-2009', 'dd-mm-yyyy'), 7, 8506, to_date('25-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726008673, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 2, 998, to_date('03-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080911008674, to_date('11-09-2008', 'dd-mm-yyyy'), to_date('25-09-2008', 'dd-mm-yyyy'), 10, 6871, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130513008675, to_date('13-05-2013', 'dd-mm-yyyy'), to_date('27-05-2013', 'dd-mm-yyyy'), 11, 6734, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527008676, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 3, 3080, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080813008677, to_date('13-08-2008', 'dd-mm-yyyy'), to_date('27-08-2008', 'dd-mm-yyyy'), 4, 7920, to_date('22-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127008678, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 6, 3364, to_date('01-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040929008679, to_date('29-09-2004', 'dd-mm-yyyy'), to_date('13-10-2004', 'dd-mm-yyyy'), 9, 2954, to_date('16-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926008680, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 11, 4461, to_date('06-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070629008681, to_date('29-06-2007', 'dd-mm-yyyy'), to_date('13-07-2007', 'dd-mm-yyyy'), 7, 6247, to_date('12-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131212008682, to_date('12-12-2013', 'dd-mm-yyyy'), to_date('26-12-2013', 'dd-mm-yyyy'), 6, 7659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090823008683, to_date('23-08-2009', 'dd-mm-yyyy'), to_date('06-09-2009', 'dd-mm-yyyy'), 10, 8123, to_date('27-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030529008684, to_date('29-05-2003', 'dd-mm-yyyy'), to_date('12-06-2003', 'dd-mm-yyyy'), 3, 2595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402008685, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 6, 9506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100102008686, to_date('02-01-2010', 'dd-mm-yyyy'), to_date('16-01-2010', 'dd-mm-yyyy'), 6, 5929, to_date('13-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711008687, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 6, 6142, to_date('24-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040621008688, to_date('21-06-2004', 'dd-mm-yyyy'), to_date('05-07-2004', 'dd-mm-yyyy'), 8, 3312, to_date('29-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100420008689, to_date('20-04-2010', 'dd-mm-yyyy'), to_date('04-05-2010', 'dd-mm-yyyy'), 5, 7180, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020416008690, to_date('16-04-2002', 'dd-mm-yyyy'), to_date('30-04-2002', 'dd-mm-yyyy'), 9, 2925, to_date('18-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110125008691, to_date('25-01-2011', 'dd-mm-yyyy'), to_date('08-02-2011', 'dd-mm-yyyy'), 3, 6617, to_date('30-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626008692, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 10, 6152, to_date('13-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120606008693, to_date('06-06-2012', 'dd-mm-yyyy'), to_date('20-06-2012', 'dd-mm-yyyy'), 11, 6185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110502008694, to_date('02-05-2011', 'dd-mm-yyyy'), to_date('16-05-2011', 'dd-mm-yyyy'), 3, 7617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070725008695, to_date('25-07-2007', 'dd-mm-yyyy'), to_date('08-08-2007', 'dd-mm-yyyy'), 6, 6552, to_date('07-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111027008696, to_date('27-10-2011', 'dd-mm-yyyy'), to_date('10-11-2011', 'dd-mm-yyyy'), 5, 9533, to_date('04-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130225008697, to_date('25-02-2013', 'dd-mm-yyyy'), to_date('11-03-2013', 'dd-mm-yyyy'), 8, 7862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010401008698, to_date('01-04-2001', 'dd-mm-yyyy'), to_date('15-04-2001', 'dd-mm-yyyy'), 1, 2466, to_date('14-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060225008699, to_date('25-02-2006', 'dd-mm-yyyy'), to_date('11-03-2006', 'dd-mm-yyyy'), 10, 6550, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101226008700, to_date('26-12-2010', 'dd-mm-yyyy'), to_date('09-01-2011', 'dd-mm-yyyy'), 3, 6489, to_date('30-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120130008701, to_date('30-01-2012', 'dd-mm-yyyy'), to_date('13-02-2012', 'dd-mm-yyyy'), 9, 9222, to_date('04-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110101008702, to_date('01-01-2011', 'dd-mm-yyyy'), to_date('15-01-2011', 'dd-mm-yyyy'), 6, 8361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040105008703, to_date('05-01-2004', 'dd-mm-yyyy'), to_date('19-01-2004', 'dd-mm-yyyy'), 8, 6738, to_date('14-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020711008704, to_date('11-07-2002', 'dd-mm-yyyy'), to_date('25-07-2002', 'dd-mm-yyyy'), 8, 2383, to_date('22-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051119008705, to_date('19-11-2005', 'dd-mm-yyyy'), to_date('03-12-2005', 'dd-mm-yyyy'), 8, 5050, to_date('08-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603008706, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 11, 3548, to_date('10-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728008707, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 9, 9234, to_date('05-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050728008708, to_date('28-07-2005', 'dd-mm-yyyy'), to_date('11-08-2005', 'dd-mm-yyyy'), 7, 2893, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070717008709, to_date('17-07-2007', 'dd-mm-yyyy'), to_date('31-07-2007', 'dd-mm-yyyy'), 11, 7212, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110902008710, to_date('02-09-2011', 'dd-mm-yyyy'), to_date('16-09-2011', 'dd-mm-yyyy'), 8, 6642, to_date('22-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010804008711, to_date('04-08-2001', 'dd-mm-yyyy'), to_date('18-08-2001', 'dd-mm-yyyy'), 11, 3431, to_date('12-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040515008712, to_date('15-05-2004', 'dd-mm-yyyy'), to_date('29-05-2004', 'dd-mm-yyyy'), 8, 7086, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120917008713, to_date('17-09-2012', 'dd-mm-yyyy'), to_date('01-10-2012', 'dd-mm-yyyy'), 10, 7590, to_date('02-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060310008714, to_date('10-03-2006', 'dd-mm-yyyy'), to_date('24-03-2006', 'dd-mm-yyyy'), 5, 6719, to_date('24-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140213008715, to_date('13-02-2014', 'dd-mm-yyyy'), to_date('27-02-2014', 'dd-mm-yyyy'), 4, 8329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100511008716, to_date('11-05-2010', 'dd-mm-yyyy'), to_date('25-05-2010', 'dd-mm-yyyy'), 9, 6728, to_date('14-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110124008717, to_date('24-01-2011', 'dd-mm-yyyy'), to_date('07-02-2011', 'dd-mm-yyyy'), 3, 6049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041016008718, to_date('16-10-2004', 'dd-mm-yyyy'), to_date('30-10-2004', 'dd-mm-yyyy'), 10, 4616, to_date('28-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000816008719, to_date('16-08-2000', 'dd-mm-yyyy'), to_date('30-08-2000', 'dd-mm-yyyy'), 4, 2264, to_date('18-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607001989, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 1, 3849, to_date('24-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131016001990, to_date('16-10-2013', 'dd-mm-yyyy'), to_date('30-10-2013', 'dd-mm-yyyy'), 8, 7806, to_date('02-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121117001991, to_date('17-11-2012', 'dd-mm-yyyy'), to_date('01-12-2012', 'dd-mm-yyyy'), 11, 9298, to_date('25-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408001992, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 4, 7536, to_date('25-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120819001993, to_date('19-08-2012', 'dd-mm-yyyy'), to_date('02-09-2012', 'dd-mm-yyyy'), 8, 6878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030509001994, to_date('09-05-2003', 'dd-mm-yyyy'), to_date('23-05-2003', 'dd-mm-yyyy'), 2, 2832, to_date('28-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070709001995, to_date('09-07-2007', 'dd-mm-yyyy'), to_date('23-07-2007', 'dd-mm-yyyy'), 2, 7228, to_date('22-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041126001996, to_date('26-11-2004', 'dd-mm-yyyy'), to_date('10-12-2004', 'dd-mm-yyyy'), 3, 4394, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050806001997, to_date('06-08-2005', 'dd-mm-yyyy'), to_date('20-08-2005', 'dd-mm-yyyy'), 11, 4076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070218001998, to_date('18-02-2007', 'dd-mm-yyyy'), to_date('04-03-2007', 'dd-mm-yyyy'), 11, 4609, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827001999, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 5, 1881, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130621002000, to_date('21-06-2013', 'dd-mm-yyyy'), to_date('05-07-2013', 'dd-mm-yyyy'), 6, 6370, to_date('06-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140116002001, to_date('16-01-2014', 'dd-mm-yyyy'), to_date('30-01-2014', 'dd-mm-yyyy'), 8, 10235, to_date('04-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112002002, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 12, 6516, to_date('01-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000822002003, to_date('22-08-2000', 'dd-mm-yyyy'), to_date('05-09-2000', 'dd-mm-yyyy'), 8, 1382, to_date('09-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000305002004, to_date('05-03-2000', 'dd-mm-yyyy'), to_date('19-03-2000', 'dd-mm-yyyy'), 10, 1176, to_date('07-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100909002005, to_date('09-09-2010', 'dd-mm-yyyy'), to_date('23-09-2010', 'dd-mm-yyyy'), 5, 6709, to_date('19-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030412002006, to_date('12-04-2003', 'dd-mm-yyyy'), to_date('26-04-2003', 'dd-mm-yyyy'), 9, 2369, to_date('17-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107002007, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 3, 6571, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020530002008, to_date('30-05-2002', 'dd-mm-yyyy'), to_date('13-06-2002', 'dd-mm-yyyy'), 10, 3688, to_date('04-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403002009, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 3, 8391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080712002010, to_date('12-07-2008', 'dd-mm-yyyy'), to_date('26-07-2008', 'dd-mm-yyyy'), 6, 6861, to_date('28-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081030002011, to_date('30-10-2008', 'dd-mm-yyyy'), to_date('13-11-2008', 'dd-mm-yyyy'), 3, 6178, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091106002012, to_date('06-11-2009', 'dd-mm-yyyy'), to_date('20-11-2009', 'dd-mm-yyyy'), 10, 5607, to_date('17-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022002013, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 7, 4662, to_date('04-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120327002014, to_date('27-03-2012', 'dd-mm-yyyy'), to_date('10-04-2012', 'dd-mm-yyyy'), 5, 5015, to_date('04-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218002015, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 10, 6508, to_date('23-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090602002016, to_date('02-06-2009', 'dd-mm-yyyy'), to_date('16-06-2009', 'dd-mm-yyyy'), 12, 5159, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016002017, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 8, 8544, to_date('02-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060213002018, to_date('13-02-2006', 'dd-mm-yyyy'), to_date('27-02-2006', 'dd-mm-yyyy'), 4, 6788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070515002019, to_date('15-05-2007', 'dd-mm-yyyy'), to_date('29-05-2007', 'dd-mm-yyyy'), 10, 8218, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060724002020, to_date('24-07-2006', 'dd-mm-yyyy'), to_date('07-08-2006', 'dd-mm-yyyy'), 1, 4898, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000413002021, to_date('13-04-2000', 'dd-mm-yyyy'), to_date('27-04-2000', 'dd-mm-yyyy'), 6, 836, to_date('24-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071208002022, to_date('08-12-2007', 'dd-mm-yyyy'), to_date('22-12-2007', 'dd-mm-yyyy'), 5, 6469, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728002023, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 5, 7630, to_date('06-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140415002024, to_date('15-04-2014', 'dd-mm-yyyy'), to_date('29-04-2014', 'dd-mm-yyyy'), 11, 8992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100502002025, to_date('02-05-2010', 'dd-mm-yyyy'), to_date('16-05-2010', 'dd-mm-yyyy'), 5, 6942, to_date('19-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010002026, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 1, 6445, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080329002027, to_date('29-03-2008', 'dd-mm-yyyy'), to_date('12-04-2008', 'dd-mm-yyyy'), 5, 10201, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140514002028, to_date('14-05-2014', 'dd-mm-yyyy'), to_date('28-05-2014', 'dd-mm-yyyy'), 3, 8585, to_date('23-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050603002029, to_date('03-06-2005', 'dd-mm-yyyy'), to_date('17-06-2005', 'dd-mm-yyyy'), 9, 2962, to_date('07-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618002030, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 5, 1455, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081218002031, to_date('18-12-2008', 'dd-mm-yyyy'), to_date('01-01-2009', 'dd-mm-yyyy'), 8, 5483, to_date('23-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604002032, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 5, 7599, to_date('24-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031106002033, to_date('06-11-2003', 'dd-mm-yyyy'), to_date('20-11-2003', 'dd-mm-yyyy'), 4, 3933, to_date('20-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001003002034, to_date('03-10-2000', 'dd-mm-yyyy'), to_date('17-10-2000', 'dd-mm-yyyy'), 11, 2680, to_date('11-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070916002035, to_date('16-09-2007', 'dd-mm-yyyy'), to_date('30-09-2007', 'dd-mm-yyyy'), 8, 7955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040107002036, to_date('07-01-2004', 'dd-mm-yyyy'), to_date('21-01-2004', 'dd-mm-yyyy'), 4, 3253, to_date('16-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081224002037, to_date('24-12-2008', 'dd-mm-yyyy'), to_date('07-01-2009', 'dd-mm-yyyy'), 5, 6592, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080322002038, to_date('22-03-2008', 'dd-mm-yyyy'), to_date('05-04-2008', 'dd-mm-yyyy'), 11, 6569, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131102002039, to_date('02-11-2013', 'dd-mm-yyyy'), to_date('16-11-2013', 'dd-mm-yyyy'), 10, 7757, to_date('19-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090222002040, to_date('22-02-2009', 'dd-mm-yyyy'), to_date('08-03-2009', 'dd-mm-yyyy'), 4, 6613, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041101002041, to_date('01-11-2004', 'dd-mm-yyyy'), to_date('15-11-2004', 'dd-mm-yyyy'), 6, 3630, to_date('20-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317002042, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 10, 3323, to_date('22-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130331002043, to_date('31-03-2013', 'dd-mm-yyyy'), to_date('14-04-2013', 'dd-mm-yyyy'), 3, 5559, to_date('19-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000520002044, to_date('20-05-2000', 'dd-mm-yyyy'), to_date('03-06-2000', 'dd-mm-yyyy'), 1, 1803, to_date('27-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423002045, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 12, 7944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121019002046, to_date('19-10-2012', 'dd-mm-yyyy'), to_date('02-11-2012', 'dd-mm-yyyy'), 8, 6937, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040321002047, to_date('21-03-2004', 'dd-mm-yyyy'), to_date('04-04-2004', 'dd-mm-yyyy'), 12, 7191, to_date('05-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029002048, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 5, 4627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113002049, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 6, 9653, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404002050, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 11, 1499, to_date('22-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050316002051, to_date('16-03-2005', 'dd-mm-yyyy'), to_date('30-03-2005', 'dd-mm-yyyy'), 5, 4793, to_date('27-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080926002052, to_date('26-09-2008', 'dd-mm-yyyy'), to_date('10-10-2008', 'dd-mm-yyyy'), 6, 5075, to_date('09-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330002053, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 12, 7550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090410002054, to_date('10-04-2009', 'dd-mm-yyyy'), to_date('24-04-2009', 'dd-mm-yyyy'), 9, 6759, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100208002055, to_date('08-02-2010', 'dd-mm-yyyy'), to_date('22-02-2010', 'dd-mm-yyyy'), 3, 6948, to_date('20-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100315002056, to_date('15-03-2010', 'dd-mm-yyyy'), to_date('29-03-2010', 'dd-mm-yyyy'), 12, 6639, to_date('23-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130706002057, to_date('06-07-2013', 'dd-mm-yyyy'), to_date('20-07-2013', 'dd-mm-yyyy'), 2, 9311, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020417002058, to_date('17-04-2002', 'dd-mm-yyyy'), to_date('01-05-2002', 'dd-mm-yyyy'), 8, 2170, to_date('27-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021002059, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 2, 8694, to_date('31-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018002060, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 11, 1922, to_date('05-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511002061, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 11, 2002, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010704002062, to_date('04-07-2001', 'dd-mm-yyyy'), to_date('18-07-2001', 'dd-mm-yyyy'), 5, 3404, to_date('14-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071218002063, to_date('18-12-2007', 'dd-mm-yyyy'), to_date('01-01-2008', 'dd-mm-yyyy'), 4, 6654, to_date('27-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501002064, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 10, 3116, to_date('04-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140104002065, to_date('04-01-2014', 'dd-mm-yyyy'), to_date('18-01-2014', 'dd-mm-yyyy'), 12, 10305, to_date('20-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010607002066, to_date('07-06-2001', 'dd-mm-yyyy'), to_date('21-06-2001', 'dd-mm-yyyy'), 8, 898, to_date('20-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040403002067, to_date('03-04-2004', 'dd-mm-yyyy'), to_date('17-04-2004', 'dd-mm-yyyy'), 8, 3162, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226002068, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 8, 4653, to_date('09-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010615002069, to_date('15-06-2001', 'dd-mm-yyyy'), to_date('29-06-2001', 'dd-mm-yyyy'), 11, 1752, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504002070, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 7, 2990, to_date('07-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070816002071, to_date('16-08-2007', 'dd-mm-yyyy'), to_date('30-08-2007', 'dd-mm-yyyy'), 4, 4907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030902002072, to_date('02-09-2003', 'dd-mm-yyyy'), to_date('16-09-2003', 'dd-mm-yyyy'), 7, 3904, to_date('17-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041216002073, to_date('16-12-2004', 'dd-mm-yyyy'), to_date('30-12-2004', 'dd-mm-yyyy'), 4, 5220, to_date('31-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051004002074, to_date('04-10-2005', 'dd-mm-yyyy'), to_date('18-10-2005', 'dd-mm-yyyy'), 11, 3958, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105002075, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 4, 2745, to_date('24-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100804002076, to_date('04-08-2010', 'dd-mm-yyyy'), to_date('18-08-2010', 'dd-mm-yyyy'), 7, 7536, to_date('22-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021103002077, to_date('03-11-2002', 'dd-mm-yyyy'), to_date('17-11-2002', 'dd-mm-yyyy'), 4, 2351, to_date('08-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081210002078, to_date('10-12-2008', 'dd-mm-yyyy'), to_date('24-12-2008', 'dd-mm-yyyy'), 2, 3818, to_date('23-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514002079, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 6, 6288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080420002080, to_date('20-04-2008', 'dd-mm-yyyy'), to_date('04-05-2008', 'dd-mm-yyyy'), 11, 5849, to_date('04-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080510002081, to_date('10-05-2008', 'dd-mm-yyyy'), to_date('24-05-2008', 'dd-mm-yyyy'), 8, 6390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050121002082, to_date('21-01-2005', 'dd-mm-yyyy'), to_date('04-02-2005', 'dd-mm-yyyy'), 3, 4160, to_date('09-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030903002083, to_date('03-09-2003', 'dd-mm-yyyy'), to_date('17-09-2003', 'dd-mm-yyyy'), 3, 3858, to_date('14-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061016002084, to_date('16-10-2006', 'dd-mm-yyyy'), to_date('30-10-2006', 'dd-mm-yyyy'), 12, 5291, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011209002085, to_date('09-12-2001', 'dd-mm-yyyy'), to_date('23-12-2001', 'dd-mm-yyyy'), 11, 1073, to_date('22-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060424002086, to_date('24-04-2006', 'dd-mm-yyyy'), to_date('08-05-2006', 'dd-mm-yyyy'), 6, 3444, to_date('03-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215002087, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 6, 7909, to_date('18-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070821002088, to_date('21-08-2007', 'dd-mm-yyyy'), to_date('04-09-2007', 'dd-mm-yyyy'), 10, 3740, to_date('31-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603002089, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 4, 4278, to_date('21-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110622002090, to_date('22-06-2011', 'dd-mm-yyyy'), to_date('06-07-2011', 'dd-mm-yyyy'), 2, 7353, to_date('01-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000922002091, to_date('22-09-2000', 'dd-mm-yyyy'), to_date('06-10-2000', 'dd-mm-yyyy'), 3, 2175, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060910002092, to_date('10-09-2006', 'dd-mm-yyyy'), to_date('24-09-2006', 'dd-mm-yyyy'), 6, 4729, to_date('17-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000504002093, to_date('04-05-2000', 'dd-mm-yyyy'), to_date('18-05-2000', 'dd-mm-yyyy'), 3, 1684, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215002094, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 2, 5824, to_date('24-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091130002095, to_date('30-11-2009', 'dd-mm-yyyy'), to_date('14-12-2009', 'dd-mm-yyyy'), 7, 4343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041105002096, to_date('05-11-2004', 'dd-mm-yyyy'), to_date('19-11-2004', 'dd-mm-yyyy'), 4, 4990, to_date('08-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060414002097, to_date('14-04-2006', 'dd-mm-yyyy'), to_date('28-04-2006', 'dd-mm-yyyy'), 5, 4733, to_date('30-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110407002098, to_date('07-04-2011', 'dd-mm-yyyy'), to_date('21-04-2011', 'dd-mm-yyyy'), 5, 6515, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130409002099, to_date('09-04-2013', 'dd-mm-yyyy'), to_date('23-04-2013', 'dd-mm-yyyy'), 10, 7963, to_date('11-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030625002100, to_date('25-06-2003', 'dd-mm-yyyy'), to_date('09-07-2003', 'dd-mm-yyyy'), 7, 3490, to_date('28-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070114002101, to_date('14-01-2007', 'dd-mm-yyyy'), to_date('28-01-2007', 'dd-mm-yyyy'), 2, 7800, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120417002102, to_date('17-04-2012', 'dd-mm-yyyy'), to_date('01-05-2012', 'dd-mm-yyyy'), 8, 9780, to_date('18-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815002103, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 12, 2087, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306002104, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 1, 3215, to_date('18-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214002105, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 11, 6719, to_date('27-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121002106, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 11, 8217, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060611002107, to_date('11-06-2006', 'dd-mm-yyyy'), to_date('25-06-2006', 'dd-mm-yyyy'), 2, 6984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090320002108, to_date('20-03-2009', 'dd-mm-yyyy'), to_date('03-04-2009', 'dd-mm-yyyy'), 3, 5849, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010717002109, to_date('17-07-2001', 'dd-mm-yyyy'), to_date('31-07-2001', 'dd-mm-yyyy'), 6, 1246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070915002110, to_date('15-09-2007', 'dd-mm-yyyy'), to_date('29-09-2007', 'dd-mm-yyyy'), 8, 3862, to_date('03-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120814002111, to_date('14-08-2012', 'dd-mm-yyyy'), to_date('28-08-2012', 'dd-mm-yyyy'), 12, 8714, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060320002112, to_date('20-03-2006', 'dd-mm-yyyy'), to_date('03-04-2006', 'dd-mm-yyyy'), 10, 5063, to_date('27-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010112002113, to_date('12-01-2001', 'dd-mm-yyyy'), to_date('26-01-2001', 'dd-mm-yyyy'), 4, 1335, to_date('28-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021220002114, to_date('20-12-2002', 'dd-mm-yyyy'), to_date('03-01-2003', 'dd-mm-yyyy'), 7, 2477, to_date('30-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130727002115, to_date('27-07-2013', 'dd-mm-yyyy'), to_date('10-08-2013', 'dd-mm-yyyy'), 5, 7776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051012002116, to_date('12-10-2005', 'dd-mm-yyyy'), to_date('26-10-2005', 'dd-mm-yyyy'), 6, 5291, to_date('21-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708002117, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 12, 7153, to_date('19-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031109002118, to_date('09-11-2003', 'dd-mm-yyyy'), to_date('23-11-2003', 'dd-mm-yyyy'), 5, 3046, to_date('12-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229002119, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 11, 6290, to_date('14-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020919002120, to_date('19-09-2002', 'dd-mm-yyyy'), to_date('03-10-2002', 'dd-mm-yyyy'), 1, 5004, to_date('25-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417002121, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 9, 2943, to_date('04-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081129002122, to_date('29-11-2008', 'dd-mm-yyyy'), to_date('13-12-2008', 'dd-mm-yyyy'), 9, 3881, to_date('08-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060201002123, to_date('01-02-2006', 'dd-mm-yyyy'), to_date('15-02-2006', 'dd-mm-yyyy'), 10, 3941, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080706002124, to_date('06-07-2008', 'dd-mm-yyyy'), to_date('20-07-2008', 'dd-mm-yyyy'), 2, 7330, to_date('13-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000322002125, to_date('22-03-2000', 'dd-mm-yyyy'), to_date('05-04-2000', 'dd-mm-yyyy'), 6, 2047, to_date('25-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110312002126, to_date('12-03-2011', 'dd-mm-yyyy'), to_date('26-03-2011', 'dd-mm-yyyy'), 2, 5889, to_date('19-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071102002127, to_date('02-11-2007', 'dd-mm-yyyy'), to_date('16-11-2007', 'dd-mm-yyyy'), 4, 4942, to_date('13-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030403002128, to_date('03-04-2003', 'dd-mm-yyyy'), to_date('17-04-2003', 'dd-mm-yyyy'), 9, 3277, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010815002129, to_date('15-08-2001', 'dd-mm-yyyy'), to_date('29-08-2001', 'dd-mm-yyyy'), 3, 3658, to_date('27-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120002130, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 6, 6082, to_date('02-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604002131, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 11, 5917, to_date('22-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301002132, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 11, 3583, to_date('07-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110113002133, to_date('13-01-2011', 'dd-mm-yyyy'), to_date('27-01-2011', 'dd-mm-yyyy'), 7, 7063, to_date('23-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030517002134, to_date('17-05-2003', 'dd-mm-yyyy'), to_date('31-05-2003', 'dd-mm-yyyy'), 1, 2645, to_date('19-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119002135, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 7, 2763, to_date('09-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020925002136, to_date('25-09-2002', 'dd-mm-yyyy'), to_date('09-10-2002', 'dd-mm-yyyy'), 7, 2559, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130206002137, to_date('06-02-2013', 'dd-mm-yyyy'), to_date('20-02-2013', 'dd-mm-yyyy'), 2, 9835, to_date('19-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080116002138, to_date('16-01-2008', 'dd-mm-yyyy'), to_date('30-01-2008', 'dd-mm-yyyy'), 9, 5013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511002139, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 3, 1957, to_date('27-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050525002140, to_date('25-05-2005', 'dd-mm-yyyy'), to_date('08-06-2005', 'dd-mm-yyyy'), 7, 4902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070127002141, to_date('27-01-2007', 'dd-mm-yyyy'), to_date('10-02-2007', 'dd-mm-yyyy'), 11, 5083, to_date('30-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060301004441, to_date('01-03-2006', 'dd-mm-yyyy'), to_date('15-03-2006', 'dd-mm-yyyy'), 12, 4541, to_date('03-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000924004442, to_date('24-09-2000', 'dd-mm-yyyy'), to_date('08-10-2000', 'dd-mm-yyyy'), 9, 1798, to_date('03-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080802004443, to_date('02-08-2008', 'dd-mm-yyyy'), to_date('16-08-2008', 'dd-mm-yyyy'), 4, 7680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091204004444, to_date('04-12-2009', 'dd-mm-yyyy'), to_date('18-12-2009', 'dd-mm-yyyy'), 6, 9043, to_date('09-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060928004445, to_date('28-09-2006', 'dd-mm-yyyy'), to_date('12-10-2006', 'dd-mm-yyyy'), 7, 4448, to_date('30-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317004446, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 3, 7246, to_date('02-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140322004447, to_date('22-03-2014', 'dd-mm-yyyy'), to_date('05-04-2014', 'dd-mm-yyyy'), 9, 8846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071128004448, to_date('28-11-2007', 'dd-mm-yyyy'), to_date('12-12-2007', 'dd-mm-yyyy'), 3, 5359, to_date('11-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020622004449, to_date('22-06-2002', 'dd-mm-yyyy'), to_date('06-07-2002', 'dd-mm-yyyy'), 2, 2797, to_date('09-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020613004450, to_date('13-06-2002', 'dd-mm-yyyy'), to_date('27-06-2002', 'dd-mm-yyyy'), 12, 3976, to_date('24-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001224004451, to_date('24-12-2000', 'dd-mm-yyyy'), to_date('07-01-2001', 'dd-mm-yyyy'), 6, 1813, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040207004452, to_date('07-02-2004', 'dd-mm-yyyy'), to_date('21-02-2004', 'dd-mm-yyyy'), 10, 4783, to_date('17-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030525004453, to_date('25-05-2003', 'dd-mm-yyyy'), to_date('08-06-2003', 'dd-mm-yyyy'), 7, 2723, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110718004454, to_date('18-07-2011', 'dd-mm-yyyy'), to_date('01-08-2011', 'dd-mm-yyyy'), 7, 7113, to_date('23-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100214004455, to_date('14-02-2010', 'dd-mm-yyyy'), to_date('28-02-2010', 'dd-mm-yyyy'), 6, 7876, to_date('25-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110322004456, to_date('22-03-2011', 'dd-mm-yyyy'), to_date('05-04-2011', 'dd-mm-yyyy'), 3, 6176, to_date('10-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213004457, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 10, 4516, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070527004458, to_date('27-05-2007', 'dd-mm-yyyy'), to_date('10-06-2007', 'dd-mm-yyyy'), 10, 7789, to_date('12-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071120004459, to_date('20-11-2007', 'dd-mm-yyyy'), to_date('04-12-2007', 'dd-mm-yyyy'), 5, 4974, to_date('04-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130429004460, to_date('29-04-2013', 'dd-mm-yyyy'), to_date('13-05-2013', 'dd-mm-yyyy'), 8, 9487, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081230004461, to_date('30-12-2008', 'dd-mm-yyyy'), to_date('13-01-2009', 'dd-mm-yyyy'), 7, 7859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622004462, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 8, 4537, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530004463, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 12, 10943, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120613004464, to_date('13-06-2012', 'dd-mm-yyyy'), to_date('27-06-2012', 'dd-mm-yyyy'), 2, 9784, to_date('21-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010117004465, to_date('17-01-2001', 'dd-mm-yyyy'), to_date('31-01-2001', 'dd-mm-yyyy'), 3, 2115, to_date('03-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020221004466, to_date('21-02-2002', 'dd-mm-yyyy'), to_date('07-03-2002', 'dd-mm-yyyy'), 1, 1446, to_date('24-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080820004467, to_date('20-08-2008', 'dd-mm-yyyy'), to_date('03-09-2008', 'dd-mm-yyyy'), 2, 5388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811004468, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 11, 7359, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821004469, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 6, 7440, to_date('22-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010726004470, to_date('26-07-2001', 'dd-mm-yyyy'), to_date('09-08-2001', 'dd-mm-yyyy'), 2, 2964, to_date('28-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010913004471, to_date('13-09-2001', 'dd-mm-yyyy'), to_date('27-09-2001', 'dd-mm-yyyy'), 6, 3033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121228004472, to_date('28-12-2012', 'dd-mm-yyyy'), to_date('11-01-2013', 'dd-mm-yyyy'), 6, 9859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103004473, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 2, 3827, to_date('08-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131004474, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 2, 9262, to_date('09-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051223004475, to_date('23-12-2005', 'dd-mm-yyyy'), to_date('06-01-2006', 'dd-mm-yyyy'), 4, 4254, to_date('04-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002004476, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 11, 3706, to_date('09-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000827004477, to_date('27-08-2000', 'dd-mm-yyyy'), to_date('10-09-2000', 'dd-mm-yyyy'), 12, 3032, to_date('02-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110201004478, to_date('01-02-2011', 'dd-mm-yyyy'), to_date('15-02-2011', 'dd-mm-yyyy'), 9, 8752, to_date('12-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100126004479, to_date('26-01-2010', 'dd-mm-yyyy'), to_date('09-02-2010', 'dd-mm-yyyy'), 9, 6942, to_date('07-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070723004480, to_date('23-07-2007', 'dd-mm-yyyy'), to_date('06-08-2007', 'dd-mm-yyyy'), 5, 4691, to_date('06-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060503004481, to_date('03-05-2006', 'dd-mm-yyyy'), to_date('17-05-2006', 'dd-mm-yyyy'), 5, 4699, to_date('09-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070216004482, to_date('16-02-2007', 'dd-mm-yyyy'), to_date('02-03-2007', 'dd-mm-yyyy'), 11, 6080, to_date('03-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060611004483, to_date('11-06-2006', 'dd-mm-yyyy'), to_date('25-06-2006', 'dd-mm-yyyy'), 6, 6524, to_date('24-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071012004484, to_date('12-10-2007', 'dd-mm-yyyy'), to_date('26-10-2007', 'dd-mm-yyyy'), 12, 4280, to_date('16-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040229004485, to_date('29-02-2004', 'dd-mm-yyyy'), to_date('14-03-2004', 'dd-mm-yyyy'), 5, 3080, to_date('12-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010911004486, to_date('11-09-2001', 'dd-mm-yyyy'), to_date('25-09-2001', 'dd-mm-yyyy'), 4, 2550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070217004487, to_date('17-02-2007', 'dd-mm-yyyy'), to_date('03-03-2007', 'dd-mm-yyyy'), 9, 7384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080228004488, to_date('28-02-2008', 'dd-mm-yyyy'), to_date('13-03-2008', 'dd-mm-yyyy'), 1, 6699, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227004489, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 11, 5685, to_date('04-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428004490, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 4, 4274, to_date('13-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120311004491, to_date('11-03-2012', 'dd-mm-yyyy'), to_date('25-03-2012', 'dd-mm-yyyy'), 2, 3648, to_date('18-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110918004492, to_date('18-09-2011', 'dd-mm-yyyy'), to_date('02-10-2011', 'dd-mm-yyyy'), 6, 8976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110501004493, to_date('01-05-2011', 'dd-mm-yyyy'), to_date('15-05-2011', 'dd-mm-yyyy'), 2, 7992, to_date('14-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070513004494, to_date('13-05-2007', 'dd-mm-yyyy'), to_date('27-05-2007', 'dd-mm-yyyy'), 9, 4018, to_date('23-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130901004495, to_date('01-09-2013', 'dd-mm-yyyy'), to_date('15-09-2013', 'dd-mm-yyyy'), 10, 9871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619004496, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 4, 1685, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070225004497, to_date('25-02-2007', 'dd-mm-yyyy'), to_date('11-03-2007', 'dd-mm-yyyy'), 8, 4535, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000615004498, to_date('15-06-2000', 'dd-mm-yyyy'), to_date('29-06-2000', 'dd-mm-yyyy'), 4, 556, to_date('02-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051213004499, to_date('13-12-2005', 'dd-mm-yyyy'), to_date('27-12-2005', 'dd-mm-yyyy'), 10, 2721, to_date('26-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110721004500, to_date('21-07-2011', 'dd-mm-yyyy'), to_date('04-08-2011', 'dd-mm-yyyy'), 6, 6223, to_date('10-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060901004501, to_date('01-09-2006', 'dd-mm-yyyy'), to_date('15-09-2006', 'dd-mm-yyyy'), 3, 8014, to_date('11-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090317004502, to_date('17-03-2009', 'dd-mm-yyyy'), to_date('31-03-2009', 'dd-mm-yyyy'), 9, 5854, to_date('25-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050921004503, to_date('21-09-2005', 'dd-mm-yyyy'), to_date('05-10-2005', 'dd-mm-yyyy'), 11, 3722, to_date('02-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050705004504, to_date('05-07-2005', 'dd-mm-yyyy'), to_date('19-07-2005', 'dd-mm-yyyy'), 8, 5365, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030731004505, to_date('31-07-2003', 'dd-mm-yyyy'), to_date('14-08-2003', 'dd-mm-yyyy'), 7, 3028, to_date('04-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080115004506, to_date('15-01-2008', 'dd-mm-yyyy'), to_date('29-01-2008', 'dd-mm-yyyy'), 6, 7228, to_date('28-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120721004507, to_date('21-07-2012', 'dd-mm-yyyy'), to_date('04-08-2012', 'dd-mm-yyyy'), 4, 9278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120826004508, to_date('26-08-2012', 'dd-mm-yyyy'), to_date('09-09-2012', 'dd-mm-yyyy'), 6, 8408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140224004509, to_date('24-02-2014', 'dd-mm-yyyy'), to_date('10-03-2014', 'dd-mm-yyyy'), 5, 8105, to_date('05-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050415004510, to_date('15-04-2005', 'dd-mm-yyyy'), to_date('29-04-2005', 'dd-mm-yyyy'), 2, 4123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061202004511, to_date('02-12-2006', 'dd-mm-yyyy'), to_date('16-12-2006', 'dd-mm-yyyy'), 1, 5391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090419004512, to_date('19-04-2009', 'dd-mm-yyyy'), to_date('03-05-2009', 'dd-mm-yyyy'), 3, 5634, to_date('04-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110004513, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 5, 6921, to_date('12-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110517004514, to_date('17-05-2011', 'dd-mm-yyyy'), to_date('31-05-2011', 'dd-mm-yyyy'), 5, 8543, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061008004515, to_date('08-10-2006', 'dd-mm-yyyy'), to_date('22-10-2006', 'dd-mm-yyyy'), 6, 5951, to_date('09-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060604004516, to_date('04-06-2006', 'dd-mm-yyyy'), to_date('18-06-2006', 'dd-mm-yyyy'), 2, 3713, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030910004517, to_date('10-09-2003', 'dd-mm-yyyy'), to_date('24-09-2003', 'dd-mm-yyyy'), 3, 1492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000409004518, to_date('09-04-2000', 'dd-mm-yyyy'), to_date('23-04-2000', 'dd-mm-yyyy'), 1, 1645, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101014004519, to_date('14-10-2010', 'dd-mm-yyyy'), to_date('28-10-2010', 'dd-mm-yyyy'), 2, 7323, to_date('28-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000207004520, to_date('07-02-2000', 'dd-mm-yyyy'), to_date('21-02-2000', 'dd-mm-yyyy'), 5, 2397, to_date('24-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040909004521, to_date('09-09-2004', 'dd-mm-yyyy'), to_date('23-09-2004', 'dd-mm-yyyy'), 3, 5963, to_date('22-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010217004522, to_date('17-02-2001', 'dd-mm-yyyy'), to_date('03-03-2001', 'dd-mm-yyyy'), 11, 3243, to_date('22-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001011004523, to_date('11-10-2000', 'dd-mm-yyyy'), to_date('25-10-2000', 'dd-mm-yyyy'), 8, 2175, to_date('16-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031004524, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 7, 5626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004004525, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 9, 5667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101003004526, to_date('03-10-2010', 'dd-mm-yyyy'), to_date('17-10-2010', 'dd-mm-yyyy'), 5, 5409, to_date('08-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080512004527, to_date('12-05-2008', 'dd-mm-yyyy'), to_date('26-05-2008', 'dd-mm-yyyy'), 5, 5308, to_date('29-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215004528, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 2, 5986, to_date('01-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060826004529, to_date('26-08-2006', 'dd-mm-yyyy'), to_date('09-09-2006', 'dd-mm-yyyy'), 8, 4342, to_date('11-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010526004530, to_date('26-05-2001', 'dd-mm-yyyy'), to_date('09-06-2001', 'dd-mm-yyyy'), 9, 2081, to_date('02-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524004531, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 11, 8786, to_date('10-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050508004532, to_date('08-05-2005', 'dd-mm-yyyy'), to_date('22-05-2005', 'dd-mm-yyyy'), 5, 5574, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071121004533, to_date('21-11-2007', 'dd-mm-yyyy'), to_date('05-12-2007', 'dd-mm-yyyy'), 3, 4657, to_date('24-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051104004534, to_date('04-11-2005', 'dd-mm-yyyy'), to_date('18-11-2005', 'dd-mm-yyyy'), 5, 5333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010331004535, to_date('31-03-2001', 'dd-mm-yyyy'), to_date('14-04-2001', 'dd-mm-yyyy'), 5, 2940, to_date('02-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608004536, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 6, 5280, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080621004537, to_date('21-06-2008', 'dd-mm-yyyy'), to_date('05-07-2008', 'dd-mm-yyyy'), 5, 7220, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021110004538, to_date('10-11-2002', 'dd-mm-yyyy'), to_date('24-11-2002', 'dd-mm-yyyy'), 5, 3852, to_date('19-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608004539, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 4, 6114, to_date('28-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529004540, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 9, 8619, to_date('04-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090717004541, to_date('17-07-2009', 'dd-mm-yyyy'), to_date('31-07-2009', 'dd-mm-yyyy'), 6, 6469, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110220004542, to_date('20-02-2011', 'dd-mm-yyyy'), to_date('06-03-2011', 'dd-mm-yyyy'), 4, 6939, to_date('26-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601004543, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 12, 10065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060411004544, to_date('11-04-2006', 'dd-mm-yyyy'), to_date('25-04-2006', 'dd-mm-yyyy'), 5, 4476, to_date('29-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125004545, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 1, 1210, to_date('10-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609004546, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 8, 980, to_date('24-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030213004547, to_date('13-02-2003', 'dd-mm-yyyy'), to_date('27-02-2003', 'dd-mm-yyyy'), 9, 3917, to_date('27-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100218004548, to_date('18-02-2010', 'dd-mm-yyyy'), to_date('04-03-2010', 'dd-mm-yyyy'), 11, 8496, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120821004549, to_date('21-08-2012', 'dd-mm-yyyy'), to_date('04-09-2012', 'dd-mm-yyyy'), 11, 9397, to_date('02-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607004550, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 12, 5291, to_date('11-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060110004551, to_date('10-01-2006', 'dd-mm-yyyy'), to_date('24-01-2006', 'dd-mm-yyyy'), 4, 4289, to_date('27-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130108004552, to_date('08-01-2013', 'dd-mm-yyyy'), to_date('22-01-2013', 'dd-mm-yyyy'), 5, 9208, to_date('27-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110311004553, to_date('11-03-2011', 'dd-mm-yyyy'), to_date('25-03-2011', 'dd-mm-yyyy'), 10, 7196, to_date('18-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080323004554, to_date('23-03-2008', 'dd-mm-yyyy'), to_date('06-04-2008', 'dd-mm-yyyy'), 2, 5491, to_date('09-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060503004555, to_date('03-05-2006', 'dd-mm-yyyy'), to_date('17-05-2006', 'dd-mm-yyyy'), 9, 5028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010704004556, to_date('04-07-2001', 'dd-mm-yyyy'), to_date('18-07-2001', 'dd-mm-yyyy'), 7, 1666, to_date('23-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229004557, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 1, 3492, to_date('03-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430004558, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 7, 4737, to_date('11-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702004559, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 8, 4368, to_date('10-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080425004560, to_date('25-04-2008', 'dd-mm-yyyy'), to_date('09-05-2008', 'dd-mm-yyyy'), 2, 6969, to_date('14-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090306004561, to_date('06-03-2009', 'dd-mm-yyyy'), to_date('20-03-2009', 'dd-mm-yyyy'), 3, 6675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100507004562, to_date('07-05-2010', 'dd-mm-yyyy'), to_date('21-05-2010', 'dd-mm-yyyy'), 12, 7384, to_date('19-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503004563, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 8, 4185, to_date('09-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100517004564, to_date('17-05-2010', 'dd-mm-yyyy'), to_date('31-05-2010', 'dd-mm-yyyy'), 6, 6706, to_date('29-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915004565, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 9, 7886, to_date('22-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010427004566, to_date('27-04-2001', 'dd-mm-yyyy'), to_date('11-05-2001', 'dd-mm-yyyy'), 5, 2364, to_date('29-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040623004567, to_date('23-06-2004', 'dd-mm-yyyy'), to_date('07-07-2004', 'dd-mm-yyyy'), 2, 3922, to_date('27-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021116004568, to_date('16-11-2002', 'dd-mm-yyyy'), to_date('30-11-2002', 'dd-mm-yyyy'), 10, 3749, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130202004569, to_date('02-02-2013', 'dd-mm-yyyy'), to_date('16-02-2013', 'dd-mm-yyyy'), 11, 9441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070814004570, to_date('14-08-2007', 'dd-mm-yyyy'), to_date('28-08-2007', 'dd-mm-yyyy'), 10, 7700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040223004571, to_date('23-02-2004', 'dd-mm-yyyy'), to_date('08-03-2004', 'dd-mm-yyyy'), 6, 2745, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402004572, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 8, 9891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090718004573, to_date('18-07-2009', 'dd-mm-yyyy'), to_date('01-08-2009', 'dd-mm-yyyy'), 12, 4824, to_date('22-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021120004574, to_date('20-11-2002', 'dd-mm-yyyy'), to_date('04-12-2002', 'dd-mm-yyyy'), 2, 2062, to_date('04-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121230004575, to_date('30-12-2012', 'dd-mm-yyyy'), to_date('13-01-2013', 'dd-mm-yyyy'), 5, 8451, to_date('01-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423004576, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 12, 7283, to_date('26-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061014004577, to_date('14-10-2006', 'dd-mm-yyyy'), to_date('28-10-2006', 'dd-mm-yyyy'), 1, 3663, to_date('30-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000202004578, to_date('02-02-2000', 'dd-mm-yyyy'), to_date('16-02-2000', 'dd-mm-yyyy'), 3, 1674, to_date('19-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050614004579, to_date('14-06-2005', 'dd-mm-yyyy'), to_date('28-06-2005', 'dd-mm-yyyy'), 5, 2926, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040221004580, to_date('21-02-2004', 'dd-mm-yyyy'), to_date('06-03-2004', 'dd-mm-yyyy'), 12, 5191, to_date('27-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070907004581, to_date('07-09-2007', 'dd-mm-yyyy'), to_date('21-09-2007', 'dd-mm-yyyy'), 4, 7207, to_date('27-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041203004582, to_date('03-12-2004', 'dd-mm-yyyy'), to_date('17-12-2004', 'dd-mm-yyyy'), 5, 5012, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121025004583, to_date('25-10-2012', 'dd-mm-yyyy'), to_date('08-11-2012', 'dd-mm-yyyy'), 7, 7741, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706004584, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 9, 3649, to_date('21-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903004585, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 11, 5302, to_date('20-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101004586, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 7, 6223, to_date('20-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070412004587, to_date('12-04-2007', 'dd-mm-yyyy'), to_date('26-04-2007', 'dd-mm-yyyy'), 7, 4904, to_date('27-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131002004588, to_date('02-10-2013', 'dd-mm-yyyy'), to_date('16-10-2013', 'dd-mm-yyyy'), 11, 10046, to_date('09-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101021004589, to_date('21-10-2010', 'dd-mm-yyyy'), to_date('04-11-2010', 'dd-mm-yyyy'), 2, 6318, to_date('05-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130727004590, to_date('27-07-2013', 'dd-mm-yyyy'), to_date('10-08-2013', 'dd-mm-yyyy'), 11, 12402, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060821004591, to_date('21-08-2006', 'dd-mm-yyyy'), to_date('04-09-2006', 'dd-mm-yyyy'), 3, 6898, to_date('27-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621004592, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 4, 2219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725004593, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 10, 4194, to_date('13-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120616006735, to_date('16-06-2012', 'dd-mm-yyyy'), to_date('30-06-2012', 'dd-mm-yyyy'), 3, 8423, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030313006736, to_date('13-03-2003', 'dd-mm-yyyy'), to_date('27-03-2003', 'dd-mm-yyyy'), 8, 2736, to_date('20-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207006737, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 3, 3487, to_date('26-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080605006738, to_date('05-06-2008', 'dd-mm-yyyy'), to_date('19-06-2008', 'dd-mm-yyyy'), 11, 5758, to_date('18-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110526006739, to_date('26-05-2011', 'dd-mm-yyyy'), to_date('09-06-2011', 'dd-mm-yyyy'), 7, 9567, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081030006740, to_date('30-10-2008', 'dd-mm-yyyy'), to_date('13-11-2008', 'dd-mm-yyyy'), 9, 5055, to_date('11-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040301006741, to_date('01-03-2004', 'dd-mm-yyyy'), to_date('15-03-2004', 'dd-mm-yyyy'), 2, 5145, to_date('03-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906006742, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 4, 8482, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809006743, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 11, 3269, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081113006744, to_date('13-11-2008', 'dd-mm-yyyy'), to_date('27-11-2008', 'dd-mm-yyyy'), 9, 3852, to_date('26-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050126006745, to_date('26-01-2005', 'dd-mm-yyyy'), to_date('09-02-2005', 'dd-mm-yyyy'), 7, 4412, to_date('30-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030926006746, to_date('26-09-2003', 'dd-mm-yyyy'), to_date('10-10-2003', 'dd-mm-yyyy'), 7, 4898, to_date('27-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091113006747, to_date('13-11-2009', 'dd-mm-yyyy'), to_date('27-11-2009', 'dd-mm-yyyy'), 8, 6074, to_date('25-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325006748, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 6, 4202, to_date('11-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040304006749, to_date('04-03-2004', 'dd-mm-yyyy'), to_date('18-03-2004', 'dd-mm-yyyy'), 8, 4481, to_date('11-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131210006750, to_date('10-12-2013', 'dd-mm-yyyy'), to_date('24-12-2013', 'dd-mm-yyyy'), 9, 6582, to_date('24-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060511006751, to_date('11-05-2006', 'dd-mm-yyyy'), to_date('25-05-2006', 'dd-mm-yyyy'), 5, 3887, to_date('24-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040215006752, to_date('15-02-2004', 'dd-mm-yyyy'), to_date('29-02-2004', 'dd-mm-yyyy'), 4, 4323, to_date('23-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070525006753, to_date('25-05-2007', 'dd-mm-yyyy'), to_date('08-06-2007', 'dd-mm-yyyy'), 3, 4594, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030204006754, to_date('04-02-2003', 'dd-mm-yyyy'), to_date('18-02-2003', 'dd-mm-yyyy'), 10, 3638, to_date('18-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081108006755, to_date('08-11-2008', 'dd-mm-yyyy'), to_date('22-11-2008', 'dd-mm-yyyy'), 9, 5261, to_date('11-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630006756, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 8, 8241, to_date('12-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050116006757, to_date('16-01-2005', 'dd-mm-yyyy'), to_date('30-01-2005', 'dd-mm-yyyy'), 5, 4858, to_date('26-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001102006758, to_date('02-11-2000', 'dd-mm-yyyy'), to_date('16-11-2000', 'dd-mm-yyyy'), 6, 1940, to_date('06-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120427006759, to_date('27-04-2012', 'dd-mm-yyyy'), to_date('11-05-2012', 'dd-mm-yyyy'), 9, 7684, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050119006760, to_date('19-01-2005', 'dd-mm-yyyy'), to_date('02-02-2005', 'dd-mm-yyyy'), 6, 3427, to_date('01-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050913006761, to_date('13-09-2005', 'dd-mm-yyyy'), to_date('27-09-2005', 'dd-mm-yyyy'), 2, 4516, to_date('29-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030727006762, to_date('27-07-2003', 'dd-mm-yyyy'), to_date('10-08-2003', 'dd-mm-yyyy'), 7, 3476, to_date('30-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000206006763, to_date('06-02-2000', 'dd-mm-yyyy'), to_date('20-02-2000', 'dd-mm-yyyy'), 2, 1749, to_date('07-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011129006764, to_date('29-11-2001', 'dd-mm-yyyy'), to_date('13-12-2001', 'dd-mm-yyyy'), 4, 2757, to_date('17-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080202006765, to_date('02-02-2008', 'dd-mm-yyyy'), to_date('16-02-2008', 'dd-mm-yyyy'), 10, 6237, to_date('14-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110901006766, to_date('01-09-2011', 'dd-mm-yyyy'), to_date('15-09-2011', 'dd-mm-yyyy'), 7, 8117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080325006767, to_date('25-03-2008', 'dd-mm-yyyy'), to_date('08-04-2008', 'dd-mm-yyyy'), 5, 8104, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010102006768, to_date('02-01-2001', 'dd-mm-yyyy'), to_date('16-01-2001', 'dd-mm-yyyy'), 10, 1440, to_date('15-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090317006769, to_date('17-03-2009', 'dd-mm-yyyy'), to_date('31-03-2009', 'dd-mm-yyyy'), 10, 6352, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051103006770, to_date('03-11-2005', 'dd-mm-yyyy'), to_date('17-11-2005', 'dd-mm-yyyy'), 2, 3403, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307006771, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 3, 8147, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120312006772, to_date('12-03-2012', 'dd-mm-yyyy'), to_date('26-03-2012', 'dd-mm-yyyy'), 9, 7188, to_date('19-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502006773, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 6, 9962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121127006774, to_date('27-11-2012', 'dd-mm-yyyy'), to_date('11-12-2012', 'dd-mm-yyyy'), 6, 9939, to_date('14-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019006775, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 3, 6128, to_date('28-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081012006776, to_date('12-10-2008', 'dd-mm-yyyy'), to_date('26-10-2008', 'dd-mm-yyyy'), 7, 4938, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010101006777, to_date('01-01-2001', 'dd-mm-yyyy'), to_date('15-01-2001', 'dd-mm-yyyy'), 5, 2854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090101006778, to_date('01-01-2009', 'dd-mm-yyyy'), to_date('15-01-2009', 'dd-mm-yyyy'), 5, 4434, to_date('04-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020207006779, to_date('07-02-2002', 'dd-mm-yyyy'), to_date('21-02-2002', 'dd-mm-yyyy'), 7, 4198, to_date('20-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011203006780, to_date('03-12-2001', 'dd-mm-yyyy'), to_date('17-12-2001', 'dd-mm-yyyy'), 2, 2832, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000623006781, to_date('23-06-2000', 'dd-mm-yyyy'), to_date('07-07-2000', 'dd-mm-yyyy'), 4, 1324, to_date('10-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060305006782, to_date('05-03-2006', 'dd-mm-yyyy'), to_date('19-03-2006', 'dd-mm-yyyy'), 8, 3985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010107006783, to_date('07-01-2001', 'dd-mm-yyyy'), to_date('21-01-2001', 'dd-mm-yyyy'), 9, 2236, to_date('08-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121026006784, to_date('26-10-2012', 'dd-mm-yyyy'), to_date('09-11-2012', 'dd-mm-yyyy'), 6, 7410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115006785, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 2, 4059, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130828006786, to_date('28-08-2013', 'dd-mm-yyyy'), to_date('11-09-2013', 'dd-mm-yyyy'), 5, 9109, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091224006787, to_date('24-12-2009', 'dd-mm-yyyy'), to_date('07-01-2010', 'dd-mm-yyyy'), 6, 7048, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090702006788, to_date('02-07-2009', 'dd-mm-yyyy'), to_date('16-07-2009', 'dd-mm-yyyy'), 8, 7659, to_date('06-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090307006789, to_date('07-03-2009', 'dd-mm-yyyy'), to_date('21-03-2009', 'dd-mm-yyyy'), 7, 6933, to_date('08-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213006790, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 11, 8199, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000814006791, to_date('14-08-2000', 'dd-mm-yyyy'), to_date('28-08-2000', 'dd-mm-yyyy'), 9, 3948, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902006792, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 5, 3620, to_date('12-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110218006793, to_date('18-02-2011', 'dd-mm-yyyy'), to_date('04-03-2011', 'dd-mm-yyyy'), 3, 5988, to_date('20-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010801006794, to_date('01-08-2001', 'dd-mm-yyyy'), to_date('15-08-2001', 'dd-mm-yyyy'), 8, 2931, to_date('10-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000823006795, to_date('23-08-2000', 'dd-mm-yyyy'), to_date('06-09-2000', 'dd-mm-yyyy'), 9, 1754, to_date('25-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131108006796, to_date('08-11-2013', 'dd-mm-yyyy'), to_date('22-11-2013', 'dd-mm-yyyy'), 11, 6097, to_date('19-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050521006797, to_date('21-05-2005', 'dd-mm-yyyy'), to_date('04-06-2005', 'dd-mm-yyyy'), 4, 3379, to_date('07-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110102006798, to_date('02-01-2011', 'dd-mm-yyyy'), to_date('16-01-2011', 'dd-mm-yyyy'), 2, 6268, to_date('16-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130428006799, to_date('28-04-2013', 'dd-mm-yyyy'), to_date('12-05-2013', 'dd-mm-yyyy'), 2, 10474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091117006800, to_date('17-11-2009', 'dd-mm-yyyy'), to_date('01-12-2009', 'dd-mm-yyyy'), 9, 5597, to_date('23-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112006801, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 12, 4658, to_date('24-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714006802, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 8, 8320, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100310006803, to_date('10-03-2010', 'dd-mm-yyyy'), to_date('24-03-2010', 'dd-mm-yyyy'), 1, 6957, to_date('21-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051102006804, to_date('02-11-2005', 'dd-mm-yyyy'), to_date('16-11-2005', 'dd-mm-yyyy'), 3, 3784, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410006805, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 6, 5802, to_date('16-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090108006806, to_date('08-01-2009', 'dd-mm-yyyy'), to_date('22-01-2009', 'dd-mm-yyyy'), 9, 5230, to_date('15-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108006807, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 8, 5304, to_date('25-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040822006808, to_date('22-08-2004', 'dd-mm-yyyy'), to_date('05-09-2004', 'dd-mm-yyyy'), 6, 3946, to_date('08-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326006809, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 11, 5335, to_date('01-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603006810, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 3, 3652, to_date('14-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060224006811, to_date('24-02-2006', 'dd-mm-yyyy'), to_date('10-03-2006', 'dd-mm-yyyy'), 8, 6161, to_date('15-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101004006812, to_date('04-10-2010', 'dd-mm-yyyy'), to_date('18-10-2010', 'dd-mm-yyyy'), 6, 7374, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100101006813, to_date('01-01-2010', 'dd-mm-yyyy'), to_date('15-01-2010', 'dd-mm-yyyy'), 1, 5347, to_date('14-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130805006814, to_date('05-08-2013', 'dd-mm-yyyy'), to_date('19-08-2013', 'dd-mm-yyyy'), 4, 8902, to_date('21-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030122006815, to_date('22-01-2003', 'dd-mm-yyyy'), to_date('05-02-2003', 'dd-mm-yyyy'), 5, 2113, to_date('08-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051217006816, to_date('17-12-2005', 'dd-mm-yyyy'), to_date('31-12-2005', 'dd-mm-yyyy'), 7, 4829, to_date('03-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120803006817, to_date('03-08-2012', 'dd-mm-yyyy'), to_date('17-08-2012', 'dd-mm-yyyy'), 4, 8191, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124006818, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 12, 7032, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020606006819, to_date('06-06-2002', 'dd-mm-yyyy'), to_date('20-06-2002', 'dd-mm-yyyy'), 12, 3414, to_date('16-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010508006820, to_date('08-05-2001', 'dd-mm-yyyy'), to_date('22-05-2001', 'dd-mm-yyyy'), 3, 1864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041203006821, to_date('03-12-2004', 'dd-mm-yyyy'), to_date('17-12-2004', 'dd-mm-yyyy'), 2, 2542, to_date('10-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020511006822, to_date('11-05-2002', 'dd-mm-yyyy'), to_date('25-05-2002', 'dd-mm-yyyy'), 4, 3716, to_date('23-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090223006823, to_date('23-02-2009', 'dd-mm-yyyy'), to_date('09-03-2009', 'dd-mm-yyyy'), 11, 4335, to_date('08-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010314006824, to_date('14-03-2001', 'dd-mm-yyyy'), to_date('28-03-2001', 'dd-mm-yyyy'), 6, 2092, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325006825, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 6, 5628, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050924006826, to_date('24-09-2005', 'dd-mm-yyyy'), to_date('08-10-2005', 'dd-mm-yyyy'), 8, 2995, to_date('13-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020927006827, to_date('27-09-2002', 'dd-mm-yyyy'), to_date('11-10-2002', 'dd-mm-yyyy'), 5, 2089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071018006828, to_date('18-10-2007', 'dd-mm-yyyy'), to_date('01-11-2007', 'dd-mm-yyyy'), 4, 7938, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040115006829, to_date('15-01-2004', 'dd-mm-yyyy'), to_date('29-01-2004', 'dd-mm-yyyy'), 4, 4692, to_date('23-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725006830, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 4, 12141, to_date('07-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040525006831, to_date('25-05-2004', 'dd-mm-yyyy'), to_date('08-06-2004', 'dd-mm-yyyy'), 2, 4187, to_date('05-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030111006832, to_date('11-01-2003', 'dd-mm-yyyy'), to_date('25-01-2003', 'dd-mm-yyyy'), 6, 3908, to_date('24-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804006833, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 10, 7506, to_date('11-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503006834, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 8, 6621, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070920006835, to_date('20-09-2007', 'dd-mm-yyyy'), to_date('04-10-2007', 'dd-mm-yyyy'), 2, 4721, to_date('03-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070930006836, to_date('30-09-2007', 'dd-mm-yyyy'), to_date('14-10-2007', 'dd-mm-yyyy'), 9, 5668, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131117006837, to_date('17-11-2013', 'dd-mm-yyyy'), to_date('01-12-2013', 'dd-mm-yyyy'), 8, 8418, to_date('04-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090925006838, to_date('25-09-2009', 'dd-mm-yyyy'), to_date('09-10-2009', 'dd-mm-yyyy'), 4, 6864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080419006839, to_date('19-04-2008', 'dd-mm-yyyy'), to_date('03-05-2008', 'dd-mm-yyyy'), 5, 3545, to_date('25-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121210006840, to_date('10-12-2012', 'dd-mm-yyyy'), to_date('24-12-2012', 'dd-mm-yyyy'), 5, 8198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912006841, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 5, 5782, to_date('14-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010924006842, to_date('24-09-2001', 'dd-mm-yyyy'), to_date('08-10-2001', 'dd-mm-yyyy'), 12, 2869, to_date('26-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110628006843, to_date('28-06-2011', 'dd-mm-yyyy'), to_date('12-07-2011', 'dd-mm-yyyy'), 8, 8173, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020223006844, to_date('23-02-2002', 'dd-mm-yyyy'), to_date('09-03-2002', 'dd-mm-yyyy'), 7, 4836, to_date('09-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040127006845, to_date('27-01-2004', 'dd-mm-yyyy'), to_date('10-02-2004', 'dd-mm-yyyy'), 8, 2901, to_date('09-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120317006846, to_date('17-03-2012', 'dd-mm-yyyy'), to_date('31-03-2012', 'dd-mm-yyyy'), 11, 8436, to_date('19-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020312006847, to_date('12-03-2002', 'dd-mm-yyyy'), to_date('26-03-2002', 'dd-mm-yyyy'), 10, 2450, to_date('26-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010915006848, to_date('15-09-2001', 'dd-mm-yyyy'), to_date('29-09-2001', 'dd-mm-yyyy'), 7, 1465, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030420006849, to_date('20-04-2003', 'dd-mm-yyyy'), to_date('04-05-2003', 'dd-mm-yyyy'), 3, 3849, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100121006850, to_date('21-01-2010', 'dd-mm-yyyy'), to_date('04-02-2010', 'dd-mm-yyyy'), 1, 7024, to_date('27-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100830006851, to_date('30-08-2010', 'dd-mm-yyyy'), to_date('13-09-2010', 'dd-mm-yyyy'), 1, 6820, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111224006852, to_date('24-12-2011', 'dd-mm-yyyy'), to_date('07-01-2012', 'dd-mm-yyyy'), 2, 9236, to_date('29-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228006853, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 4, 1300, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614006854, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 11, 4419, to_date('30-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202006855, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 10, 4465, to_date('17-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070903006856, to_date('03-09-2007', 'dd-mm-yyyy'), to_date('17-09-2007', 'dd-mm-yyyy'), 10, 4288, to_date('08-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210006857, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 6, 3477, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111012006858, to_date('12-10-2011', 'dd-mm-yyyy'), to_date('26-10-2011', 'dd-mm-yyyy'), 6, 5894, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131026006859, to_date('26-10-2013', 'dd-mm-yyyy'), to_date('09-11-2013', 'dd-mm-yyyy'), 2, 9874, to_date('14-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022006860, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 5, 3879, to_date('23-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110304006861, to_date('04-03-2011', 'dd-mm-yyyy'), to_date('18-03-2011', 'dd-mm-yyyy'), 2, 8100, to_date('06-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813006862, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 2, 2699, to_date('28-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130511006863, to_date('11-05-2013', 'dd-mm-yyyy'), to_date('25-05-2013', 'dd-mm-yyyy'), 8, 7692, to_date('22-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070130006864, to_date('30-01-2007', 'dd-mm-yyyy'), to_date('13-02-2007', 'dd-mm-yyyy'), 6, 5572, to_date('11-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000220006865, to_date('20-02-2000', 'dd-mm-yyyy'), to_date('05-03-2000', 'dd-mm-yyyy'), 10, 910, to_date('11-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930006866, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 8, 3628, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110301006867, to_date('01-03-2011', 'dd-mm-yyyy'), to_date('15-03-2011', 'dd-mm-yyyy'), 8, 7596, to_date('14-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061025006868, to_date('25-10-2006', 'dd-mm-yyyy'), to_date('08-11-2006', 'dd-mm-yyyy'), 3, 2954, to_date('11-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121123006869, to_date('23-11-2012', 'dd-mm-yyyy'), to_date('07-12-2012', 'dd-mm-yyyy'), 6, 7559, to_date('01-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131006870, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 6, 4713, to_date('07-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091221006871, to_date('21-12-2009', 'dd-mm-yyyy'), to_date('04-01-2010', 'dd-mm-yyyy'), 6, 5457, to_date('31-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100321006872, to_date('21-03-2010', 'dd-mm-yyyy'), to_date('04-04-2010', 'dd-mm-yyyy'), 10, 8089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081222006873, to_date('22-12-2008', 'dd-mm-yyyy'), to_date('05-01-2009', 'dd-mm-yyyy'), 3, 8102, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080219006874, to_date('19-02-2008', 'dd-mm-yyyy'), to_date('04-03-2008', 'dd-mm-yyyy'), 11, 5380, to_date('21-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831006875, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 11, 6811, to_date('20-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821006876, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 4, 7985, to_date('03-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040423006877, to_date('23-04-2004', 'dd-mm-yyyy'), to_date('07-05-2004', 'dd-mm-yyyy'), 3, 2871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050415006878, to_date('15-04-2005', 'dd-mm-yyyy'), to_date('29-04-2005', 'dd-mm-yyyy'), 2, 5010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111001006879, to_date('01-10-2011', 'dd-mm-yyyy'), to_date('15-10-2011', 'dd-mm-yyyy'), 9, 5835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111106006880, to_date('06-11-2011', 'dd-mm-yyyy'), to_date('20-11-2011', 'dd-mm-yyyy'), 6, 6635, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031007006881, to_date('07-10-2003', 'dd-mm-yyyy'), to_date('21-10-2003', 'dd-mm-yyyy'), 1, 2885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030810006882, to_date('10-08-2003', 'dd-mm-yyyy'), to_date('24-08-2003', 'dd-mm-yyyy'), 10, 4080, to_date('25-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119006883, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 3, 2440, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120006884, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 10, 5021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001211006885, to_date('11-12-2000', 'dd-mm-yyyy'), to_date('25-12-2000', 'dd-mm-yyyy'), 3, 3606, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030917006886, to_date('17-09-2003', 'dd-mm-yyyy'), to_date('01-10-2003', 'dd-mm-yyyy'), 10, 3077, to_date('02-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228006887, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 5, 380, to_date('12-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020418009025, to_date('18-04-2002', 'dd-mm-yyyy'), to_date('02-05-2002', 'dd-mm-yyyy'), 3, 2903, to_date('01-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220009026, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 5, 7863, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212009027, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 10, 3137, to_date('28-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030306009028, to_date('06-03-2003', 'dd-mm-yyyy'), to_date('20-03-2003', 'dd-mm-yyyy'), 6, 3987, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100820009029, to_date('20-08-2010', 'dd-mm-yyyy'), to_date('03-09-2010', 'dd-mm-yyyy'), 10, 7843, to_date('07-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120505009030, to_date('05-05-2012', 'dd-mm-yyyy'), to_date('19-05-2012', 'dd-mm-yyyy'), 9, 8966, to_date('08-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080415009031, to_date('15-04-2008', 'dd-mm-yyyy'), to_date('29-04-2008', 'dd-mm-yyyy'), 4, 5738, to_date('27-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010908009032, to_date('08-09-2001', 'dd-mm-yyyy'), to_date('22-09-2001', 'dd-mm-yyyy'), 9, 2456, to_date('13-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020412009033, to_date('12-04-2002', 'dd-mm-yyyy'), to_date('26-04-2002', 'dd-mm-yyyy'), 7, 3023, to_date('27-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010531009034, to_date('31-05-2001', 'dd-mm-yyyy'), to_date('14-06-2001', 'dd-mm-yyyy'), 9, 514, to_date('16-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131130009035, to_date('30-11-2013', 'dd-mm-yyyy'), to_date('14-12-2013', 'dd-mm-yyyy'), 12, 6134, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725009036, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 11, 7559, to_date('02-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217009037, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 7, 3734, to_date('25-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808009038, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 6, 5455, to_date('14-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081224009039, to_date('24-12-2008', 'dd-mm-yyyy'), to_date('07-01-2009', 'dd-mm-yyyy'), 2, 5335, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080204009040, to_date('04-02-2008', 'dd-mm-yyyy'), to_date('18-02-2008', 'dd-mm-yyyy'), 2, 6943, to_date('22-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040416009041, to_date('16-04-2004', 'dd-mm-yyyy'), to_date('30-04-2004', 'dd-mm-yyyy'), 7, 3653, to_date('05-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020502009042, to_date('02-05-2002', 'dd-mm-yyyy'), to_date('16-05-2002', 'dd-mm-yyyy'), 1, 4052, to_date('16-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130714009043, to_date('14-07-2013', 'dd-mm-yyyy'), to_date('28-07-2013', 'dd-mm-yyyy'), 11, 9159, to_date('27-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100211009044, to_date('11-02-2010', 'dd-mm-yyyy'), to_date('25-02-2010', 'dd-mm-yyyy'), 9, 6740, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011028009045, to_date('28-10-2001', 'dd-mm-yyyy'), to_date('11-11-2001', 'dd-mm-yyyy'), 2, 1234, to_date('15-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130213009046, to_date('13-02-2013', 'dd-mm-yyyy'), to_date('27-02-2013', 'dd-mm-yyyy'), 1, 7782, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126009047, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 3, 4359, to_date('12-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208009048, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 8, 6418, to_date('12-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130630009049, to_date('30-06-2013', 'dd-mm-yyyy'), to_date('14-07-2013', 'dd-mm-yyyy'), 8, 8000, to_date('13-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926009050, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 5, 10998, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131014009051, to_date('14-10-2013', 'dd-mm-yyyy'), to_date('28-10-2013', 'dd-mm-yyyy'), 8, 9306, to_date('17-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051108009052, to_date('08-11-2005', 'dd-mm-yyyy'), to_date('22-11-2005', 'dd-mm-yyyy'), 8, 4914, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128009053, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 12, 9210, to_date('12-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000106009054, to_date('06-01-2000', 'dd-mm-yyyy'), to_date('20-01-2000', 'dd-mm-yyyy'), 1, 2443, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100412009055, to_date('12-04-2010', 'dd-mm-yyyy'), to_date('26-04-2010', 'dd-mm-yyyy'), 11, 7546, to_date('01-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404009056, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 9, 5103, to_date('17-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000130009057, to_date('30-01-2000', 'dd-mm-yyyy'), to_date('13-02-2000', 'dd-mm-yyyy'), 10, 1606, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070308009058, to_date('08-03-2007', 'dd-mm-yyyy'), to_date('22-03-2007', 'dd-mm-yyyy'), 6, 6731, to_date('13-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090117009059, to_date('17-01-2009', 'dd-mm-yyyy'), to_date('31-01-2009', 'dd-mm-yyyy'), 6, 5532, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627009060, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 2, 9598, to_date('08-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110703009061, to_date('03-07-2011', 'dd-mm-yyyy'), to_date('17-07-2011', 'dd-mm-yyyy'), 6, 10496, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010513009062, to_date('13-05-2001', 'dd-mm-yyyy'), to_date('27-05-2001', 'dd-mm-yyyy'), 7, 3150, to_date('27-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100508009063, to_date('08-05-2010', 'dd-mm-yyyy'), to_date('22-05-2010', 'dd-mm-yyyy'), 9, 6878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030919009064, to_date('19-09-2003', 'dd-mm-yyyy'), to_date('03-10-2003', 'dd-mm-yyyy'), 7, 2408, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091230009065, to_date('30-12-2009', 'dd-mm-yyyy'), to_date('13-01-2010', 'dd-mm-yyyy'), 5, 5600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030811009066, to_date('11-08-2003', 'dd-mm-yyyy'), to_date('25-08-2003', 'dd-mm-yyyy'), 4, 3612, to_date('27-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070523009067, to_date('23-05-2007', 'dd-mm-yyyy'), to_date('06-06-2007', 'dd-mm-yyyy'), 8, 3790, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090612009068, to_date('12-06-2009', 'dd-mm-yyyy'), to_date('26-06-2009', 'dd-mm-yyyy'), 10, 5260, to_date('20-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060915009069, to_date('15-09-2006', 'dd-mm-yyyy'), to_date('29-09-2006', 'dd-mm-yyyy'), 6, 4830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120229009070, to_date('29-02-2012', 'dd-mm-yyyy'), to_date('14-03-2012', 'dd-mm-yyyy'), 11, 7614, to_date('02-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210009071, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 8, 3248, to_date('19-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430009072, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 6, 5611, to_date('15-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020327009073, to_date('27-03-2002', 'dd-mm-yyyy'), to_date('10-04-2002', 'dd-mm-yyyy'), 6, 3262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071208009074, to_date('08-12-2007', 'dd-mm-yyyy'), to_date('22-12-2007', 'dd-mm-yyyy'), 1, 5829, to_date('13-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010713009075, to_date('13-07-2001', 'dd-mm-yyyy'), to_date('27-07-2001', 'dd-mm-yyyy'), 7, 2357, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080305009076, to_date('05-03-2008', 'dd-mm-yyyy'), to_date('19-03-2008', 'dd-mm-yyyy'), 12, 5957, to_date('22-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010729009077, to_date('29-07-2001', 'dd-mm-yyyy'), to_date('12-08-2001', 'dd-mm-yyyy'), 4, 2548, to_date('16-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131017009078, to_date('17-10-2013', 'dd-mm-yyyy'), to_date('31-10-2013', 'dd-mm-yyyy'), 2, 10284, to_date('24-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060521009079, to_date('21-05-2006', 'dd-mm-yyyy'), to_date('04-06-2006', 'dd-mm-yyyy'), 2, 4969, to_date('05-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813009080, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 4, 4612, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131230009081, to_date('30-12-2013', 'dd-mm-yyyy'), to_date('13-01-2014', 'dd-mm-yyyy'), 2, 7426, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030926009082, to_date('26-09-2003', 'dd-mm-yyyy'), to_date('10-10-2003', 'dd-mm-yyyy'), 11, 4243, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030307009083, to_date('07-03-2003', 'dd-mm-yyyy'), to_date('21-03-2003', 'dd-mm-yyyy'), 7, 3484, to_date('27-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024009084, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 8, 5410, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830009085, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 4, 5303, to_date('11-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090410009086, to_date('10-04-2009', 'dd-mm-yyyy'), to_date('24-04-2009', 'dd-mm-yyyy'), 3, 5413, to_date('13-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207009087, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 8, 3593, to_date('10-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080303009088, to_date('03-03-2008', 'dd-mm-yyyy'), to_date('17-03-2008', 'dd-mm-yyyy'), 8, 8702, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001217009089, to_date('17-12-2000', 'dd-mm-yyyy'), to_date('31-12-2000', 'dd-mm-yyyy'), 12, 1622, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050327009090, to_date('27-03-2005', 'dd-mm-yyyy'), to_date('10-04-2005', 'dd-mm-yyyy'), 11, 4081, to_date('28-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100209009091, to_date('09-02-2010', 'dd-mm-yyyy'), to_date('23-02-2010', 'dd-mm-yyyy'), 8, 7803, to_date('14-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009009092, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 8, 11512, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100320009093, to_date('20-03-2010', 'dd-mm-yyyy'), to_date('03-04-2010', 'dd-mm-yyyy'), 5, 6227, to_date('07-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509009094, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 8, 8912, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051031009095, to_date('31-10-2005', 'dd-mm-yyyy'), to_date('14-11-2005', 'dd-mm-yyyy'), 8, 3834, to_date('08-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090502009096, to_date('02-05-2009', 'dd-mm-yyyy'), to_date('16-05-2009', 'dd-mm-yyyy'), 10, 4601, to_date('19-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417009097, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 5, 6252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712009098, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 7, 3308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080928009099, to_date('28-09-2008', 'dd-mm-yyyy'), to_date('12-10-2008', 'dd-mm-yyyy'), 2, 6682, to_date('15-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060731009100, to_date('31-07-2006', 'dd-mm-yyyy'), to_date('14-08-2006', 'dd-mm-yyyy'), 7, 3939, to_date('06-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329009101, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 9, 5995, to_date('01-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071226009102, to_date('26-12-2007', 'dd-mm-yyyy'), to_date('09-01-2008', 'dd-mm-yyyy'), 10, 2929, to_date('10-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130219009103, to_date('19-02-2013', 'dd-mm-yyyy'), to_date('05-03-2013', 'dd-mm-yyyy'), 5, 12405, to_date('08-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805009104, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 10, 4113, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060724009105, to_date('24-07-2006', 'dd-mm-yyyy'), to_date('07-08-2006', 'dd-mm-yyyy'), 2, 6592, to_date('27-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000210009106, to_date('10-02-2000', 'dd-mm-yyyy'), to_date('24-02-2000', 'dd-mm-yyyy'), 11, 1112, to_date('24-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130304009107, to_date('04-03-2013', 'dd-mm-yyyy'), to_date('18-03-2013', 'dd-mm-yyyy'), 2, 6887, to_date('21-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226009108, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 2, 2111, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080212009109, to_date('12-02-2008', 'dd-mm-yyyy'), to_date('26-02-2008', 'dd-mm-yyyy'), 10, 4136, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111109009110, to_date('09-11-2011', 'dd-mm-yyyy'), to_date('23-11-2011', 'dd-mm-yyyy'), 7, 9329, to_date('20-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217009111, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 10, 2776, to_date('20-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515009112, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 5, 2330, to_date('16-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120629009113, to_date('29-06-2012', 'dd-mm-yyyy'), to_date('13-07-2012', 'dd-mm-yyyy'), 9, 8535, to_date('16-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000506009114, to_date('06-05-2000', 'dd-mm-yyyy'), to_date('20-05-2000', 'dd-mm-yyyy'), 12, 658, to_date('09-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070416009115, to_date('16-04-2007', 'dd-mm-yyyy'), to_date('30-04-2007', 'dd-mm-yyyy'), 9, 5959, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117009116, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 8, 5536, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020801009117, to_date('01-08-2002', 'dd-mm-yyyy'), to_date('15-08-2002', 'dd-mm-yyyy'), 3, 2148, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218009118, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 8, 2698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000709009119, to_date('09-07-2000', 'dd-mm-yyyy'), to_date('23-07-2000', 'dd-mm-yyyy'), 2, 741, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004009120, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 4, 4011, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329009121, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 6, 2710, to_date('03-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000508009122, to_date('08-05-2000', 'dd-mm-yyyy'), to_date('22-05-2000', 'dd-mm-yyyy'), 2, 550, to_date('21-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129009123, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 7, 3360, to_date('12-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013009124, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 5, 2069, to_date('23-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020310009125, to_date('10-03-2002', 'dd-mm-yyyy'), to_date('24-03-2002', 'dd-mm-yyyy'), 2, 2190, to_date('17-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021128009126, to_date('28-11-2002', 'dd-mm-yyyy'), to_date('12-12-2002', 'dd-mm-yyyy'), 6, 2068, to_date('29-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001221009127, to_date('21-12-2000', 'dd-mm-yyyy'), to_date('04-01-2001', 'dd-mm-yyyy'), 3, 1927, to_date('05-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050310009128, to_date('10-03-2005', 'dd-mm-yyyy'), to_date('24-03-2005', 'dd-mm-yyyy'), 3, 4931, to_date('17-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040505009129, to_date('05-05-2004', 'dd-mm-yyyy'), to_date('19-05-2004', 'dd-mm-yyyy'), 3, 4367, to_date('21-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000514009130, to_date('14-05-2000', 'dd-mm-yyyy'), to_date('28-05-2000', 'dd-mm-yyyy'), 4, 1449, to_date('31-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130513009131, to_date('13-05-2013', 'dd-mm-yyyy'), to_date('27-05-2013', 'dd-mm-yyyy'), 10, 9600, to_date('24-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723009132, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 1, 2792, to_date('27-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050225009133, to_date('25-02-2005', 'dd-mm-yyyy'), to_date('11-03-2005', 'dd-mm-yyyy'), 11, 4100, to_date('27-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090102009134, to_date('02-01-2009', 'dd-mm-yyyy'), to_date('16-01-2009', 'dd-mm-yyyy'), 6, 6880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120515009135, to_date('15-05-2012', 'dd-mm-yyyy'), to_date('29-05-2012', 'dd-mm-yyyy'), 7, 7841, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315009136, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 2, 6625, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121030009137, to_date('30-10-2012', 'dd-mm-yyyy'), to_date('13-11-2012', 'dd-mm-yyyy'), 7, 6913, to_date('14-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080630009138, to_date('30-06-2008', 'dd-mm-yyyy'), to_date('14-07-2008', 'dd-mm-yyyy'), 8, 4885, to_date('11-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307009139, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 11, 4951, to_date('12-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121107009140, to_date('07-11-2012', 'dd-mm-yyyy'), to_date('21-11-2012', 'dd-mm-yyyy'), 2, 5343, to_date('20-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001209009141, to_date('09-12-2000', 'dd-mm-yyyy'), to_date('23-12-2000', 'dd-mm-yyyy'), 8, 1774, to_date('26-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100827009142, to_date('27-08-2010', 'dd-mm-yyyy'), to_date('10-09-2010', 'dd-mm-yyyy'), 3, 6028, to_date('15-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001204009143, to_date('04-12-2000', 'dd-mm-yyyy'), to_date('18-12-2000', 'dd-mm-yyyy'), 2, 1520, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230009144, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 10, 3979, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111216009145, to_date('16-12-2011', 'dd-mm-yyyy'), to_date('30-12-2011', 'dd-mm-yyyy'), 12, 6342, to_date('19-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100826009146, to_date('26-08-2010', 'dd-mm-yyyy'), to_date('09-09-2010', 'dd-mm-yyyy'), 2, 7363, to_date('28-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120314009147, to_date('14-03-2012', 'dd-mm-yyyy'), to_date('28-03-2012', 'dd-mm-yyyy'), 10, 7715, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010614009148, to_date('14-06-2001', 'dd-mm-yyyy'), to_date('28-06-2001', 'dd-mm-yyyy'), 9, 2663, to_date('24-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090310009149, to_date('10-03-2009', 'dd-mm-yyyy'), to_date('24-03-2009', 'dd-mm-yyyy'), 6, 6475, to_date('27-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090324009150, to_date('24-03-2009', 'dd-mm-yyyy'), to_date('07-04-2009', 'dd-mm-yyyy'), 10, 8415, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908009151, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 12, 5756, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070720009152, to_date('20-07-2007', 'dd-mm-yyyy'), to_date('03-08-2007', 'dd-mm-yyyy'), 9, 6579, to_date('05-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041223009153, to_date('23-12-2004', 'dd-mm-yyyy'), to_date('06-01-2005', 'dd-mm-yyyy'), 11, 4030, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303009154, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 11, 8394, to_date('22-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110912009155, to_date('12-09-2011', 'dd-mm-yyyy'), to_date('26-09-2011', 'dd-mm-yyyy'), 11, 6454, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110306009156, to_date('06-03-2011', 'dd-mm-yyyy'), to_date('20-03-2011', 'dd-mm-yyyy'), 10, 6439, to_date('08-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000215009157, to_date('15-02-2000', 'dd-mm-yyyy'), to_date('29-02-2000', 'dd-mm-yyyy'), 8, 2450, to_date('19-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060715009158, to_date('15-07-2006', 'dd-mm-yyyy'), to_date('29-07-2006', 'dd-mm-yyyy'), 2, 4600, to_date('02-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110715009159, to_date('15-07-2011', 'dd-mm-yyyy'), to_date('29-07-2011', 'dd-mm-yyyy'), 10, 6724, to_date('31-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107009160, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 12, 4803, to_date('25-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071223009161, to_date('23-12-2007', 'dd-mm-yyyy'), to_date('06-01-2008', 'dd-mm-yyyy'), 6, 5914, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000503009162, to_date('03-05-2000', 'dd-mm-yyyy'), to_date('17-05-2000', 'dd-mm-yyyy'), 2, 2314, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503009163, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 2, 2298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070813009164, to_date('13-08-2007', 'dd-mm-yyyy'), to_date('27-08-2007', 'dd-mm-yyyy'), 8, 4224, to_date('23-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112009165, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 9, 3698, to_date('27-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120427009166, to_date('27-04-2012', 'dd-mm-yyyy'), to_date('11-05-2012', 'dd-mm-yyyy'), 10, 8867, to_date('11-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626009167, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 10, 5494, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614009168, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 3, 6957, to_date('02-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008009169, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 4, 5091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208009170, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 6, 4442, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091003009171, to_date('03-10-2009', 'dd-mm-yyyy'), to_date('17-10-2009', 'dd-mm-yyyy'), 2, 5331, to_date('14-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120202009172, to_date('02-02-2012', 'dd-mm-yyyy'), to_date('16-02-2012', 'dd-mm-yyyy'), 6, 7568, to_date('08-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001009173, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 8, 3970, to_date('13-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101009174, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 1, 6532, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040811009175, to_date('11-08-2004', 'dd-mm-yyyy'), to_date('25-08-2004', 'dd-mm-yyyy'), 8, 2806, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504002142, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 4, 7333, to_date('08-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071112002143, to_date('12-11-2007', 'dd-mm-yyyy'), to_date('26-11-2007', 'dd-mm-yyyy'), 10, 5386, to_date('16-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100906002144, to_date('06-09-2010', 'dd-mm-yyyy'), to_date('20-09-2010', 'dd-mm-yyyy'), 12, 9878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040118002145, to_date('18-01-2004', 'dd-mm-yyyy'), to_date('01-02-2004', 'dd-mm-yyyy'), 2, 3641, to_date('05-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010117002146, to_date('17-01-2001', 'dd-mm-yyyy'), to_date('31-01-2001', 'dd-mm-yyyy'), 3, 1975, to_date('31-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001018002147, to_date('18-10-2000', 'dd-mm-yyyy'), to_date('01-11-2000', 'dd-mm-yyyy'), 2, 1998, to_date('25-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080624002148, to_date('24-06-2008', 'dd-mm-yyyy'), to_date('08-07-2008', 'dd-mm-yyyy'), 7, 5171, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070503002149, to_date('03-05-2007', 'dd-mm-yyyy'), to_date('17-05-2007', 'dd-mm-yyyy'), 8, 5614, to_date('14-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140116002150, to_date('16-01-2014', 'dd-mm-yyyy'), to_date('30-01-2014', 'dd-mm-yyyy'), 11, 10853, to_date('26-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129002151, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 2, 6935, to_date('08-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070220002152, to_date('20-02-2007', 'dd-mm-yyyy'), to_date('06-03-2007', 'dd-mm-yyyy'), 4, 6219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131029002153, to_date('29-10-2013', 'dd-mm-yyyy'), to_date('12-11-2013', 'dd-mm-yyyy'), 12, 8128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080111002154, to_date('11-01-2008', 'dd-mm-yyyy'), to_date('25-01-2008', 'dd-mm-yyyy'), 12, 6900, to_date('27-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101015002155, to_date('15-10-2010', 'dd-mm-yyyy'), to_date('29-10-2010', 'dd-mm-yyyy'), 7, 6701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100412002156, to_date('12-04-2010', 'dd-mm-yyyy'), to_date('26-04-2010', 'dd-mm-yyyy'), 11, 8081, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011104002157, to_date('04-11-2001', 'dd-mm-yyyy'), to_date('18-11-2001', 'dd-mm-yyyy'), 8, 2506, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130816002158, to_date('16-08-2013', 'dd-mm-yyyy'), to_date('30-08-2013', 'dd-mm-yyyy'), 10, 6309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060113002159, to_date('13-01-2006', 'dd-mm-yyyy'), to_date('27-01-2006', 'dd-mm-yyyy'), 10, 6319, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420002160, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 10, 4100, to_date('04-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110521002161, to_date('21-05-2011', 'dd-mm-yyyy'), to_date('04-06-2011', 'dd-mm-yyyy'), 11, 7727, to_date('01-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830002162, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 8, 4325, to_date('07-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040519002163, to_date('19-05-2004', 'dd-mm-yyyy'), to_date('02-06-2004', 'dd-mm-yyyy'), 12, 6016, to_date('21-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090930002164, to_date('30-09-2009', 'dd-mm-yyyy'), to_date('14-10-2009', 'dd-mm-yyyy'), 5, 7936, to_date('16-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050520002165, to_date('20-05-2005', 'dd-mm-yyyy'), to_date('03-06-2005', 'dd-mm-yyyy'), 4, 3426, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213002166, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 12, 7827, to_date('26-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626002167, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 2, 3563, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010806002168, to_date('06-08-2001', 'dd-mm-yyyy'), to_date('20-08-2001', 'dd-mm-yyyy'), 6, 1591, to_date('10-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060428002169, to_date('28-04-2006', 'dd-mm-yyyy'), to_date('12-05-2006', 'dd-mm-yyyy'), 7, 4475, to_date('08-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423002170, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 8, 2835, to_date('27-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070219002171, to_date('19-02-2007', 'dd-mm-yyyy'), to_date('05-03-2007', 'dd-mm-yyyy'), 5, 6246, to_date('28-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121028002172, to_date('28-10-2012', 'dd-mm-yyyy'), to_date('11-11-2012', 'dd-mm-yyyy'), 10, 11408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040609002173, to_date('09-06-2004', 'dd-mm-yyyy'), to_date('23-06-2004', 'dd-mm-yyyy'), 9, 3541, to_date('11-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107002174, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 7, 5707, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040616002175, to_date('16-06-2004', 'dd-mm-yyyy'), to_date('30-06-2004', 'dd-mm-yyyy'), 11, 4073, to_date('18-06-2004', 'dd-mm-yyyy'));
commit;
prompt 6000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040503002176, to_date('03-05-2004', 'dd-mm-yyyy'), to_date('17-05-2004', 'dd-mm-yyyy'), 5, 4307, to_date('10-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010914002177, to_date('14-09-2001', 'dd-mm-yyyy'), to_date('28-09-2001', 'dd-mm-yyyy'), 8, 2420, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030421002178, to_date('21-04-2003', 'dd-mm-yyyy'), to_date('05-05-2003', 'dd-mm-yyyy'), 4, 5086, to_date('03-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206002179, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 3, 4546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090728002180, to_date('28-07-2009', 'dd-mm-yyyy'), to_date('11-08-2009', 'dd-mm-yyyy'), 5, 6516, to_date('04-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010926002181, to_date('26-09-2001', 'dd-mm-yyyy'), to_date('10-10-2001', 'dd-mm-yyyy'), 3, 2020, to_date('16-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031223002182, to_date('23-12-2003', 'dd-mm-yyyy'), to_date('06-01-2004', 'dd-mm-yyyy'), 4, 5271, to_date('05-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140513002183, to_date('13-05-2014', 'dd-mm-yyyy'), to_date('27-05-2014', 'dd-mm-yyyy'), 8, 9111, to_date('16-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602002184, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 2, 2838, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628002185, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 2, 2359, to_date('09-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041105002186, to_date('05-11-2004', 'dd-mm-yyyy'), to_date('19-11-2004', 'dd-mm-yyyy'), 11, 2975, to_date('13-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323002187, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 6, 5719, to_date('25-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110310002188, to_date('10-03-2011', 'dd-mm-yyyy'), to_date('24-03-2011', 'dd-mm-yyyy'), 3, 7446, to_date('17-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000226002189, to_date('26-02-2000', 'dd-mm-yyyy'), to_date('11-03-2000', 'dd-mm-yyyy'), 7, 3291, to_date('05-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110417002190, to_date('17-04-2011', 'dd-mm-yyyy'), to_date('01-05-2011', 'dd-mm-yyyy'), 8, 7732, to_date('29-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030215002191, to_date('15-02-2003', 'dd-mm-yyyy'), to_date('01-03-2003', 'dd-mm-yyyy'), 6, 5317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130515002192, to_date('15-05-2013', 'dd-mm-yyyy'), to_date('29-05-2013', 'dd-mm-yyyy'), 9, 10285, to_date('23-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116002193, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 7, 8175, to_date('28-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006002194, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 1, 9323, to_date('16-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031024002195, to_date('24-10-2003', 'dd-mm-yyyy'), to_date('07-11-2003', 'dd-mm-yyyy'), 5, 2397, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220002196, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 3, 9193, to_date('09-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130506002197, to_date('06-05-2013', 'dd-mm-yyyy'), to_date('20-05-2013', 'dd-mm-yyyy'), 7, 12052, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321002198, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 8, 10842, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624002199, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 3, 2864, to_date('05-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001003002200, to_date('03-10-2000', 'dd-mm-yyyy'), to_date('17-10-2000', 'dd-mm-yyyy'), 8, 2194, to_date('21-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120411002201, to_date('11-04-2012', 'dd-mm-yyyy'), to_date('25-04-2012', 'dd-mm-yyyy'), 6, 6634, to_date('29-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405002202, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 4, 5332, to_date('14-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020510002203, to_date('10-05-2002', 'dd-mm-yyyy'), to_date('24-05-2002', 'dd-mm-yyyy'), 5, 4169, to_date('28-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108002204, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 9, 3962, to_date('25-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041027002205, to_date('27-10-2004', 'dd-mm-yyyy'), to_date('10-11-2004', 'dd-mm-yyyy'), 5, 5351, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010803002206, to_date('03-08-2001', 'dd-mm-yyyy'), to_date('17-08-2001', 'dd-mm-yyyy'), 10, 2748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060506002207, to_date('06-05-2006', 'dd-mm-yyyy'), to_date('20-05-2006', 'dd-mm-yyyy'), 1, 2869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060414002208, to_date('14-04-2006', 'dd-mm-yyyy'), to_date('28-04-2006', 'dd-mm-yyyy'), 9, 4831, to_date('26-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140203002209, to_date('03-02-2014', 'dd-mm-yyyy'), to_date('17-02-2014', 'dd-mm-yyyy'), 3, 7452, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011023002210, to_date('23-10-2001', 'dd-mm-yyyy'), to_date('06-11-2001', 'dd-mm-yyyy'), 6, 923, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522002211, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 2, 1860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907002212, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 4, 3921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010801002213, to_date('01-08-2001', 'dd-mm-yyyy'), to_date('15-08-2001', 'dd-mm-yyyy'), 6, 2495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050512002214, to_date('12-05-2005', 'dd-mm-yyyy'), to_date('26-05-2005', 'dd-mm-yyyy'), 6, 4936, to_date('17-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090117002215, to_date('17-01-2009', 'dd-mm-yyyy'), to_date('31-01-2009', 'dd-mm-yyyy'), 10, 8694, to_date('29-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060719002216, to_date('19-07-2006', 'dd-mm-yyyy'), to_date('02-08-2006', 'dd-mm-yyyy'), 8, 3499, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222002217, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 8, 6725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000417002218, to_date('17-04-2000', 'dd-mm-yyyy'), to_date('01-05-2000', 'dd-mm-yyyy'), 7, 1405, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120426002219, to_date('26-04-2012', 'dd-mm-yyyy'), to_date('10-05-2012', 'dd-mm-yyyy'), 3, 10144, to_date('02-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070523002220, to_date('23-05-2007', 'dd-mm-yyyy'), to_date('06-06-2007', 'dd-mm-yyyy'), 5, 2942, to_date('27-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100429002221, to_date('29-04-2010', 'dd-mm-yyyy'), to_date('13-05-2010', 'dd-mm-yyyy'), 8, 11533, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090825002222, to_date('25-08-2009', 'dd-mm-yyyy'), to_date('08-09-2009', 'dd-mm-yyyy'), 4, 4724, to_date('10-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140213002223, to_date('13-02-2014', 'dd-mm-yyyy'), to_date('27-02-2014', 'dd-mm-yyyy'), 10, 9521, to_date('26-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921002224, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 2, 8093, to_date('30-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010807002225, to_date('07-08-2001', 'dd-mm-yyyy'), to_date('21-08-2001', 'dd-mm-yyyy'), 8, 1389, to_date('18-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516002226, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 2, 3608, to_date('29-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060619002227, to_date('19-06-2006', 'dd-mm-yyyy'), to_date('03-07-2006', 'dd-mm-yyyy'), 6, 3770, to_date('09-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111124002228, to_date('24-11-2011', 'dd-mm-yyyy'), to_date('08-12-2011', 'dd-mm-yyyy'), 9, 8606, to_date('02-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101123002229, to_date('23-11-2010', 'dd-mm-yyyy'), to_date('07-12-2010', 'dd-mm-yyyy'), 11, 6148, to_date('02-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020720002230, to_date('20-07-2002', 'dd-mm-yyyy'), to_date('03-08-2002', 'dd-mm-yyyy'), 3, 2723, to_date('31-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821002231, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 5, 6220, to_date('07-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091125002232, to_date('25-11-2009', 'dd-mm-yyyy'), to_date('09-12-2009', 'dd-mm-yyyy'), 6, 6293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090924002233, to_date('24-09-2009', 'dd-mm-yyyy'), to_date('08-10-2009', 'dd-mm-yyyy'), 6, 6128, to_date('02-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811002234, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 10, 6314, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060524002235, to_date('24-05-2006', 'dd-mm-yyyy'), to_date('07-06-2006', 'dd-mm-yyyy'), 11, 4787, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090526002236, to_date('26-05-2009', 'dd-mm-yyyy'), to_date('09-06-2009', 'dd-mm-yyyy'), 11, 10192, to_date('28-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080121002237, to_date('21-01-2008', 'dd-mm-yyyy'), to_date('04-02-2008', 'dd-mm-yyyy'), 2, 5718, to_date('24-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604002238, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 2, 7611, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131129002239, to_date('29-11-2013', 'dd-mm-yyyy'), to_date('13-12-2013', 'dd-mm-yyyy'), 9, 11562, to_date('08-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070825002240, to_date('25-08-2007', 'dd-mm-yyyy'), to_date('08-09-2007', 'dd-mm-yyyy'), 12, 4895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080912002241, to_date('12-09-2008', 'dd-mm-yyyy'), to_date('26-09-2008', 'dd-mm-yyyy'), 12, 6406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061226002242, to_date('26-12-2006', 'dd-mm-yyyy'), to_date('09-01-2007', 'dd-mm-yyyy'), 3, 3054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116002243, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 4, 8539, to_date('25-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825002244, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 11, 7853, to_date('09-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712002245, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 10, 1624, to_date('29-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023002246, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 10, 2883, to_date('30-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100901002247, to_date('01-09-2010', 'dd-mm-yyyy'), to_date('15-09-2010', 'dd-mm-yyyy'), 2, 8681, to_date('20-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091108002248, to_date('08-11-2009', 'dd-mm-yyyy'), to_date('22-11-2009', 'dd-mm-yyyy'), 11, 6549, to_date('10-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723002249, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 9, 8604, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030225002250, to_date('25-02-2003', 'dd-mm-yyyy'), to_date('11-03-2003', 'dd-mm-yyyy'), 9, 2726, to_date('06-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100225002251, to_date('25-02-2010', 'dd-mm-yyyy'), to_date('11-03-2010', 'dd-mm-yyyy'), 11, 5477, to_date('01-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041106002252, to_date('06-11-2004', 'dd-mm-yyyy'), to_date('20-11-2004', 'dd-mm-yyyy'), 8, 2546, to_date('13-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131104002253, to_date('04-11-2013', 'dd-mm-yyyy'), to_date('18-11-2013', 'dd-mm-yyyy'), 11, 8650, to_date('07-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010430002254, to_date('30-04-2001', 'dd-mm-yyyy'), to_date('14-05-2001', 'dd-mm-yyyy'), 3, 935, to_date('02-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530002255, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 9, 732, to_date('04-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130513002256, to_date('13-05-2013', 'dd-mm-yyyy'), to_date('27-05-2013', 'dd-mm-yyyy'), 7, 7882, to_date('21-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302002257, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 8, 2385, to_date('20-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010629002258, to_date('29-06-2001', 'dd-mm-yyyy'), to_date('13-07-2001', 'dd-mm-yyyy'), 11, 1661, to_date('04-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130819002259, to_date('19-08-2013', 'dd-mm-yyyy'), to_date('02-09-2013', 'dd-mm-yyyy'), 4, 7856, to_date('06-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080805002260, to_date('05-08-2008', 'dd-mm-yyyy'), to_date('19-08-2008', 'dd-mm-yyyy'), 11, 6084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016002261, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 7, 6742, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010609002262, to_date('09-06-2001', 'dd-mm-yyyy'), to_date('23-06-2001', 'dd-mm-yyyy'), 2, 2409, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201002263, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 11, 8418, to_date('03-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030130002264, to_date('30-01-2003', 'dd-mm-yyyy'), to_date('13-02-2003', 'dd-mm-yyyy'), 5, 3426, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404002265, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 2, 5662, to_date('08-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000226002266, to_date('26-02-2000', 'dd-mm-yyyy'), to_date('11-03-2000', 'dd-mm-yyyy'), 5, 1536, to_date('15-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110606002267, to_date('06-06-2011', 'dd-mm-yyyy'), to_date('20-06-2011', 'dd-mm-yyyy'), 12, 10866, to_date('10-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120626002268, to_date('26-06-2012', 'dd-mm-yyyy'), to_date('10-07-2012', 'dd-mm-yyyy'), 2, 9174, to_date('15-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824002269, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 9, 6159, to_date('13-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071015002270, to_date('15-10-2007', 'dd-mm-yyyy'), to_date('29-10-2007', 'dd-mm-yyyy'), 10, 4339, to_date('25-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020626002271, to_date('26-06-2002', 'dd-mm-yyyy'), to_date('10-07-2002', 'dd-mm-yyyy'), 5, 2552, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130304002272, to_date('04-03-2013', 'dd-mm-yyyy'), to_date('18-03-2013', 'dd-mm-yyyy'), 2, 9262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429002273, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 7, 5525, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060708002274, to_date('08-07-2006', 'dd-mm-yyyy'), to_date('22-07-2006', 'dd-mm-yyyy'), 2, 5696, to_date('17-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703002275, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 7, 3570, to_date('09-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140307002276, to_date('07-03-2014', 'dd-mm-yyyy'), to_date('21-03-2014', 'dd-mm-yyyy'), 9, 10473, to_date('19-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204002277, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 2, 9488, to_date('18-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020119002278, to_date('19-01-2002', 'dd-mm-yyyy'), to_date('02-02-2002', 'dd-mm-yyyy'), 2, 2216, to_date('21-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630002279, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 10, 2807, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030517002280, to_date('17-05-2003', 'dd-mm-yyyy'), to_date('31-05-2003', 'dd-mm-yyyy'), 11, 3116, to_date('22-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130414002281, to_date('14-04-2013', 'dd-mm-yyyy'), to_date('28-04-2013', 'dd-mm-yyyy'), 12, 7855, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050303002282, to_date('03-03-2005', 'dd-mm-yyyy'), to_date('17-03-2005', 'dd-mm-yyyy'), 5, 4238, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041010002283, to_date('10-10-2004', 'dd-mm-yyyy'), to_date('24-10-2004', 'dd-mm-yyyy'), 9, 5091, to_date('25-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125002284, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 11, 6333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081007002285, to_date('07-10-2008', 'dd-mm-yyyy'), to_date('21-10-2008', 'dd-mm-yyyy'), 3, 5846, to_date('18-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080428002286, to_date('28-04-2008', 'dd-mm-yyyy'), to_date('12-05-2008', 'dd-mm-yyyy'), 12, 6308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020719002287, to_date('19-07-2002', 'dd-mm-yyyy'), to_date('02-08-2002', 'dd-mm-yyyy'), 10, 2811, to_date('22-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080115002288, to_date('15-01-2008', 'dd-mm-yyyy'), to_date('29-01-2008', 'dd-mm-yyyy'), 11, 9192, to_date('01-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030323002289, to_date('23-03-2003', 'dd-mm-yyyy'), to_date('06-04-2003', 'dd-mm-yyyy'), 5, 4567, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001008002290, to_date('08-10-2000', 'dd-mm-yyyy'), to_date('22-10-2000', 'dd-mm-yyyy'), 6, 1201, to_date('10-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110905002291, to_date('05-09-2011', 'dd-mm-yyyy'), to_date('19-09-2011', 'dd-mm-yyyy'), 9, 7193, to_date('07-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050127002292, to_date('27-01-2005', 'dd-mm-yyyy'), to_date('10-02-2005', 'dd-mm-yyyy'), 10, 3368, to_date('11-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001011002293, to_date('11-10-2000', 'dd-mm-yyyy'), to_date('25-10-2000', 'dd-mm-yyyy'), 3, 1693, to_date('30-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040714002294, to_date('14-07-2004', 'dd-mm-yyyy'), to_date('28-07-2004', 'dd-mm-yyyy'), 6, 3914, to_date('02-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050404002295, to_date('04-04-2005', 'dd-mm-yyyy'), to_date('18-04-2005', 'dd-mm-yyyy'), 9, 5068, to_date('23-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215004594, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 9, 7827, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605004595, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 9, 1417, to_date('19-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511004596, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 11, 2529, to_date('29-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130523004597, to_date('23-05-2013', 'dd-mm-yyyy'), to_date('06-06-2013', 'dd-mm-yyyy'), 2, 7544, to_date('05-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060605004598, to_date('05-06-2006', 'dd-mm-yyyy'), to_date('19-06-2006', 'dd-mm-yyyy'), 4, 5549, to_date('22-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120912004599, to_date('12-09-2012', 'dd-mm-yyyy'), to_date('26-09-2012', 'dd-mm-yyyy'), 6, 5604, to_date('17-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911004600, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 8, 6669, to_date('17-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110311004601, to_date('11-03-2011', 'dd-mm-yyyy'), to_date('25-03-2011', 'dd-mm-yyyy'), 1, 5832, to_date('16-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050920004602, to_date('20-09-2005', 'dd-mm-yyyy'), to_date('04-10-2005', 'dd-mm-yyyy'), 5, 3150, to_date('06-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090514004603, to_date('14-05-2009', 'dd-mm-yyyy'), to_date('28-05-2009', 'dd-mm-yyyy'), 6, 8023, to_date('26-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000813004604, to_date('13-08-2000', 'dd-mm-yyyy'), to_date('27-08-2000', 'dd-mm-yyyy'), 7, 2220, to_date('27-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030418004605, to_date('18-04-2003', 'dd-mm-yyyy'), to_date('02-05-2003', 'dd-mm-yyyy'), 2, 2872, to_date('03-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090609004606, to_date('09-06-2009', 'dd-mm-yyyy'), to_date('23-06-2009', 'dd-mm-yyyy'), 10, 5046, to_date('13-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090323004607, to_date('23-03-2009', 'dd-mm-yyyy'), to_date('06-04-2009', 'dd-mm-yyyy'), 10, 6756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110410004608, to_date('10-04-2011', 'dd-mm-yyyy'), to_date('24-04-2011', 'dd-mm-yyyy'), 2, 8078, to_date('17-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031207004609, to_date('07-12-2003', 'dd-mm-yyyy'), to_date('21-12-2003', 'dd-mm-yyyy'), 4, 3825, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928004610, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 8, 5537, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080311004611, to_date('11-03-2008', 'dd-mm-yyyy'), to_date('25-03-2008', 'dd-mm-yyyy'), 10, 6975, to_date('16-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000622004612, to_date('22-06-2000', 'dd-mm-yyyy'), to_date('06-07-2000', 'dd-mm-yyyy'), 11, 525, to_date('02-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121004613, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 8, 810, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140211004614, to_date('11-02-2014', 'dd-mm-yyyy'), to_date('25-02-2014', 'dd-mm-yyyy'), 7, 6669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090306004615, to_date('06-03-2009', 'dd-mm-yyyy'), to_date('20-03-2009', 'dd-mm-yyyy'), 7, 5553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509004616, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 11, 4622, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120415004617, to_date('15-04-2012', 'dd-mm-yyyy'), to_date('29-04-2012', 'dd-mm-yyyy'), 6, 10358, to_date('24-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020117004618, to_date('17-01-2002', 'dd-mm-yyyy'), to_date('31-01-2002', 'dd-mm-yyyy'), 4, 3554, to_date('06-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040727004619, to_date('27-07-2004', 'dd-mm-yyyy'), to_date('10-08-2004', 'dd-mm-yyyy'), 2, 4692, to_date('11-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030228004620, to_date('28-02-2003', 'dd-mm-yyyy'), to_date('14-03-2003', 'dd-mm-yyyy'), 8, 2424, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050210004621, to_date('10-02-2005', 'dd-mm-yyyy'), to_date('24-02-2005', 'dd-mm-yyyy'), 4, 3693, to_date('01-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010718004622, to_date('18-07-2001', 'dd-mm-yyyy'), to_date('01-08-2001', 'dd-mm-yyyy'), 3, 1941, to_date('25-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121216004623, to_date('16-12-2012', 'dd-mm-yyyy'), to_date('30-12-2012', 'dd-mm-yyyy'), 8, 9612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030414004624, to_date('14-04-2003', 'dd-mm-yyyy'), to_date('28-04-2003', 'dd-mm-yyyy'), 3, 3559, to_date('16-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120810004625, to_date('10-08-2012', 'dd-mm-yyyy'), to_date('24-08-2012', 'dd-mm-yyyy'), 6, 6670, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110923004626, to_date('23-09-2011', 'dd-mm-yyyy'), to_date('07-10-2011', 'dd-mm-yyyy'), 3, 7315, to_date('08-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080831004627, to_date('31-08-2008', 'dd-mm-yyyy'), to_date('14-09-2008', 'dd-mm-yyyy'), 11, 5780, to_date('09-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111205004628, to_date('05-12-2011', 'dd-mm-yyyy'), to_date('19-12-2011', 'dd-mm-yyyy'), 9, 7645, to_date('08-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000422004629, to_date('22-04-2000', 'dd-mm-yyyy'), to_date('06-05-2000', 'dd-mm-yyyy'), 7, 1687, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020503004630, to_date('03-05-2002', 'dd-mm-yyyy'), to_date('17-05-2002', 'dd-mm-yyyy'), 2, 2883, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000807004631, to_date('07-08-2000', 'dd-mm-yyyy'), to_date('21-08-2000', 'dd-mm-yyyy'), 10, 2900, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130209004632, to_date('09-02-2013', 'dd-mm-yyyy'), to_date('23-02-2013', 'dd-mm-yyyy'), 4, 7706, to_date('18-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070927004633, to_date('27-09-2007', 'dd-mm-yyyy'), to_date('11-10-2007', 'dd-mm-yyyy'), 1, 6415, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510004634, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 5, 1484, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030317004635, to_date('17-03-2003', 'dd-mm-yyyy'), to_date('31-03-2003', 'dd-mm-yyyy'), 2, 2832, to_date('05-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101004636, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 1, 2388, to_date('05-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081206004637, to_date('06-12-2008', 'dd-mm-yyyy'), to_date('20-12-2008', 'dd-mm-yyyy'), 9, 4881, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214004638, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 10, 8102, to_date('19-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080328004639, to_date('28-03-2008', 'dd-mm-yyyy'), to_date('11-04-2008', 'dd-mm-yyyy'), 10, 5343, to_date('15-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119004640, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 12, 3807, to_date('22-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140324004641, to_date('24-03-2014', 'dd-mm-yyyy'), to_date('07-04-2014', 'dd-mm-yyyy'), 1, 8210, to_date('12-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071219004642, to_date('19-12-2007', 'dd-mm-yyyy'), to_date('02-01-2008', 'dd-mm-yyyy'), 8, 5442, to_date('31-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100929004643, to_date('29-09-2010', 'dd-mm-yyyy'), to_date('13-10-2010', 'dd-mm-yyyy'), 10, 6903, to_date('15-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101003004644, to_date('03-10-2010', 'dd-mm-yyyy'), to_date('17-10-2010', 'dd-mm-yyyy'), 3, 5608, to_date('13-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060407004645, to_date('07-04-2006', 'dd-mm-yyyy'), to_date('21-04-2006', 'dd-mm-yyyy'), 8, 5869, to_date('23-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110625004646, to_date('25-06-2011', 'dd-mm-yyyy'), to_date('09-07-2011', 'dd-mm-yyyy'), 4, 9332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041024004647, to_date('24-10-2004', 'dd-mm-yyyy'), to_date('07-11-2004', 'dd-mm-yyyy'), 3, 3501, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100520004648, to_date('20-05-2010', 'dd-mm-yyyy'), to_date('03-06-2010', 'dd-mm-yyyy'), 5, 7065, to_date('27-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019004649, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 7, 8662, to_date('26-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000411004650, to_date('11-04-2000', 'dd-mm-yyyy'), to_date('25-04-2000', 'dd-mm-yyyy'), 4, 815, to_date('24-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212004651, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 11, 3056, to_date('13-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050324004652, to_date('24-03-2005', 'dd-mm-yyyy'), to_date('07-04-2005', 'dd-mm-yyyy'), 4, 4519, to_date('08-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071104004653, to_date('04-11-2007', 'dd-mm-yyyy'), to_date('18-11-2007', 'dd-mm-yyyy'), 8, 4945, to_date('07-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000929004654, to_date('29-09-2000', 'dd-mm-yyyy'), to_date('13-10-2000', 'dd-mm-yyyy'), 10, 1208, to_date('10-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901004655, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 9, 4714, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130419004656, to_date('19-04-2013', 'dd-mm-yyyy'), to_date('03-05-2013', 'dd-mm-yyyy'), 11, 8812, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070719004657, to_date('19-07-2007', 'dd-mm-yyyy'), to_date('02-08-2007', 'dd-mm-yyyy'), 7, 8696, to_date('26-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215004658, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 9, 8544, to_date('21-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010321004659, to_date('21-03-2001', 'dd-mm-yyyy'), to_date('04-04-2001', 'dd-mm-yyyy'), 8, 1768, to_date('08-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080709004660, to_date('09-07-2008', 'dd-mm-yyyy'), to_date('23-07-2008', 'dd-mm-yyyy'), 8, 4655, to_date('28-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080119004661, to_date('19-01-2008', 'dd-mm-yyyy'), to_date('02-02-2008', 'dd-mm-yyyy'), 11, 6640, to_date('08-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070123004662, to_date('23-01-2007', 'dd-mm-yyyy'), to_date('06-02-2007', 'dd-mm-yyyy'), 6, 6987, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109004663, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 3, 6267, to_date('27-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030412004664, to_date('12-04-2003', 'dd-mm-yyyy'), to_date('26-04-2003', 'dd-mm-yyyy'), 3, 3751, to_date('24-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204004665, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 7, 6927, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110217004666, to_date('17-02-2011', 'dd-mm-yyyy'), to_date('03-03-2011', 'dd-mm-yyyy'), 3, 8906, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121012004667, to_date('12-10-2012', 'dd-mm-yyyy'), to_date('26-10-2012', 'dd-mm-yyyy'), 3, 8933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110712004668, to_date('12-07-2011', 'dd-mm-yyyy'), to_date('26-07-2011', 'dd-mm-yyyy'), 8, 7462, to_date('24-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110731004669, to_date('31-07-2011', 'dd-mm-yyyy'), to_date('14-08-2011', 'dd-mm-yyyy'), 8, 8535, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130515004670, to_date('15-05-2013', 'dd-mm-yyyy'), to_date('29-05-2013', 'dd-mm-yyyy'), 4, 8646, to_date('25-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131226004671, to_date('26-12-2013', 'dd-mm-yyyy'), to_date('09-01-2014', 'dd-mm-yyyy'), 2, 8331, to_date('15-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120716004672, to_date('16-07-2012', 'dd-mm-yyyy'), to_date('30-07-2012', 'dd-mm-yyyy'), 6, 9080, to_date('04-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108004673, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 3, 5786, to_date('24-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100726004674, to_date('26-07-2010', 'dd-mm-yyyy'), to_date('09-08-2010', 'dd-mm-yyyy'), 3, 8431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901004675, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 12, 1470, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618004676, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 9, 8780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041004004677, to_date('04-10-2004', 'dd-mm-yyyy'), to_date('18-10-2004', 'dd-mm-yyyy'), 6, 4667, to_date('10-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420004678, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 11, 6539, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130521004679, to_date('21-05-2013', 'dd-mm-yyyy'), to_date('04-06-2013', 'dd-mm-yyyy'), 10, 8132, to_date('25-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000814004680, to_date('14-08-2000', 'dd-mm-yyyy'), to_date('28-08-2000', 'dd-mm-yyyy'), 7, 1801, to_date('20-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060625004681, to_date('25-06-2006', 'dd-mm-yyyy'), to_date('09-07-2006', 'dd-mm-yyyy'), 8, 4529, to_date('01-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080219004682, to_date('19-02-2008', 'dd-mm-yyyy'), to_date('04-03-2008', 'dd-mm-yyyy'), 12, 5678, to_date('24-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000407004683, to_date('07-04-2000', 'dd-mm-yyyy'), to_date('21-04-2000', 'dd-mm-yyyy'), 8, 578, to_date('26-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010615004684, to_date('15-06-2001', 'dd-mm-yyyy'), to_date('29-06-2001', 'dd-mm-yyyy'), 7, 4424, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091121004685, to_date('21-11-2009', 'dd-mm-yyyy'), to_date('05-12-2009', 'dd-mm-yyyy'), 3, 8063, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120204004686, to_date('04-02-2012', 'dd-mm-yyyy'), to_date('18-02-2012', 'dd-mm-yyyy'), 7, 10025, to_date('10-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100331004687, to_date('31-03-2010', 'dd-mm-yyyy'), to_date('14-04-2010', 'dd-mm-yyyy'), 3, 6623, to_date('02-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120004688, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 1, 2254, to_date('06-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050706004689, to_date('06-07-2005', 'dd-mm-yyyy'), to_date('20-07-2005', 'dd-mm-yyyy'), 9, 3726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090612004690, to_date('12-06-2009', 'dd-mm-yyyy'), to_date('26-06-2009', 'dd-mm-yyyy'), 3, 8270, to_date('01-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091120004691, to_date('20-11-2009', 'dd-mm-yyyy'), to_date('04-12-2009', 'dd-mm-yyyy'), 9, 6532, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021217004692, to_date('17-12-2002', 'dd-mm-yyyy'), to_date('31-12-2002', 'dd-mm-yyyy'), 8, 4689, to_date('01-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110420004693, to_date('20-04-2011', 'dd-mm-yyyy'), to_date('04-05-2011', 'dd-mm-yyyy'), 2, 7897, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131030004694, to_date('30-10-2013', 'dd-mm-yyyy'), to_date('13-11-2013', 'dd-mm-yyyy'), 3, 8792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020904004695, to_date('04-09-2002', 'dd-mm-yyyy'), to_date('18-09-2002', 'dd-mm-yyyy'), 5, 3191, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107004696, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 6, 7487, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311004697, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 12, 5862, to_date('13-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080515004698, to_date('15-05-2008', 'dd-mm-yyyy'), to_date('29-05-2008', 'dd-mm-yyyy'), 6, 7648, to_date('25-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140107004699, to_date('07-01-2014', 'dd-mm-yyyy'), to_date('21-01-2014', 'dd-mm-yyyy'), 2, 8381, to_date('20-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080130004700, to_date('30-01-2008', 'dd-mm-yyyy'), to_date('13-02-2008', 'dd-mm-yyyy'), 10, 6186, to_date('02-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060115004701, to_date('15-01-2006', 'dd-mm-yyyy'), to_date('29-01-2006', 'dd-mm-yyyy'), 9, 7041, to_date('27-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100616004702, to_date('16-06-2010', 'dd-mm-yyyy'), to_date('30-06-2010', 'dd-mm-yyyy'), 9, 8436, to_date('25-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070219004703, to_date('19-02-2007', 'dd-mm-yyyy'), to_date('05-03-2007', 'dd-mm-yyyy'), 6, 5702, to_date('09-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091027004704, to_date('27-10-2009', 'dd-mm-yyyy'), to_date('10-11-2009', 'dd-mm-yyyy'), 6, 8150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418004705, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 3, 8648, to_date('20-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010726004706, to_date('26-07-2001', 'dd-mm-yyyy'), to_date('09-08-2001', 'dd-mm-yyyy'), 11, 2316, to_date('09-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090612004707, to_date('12-06-2009', 'dd-mm-yyyy'), to_date('26-06-2009', 'dd-mm-yyyy'), 7, 7159, to_date('19-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526004708, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 6, 9715, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120826004709, to_date('26-08-2012', 'dd-mm-yyyy'), to_date('09-09-2012', 'dd-mm-yyyy'), 7, 10498, to_date('02-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011104004710, to_date('04-11-2001', 'dd-mm-yyyy'), to_date('18-11-2001', 'dd-mm-yyyy'), 1, 1614, to_date('20-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604004711, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 12, 9924, to_date('09-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080923004712, to_date('23-09-2008', 'dd-mm-yyyy'), to_date('07-10-2008', 'dd-mm-yyyy'), 3, 8916, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131114004713, to_date('14-11-2013', 'dd-mm-yyyy'), to_date('28-11-2013', 'dd-mm-yyyy'), 6, 9274, to_date('26-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031211004714, to_date('11-12-2003', 'dd-mm-yyyy'), to_date('25-12-2003', 'dd-mm-yyyy'), 2, 3123, to_date('23-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101004715, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 12, 4232, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020524004716, to_date('24-05-2002', 'dd-mm-yyyy'), to_date('07-06-2002', 'dd-mm-yyyy'), 7, 2252, to_date('09-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091117004717, to_date('17-11-2009', 'dd-mm-yyyy'), to_date('01-12-2009', 'dd-mm-yyyy'), 3, 8795, to_date('26-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020626004718, to_date('26-06-2002', 'dd-mm-yyyy'), to_date('10-07-2002', 'dd-mm-yyyy'), 4, 1714, to_date('03-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130811004719, to_date('11-08-2013', 'dd-mm-yyyy'), to_date('25-08-2013', 'dd-mm-yyyy'), 10, 7452, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080908004720, to_date('08-09-2008', 'dd-mm-yyyy'), to_date('22-09-2008', 'dd-mm-yyyy'), 4, 7466, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820004721, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 10, 3107, to_date('01-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031028004722, to_date('28-10-2003', 'dd-mm-yyyy'), to_date('11-11-2003', 'dd-mm-yyyy'), 4, 1961, to_date('02-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921004723, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 11, 9780, to_date('26-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021221004724, to_date('21-12-2002', 'dd-mm-yyyy'), to_date('04-01-2003', 'dd-mm-yyyy'), 3, 5358, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111114004725, to_date('14-11-2011', 'dd-mm-yyyy'), to_date('28-11-2011', 'dd-mm-yyyy'), 2, 8353, to_date('22-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091204004726, to_date('04-12-2009', 'dd-mm-yyyy'), to_date('18-12-2009', 'dd-mm-yyyy'), 9, 7023, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061030004727, to_date('30-10-2006', 'dd-mm-yyyy'), to_date('13-11-2006', 'dd-mm-yyyy'), 1, 5795, to_date('05-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110511004728, to_date('11-05-2011', 'dd-mm-yyyy'), to_date('25-05-2011', 'dd-mm-yyyy'), 5, 9313, to_date('13-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131110004729, to_date('10-11-2013', 'dd-mm-yyyy'), to_date('24-11-2013', 'dd-mm-yyyy'), 7, 10348, to_date('19-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020929004730, to_date('29-09-2002', 'dd-mm-yyyy'), to_date('13-10-2002', 'dd-mm-yyyy'), 2, 3313, to_date('07-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221004731, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 9, 11643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111109004732, to_date('09-11-2011', 'dd-mm-yyyy'), to_date('23-11-2011', 'dd-mm-yyyy'), 12, 6391, to_date('23-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011007004733, to_date('07-10-2001', 'dd-mm-yyyy'), to_date('21-10-2001', 'dd-mm-yyyy'), 9, 1654, to_date('12-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916004734, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 5, 6183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080720004735, to_date('20-07-2008', 'dd-mm-yyyy'), to_date('03-08-2008', 'dd-mm-yyyy'), 4, 3149, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070207004736, to_date('07-02-2007', 'dd-mm-yyyy'), to_date('21-02-2007', 'dd-mm-yyyy'), 10, 4541, to_date('15-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010124004737, to_date('24-01-2001', 'dd-mm-yyyy'), to_date('07-02-2001', 'dd-mm-yyyy'), 4, 2598, to_date('29-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011112004738, to_date('12-11-2001', 'dd-mm-yyyy'), to_date('26-11-2001', 'dd-mm-yyyy'), 7, 3620, to_date('20-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010226004739, to_date('26-02-2001', 'dd-mm-yyyy'), to_date('12-03-2001', 'dd-mm-yyyy'), 12, 2799, to_date('13-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111225004740, to_date('25-12-2011', 'dd-mm-yyyy'), to_date('08-01-2012', 'dd-mm-yyyy'), 5, 7456, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040922004741, to_date('22-09-2004', 'dd-mm-yyyy'), to_date('06-10-2004', 'dd-mm-yyyy'), 5, 2551, to_date('25-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060226004742, to_date('26-02-2006', 'dd-mm-yyyy'), to_date('12-03-2006', 'dd-mm-yyyy'), 1, 4399, to_date('06-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090718004743, to_date('18-07-2009', 'dd-mm-yyyy'), to_date('01-08-2009', 'dd-mm-yyyy'), 6, 7618, to_date('24-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100407004744, to_date('07-04-2010', 'dd-mm-yyyy'), to_date('21-04-2010', 'dd-mm-yyyy'), 6, 9805, to_date('19-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100302006888, to_date('02-03-2010', 'dd-mm-yyyy'), to_date('16-03-2010', 'dd-mm-yyyy'), 10, 7350, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070707006889, to_date('07-07-2007', 'dd-mm-yyyy'), to_date('21-07-2007', 'dd-mm-yyyy'), 4, 5649, to_date('16-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408006890, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 4, 2076, to_date('11-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061121006891, to_date('21-11-2006', 'dd-mm-yyyy'), to_date('05-12-2006', 'dd-mm-yyyy'), 5, 3424, to_date('08-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924006892, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 5, 4572, to_date('30-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130206006893, to_date('06-02-2013', 'dd-mm-yyyy'), to_date('20-02-2013', 'dd-mm-yyyy'), 10, 7629, to_date('17-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060104006894, to_date('04-01-2006', 'dd-mm-yyyy'), to_date('18-01-2006', 'dd-mm-yyyy'), 6, 6579, to_date('20-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011218006895, to_date('18-12-2001', 'dd-mm-yyyy'), to_date('01-01-2002', 'dd-mm-yyyy'), 1, 1656, to_date('21-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070804006896, to_date('04-08-2007', 'dd-mm-yyyy'), to_date('18-08-2007', 'dd-mm-yyyy'), 4, 6067, to_date('11-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100426006897, to_date('26-04-2010', 'dd-mm-yyyy'), to_date('10-05-2010', 'dd-mm-yyyy'), 9, 7005, to_date('28-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050322006898, to_date('22-03-2005', 'dd-mm-yyyy'), to_date('05-04-2005', 'dd-mm-yyyy'), 4, 5243, to_date('29-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090202006899, to_date('02-02-2009', 'dd-mm-yyyy'), to_date('16-02-2009', 'dd-mm-yyyy'), 5, 8566, to_date('11-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010503006900, to_date('03-05-2001', 'dd-mm-yyyy'), to_date('17-05-2001', 'dd-mm-yyyy'), 1, 2924, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030820006901, to_date('20-08-2003', 'dd-mm-yyyy'), to_date('03-09-2003', 'dd-mm-yyyy'), 11, 1621, to_date('09-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090508006902, to_date('08-05-2009', 'dd-mm-yyyy'), to_date('22-05-2009', 'dd-mm-yyyy'), 10, 7450, to_date('27-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110705006903, to_date('05-07-2011', 'dd-mm-yyyy'), to_date('19-07-2011', 'dd-mm-yyyy'), 11, 9031, to_date('19-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714006904, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 6, 5580, to_date('26-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123006905, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 6, 4164, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060224006906, to_date('24-02-2006', 'dd-mm-yyyy'), to_date('10-03-2006', 'dd-mm-yyyy'), 8, 6435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020527006907, to_date('27-05-2002', 'dd-mm-yyyy'), to_date('10-06-2002', 'dd-mm-yyyy'), 7, 4862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201006908, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 9, 8384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060222006909, to_date('22-02-2006', 'dd-mm-yyyy'), to_date('08-03-2006', 'dd-mm-yyyy'), 10, 4977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020508006910, to_date('08-05-2002', 'dd-mm-yyyy'), to_date('22-05-2002', 'dd-mm-yyyy'), 6, 2131, to_date('21-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131218006911, to_date('18-12-2013', 'dd-mm-yyyy'), to_date('01-01-2014', 'dd-mm-yyyy'), 5, 9516, to_date('02-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130907006912, to_date('07-09-2013', 'dd-mm-yyyy'), to_date('21-09-2013', 'dd-mm-yyyy'), 7, 7882, to_date('12-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011008006913, to_date('08-10-2001', 'dd-mm-yyyy'), to_date('22-10-2001', 'dd-mm-yyyy'), 5, 2445, to_date('17-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090610006914, to_date('10-06-2009', 'dd-mm-yyyy'), to_date('24-06-2009', 'dd-mm-yyyy'), 1, 6309, to_date('13-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123006915, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 8, 9692, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423006916, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 4, 8676, to_date('01-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120129006917, to_date('29-01-2012', 'dd-mm-yyyy'), to_date('12-02-2012', 'dd-mm-yyyy'), 2, 7845, to_date('17-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060516006918, to_date('16-05-2006', 'dd-mm-yyyy'), to_date('30-05-2006', 'dd-mm-yyyy'), 4, 5267, to_date('26-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010714006919, to_date('14-07-2001', 'dd-mm-yyyy'), to_date('28-07-2001', 'dd-mm-yyyy'), 6, 2034, to_date('17-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031104006920, to_date('04-11-2003', 'dd-mm-yyyy'), to_date('18-11-2003', 'dd-mm-yyyy'), 9, 3136, to_date('14-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117006921, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 9, 6949, to_date('27-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130411006922, to_date('11-04-2013', 'dd-mm-yyyy'), to_date('25-04-2013', 'dd-mm-yyyy'), 8, 9656, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000107006923, to_date('07-01-2000', 'dd-mm-yyyy'), to_date('21-01-2000', 'dd-mm-yyyy'), 12, 1042, to_date('15-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070914006924, to_date('14-09-2007', 'dd-mm-yyyy'), to_date('28-09-2007', 'dd-mm-yyyy'), 10, 6089, to_date('25-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313006925, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 12, 8512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010419006926, to_date('19-04-2001', 'dd-mm-yyyy'), to_date('03-05-2001', 'dd-mm-yyyy'), 2, 1330, to_date('24-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101021006927, to_date('21-10-2010', 'dd-mm-yyyy'), to_date('04-11-2010', 'dd-mm-yyyy'), 5, 8357, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000527006928, to_date('27-05-2000', 'dd-mm-yyyy'), to_date('10-06-2000', 'dd-mm-yyyy'), 4, 1984, to_date('13-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503006929, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 6, 3196, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030612006930, to_date('12-06-2003', 'dd-mm-yyyy'), to_date('26-06-2003', 'dd-mm-yyyy'), 10, 1504, to_date('01-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515006931, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 3, 2839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612006932, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 6, 172, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051202006933, to_date('02-12-2005', 'dd-mm-yyyy'), to_date('16-12-2005', 'dd-mm-yyyy'), 5, 3895, to_date('06-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070816006934, to_date('16-08-2007', 'dd-mm-yyyy'), to_date('30-08-2007', 'dd-mm-yyyy'), 8, 4904, to_date('03-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120908006935, to_date('08-09-2012', 'dd-mm-yyyy'), to_date('22-09-2012', 'dd-mm-yyyy'), 12, 8185, to_date('27-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050806006936, to_date('06-08-2005', 'dd-mm-yyyy'), to_date('20-08-2005', 'dd-mm-yyyy'), 10, 4306, to_date('20-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219006937, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 2, 2476, to_date('30-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130906006938, to_date('06-09-2013', 'dd-mm-yyyy'), to_date('20-09-2013', 'dd-mm-yyyy'), 10, 11405, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140323006939, to_date('23-03-2014', 'dd-mm-yyyy'), to_date('06-04-2014', 'dd-mm-yyyy'), 8, 8062, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113006940, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 8, 2775, to_date('17-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124006941, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 9, 2539, to_date('06-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061230006942, to_date('30-12-2006', 'dd-mm-yyyy'), to_date('13-01-2007', 'dd-mm-yyyy'), 6, 5348, to_date('06-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131006943, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 1, 7093, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070722006944, to_date('22-07-2007', 'dd-mm-yyyy'), to_date('05-08-2007', 'dd-mm-yyyy'), 8, 4645, to_date('05-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021203006945, to_date('03-12-2002', 'dd-mm-yyyy'), to_date('17-12-2002', 'dd-mm-yyyy'), 5, 5549, to_date('20-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040716006946, to_date('16-07-2004', 'dd-mm-yyyy'), to_date('30-07-2004', 'dd-mm-yyyy'), 10, 3596, to_date('24-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060427006947, to_date('27-04-2006', 'dd-mm-yyyy'), to_date('11-05-2006', 'dd-mm-yyyy'), 2, 4982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130511006948, to_date('11-05-2013', 'dd-mm-yyyy'), to_date('25-05-2013', 'dd-mm-yyyy'), 9, 10480, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130127006949, to_date('27-01-2013', 'dd-mm-yyyy'), to_date('10-02-2013', 'dd-mm-yyyy'), 2, 9089, to_date('02-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110515006950, to_date('15-05-2011', 'dd-mm-yyyy'), to_date('29-05-2011', 'dd-mm-yyyy'), 11, 9321, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050709006951, to_date('09-07-2005', 'dd-mm-yyyy'), to_date('23-07-2005', 'dd-mm-yyyy'), 3, 3557, to_date('16-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030504006952, to_date('04-05-2003', 'dd-mm-yyyy'), to_date('18-05-2003', 'dd-mm-yyyy'), 9, 4130, to_date('11-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225006953, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 6, 5027, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040502006954, to_date('02-05-2004', 'dd-mm-yyyy'), to_date('16-05-2004', 'dd-mm-yyyy'), 6, 5042, to_date('19-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208006955, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 9, 7055, to_date('26-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100122006956, to_date('22-01-2010', 'dd-mm-yyyy'), to_date('05-02-2010', 'dd-mm-yyyy'), 11, 8807, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605006957, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 7, 2343, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921006958, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 7, 5148, to_date('26-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040808006959, to_date('08-08-2004', 'dd-mm-yyyy'), to_date('22-08-2004', 'dd-mm-yyyy'), 9, 1878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040321006960, to_date('21-03-2004', 'dd-mm-yyyy'), to_date('04-04-2004', 'dd-mm-yyyy'), 2, 4795, to_date('25-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070825006961, to_date('25-08-2007', 'dd-mm-yyyy'), to_date('08-09-2007', 'dd-mm-yyyy'), 7, 3809, to_date('02-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050803006962, to_date('03-08-2005', 'dd-mm-yyyy'), to_date('17-08-2005', 'dd-mm-yyyy'), 4, 6159, to_date('05-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051220006963, to_date('20-12-2005', 'dd-mm-yyyy'), to_date('03-01-2006', 'dd-mm-yyyy'), 5, 4808, to_date('28-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417006964, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 1, 2792, to_date('19-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010323006965, to_date('23-03-2001', 'dd-mm-yyyy'), to_date('06-04-2001', 'dd-mm-yyyy'), 1, 4100, to_date('09-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119006966, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 8, 2037, to_date('22-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710006967, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 1, 3244, to_date('22-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010421006968, to_date('21-04-2001', 'dd-mm-yyyy'), to_date('05-05-2001', 'dd-mm-yyyy'), 8, 2504, to_date('11-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020820006969, to_date('20-08-2002', 'dd-mm-yyyy'), to_date('03-09-2002', 'dd-mm-yyyy'), 1, 2612, to_date('30-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110308006970, to_date('08-03-2011', 'dd-mm-yyyy'), to_date('22-03-2011', 'dd-mm-yyyy'), 4, 7322, to_date('22-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321006971, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 7, 8818, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023006972, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 1, 3627, to_date('10-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010716006973, to_date('16-07-2001', 'dd-mm-yyyy'), to_date('30-07-2001', 'dd-mm-yyyy'), 5, 2246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427006974, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 2, 5973, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011105006975, to_date('05-11-2001', 'dd-mm-yyyy'), to_date('19-11-2001', 'dd-mm-yyyy'), 2, 1564, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080408006976, to_date('08-04-2008', 'dd-mm-yyyy'), to_date('22-04-2008', 'dd-mm-yyyy'), 11, 4545, to_date('21-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090502006977, to_date('02-05-2009', 'dd-mm-yyyy'), to_date('16-05-2009', 'dd-mm-yyyy'), 9, 4667, to_date('11-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080119006978, to_date('19-01-2008', 'dd-mm-yyyy'), to_date('02-02-2008', 'dd-mm-yyyy'), 3, 7402, to_date('29-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101006979, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 11, 4664, to_date('18-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091222006980, to_date('22-12-2009', 'dd-mm-yyyy'), to_date('05-01-2010', 'dd-mm-yyyy'), 9, 6441, to_date('27-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020118006981, to_date('18-01-2002', 'dd-mm-yyyy'), to_date('01-02-2002', 'dd-mm-yyyy'), 3, 3350, to_date('05-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120706006982, to_date('06-07-2012', 'dd-mm-yyyy'), to_date('20-07-2012', 'dd-mm-yyyy'), 10, 8065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505006983, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 2, 3846, to_date('20-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040808006984, to_date('08-08-2004', 'dd-mm-yyyy'), to_date('22-08-2004', 'dd-mm-yyyy'), 4, 3037, to_date('14-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050615006985, to_date('15-06-2005', 'dd-mm-yyyy'), to_date('29-06-2005', 'dd-mm-yyyy'), 10, 4314, to_date('30-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817006986, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 8, 7748, to_date('21-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020131006987, to_date('31-01-2002', 'dd-mm-yyyy'), to_date('14-02-2002', 'dd-mm-yyyy'), 9, 4157, to_date('16-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011101006988, to_date('01-11-2001', 'dd-mm-yyyy'), to_date('15-11-2001', 'dd-mm-yyyy'), 2, 2963, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050615006989, to_date('15-06-2005', 'dd-mm-yyyy'), to_date('29-06-2005', 'dd-mm-yyyy'), 5, 4415, to_date('27-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809006990, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 9, 2591, to_date('25-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710006991, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 1, 1906, to_date('28-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090228006992, to_date('28-02-2009', 'dd-mm-yyyy'), to_date('14-03-2009', 'dd-mm-yyyy'), 4, 9029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525006993, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 10, 8824, to_date('03-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060326006994, to_date('26-03-2006', 'dd-mm-yyyy'), to_date('09-04-2006', 'dd-mm-yyyy'), 2, 5693, to_date('28-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060810006995, to_date('10-08-2006', 'dd-mm-yyyy'), to_date('24-08-2006', 'dd-mm-yyyy'), 9, 5102, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080620006996, to_date('20-06-2008', 'dd-mm-yyyy'), to_date('04-07-2008', 'dd-mm-yyyy'), 8, 6984, to_date('01-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080318006997, to_date('18-03-2008', 'dd-mm-yyyy'), to_date('01-04-2008', 'dd-mm-yyyy'), 6, 7125, to_date('07-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801006998, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 3, 2007, to_date('02-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000114006999, to_date('14-01-2000', 'dd-mm-yyyy'), to_date('28-01-2000', 'dd-mm-yyyy'), 9, 2116, to_date('28-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507007000, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 4, 4425, to_date('13-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417007001, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 7, 4576, to_date('27-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031108007002, to_date('08-11-2003', 'dd-mm-yyyy'), to_date('22-11-2003', 'dd-mm-yyyy'), 1, 2706, to_date('10-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120419007003, to_date('19-04-2012', 'dd-mm-yyyy'), to_date('03-05-2012', 'dd-mm-yyyy'), 11, 6373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020111007004, to_date('11-01-2002', 'dd-mm-yyyy'), to_date('25-01-2002', 'dd-mm-yyyy'), 10, 3690, to_date('20-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906007005, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 2, 4897, to_date('24-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030524007006, to_date('24-05-2003', 'dd-mm-yyyy'), to_date('07-06-2003', 'dd-mm-yyyy'), 10, 3292, to_date('13-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000215007007, to_date('15-02-2000', 'dd-mm-yyyy'), to_date('29-02-2000', 'dd-mm-yyyy'), 5, 1127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081126007008, to_date('26-11-2008', 'dd-mm-yyyy'), to_date('10-12-2008', 'dd-mm-yyyy'), 12, 7780, to_date('16-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006007009, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 7, 5568, to_date('08-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020513007010, to_date('13-05-2002', 'dd-mm-yyyy'), to_date('27-05-2002', 'dd-mm-yyyy'), 5, 1630, to_date('26-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120314007011, to_date('14-03-2012', 'dd-mm-yyyy'), to_date('28-03-2012', 'dd-mm-yyyy'), 8, 6976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060102007012, to_date('02-01-2006', 'dd-mm-yyyy'), to_date('16-01-2006', 'dd-mm-yyyy'), 8, 6157, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070821007013, to_date('21-08-2007', 'dd-mm-yyyy'), to_date('04-09-2007', 'dd-mm-yyyy'), 6, 4521, to_date('02-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011109007014, to_date('09-11-2001', 'dd-mm-yyyy'), to_date('23-11-2001', 'dd-mm-yyyy'), 12, 1809, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060810007015, to_date('10-08-2006', 'dd-mm-yyyy'), to_date('24-08-2006', 'dd-mm-yyyy'), 6, 4502, to_date('14-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090107007016, to_date('07-01-2009', 'dd-mm-yyyy'), to_date('21-01-2009', 'dd-mm-yyyy'), 10, 5860, to_date('15-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408007017, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 10, 12222, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121129007018, to_date('29-11-2012', 'dd-mm-yyyy'), to_date('13-12-2012', 'dd-mm-yyyy'), 9, 7172, to_date('01-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120508007019, to_date('08-05-2012', 'dd-mm-yyyy'), to_date('22-05-2012', 'dd-mm-yyyy'), 6, 9903, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061004007020, to_date('04-10-2006', 'dd-mm-yyyy'), to_date('18-10-2006', 'dd-mm-yyyy'), 11, 4038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110126007021, to_date('26-01-2011', 'dd-mm-yyyy'), to_date('09-02-2011', 'dd-mm-yyyy'), 3, 5755, to_date('28-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106007022, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 5, 6634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215007023, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 3, 6864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100424007024, to_date('24-04-2010', 'dd-mm-yyyy'), to_date('08-05-2010', 'dd-mm-yyyy'), 10, 6104, to_date('07-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120115007025, to_date('15-01-2012', 'dd-mm-yyyy'), to_date('29-01-2012', 'dd-mm-yyyy'), 6, 8412, to_date('04-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100910007026, to_date('10-09-2010', 'dd-mm-yyyy'), to_date('24-09-2010', 'dd-mm-yyyy'), 3, 7390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121126007027, to_date('26-11-2012', 'dd-mm-yyyy'), to_date('10-12-2012', 'dd-mm-yyyy'), 9, 8407, to_date('13-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229007028, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 11, 6946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703007029, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 5, 3336, to_date('12-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011026007030, to_date('26-10-2001', 'dd-mm-yyyy'), to_date('09-11-2001', 'dd-mm-yyyy'), 8, 3420, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326007031, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 1, 4254, to_date('02-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040323007032, to_date('23-03-2004', 'dd-mm-yyyy'), to_date('06-04-2004', 'dd-mm-yyyy'), 5, 3760, to_date('31-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001116007033, to_date('16-11-2000', 'dd-mm-yyyy'), to_date('30-11-2000', 'dd-mm-yyyy'), 6, 893, to_date('18-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140416007034, to_date('16-04-2014', 'dd-mm-yyyy'), to_date('30-04-2014', 'dd-mm-yyyy'), 4, 8689, to_date('28-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220007035, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 10, 4958, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101007036, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 9, 3208, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215007037, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 2, 7391, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020217007038, to_date('17-02-2002', 'dd-mm-yyyy'), to_date('03-03-2002', 'dd-mm-yyyy'), 9, 3049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081009007039, to_date('09-10-2008', 'dd-mm-yyyy'), to_date('23-10-2008', 'dd-mm-yyyy'), 4, 6666, to_date('20-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011117000001, to_date('17-11-2001', 'dd-mm-yyyy'), to_date('01-12-2001', 'dd-mm-yyyy'), 4, 2549, to_date('22-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011014000002, to_date('14-10-2001', 'dd-mm-yyyy'), to_date('28-10-2001', 'dd-mm-yyyy'), 1, 2259, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530000003, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 8, 8664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061027000004, to_date('27-10-2006', 'dd-mm-yyyy'), to_date('10-11-2006', 'dd-mm-yyyy'), 4, 5932, to_date('09-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110204000005, to_date('04-02-2011', 'dd-mm-yyyy'), to_date('18-02-2011', 'dd-mm-yyyy'), 7, 4146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091103000006, to_date('03-11-2009', 'dd-mm-yyyy'), to_date('17-11-2009', 'dd-mm-yyyy'), 5, 8005, to_date('09-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725000007, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 10, 5291, to_date('09-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622000008, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 3, 6024, to_date('05-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060522000009, to_date('22-05-2006', 'dd-mm-yyyy'), to_date('05-06-2006', 'dd-mm-yyyy'), 7, 3730, to_date('04-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040113000010, to_date('13-01-2004', 'dd-mm-yyyy'), to_date('27-01-2004', 'dd-mm-yyyy'), 2, 2303, to_date('22-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020606000011, to_date('06-06-2002', 'dd-mm-yyyy'), to_date('20-06-2002', 'dd-mm-yyyy'), 2, 2020, to_date('16-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208000012, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 8, 2587, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912000013, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 6, 3581, to_date('27-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080731000014, to_date('31-07-2008', 'dd-mm-yyyy'), to_date('14-08-2008', 'dd-mm-yyyy'), 10, 5855, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010828000015, to_date('28-08-2001', 'dd-mm-yyyy'), to_date('11-09-2001', 'dd-mm-yyyy'), 9, 2054, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022000016, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 12, 4360, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025000017, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 7, 6846, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070802000018, to_date('02-08-2007', 'dd-mm-yyyy'), to_date('16-08-2007', 'dd-mm-yyyy'), 8, 2891, to_date('19-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022000019, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 4, 3974, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100416000020, to_date('16-04-2010', 'dd-mm-yyyy'), to_date('30-04-2010', 'dd-mm-yyyy'), 8, 6166, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031114000021, to_date('14-11-2003', 'dd-mm-yyyy'), to_date('28-11-2003', 'dd-mm-yyyy'), 11, 2646, to_date('29-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901000022, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 7, 1249, to_date('06-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010806000023, to_date('06-08-2001', 'dd-mm-yyyy'), to_date('20-08-2001', 'dd-mm-yyyy'), 5, 2792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820000024, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 2, 1332, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001014000025, to_date('14-10-2000', 'dd-mm-yyyy'), to_date('28-10-2000', 'dd-mm-yyyy'), 3, 1474, to_date('28-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140107000026, to_date('07-01-2014', 'dd-mm-yyyy'), to_date('21-01-2014', 'dd-mm-yyyy'), 10, 9786, to_date('11-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081231000027, to_date('31-12-2008', 'dd-mm-yyyy'), to_date('14-01-2009', 'dd-mm-yyyy'), 11, 5788, to_date('06-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081117000028, to_date('17-11-2008', 'dd-mm-yyyy'), to_date('01-12-2008', 'dd-mm-yyyy'), 6, 7083, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016000029, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 10, 3735, to_date('02-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070811000030, to_date('11-08-2007', 'dd-mm-yyyy'), to_date('25-08-2007', 'dd-mm-yyyy'), 9, 4538, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030124000031, to_date('24-01-2003', 'dd-mm-yyyy'), to_date('07-02-2003', 'dd-mm-yyyy'), 9, 1949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040410000032, to_date('10-04-2004', 'dd-mm-yyyy'), to_date('24-04-2004', 'dd-mm-yyyy'), 8, 4175, to_date('22-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121010000033, to_date('10-10-2012', 'dd-mm-yyyy'), to_date('24-10-2012', 'dd-mm-yyyy'), 8, 8313, to_date('16-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020718000034, to_date('18-07-2002', 'dd-mm-yyyy'), to_date('01-08-2002', 'dd-mm-yyyy'), 7, 2257, to_date('24-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041116000035, to_date('16-11-2004', 'dd-mm-yyyy'), to_date('30-11-2004', 'dd-mm-yyyy'), 10, 4909, to_date('18-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110611000036, to_date('11-06-2011', 'dd-mm-yyyy'), to_date('25-06-2011', 'dd-mm-yyyy'), 3, 7978, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929000037, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 5, 6909, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040825000038, to_date('25-08-2004', 'dd-mm-yyyy'), to_date('08-09-2004', 'dd-mm-yyyy'), 4, 3790, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908000039, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 11, 8012, to_date('24-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040428000040, to_date('28-04-2004', 'dd-mm-yyyy'), to_date('12-05-2004', 'dd-mm-yyyy'), 2, 3773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630000041, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 1, 2098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010727000042, to_date('27-07-2001', 'dd-mm-yyyy'), to_date('10-08-2001', 'dd-mm-yyyy'), 1, 2634, to_date('31-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060611000043, to_date('11-06-2006', 'dd-mm-yyyy'), to_date('25-06-2006', 'dd-mm-yyyy'), 5, 2581, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031028000044, to_date('28-10-2003', 'dd-mm-yyyy'), to_date('11-11-2003', 'dd-mm-yyyy'), 12, 2242, to_date('11-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000330000045, to_date('30-03-2000', 'dd-mm-yyyy'), to_date('13-04-2000', 'dd-mm-yyyy'), 1, 752, to_date('12-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050222000046, to_date('22-02-2005', 'dd-mm-yyyy'), to_date('08-03-2005', 'dd-mm-yyyy'), 11, 3902, to_date('24-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050608000047, to_date('08-06-2005', 'dd-mm-yyyy'), to_date('22-06-2005', 'dd-mm-yyyy'), 6, 4575, to_date('12-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215000048, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 3, 7089, to_date('19-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130224000049, to_date('24-02-2013', 'dd-mm-yyyy'), to_date('10-03-2013', 'dd-mm-yyyy'), 2, 9404, to_date('08-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070527000050, to_date('27-05-2007', 'dd-mm-yyyy'), to_date('10-06-2007', 'dd-mm-yyyy'), 3, 7214, to_date('04-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010822000051, to_date('22-08-2001', 'dd-mm-yyyy'), to_date('05-09-2001', 'dd-mm-yyyy'), 7, 2877, to_date('09-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080324000052, to_date('24-03-2008', 'dd-mm-yyyy'), to_date('07-04-2008', 'dd-mm-yyyy'), 1, 6359, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000527000053, to_date('27-05-2000', 'dd-mm-yyyy'), to_date('10-06-2000', 'dd-mm-yyyy'), 10, 2474, to_date('06-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120408000054, to_date('08-04-2012', 'dd-mm-yyyy'), to_date('22-04-2012', 'dd-mm-yyyy'), 9, 9642, to_date('26-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031025000055, to_date('25-10-2003', 'dd-mm-yyyy'), to_date('08-11-2003', 'dd-mm-yyyy'), 12, 2873, to_date('02-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504000056, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 4, 5610, to_date('20-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020528000057, to_date('28-05-2002', 'dd-mm-yyyy'), to_date('11-06-2002', 'dd-mm-yyyy'), 5, 4641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020816000058, to_date('16-08-2002', 'dd-mm-yyyy'), to_date('30-08-2002', 'dd-mm-yyyy'), 10, 2934, to_date('22-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001218000059, to_date('18-12-2000', 'dd-mm-yyyy'), to_date('01-01-2001', 'dd-mm-yyyy'), 10, 857, to_date('30-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081027000060, to_date('27-10-2008', 'dd-mm-yyyy'), to_date('10-11-2008', 'dd-mm-yyyy'), 5, 7117, to_date('29-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230000061, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 1, 2605, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060127000062, to_date('27-01-2006', 'dd-mm-yyyy'), to_date('10-02-2006', 'dd-mm-yyyy'), 5, 4670, to_date('28-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120501000063, to_date('01-05-2012', 'dd-mm-yyyy'), to_date('15-05-2012', 'dd-mm-yyyy'), 8, 7236, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011219000064, to_date('19-12-2001', 'dd-mm-yyyy'), to_date('02-01-2002', 'dd-mm-yyyy'), 10, 3083, to_date('25-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010824000065, to_date('24-08-2001', 'dd-mm-yyyy'), to_date('07-09-2001', 'dd-mm-yyyy'), 7, 3033, to_date('08-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091103000066, to_date('03-11-2009', 'dd-mm-yyyy'), to_date('17-11-2009', 'dd-mm-yyyy'), 9, 6562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327000067, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 9, 4911, to_date('11-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140308000068, to_date('08-03-2014', 'dd-mm-yyyy'), to_date('22-03-2014', 'dd-mm-yyyy'), 8, 9977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100421000069, to_date('21-04-2010', 'dd-mm-yyyy'), to_date('05-05-2010', 'dd-mm-yyyy'), 6, 5754, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000513000070, to_date('13-05-2000', 'dd-mm-yyyy'), to_date('27-05-2000', 'dd-mm-yyyy'), 6, 1834, to_date('17-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020325000071, to_date('25-03-2002', 'dd-mm-yyyy'), to_date('08-04-2002', 'dd-mm-yyyy'), 4, 3871, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801000072, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 6, 9355, to_date('09-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070128000073, to_date('28-01-2007', 'dd-mm-yyyy'), to_date('11-02-2007', 'dd-mm-yyyy'), 3, 6683, to_date('10-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100710000074, to_date('10-07-2010', 'dd-mm-yyyy'), to_date('24-07-2010', 'dd-mm-yyyy'), 3, 8558, to_date('21-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010112000075, to_date('12-01-2001', 'dd-mm-yyyy'), to_date('26-01-2001', 'dd-mm-yyyy'), 9, 2973, to_date('26-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421000076, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 11, 11071, to_date('26-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120126000077, to_date('26-01-2012', 'dd-mm-yyyy'), to_date('09-02-2012', 'dd-mm-yyyy'), 12, 9633, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080903000078, to_date('03-09-2008', 'dd-mm-yyyy'), to_date('17-09-2008', 'dd-mm-yyyy'), 6, 7665, to_date('16-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060701000079, to_date('01-07-2006', 'dd-mm-yyyy'), to_date('15-07-2006', 'dd-mm-yyyy'), 6, 2924, to_date('07-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025000080, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 6, 7266, to_date('13-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041026000081, to_date('26-10-2004', 'dd-mm-yyyy'), to_date('09-11-2004', 'dd-mm-yyyy'), 2, 4156, to_date('04-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020221000082, to_date('21-02-2002', 'dd-mm-yyyy'), to_date('07-03-2002', 'dd-mm-yyyy'), 3, 4375, to_date('11-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823000083, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 8, 4661, to_date('04-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070730000084, to_date('30-07-2007', 'dd-mm-yyyy'), to_date('13-08-2007', 'dd-mm-yyyy'), 2, 6077, to_date('17-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050826000085, to_date('26-08-2005', 'dd-mm-yyyy'), to_date('09-09-2005', 'dd-mm-yyyy'), 4, 4395, to_date('31-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030429000086, to_date('29-04-2003', 'dd-mm-yyyy'), to_date('13-05-2003', 'dd-mm-yyyy'), 9, 2511, to_date('12-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000616000087, to_date('16-06-2000', 'dd-mm-yyyy'), to_date('30-06-2000', 'dd-mm-yyyy'), 5, 1621, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214000088, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 7, 8447, to_date('21-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507000089, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 9, 8237, to_date('21-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100126000090, to_date('26-01-2010', 'dd-mm-yyyy'), to_date('09-02-2010', 'dd-mm-yyyy'), 3, 5724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140103000091, to_date('03-01-2014', 'dd-mm-yyyy'), to_date('17-01-2014', 'dd-mm-yyyy'), 3, 12391, to_date('05-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031029000092, to_date('29-10-2003', 'dd-mm-yyyy'), to_date('12-11-2003', 'dd-mm-yyyy'), 6, 2971, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510000093, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 10, 5426, to_date('28-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204000094, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 6, 5916, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080422000095, to_date('22-04-2008', 'dd-mm-yyyy'), to_date('06-05-2008', 'dd-mm-yyyy'), 7, 6097, to_date('12-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070302000096, to_date('02-03-2007', 'dd-mm-yyyy'), to_date('16-03-2007', 'dd-mm-yyyy'), 7, 6399, to_date('07-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101216000097, to_date('16-12-2010', 'dd-mm-yyyy'), to_date('30-12-2010', 'dd-mm-yyyy'), 7, 6524, to_date('30-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000102000098, to_date('02-01-2000', 'dd-mm-yyyy'), to_date('16-01-2000', 'dd-mm-yyyy'), 7, 1414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061214000099, to_date('14-12-2006', 'dd-mm-yyyy'), to_date('28-12-2006', 'dd-mm-yyyy'), 6, 5326, to_date('18-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214000100, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 10, 4550, to_date('19-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213000101, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 10, 9530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111011000102, to_date('11-10-2011', 'dd-mm-yyyy'), to_date('25-10-2011', 'dd-mm-yyyy'), 6, 6194, to_date('20-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101008000103, to_date('08-10-2010', 'dd-mm-yyyy'), to_date('22-10-2010', 'dd-mm-yyyy'), 2, 8068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011231000104, to_date('31-12-2001', 'dd-mm-yyyy'), to_date('14-01-2002', 'dd-mm-yyyy'), 7, 3112, to_date('19-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090311000105, to_date('11-03-2009', 'dd-mm-yyyy'), to_date('25-03-2009', 'dd-mm-yyyy'), 7, 3957, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509000106, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 7, 2824, to_date('25-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000725000107, to_date('25-07-2000', 'dd-mm-yyyy'), to_date('08-08-2000', 'dd-mm-yyyy'), 9, 1773, to_date('12-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090315000108, to_date('15-03-2009', 'dd-mm-yyyy'), to_date('29-03-2009', 'dd-mm-yyyy'), 8, 5887, to_date('25-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130825000109, to_date('25-08-2013', 'dd-mm-yyyy'), to_date('08-09-2013', 'dd-mm-yyyy'), 5, 12352, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060522000110, to_date('22-05-2006', 'dd-mm-yyyy'), to_date('05-06-2006', 'dd-mm-yyyy'), 4, 5774, to_date('24-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030601000111, to_date('01-06-2003', 'dd-mm-yyyy'), to_date('15-06-2003', 'dd-mm-yyyy'), 4, 3186, to_date('04-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613000112, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 2, 1605, to_date('18-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020601000113, to_date('01-06-2002', 'dd-mm-yyyy'), to_date('15-06-2002', 'dd-mm-yyyy'), 4, 2948, to_date('18-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100702000114, to_date('02-07-2010', 'dd-mm-yyyy'), to_date('16-07-2010', 'dd-mm-yyyy'), 11, 8840, to_date('08-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041014000115, to_date('14-10-2004', 'dd-mm-yyyy'), to_date('28-10-2004', 'dd-mm-yyyy'), 3, 2555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100629000116, to_date('29-06-2010', 'dd-mm-yyyy'), to_date('13-07-2010', 'dd-mm-yyyy'), 11, 6219, to_date('02-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071118000117, to_date('18-11-2007', 'dd-mm-yyyy'), to_date('02-12-2007', 'dd-mm-yyyy'), 1, 7313, to_date('29-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604000118, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 2, 8786, to_date('16-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050730000119, to_date('30-07-2005', 'dd-mm-yyyy'), to_date('13-08-2005', 'dd-mm-yyyy'), 6, 2901, to_date('08-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221000120, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 3, 3658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010407000121, to_date('07-04-2001', 'dd-mm-yyyy'), to_date('21-04-2001', 'dd-mm-yyyy'), 2, 3006, to_date('20-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215000122, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 5, 5110, to_date('03-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213000123, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 8, 3510, to_date('20-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910000124, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 2, 3617, to_date('27-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120718000125, to_date('18-07-2012', 'dd-mm-yyyy'), to_date('01-08-2012', 'dd-mm-yyyy'), 11, 6954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020809000126, to_date('09-08-2002', 'dd-mm-yyyy'), to_date('23-08-2002', 'dd-mm-yyyy'), 7, 2520, to_date('22-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307000127, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 6, 9777, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080527000128, to_date('27-05-2008', 'dd-mm-yyyy'), to_date('10-06-2008', 'dd-mm-yyyy'), 7, 6434, to_date('29-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070914000129, to_date('14-09-2007', 'dd-mm-yyyy'), to_date('28-09-2007', 'dd-mm-yyyy'), 4, 4391, to_date('16-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104000130, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 8, 5245, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110416000131, to_date('16-04-2011', 'dd-mm-yyyy'), to_date('30-04-2011', 'dd-mm-yyyy'), 2, 8294, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080101000132, to_date('01-01-2008', 'dd-mm-yyyy'), to_date('15-01-2008', 'dd-mm-yyyy'), 5, 5893, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040208000133, to_date('08-02-2004', 'dd-mm-yyyy'), to_date('22-02-2004', 'dd-mm-yyyy'), 4, 3095, to_date('25-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081023000134, to_date('23-10-2008', 'dd-mm-yyyy'), to_date('06-11-2008', 'dd-mm-yyyy'), 5, 8657, to_date('07-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090321000135, to_date('21-03-2009', 'dd-mm-yyyy'), to_date('04-04-2009', 'dd-mm-yyyy'), 10, 6838, to_date('24-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130906000136, to_date('06-09-2013', 'dd-mm-yyyy'), to_date('20-09-2013', 'dd-mm-yyyy'), 8, 9583, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429000137, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 2, 4045, to_date('10-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130103000138, to_date('03-01-2013', 'dd-mm-yyyy'), to_date('17-01-2013', 'dd-mm-yyyy'), 2, 9400, to_date('10-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714000139, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 10, 6189, to_date('26-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130804000140, to_date('04-08-2013', 'dd-mm-yyyy'), to_date('18-08-2013', 'dd-mm-yyyy'), 9, 9046, to_date('10-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407000141, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 12, 13418, to_date('16-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120514000142, to_date('14-05-2012', 'dd-mm-yyyy'), to_date('28-05-2012', 'dd-mm-yyyy'), 11, 9428, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326000143, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 7, 6149, to_date('05-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000410000144, to_date('10-04-2000', 'dd-mm-yyyy'), to_date('24-04-2000', 'dd-mm-yyyy'), 6, 1199, to_date('22-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021025000145, to_date('25-10-2002', 'dd-mm-yyyy'), to_date('08-11-2002', 'dd-mm-yyyy'), 7, 3031, to_date('29-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061211000146, to_date('11-12-2006', 'dd-mm-yyyy'), to_date('25-12-2006', 'dd-mm-yyyy'), 6, 5609, to_date('22-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030105000147, to_date('05-01-2003', 'dd-mm-yyyy'), to_date('19-01-2003', 'dd-mm-yyyy'), 9, 4698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100502000148, to_date('02-05-2010', 'dd-mm-yyyy'), to_date('16-05-2010', 'dd-mm-yyyy'), 11, 5960, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081213000149, to_date('13-12-2008', 'dd-mm-yyyy'), to_date('27-12-2008', 'dd-mm-yyyy'), 6, 5551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810000150, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 1, 4451, to_date('18-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030413000151, to_date('13-04-2003', 'dd-mm-yyyy'), to_date('27-04-2003', 'dd-mm-yyyy'), 5, 3436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227000152, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 1, 9146, to_date('05-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080410002296, to_date('10-04-2008', 'dd-mm-yyyy'), to_date('24-04-2008', 'dd-mm-yyyy'), 4, 7019, to_date('14-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123002297, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 7, 6223, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110304002298, to_date('04-03-2011', 'dd-mm-yyyy'), to_date('18-03-2011', 'dd-mm-yyyy'), 3, 5841, to_date('05-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080326002299, to_date('26-03-2008', 'dd-mm-yyyy'), to_date('09-04-2008', 'dd-mm-yyyy'), 9, 4894, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070616002300, to_date('16-06-2007', 'dd-mm-yyyy'), to_date('30-06-2007', 'dd-mm-yyyy'), 2, 4534, to_date('02-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619002301, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 9, 2547, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030502002302, to_date('02-05-2003', 'dd-mm-yyyy'), to_date('16-05-2003', 'dd-mm-yyyy'), 11, 3015, to_date('07-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703002303, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 9, 7747, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513002304, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 10, 7248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001128002305, to_date('28-11-2000', 'dd-mm-yyyy'), to_date('12-12-2000', 'dd-mm-yyyy'), 1, 1610, to_date('02-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070312002306, to_date('12-03-2007', 'dd-mm-yyyy'), to_date('26-03-2007', 'dd-mm-yyyy'), 2, 7035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110727002307, to_date('27-07-2011', 'dd-mm-yyyy'), to_date('10-08-2011', 'dd-mm-yyyy'), 5, 6378, to_date('30-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521002308, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 5, 4737, to_date('25-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030725002309, to_date('25-07-2003', 'dd-mm-yyyy'), to_date('08-08-2003', 'dd-mm-yyyy'), 4, 2613, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060621002310, to_date('21-06-2006', 'dd-mm-yyyy'), to_date('05-07-2006', 'dd-mm-yyyy'), 2, 5225, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100714002311, to_date('14-07-2010', 'dd-mm-yyyy'), to_date('28-07-2010', 'dd-mm-yyyy'), 11, 9421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011109002312, to_date('09-11-2001', 'dd-mm-yyyy'), to_date('23-11-2001', 'dd-mm-yyyy'), 4, 3620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020301002313, to_date('01-03-2002', 'dd-mm-yyyy'), to_date('15-03-2002', 'dd-mm-yyyy'), 2, 4107, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090729002314, to_date('29-07-2009', 'dd-mm-yyyy'), to_date('12-08-2009', 'dd-mm-yyyy'), 11, 7443, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090515002315, to_date('15-05-2009', 'dd-mm-yyyy'), to_date('29-05-2009', 'dd-mm-yyyy'), 9, 6689, to_date('01-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303002316, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 6, 7910, to_date('14-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830002317, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 10, 3791, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040824002318, to_date('24-08-2004', 'dd-mm-yyyy'), to_date('07-09-2004', 'dd-mm-yyyy'), 12, 5665, to_date('04-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030617002319, to_date('17-06-2003', 'dd-mm-yyyy'), to_date('01-07-2003', 'dd-mm-yyyy'), 12, 4604, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000917002320, to_date('17-09-2000', 'dd-mm-yyyy'), to_date('01-10-2000', 'dd-mm-yyyy'), 8, 1710, to_date('24-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020312002321, to_date('12-03-2002', 'dd-mm-yyyy'), to_date('26-03-2002', 'dd-mm-yyyy'), 9, 2254, to_date('18-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131006002322, to_date('06-10-2013', 'dd-mm-yyyy'), to_date('20-10-2013', 'dd-mm-yyyy'), 3, 9151, to_date('26-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725002323, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 12, 6576, to_date('26-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010319002324, to_date('19-03-2001', 'dd-mm-yyyy'), to_date('02-04-2001', 'dd-mm-yyyy'), 9, 2034, to_date('02-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060818002325, to_date('18-08-2006', 'dd-mm-yyyy'), to_date('01-09-2006', 'dd-mm-yyyy'), 9, 7474, to_date('01-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000127002326, to_date('27-01-2000', 'dd-mm-yyyy'), to_date('10-02-2000', 'dd-mm-yyyy'), 5, 1302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213002327, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 7, 9128, to_date('01-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000829002328, to_date('29-08-2000', 'dd-mm-yyyy'), to_date('12-09-2000', 'dd-mm-yyyy'), 5, 1913, to_date('03-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140324002329, to_date('24-03-2014', 'dd-mm-yyyy'), to_date('07-04-2014', 'dd-mm-yyyy'), 7, 8961, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070923002330, to_date('23-09-2007', 'dd-mm-yyyy'), to_date('07-10-2007', 'dd-mm-yyyy'), 1, 5562, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110002331, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 10, 6676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907002332, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 10, 4044, to_date('17-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031102002333, to_date('02-11-2003', 'dd-mm-yyyy'), to_date('16-11-2003', 'dd-mm-yyyy'), 7, 3041, to_date('21-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000916002334, to_date('16-09-2000', 'dd-mm-yyyy'), to_date('30-09-2000', 'dd-mm-yyyy'), 11, 4033, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100828002335, to_date('28-08-2010', 'dd-mm-yyyy'), to_date('11-09-2010', 'dd-mm-yyyy'), 4, 6136, to_date('06-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000314002336, to_date('14-03-2000', 'dd-mm-yyyy'), to_date('28-03-2000', 'dd-mm-yyyy'), 6, 1160, to_date('25-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120930002337, to_date('30-09-2012', 'dd-mm-yyyy'), to_date('14-10-2012', 'dd-mm-yyyy'), 7, 7146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030121002338, to_date('21-01-2003', 'dd-mm-yyyy'), to_date('04-02-2003', 'dd-mm-yyyy'), 5, 3158, to_date('23-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081023002339, to_date('23-10-2008', 'dd-mm-yyyy'), to_date('06-11-2008', 'dd-mm-yyyy'), 2, 4429, to_date('08-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081219002340, to_date('19-12-2008', 'dd-mm-yyyy'), to_date('02-01-2009', 'dd-mm-yyyy'), 8, 6186, to_date('22-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011120002341, to_date('20-11-2001', 'dd-mm-yyyy'), to_date('04-12-2001', 'dd-mm-yyyy'), 10, 3184, to_date('26-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131002002342, to_date('02-10-2013', 'dd-mm-yyyy'), to_date('16-10-2013', 'dd-mm-yyyy'), 11, 9861, to_date('03-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120002343, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 9, 4217, to_date('06-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010701002344, to_date('01-07-2001', 'dd-mm-yyyy'), to_date('15-07-2001', 'dd-mm-yyyy'), 3, 3546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821002345, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 10, 5634, to_date('22-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100101002346, to_date('01-01-2010', 'dd-mm-yyyy'), to_date('15-01-2010', 'dd-mm-yyyy'), 4, 7023, to_date('04-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627002347, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 9, 5656, to_date('16-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061117002348, to_date('17-11-2006', 'dd-mm-yyyy'), to_date('01-12-2006', 'dd-mm-yyyy'), 5, 7163, to_date('23-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509002349, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 9, 6863, to_date('15-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090417002350, to_date('17-04-2009', 'dd-mm-yyyy'), to_date('01-05-2009', 'dd-mm-yyyy'), 9, 8451, to_date('29-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000505002351, to_date('05-05-2000', 'dd-mm-yyyy'), to_date('19-05-2000', 'dd-mm-yyyy'), 11, 658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060217002352, to_date('17-02-2006', 'dd-mm-yyyy'), to_date('03-03-2006', 'dd-mm-yyyy'), 2, 3552, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010612002353, to_date('12-06-2001', 'dd-mm-yyyy'), to_date('26-06-2001', 'dd-mm-yyyy'), 3, 4428, to_date('20-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070509002354, to_date('09-05-2007', 'dd-mm-yyyy'), to_date('23-05-2007', 'dd-mm-yyyy'), 7, 7187, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080704002355, to_date('04-07-2008', 'dd-mm-yyyy'), to_date('18-07-2008', 'dd-mm-yyyy'), 8, 7919, to_date('08-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070725002356, to_date('25-07-2007', 'dd-mm-yyyy'), to_date('08-08-2007', 'dd-mm-yyyy'), 12, 3866, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090705002357, to_date('05-07-2009', 'dd-mm-yyyy'), to_date('19-07-2009', 'dd-mm-yyyy'), 11, 6702, to_date('12-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051217002358, to_date('17-12-2005', 'dd-mm-yyyy'), to_date('31-12-2005', 'dd-mm-yyyy'), 8, 5305, to_date('26-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090425002359, to_date('25-04-2009', 'dd-mm-yyyy'), to_date('09-05-2009', 'dd-mm-yyyy'), 11, 7440, to_date('05-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416002360, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 3, 2960, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919002361, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 2, 7185, to_date('09-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110708002362, to_date('08-07-2011', 'dd-mm-yyyy'), to_date('22-07-2011', 'dd-mm-yyyy'), 10, 7027, to_date('20-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929002363, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 3, 2158, to_date('06-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220002364, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 7, 8362, to_date('26-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605002365, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 8, 2788, to_date('19-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130605002366, to_date('05-06-2013', 'dd-mm-yyyy'), to_date('19-06-2013', 'dd-mm-yyyy'), 5, 8800, to_date('21-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120613002367, to_date('13-06-2012', 'dd-mm-yyyy'), to_date('27-06-2012', 'dd-mm-yyyy'), 6, 7506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090309002368, to_date('09-03-2009', 'dd-mm-yyyy'), to_date('23-03-2009', 'dd-mm-yyyy'), 12, 6232, to_date('18-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050112002369, to_date('12-01-2005', 'dd-mm-yyyy'), to_date('26-01-2005', 'dd-mm-yyyy'), 5, 2651, to_date('16-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030603002370, to_date('03-06-2003', 'dd-mm-yyyy'), to_date('17-06-2003', 'dd-mm-yyyy'), 2, 5054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008002371, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 6, 3487, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120908002372, to_date('08-09-2012', 'dd-mm-yyyy'), to_date('22-09-2012', 'dd-mm-yyyy'), 9, 7158, to_date('10-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823002373, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 8, 6388, to_date('31-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051010002374, to_date('10-10-2005', 'dd-mm-yyyy'), to_date('24-10-2005', 'dd-mm-yyyy'), 11, 3798, to_date('11-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010324002375, to_date('24-03-2001', 'dd-mm-yyyy'), to_date('07-04-2001', 'dd-mm-yyyy'), 11, 1272, to_date('07-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423002376, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 5, 5111, to_date('09-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010002377, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 4, 6770, to_date('21-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725002378, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 10, 5883, to_date('27-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602002379, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 5, 6051, to_date('17-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604002380, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 10, 6205, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110827002381, to_date('27-08-2011', 'dd-mm-yyyy'), to_date('10-09-2011', 'dd-mm-yyyy'), 8, 5185, to_date('05-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080429002382, to_date('29-04-2008', 'dd-mm-yyyy'), to_date('13-05-2008', 'dd-mm-yyyy'), 9, 3941, to_date('14-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130608002383, to_date('08-06-2013', 'dd-mm-yyyy'), to_date('22-06-2013', 'dd-mm-yyyy'), 2, 5944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130523002384, to_date('23-05-2013', 'dd-mm-yyyy'), to_date('06-06-2013', 'dd-mm-yyyy'), 8, 9433, to_date('12-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060823002385, to_date('23-08-2006', 'dd-mm-yyyy'), to_date('06-09-2006', 'dd-mm-yyyy'), 5, 5279, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061008002386, to_date('08-10-2006', 'dd-mm-yyyy'), to_date('22-10-2006', 'dd-mm-yyyy'), 11, 5015, to_date('13-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051007002387, to_date('07-10-2005', 'dd-mm-yyyy'), to_date('21-10-2005', 'dd-mm-yyyy'), 9, 3928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080228002388, to_date('28-02-2008', 'dd-mm-yyyy'), to_date('13-03-2008', 'dd-mm-yyyy'), 4, 6680, to_date('07-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110306002389, to_date('06-03-2011', 'dd-mm-yyyy'), to_date('20-03-2011', 'dd-mm-yyyy'), 5, 6937, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130306002390, to_date('06-03-2013', 'dd-mm-yyyy'), to_date('20-03-2013', 'dd-mm-yyyy'), 6, 8853, to_date('21-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120515002391, to_date('15-05-2012', 'dd-mm-yyyy'), to_date('29-05-2012', 'dd-mm-yyyy'), 8, 5734, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130608002392, to_date('08-06-2013', 'dd-mm-yyyy'), to_date('22-06-2013', 'dd-mm-yyyy'), 8, 10089, to_date('19-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001113002393, to_date('13-11-2000', 'dd-mm-yyyy'), to_date('27-11-2000', 'dd-mm-yyyy'), 2, 2588, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325002394, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 2, 3613, to_date('05-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010828002395, to_date('28-08-2001', 'dd-mm-yyyy'), to_date('11-09-2001', 'dd-mm-yyyy'), 4, 2618, to_date('31-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090307002396, to_date('07-03-2009', 'dd-mm-yyyy'), to_date('21-03-2009', 'dd-mm-yyyy'), 1, 6224, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305002397, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 2, 8460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110720002398, to_date('20-07-2011', 'dd-mm-yyyy'), to_date('03-08-2011', 'dd-mm-yyyy'), 12, 7630, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060611002399, to_date('11-06-2006', 'dd-mm-yyyy'), to_date('25-06-2006', 'dd-mm-yyyy'), 12, 6751, to_date('13-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080627002400, to_date('27-06-2008', 'dd-mm-yyyy'), to_date('11-07-2008', 'dd-mm-yyyy'), 10, 6012, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130223002401, to_date('23-02-2013', 'dd-mm-yyyy'), to_date('09-03-2013', 'dd-mm-yyyy'), 8, 9078, to_date('05-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080701002402, to_date('01-07-2008', 'dd-mm-yyyy'), to_date('15-07-2008', 'dd-mm-yyyy'), 3, 6151, to_date('02-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110808002403, to_date('08-08-2011', 'dd-mm-yyyy'), to_date('22-08-2011', 'dd-mm-yyyy'), 11, 6479, to_date('13-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051119002404, to_date('19-11-2005', 'dd-mm-yyyy'), to_date('03-12-2005', 'dd-mm-yyyy'), 10, 4811, to_date('27-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524002405, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 6, 9496, to_date('11-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217002406, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 2, 5396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001012002407, to_date('12-10-2000', 'dd-mm-yyyy'), to_date('26-10-2000', 'dd-mm-yyyy'), 6, 2266, to_date('24-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516002408, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 2, 3708, to_date('18-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100722002409, to_date('22-07-2010', 'dd-mm-yyyy'), to_date('05-08-2010', 'dd-mm-yyyy'), 11, 6095, to_date('05-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090730002410, to_date('30-07-2009', 'dd-mm-yyyy'), to_date('13-08-2009', 'dd-mm-yyyy'), 9, 8451, to_date('09-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110924002411, to_date('24-09-2011', 'dd-mm-yyyy'), to_date('08-10-2011', 'dd-mm-yyyy'), 12, 7368, to_date('12-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121206002412, to_date('06-12-2012', 'dd-mm-yyyy'), to_date('20-12-2012', 'dd-mm-yyyy'), 2, 10297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603002413, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 10, 1924, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010819002414, to_date('19-08-2001', 'dd-mm-yyyy'), to_date('02-09-2001', 'dd-mm-yyyy'), 10, 2579, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080321002415, to_date('21-03-2008', 'dd-mm-yyyy'), to_date('04-04-2008', 'dd-mm-yyyy'), 6, 7434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010611002416, to_date('11-06-2001', 'dd-mm-yyyy'), to_date('25-06-2001', 'dd-mm-yyyy'), 10, 1962, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040720002417, to_date('20-07-2004', 'dd-mm-yyyy'), to_date('03-08-2004', 'dd-mm-yyyy'), 7, 4016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060408002418, to_date('08-04-2006', 'dd-mm-yyyy'), to_date('22-04-2006', 'dd-mm-yyyy'), 7, 6771, to_date('17-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000716002419, to_date('16-07-2000', 'dd-mm-yyyy'), to_date('30-07-2000', 'dd-mm-yyyy'), 11, 2670, to_date('02-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130318002420, to_date('18-03-2013', 'dd-mm-yyyy'), to_date('01-04-2013', 'dd-mm-yyyy'), 8, 9389, to_date('23-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090801002421, to_date('01-08-2009', 'dd-mm-yyyy'), to_date('15-08-2009', 'dd-mm-yyyy'), 6, 6375, to_date('09-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827002422, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 5, 1788, to_date('09-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000809002423, to_date('09-08-2000', 'dd-mm-yyyy'), to_date('23-08-2000', 'dd-mm-yyyy'), 7, 812, to_date('17-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018002424, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 5, 3114, to_date('02-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060822002425, to_date('22-08-2006', 'dd-mm-yyyy'), to_date('05-09-2006', 'dd-mm-yyyy'), 10, 5630, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030908002426, to_date('08-09-2003', 'dd-mm-yyyy'), to_date('22-09-2003', 'dd-mm-yyyy'), 7, 4909, to_date('22-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060614002427, to_date('14-06-2006', 'dd-mm-yyyy'), to_date('28-06-2006', 'dd-mm-yyyy'), 6, 6720, to_date('28-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060911002428, to_date('11-09-2006', 'dd-mm-yyyy'), to_date('25-09-2006', 'dd-mm-yyyy'), 6, 5320, to_date('15-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000401002429, to_date('01-04-2000', 'dd-mm-yyyy'), to_date('15-04-2000', 'dd-mm-yyyy'), 2, 3049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100907002430, to_date('07-09-2010', 'dd-mm-yyyy'), to_date('21-09-2010', 'dd-mm-yyyy'), 5, 8418, to_date('10-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629002431, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 11, 4131, to_date('18-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100829002432, to_date('29-08-2010', 'dd-mm-yyyy'), to_date('12-09-2010', 'dd-mm-yyyy'), 8, 6134, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070725002433, to_date('25-07-2007', 'dd-mm-yyyy'), to_date('08-08-2007', 'dd-mm-yyyy'), 2, 5624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110212002434, to_date('12-02-2011', 'dd-mm-yyyy'), to_date('26-02-2011', 'dd-mm-yyyy'), 8, 9147, to_date('03-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090812002435, to_date('12-08-2009', 'dd-mm-yyyy'), to_date('26-08-2009', 'dd-mm-yyyy'), 3, 8688, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731002436, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 11, 6447, to_date('14-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121119002437, to_date('19-11-2012', 'dd-mm-yyyy'), to_date('03-12-2012', 'dd-mm-yyyy'), 11, 7018, to_date('07-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060620002438, to_date('20-06-2006', 'dd-mm-yyyy'), to_date('04-07-2006', 'dd-mm-yyyy'), 5, 5318, to_date('04-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022002439, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 9, 5854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110423002440, to_date('23-04-2011', 'dd-mm-yyyy'), to_date('07-05-2011', 'dd-mm-yyyy'), 3, 6102, to_date('25-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080928002441, to_date('28-09-2008', 'dd-mm-yyyy'), to_date('12-10-2008', 'dd-mm-yyyy'), 2, 6688, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050610002442, to_date('10-06-2005', 'dd-mm-yyyy'), to_date('24-06-2005', 'dd-mm-yyyy'), 7, 6727, to_date('29-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011102002443, to_date('02-11-2001', 'dd-mm-yyyy'), to_date('16-11-2001', 'dd-mm-yyyy'), 7, 3223, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071227002444, to_date('27-12-2007', 'dd-mm-yyyy'), to_date('10-01-2008', 'dd-mm-yyyy'), 9, 6102, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104002445, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 1, 10059, to_date('24-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112002446, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 10, 5517, to_date('22-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103002447, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 9, 5401, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702002448, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 2, 3279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209002449, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 4, 3060, to_date('26-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030314004745, to_date('14-03-2003', 'dd-mm-yyyy'), to_date('28-03-2003', 'dd-mm-yyyy'), 5, 4296, to_date('16-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081230004746, to_date('30-12-2008', 'dd-mm-yyyy'), to_date('13-01-2009', 'dd-mm-yyyy'), 4, 4884, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130326004747, to_date('26-03-2013', 'dd-mm-yyyy'), to_date('09-04-2013', 'dd-mm-yyyy'), 8, 8201, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021020004748, to_date('20-10-2002', 'dd-mm-yyyy'), to_date('03-11-2002', 'dd-mm-yyyy'), 1, 1999, to_date('28-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000401004749, to_date('01-04-2000', 'dd-mm-yyyy'), to_date('15-04-2000', 'dd-mm-yyyy'), 1, 2770, to_date('04-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204004750, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 7, 7411, to_date('08-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210004751, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 12, 3454, to_date('24-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603004752, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 6, 1997, to_date('16-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010113004753, to_date('13-01-2001', 'dd-mm-yyyy'), to_date('27-01-2001', 'dd-mm-yyyy'), 3, 2105, to_date('24-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070920004754, to_date('20-09-2007', 'dd-mm-yyyy'), to_date('04-10-2007', 'dd-mm-yyyy'), 6, 4465, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422004755, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 6, 3978, to_date('06-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926004756, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 3, 4461, to_date('28-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101117004757, to_date('17-11-2010', 'dd-mm-yyyy'), to_date('01-12-2010', 'dd-mm-yyyy'), 6, 7323, to_date('28-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101126004758, to_date('26-11-2010', 'dd-mm-yyyy'), to_date('10-12-2010', 'dd-mm-yyyy'), 2, 6817, to_date('12-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021019004759, to_date('19-10-2002', 'dd-mm-yyyy'), to_date('02-11-2002', 'dd-mm-yyyy'), 11, 2338, to_date('01-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126004760, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 2, 2931, to_date('15-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071005004761, to_date('05-10-2007', 'dd-mm-yyyy'), to_date('19-10-2007', 'dd-mm-yyyy'), 10, 5527, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130708004762, to_date('08-07-2013', 'dd-mm-yyyy'), to_date('22-07-2013', 'dd-mm-yyyy'), 7, 8821, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030829004763, to_date('29-08-2003', 'dd-mm-yyyy'), to_date('12-09-2003', 'dd-mm-yyyy'), 10, 3251, to_date('02-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601004764, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 11, 4993, to_date('10-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100811004765, to_date('11-08-2010', 'dd-mm-yyyy'), to_date('25-08-2010', 'dd-mm-yyyy'), 3, 6219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131018004766, to_date('18-10-2013', 'dd-mm-yyyy'), to_date('01-11-2013', 'dd-mm-yyyy'), 3, 8811, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020306004767, to_date('06-03-2002', 'dd-mm-yyyy'), to_date('20-03-2002', 'dd-mm-yyyy'), 9, 3744, to_date('11-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051108004768, to_date('08-11-2005', 'dd-mm-yyyy'), to_date('22-11-2005', 'dd-mm-yyyy'), 5, 5944, to_date('18-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110126004769, to_date('26-01-2011', 'dd-mm-yyyy'), to_date('09-02-2011', 'dd-mm-yyyy'), 11, 6807, to_date('10-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051021004770, to_date('21-10-2005', 'dd-mm-yyyy'), to_date('04-11-2005', 'dd-mm-yyyy'), 7, 3014, to_date('08-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030706004771, to_date('06-07-2003', 'dd-mm-yyyy'), to_date('20-07-2003', 'dd-mm-yyyy'), 8, 2931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040419004772, to_date('19-04-2004', 'dd-mm-yyyy'), to_date('03-05-2004', 'dd-mm-yyyy'), 10, 2353, to_date('28-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060114004773, to_date('14-01-2006', 'dd-mm-yyyy'), to_date('28-01-2006', 'dd-mm-yyyy'), 8, 6321, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010815004774, to_date('15-08-2001', 'dd-mm-yyyy'), to_date('29-08-2001', 'dd-mm-yyyy'), 6, 2080, to_date('27-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010209004775, to_date('09-02-2001', 'dd-mm-yyyy'), to_date('23-02-2001', 'dd-mm-yyyy'), 2, 4048, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060401004776, to_date('01-04-2006', 'dd-mm-yyyy'), to_date('15-04-2006', 'dd-mm-yyyy'), 3, 5524, to_date('17-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100428004777, to_date('28-04-2010', 'dd-mm-yyyy'), to_date('12-05-2010', 'dd-mm-yyyy'), 7, 7198, to_date('09-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041106004778, to_date('06-11-2004', 'dd-mm-yyyy'), to_date('20-11-2004', 'dd-mm-yyyy'), 6, 5307, to_date('17-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040317004779, to_date('17-03-2004', 'dd-mm-yyyy'), to_date('31-03-2004', 'dd-mm-yyyy'), 10, 4281, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607004780, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 9, 4161, to_date('12-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050128004781, to_date('28-01-2005', 'dd-mm-yyyy'), to_date('11-02-2005', 'dd-mm-yyyy'), 1, 4180, to_date('31-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100620004782, to_date('20-06-2010', 'dd-mm-yyyy'), to_date('04-07-2010', 'dd-mm-yyyy'), 8, 8476, to_date('29-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131010004783, to_date('10-10-2013', 'dd-mm-yyyy'), to_date('24-10-2013', 'dd-mm-yyyy'), 2, 10459, to_date('13-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070721004784, to_date('21-07-2007', 'dd-mm-yyyy'), to_date('04-08-2007', 'dd-mm-yyyy'), 6, 6775, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001104004785, to_date('04-11-2000', 'dd-mm-yyyy'), to_date('18-11-2000', 'dd-mm-yyyy'), 2, 2209, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070603004786, to_date('03-06-2007', 'dd-mm-yyyy'), to_date('17-06-2007', 'dd-mm-yyyy'), 9, 6038, to_date('22-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080526004787, to_date('26-05-2008', 'dd-mm-yyyy'), to_date('09-06-2008', 'dd-mm-yyyy'), 3, 5708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031227004788, to_date('27-12-2003', 'dd-mm-yyyy'), to_date('10-01-2004', 'dd-mm-yyyy'), 7, 2976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314004789, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 3, 5762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114004790, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 2, 2346, to_date('23-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307004791, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 1, 6011, to_date('20-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040126004792, to_date('26-01-2004', 'dd-mm-yyyy'), to_date('09-02-2004', 'dd-mm-yyyy'), 8, 3504, to_date('12-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071004004793, to_date('04-10-2007', 'dd-mm-yyyy'), to_date('18-10-2007', 'dd-mm-yyyy'), 10, 4260, to_date('16-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030830004794, to_date('30-08-2003', 'dd-mm-yyyy'), to_date('13-09-2003', 'dd-mm-yyyy'), 3, 1707, to_date('06-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912004795, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 4, 701, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104004796, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 2, 1617, to_date('08-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321004797, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 7, 8640, to_date('03-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225004798, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 2, 6208, to_date('10-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001110004799, to_date('10-11-2000', 'dd-mm-yyyy'), to_date('24-11-2000', 'dd-mm-yyyy'), 8, 2385, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030923004800, to_date('23-09-2003', 'dd-mm-yyyy'), to_date('07-10-2003', 'dd-mm-yyyy'), 10, 2451, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429004801, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 7, 3911, to_date('13-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050805004802, to_date('05-08-2005', 'dd-mm-yyyy'), to_date('19-08-2005', 'dd-mm-yyyy'), 7, 4917, to_date('21-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026004803, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 8, 7732, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070328004804, to_date('28-03-2007', 'dd-mm-yyyy'), to_date('11-04-2007', 'dd-mm-yyyy'), 2, 5036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091114004805, to_date('14-11-2009', 'dd-mm-yyyy'), to_date('28-11-2009', 'dd-mm-yyyy'), 10, 6946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120713004806, to_date('13-07-2012', 'dd-mm-yyyy'), to_date('27-07-2012', 'dd-mm-yyyy'), 12, 9708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071016004807, to_date('16-10-2007', 'dd-mm-yyyy'), to_date('30-10-2007', 'dd-mm-yyyy'), 2, 7410, to_date('01-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010420004808, to_date('20-04-2001', 'dd-mm-yyyy'), to_date('04-05-2001', 'dd-mm-yyyy'), 3, 436, to_date('23-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030407004809, to_date('07-04-2003', 'dd-mm-yyyy'), to_date('21-04-2003', 'dd-mm-yyyy'), 12, 4879, to_date('20-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021216004810, to_date('16-12-2002', 'dd-mm-yyyy'), to_date('30-12-2002', 'dd-mm-yyyy'), 5, 3668, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020315004811, to_date('15-03-2002', 'dd-mm-yyyy'), to_date('29-03-2002', 'dd-mm-yyyy'), 4, 2520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101004812, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 11, 5330, to_date('12-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111213004813, to_date('13-12-2011', 'dd-mm-yyyy'), to_date('27-12-2011', 'dd-mm-yyyy'), 3, 6697, to_date('30-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031209004814, to_date('09-12-2003', 'dd-mm-yyyy'), to_date('23-12-2003', 'dd-mm-yyyy'), 4, 4090, to_date('26-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409004815, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 8, 5594, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041214004816, to_date('14-12-2004', 'dd-mm-yyyy'), to_date('28-12-2004', 'dd-mm-yyyy'), 2, 4006, to_date('21-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010306004817, to_date('06-03-2001', 'dd-mm-yyyy'), to_date('20-03-2001', 'dd-mm-yyyy'), 7, 2384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031004818, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 10, 3397, to_date('02-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060216004819, to_date('16-02-2006', 'dd-mm-yyyy'), to_date('02-03-2006', 'dd-mm-yyyy'), 5, 3796, to_date('07-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929004820, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 1, 1571, to_date('03-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530004821, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 5, 7787, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090606004822, to_date('06-06-2009', 'dd-mm-yyyy'), to_date('20-06-2009', 'dd-mm-yyyy'), 4, 6936, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110110004823, to_date('10-01-2011', 'dd-mm-yyyy'), to_date('24-01-2011', 'dd-mm-yyyy'), 5, 4494, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040122004824, to_date('22-01-2004', 'dd-mm-yyyy'), to_date('05-02-2004', 'dd-mm-yyyy'), 4, 3814, to_date('26-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051221004825, to_date('21-12-2005', 'dd-mm-yyyy'), to_date('04-01-2006', 'dd-mm-yyyy'), 7, 3660, to_date('27-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000502004826, to_date('02-05-2000', 'dd-mm-yyyy'), to_date('16-05-2000', 'dd-mm-yyyy'), 10, 2298, to_date('03-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050721004827, to_date('21-07-2005', 'dd-mm-yyyy'), to_date('04-08-2005', 'dd-mm-yyyy'), 6, 5135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711004828, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 2, 4884, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130704004829, to_date('04-07-2013', 'dd-mm-yyyy'), to_date('18-07-2013', 'dd-mm-yyyy'), 11, 7233, to_date('23-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110408004830, to_date('08-04-2011', 'dd-mm-yyyy'), to_date('22-04-2011', 'dd-mm-yyyy'), 5, 7900, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207004831, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 10, 5155, to_date('23-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040620004832, to_date('20-06-2004', 'dd-mm-yyyy'), to_date('04-07-2004', 'dd-mm-yyyy'), 1, 3810, to_date('23-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091028004833, to_date('28-10-2009', 'dd-mm-yyyy'), to_date('11-11-2009', 'dd-mm-yyyy'), 5, 6951, to_date('11-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060429004834, to_date('29-04-2006', 'dd-mm-yyyy'), to_date('13-05-2006', 'dd-mm-yyyy'), 3, 3643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110915004835, to_date('15-09-2011', 'dd-mm-yyyy'), to_date('29-09-2011', 'dd-mm-yyyy'), 12, 8955, to_date('25-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051216004836, to_date('16-12-2005', 'dd-mm-yyyy'), to_date('30-12-2005', 'dd-mm-yyyy'), 1, 3230, to_date('25-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051014004837, to_date('14-10-2005', 'dd-mm-yyyy'), to_date('28-10-2005', 'dd-mm-yyyy'), 5, 6528, to_date('28-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100820004838, to_date('20-08-2010', 'dd-mm-yyyy'), to_date('03-09-2010', 'dd-mm-yyyy'), 8, 8143, to_date('24-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605004839, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 4, 3262, to_date('09-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819004840, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 5, 4454, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080215004841, to_date('15-02-2008', 'dd-mm-yyyy'), to_date('29-02-2008', 'dd-mm-yyyy'), 8, 6283, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050324004842, to_date('24-03-2005', 'dd-mm-yyyy'), to_date('07-04-2005', 'dd-mm-yyyy'), 6, 4363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001011004843, to_date('11-10-2000', 'dd-mm-yyyy'), to_date('25-10-2000', 'dd-mm-yyyy'), 6, 1307, to_date('21-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111123004844, to_date('23-11-2011', 'dd-mm-yyyy'), to_date('07-12-2011', 'dd-mm-yyyy'), 10, 5295, to_date('25-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130409004845, to_date('09-04-2013', 'dd-mm-yyyy'), to_date('23-04-2013', 'dd-mm-yyyy'), 6, 10637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080605004846, to_date('05-06-2008', 'dd-mm-yyyy'), to_date('19-06-2008', 'dd-mm-yyyy'), 10, 8026, to_date('11-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130825004847, to_date('25-08-2013', 'dd-mm-yyyy'), to_date('08-09-2013', 'dd-mm-yyyy'), 3, 7746, to_date('09-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101118004848, to_date('18-11-2010', 'dd-mm-yyyy'), to_date('02-12-2010', 'dd-mm-yyyy'), 6, 7009, to_date('06-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061021004849, to_date('21-10-2006', 'dd-mm-yyyy'), to_date('04-11-2006', 'dd-mm-yyyy'), 9, 6695, to_date('04-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516004850, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 2, 2805, to_date('24-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517004851, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 2, 7565, to_date('30-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204004852, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 4, 9930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309004853, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 10, 6743, to_date('24-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304004854, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 10, 5955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111116004855, to_date('16-11-2011', 'dd-mm-yyyy'), to_date('30-11-2011', 'dd-mm-yyyy'), 2, 5308, to_date('19-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070824004856, to_date('24-08-2007', 'dd-mm-yyyy'), to_date('07-09-2007', 'dd-mm-yyyy'), 8, 5935, to_date('04-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803004857, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 5, 9793, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018004858, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 10, 3023, to_date('30-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000330004859, to_date('30-03-2000', 'dd-mm-yyyy'), to_date('13-04-2000', 'dd-mm-yyyy'), 9, 3061, to_date('31-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529004860, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 6, 8785, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100212004861, to_date('12-02-2010', 'dd-mm-yyyy'), to_date('26-02-2010', 'dd-mm-yyyy'), 7, 7970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071218004862, to_date('18-12-2007', 'dd-mm-yyyy'), to_date('01-01-2008', 'dd-mm-yyyy'), 6, 4742, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130115004863, to_date('15-01-2013', 'dd-mm-yyyy'), to_date('29-01-2013', 'dd-mm-yyyy'), 2, 10644, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090925004864, to_date('25-09-2009', 'dd-mm-yyyy'), to_date('09-10-2009', 'dd-mm-yyyy'), 6, 6242, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002004865, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 11, 5902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100824004866, to_date('24-08-2010', 'dd-mm-yyyy'), to_date('07-09-2010', 'dd-mm-yyyy'), 9, 5710, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020126004867, to_date('26-01-2002', 'dd-mm-yyyy'), to_date('09-02-2002', 'dd-mm-yyyy'), 2, 3178, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507004868, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 1, 3037, to_date('15-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000326004869, to_date('26-03-2000', 'dd-mm-yyyy'), to_date('09-04-2000', 'dd-mm-yyyy'), 4, 2869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218004870, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 7, 2920, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307004871, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 1, 5929, to_date('14-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419004872, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 11, 4075, to_date('29-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061128004873, to_date('28-11-2006', 'dd-mm-yyyy'), to_date('12-12-2006', 'dd-mm-yyyy'), 2, 4922, to_date('13-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011103004874, to_date('03-11-2001', 'dd-mm-yyyy'), to_date('17-11-2001', 'dd-mm-yyyy'), 6, 4315, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100706004875, to_date('06-07-2010', 'dd-mm-yyyy'), to_date('20-07-2010', 'dd-mm-yyyy'), 9, 7734, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051103004876, to_date('03-11-2005', 'dd-mm-yyyy'), to_date('17-11-2005', 'dd-mm-yyyy'), 7, 4420, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051208004877, to_date('08-12-2005', 'dd-mm-yyyy'), to_date('22-12-2005', 'dd-mm-yyyy'), 3, 3865, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120731004878, to_date('31-07-2012', 'dd-mm-yyyy'), to_date('14-08-2012', 'dd-mm-yyyy'), 8, 5600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213004879, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 6, 2797, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101004880, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 2, 5686, to_date('02-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010214004881, to_date('14-02-2001', 'dd-mm-yyyy'), to_date('28-02-2001', 'dd-mm-yyyy'), 11, 2542, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130327004882, to_date('27-03-2013', 'dd-mm-yyyy'), to_date('10-04-2013', 'dd-mm-yyyy'), 11, 8738, to_date('11-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090210004883, to_date('10-02-2009', 'dd-mm-yyyy'), to_date('24-02-2009', 'dd-mm-yyyy'), 4, 8638, to_date('01-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021219004884, to_date('19-12-2002', 'dd-mm-yyyy'), to_date('02-01-2003', 'dd-mm-yyyy'), 2, 2862, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003004885, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 6, 2897, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212004886, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 11, 3544, to_date('03-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080105004887, to_date('05-01-2008', 'dd-mm-yyyy'), to_date('19-01-2008', 'dd-mm-yyyy'), 2, 6338, to_date('08-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000424004888, to_date('24-04-2000', 'dd-mm-yyyy'), to_date('08-05-2000', 'dd-mm-yyyy'), 7, 1600, to_date('26-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110624004889, to_date('24-06-2011', 'dd-mm-yyyy'), to_date('08-07-2011', 'dd-mm-yyyy'), 7, 6341, to_date('08-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100406004890, to_date('06-04-2010', 'dd-mm-yyyy'), to_date('20-04-2010', 'dd-mm-yyyy'), 2, 6483, to_date('25-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921004891, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 2, 1911, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080316004892, to_date('16-03-2008', 'dd-mm-yyyy'), to_date('30-03-2008', 'dd-mm-yyyy'), 8, 5447, to_date('30-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090213004893, to_date('13-02-2009', 'dd-mm-yyyy'), to_date('27-02-2009', 'dd-mm-yyyy'), 7, 5295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010730004894, to_date('30-07-2001', 'dd-mm-yyyy'), to_date('13-08-2001', 'dd-mm-yyyy'), 4, 3546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323004895, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 3, 9443, to_date('24-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426004896, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 5, 798, to_date('29-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021004897, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 7, 2678, to_date('22-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000624004898, to_date('24-06-2000', 'dd-mm-yyyy'), to_date('08-07-2000', 'dd-mm-yyyy'), 2, 2864, to_date('05-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091008007040, to_date('08-10-2009', 'dd-mm-yyyy'), to_date('22-10-2009', 'dd-mm-yyyy'), 8, 6426, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010701007041, to_date('01-07-2001', 'dd-mm-yyyy'), to_date('15-07-2001', 'dd-mm-yyyy'), 8, 1267, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101128007042, to_date('28-11-2010', 'dd-mm-yyyy'), to_date('12-12-2010', 'dd-mm-yyyy'), 1, 6373, to_date('30-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040212007043, to_date('12-02-2004', 'dd-mm-yyyy'), to_date('26-02-2004', 'dd-mm-yyyy'), 5, 3679, to_date('14-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120709007044, to_date('09-07-2012', 'dd-mm-yyyy'), to_date('23-07-2012', 'dd-mm-yyyy'), 6, 8221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070822007045, to_date('22-08-2007', 'dd-mm-yyyy'), to_date('05-09-2007', 'dd-mm-yyyy'), 10, 4716, to_date('07-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702007046, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 11, 1857, to_date('16-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821007047, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 8, 7487, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071226007048, to_date('26-12-2007', 'dd-mm-yyyy'), to_date('09-01-2008', 'dd-mm-yyyy'), 12, 4792, to_date('01-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051017007049, to_date('17-10-2005', 'dd-mm-yyyy'), to_date('31-10-2005', 'dd-mm-yyyy'), 5, 3841, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903007050, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 3, 8200, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001023007051, to_date('23-10-2000', 'dd-mm-yyyy'), to_date('06-11-2000', 'dd-mm-yyyy'), 4, 3203, to_date('09-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321007052, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 5, 8273, to_date('29-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120819007053, to_date('19-08-2012', 'dd-mm-yyyy'), to_date('02-09-2012', 'dd-mm-yyyy'), 1, 6937, to_date('03-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010412007054, to_date('12-04-2001', 'dd-mm-yyyy'), to_date('26-04-2001', 'dd-mm-yyyy'), 12, 1070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110302007055, to_date('02-03-2011', 'dd-mm-yyyy'), to_date('16-03-2011', 'dd-mm-yyyy'), 9, 8382, to_date('06-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031116007056, to_date('16-11-2003', 'dd-mm-yyyy'), to_date('30-11-2003', 'dd-mm-yyyy'), 6, 2743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060604007057, to_date('04-06-2006', 'dd-mm-yyyy'), to_date('18-06-2006', 'dd-mm-yyyy'), 2, 3808, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100728007058, to_date('28-07-2010', 'dd-mm-yyyy'), to_date('11-08-2010', 'dd-mm-yyyy'), 5, 7122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090118007059, to_date('18-01-2009', 'dd-mm-yyyy'), to_date('01-02-2009', 'dd-mm-yyyy'), 6, 5517, to_date('02-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011123007060, to_date('23-11-2001', 'dd-mm-yyyy'), to_date('07-12-2001', 'dd-mm-yyyy'), 2, 1772, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011021007061, to_date('21-10-2001', 'dd-mm-yyyy'), to_date('04-11-2001', 'dd-mm-yyyy'), 7, 2011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202007062, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 9, 5338, to_date('09-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020309007063, to_date('09-03-2002', 'dd-mm-yyyy'), to_date('23-03-2002', 'dd-mm-yyyy'), 3, 2965, to_date('12-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505007064, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 5, 4794, to_date('14-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110301007065, to_date('01-03-2011', 'dd-mm-yyyy'), to_date('15-03-2011', 'dd-mm-yyyy'), 11, 7272, to_date('07-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000705007066, to_date('05-07-2000', 'dd-mm-yyyy'), to_date('19-07-2000', 'dd-mm-yyyy'), 4, 2265, to_date('21-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010109007067, to_date('09-01-2001', 'dd-mm-yyyy'), to_date('23-01-2001', 'dd-mm-yyyy'), 9, 2400, to_date('27-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110406007068, to_date('06-04-2011', 'dd-mm-yyyy'), to_date('20-04-2011', 'dd-mm-yyyy'), 8, 7811, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119007069, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 7, 1053, to_date('28-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010820007070, to_date('20-08-2001', 'dd-mm-yyyy'), to_date('03-09-2001', 'dd-mm-yyyy'), 11, 1310, to_date('02-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030712007071, to_date('12-07-2003', 'dd-mm-yyyy'), to_date('26-07-2003', 'dd-mm-yyyy'), 3, 2862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002007072, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 2, 3957, to_date('13-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131205007073, to_date('05-12-2013', 'dd-mm-yyyy'), to_date('19-12-2013', 'dd-mm-yyyy'), 8, 7574, to_date('19-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121230007074, to_date('30-12-2012', 'dd-mm-yyyy'), to_date('13-01-2013', 'dd-mm-yyyy'), 7, 7646, to_date('11-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030325007075, to_date('25-03-2003', 'dd-mm-yyyy'), to_date('08-04-2003', 'dd-mm-yyyy'), 6, 1444, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021007076, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 11, 1790, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823007077, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 5, 3151, to_date('02-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612007078, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 4, 7787, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000604007079, to_date('04-06-2000', 'dd-mm-yyyy'), to_date('18-06-2000', 'dd-mm-yyyy'), 2, 1869, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603007080, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 12, 9382, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040721007081, to_date('21-07-2004', 'dd-mm-yyyy'), to_date('04-08-2004', 'dd-mm-yyyy'), 6, 3440, to_date('25-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131007082, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 5, 5951, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070417007083, to_date('17-04-2007', 'dd-mm-yyyy'), to_date('01-05-2007', 'dd-mm-yyyy'), 11, 6332, to_date('06-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050720007084, to_date('20-07-2005', 'dd-mm-yyyy'), to_date('03-08-2005', 'dd-mm-yyyy'), 9, 4341, to_date('29-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225007085, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 4, 1076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081110007086, to_date('10-11-2008', 'dd-mm-yyyy'), to_date('24-11-2008', 'dd-mm-yyyy'), 8, 4911, to_date('24-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120628007087, to_date('28-06-2012', 'dd-mm-yyyy'), to_date('12-07-2012', 'dd-mm-yyyy'), 10, 8233, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090228007088, to_date('28-02-2009', 'dd-mm-yyyy'), to_date('14-03-2009', 'dd-mm-yyyy'), 3, 6461, to_date('03-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121224007089, to_date('24-12-2012', 'dd-mm-yyyy'), to_date('07-01-2013', 'dd-mm-yyyy'), 4, 9497, to_date('04-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060726007090, to_date('26-07-2006', 'dd-mm-yyyy'), to_date('09-08-2006', 'dd-mm-yyyy'), 10, 4909, to_date('09-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051108007091, to_date('08-11-2005', 'dd-mm-yyyy'), to_date('22-11-2005', 'dd-mm-yyyy'), 12, 4419, to_date('19-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010903007092, to_date('03-09-2001', 'dd-mm-yyyy'), to_date('17-09-2001', 'dd-mm-yyyy'), 10, 1962, to_date('11-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000705007093, to_date('05-07-2000', 'dd-mm-yyyy'), to_date('19-07-2000', 'dd-mm-yyyy'), 3, 1869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100920007094, to_date('20-09-2010', 'dd-mm-yyyy'), to_date('04-10-2010', 'dd-mm-yyyy'), 12, 8506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100606007095, to_date('06-06-2010', 'dd-mm-yyyy'), to_date('20-06-2010', 'dd-mm-yyyy'), 2, 7283, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130815007096, to_date('15-08-2013', 'dd-mm-yyyy'), to_date('29-08-2013', 'dd-mm-yyyy'), 3, 7671, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021019007097, to_date('19-10-2002', 'dd-mm-yyyy'), to_date('02-11-2002', 'dd-mm-yyyy'), 4, 3469, to_date('03-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100128007098, to_date('28-01-2010', 'dd-mm-yyyy'), to_date('11-02-2010', 'dd-mm-yyyy'), 9, 7704, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020525007099, to_date('25-05-2002', 'dd-mm-yyyy'), to_date('08-06-2002', 'dd-mm-yyyy'), 9, 3740, to_date('07-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090804007100, to_date('04-08-2009', 'dd-mm-yyyy'), to_date('18-08-2009', 'dd-mm-yyyy'), 10, 5242, to_date('14-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011107007101, to_date('07-11-2001', 'dd-mm-yyyy'), to_date('21-11-2001', 'dd-mm-yyyy'), 5, 3312, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000710007102, to_date('10-07-2000', 'dd-mm-yyyy'), to_date('24-07-2000', 'dd-mm-yyyy'), 1, 1999, to_date('30-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070402007103, to_date('02-04-2007', 'dd-mm-yyyy'), to_date('16-04-2007', 'dd-mm-yyyy'), 3, 5445, to_date('06-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070522007104, to_date('22-05-2007', 'dd-mm-yyyy'), to_date('05-06-2007', 'dd-mm-yyyy'), 10, 4541, to_date('24-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040720007105, to_date('20-07-2004', 'dd-mm-yyyy'), to_date('03-08-2004', 'dd-mm-yyyy'), 11, 5592, to_date('24-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323007106, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 5, 6826, to_date('24-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040724007107, to_date('24-07-2004', 'dd-mm-yyyy'), to_date('07-08-2004', 'dd-mm-yyyy'), 7, 5033, to_date('13-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140122007108, to_date('22-01-2014', 'dd-mm-yyyy'), to_date('05-02-2014', 'dd-mm-yyyy'), 5, 7265, to_date('03-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080225007109, to_date('25-02-2008', 'dd-mm-yyyy'), to_date('10-03-2008', 'dd-mm-yyyy'), 11, 6274, to_date('11-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815007110, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 2, 2666, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050305007111, to_date('05-03-2005', 'dd-mm-yyyy'), to_date('19-03-2005', 'dd-mm-yyyy'), 5, 3824, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131202007112, to_date('02-12-2013', 'dd-mm-yyyy'), to_date('16-12-2013', 'dd-mm-yyyy'), 10, 8565, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212007113, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 4, 2018, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080322007114, to_date('22-03-2008', 'dd-mm-yyyy'), to_date('05-04-2008', 'dd-mm-yyyy'), 12, 5590, to_date('26-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710007115, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 2, 4649, to_date('28-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509007116, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 3, 6960, to_date('11-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801007117, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 2, 10000, to_date('06-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090920007118, to_date('20-09-2009', 'dd-mm-yyyy'), to_date('04-10-2009', 'dd-mm-yyyy'), 2, 4943, to_date('26-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120404007119, to_date('04-04-2012', 'dd-mm-yyyy'), to_date('18-04-2012', 'dd-mm-yyyy'), 10, 7434, to_date('07-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210007120, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 6, 7318, to_date('27-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714007121, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 6, 6312, to_date('23-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130314007122, to_date('14-03-2013', 'dd-mm-yyyy'), to_date('28-03-2013', 'dd-mm-yyyy'), 11, 8529, to_date('23-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517007123, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 4, 9217, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031018007124, to_date('18-10-2003', 'dd-mm-yyyy'), to_date('01-11-2003', 'dd-mm-yyyy'), 3, 2523, to_date('04-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010816007125, to_date('16-08-2001', 'dd-mm-yyyy'), to_date('30-08-2001', 'dd-mm-yyyy'), 6, 2683, to_date('28-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915007126, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 5, 2979, to_date('02-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125007127, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 8, 7609, to_date('31-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050512007128, to_date('12-05-2005', 'dd-mm-yyyy'), to_date('26-05-2005', 'dd-mm-yyyy'), 4, 5384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010416007129, to_date('16-04-2001', 'dd-mm-yyyy'), to_date('30-04-2001', 'dd-mm-yyyy'), 2, 2437, to_date('18-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070828007130, to_date('28-08-2007', 'dd-mm-yyyy'), to_date('11-09-2007', 'dd-mm-yyyy'), 6, 5082, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060224007131, to_date('24-02-2006', 'dd-mm-yyyy'), to_date('10-03-2006', 'dd-mm-yyyy'), 12, 5676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121128007132, to_date('28-11-2012', 'dd-mm-yyyy'), to_date('12-12-2012', 'dd-mm-yyyy'), 9, 8745, to_date('03-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010518007133, to_date('18-05-2001', 'dd-mm-yyyy'), to_date('01-06-2001', 'dd-mm-yyyy'), 5, 1488, to_date('05-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071229007134, to_date('29-12-2007', 'dd-mm-yyyy'), to_date('12-01-2008', 'dd-mm-yyyy'), 7, 4917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529007135, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 12, 6267, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110606007136, to_date('06-06-2011', 'dd-mm-yyyy'), to_date('20-06-2011', 'dd-mm-yyyy'), 10, 5212, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080312007137, to_date('12-03-2008', 'dd-mm-yyyy'), to_date('26-03-2008', 'dd-mm-yyyy'), 3, 5894, to_date('16-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100426007138, to_date('26-04-2010', 'dd-mm-yyyy'), to_date('10-05-2010', 'dd-mm-yyyy'), 2, 4785, to_date('02-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121110007139, to_date('10-11-2012', 'dd-mm-yyyy'), to_date('24-11-2012', 'dd-mm-yyyy'), 12, 10758, to_date('26-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050418007140, to_date('18-04-2005', 'dd-mm-yyyy'), to_date('02-05-2005', 'dd-mm-yyyy'), 9, 6190, to_date('04-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070117007141, to_date('17-01-2007', 'dd-mm-yyyy'), to_date('31-01-2007', 'dd-mm-yyyy'), 10, 4358, to_date('06-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041016007142, to_date('16-10-2004', 'dd-mm-yyyy'), to_date('30-10-2004', 'dd-mm-yyyy'), 9, 4295, to_date('29-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130816007143, to_date('16-08-2013', 'dd-mm-yyyy'), to_date('30-08-2013', 'dd-mm-yyyy'), 3, 10374, to_date('25-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010701007144, to_date('01-07-2001', 'dd-mm-yyyy'), to_date('15-07-2001', 'dd-mm-yyyy'), 1, 1951, to_date('10-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120506007145, to_date('06-05-2012', 'dd-mm-yyyy'), to_date('20-05-2012', 'dd-mm-yyyy'), 8, 7971, to_date('08-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000318007146, to_date('18-03-2000', 'dd-mm-yyyy'), to_date('01-04-2000', 'dd-mm-yyyy'), 9, 3038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081120007147, to_date('20-11-2008', 'dd-mm-yyyy'), to_date('04-12-2008', 'dd-mm-yyyy'), 6, 5139, to_date('07-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110324007148, to_date('24-03-2011', 'dd-mm-yyyy'), to_date('07-04-2011', 'dd-mm-yyyy'), 8, 7044, to_date('09-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080918007149, to_date('18-09-2008', 'dd-mm-yyyy'), to_date('02-10-2008', 'dd-mm-yyyy'), 4, 6877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040809007150, to_date('09-08-2004', 'dd-mm-yyyy'), to_date('23-08-2004', 'dd-mm-yyyy'), 6, 3255, to_date('28-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051202007151, to_date('02-12-2005', 'dd-mm-yyyy'), to_date('16-12-2005', 'dd-mm-yyyy'), 3, 3548, to_date('22-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000208007152, to_date('08-02-2000', 'dd-mm-yyyy'), to_date('22-02-2000', 'dd-mm-yyyy'), 7, 2652, to_date('09-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061205007153, to_date('05-12-2006', 'dd-mm-yyyy'), to_date('19-12-2006', 'dd-mm-yyyy'), 8, 6691, to_date('07-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061228007154, to_date('28-12-2006', 'dd-mm-yyyy'), to_date('11-01-2007', 'dd-mm-yyyy'), 3, 6152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061205007155, to_date('05-12-2006', 'dd-mm-yyyy'), to_date('19-12-2006', 'dd-mm-yyyy'), 6, 7047, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040618007156, to_date('18-06-2004', 'dd-mm-yyyy'), to_date('02-07-2004', 'dd-mm-yyyy'), 6, 2460, to_date('22-06-2004', 'dd-mm-yyyy'));
commit;
prompt 7000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060622007157, to_date('22-06-2006', 'dd-mm-yyyy'), to_date('06-07-2006', 'dd-mm-yyyy'), 6, 4861, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000303007158, to_date('03-03-2000', 'dd-mm-yyyy'), to_date('17-03-2000', 'dd-mm-yyyy'), 5, 1392, to_date('13-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507007159, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 7, 2132, to_date('23-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090509007160, to_date('09-05-2009', 'dd-mm-yyyy'), to_date('23-05-2009', 'dd-mm-yyyy'), 9, 6991, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071130007161, to_date('30-11-2007', 'dd-mm-yyyy'), to_date('14-12-2007', 'dd-mm-yyyy'), 8, 4264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071023007162, to_date('23-10-2007', 'dd-mm-yyyy'), to_date('06-11-2007', 'dd-mm-yyyy'), 8, 5440, to_date('07-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507007163, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 8, 7019, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010313007164, to_date('13-03-2001', 'dd-mm-yyyy'), to_date('27-03-2001', 'dd-mm-yyyy'), 9, 1485, to_date('20-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091210007165, to_date('10-12-2009', 'dd-mm-yyyy'), to_date('24-12-2009', 'dd-mm-yyyy'), 5, 5847, to_date('12-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110708007166, to_date('08-07-2011', 'dd-mm-yyyy'), to_date('22-07-2011', 'dd-mm-yyyy'), 12, 8800, to_date('11-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723007167, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 6, 8142, to_date('30-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070526007168, to_date('26-05-2007', 'dd-mm-yyyy'), to_date('09-06-2007', 'dd-mm-yyyy'), 12, 5182, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110507007169, to_date('07-05-2011', 'dd-mm-yyyy'), to_date('21-05-2011', 'dd-mm-yyyy'), 10, 9342, to_date('26-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130101007170, to_date('01-01-2013', 'dd-mm-yyyy'), to_date('15-01-2013', 'dd-mm-yyyy'), 6, 9491, to_date('17-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010810007171, to_date('10-08-2001', 'dd-mm-yyyy'), to_date('24-08-2001', 'dd-mm-yyyy'), 6, 2242, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020304007172, to_date('04-03-2002', 'dd-mm-yyyy'), to_date('18-03-2002', 'dd-mm-yyyy'), 6, 4027, to_date('14-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121225007173, to_date('25-12-2012', 'dd-mm-yyyy'), to_date('08-01-2013', 'dd-mm-yyyy'), 1, 5713, to_date('02-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926007174, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 11, 8426, to_date('28-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011030007175, to_date('30-10-2001', 'dd-mm-yyyy'), to_date('13-11-2001', 'dd-mm-yyyy'), 10, 4059, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020614007176, to_date('14-06-2002', 'dd-mm-yyyy'), to_date('28-06-2002', 'dd-mm-yyyy'), 6, 1764, to_date('01-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030629007177, to_date('29-06-2003', 'dd-mm-yyyy'), to_date('13-07-2003', 'dd-mm-yyyy'), 2, 4514, to_date('18-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513007178, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 2, 4332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130413007179, to_date('13-04-2013', 'dd-mm-yyyy'), to_date('27-04-2013', 'dd-mm-yyyy'), 7, 11020, to_date('25-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020724007180, to_date('24-07-2002', 'dd-mm-yyyy'), to_date('07-08-2002', 'dd-mm-yyyy'), 8, 2150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040725007181, to_date('25-07-2004', 'dd-mm-yyyy'), to_date('08-08-2004', 'dd-mm-yyyy'), 9, 4683, to_date('13-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130113007182, to_date('13-01-2013', 'dd-mm-yyyy'), to_date('27-01-2013', 'dd-mm-yyyy'), 3, 7973, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130104007183, to_date('04-01-2013', 'dd-mm-yyyy'), to_date('18-01-2013', 'dd-mm-yyyy'), 11, 8188, to_date('22-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201007184, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 8, 3640, to_date('09-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140302007185, to_date('02-03-2014', 'dd-mm-yyyy'), to_date('16-03-2014', 'dd-mm-yyyy'), 5, 11413, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806007186, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 8, 2959, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080222007187, to_date('22-02-2008', 'dd-mm-yyyy'), to_date('07-03-2008', 'dd-mm-yyyy'), 2, 4803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001107007188, to_date('07-11-2000', 'dd-mm-yyyy'), to_date('21-11-2000', 'dd-mm-yyyy'), 7, 1829, to_date('08-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020712007189, to_date('12-07-2002', 'dd-mm-yyyy'), to_date('26-07-2002', 'dd-mm-yyyy'), 7, 1839, to_date('14-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051204007190, to_date('04-12-2005', 'dd-mm-yyyy'), to_date('18-12-2005', 'dd-mm-yyyy'), 10, 5211, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090220007191, to_date('20-02-2009', 'dd-mm-yyyy'), to_date('06-03-2009', 'dd-mm-yyyy'), 3, 9076, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050718007192, to_date('18-07-2005', 'dd-mm-yyyy'), to_date('01-08-2005', 'dd-mm-yyyy'), 10, 5097, to_date('26-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020421007193, to_date('21-04-2002', 'dd-mm-yyyy'), to_date('05-05-2002', 'dd-mm-yyyy'), 3, 4289, to_date('24-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215000153, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 12, 7453, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130906000154, to_date('06-09-2013', 'dd-mm-yyyy'), to_date('20-09-2013', 'dd-mm-yyyy'), 3, 9299, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100329000155, to_date('29-03-2010', 'dd-mm-yyyy'), to_date('12-04-2010', 'dd-mm-yyyy'), 3, 6406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030619000156, to_date('19-06-2003', 'dd-mm-yyyy'), to_date('03-07-2003', 'dd-mm-yyyy'), 9, 3736, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071204000157, to_date('04-12-2007', 'dd-mm-yyyy'), to_date('18-12-2007', 'dd-mm-yyyy'), 1, 6313, to_date('13-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000909000158, to_date('09-09-2000', 'dd-mm-yyyy'), to_date('23-09-2000', 'dd-mm-yyyy'), 1, 2363, to_date('14-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040105000159, to_date('05-01-2004', 'dd-mm-yyyy'), to_date('19-01-2004', 'dd-mm-yyyy'), 4, 3842, to_date('09-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031014000160, to_date('14-10-2003', 'dd-mm-yyyy'), to_date('28-10-2003', 'dd-mm-yyyy'), 8, 2707, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010222000161, to_date('22-02-2001', 'dd-mm-yyyy'), to_date('08-03-2001', 'dd-mm-yyyy'), 8, 2140, to_date('08-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913000162, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 6, 2819, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101122000163, to_date('22-11-2010', 'dd-mm-yyyy'), to_date('06-12-2010', 'dd-mm-yyyy'), 7, 6619, to_date('08-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000719000164, to_date('19-07-2000', 'dd-mm-yyyy'), to_date('02-08-2000', 'dd-mm-yyyy'), 1, 376, to_date('22-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227000165, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 4, 3063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050725000166, to_date('25-07-2005', 'dd-mm-yyyy'), to_date('08-08-2005', 'dd-mm-yyyy'), 1, 4484, to_date('08-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140224000167, to_date('24-02-2014', 'dd-mm-yyyy'), to_date('10-03-2014', 'dd-mm-yyyy'), 8, 6759, to_date('12-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060222000168, to_date('22-02-2006', 'dd-mm-yyyy'), to_date('08-03-2006', 'dd-mm-yyyy'), 6, 4237, to_date('24-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021113000169, to_date('13-11-2002', 'dd-mm-yyyy'), to_date('27-11-2002', 'dd-mm-yyyy'), 4, 3124, to_date('29-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110405000170, to_date('05-04-2011', 'dd-mm-yyyy'), to_date('19-04-2011', 'dd-mm-yyyy'), 6, 6449, to_date('17-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101013000171, to_date('13-10-2010', 'dd-mm-yyyy'), to_date('27-10-2010', 'dd-mm-yyyy'), 8, 8757, to_date('29-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121000172, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 4, 7240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060809000173, to_date('09-08-2006', 'dd-mm-yyyy'), to_date('23-08-2006', 'dd-mm-yyyy'), 4, 6241, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000327000174, to_date('27-03-2000', 'dd-mm-yyyy'), to_date('10-04-2000', 'dd-mm-yyyy'), 9, 1694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023000175, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 8, 1972, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202000176, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 8, 8442, to_date('08-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071019000177, to_date('19-10-2007', 'dd-mm-yyyy'), to_date('02-11-2007', 'dd-mm-yyyy'), 7, 5651, to_date('21-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110124000178, to_date('24-01-2011', 'dd-mm-yyyy'), to_date('07-02-2011', 'dd-mm-yyyy'), 4, 10471, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423000179, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 8, 8098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100401000180, to_date('01-04-2010', 'dd-mm-yyyy'), to_date('15-04-2010', 'dd-mm-yyyy'), 6, 7329, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021118000181, to_date('18-11-2002', 'dd-mm-yyyy'), to_date('02-12-2002', 'dd-mm-yyyy'), 5, 2249, to_date('20-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080215000182, to_date('15-02-2008', 'dd-mm-yyyy'), to_date('29-02-2008', 'dd-mm-yyyy'), 3, 5982, to_date('01-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021116000183, to_date('16-11-2002', 'dd-mm-yyyy'), to_date('30-11-2002', 'dd-mm-yyyy'), 2, 1033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040507000184, to_date('07-05-2004', 'dd-mm-yyyy'), to_date('21-05-2004', 'dd-mm-yyyy'), 5, 4189, to_date('16-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000514000185, to_date('14-05-2000', 'dd-mm-yyyy'), to_date('28-05-2000', 'dd-mm-yyyy'), 11, 3658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714000186, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 5, 4297, to_date('20-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020405000187, to_date('05-04-2002', 'dd-mm-yyyy'), to_date('19-04-2002', 'dd-mm-yyyy'), 6, 2142, to_date('09-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060127000188, to_date('27-01-2006', 'dd-mm-yyyy'), to_date('10-02-2006', 'dd-mm-yyyy'), 10, 5776, to_date('08-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131122000189, to_date('22-11-2013', 'dd-mm-yyyy'), to_date('06-12-2013', 'dd-mm-yyyy'), 3, 9613, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808000190, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 9, 3980, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030119000191, to_date('19-01-2003', 'dd-mm-yyyy'), to_date('02-02-2003', 'dd-mm-yyyy'), 2, 3041, to_date('27-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110819000192, to_date('19-08-2011', 'dd-mm-yyyy'), to_date('02-09-2011', 'dd-mm-yyyy'), 4, 7356, to_date('26-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110630000193, to_date('30-06-2011', 'dd-mm-yyyy'), to_date('14-07-2011', 'dd-mm-yyyy'), 8, 6221, to_date('04-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050730000194, to_date('30-07-2005', 'dd-mm-yyyy'), to_date('13-08-2005', 'dd-mm-yyyy'), 2, 5471, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050414000195, to_date('14-04-2005', 'dd-mm-yyyy'), to_date('28-04-2005', 'dd-mm-yyyy'), 5, 4002, to_date('02-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080910000196, to_date('10-09-2008', 'dd-mm-yyyy'), to_date('24-09-2008', 'dd-mm-yyyy'), 11, 6723, to_date('24-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016000197, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 5, 2280, to_date('24-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090122000198, to_date('22-01-2009', 'dd-mm-yyyy'), to_date('05-02-2009', 'dd-mm-yyyy'), 5, 8114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041118000199, to_date('18-11-2004', 'dd-mm-yyyy'), to_date('02-12-2004', 'dd-mm-yyyy'), 9, 3262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011000200, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 2, 2834, to_date('15-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001022000201, to_date('22-10-2000', 'dd-mm-yyyy'), to_date('05-11-2000', 'dd-mm-yyyy'), 3, 1358, to_date('31-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030107000202, to_date('07-01-2003', 'dd-mm-yyyy'), to_date('21-01-2003', 'dd-mm-yyyy'), 7, 3109, to_date('19-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050812000203, to_date('12-08-2005', 'dd-mm-yyyy'), to_date('26-08-2005', 'dd-mm-yyyy'), 2, 5360, to_date('29-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020810000204, to_date('10-08-2002', 'dd-mm-yyyy'), to_date('24-08-2002', 'dd-mm-yyyy'), 6, 3767, to_date('21-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000919000205, to_date('19-09-2000', 'dd-mm-yyyy'), to_date('03-10-2000', 'dd-mm-yyyy'), 4, 3654, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080403000206, to_date('03-04-2008', 'dd-mm-yyyy'), to_date('17-04-2008', 'dd-mm-yyyy'), 7, 5119, to_date('15-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121000207, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 2, 6810, to_date('06-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010709000208, to_date('09-07-2001', 'dd-mm-yyyy'), to_date('23-07-2001', 'dd-mm-yyyy'), 2, 1180, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070919000209, to_date('19-09-2007', 'dd-mm-yyyy'), to_date('03-10-2007', 'dd-mm-yyyy'), 8, 3031, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130420000210, to_date('20-04-2013', 'dd-mm-yyyy'), to_date('04-05-2013', 'dd-mm-yyyy'), 9, 10911, to_date('08-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080225000211, to_date('25-02-2008', 'dd-mm-yyyy'), to_date('10-03-2008', 'dd-mm-yyyy'), 8, 7497, to_date('05-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070603000212, to_date('03-06-2007', 'dd-mm-yyyy'), to_date('17-06-2007', 'dd-mm-yyyy'), 12, 5904, to_date('16-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090131000213, to_date('31-01-2009', 'dd-mm-yyyy'), to_date('14-02-2009', 'dd-mm-yyyy'), 4, 6919, to_date('05-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050707000214, to_date('07-07-2005', 'dd-mm-yyyy'), to_date('21-07-2005', 'dd-mm-yyyy'), 3, 5453, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060212000215, to_date('12-02-2006', 'dd-mm-yyyy'), to_date('26-02-2006', 'dd-mm-yyyy'), 8, 4999, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020617000216, to_date('17-06-2002', 'dd-mm-yyyy'), to_date('01-07-2002', 'dd-mm-yyyy'), 2, 2465, to_date('25-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120716000217, to_date('16-07-2012', 'dd-mm-yyyy'), to_date('30-07-2012', 'dd-mm-yyyy'), 12, 5672, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090630000218, to_date('30-06-2009', 'dd-mm-yyyy'), to_date('14-07-2009', 'dd-mm-yyyy'), 8, 3967, to_date('04-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903000219, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 4, 5147, to_date('08-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010820000220, to_date('20-08-2001', 'dd-mm-yyyy'), to_date('03-09-2001', 'dd-mm-yyyy'), 9, 3557, to_date('31-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091127000221, to_date('27-11-2009', 'dd-mm-yyyy'), to_date('11-12-2009', 'dd-mm-yyyy'), 2, 5358, to_date('06-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041017000222, to_date('17-10-2004', 'dd-mm-yyyy'), to_date('31-10-2004', 'dd-mm-yyyy'), 5, 1914, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018000223, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 2, 4317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331000224, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 6, 6602, to_date('13-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130425000225, to_date('25-04-2013', 'dd-mm-yyyy'), to_date('09-05-2013', 'dd-mm-yyyy'), 10, 11535, to_date('06-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010120000226, to_date('20-01-2001', 'dd-mm-yyyy'), to_date('03-02-2001', 'dd-mm-yyyy'), 2, 4031, to_date('30-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131022000227, to_date('22-10-2013', 'dd-mm-yyyy'), to_date('05-11-2013', 'dd-mm-yyyy'), 6, 9061, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011102000228, to_date('02-11-2001', 'dd-mm-yyyy'), to_date('16-11-2001', 'dd-mm-yyyy'), 7, 2220, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105000229, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 10, 9619, to_date('16-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080922000230, to_date('22-09-2008', 'dd-mm-yyyy'), to_date('06-10-2008', 'dd-mm-yyyy'), 11, 5215, to_date('10-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010814000231, to_date('14-08-2001', 'dd-mm-yyyy'), to_date('28-08-2001', 'dd-mm-yyyy'), 7, 2437, to_date('01-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130902000232, to_date('02-09-2013', 'dd-mm-yyyy'), to_date('16-09-2013', 'dd-mm-yyyy'), 8, 7155, to_date('08-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051002000233, to_date('02-10-2005', 'dd-mm-yyyy'), to_date('16-10-2005', 'dd-mm-yyyy'), 8, 6826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010211000234, to_date('11-02-2001', 'dd-mm-yyyy'), to_date('25-02-2001', 'dd-mm-yyyy'), 3, 1361, to_date('02-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426000235, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 5, 1187, to_date('08-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060110000236, to_date('10-01-2006', 'dd-mm-yyyy'), to_date('24-01-2006', 'dd-mm-yyyy'), 10, 6859, to_date('29-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060409000237, to_date('09-04-2006', 'dd-mm-yyyy'), to_date('23-04-2006', 'dd-mm-yyyy'), 11, 6821, to_date('12-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121004000238, to_date('04-10-2012', 'dd-mm-yyyy'), to_date('18-10-2012', 'dd-mm-yyyy'), 6, 6669, to_date('10-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020823000239, to_date('23-08-2002', 'dd-mm-yyyy'), to_date('06-09-2002', 'dd-mm-yyyy'), 3, 1570, to_date('04-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408000240, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 9, 4255, to_date('21-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010625000241, to_date('25-06-2001', 'dd-mm-yyyy'), to_date('09-07-2001', 'dd-mm-yyyy'), 4, 3202, to_date('30-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703000242, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 2, 2749, to_date('17-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123000243, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 3, 3149, to_date('29-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628000244, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 12, 2184, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001220000245, to_date('20-12-2000', 'dd-mm-yyyy'), to_date('03-01-2001', 'dd-mm-yyyy'), 6, 968, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624000246, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 10, 9070, to_date('07-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000105000247, to_date('05-01-2000', 'dd-mm-yyyy'), to_date('19-01-2000', 'dd-mm-yyyy'), 2, 1113, to_date('12-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100531000248, to_date('31-05-2010', 'dd-mm-yyyy'), to_date('14-06-2010', 'dd-mm-yyyy'), 9, 6195, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601000249, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 7, 6891, to_date('16-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060610000250, to_date('10-06-2006', 'dd-mm-yyyy'), to_date('24-06-2006', 'dd-mm-yyyy'), 1, 4465, to_date('18-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050708000251, to_date('08-07-2005', 'dd-mm-yyyy'), to_date('22-07-2005', 'dd-mm-yyyy'), 10, 5583, to_date('27-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811000252, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 5, 10209, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525000253, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 10, 1740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070310000254, to_date('10-03-2007', 'dd-mm-yyyy'), to_date('24-03-2007', 'dd-mm-yyyy'), 6, 3088, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051008000255, to_date('08-10-2005', 'dd-mm-yyyy'), to_date('22-10-2005', 'dd-mm-yyyy'), 5, 7501, to_date('13-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130213000256, to_date('13-02-2013', 'dd-mm-yyyy'), to_date('27-02-2013', 'dd-mm-yyyy'), 9, 6278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040818000257, to_date('18-08-2004', 'dd-mm-yyyy'), to_date('01-09-2004', 'dd-mm-yyyy'), 2, 3043, to_date('02-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130612000258, to_date('12-06-2013', 'dd-mm-yyyy'), to_date('26-06-2013', 'dd-mm-yyyy'), 6, 9698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624000259, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 2, 3229, to_date('28-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020629000260, to_date('29-06-2002', 'dd-mm-yyyy'), to_date('13-07-2002', 'dd-mm-yyyy'), 8, 2854, to_date('01-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040214000261, to_date('14-02-2004', 'dd-mm-yyyy'), to_date('28-02-2004', 'dd-mm-yyyy'), 8, 4410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130215000262, to_date('15-02-2013', 'dd-mm-yyyy'), to_date('01-03-2013', 'dd-mm-yyyy'), 9, 6963, to_date('27-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140217000263, to_date('17-02-2014', 'dd-mm-yyyy'), to_date('03-03-2014', 'dd-mm-yyyy'), 1, 10421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100514000264, to_date('14-05-2010', 'dd-mm-yyyy'), to_date('28-05-2010', 'dd-mm-yyyy'), 5, 6698, to_date('27-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010824000265, to_date('24-08-2001', 'dd-mm-yyyy'), to_date('07-09-2001', 'dd-mm-yyyy'), 9, 4265, to_date('05-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040710000266, to_date('10-07-2004', 'dd-mm-yyyy'), to_date('24-07-2004', 'dd-mm-yyyy'), 12, 3279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215000267, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 12, 4957, to_date('18-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120501000268, to_date('01-05-2012', 'dd-mm-yyyy'), to_date('15-05-2012', 'dd-mm-yyyy'), 11, 9005, to_date('19-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100918000269, to_date('18-09-2010', 'dd-mm-yyyy'), to_date('02-10-2010', 'dd-mm-yyyy'), 12, 5870, to_date('07-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020402000270, to_date('02-04-2002', 'dd-mm-yyyy'), to_date('16-04-2002', 'dd-mm-yyyy'), 11, 1696, to_date('16-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131115000271, to_date('15-11-2013', 'dd-mm-yyyy'), to_date('29-11-2013', 'dd-mm-yyyy'), 11, 8653, to_date('18-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070930000272, to_date('30-09-2007', 'dd-mm-yyyy'), to_date('14-10-2007', 'dd-mm-yyyy'), 4, 5720, to_date('08-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011015000273, to_date('15-10-2001', 'dd-mm-yyyy'), to_date('29-10-2001', 'dd-mm-yyyy'), 1, 3173, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000924000274, to_date('24-09-2000', 'dd-mm-yyyy'), to_date('08-10-2000', 'dd-mm-yyyy'), 8, 1252, to_date('26-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040411000275, to_date('11-04-2004', 'dd-mm-yyyy'), to_date('25-04-2004', 'dd-mm-yyyy'), 5, 3148, to_date('18-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000623000276, to_date('23-06-2000', 'dd-mm-yyyy'), to_date('07-07-2000', 'dd-mm-yyyy'), 6, 2341, to_date('07-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040725000277, to_date('25-07-2004', 'dd-mm-yyyy'), to_date('08-08-2004', 'dd-mm-yyyy'), 3, 3029, to_date('28-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604000278, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 9, 6249, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000304000279, to_date('04-03-2000', 'dd-mm-yyyy'), to_date('18-03-2000', 'dd-mm-yyyy'), 10, 1364, to_date('22-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225000280, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 4, 662, to_date('27-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213000281, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 9, 7127, to_date('18-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100626000282, to_date('26-06-2010', 'dd-mm-yyyy'), to_date('10-07-2010', 'dd-mm-yyyy'), 8, 6732, to_date('07-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000517000283, to_date('17-05-2000', 'dd-mm-yyyy'), to_date('31-05-2000', 'dd-mm-yyyy'), 5, 876, to_date('05-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120530000284, to_date('30-05-2012', 'dd-mm-yyyy'), to_date('13-06-2012', 'dd-mm-yyyy'), 5, 7624, to_date('09-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071012000285, to_date('12-10-2007', 'dd-mm-yyyy'), to_date('26-10-2007', 'dd-mm-yyyy'), 7, 7821, to_date('31-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041017000286, to_date('17-10-2004', 'dd-mm-yyyy'), to_date('31-10-2004', 'dd-mm-yyyy'), 6, 3839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209000287, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 7, 2774, to_date('26-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071025000288, to_date('25-10-2007', 'dd-mm-yyyy'), to_date('08-11-2007', 'dd-mm-yyyy'), 6, 5991, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080129000289, to_date('29-01-2008', 'dd-mm-yyyy'), to_date('12-02-2008', 'dd-mm-yyyy'), 2, 7258, to_date('11-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011012000290, to_date('12-10-2001', 'dd-mm-yyyy'), to_date('26-10-2001', 'dd-mm-yyyy'), 11, 2377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051223000291, to_date('23-12-2005', 'dd-mm-yyyy'), to_date('06-01-2006', 'dd-mm-yyyy'), 4, 4428, to_date('01-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010612000292, to_date('12-06-2001', 'dd-mm-yyyy'), to_date('26-06-2001', 'dd-mm-yyyy'), 3, 2901, to_date('24-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725000293, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 9, 5288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712000294, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 11, 2305, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130000295, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 3, 2939, to_date('15-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071202000296, to_date('02-12-2007', 'dd-mm-yyyy'), to_date('16-12-2007', 'dd-mm-yyyy'), 8, 6375, to_date('09-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020127000297, to_date('27-01-2002', 'dd-mm-yyyy'), to_date('10-02-2002', 'dd-mm-yyyy'), 9, 2065, to_date('06-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131012000298, to_date('12-10-2013', 'dd-mm-yyyy'), to_date('26-10-2013', 'dd-mm-yyyy'), 3, 8861, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040128000299, to_date('28-01-2004', 'dd-mm-yyyy'), to_date('11-02-2004', 'dd-mm-yyyy'), 12, 3347, to_date('13-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120304000300, to_date('04-03-2012', 'dd-mm-yyyy'), to_date('18-03-2012', 'dd-mm-yyyy'), 4, 8287, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080118000301, to_date('18-01-2008', 'dd-mm-yyyy'), to_date('01-02-2008', 'dd-mm-yyyy'), 7, 6646, to_date('26-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000711000302, to_date('11-07-2000', 'dd-mm-yyyy'), to_date('25-07-2000', 'dd-mm-yyyy'), 8, 819, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526000303, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 8, 2576, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813000304, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 4, 875, to_date('16-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714000305, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 12, 4733, to_date('30-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020112000306, to_date('12-01-2002', 'dd-mm-yyyy'), to_date('26-01-2002', 'dd-mm-yyyy'), 10, 3908, to_date('27-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140501002450, to_date('01-05-2014', 'dd-mm-yyyy'), to_date('15-05-2014', 'dd-mm-yyyy'), 12, 8819, to_date('14-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050225002451, to_date('25-02-2005', 'dd-mm-yyyy'), to_date('11-03-2005', 'dd-mm-yyyy'), 1, 4197, to_date('17-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121115002452, to_date('15-11-2012', 'dd-mm-yyyy'), to_date('29-11-2012', 'dd-mm-yyyy'), 2, 10862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131010002453, to_date('10-10-2013', 'dd-mm-yyyy'), to_date('24-10-2013', 'dd-mm-yyyy'), 5, 6731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121219002454, to_date('19-12-2012', 'dd-mm-yyyy'), to_date('02-01-2013', 'dd-mm-yyyy'), 7, 7339, to_date('21-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011207002455, to_date('07-12-2001', 'dd-mm-yyyy'), to_date('21-12-2001', 'dd-mm-yyyy'), 3, 1087, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050702002456, to_date('02-07-2005', 'dd-mm-yyyy'), to_date('16-07-2005', 'dd-mm-yyyy'), 2, 5733, to_date('14-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060618002457, to_date('18-06-2006', 'dd-mm-yyyy'), to_date('02-07-2006', 'dd-mm-yyyy'), 6, 5571, to_date('23-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010825002458, to_date('25-08-2001', 'dd-mm-yyyy'), to_date('08-09-2001', 'dd-mm-yyyy'), 3, 2220, to_date('27-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140302002459, to_date('02-03-2014', 'dd-mm-yyyy'), to_date('16-03-2014', 'dd-mm-yyyy'), 8, 7585, to_date('07-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010928002460, to_date('28-09-2001', 'dd-mm-yyyy'), to_date('12-10-2001', 'dd-mm-yyyy'), 4, 1151, to_date('02-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303002461, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 7, 3278, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090307002462, to_date('07-03-2009', 'dd-mm-yyyy'), to_date('21-03-2009', 'dd-mm-yyyy'), 2, 6574, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111002463, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 5, 8309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140131002464, to_date('31-01-2014', 'dd-mm-yyyy'), to_date('14-02-2014', 'dd-mm-yyyy'), 8, 8755, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070417002465, to_date('17-04-2007', 'dd-mm-yyyy'), to_date('01-05-2007', 'dd-mm-yyyy'), 9, 3886, to_date('21-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120418002466, to_date('18-04-2012', 'dd-mm-yyyy'), to_date('02-05-2012', 'dd-mm-yyyy'), 7, 7677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924002467, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 11, 4124, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021229002468, to_date('29-12-2002', 'dd-mm-yyyy'), to_date('12-01-2003', 'dd-mm-yyyy'), 7, 3268, to_date('03-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130502002469, to_date('02-05-2013', 'dd-mm-yyyy'), to_date('16-05-2013', 'dd-mm-yyyy'), 4, 9515, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000307002470, to_date('07-03-2000', 'dd-mm-yyyy'), to_date('21-03-2000', 'dd-mm-yyyy'), 2, 1315, to_date('25-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060401002471, to_date('01-04-2006', 'dd-mm-yyyy'), to_date('15-04-2006', 'dd-mm-yyyy'), 6, 5421, to_date('13-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100911002472, to_date('11-09-2010', 'dd-mm-yyyy'), to_date('25-09-2010', 'dd-mm-yyyy'), 3, 6142, to_date('16-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010807002473, to_date('07-08-2001', 'dd-mm-yyyy'), to_date('21-08-2001', 'dd-mm-yyyy'), 7, 2562, to_date('20-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120129002474, to_date('29-01-2012', 'dd-mm-yyyy'), to_date('12-02-2012', 'dd-mm-yyyy'), 11, 6585, to_date('08-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121119002475, to_date('19-11-2012', 'dd-mm-yyyy'), to_date('03-12-2012', 'dd-mm-yyyy'), 5, 8566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011125002476, to_date('25-11-2001', 'dd-mm-yyyy'), to_date('09-12-2001', 'dd-mm-yyyy'), 11, 1752, to_date('11-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402002477, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 9, 2308, to_date('21-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090515002478, to_date('15-05-2009', 'dd-mm-yyyy'), to_date('29-05-2009', 'dd-mm-yyyy'), 2, 8401, to_date('04-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070721002479, to_date('21-07-2007', 'dd-mm-yyyy'), to_date('04-08-2007', 'dd-mm-yyyy'), 2, 5289, to_date('25-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060323002480, to_date('23-03-2006', 'dd-mm-yyyy'), to_date('06-04-2006', 'dd-mm-yyyy'), 6, 3987, to_date('03-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228002481, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 9, 8133, to_date('15-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120128002482, to_date('28-01-2012', 'dd-mm-yyyy'), to_date('11-02-2012', 'dd-mm-yyyy'), 9, 8360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110222002483, to_date('22-02-2011', 'dd-mm-yyyy'), to_date('08-03-2011', 'dd-mm-yyyy'), 12, 6711, to_date('10-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323002484, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 11, 3651, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030924002485, to_date('24-09-2003', 'dd-mm-yyyy'), to_date('08-10-2003', 'dd-mm-yyyy'), 8, 2308, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120204002486, to_date('04-02-2012', 'dd-mm-yyyy'), to_date('18-02-2012', 'dd-mm-yyyy'), 6, 6413, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112002487, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 11, 3794, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090606002488, to_date('06-06-2009', 'dd-mm-yyyy'), to_date('20-06-2009', 'dd-mm-yyyy'), 2, 7536, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010623002489, to_date('23-06-2001', 'dd-mm-yyyy'), to_date('07-07-2001', 'dd-mm-yyyy'), 7, 2173, to_date('08-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613002490, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 11, 858, to_date('23-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060104002491, to_date('04-01-2006', 'dd-mm-yyyy'), to_date('18-01-2006', 'dd-mm-yyyy'), 9, 5573, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080214002492, to_date('14-02-2008', 'dd-mm-yyyy'), to_date('28-02-2008', 'dd-mm-yyyy'), 5, 5297, to_date('20-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091015002493, to_date('15-10-2009', 'dd-mm-yyyy'), to_date('29-10-2009', 'dd-mm-yyyy'), 12, 5267, to_date('01-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010420002494, to_date('20-04-2001', 'dd-mm-yyyy'), to_date('04-05-2001', 'dd-mm-yyyy'), 2, 2074, to_date('28-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070302002495, to_date('02-03-2007', 'dd-mm-yyyy'), to_date('16-03-2007', 'dd-mm-yyyy'), 11, 4948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090910002496, to_date('10-09-2009', 'dd-mm-yyyy'), to_date('24-09-2009', 'dd-mm-yyyy'), 11, 7342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000810002497, to_date('10-08-2000', 'dd-mm-yyyy'), to_date('24-08-2000', 'dd-mm-yyyy'), 9, 926, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119002498, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 8, 2277, to_date('02-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040804002499, to_date('04-08-2004', 'dd-mm-yyyy'), to_date('18-08-2004', 'dd-mm-yyyy'), 10, 4072, to_date('10-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100723002500, to_date('23-07-2010', 'dd-mm-yyyy'), to_date('06-08-2010', 'dd-mm-yyyy'), 11, 8767, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010106002501, to_date('06-01-2001', 'dd-mm-yyyy'), to_date('20-01-2001', 'dd-mm-yyyy'), 1, 1774, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404002502, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 4, 4960, to_date('16-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070716002503, to_date('16-07-2007', 'dd-mm-yyyy'), to_date('30-07-2007', 'dd-mm-yyyy'), 8, 6792, to_date('29-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010517002504, to_date('17-05-2001', 'dd-mm-yyyy'), to_date('31-05-2001', 'dd-mm-yyyy'), 2, 3259, to_date('04-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104002505, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 11, 5479, to_date('16-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106002506, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 4, 6699, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225002507, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 1, 8439, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225002508, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 8, 5262, to_date('27-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316002509, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 3, 5799, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050407002510, to_date('07-04-2005', 'dd-mm-yyyy'), to_date('21-04-2005', 'dd-mm-yyyy'), 8, 2128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021222002511, to_date('22-12-2002', 'dd-mm-yyyy'), to_date('05-01-2003', 'dd-mm-yyyy'), 2, 3322, to_date('07-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130506002512, to_date('06-05-2013', 'dd-mm-yyyy'), to_date('20-05-2013', 'dd-mm-yyyy'), 3, 6400, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010328002513, to_date('28-03-2001', 'dd-mm-yyyy'), to_date('11-04-2001', 'dd-mm-yyyy'), 2, 3009, to_date('03-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120706002514, to_date('06-07-2012', 'dd-mm-yyyy'), to_date('20-07-2012', 'dd-mm-yyyy'), 1, 6671, to_date('09-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010527002515, to_date('27-05-2001', 'dd-mm-yyyy'), to_date('10-06-2001', 'dd-mm-yyyy'), 12, 3585, to_date('11-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090718002516, to_date('18-07-2009', 'dd-mm-yyyy'), to_date('01-08-2009', 'dd-mm-yyyy'), 3, 10117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050819002517, to_date('19-08-2005', 'dd-mm-yyyy'), to_date('02-09-2005', 'dd-mm-yyyy'), 3, 4936, to_date('02-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000517002518, to_date('17-05-2000', 'dd-mm-yyyy'), to_date('31-05-2000', 'dd-mm-yyyy'), 4, 1482, to_date('19-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110216002519, to_date('16-02-2011', 'dd-mm-yyyy'), to_date('02-03-2011', 'dd-mm-yyyy'), 5, 7289, to_date('07-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120811002520, to_date('11-08-2012', 'dd-mm-yyyy'), to_date('25-08-2012', 'dd-mm-yyyy'), 9, 5751, to_date('31-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010827002521, to_date('27-08-2001', 'dd-mm-yyyy'), to_date('10-09-2001', 'dd-mm-yyyy'), 5, 3504, to_date('30-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060315002522, to_date('15-03-2006', 'dd-mm-yyyy'), to_date('29-03-2006', 'dd-mm-yyyy'), 7, 6650, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010321002523, to_date('21-03-2001', 'dd-mm-yyyy'), to_date('04-04-2001', 'dd-mm-yyyy'), 5, 862, to_date('29-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130820002524, to_date('20-08-2013', 'dd-mm-yyyy'), to_date('03-09-2013', 'dd-mm-yyyy'), 7, 7259, to_date('05-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101223002525, to_date('23-12-2010', 'dd-mm-yyyy'), to_date('06-01-2011', 'dd-mm-yyyy'), 3, 6689, to_date('02-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110516002526, to_date('16-05-2011', 'dd-mm-yyyy'), to_date('30-05-2011', 'dd-mm-yyyy'), 8, 7318, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303002527, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 6, 10464, to_date('06-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081012002528, to_date('12-10-2008', 'dd-mm-yyyy'), to_date('26-10-2008', 'dd-mm-yyyy'), 10, 5716, to_date('17-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090518002529, to_date('18-05-2009', 'dd-mm-yyyy'), to_date('01-06-2009', 'dd-mm-yyyy'), 4, 5632, to_date('23-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528002530, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 6, 6913, to_date('01-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130615002531, to_date('15-06-2013', 'dd-mm-yyyy'), to_date('29-06-2013', 'dd-mm-yyyy'), 7, 6224, to_date('05-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131011002532, to_date('11-10-2013', 'dd-mm-yyyy'), to_date('25-10-2013', 'dd-mm-yyyy'), 2, 10919, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080620002533, to_date('20-06-2008', 'dd-mm-yyyy'), to_date('04-07-2008', 'dd-mm-yyyy'), 10, 6531, to_date('28-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000417002534, to_date('17-04-2000', 'dd-mm-yyyy'), to_date('01-05-2000', 'dd-mm-yyyy'), 12, 1021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060915002535, to_date('15-09-2006', 'dd-mm-yyyy'), to_date('29-09-2006', 'dd-mm-yyyy'), 6, 4699, to_date('22-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070913002536, to_date('13-09-2007', 'dd-mm-yyyy'), to_date('27-09-2007', 'dd-mm-yyyy'), 6, 5598, to_date('23-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725002537, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 4, 7290, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091113002538, to_date('13-11-2009', 'dd-mm-yyyy'), to_date('27-11-2009', 'dd-mm-yyyy'), 8, 5524, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111002539, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 7, 1114, to_date('18-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327002540, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 1, 13472, to_date('30-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408002541, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 10, 3403, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090506002542, to_date('06-05-2009', 'dd-mm-yyyy'), to_date('20-05-2009', 'dd-mm-yyyy'), 9, 7554, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227002543, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 11, 3647, to_date('03-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111021002544, to_date('21-10-2011', 'dd-mm-yyyy'), to_date('04-11-2011', 'dd-mm-yyyy'), 5, 9962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927002545, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 6, 7462, to_date('29-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927002546, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 7, 5832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120614002547, to_date('14-06-2012', 'dd-mm-yyyy'), to_date('28-06-2012', 'dd-mm-yyyy'), 8, 8545, to_date('03-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040116002548, to_date('16-01-2004', 'dd-mm-yyyy'), to_date('30-01-2004', 'dd-mm-yyyy'), 7, 5451, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050113002549, to_date('13-01-2005', 'dd-mm-yyyy'), to_date('27-01-2005', 'dd-mm-yyyy'), 5, 2816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020619002550, to_date('19-06-2002', 'dd-mm-yyyy'), to_date('03-07-2002', 'dd-mm-yyyy'), 10, 3598, to_date('22-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040228002551, to_date('28-02-2004', 'dd-mm-yyyy'), to_date('13-03-2004', 'dd-mm-yyyy'), 11, 5979, to_date('05-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130926002552, to_date('26-09-2013', 'dd-mm-yyyy'), to_date('10-10-2013', 'dd-mm-yyyy'), 4, 9315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100119002553, to_date('19-01-2010', 'dd-mm-yyyy'), to_date('02-02-2010', 'dd-mm-yyyy'), 6, 7584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060616002554, to_date('16-06-2006', 'dd-mm-yyyy'), to_date('30-06-2006', 'dd-mm-yyyy'), 1, 6272, to_date('25-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090613002555, to_date('13-06-2009', 'dd-mm-yyyy'), to_date('27-06-2009', 'dd-mm-yyyy'), 3, 5300, to_date('16-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020928002556, to_date('28-09-2002', 'dd-mm-yyyy'), to_date('12-10-2002', 'dd-mm-yyyy'), 1, 1587, to_date('03-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011005002557, to_date('05-10-2001', 'dd-mm-yyyy'), to_date('19-10-2001', 'dd-mm-yyyy'), 10, 1616, to_date('07-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001218002558, to_date('18-12-2000', 'dd-mm-yyyy'), to_date('01-01-2001', 'dd-mm-yyyy'), 2, 1816, to_date('30-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100714002559, to_date('14-07-2010', 'dd-mm-yyyy'), to_date('28-07-2010', 'dd-mm-yyyy'), 8, 7814, to_date('24-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120415002560, to_date('15-04-2012', 'dd-mm-yyyy'), to_date('29-04-2012', 'dd-mm-yyyy'), 6, 8062, to_date('26-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821002561, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 2, 6688, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070327002562, to_date('27-03-2007', 'dd-mm-yyyy'), to_date('10-04-2007', 'dd-mm-yyyy'), 2, 5677, to_date('12-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101028002563, to_date('28-10-2010', 'dd-mm-yyyy'), to_date('11-11-2010', 'dd-mm-yyyy'), 7, 5960, to_date('09-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210002564, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 1, 5831, to_date('12-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140306002565, to_date('06-03-2014', 'dd-mm-yyyy'), to_date('20-03-2014', 'dd-mm-yyyy'), 7, 9771, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090118002566, to_date('18-01-2009', 'dd-mm-yyyy'), to_date('01-02-2009', 'dd-mm-yyyy'), 10, 6705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131124002567, to_date('24-11-2013', 'dd-mm-yyyy'), to_date('08-12-2013', 'dd-mm-yyyy'), 8, 7946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121018002568, to_date('18-10-2012', 'dd-mm-yyyy'), to_date('01-11-2012', 'dd-mm-yyyy'), 4, 10172, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140415002569, to_date('15-04-2014', 'dd-mm-yyyy'), to_date('29-04-2014', 'dd-mm-yyyy'), 8, 6367, to_date('18-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010707002570, to_date('07-07-2001', 'dd-mm-yyyy'), to_date('21-07-2001', 'dd-mm-yyyy'), 2, 1603, to_date('13-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130111002571, to_date('11-01-2013', 'dd-mm-yyyy'), to_date('25-01-2013', 'dd-mm-yyyy'), 10, 7529, to_date('30-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000913002572, to_date('13-09-2000', 'dd-mm-yyyy'), to_date('27-09-2000', 'dd-mm-yyyy'), 7, 1510, to_date('29-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100413002573, to_date('13-04-2010', 'dd-mm-yyyy'), to_date('27-04-2010', 'dd-mm-yyyy'), 10, 8665, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901002574, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 4, 478, to_date('16-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010425002575, to_date('25-04-2001', 'dd-mm-yyyy'), to_date('09-05-2001', 'dd-mm-yyyy'), 1, 2264, to_date('12-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202002576, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 11, 6530, to_date('17-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040430002577, to_date('30-04-2004', 'dd-mm-yyyy'), to_date('14-05-2004', 'dd-mm-yyyy'), 9, 2164, to_date('07-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061109002578, to_date('09-11-2006', 'dd-mm-yyyy'), to_date('23-11-2006', 'dd-mm-yyyy'), 6, 4560, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030903002579, to_date('03-09-2003', 'dd-mm-yyyy'), to_date('17-09-2003', 'dd-mm-yyyy'), 12, 4335, to_date('19-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015002580, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 10, 960, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101217002581, to_date('17-12-2010', 'dd-mm-yyyy'), to_date('31-12-2010', 'dd-mm-yyyy'), 4, 9773, to_date('21-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080620002582, to_date('20-06-2008', 'dd-mm-yyyy'), to_date('04-07-2008', 'dd-mm-yyyy'), 1, 4929, to_date('05-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100523002583, to_date('23-05-2010', 'dd-mm-yyyy'), to_date('06-06-2010', 'dd-mm-yyyy'), 7, 7328, to_date('26-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051223002584, to_date('23-12-2005', 'dd-mm-yyyy'), to_date('06-01-2006', 'dd-mm-yyyy'), 7, 3428, to_date('27-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080523002585, to_date('23-05-2008', 'dd-mm-yyyy'), to_date('06-06-2008', 'dd-mm-yyyy'), 5, 5483, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030826002586, to_date('26-08-2003', 'dd-mm-yyyy'), to_date('09-09-2003', 'dd-mm-yyyy'), 4, 3041, to_date('07-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030429002587, to_date('29-04-2003', 'dd-mm-yyyy'), to_date('13-05-2003', 'dd-mm-yyyy'), 11, 2841, to_date('01-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228002588, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 12, 6108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110417002589, to_date('17-04-2011', 'dd-mm-yyyy'), to_date('01-05-2011', 'dd-mm-yyyy'), 3, 8533, to_date('27-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110806002590, to_date('06-08-2011', 'dd-mm-yyyy'), to_date('20-08-2011', 'dd-mm-yyyy'), 12, 9170, to_date('11-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020130002591, to_date('30-01-2002', 'dd-mm-yyyy'), to_date('13-02-2002', 'dd-mm-yyyy'), 9, 3245, to_date('01-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815002592, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 8, 2361, to_date('17-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061213002593, to_date('13-12-2006', 'dd-mm-yyyy'), to_date('27-12-2006', 'dd-mm-yyyy'), 8, 4648, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020705002594, to_date('05-07-2002', 'dd-mm-yyyy'), to_date('19-07-2002', 'dd-mm-yyyy'), 5, 3520, to_date('23-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130503002595, to_date('03-05-2013', 'dd-mm-yyyy'), to_date('17-05-2013', 'dd-mm-yyyy'), 7, 11802, to_date('07-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060821002596, to_date('21-08-2006', 'dd-mm-yyyy'), to_date('04-09-2006', 'dd-mm-yyyy'), 3, 6235, to_date('23-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091229002597, to_date('29-12-2009', 'dd-mm-yyyy'), to_date('12-01-2010', 'dd-mm-yyyy'), 4, 7441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050616002598, to_date('16-06-2005', 'dd-mm-yyyy'), to_date('30-06-2005', 'dd-mm-yyyy'), 5, 3094, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100405002599, to_date('05-04-2010', 'dd-mm-yyyy'), to_date('19-04-2010', 'dd-mm-yyyy'), 4, 9075, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080422002600, to_date('22-04-2008', 'dd-mm-yyyy'), to_date('06-05-2008', 'dd-mm-yyyy'), 7, 7685, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030106002601, to_date('06-01-2003', 'dd-mm-yyyy'), to_date('20-01-2003', 'dd-mm-yyyy'), 3, 4194, to_date('21-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110226002602, to_date('26-02-2011', 'dd-mm-yyyy'), to_date('12-03-2011', 'dd-mm-yyyy'), 11, 6579, to_date('03-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040329002603, to_date('29-03-2004', 'dd-mm-yyyy'), to_date('12-04-2004', 'dd-mm-yyyy'), 9, 4316, to_date('07-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060927004899, to_date('27-09-2006', 'dd-mm-yyyy'), to_date('11-10-2006', 'dd-mm-yyyy'), 6, 4482, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060510004900, to_date('10-05-2006', 'dd-mm-yyyy'), to_date('24-05-2006', 'dd-mm-yyyy'), 5, 4669, to_date('16-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060920004901, to_date('20-09-2006', 'dd-mm-yyyy'), to_date('04-10-2006', 'dd-mm-yyyy'), 4, 7151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100225004902, to_date('25-02-2010', 'dd-mm-yyyy'), to_date('11-03-2010', 'dd-mm-yyyy'), 5, 6513, to_date('06-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703004903, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 11, 2343, to_date('20-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140303004904, to_date('03-03-2014', 'dd-mm-yyyy'), to_date('17-03-2014', 'dd-mm-yyyy'), 4, 9614, to_date('14-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112004905, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 2, 6726, to_date('01-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090113004906, to_date('13-01-2009', 'dd-mm-yyyy'), to_date('27-01-2009', 'dd-mm-yyyy'), 11, 3920, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607004907, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 9, 5104, to_date('24-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071006004908, to_date('06-10-2007', 'dd-mm-yyyy'), to_date('20-10-2007', 'dd-mm-yyyy'), 10, 6116, to_date('19-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212004909, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 11, 3612, to_date('28-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070414004910, to_date('14-04-2007', 'dd-mm-yyyy'), to_date('28-04-2007', 'dd-mm-yyyy'), 5, 5835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070216004911, to_date('16-02-2007', 'dd-mm-yyyy'), to_date('02-03-2007', 'dd-mm-yyyy'), 8, 5747, to_date('06-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061009004912, to_date('09-10-2006', 'dd-mm-yyyy'), to_date('23-10-2006', 'dd-mm-yyyy'), 2, 7049, to_date('12-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140404004913, to_date('04-04-2014', 'dd-mm-yyyy'), to_date('18-04-2014', 'dd-mm-yyyy'), 5, 9211, to_date('20-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729004914, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 8, 7080, to_date('11-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923004915, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 9, 2367, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070110004916, to_date('10-01-2007', 'dd-mm-yyyy'), to_date('24-01-2007', 'dd-mm-yyyy'), 8, 5410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091025004917, to_date('25-10-2009', 'dd-mm-yyyy'), to_date('08-11-2009', 'dd-mm-yyyy'), 3, 6029, to_date('29-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020620004918, to_date('20-06-2002', 'dd-mm-yyyy'), to_date('04-07-2002', 'dd-mm-yyyy'), 10, 1507, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070416004919, to_date('16-04-2007', 'dd-mm-yyyy'), to_date('30-04-2007', 'dd-mm-yyyy'), 11, 5097, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100114004920, to_date('14-01-2010', 'dd-mm-yyyy'), to_date('28-01-2010', 'dd-mm-yyyy'), 8, 6174, to_date('23-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071119004921, to_date('19-11-2007', 'dd-mm-yyyy'), to_date('03-12-2007', 'dd-mm-yyyy'), 3, 4220, to_date('05-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230004922, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 1, 1561, to_date('12-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602004923, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 5, 4783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041022004924, to_date('22-10-2004', 'dd-mm-yyyy'), to_date('05-11-2004', 'dd-mm-yyyy'), 8, 3043, to_date('10-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000823004925, to_date('23-08-2000', 'dd-mm-yyyy'), to_date('06-09-2000', 'dd-mm-yyyy'), 6, 3417, to_date('27-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906004926, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 6, 4777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101004927, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 7, 1594, to_date('14-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010124004928, to_date('24-01-2001', 'dd-mm-yyyy'), to_date('07-02-2001', 'dd-mm-yyyy'), 9, 1431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030829004929, to_date('29-08-2003', 'dd-mm-yyyy'), to_date('12-09-2003', 'dd-mm-yyyy'), 12, 3478, to_date('05-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070918004930, to_date('18-09-2007', 'dd-mm-yyyy'), to_date('02-10-2007', 'dd-mm-yyyy'), 5, 6815, to_date('23-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307004931, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 8, 6953, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229004932, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 2, 6762, to_date('14-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010903004933, to_date('03-09-2001', 'dd-mm-yyyy'), to_date('17-09-2001', 'dd-mm-yyyy'), 9, 2703, to_date('18-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010629004934, to_date('29-06-2001', 'dd-mm-yyyy'), to_date('13-07-2001', 'dd-mm-yyyy'), 6, 4048, to_date('11-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081220004935, to_date('20-12-2008', 'dd-mm-yyyy'), to_date('03-01-2009', 'dd-mm-yyyy'), 6, 7899, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120415004936, to_date('15-04-2012', 'dd-mm-yyyy'), to_date('29-04-2012', 'dd-mm-yyyy'), 12, 8026, to_date('29-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602004937, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 8, 4620, to_date('12-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100112004938, to_date('12-01-2010', 'dd-mm-yyyy'), to_date('26-01-2010', 'dd-mm-yyyy'), 6, 6939, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420004939, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 4, 3440, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060502004940, to_date('02-05-2006', 'dd-mm-yyyy'), to_date('16-05-2006', 'dd-mm-yyyy'), 12, 6685, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821004941, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 10, 6343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041214004942, to_date('14-12-2004', 'dd-mm-yyyy'), to_date('28-12-2004', 'dd-mm-yyyy'), 8, 5535, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061008004943, to_date('08-10-2006', 'dd-mm-yyyy'), to_date('22-10-2006', 'dd-mm-yyyy'), 5, 6363, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120514004944, to_date('14-05-2012', 'dd-mm-yyyy'), to_date('28-05-2012', 'dd-mm-yyyy'), 8, 8184, to_date('20-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061022004945, to_date('22-10-2006', 'dd-mm-yyyy'), to_date('05-11-2006', 'dd-mm-yyyy'), 2, 5349, to_date('29-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021025004946, to_date('25-10-2002', 'dd-mm-yyyy'), to_date('08-11-2002', 'dd-mm-yyyy'), 11, 1718, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624004947, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 4, 5874, to_date('28-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101004948, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 4, 5706, to_date('10-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111004949, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 8, 10636, to_date('23-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020922004950, to_date('22-09-2002', 'dd-mm-yyyy'), to_date('06-10-2002', 'dd-mm-yyyy'), 7, 4225, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100408004951, to_date('08-04-2010', 'dd-mm-yyyy'), to_date('22-04-2010', 'dd-mm-yyyy'), 10, 7380, to_date('12-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211004952, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 4, 1990, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101221004953, to_date('21-12-2010', 'dd-mm-yyyy'), to_date('04-01-2011', 'dd-mm-yyyy'), 2, 7311, to_date('28-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021009004954, to_date('09-10-2002', 'dd-mm-yyyy'), to_date('23-10-2002', 'dd-mm-yyyy'), 5, 2291, to_date('10-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060825004955, to_date('25-08-2006', 'dd-mm-yyyy'), to_date('08-09-2006', 'dd-mm-yyyy'), 1, 6108, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040305004956, to_date('05-03-2004', 'dd-mm-yyyy'), to_date('19-03-2004', 'dd-mm-yyyy'), 9, 3641, to_date('21-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080505004957, to_date('05-05-2008', 'dd-mm-yyyy'), to_date('19-05-2008', 'dd-mm-yyyy'), 4, 5628, to_date('17-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070526004958, to_date('26-05-2007', 'dd-mm-yyyy'), to_date('09-06-2007', 'dd-mm-yyyy'), 11, 5021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000714004959, to_date('14-07-2000', 'dd-mm-yyyy'), to_date('28-07-2000', 'dd-mm-yyyy'), 7, 1575, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051219004960, to_date('19-12-2005', 'dd-mm-yyyy'), to_date('02-01-2006', 'dd-mm-yyyy'), 3, 5004, to_date('07-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130125004961, to_date('25-01-2013', 'dd-mm-yyyy'), to_date('08-02-2013', 'dd-mm-yyyy'), 11, 11458, to_date('08-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112004962, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 2, 2624, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060524004963, to_date('24-05-2006', 'dd-mm-yyyy'), to_date('07-06-2006', 'dd-mm-yyyy'), 3, 5071, to_date('25-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001220004964, to_date('20-12-2000', 'dd-mm-yyyy'), to_date('03-01-2001', 'dd-mm-yyyy'), 11, 2374, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131117004965, to_date('17-11-2013', 'dd-mm-yyyy'), to_date('01-12-2013', 'dd-mm-yyyy'), 9, 9032, to_date('30-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070806004966, to_date('06-08-2007', 'dd-mm-yyyy'), to_date('20-08-2007', 'dd-mm-yyyy'), 7, 7500, to_date('16-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916004967, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 9, 2576, to_date('30-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000815004968, to_date('15-08-2000', 'dd-mm-yyyy'), to_date('29-08-2000', 'dd-mm-yyyy'), 2, 2696, to_date('21-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110120004969, to_date('20-01-2011', 'dd-mm-yyyy'), to_date('03-02-2011', 'dd-mm-yyyy'), 2, 5636, to_date('30-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061006004970, to_date('06-10-2006', 'dd-mm-yyyy'), to_date('20-10-2006', 'dd-mm-yyyy'), 5, 3724, to_date('09-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110603004971, to_date('03-06-2011', 'dd-mm-yyyy'), to_date('17-06-2011', 'dd-mm-yyyy'), 8, 7101, to_date('14-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070123004972, to_date('23-01-2007', 'dd-mm-yyyy'), to_date('06-02-2007', 'dd-mm-yyyy'), 7, 4718, to_date('10-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081123004973, to_date('23-11-2008', 'dd-mm-yyyy'), to_date('07-12-2008', 'dd-mm-yyyy'), 4, 5376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070709004974, to_date('09-07-2007', 'dd-mm-yyyy'), to_date('23-07-2007', 'dd-mm-yyyy'), 9, 4523, to_date('23-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218004975, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 7, 3242, to_date('07-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070625004976, to_date('25-06-2007', 'dd-mm-yyyy'), to_date('09-07-2007', 'dd-mm-yyyy'), 12, 4832, to_date('03-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070929004977, to_date('29-09-2007', 'dd-mm-yyyy'), to_date('13-10-2007', 'dd-mm-yyyy'), 12, 4956, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209004978, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 6, 4926, to_date('23-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041019004979, to_date('19-10-2004', 'dd-mm-yyyy'), to_date('02-11-2004', 'dd-mm-yyyy'), 2, 4326, to_date('31-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131130004980, to_date('30-11-2013', 'dd-mm-yyyy'), to_date('14-12-2013', 'dd-mm-yyyy'), 4, 7455, to_date('03-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070607004981, to_date('07-06-2007', 'dd-mm-yyyy'), to_date('21-06-2007', 'dd-mm-yyyy'), 8, 5685, to_date('16-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101024004982, to_date('24-10-2010', 'dd-mm-yyyy'), to_date('07-11-2010', 'dd-mm-yyyy'), 6, 8650, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010824004983, to_date('24-08-2001', 'dd-mm-yyyy'), to_date('07-09-2001', 'dd-mm-yyyy'), 5, 1459, to_date('05-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020125004984, to_date('25-01-2002', 'dd-mm-yyyy'), to_date('08-02-2002', 'dd-mm-yyyy'), 1, 4026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001124004985, to_date('24-11-2000', 'dd-mm-yyyy'), to_date('08-12-2000', 'dd-mm-yyyy'), 3, 520, to_date('08-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908004986, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 7, 4362, to_date('17-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101029004987, to_date('29-10-2010', 'dd-mm-yyyy'), to_date('12-11-2010', 'dd-mm-yyyy'), 12, 7589, to_date('11-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110402004988, to_date('02-04-2011', 'dd-mm-yyyy'), to_date('16-04-2011', 'dd-mm-yyyy'), 10, 5767, to_date('04-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030812004989, to_date('12-08-2003', 'dd-mm-yyyy'), to_date('26-08-2003', 'dd-mm-yyyy'), 10, 3793, to_date('28-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100111004990, to_date('11-01-2010', 'dd-mm-yyyy'), to_date('25-01-2010', 'dd-mm-yyyy'), 2, 7981, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130604004991, to_date('04-06-2013', 'dd-mm-yyyy'), to_date('18-06-2013', 'dd-mm-yyyy'), 3, 9754, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728004992, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 4, 8167, to_date('14-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206004993, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 10, 6161, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001212004994, to_date('12-12-2000', 'dd-mm-yyyy'), to_date('26-12-2000', 'dd-mm-yyyy'), 5, 2037, to_date('18-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030418004995, to_date('18-04-2003', 'dd-mm-yyyy'), to_date('02-05-2003', 'dd-mm-yyyy'), 6, 3487, to_date('22-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040918004996, to_date('18-09-2004', 'dd-mm-yyyy'), to_date('02-10-2004', 'dd-mm-yyyy'), 1, 3145, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040321004997, to_date('21-03-2004', 'dd-mm-yyyy'), to_date('04-04-2004', 'dd-mm-yyyy'), 10, 3813, to_date('27-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090421004998, to_date('21-04-2009', 'dd-mm-yyyy'), to_date('05-05-2009', 'dd-mm-yyyy'), 12, 9464, to_date('30-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010808004999, to_date('08-08-2001', 'dd-mm-yyyy'), to_date('22-08-2001', 'dd-mm-yyyy'), 6, 2147, to_date('21-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120623005000, to_date('23-06-2012', 'dd-mm-yyyy'), to_date('07-07-2012', 'dd-mm-yyyy'), 3, 10163, to_date('26-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060321005001, to_date('21-03-2006', 'dd-mm-yyyy'), to_date('04-04-2006', 'dd-mm-yyyy'), 2, 4113, to_date('06-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020603005002, to_date('03-06-2002', 'dd-mm-yyyy'), to_date('17-06-2002', 'dd-mm-yyyy'), 10, 3719, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110805005003, to_date('05-08-2011', 'dd-mm-yyyy'), to_date('19-08-2011', 'dd-mm-yyyy'), 12, 7289, to_date('16-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020311005004, to_date('11-03-2002', 'dd-mm-yyyy'), to_date('25-03-2002', 'dd-mm-yyyy'), 3, 2855, to_date('22-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011001005005, to_date('01-10-2001', 'dd-mm-yyyy'), to_date('15-10-2001', 'dd-mm-yyyy'), 9, 1756, to_date('09-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091122005006, to_date('22-11-2009', 'dd-mm-yyyy'), to_date('06-12-2009', 'dd-mm-yyyy'), 6, 6298, to_date('10-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313005007, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 8, 5271, to_date('31-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912005008, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 10, 3057, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041102005009, to_date('02-11-2004', 'dd-mm-yyyy'), to_date('16-11-2004', 'dd-mm-yyyy'), 9, 3869, to_date('06-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120311005010, to_date('11-03-2012', 'dd-mm-yyyy'), to_date('25-03-2012', 'dd-mm-yyyy'), 1, 8017, to_date('31-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004005011, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 8, 6598, to_date('22-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928005012, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 10, 6362, to_date('10-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090129005013, to_date('29-01-2009', 'dd-mm-yyyy'), to_date('12-02-2009', 'dd-mm-yyyy'), 6, 3910, to_date('06-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001030005014, to_date('30-10-2000', 'dd-mm-yyyy'), to_date('13-11-2000', 'dd-mm-yyyy'), 7, 2835, to_date('13-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121119005015, to_date('19-11-2012', 'dd-mm-yyyy'), to_date('03-12-2012', 'dd-mm-yyyy'), 5, 7567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019005016, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 5, 8741, to_date('25-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140306005017, to_date('06-03-2014', 'dd-mm-yyyy'), to_date('20-03-2014', 'dd-mm-yyyy'), 2, 9744, to_date('18-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030701005018, to_date('01-07-2003', 'dd-mm-yyyy'), to_date('15-07-2003', 'dd-mm-yyyy'), 8, 2677, to_date('11-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100710005019, to_date('10-07-2010', 'dd-mm-yyyy'), to_date('24-07-2010', 'dd-mm-yyyy'), 4, 8766, to_date('29-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101224005020, to_date('24-12-2010', 'dd-mm-yyyy'), to_date('07-01-2011', 'dd-mm-yyyy'), 4, 6048, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101118005021, to_date('18-11-2010', 'dd-mm-yyyy'), to_date('02-12-2010', 'dd-mm-yyyy'), 10, 6923, to_date('21-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070810005022, to_date('10-08-2007', 'dd-mm-yyyy'), to_date('24-08-2007', 'dd-mm-yyyy'), 4, 7886, to_date('13-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909005023, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 5, 6631, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041001005024, to_date('01-10-2004', 'dd-mm-yyyy'), to_date('15-10-2004', 'dd-mm-yyyy'), 7, 3714, to_date('03-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030223005025, to_date('23-02-2003', 'dd-mm-yyyy'), to_date('09-03-2003', 'dd-mm-yyyy'), 12, 3305, to_date('05-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000529005026, to_date('29-05-2000', 'dd-mm-yyyy'), to_date('12-06-2000', 'dd-mm-yyyy'), 12, 1568, to_date('03-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131004005027, to_date('04-10-2013', 'dd-mm-yyyy'), to_date('18-10-2013', 'dd-mm-yyyy'), 7, 5957, to_date('16-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031018005028, to_date('18-10-2003', 'dd-mm-yyyy'), to_date('01-11-2003', 'dd-mm-yyyy'), 8, 4526, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040418005029, to_date('18-04-2004', 'dd-mm-yyyy'), to_date('02-05-2004', 'dd-mm-yyyy'), 3, 5755, to_date('04-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130113005030, to_date('13-01-2013', 'dd-mm-yyyy'), to_date('27-01-2013', 'dd-mm-yyyy'), 3, 9066, to_date('31-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020331005031, to_date('31-03-2002', 'dd-mm-yyyy'), to_date('14-04-2002', 'dd-mm-yyyy'), 5, 2242, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031106005032, to_date('06-11-2003', 'dd-mm-yyyy'), to_date('20-11-2003', 'dd-mm-yyyy'), 8, 3230, to_date('25-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120306005033, to_date('06-03-2012', 'dd-mm-yyyy'), to_date('20-03-2012', 'dd-mm-yyyy'), 8, 9608, to_date('10-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117005034, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 7, 8978, to_date('19-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031021005035, to_date('21-10-2003', 'dd-mm-yyyy'), to_date('04-11-2003', 'dd-mm-yyyy'), 3, 2379, to_date('03-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070409005036, to_date('09-04-2007', 'dd-mm-yyyy'), to_date('23-04-2007', 'dd-mm-yyyy'), 5, 5256, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050603005037, to_date('03-06-2005', 'dd-mm-yyyy'), to_date('17-06-2005', 'dd-mm-yyyy'), 7, 4976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061223005038, to_date('23-12-2006', 'dd-mm-yyyy'), to_date('06-01-2007', 'dd-mm-yyyy'), 1, 5676, to_date('10-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030318005039, to_date('18-03-2003', 'dd-mm-yyyy'), to_date('01-04-2003', 'dd-mm-yyyy'), 12, 4914, to_date('03-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090524005040, to_date('24-05-2009', 'dd-mm-yyyy'), to_date('07-06-2009', 'dd-mm-yyyy'), 11, 8021, to_date('10-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050701005041, to_date('01-07-2005', 'dd-mm-yyyy'), to_date('15-07-2005', 'dd-mm-yyyy'), 1, 4044, to_date('02-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061019005042, to_date('19-10-2006', 'dd-mm-yyyy'), to_date('02-11-2006', 'dd-mm-yyyy'), 4, 5181, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011005043, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 2, 7164, to_date('30-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213005044, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 5, 6790, to_date('26-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090308005045, to_date('08-03-2009', 'dd-mm-yyyy'), to_date('22-03-2009', 'dd-mm-yyyy'), 6, 6462, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051115005046, to_date('15-11-2005', 'dd-mm-yyyy'), to_date('29-11-2005', 'dd-mm-yyyy'), 5, 3833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061228005047, to_date('28-12-2006', 'dd-mm-yyyy'), to_date('11-01-2007', 'dd-mm-yyyy'), 9, 8185, to_date('12-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716005048, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 6, 3895, to_date('30-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202005049, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 3, 4887, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070316005050, to_date('16-03-2007', 'dd-mm-yyyy'), to_date('30-03-2007', 'dd-mm-yyyy'), 7, 7036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091104005051, to_date('04-11-2009', 'dd-mm-yyyy'), to_date('18-11-2009', 'dd-mm-yyyy'), 10, 6334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110320007194, to_date('20-03-2011', 'dd-mm-yyyy'), to_date('03-04-2011', 'dd-mm-yyyy'), 4, 7065, to_date('26-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924007195, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 4, 9192, to_date('05-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207007196, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 2, 5176, to_date('13-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071210007197, to_date('10-12-2007', 'dd-mm-yyyy'), to_date('24-12-2007', 'dd-mm-yyyy'), 7, 5249, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707007198, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 12, 6203, to_date('21-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403007199, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 7, 5065, to_date('08-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081002007200, to_date('02-10-2008', 'dd-mm-yyyy'), to_date('16-10-2008', 'dd-mm-yyyy'), 9, 8276, to_date('19-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080106007201, to_date('06-01-2008', 'dd-mm-yyyy'), to_date('20-01-2008', 'dd-mm-yyyy'), 9, 4022, to_date('14-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071031007202, to_date('31-10-2007', 'dd-mm-yyyy'), to_date('14-11-2007', 'dd-mm-yyyy'), 11, 3294, to_date('10-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081018007203, to_date('18-10-2008', 'dd-mm-yyyy'), to_date('01-11-2008', 'dd-mm-yyyy'), 10, 5701, to_date('24-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140312007204, to_date('12-03-2014', 'dd-mm-yyyy'), to_date('26-03-2014', 'dd-mm-yyyy'), 9, 10216, to_date('17-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060720007205, to_date('20-07-2006', 'dd-mm-yyyy'), to_date('03-08-2006', 'dd-mm-yyyy'), 5, 4937, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926007206, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 7, 10006, to_date('13-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031114007207, to_date('14-11-2003', 'dd-mm-yyyy'), to_date('28-11-2003', 'dd-mm-yyyy'), 6, 1985, to_date('30-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130201007208, to_date('01-02-2013', 'dd-mm-yyyy'), to_date('15-02-2013', 'dd-mm-yyyy'), 6, 6842, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000531007209, to_date('31-05-2000', 'dd-mm-yyyy'), to_date('14-06-2000', 'dd-mm-yyyy'), 8, 1151, to_date('02-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030812007210, to_date('12-08-2003', 'dd-mm-yyyy'), to_date('26-08-2003', 'dd-mm-yyyy'), 11, 4235, to_date('17-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812007211, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 10, 6718, to_date('31-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121002007212, to_date('02-10-2012', 'dd-mm-yyyy'), to_date('16-10-2012', 'dd-mm-yyyy'), 1, 8520, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070524007213, to_date('24-05-2007', 'dd-mm-yyyy'), to_date('07-06-2007', 'dd-mm-yyyy'), 5, 4176, to_date('02-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703007214, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 7, 5998, to_date('05-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601007215, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 8, 6064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020313007216, to_date('13-03-2002', 'dd-mm-yyyy'), to_date('27-03-2002', 'dd-mm-yyyy'), 3, 2026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302007217, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 7, 4303, to_date('06-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107007218, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 6, 9154, to_date('15-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009007219, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 11, 6899, to_date('22-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040315007220, to_date('15-03-2004', 'dd-mm-yyyy'), to_date('29-03-2004', 'dd-mm-yyyy'), 8, 3527, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010224007221, to_date('24-02-2001', 'dd-mm-yyyy'), to_date('10-03-2001', 'dd-mm-yyyy'), 5, 2217, to_date('16-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020914007222, to_date('14-09-2002', 'dd-mm-yyyy'), to_date('28-09-2002', 'dd-mm-yyyy'), 8, 2579, to_date('03-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050715007223, to_date('15-07-2005', 'dd-mm-yyyy'), to_date('29-07-2005', 'dd-mm-yyyy'), 12, 2998, to_date('25-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130527007224, to_date('27-05-2013', 'dd-mm-yyyy'), to_date('10-06-2013', 'dd-mm-yyyy'), 5, 11287, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090518007225, to_date('18-05-2009', 'dd-mm-yyyy'), to_date('01-06-2009', 'dd-mm-yyyy'), 6, 8812, to_date('25-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030926007226, to_date('26-09-2003', 'dd-mm-yyyy'), to_date('10-10-2003', 'dd-mm-yyyy'), 6, 2355, to_date('02-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114007227, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 10, 2893, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618007228, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 12, 1057, to_date('28-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081106007229, to_date('06-11-2008', 'dd-mm-yyyy'), to_date('20-11-2008', 'dd-mm-yyyy'), 2, 6516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051025007230, to_date('25-10-2005', 'dd-mm-yyyy'), to_date('08-11-2005', 'dd-mm-yyyy'), 8, 5379, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101020007231, to_date('20-10-2010', 'dd-mm-yyyy'), to_date('03-11-2010', 'dd-mm-yyyy'), 7, 8336, to_date('24-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070902007232, to_date('02-09-2007', 'dd-mm-yyyy'), to_date('16-09-2007', 'dd-mm-yyyy'), 10, 5527, to_date('20-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041028007233, to_date('28-10-2004', 'dd-mm-yyyy'), to_date('11-11-2004', 'dd-mm-yyyy'), 8, 2642, to_date('03-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515007234, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 11, 5336, to_date('29-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090710007235, to_date('10-07-2009', 'dd-mm-yyyy'), to_date('24-07-2009', 'dd-mm-yyyy'), 7, 5598, to_date('29-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040824007236, to_date('24-08-2004', 'dd-mm-yyyy'), to_date('07-09-2004', 'dd-mm-yyyy'), 4, 3909, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080731007237, to_date('31-07-2008', 'dd-mm-yyyy'), to_date('14-08-2008', 'dd-mm-yyyy'), 8, 6829, to_date('17-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010921007238, to_date('21-09-2001', 'dd-mm-yyyy'), to_date('05-10-2001', 'dd-mm-yyyy'), 3, 2212, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070401007239, to_date('01-04-2007', 'dd-mm-yyyy'), to_date('15-04-2007', 'dd-mm-yyyy'), 5, 7713, to_date('11-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111227007240, to_date('27-12-2011', 'dd-mm-yyyy'), to_date('10-01-2012', 'dd-mm-yyyy'), 7, 9204, to_date('29-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111019007241, to_date('19-10-2011', 'dd-mm-yyyy'), to_date('02-11-2011', 'dd-mm-yyyy'), 4, 8463, to_date('01-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020623007242, to_date('23-06-2002', 'dd-mm-yyyy'), to_date('07-07-2002', 'dd-mm-yyyy'), 2, 4082, to_date('07-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031120007243, to_date('20-11-2003', 'dd-mm-yyyy'), to_date('04-12-2003', 'dd-mm-yyyy'), 3, 3817, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006007244, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 3, 8828, to_date('19-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101110007245, to_date('10-11-2010', 'dd-mm-yyyy'), to_date('24-11-2010', 'dd-mm-yyyy'), 10, 10132, to_date('23-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921007246, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 4, 1342, to_date('28-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010130007247, to_date('30-01-2001', 'dd-mm-yyyy'), to_date('13-02-2001', 'dd-mm-yyyy'), 1, 1414, to_date('01-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080710007248, to_date('10-07-2008', 'dd-mm-yyyy'), to_date('24-07-2008', 'dd-mm-yyyy'), 6, 6809, to_date('11-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091002007249, to_date('02-10-2009', 'dd-mm-yyyy'), to_date('16-10-2009', 'dd-mm-yyyy'), 6, 6930, to_date('17-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030715007250, to_date('15-07-2003', 'dd-mm-yyyy'), to_date('29-07-2003', 'dd-mm-yyyy'), 6, 2519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422007251, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 12, 5351, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070113007252, to_date('13-01-2007', 'dd-mm-yyyy'), to_date('27-01-2007', 'dd-mm-yyyy'), 10, 4346, to_date('16-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070303007253, to_date('03-03-2007', 'dd-mm-yyyy'), to_date('17-03-2007', 'dd-mm-yyyy'), 6, 5913, to_date('22-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513007254, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 9, 6101, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929007255, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 6, 2163, to_date('10-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100623007256, to_date('23-06-2010', 'dd-mm-yyyy'), to_date('07-07-2010', 'dd-mm-yyyy'), 8, 7285, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010815007257, to_date('15-08-2001', 'dd-mm-yyyy'), to_date('29-08-2001', 'dd-mm-yyyy'), 10, 1712, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027007258, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 7, 5614, to_date('06-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061019007259, to_date('19-10-2006', 'dd-mm-yyyy'), to_date('02-11-2006', 'dd-mm-yyyy'), 10, 4557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020822007260, to_date('22-08-2002', 'dd-mm-yyyy'), to_date('05-09-2002', 'dd-mm-yyyy'), 2, 3464, to_date('31-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111001007261, to_date('01-10-2011', 'dd-mm-yyyy'), to_date('15-10-2011', 'dd-mm-yyyy'), 2, 7819, to_date('04-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041115007262, to_date('15-11-2004', 'dd-mm-yyyy'), to_date('29-11-2004', 'dd-mm-yyyy'), 2, 4286, to_date('30-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000421007263, to_date('21-04-2000', 'dd-mm-yyyy'), to_date('05-05-2000', 'dd-mm-yyyy'), 1, 1885, to_date('27-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131122007264, to_date('22-11-2013', 'dd-mm-yyyy'), to_date('06-12-2013', 'dd-mm-yyyy'), 3, 12501, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050930007265, to_date('30-09-2005', 'dd-mm-yyyy'), to_date('14-10-2005', 'dd-mm-yyyy'), 1, 5633, to_date('08-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061111007266, to_date('11-11-2006', 'dd-mm-yyyy'), to_date('25-11-2006', 'dd-mm-yyyy'), 12, 5946, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128007267, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 12, 2829, to_date('30-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080820007268, to_date('20-08-2008', 'dd-mm-yyyy'), to_date('03-09-2008', 'dd-mm-yyyy'), 8, 3773, to_date('22-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070404007269, to_date('04-04-2007', 'dd-mm-yyyy'), to_date('18-04-2007', 'dd-mm-yyyy'), 5, 5860, to_date('16-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100430007270, to_date('30-04-2010', 'dd-mm-yyyy'), to_date('14-05-2010', 'dd-mm-yyyy'), 10, 5362, to_date('20-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603007271, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 8, 4775, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030320007272, to_date('20-03-2003', 'dd-mm-yyyy'), to_date('03-04-2003', 'dd-mm-yyyy'), 11, 2358, to_date('26-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010325007273, to_date('25-03-2001', 'dd-mm-yyyy'), to_date('08-04-2001', 'dd-mm-yyyy'), 1, 1438, to_date('03-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040324007274, to_date('24-03-2004', 'dd-mm-yyyy'), to_date('07-04-2004', 'dd-mm-yyyy'), 12, 3377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130430007275, to_date('30-04-2013', 'dd-mm-yyyy'), to_date('14-05-2013', 'dd-mm-yyyy'), 2, 8749, to_date('15-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723007276, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 1, 3008, to_date('09-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090110007277, to_date('10-01-2009', 'dd-mm-yyyy'), to_date('24-01-2009', 'dd-mm-yyyy'), 10, 6232, to_date('17-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513007278, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 10, 5475, to_date('27-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100519007279, to_date('19-05-2010', 'dd-mm-yyyy'), to_date('02-06-2010', 'dd-mm-yyyy'), 12, 5483, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408007280, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 2, 5408, to_date('13-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030219007281, to_date('19-02-2003', 'dd-mm-yyyy'), to_date('05-03-2003', 'dd-mm-yyyy'), 7, 4682, to_date('06-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081013007282, to_date('13-10-2008', 'dd-mm-yyyy'), to_date('27-10-2008', 'dd-mm-yyyy'), 6, 6783, to_date('17-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020824007283, to_date('24-08-2002', 'dd-mm-yyyy'), to_date('07-09-2002', 'dd-mm-yyyy'), 12, 3644, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825007284, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 3, 3325, to_date('08-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010909007285, to_date('09-09-2001', 'dd-mm-yyyy'), to_date('23-09-2001', 'dd-mm-yyyy'), 7, 946, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609007286, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 6, 880, to_date('19-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723007287, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 8, 3031, to_date('05-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070728007288, to_date('28-07-2007', 'dd-mm-yyyy'), to_date('11-08-2007', 'dd-mm-yyyy'), 11, 5418, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020425007289, to_date('25-04-2002', 'dd-mm-yyyy'), to_date('09-05-2002', 'dd-mm-yyyy'), 5, 3275, to_date('02-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129007290, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 11, 4745, to_date('30-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030917007291, to_date('17-09-2003', 'dd-mm-yyyy'), to_date('01-10-2003', 'dd-mm-yyyy'), 8, 3840, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001016007292, to_date('16-10-2000', 'dd-mm-yyyy'), to_date('30-10-2000', 'dd-mm-yyyy'), 7, 1334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000212007293, to_date('12-02-2000', 'dd-mm-yyyy'), to_date('26-02-2000', 'dd-mm-yyyy'), 2, 2224, to_date('15-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815007294, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 10, 3668, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121030007295, to_date('30-10-2012', 'dd-mm-yyyy'), to_date('13-11-2012', 'dd-mm-yyyy'), 5, 8421, to_date('18-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110427007296, to_date('27-04-2011', 'dd-mm-yyyy'), to_date('11-05-2011', 'dd-mm-yyyy'), 2, 10381, to_date('05-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030627007297, to_date('27-06-2003', 'dd-mm-yyyy'), to_date('11-07-2003', 'dd-mm-yyyy'), 12, 3530, to_date('06-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070423007298, to_date('23-04-2007', 'dd-mm-yyyy'), to_date('07-05-2007', 'dd-mm-yyyy'), 7, 6436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090829007299, to_date('29-08-2009', 'dd-mm-yyyy'), to_date('12-09-2009', 'dd-mm-yyyy'), 3, 5997, to_date('14-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411007300, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 7, 4020, to_date('25-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100729007301, to_date('29-07-2010', 'dd-mm-yyyy'), to_date('12-08-2010', 'dd-mm-yyyy'), 1, 5561, to_date('14-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100408007302, to_date('08-04-2010', 'dd-mm-yyyy'), to_date('22-04-2010', 'dd-mm-yyyy'), 3, 6125, to_date('24-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813007303, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 12, 8434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100131007304, to_date('31-01-2010', 'dd-mm-yyyy'), to_date('14-02-2010', 'dd-mm-yyyy'), 10, 6607, to_date('07-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081209007305, to_date('09-12-2008', 'dd-mm-yyyy'), to_date('23-12-2008', 'dd-mm-yyyy'), 9, 5210, to_date('20-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000430007306, to_date('30-04-2000', 'dd-mm-yyyy'), to_date('14-05-2000', 'dd-mm-yyyy'), 3, 965, to_date('10-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140226007307, to_date('26-02-2014', 'dd-mm-yyyy'), to_date('12-03-2014', 'dd-mm-yyyy'), 4, 7333, to_date('15-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304007308, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 9, 7745, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101226007309, to_date('26-12-2010', 'dd-mm-yyyy'), to_date('09-01-2011', 'dd-mm-yyyy'), 8, 7803, to_date('08-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001020007310, to_date('20-10-2000', 'dd-mm-yyyy'), to_date('03-11-2000', 'dd-mm-yyyy'), 10, 2128, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021028007311, to_date('28-10-2002', 'dd-mm-yyyy'), to_date('11-11-2002', 'dd-mm-yyyy'), 7, 1771, to_date('15-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806007312, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 3, 7865, to_date('17-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050426007313, to_date('26-04-2005', 'dd-mm-yyyy'), to_date('10-05-2005', 'dd-mm-yyyy'), 7, 4125, to_date('28-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071029007314, to_date('29-10-2007', 'dd-mm-yyyy'), to_date('12-11-2007', 'dd-mm-yyyy'), 12, 5589, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080424007315, to_date('24-04-2008', 'dd-mm-yyyy'), to_date('08-05-2008', 'dd-mm-yyyy'), 11, 6733, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010705007316, to_date('05-07-2001', 'dd-mm-yyyy'), to_date('19-07-2001', 'dd-mm-yyyy'), 6, 869, to_date('08-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090804007317, to_date('04-08-2009', 'dd-mm-yyyy'), to_date('18-08-2009', 'dd-mm-yyyy'), 4, 6132, to_date('12-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061023007318, to_date('23-10-2006', 'dd-mm-yyyy'), to_date('06-11-2006', 'dd-mm-yyyy'), 1, 4397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010112007319, to_date('12-01-2001', 'dd-mm-yyyy'), to_date('26-01-2001', 'dd-mm-yyyy'), 6, 1254, to_date('28-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060719007320, to_date('19-07-2006', 'dd-mm-yyyy'), to_date('02-08-2006', 'dd-mm-yyyy'), 8, 4161, to_date('01-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411007321, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 4, 6983, to_date('22-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629007322, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 8, 2802, to_date('18-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000217007323, to_date('17-02-2000', 'dd-mm-yyyy'), to_date('02-03-2000', 'dd-mm-yyyy'), 9, 2359, to_date('06-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080523007324, to_date('23-05-2008', 'dd-mm-yyyy'), to_date('06-06-2008', 'dd-mm-yyyy'), 6, 6657, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070201007325, to_date('01-02-2007', 'dd-mm-yyyy'), to_date('15-02-2007', 'dd-mm-yyyy'), 7, 5444, to_date('21-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225007326, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 10, 8227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510007327, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 4, 2128, to_date('20-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060612007328, to_date('12-06-2006', 'dd-mm-yyyy'), to_date('26-06-2006', 'dd-mm-yyyy'), 4, 3396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110201007329, to_date('01-02-2011', 'dd-mm-yyyy'), to_date('15-02-2011', 'dd-mm-yyyy'), 5, 5433, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101206007330, to_date('06-12-2010', 'dd-mm-yyyy'), to_date('20-12-2010', 'dd-mm-yyyy'), 9, 8418, to_date('16-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110918007331, to_date('18-09-2011', 'dd-mm-yyyy'), to_date('02-10-2011', 'dd-mm-yyyy'), 8, 7613, to_date('05-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090103007332, to_date('03-01-2009', 'dd-mm-yyyy'), to_date('17-01-2009', 'dd-mm-yyyy'), 6, 6361, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080111007333, to_date('11-01-2008', 'dd-mm-yyyy'), to_date('25-01-2008', 'dd-mm-yyyy'), 3, 4571, to_date('30-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100810007334, to_date('10-08-2010', 'dd-mm-yyyy'), to_date('24-08-2010', 'dd-mm-yyyy'), 11, 8112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603007335, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 2, 4628, to_date('12-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040202007336, to_date('02-02-2004', 'dd-mm-yyyy'), to_date('16-02-2004', 'dd-mm-yyyy'), 4, 4273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723007337, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 6, 2368, to_date('30-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050803007338, to_date('03-08-2005', 'dd-mm-yyyy'), to_date('17-08-2005', 'dd-mm-yyyy'), 5, 5807, to_date('11-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030611007339, to_date('11-06-2003', 'dd-mm-yyyy'), to_date('25-06-2003', 'dd-mm-yyyy'), 4, 3229, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416007340, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 5, 4593, to_date('22-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707007341, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 7, 4895, to_date('11-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221007342, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 11, 2085, to_date('26-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081127007343, to_date('27-11-2008', 'dd-mm-yyyy'), to_date('11-12-2008', 'dd-mm-yyyy'), 9, 6099, to_date('12-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110120007344, to_date('20-01-2011', 'dd-mm-yyyy'), to_date('03-02-2011', 'dd-mm-yyyy'), 7, 7057, to_date('06-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070910000307, to_date('10-09-2007', 'dd-mm-yyyy'), to_date('24-09-2007', 'dd-mm-yyyy'), 10, 4135, to_date('13-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618000308, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 10, 9693, to_date('01-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040201000309, to_date('01-02-2004', 'dd-mm-yyyy'), to_date('15-02-2004', 'dd-mm-yyyy'), 11, 3024, to_date('03-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020223000310, to_date('23-02-2002', 'dd-mm-yyyy'), to_date('09-03-2002', 'dd-mm-yyyy'), 4, 4733, to_date('02-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030102000311, to_date('02-01-2003', 'dd-mm-yyyy'), to_date('16-01-2003', 'dd-mm-yyyy'), 11, 2398, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040803000312, to_date('03-08-2004', 'dd-mm-yyyy'), to_date('17-08-2004', 'dd-mm-yyyy'), 4, 5406, to_date('12-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406000313, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 12, 8468, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100720000314, to_date('20-07-2010', 'dd-mm-yyyy'), to_date('03-08-2010', 'dd-mm-yyyy'), 3, 8982, to_date('27-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100814000315, to_date('14-08-2010', 'dd-mm-yyyy'), to_date('28-08-2010', 'dd-mm-yyyy'), 4, 5209, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040118000316, to_date('18-01-2004', 'dd-mm-yyyy'), to_date('01-02-2004', 'dd-mm-yyyy'), 8, 3528, to_date('01-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130528000317, to_date('28-05-2013', 'dd-mm-yyyy'), to_date('11-06-2013', 'dd-mm-yyyy'), 11, 8526, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130000318, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 7, 3757, to_date('04-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101010000319, to_date('10-10-2010', 'dd-mm-yyyy'), to_date('24-10-2010', 'dd-mm-yyyy'), 2, 8611, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080320000320, to_date('20-03-2008', 'dd-mm-yyyy'), to_date('03-04-2008', 'dd-mm-yyyy'), 9, 4846, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100201000321, to_date('01-02-2010', 'dd-mm-yyyy'), to_date('15-02-2010', 'dd-mm-yyyy'), 8, 7525, to_date('07-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050721000322, to_date('21-07-2005', 'dd-mm-yyyy'), to_date('04-08-2005', 'dd-mm-yyyy'), 8, 4792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825000323, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 2, 10234, to_date('06-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020116000324, to_date('16-01-2002', 'dd-mm-yyyy'), to_date('30-01-2002', 'dd-mm-yyyy'), 1, 1784, to_date('28-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030316000325, to_date('16-03-2003', 'dd-mm-yyyy'), to_date('30-03-2003', 'dd-mm-yyyy'), 11, 4904, to_date('24-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010908000326, to_date('08-09-2001', 'dd-mm-yyyy'), to_date('22-09-2001', 'dd-mm-yyyy'), 4, 2565, to_date('26-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140321000327, to_date('21-03-2014', 'dd-mm-yyyy'), to_date('04-04-2014', 'dd-mm-yyyy'), 10, 9427, to_date('01-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000922000328, to_date('22-09-2000', 'dd-mm-yyyy'), to_date('06-10-2000', 'dd-mm-yyyy'), 11, 1654, to_date('30-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060823000329, to_date('23-08-2006', 'dd-mm-yyyy'), to_date('06-09-2006', 'dd-mm-yyyy'), 12, 4583, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020912000330, to_date('12-09-2002', 'dd-mm-yyyy'), to_date('26-09-2002', 'dd-mm-yyyy'), 5, 3169, to_date('02-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923000331, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 4, 6617, to_date('12-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010428000332, to_date('28-04-2001', 'dd-mm-yyyy'), to_date('12-05-2001', 'dd-mm-yyyy'), 4, 2127, to_date('06-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006000333, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 5, 7981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060103000334, to_date('03-01-2006', 'dd-mm-yyyy'), to_date('17-01-2006', 'dd-mm-yyyy'), 2, 1503, to_date('08-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121209000335, to_date('09-12-2012', 'dd-mm-yyyy'), to_date('23-12-2012', 'dd-mm-yyyy'), 5, 6963, to_date('17-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230000336, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 5, 1834, to_date('08-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011123000337, to_date('23-11-2001', 'dd-mm-yyyy'), to_date('07-12-2001', 'dd-mm-yyyy'), 9, 1575, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050806000338, to_date('06-08-2005', 'dd-mm-yyyy'), to_date('20-08-2005', 'dd-mm-yyyy'), 9, 5512, to_date('19-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130930000339, to_date('30-09-2013', 'dd-mm-yyyy'), to_date('14-10-2013', 'dd-mm-yyyy'), 9, 10943, to_date('11-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080226000340, to_date('26-02-2008', 'dd-mm-yyyy'), to_date('11-03-2008', 'dd-mm-yyyy'), 10, 7109, to_date('16-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070902000341, to_date('02-09-2007', 'dd-mm-yyyy'), to_date('16-09-2007', 'dd-mm-yyyy'), 5, 5816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060905000342, to_date('05-09-2006', 'dd-mm-yyyy'), to_date('19-09-2006', 'dd-mm-yyyy'), 11, 5664, to_date('06-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120507000343, to_date('07-05-2012', 'dd-mm-yyyy'), to_date('21-05-2012', 'dd-mm-yyyy'), 6, 6435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303000344, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 6, 8284, to_date('18-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060802000345, to_date('02-08-2006', 'dd-mm-yyyy'), to_date('16-08-2006', 'dd-mm-yyyy'), 11, 5705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050523000346, to_date('23-05-2005', 'dd-mm-yyyy'), to_date('06-06-2005', 'dd-mm-yyyy'), 10, 5318, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051105000347, to_date('05-11-2005', 'dd-mm-yyyy'), to_date('19-11-2005', 'dd-mm-yyyy'), 5, 2364, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620000348, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 9, 4822, to_date('30-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031204000349, to_date('04-12-2003', 'dd-mm-yyyy'), to_date('18-12-2003', 'dd-mm-yyyy'), 5, 4107, to_date('24-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121006000350, to_date('06-10-2012', 'dd-mm-yyyy'), to_date('20-10-2012', 'dd-mm-yyyy'), 2, 10379, to_date('24-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120720000351, to_date('20-07-2012', 'dd-mm-yyyy'), to_date('03-08-2012', 'dd-mm-yyyy'), 10, 7063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928000352, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 7, 6571, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140108000353, to_date('08-01-2014', 'dd-mm-yyyy'), to_date('22-01-2014', 'dd-mm-yyyy'), 7, 9393, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010206000354, to_date('06-02-2001', 'dd-mm-yyyy'), to_date('20-02-2001', 'dd-mm-yyyy'), 3, 2799, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071018000355, to_date('18-10-2007', 'dd-mm-yyyy'), to_date('01-11-2007', 'dd-mm-yyyy'), 12, 8178, to_date('20-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729000356, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 11, 9031, to_date('07-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091027000357, to_date('27-10-2009', 'dd-mm-yyyy'), to_date('10-11-2009', 'dd-mm-yyyy'), 9, 6230, to_date('14-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100123000358, to_date('23-01-2010', 'dd-mm-yyyy'), to_date('06-02-2010', 'dd-mm-yyyy'), 11, 9978, to_date('10-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906000359, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 2, 6389, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070203000360, to_date('03-02-2007', 'dd-mm-yyyy'), to_date('17-02-2007', 'dd-mm-yyyy'), 2, 4560, to_date('07-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040618000361, to_date('18-06-2004', 'dd-mm-yyyy'), to_date('02-07-2004', 'dd-mm-yyyy'), 10, 4618, to_date('05-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080722000362, to_date('22-07-2008', 'dd-mm-yyyy'), to_date('05-08-2008', 'dd-mm-yyyy'), 9, 5328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091216000363, to_date('16-12-2009', 'dd-mm-yyyy'), to_date('30-12-2009', 'dd-mm-yyyy'), 3, 6231, to_date('30-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070717000364, to_date('17-07-2007', 'dd-mm-yyyy'), to_date('31-07-2007', 'dd-mm-yyyy'), 4, 4772, to_date('23-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050221000365, to_date('21-02-2005', 'dd-mm-yyyy'), to_date('07-03-2005', 'dd-mm-yyyy'), 7, 4864, to_date('23-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030912000366, to_date('12-09-2003', 'dd-mm-yyyy'), to_date('26-09-2003', 'dd-mm-yyyy'), 3, 5871, to_date('28-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000121000367, to_date('21-01-2000', 'dd-mm-yyyy'), to_date('04-02-2000', 'dd-mm-yyyy'), 1, 1780, to_date('24-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060303000368, to_date('03-03-2006', 'dd-mm-yyyy'), to_date('17-03-2006', 'dd-mm-yyyy'), 5, 7593, to_date('13-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018000369, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 2, 2801, to_date('24-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040322000370, to_date('22-03-2004', 'dd-mm-yyyy'), to_date('05-04-2004', 'dd-mm-yyyy'), 7, 3120, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090827000371, to_date('27-08-2009', 'dd-mm-yyyy'), to_date('10-09-2009', 'dd-mm-yyyy'), 1, 5737, to_date('28-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070617000372, to_date('17-06-2007', 'dd-mm-yyyy'), to_date('01-07-2007', 'dd-mm-yyyy'), 10, 3374, to_date('23-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020319000373, to_date('19-03-2002', 'dd-mm-yyyy'), to_date('02-04-2002', 'dd-mm-yyyy'), 5, 3359, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522000374, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 5, 2201, to_date('27-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020821000375, to_date('21-08-2002', 'dd-mm-yyyy'), to_date('04-09-2002', 'dd-mm-yyyy'), 2, 2837, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100911000376, to_date('11-09-2010', 'dd-mm-yyyy'), to_date('25-09-2010', 'dd-mm-yyyy'), 1, 5947, to_date('27-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410000377, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 7, 3567, to_date('24-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040723000378, to_date('23-07-2004', 'dd-mm-yyyy'), to_date('06-08-2004', 'dd-mm-yyyy'), 3, 3917, to_date('27-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070421000379, to_date('21-04-2007', 'dd-mm-yyyy'), to_date('05-05-2007', 'dd-mm-yyyy'), 6, 5320, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129000380, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 9, 7796, to_date('17-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061112000381, to_date('12-11-2006', 'dd-mm-yyyy'), to_date('26-11-2006', 'dd-mm-yyyy'), 12, 3783, to_date('24-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060216000382, to_date('16-02-2006', 'dd-mm-yyyy'), to_date('02-03-2006', 'dd-mm-yyyy'), 6, 4846, to_date('26-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040221000383, to_date('21-02-2004', 'dd-mm-yyyy'), to_date('06-03-2004', 'dd-mm-yyyy'), 12, 2272, to_date('10-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817000384, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 8, 7732, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091030000385, to_date('30-10-2009', 'dd-mm-yyyy'), to_date('13-11-2009', 'dd-mm-yyyy'), 5, 6792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130307000386, to_date('07-03-2013', 'dd-mm-yyyy'), to_date('21-03-2013', 'dd-mm-yyyy'), 3, 6510, to_date('09-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130214000387, to_date('14-02-2013', 'dd-mm-yyyy'), to_date('28-02-2013', 'dd-mm-yyyy'), 6, 7096, to_date('01-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080802000388, to_date('02-08-2008', 'dd-mm-yyyy'), to_date('16-08-2008', 'dd-mm-yyyy'), 9, 5281, to_date('16-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090913000389, to_date('13-09-2009', 'dd-mm-yyyy'), to_date('27-09-2009', 'dd-mm-yyyy'), 6, 6121, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130827000390, to_date('27-08-2013', 'dd-mm-yyyy'), to_date('10-09-2013', 'dd-mm-yyyy'), 4, 7919, to_date('09-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130430000391, to_date('30-04-2013', 'dd-mm-yyyy'), to_date('14-05-2013', 'dd-mm-yyyy'), 10, 7265, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317000392, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 8, 8117, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220000393, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 11, 7064, to_date('26-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213000394, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 10, 2298, to_date('21-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070812000395, to_date('12-08-2007', 'dd-mm-yyyy'), to_date('26-08-2007', 'dd-mm-yyyy'), 5, 4118, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070205000396, to_date('05-02-2007', 'dd-mm-yyyy'), to_date('19-02-2007', 'dd-mm-yyyy'), 8, 5935, to_date('12-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010415000397, to_date('15-04-2001', 'dd-mm-yyyy'), to_date('29-04-2001', 'dd-mm-yyyy'), 11, 2073, to_date('25-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090504000398, to_date('04-05-2009', 'dd-mm-yyyy'), to_date('18-05-2009', 'dd-mm-yyyy'), 6, 6961, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001000399, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 2, 5640, to_date('07-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121027000400, to_date('27-10-2012', 'dd-mm-yyyy'), to_date('10-11-2012', 'dd-mm-yyyy'), 8, 5526, to_date('16-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812000401, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 1, 11091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010104000402, to_date('04-01-2001', 'dd-mm-yyyy'), to_date('18-01-2001', 'dd-mm-yyyy'), 9, 2117, to_date('18-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070321000403, to_date('21-03-2007', 'dd-mm-yyyy'), to_date('04-04-2007', 'dd-mm-yyyy'), 5, 6108, to_date('07-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100315000404, to_date('15-03-2010', 'dd-mm-yyyy'), to_date('29-03-2010', 'dd-mm-yyyy'), 9, 6190, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708000405, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 10, 6226, to_date('10-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030204000406, to_date('04-02-2003', 'dd-mm-yyyy'), to_date('18-02-2003', 'dd-mm-yyyy'), 4, 1754, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060903000407, to_date('03-09-2006', 'dd-mm-yyyy'), to_date('17-09-2006', 'dd-mm-yyyy'), 10, 5782, to_date('05-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020724000408, to_date('24-07-2002', 'dd-mm-yyyy'), to_date('07-08-2002', 'dd-mm-yyyy'), 2, 2561, to_date('01-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030730000409, to_date('30-07-2003', 'dd-mm-yyyy'), to_date('13-08-2003', 'dd-mm-yyyy'), 10, 4485, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021109000410, to_date('09-11-2002', 'dd-mm-yyyy'), to_date('23-11-2002', 'dd-mm-yyyy'), 11, 2936, to_date('22-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228000411, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 10, 6022, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040627000412, to_date('27-06-2004', 'dd-mm-yyyy'), to_date('11-07-2004', 'dd-mm-yyyy'), 12, 4598, to_date('01-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100505000413, to_date('05-05-2010', 'dd-mm-yyyy'), to_date('19-05-2010', 'dd-mm-yyyy'), 4, 8083, to_date('23-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307000414, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 11, 4390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010717000415, to_date('17-07-2001', 'dd-mm-yyyy'), to_date('31-07-2001', 'dd-mm-yyyy'), 1, 3706, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060612000416, to_date('12-06-2006', 'dd-mm-yyyy'), to_date('26-06-2006', 'dd-mm-yyyy'), 11, 6522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101212000417, to_date('12-12-2010', 'dd-mm-yyyy'), to_date('26-12-2010', 'dd-mm-yyyy'), 8, 6100, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091215000418, to_date('15-12-2009', 'dd-mm-yyyy'), to_date('29-12-2009', 'dd-mm-yyyy'), 3, 7902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110727000419, to_date('27-07-2011', 'dd-mm-yyyy'), to_date('10-08-2011', 'dd-mm-yyyy'), 4, 5370, to_date('31-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120713000420, to_date('13-07-2012', 'dd-mm-yyyy'), to_date('27-07-2012', 'dd-mm-yyyy'), 1, 6548, to_date('27-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041024000421, to_date('24-10-2004', 'dd-mm-yyyy'), to_date('07-11-2004', 'dd-mm-yyyy'), 10, 3436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121230000422, to_date('30-12-2012', 'dd-mm-yyyy'), to_date('13-01-2013', 'dd-mm-yyyy'), 5, 8295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101212000423, to_date('12-12-2010', 'dd-mm-yyyy'), to_date('26-12-2010', 'dd-mm-yyyy'), 7, 7043, to_date('15-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004000424, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 4, 6691, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617000425, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 7, 1299, to_date('04-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116000426, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 3, 10351, to_date('25-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040229000427, to_date('29-02-2004', 'dd-mm-yyyy'), to_date('14-03-2004', 'dd-mm-yyyy'), 2, 3153, to_date('07-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119000428, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 8, 3145, to_date('30-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130702000429, to_date('02-07-2013', 'dd-mm-yyyy'), to_date('16-07-2013', 'dd-mm-yyyy'), 11, 8414, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030604000430, to_date('04-06-2003', 'dd-mm-yyyy'), to_date('18-06-2003', 'dd-mm-yyyy'), 2, 2013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060121000431, to_date('21-01-2006', 'dd-mm-yyyy'), to_date('04-02-2006', 'dd-mm-yyyy'), 9, 4728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040721000432, to_date('21-07-2004', 'dd-mm-yyyy'), to_date('04-08-2004', 'dd-mm-yyyy'), 9, 2474, to_date('09-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120719000433, to_date('19-07-2012', 'dd-mm-yyyy'), to_date('02-08-2012', 'dd-mm-yyyy'), 3, 5718, to_date('24-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202000434, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 4, 7437, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050313000435, to_date('13-03-2005', 'dd-mm-yyyy'), to_date('27-03-2005', 'dd-mm-yyyy'), 7, 4904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050905000436, to_date('05-09-2005', 'dd-mm-yyyy'), to_date('19-09-2005', 'dd-mm-yyyy'), 9, 3818, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061114000437, to_date('14-11-2006', 'dd-mm-yyyy'), to_date('28-11-2006', 'dd-mm-yyyy'), 5, 5971, to_date('29-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111226000438, to_date('26-12-2011', 'dd-mm-yyyy'), to_date('09-01-2012', 'dd-mm-yyyy'), 6, 7431, to_date('31-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040626000439, to_date('26-06-2004', 'dd-mm-yyyy'), to_date('10-07-2004', 'dd-mm-yyyy'), 4, 2740, to_date('16-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040227000440, to_date('27-02-2004', 'dd-mm-yyyy'), to_date('12-03-2004', 'dd-mm-yyyy'), 3, 3686, to_date('06-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031228000441, to_date('28-12-2003', 'dd-mm-yyyy'), to_date('11-01-2004', 'dd-mm-yyyy'), 8, 3519, to_date('08-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816000442, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 2, 6340, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090317000443, to_date('17-03-2009', 'dd-mm-yyyy'), to_date('31-03-2009', 'dd-mm-yyyy'), 9, 8785, to_date('31-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130000444, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 3, 2863, to_date('12-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070828000445, to_date('28-08-2007', 'dd-mm-yyyy'), to_date('11-09-2007', 'dd-mm-yyyy'), 7, 5257, to_date('01-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020114000446, to_date('14-01-2002', 'dd-mm-yyyy'), to_date('28-01-2002', 'dd-mm-yyyy'), 6, 2677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215000447, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 10, 4584, to_date('19-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011024000448, to_date('24-10-2001', 'dd-mm-yyyy'), to_date('07-11-2001', 'dd-mm-yyyy'), 8, 3174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130909000449, to_date('09-09-2013', 'dd-mm-yyyy'), to_date('23-09-2013', 'dd-mm-yyyy'), 2, 7430, to_date('26-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020729000450, to_date('29-07-2002', 'dd-mm-yyyy'), to_date('12-08-2002', 'dd-mm-yyyy'), 8, 3351, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071220000451, to_date('20-12-2007', 'dd-mm-yyyy'), to_date('03-01-2008', 'dd-mm-yyyy'), 9, 4183, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728000452, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 10, 8592, to_date('30-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060909000453, to_date('09-09-2006', 'dd-mm-yyyy'), to_date('23-09-2006', 'dd-mm-yyyy'), 6, 5999, to_date('14-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080512000454, to_date('12-05-2008', 'dd-mm-yyyy'), to_date('26-05-2008', 'dd-mm-yyyy'), 2, 3582, to_date('21-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101220000455, to_date('20-12-2010', 'dd-mm-yyyy'), to_date('03-01-2011', 'dd-mm-yyyy'), 11, 7564, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625000456, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 4, 2402, to_date('05-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020622000457, to_date('22-06-2002', 'dd-mm-yyyy'), to_date('06-07-2002', 'dd-mm-yyyy'), 1, 4370, to_date('26-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090603000458, to_date('03-06-2009', 'dd-mm-yyyy'), to_date('17-06-2009', 'dd-mm-yyyy'), 12, 8327, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130715000459, to_date('15-07-2013', 'dd-mm-yyyy'), to_date('29-07-2013', 'dd-mm-yyyy'), 11, 7943, to_date('18-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522000460, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 6, 8468, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403002604, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 3, 4793, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060213002605, to_date('13-02-2006', 'dd-mm-yyyy'), to_date('27-02-2006', 'dd-mm-yyyy'), 2, 5834, to_date('22-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216002606, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 7, 2328, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020620002607, to_date('20-06-2002', 'dd-mm-yyyy'), to_date('04-07-2002', 'dd-mm-yyyy'), 7, 2394, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080801002608, to_date('01-08-2008', 'dd-mm-yyyy'), to_date('15-08-2008', 'dd-mm-yyyy'), 1, 6764, to_date('13-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080611002609, to_date('11-06-2008', 'dd-mm-yyyy'), to_date('25-06-2008', 'dd-mm-yyyy'), 7, 5445, to_date('27-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020111002610, to_date('11-01-2002', 'dd-mm-yyyy'), to_date('25-01-2002', 'dd-mm-yyyy'), 5, 2043, to_date('20-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030612002611, to_date('12-06-2003', 'dd-mm-yyyy'), to_date('26-06-2003', 'dd-mm-yyyy'), 3, 4190, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526002612, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 12, 9753, to_date('02-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227002613, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 5, 6964, to_date('08-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822002614, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 10, 8046, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030122002615, to_date('22-01-2003', 'dd-mm-yyyy'), to_date('05-02-2003', 'dd-mm-yyyy'), 8, 3796, to_date('24-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050924002616, to_date('24-09-2005', 'dd-mm-yyyy'), to_date('08-10-2005', 'dd-mm-yyyy'), 9, 4081, to_date('26-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090623002617, to_date('23-06-2009', 'dd-mm-yyyy'), to_date('07-07-2009', 'dd-mm-yyyy'), 12, 7743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080317002618, to_date('17-03-2008', 'dd-mm-yyyy'), to_date('31-03-2008', 'dd-mm-yyyy'), 5, 6392, to_date('27-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040916002619, to_date('16-09-2004', 'dd-mm-yyyy'), to_date('30-09-2004', 'dd-mm-yyyy'), 8, 2880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525002620, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 7, 7271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080816002621, to_date('16-08-2008', 'dd-mm-yyyy'), to_date('30-08-2008', 'dd-mm-yyyy'), 1, 5916, to_date('20-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040321002622, to_date('21-03-2004', 'dd-mm-yyyy'), to_date('04-04-2004', 'dd-mm-yyyy'), 4, 3359, to_date('29-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050418002623, to_date('18-04-2005', 'dd-mm-yyyy'), to_date('02-05-2005', 'dd-mm-yyyy'), 7, 5643, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101112002624, to_date('12-11-2010', 'dd-mm-yyyy'), to_date('26-11-2010', 'dd-mm-yyyy'), 12, 7876, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130002625, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 7, 8026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000815002626, to_date('15-08-2000', 'dd-mm-yyyy'), to_date('29-08-2000', 'dd-mm-yyyy'), 1, 2715, to_date('03-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040328002627, to_date('28-03-2004', 'dd-mm-yyyy'), to_date('11-04-2004', 'dd-mm-yyyy'), 4, 4135, to_date('12-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110712002628, to_date('12-07-2011', 'dd-mm-yyyy'), to_date('26-07-2011', 'dd-mm-yyyy'), 7, 5658, to_date('17-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100805002629, to_date('05-08-2010', 'dd-mm-yyyy'), to_date('19-08-2010', 'dd-mm-yyyy'), 2, 8366, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126002630, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 9, 6460, to_date('11-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020413002631, to_date('13-04-2002', 'dd-mm-yyyy'), to_date('27-04-2002', 'dd-mm-yyyy'), 8, 3993, to_date('26-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000325002632, to_date('25-03-2000', 'dd-mm-yyyy'), to_date('08-04-2000', 'dd-mm-yyyy'), 5, 709, to_date('08-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010909002633, to_date('09-09-2001', 'dd-mm-yyyy'), to_date('23-09-2001', 'dd-mm-yyyy'), 2, 2353, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100812002634, to_date('12-08-2010', 'dd-mm-yyyy'), to_date('26-08-2010', 'dd-mm-yyyy'), 4, 5376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000314002635, to_date('14-03-2000', 'dd-mm-yyyy'), to_date('28-03-2000', 'dd-mm-yyyy'), 5, 2368, to_date('26-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926002636, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 12, 3997, to_date('09-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515002637, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 1, 2068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711002638, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 9, 8839, to_date('27-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112002639, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 9, 8830, to_date('18-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131027002640, to_date('27-10-2013', 'dd-mm-yyyy'), to_date('10-11-2013', 'dd-mm-yyyy'), 7, 9855, to_date('03-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121016002641, to_date('16-10-2012', 'dd-mm-yyyy'), to_date('30-10-2012', 'dd-mm-yyyy'), 11, 7395, to_date('29-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140130002642, to_date('30-01-2014', 'dd-mm-yyyy'), to_date('13-02-2014', 'dd-mm-yyyy'), 8, 7777, to_date('03-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100701002643, to_date('01-07-2010', 'dd-mm-yyyy'), to_date('15-07-2010', 'dd-mm-yyyy'), 11, 7913, to_date('14-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080727002644, to_date('27-07-2008', 'dd-mm-yyyy'), to_date('10-08-2008', 'dd-mm-yyyy'), 7, 6985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090804002645, to_date('04-08-2009', 'dd-mm-yyyy'), to_date('18-08-2009', 'dd-mm-yyyy'), 7, 7401, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703002646, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 6, 1200, to_date('19-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010226002647, to_date('26-02-2001', 'dd-mm-yyyy'), to_date('12-03-2001', 'dd-mm-yyyy'), 3, 1462, to_date('04-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802002648, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 3, 7228, to_date('13-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050111002649, to_date('11-01-2005', 'dd-mm-yyyy'), to_date('25-01-2005', 'dd-mm-yyyy'), 8, 3318, to_date('22-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001201002650, to_date('01-12-2000', 'dd-mm-yyyy'), to_date('15-12-2000', 'dd-mm-yyyy'), 1, 1039, to_date('02-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726002651, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 3, 8128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010115002652, to_date('15-01-2001', 'dd-mm-yyyy'), to_date('29-01-2001', 'dd-mm-yyyy'), 3, 3099, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100606002653, to_date('06-06-2010', 'dd-mm-yyyy'), to_date('20-06-2010', 'dd-mm-yyyy'), 5, 6414, to_date('11-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050827002654, to_date('27-08-2005', 'dd-mm-yyyy'), to_date('10-09-2005', 'dd-mm-yyyy'), 9, 7746, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009002655, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 8, 802, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010324002656, to_date('24-03-2001', 'dd-mm-yyyy'), to_date('07-04-2001', 'dd-mm-yyyy'), 2, 2138, to_date('29-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801002657, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 2, 2489, to_date('04-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011227002658, to_date('27-12-2001', 'dd-mm-yyyy'), to_date('10-01-2002', 'dd-mm-yyyy'), 6, 1346, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101206002659, to_date('06-12-2010', 'dd-mm-yyyy'), to_date('20-12-2010', 'dd-mm-yyyy'), 8, 7662, to_date('12-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823002660, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 12, 9444, to_date('31-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101017002661, to_date('17-10-2010', 'dd-mm-yyyy'), to_date('31-10-2010', 'dd-mm-yyyy'), 3, 6853, to_date('05-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130107002662, to_date('07-01-2013', 'dd-mm-yyyy'), to_date('21-01-2013', 'dd-mm-yyyy'), 2, 8823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060617002663, to_date('17-06-2006', 'dd-mm-yyyy'), to_date('01-07-2006', 'dd-mm-yyyy'), 5, 5413, to_date('22-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319002664, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 8, 4814, to_date('05-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061026002665, to_date('26-10-2006', 'dd-mm-yyyy'), to_date('09-11-2006', 'dd-mm-yyyy'), 11, 6006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418002666, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 2, 8306, to_date('28-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061205002667, to_date('05-12-2006', 'dd-mm-yyyy'), to_date('19-12-2006', 'dd-mm-yyyy'), 3, 3627, to_date('23-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031129002668, to_date('29-11-2003', 'dd-mm-yyyy'), to_date('13-12-2003', 'dd-mm-yyyy'), 5, 4051, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212002669, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 2, 2809, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030608002670, to_date('08-06-2003', 'dd-mm-yyyy'), to_date('22-06-2003', 'dd-mm-yyyy'), 7, 3050, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070610002671, to_date('10-06-2007', 'dd-mm-yyyy'), to_date('24-06-2007', 'dd-mm-yyyy'), 7, 6354, to_date('17-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023002672, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 7, 6032, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121128002673, to_date('28-11-2012', 'dd-mm-yyyy'), to_date('12-12-2012', 'dd-mm-yyyy'), 1, 7914, to_date('08-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406002674, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 9, 8255, to_date('26-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041020002675, to_date('20-10-2004', 'dd-mm-yyyy'), to_date('03-11-2004', 'dd-mm-yyyy'), 8, 3411, to_date('30-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113002676, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 3, 3190, to_date('02-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040531002677, to_date('31-05-2004', 'dd-mm-yyyy'), to_date('14-06-2004', 'dd-mm-yyyy'), 6, 4068, to_date('04-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330002678, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 11, 7893, to_date('03-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020219002679, to_date('19-02-2002', 'dd-mm-yyyy'), to_date('05-03-2002', 'dd-mm-yyyy'), 7, 1900, to_date('21-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060107002680, to_date('07-01-2006', 'dd-mm-yyyy'), to_date('21-01-2006', 'dd-mm-yyyy'), 12, 2440, to_date('21-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040511002681, to_date('11-05-2004', 'dd-mm-yyyy'), to_date('25-05-2004', 'dd-mm-yyyy'), 6, 4019, to_date('28-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624002682, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 2, 2376, to_date('09-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702002683, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 1, 4483, to_date('13-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001212002684, to_date('12-12-2000', 'dd-mm-yyyy'), to_date('26-12-2000', 'dd-mm-yyyy'), 12, 2354, to_date('29-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010904002685, to_date('04-09-2001', 'dd-mm-yyyy'), to_date('18-09-2001', 'dd-mm-yyyy'), 12, 1515, to_date('20-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328002686, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 4, 3248, to_date('05-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100926002687, to_date('26-09-2010', 'dd-mm-yyyy'), to_date('10-10-2010', 'dd-mm-yyyy'), 7, 6314, to_date('08-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921002688, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 5, 8529, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110428002689, to_date('28-04-2011', 'dd-mm-yyyy'), to_date('12-05-2011', 'dd-mm-yyyy'), 8, 7868, to_date('04-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100315002690, to_date('15-03-2010', 'dd-mm-yyyy'), to_date('29-03-2010', 'dd-mm-yyyy'), 4, 3563, to_date('20-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041108002691, to_date('08-11-2004', 'dd-mm-yyyy'), to_date('22-11-2004', 'dd-mm-yyyy'), 5, 5031, to_date('17-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090929002692, to_date('29-09-2009', 'dd-mm-yyyy'), to_date('13-10-2009', 'dd-mm-yyyy'), 9, 6266, to_date('03-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131102002693, to_date('02-11-2013', 'dd-mm-yyyy'), to_date('16-11-2013', 'dd-mm-yyyy'), 2, 9176, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129002694, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 5, 6734, to_date('17-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331002695, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 4, 6932, to_date('18-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130111002696, to_date('11-01-2013', 'dd-mm-yyyy'), to_date('25-01-2013', 'dd-mm-yyyy'), 6, 8200, to_date('27-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827002697, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 11, 3828, to_date('30-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515002698, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 7, 7569, to_date('26-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060117002699, to_date('17-01-2006', 'dd-mm-yyyy'), to_date('31-01-2006', 'dd-mm-yyyy'), 2, 3775, to_date('26-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010529002700, to_date('29-05-2001', 'dd-mm-yyyy'), to_date('12-06-2001', 'dd-mm-yyyy'), 4, 1832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100624002701, to_date('24-06-2010', 'dd-mm-yyyy'), to_date('08-07-2010', 'dd-mm-yyyy'), 12, 4370, to_date('27-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070318002702, to_date('18-03-2007', 'dd-mm-yyyy'), to_date('01-04-2007', 'dd-mm-yyyy'), 6, 6944, to_date('23-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100130002703, to_date('30-01-2010', 'dd-mm-yyyy'), to_date('13-02-2010', 'dd-mm-yyyy'), 3, 8116, to_date('04-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060209002704, to_date('09-02-2006', 'dd-mm-yyyy'), to_date('23-02-2006', 'dd-mm-yyyy'), 6, 4055, to_date('17-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100901002705, to_date('01-09-2010', 'dd-mm-yyyy'), to_date('15-09-2010', 'dd-mm-yyyy'), 11, 9627, to_date('10-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100731002706, to_date('31-07-2010', 'dd-mm-yyyy'), to_date('14-08-2010', 'dd-mm-yyyy'), 7, 7606, to_date('03-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110412002707, to_date('12-04-2011', 'dd-mm-yyyy'), to_date('26-04-2011', 'dd-mm-yyyy'), 1, 8339, to_date('19-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010703002708, to_date('03-07-2001', 'dd-mm-yyyy'), to_date('17-07-2001', 'dd-mm-yyyy'), 4, 1391, to_date('08-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100904002709, to_date('04-09-2010', 'dd-mm-yyyy'), to_date('18-09-2010', 'dd-mm-yyyy'), 7, 7950, to_date('07-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100615002710, to_date('15-06-2010', 'dd-mm-yyyy'), to_date('29-06-2010', 'dd-mm-yyyy'), 4, 8795, to_date('05-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140131002711, to_date('31-01-2014', 'dd-mm-yyyy'), to_date('14-02-2014', 'dd-mm-yyyy'), 10, 8132, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921002712, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 2, 1265, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071112002713, to_date('12-11-2007', 'dd-mm-yyyy'), to_date('26-11-2007', 'dd-mm-yyyy'), 2, 5268, to_date('14-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010311002714, to_date('11-03-2001', 'dd-mm-yyyy'), to_date('25-03-2001', 'dd-mm-yyyy'), 4, 3244, to_date('14-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224002715, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 1, 6213, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001119002716, to_date('19-11-2000', 'dd-mm-yyyy'), to_date('03-12-2000', 'dd-mm-yyyy'), 8, 1120, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140120002717, to_date('20-01-2014', 'dd-mm-yyyy'), to_date('03-02-2014', 'dd-mm-yyyy'), 2, 9769, to_date('05-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110513002718, to_date('13-05-2011', 'dd-mm-yyyy'), to_date('27-05-2011', 'dd-mm-yyyy'), 5, 10033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010204002719, to_date('04-02-2001', 'dd-mm-yyyy'), to_date('18-02-2001', 'dd-mm-yyyy'), 5, 4055, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227002720, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 3, 8441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512002721, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 3, 3318, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130901002722, to_date('01-09-2013', 'dd-mm-yyyy'), to_date('15-09-2013', 'dd-mm-yyyy'), 4, 10429, to_date('12-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606002723, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 5, 3134, to_date('20-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081209002724, to_date('09-12-2008', 'dd-mm-yyyy'), to_date('23-12-2008', 'dd-mm-yyyy'), 10, 4832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080818002725, to_date('18-08-2008', 'dd-mm-yyyy'), to_date('01-09-2008', 'dd-mm-yyyy'), 2, 5036, to_date('05-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609002726, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 10, 7435, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504002727, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 10, 8177, to_date('18-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101213002728, to_date('13-12-2010', 'dd-mm-yyyy'), to_date('27-12-2010', 'dd-mm-yyyy'), 10, 7002, to_date('28-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130811002729, to_date('11-08-2013', 'dd-mm-yyyy'), to_date('25-08-2013', 'dd-mm-yyyy'), 6, 8100, to_date('22-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001003002730, to_date('03-10-2000', 'dd-mm-yyyy'), to_date('17-10-2000', 'dd-mm-yyyy'), 12, 462, to_date('23-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080611002731, to_date('11-06-2008', 'dd-mm-yyyy'), to_date('25-06-2008', 'dd-mm-yyyy'), 5, 6276, to_date('27-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051116002732, to_date('16-11-2005', 'dd-mm-yyyy'), to_date('30-11-2005', 'dd-mm-yyyy'), 6, 3703, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041125002733, to_date('25-11-2004', 'dd-mm-yyyy'), to_date('09-12-2004', 'dd-mm-yyyy'), 5, 4468, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070605002734, to_date('05-06-2007', 'dd-mm-yyyy'), to_date('19-06-2007', 'dd-mm-yyyy'), 8, 6574, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111111002735, to_date('11-11-2011', 'dd-mm-yyyy'), to_date('25-11-2011', 'dd-mm-yyyy'), 11, 8438, to_date('14-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051224002736, to_date('24-12-2005', 'dd-mm-yyyy'), to_date('07-01-2006', 'dd-mm-yyyy'), 1, 4847, to_date('07-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000109002737, to_date('09-01-2000', 'dd-mm-yyyy'), to_date('23-01-2000', 'dd-mm-yyyy'), 11, 1008, to_date('15-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311002738, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 8, 8550, to_date('20-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120915002739, to_date('15-09-2012', 'dd-mm-yyyy'), to_date('29-09-2012', 'dd-mm-yyyy'), 2, 9648, to_date('25-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010612002740, to_date('12-06-2001', 'dd-mm-yyyy'), to_date('26-06-2001', 'dd-mm-yyyy'), 11, 4264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060531002741, to_date('31-05-2006', 'dd-mm-yyyy'), to_date('14-06-2006', 'dd-mm-yyyy'), 8, 6048, to_date('04-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011029002742, to_date('29-10-2001', 'dd-mm-yyyy'), to_date('12-11-2001', 'dd-mm-yyyy'), 6, 1686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030414002743, to_date('14-04-2003', 'dd-mm-yyyy'), to_date('28-04-2003', 'dd-mm-yyyy'), 3, 2858, to_date('28-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031212002744, to_date('12-12-2003', 'dd-mm-yyyy'), to_date('26-12-2003', 'dd-mm-yyyy'), 10, 3324, to_date('28-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090424002745, to_date('24-04-2009', 'dd-mm-yyyy'), to_date('08-05-2009', 'dd-mm-yyyy'), 3, 6217, to_date('27-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021214002746, to_date('14-12-2002', 'dd-mm-yyyy'), to_date('28-12-2002', 'dd-mm-yyyy'), 2, 3245, to_date('18-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100617002747, to_date('17-06-2010', 'dd-mm-yyyy'), to_date('01-07-2010', 'dd-mm-yyyy'), 9, 6724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060913002748, to_date('13-09-2006', 'dd-mm-yyyy'), to_date('27-09-2006', 'dd-mm-yyyy'), 3, 4410, to_date('21-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030707002749, to_date('07-07-2003', 'dd-mm-yyyy'), to_date('21-07-2003', 'dd-mm-yyyy'), 3, 2528, to_date('25-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010928002750, to_date('28-09-2001', 'dd-mm-yyyy'), to_date('12-10-2001', 'dd-mm-yyyy'), 2, 3602, to_date('04-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060906002751, to_date('06-09-2006', 'dd-mm-yyyy'), to_date('20-09-2006', 'dd-mm-yyyy'), 1, 3364, to_date('25-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130426002752, to_date('26-04-2013', 'dd-mm-yyyy'), to_date('10-05-2013', 'dd-mm-yyyy'), 8, 7737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080515002753, to_date('15-05-2008', 'dd-mm-yyyy'), to_date('29-05-2008', 'dd-mm-yyyy'), 11, 7361, to_date('30-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021012002754, to_date('12-10-2002', 'dd-mm-yyyy'), to_date('26-10-2002', 'dd-mm-yyyy'), 8, 2378, to_date('23-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527002755, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 2, 5211, to_date('31-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120730002756, to_date('30-07-2012', 'dd-mm-yyyy'), to_date('13-08-2012', 'dd-mm-yyyy'), 6, 5745, to_date('14-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060905005052, to_date('05-09-2006', 'dd-mm-yyyy'), to_date('19-09-2006', 'dd-mm-yyyy'), 10, 4085, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208005053, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 5, 4947, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051206005054, to_date('06-12-2005', 'dd-mm-yyyy'), to_date('20-12-2005', 'dd-mm-yyyy'), 4, 2795, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010513005055, to_date('13-05-2001', 'dd-mm-yyyy'), to_date('27-05-2001', 'dd-mm-yyyy'), 6, 3485, to_date('15-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030510005056, to_date('10-05-2003', 'dd-mm-yyyy'), to_date('24-05-2003', 'dd-mm-yyyy'), 6, 2937, to_date('19-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011216005057, to_date('16-12-2001', 'dd-mm-yyyy'), to_date('30-12-2001', 'dd-mm-yyyy'), 3, 2052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060928005058, to_date('28-09-2006', 'dd-mm-yyyy'), to_date('12-10-2006', 'dd-mm-yyyy'), 5, 6101, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001227005059, to_date('27-12-2000', 'dd-mm-yyyy'), to_date('10-01-2001', 'dd-mm-yyyy'), 2, 2937, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000304005060, to_date('04-03-2000', 'dd-mm-yyyy'), to_date('18-03-2000', 'dd-mm-yyyy'), 5, 1686, to_date('05-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040329005061, to_date('29-03-2004', 'dd-mm-yyyy'), to_date('12-04-2004', 'dd-mm-yyyy'), 6, 3736, to_date('10-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226005062, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 2, 5894, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010209005063, to_date('09-02-2001', 'dd-mm-yyyy'), to_date('23-02-2001', 'dd-mm-yyyy'), 11, 2270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010415005064, to_date('15-04-2001', 'dd-mm-yyyy'), to_date('29-04-2001', 'dd-mm-yyyy'), 9, 1296, to_date('17-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120621005065, to_date('21-06-2012', 'dd-mm-yyyy'), to_date('05-07-2012', 'dd-mm-yyyy'), 2, 11525, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020430005066, to_date('30-04-2002', 'dd-mm-yyyy'), to_date('14-05-2002', 'dd-mm-yyyy'), 4, 1699, to_date('09-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000607005067, to_date('07-06-2000', 'dd-mm-yyyy'), to_date('21-06-2000', 'dd-mm-yyyy'), 3, 3102, to_date('11-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081125005068, to_date('25-11-2008', 'dd-mm-yyyy'), to_date('09-12-2008', 'dd-mm-yyyy'), 7, 5874, to_date('13-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020903005069, to_date('03-09-2002', 'dd-mm-yyyy'), to_date('17-09-2002', 'dd-mm-yyyy'), 7, 3983, to_date('14-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120215005070, to_date('15-02-2012', 'dd-mm-yyyy'), to_date('29-02-2012', 'dd-mm-yyyy'), 5, 6524, to_date('29-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090803005071, to_date('03-08-2009', 'dd-mm-yyyy'), to_date('17-08-2009', 'dd-mm-yyyy'), 5, 6096, to_date('19-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010101005072, to_date('01-01-2001', 'dd-mm-yyyy'), to_date('15-01-2001', 'dd-mm-yyyy'), 7, 3049, to_date('15-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070502005073, to_date('02-05-2007', 'dd-mm-yyyy'), to_date('16-05-2007', 'dd-mm-yyyy'), 9, 4392, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010131005074, to_date('31-01-2001', 'dd-mm-yyyy'), to_date('14-02-2001', 'dd-mm-yyyy'), 11, 3623, to_date('04-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050113005075, to_date('13-01-2005', 'dd-mm-yyyy'), to_date('27-01-2005', 'dd-mm-yyyy'), 2, 6208, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020616005076, to_date('16-06-2002', 'dd-mm-yyyy'), to_date('30-06-2002', 'dd-mm-yyyy'), 2, 3119, to_date('20-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050612005077, to_date('12-06-2005', 'dd-mm-yyyy'), to_date('26-06-2005', 'dd-mm-yyyy'), 8, 3777, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090627005078, to_date('27-06-2009', 'dd-mm-yyyy'), to_date('11-07-2009', 'dd-mm-yyyy'), 6, 6989, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100312005079, to_date('12-03-2010', 'dd-mm-yyyy'), to_date('26-03-2010', 'dd-mm-yyyy'), 7, 6445, to_date('16-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070125005080, to_date('25-01-2007', 'dd-mm-yyyy'), to_date('08-02-2007', 'dd-mm-yyyy'), 7, 6012, to_date('31-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020704005081, to_date('04-07-2002', 'dd-mm-yyyy'), to_date('18-07-2002', 'dd-mm-yyyy'), 2, 1654, to_date('15-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090402005082, to_date('02-04-2009', 'dd-mm-yyyy'), to_date('16-04-2009', 'dd-mm-yyyy'), 9, 8213, to_date('17-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100505005083, to_date('05-05-2010', 'dd-mm-yyyy'), to_date('19-05-2010', 'dd-mm-yyyy'), 2, 6227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030225005084, to_date('25-02-2003', 'dd-mm-yyyy'), to_date('11-03-2003', 'dd-mm-yyyy'), 2, 5093, to_date('12-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130804005085, to_date('04-08-2013', 'dd-mm-yyyy'), to_date('18-08-2013', 'dd-mm-yyyy'), 5, 9758, to_date('18-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213005086, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 12, 2017, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080402005087, to_date('02-04-2008', 'dd-mm-yyyy'), to_date('16-04-2008', 'dd-mm-yyyy'), 7, 5281, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060617005088, to_date('17-06-2006', 'dd-mm-yyyy'), to_date('01-07-2006', 'dd-mm-yyyy'), 3, 3497, to_date('01-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070327005089, to_date('27-03-2007', 'dd-mm-yyyy'), to_date('10-04-2007', 'dd-mm-yyyy'), 2, 7109, to_date('09-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031218005090, to_date('18-12-2003', 'dd-mm-yyyy'), to_date('01-01-2004', 'dd-mm-yyyy'), 10, 1951, to_date('25-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121201005091, to_date('01-12-2012', 'dd-mm-yyyy'), to_date('15-12-2012', 'dd-mm-yyyy'), 12, 8488, to_date('07-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131109005092, to_date('09-11-2013', 'dd-mm-yyyy'), to_date('23-11-2013', 'dd-mm-yyyy'), 11, 8694, to_date('14-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050804005093, to_date('04-08-2005', 'dd-mm-yyyy'), to_date('18-08-2005', 'dd-mm-yyyy'), 9, 6718, to_date('08-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040605005094, to_date('05-06-2004', 'dd-mm-yyyy'), to_date('19-06-2004', 'dd-mm-yyyy'), 4, 4436, to_date('20-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100903005095, to_date('03-09-2010', 'dd-mm-yyyy'), to_date('17-09-2010', 'dd-mm-yyyy'), 8, 5972, to_date('12-09-2010', 'dd-mm-yyyy'));
commit;
prompt 8000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518005096, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 7, 8051, to_date('30-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111005097, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 12, 6129, to_date('20-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722005098, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 4, 2118, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101225005099, to_date('25-12-2010', 'dd-mm-yyyy'), to_date('08-01-2011', 'dd-mm-yyyy'), 2, 5178, to_date('10-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120317005100, to_date('17-03-2012', 'dd-mm-yyyy'), to_date('31-03-2012', 'dd-mm-yyyy'), 10, 9026, to_date('30-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110630005101, to_date('30-06-2011', 'dd-mm-yyyy'), to_date('14-07-2011', 'dd-mm-yyyy'), 7, 6856, to_date('20-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908005102, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 8, 4076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902005103, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 8, 3925, to_date('10-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140122005104, to_date('22-01-2014', 'dd-mm-yyyy'), to_date('05-02-2014', 'dd-mm-yyyy'), 3, 9717, to_date('25-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409005105, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 1, 6087, to_date('29-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424005106, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 6, 7322, to_date('09-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226005107, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 3, 5357, to_date('04-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040507005108, to_date('07-05-2004', 'dd-mm-yyyy'), to_date('21-05-2004', 'dd-mm-yyyy'), 12, 2937, to_date('19-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110130005109, to_date('30-01-2011', 'dd-mm-yyyy'), to_date('13-02-2011', 'dd-mm-yyyy'), 2, 5305, to_date('13-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130330005110, to_date('30-03-2013', 'dd-mm-yyyy'), to_date('13-04-2013', 'dd-mm-yyyy'), 7, 7828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916005111, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 5, 7738, to_date('17-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091120005112, to_date('20-11-2009', 'dd-mm-yyyy'), to_date('04-12-2009', 'dd-mm-yyyy'), 5, 4607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060829005113, to_date('29-08-2006', 'dd-mm-yyyy'), to_date('12-09-2006', 'dd-mm-yyyy'), 6, 6739, to_date('12-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510005114, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 6, 7891, to_date('18-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008005115, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 10, 6263, to_date('15-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208005116, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 5, 2320, to_date('13-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030125005117, to_date('25-01-2003', 'dd-mm-yyyy'), to_date('08-02-2003', 'dd-mm-yyyy'), 12, 4340, to_date('29-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522005118, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 5, 5932, to_date('01-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504005119, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 7, 578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123005120, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 3, 2423, to_date('09-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080610005121, to_date('10-06-2008', 'dd-mm-yyyy'), to_date('24-06-2008', 'dd-mm-yyyy'), 11, 5222, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030521005122, to_date('21-05-2003', 'dd-mm-yyyy'), to_date('04-06-2003', 'dd-mm-yyyy'), 10, 3652, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081102005123, to_date('02-11-2008', 'dd-mm-yyyy'), to_date('16-11-2008', 'dd-mm-yyyy'), 5, 6999, to_date('08-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629005124, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 9, 4259, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511005125, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 5, 3042, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105005126, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 3, 5327, to_date('17-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013005127, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 3, 2121, to_date('18-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111130005128, to_date('30-11-2011', 'dd-mm-yyyy'), to_date('14-12-2011', 'dd-mm-yyyy'), 10, 8723, to_date('10-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030322005129, to_date('22-03-2003', 'dd-mm-yyyy'), to_date('05-04-2003', 'dd-mm-yyyy'), 11, 4925, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000818005130, to_date('18-08-2000', 'dd-mm-yyyy'), to_date('01-09-2000', 'dd-mm-yyyy'), 8, 2422, to_date('21-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815005131, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 12, 5837, to_date('25-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050217005132, to_date('17-02-2005', 'dd-mm-yyyy'), to_date('03-03-2005', 'dd-mm-yyyy'), 4, 3256, to_date('07-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091229005133, to_date('29-12-2009', 'dd-mm-yyyy'), to_date('12-01-2010', 'dd-mm-yyyy'), 8, 5690, to_date('13-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080922005134, to_date('22-09-2008', 'dd-mm-yyyy'), to_date('06-10-2008', 'dd-mm-yyyy'), 12, 5258, to_date('10-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090417005135, to_date('17-04-2009', 'dd-mm-yyyy'), to_date('01-05-2009', 'dd-mm-yyyy'), 8, 8520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070206005136, to_date('06-02-2007', 'dd-mm-yyyy'), to_date('20-02-2007', 'dd-mm-yyyy'), 3, 4725, to_date('22-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006005137, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 5, 3401, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050619005138, to_date('19-06-2005', 'dd-mm-yyyy'), to_date('03-07-2005', 'dd-mm-yyyy'), 12, 4730, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603005139, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 4, 3490, to_date('09-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131112005140, to_date('12-11-2013', 'dd-mm-yyyy'), to_date('26-11-2013', 'dd-mm-yyyy'), 9, 8122, to_date('02-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111115005141, to_date('15-11-2011', 'dd-mm-yyyy'), to_date('29-11-2011', 'dd-mm-yyyy'), 9, 7394, to_date('19-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050605005142, to_date('05-06-2005', 'dd-mm-yyyy'), to_date('19-06-2005', 'dd-mm-yyyy'), 12, 5252, to_date('14-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130104005143, to_date('04-01-2013', 'dd-mm-yyyy'), to_date('18-01-2013', 'dd-mm-yyyy'), 9, 8777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070924005144, to_date('24-09-2007', 'dd-mm-yyyy'), to_date('08-10-2007', 'dd-mm-yyyy'), 3, 5507, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318005145, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 8, 8540, to_date('07-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010413005146, to_date('13-04-2001', 'dd-mm-yyyy'), to_date('27-04-2001', 'dd-mm-yyyy'), 10, 2636, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051020005147, to_date('20-10-2005', 'dd-mm-yyyy'), to_date('03-11-2005', 'dd-mm-yyyy'), 10, 6661, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090625005148, to_date('25-06-2009', 'dd-mm-yyyy'), to_date('09-07-2009', 'dd-mm-yyyy'), 2, 5296, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050608005149, to_date('08-06-2005', 'dd-mm-yyyy'), to_date('22-06-2005', 'dd-mm-yyyy'), 3, 4923, to_date('21-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090817005150, to_date('17-08-2009', 'dd-mm-yyyy'), to_date('31-08-2009', 'dd-mm-yyyy'), 11, 6426, to_date('23-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040614005151, to_date('14-06-2004', 'dd-mm-yyyy'), to_date('28-06-2004', 'dd-mm-yyyy'), 9, 5469, to_date('27-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051226005152, to_date('26-12-2005', 'dd-mm-yyyy'), to_date('09-01-2006', 'dd-mm-yyyy'), 1, 6079, to_date('11-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120912005153, to_date('12-09-2012', 'dd-mm-yyyy'), to_date('26-09-2012', 'dd-mm-yyyy'), 3, 7976, to_date('20-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050419005154, to_date('19-04-2005', 'dd-mm-yyyy'), to_date('03-05-2005', 'dd-mm-yyyy'), 2, 4678, to_date('26-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060516005155, to_date('16-05-2006', 'dd-mm-yyyy'), to_date('30-05-2006', 'dd-mm-yyyy'), 9, 5369, to_date('23-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030129005156, to_date('29-01-2003', 'dd-mm-yyyy'), to_date('12-02-2003', 'dd-mm-yyyy'), 8, 3289, to_date('10-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070108005157, to_date('08-01-2007', 'dd-mm-yyyy'), to_date('22-01-2007', 'dd-mm-yyyy'), 5, 5631, to_date('11-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051104005158, to_date('04-11-2005', 'dd-mm-yyyy'), to_date('18-11-2005', 'dd-mm-yyyy'), 11, 5191, to_date('17-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813005159, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 10, 9194, to_date('16-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010608005160, to_date('08-06-2001', 'dd-mm-yyyy'), to_date('22-06-2001', 'dd-mm-yyyy'), 7, 1680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000316005161, to_date('16-03-2000', 'dd-mm-yyyy'), to_date('30-03-2000', 'dd-mm-yyyy'), 2, 2038, to_date('02-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131129005162, to_date('29-11-2013', 'dd-mm-yyyy'), to_date('13-12-2013', 'dd-mm-yyyy'), 2, 6906, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000503005163, to_date('03-05-2000', 'dd-mm-yyyy'), to_date('17-05-2000', 'dd-mm-yyyy'), 6, 1975, to_date('12-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050921005164, to_date('21-09-2005', 'dd-mm-yyyy'), to_date('05-10-2005', 'dd-mm-yyyy'), 6, 5340, to_date('28-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010126005165, to_date('26-01-2001', 'dd-mm-yyyy'), to_date('09-02-2001', 'dd-mm-yyyy'), 4, 2887, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507005166, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 4, 2208, to_date('21-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010630005167, to_date('30-06-2001', 'dd-mm-yyyy'), to_date('14-07-2001', 'dd-mm-yyyy'), 2, 2972, to_date('18-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060906005168, to_date('06-09-2006', 'dd-mm-yyyy'), to_date('20-09-2006', 'dd-mm-yyyy'), 5, 6054, to_date('11-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010808005169, to_date('08-08-2001', 'dd-mm-yyyy'), to_date('22-08-2001', 'dd-mm-yyyy'), 3, 3038, to_date('19-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519005170, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 4, 3575, to_date('06-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110326005171, to_date('26-03-2011', 'dd-mm-yyyy'), to_date('09-04-2011', 'dd-mm-yyyy'), 10, 6270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815005172, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 3, 2660, to_date('31-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140223005173, to_date('23-02-2014', 'dd-mm-yyyy'), to_date('09-03-2014', 'dd-mm-yyyy'), 9, 7652, to_date('10-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080220005174, to_date('20-02-2008', 'dd-mm-yyyy'), to_date('05-03-2008', 'dd-mm-yyyy'), 11, 6888, to_date('09-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030819005175, to_date('19-08-2003', 'dd-mm-yyyy'), to_date('02-09-2003', 'dd-mm-yyyy'), 2, 3640, to_date('30-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023005176, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 8, 3442, to_date('28-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120916005177, to_date('16-09-2012', 'dd-mm-yyyy'), to_date('30-09-2012', 'dd-mm-yyyy'), 10, 8427, to_date('22-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041114005178, to_date('14-11-2004', 'dd-mm-yyyy'), to_date('28-11-2004', 'dd-mm-yyyy'), 8, 2674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521005179, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 4, 3226, to_date('26-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522005180, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 7, 7933, to_date('04-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030802005181, to_date('02-08-2003', 'dd-mm-yyyy'), to_date('16-08-2003', 'dd-mm-yyyy'), 11, 4943, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091230005182, to_date('30-12-2009', 'dd-mm-yyyy'), to_date('13-01-2010', 'dd-mm-yyyy'), 4, 7153, to_date('06-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071110005183, to_date('10-11-2007', 'dd-mm-yyyy'), to_date('24-11-2007', 'dd-mm-yyyy'), 6, 5091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070818005184, to_date('18-08-2007', 'dd-mm-yyyy'), to_date('01-09-2007', 'dd-mm-yyyy'), 2, 3668, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000215005185, to_date('15-02-2000', 'dd-mm-yyyy'), to_date('29-02-2000', 'dd-mm-yyyy'), 10, 1025, to_date('20-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090121005186, to_date('21-01-2009', 'dd-mm-yyyy'), to_date('04-02-2009', 'dd-mm-yyyy'), 5, 6608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111209005187, to_date('09-12-2011', 'dd-mm-yyyy'), to_date('23-12-2011', 'dd-mm-yyyy'), 4, 8378, to_date('26-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831005188, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 6, 6253, to_date('17-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103005189, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 9, 4383, to_date('12-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030901005190, to_date('01-09-2003', 'dd-mm-yyyy'), to_date('15-09-2003', 'dd-mm-yyyy'), 3, 2901, to_date('18-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060103005191, to_date('03-01-2006', 'dd-mm-yyyy'), to_date('17-01-2006', 'dd-mm-yyyy'), 1, 4728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040622005192, to_date('22-06-2004', 'dd-mm-yyyy'), to_date('06-07-2004', 'dd-mm-yyyy'), 7, 3114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050710005193, to_date('10-07-2005', 'dd-mm-yyyy'), to_date('24-07-2005', 'dd-mm-yyyy'), 3, 4980, to_date('15-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512005194, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 8, 4011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021108005195, to_date('08-11-2002', 'dd-mm-yyyy'), to_date('22-11-2002', 'dd-mm-yyyy'), 11, 1782, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628005196, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 3, 7643, to_date('15-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050809005197, to_date('09-08-2005', 'dd-mm-yyyy'), to_date('23-08-2005', 'dd-mm-yyyy'), 3, 5225, to_date('12-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411005198, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 5, 6236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822005199, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 10, 6840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071030005200, to_date('30-10-2007', 'dd-mm-yyyy'), to_date('13-11-2007', 'dd-mm-yyyy'), 4, 9510, to_date('18-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020228005201, to_date('28-02-2002', 'dd-mm-yyyy'), to_date('14-03-2002', 'dd-mm-yyyy'), 6, 3158, to_date('06-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071117005202, to_date('17-11-2007', 'dd-mm-yyyy'), to_date('01-12-2007', 'dd-mm-yyyy'), 9, 6020, to_date('05-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060924005203, to_date('24-09-2006', 'dd-mm-yyyy'), to_date('08-10-2006', 'dd-mm-yyyy'), 6, 3869, to_date('03-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060617007345, to_date('17-06-2006', 'dd-mm-yyyy'), to_date('01-07-2006', 'dd-mm-yyyy'), 8, 5158, to_date('30-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030917007346, to_date('17-09-2003', 'dd-mm-yyyy'), to_date('01-10-2003', 'dd-mm-yyyy'), 4, 5386, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110207007347, to_date('07-02-2011', 'dd-mm-yyyy'), to_date('21-02-2011', 'dd-mm-yyyy'), 2, 5415, to_date('11-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605007348, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 10, 1195, to_date('18-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041210007349, to_date('10-12-2004', 'dd-mm-yyyy'), to_date('24-12-2004', 'dd-mm-yyyy'), 2, 3273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503007350, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 6, 4043, to_date('17-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131120007351, to_date('20-11-2013', 'dd-mm-yyyy'), to_date('04-12-2013', 'dd-mm-yyyy'), 7, 10116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131219007352, to_date('19-12-2013', 'dd-mm-yyyy'), to_date('02-01-2014', 'dd-mm-yyyy'), 8, 8975, to_date('27-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213007353, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 8, 7112, to_date('19-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101104007354, to_date('04-11-2010', 'dd-mm-yyyy'), to_date('18-11-2010', 'dd-mm-yyyy'), 2, 8182, to_date('20-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621007355, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 5, 2635, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917007356, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 10, 6254, to_date('19-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080828007357, to_date('28-08-2008', 'dd-mm-yyyy'), to_date('11-09-2008', 'dd-mm-yyyy'), 5, 4814, to_date('02-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110007358, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 5, 3846, to_date('19-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061005007359, to_date('05-10-2006', 'dd-mm-yyyy'), to_date('19-10-2006', 'dd-mm-yyyy'), 1, 6148, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130729007360, to_date('29-07-2013', 'dd-mm-yyyy'), to_date('12-08-2013', 'dd-mm-yyyy'), 5, 9482, to_date('31-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319007361, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 3, 4554, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719007362, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 1, 3018, to_date('06-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000124007363, to_date('24-01-2000', 'dd-mm-yyyy'), to_date('07-02-2000', 'dd-mm-yyyy'), 10, 2225, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110319007364, to_date('19-03-2011', 'dd-mm-yyyy'), to_date('02-04-2011', 'dd-mm-yyyy'), 7, 7785, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218007365, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 10, 5140, to_date('21-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917007366, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 7, 8472, to_date('02-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030804007367, to_date('04-08-2003', 'dd-mm-yyyy'), to_date('18-08-2003', 'dd-mm-yyyy'), 8, 2981, to_date('12-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020518007368, to_date('18-05-2002', 'dd-mm-yyyy'), to_date('01-06-2002', 'dd-mm-yyyy'), 9, 3505, to_date('25-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104007369, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 4, 4245, to_date('23-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102007370, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 8, 3244, to_date('10-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129007371, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 7, 9849, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000329007372, to_date('29-03-2000', 'dd-mm-yyyy'), to_date('12-04-2000', 'dd-mm-yyyy'), 11, 3163, to_date('31-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010622007373, to_date('22-06-2001', 'dd-mm-yyyy'), to_date('06-07-2001', 'dd-mm-yyyy'), 9, 2646, to_date('06-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080913007374, to_date('13-09-2008', 'dd-mm-yyyy'), to_date('27-09-2008', 'dd-mm-yyyy'), 4, 5183, to_date('19-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100523007375, to_date('23-05-2010', 'dd-mm-yyyy'), to_date('06-06-2010', 'dd-mm-yyyy'), 6, 9324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301007376, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 7, 3056, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121206007377, to_date('06-12-2012', 'dd-mm-yyyy'), to_date('20-12-2012', 'dd-mm-yyyy'), 7, 11385, to_date('20-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060806007378, to_date('06-08-2006', 'dd-mm-yyyy'), to_date('20-08-2006', 'dd-mm-yyyy'), 3, 3323, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091019007379, to_date('19-10-2009', 'dd-mm-yyyy'), to_date('02-11-2009', 'dd-mm-yyyy'), 10, 6618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080723007380, to_date('23-07-2008', 'dd-mm-yyyy'), to_date('06-08-2008', 'dd-mm-yyyy'), 6, 3567, to_date('11-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090208007381, to_date('08-02-2009', 'dd-mm-yyyy'), to_date('22-02-2009', 'dd-mm-yyyy'), 7, 7652, to_date('28-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130219007382, to_date('19-02-2013', 'dd-mm-yyyy'), to_date('05-03-2013', 'dd-mm-yyyy'), 1, 7381, to_date('06-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060703007383, to_date('03-07-2006', 'dd-mm-yyyy'), to_date('17-07-2006', 'dd-mm-yyyy'), 11, 4237, to_date('23-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802007384, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 9, 10727, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070115007385, to_date('15-01-2007', 'dd-mm-yyyy'), to_date('29-01-2007', 'dd-mm-yyyy'), 5, 2673, to_date('28-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070420007386, to_date('20-04-2007', 'dd-mm-yyyy'), to_date('04-05-2007', 'dd-mm-yyyy'), 8, 4445, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004007387, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 12, 7105, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090728007388, to_date('28-07-2009', 'dd-mm-yyyy'), to_date('11-08-2009', 'dd-mm-yyyy'), 3, 6697, to_date('31-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001209007389, to_date('09-12-2000', 'dd-mm-yyyy'), to_date('23-12-2000', 'dd-mm-yyyy'), 11, 2158, to_date('11-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111209007390, to_date('09-12-2011', 'dd-mm-yyyy'), to_date('23-12-2011', 'dd-mm-yyyy'), 12, 7032, to_date('17-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140121007391, to_date('21-01-2014', 'dd-mm-yyyy'), to_date('04-02-2014', 'dd-mm-yyyy'), 3, 7179, to_date('30-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090923007392, to_date('23-09-2009', 'dd-mm-yyyy'), to_date('07-10-2009', 'dd-mm-yyyy'), 3, 7010, to_date('01-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130521007393, to_date('21-05-2013', 'dd-mm-yyyy'), to_date('04-06-2013', 'dd-mm-yyyy'), 8, 5711, to_date('24-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070626007394, to_date('26-06-2007', 'dd-mm-yyyy'), to_date('10-07-2007', 'dd-mm-yyyy'), 5, 4893, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050629007395, to_date('29-06-2005', 'dd-mm-yyyy'), to_date('13-07-2005', 'dd-mm-yyyy'), 5, 3522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120315007396, to_date('15-03-2012', 'dd-mm-yyyy'), to_date('29-03-2012', 'dd-mm-yyyy'), 9, 6536, to_date('28-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060401007397, to_date('01-04-2006', 'dd-mm-yyyy'), to_date('15-04-2006', 'dd-mm-yyyy'), 2, 4133, to_date('21-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090306007398, to_date('06-03-2009', 'dd-mm-yyyy'), to_date('20-03-2009', 'dd-mm-yyyy'), 11, 5833, to_date('12-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127007399, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 10, 7017, to_date('08-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108007400, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 8, 8620, to_date('27-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140122007401, to_date('22-01-2014', 'dd-mm-yyyy'), to_date('05-02-2014', 'dd-mm-yyyy'), 2, 9384, to_date('10-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070205007402, to_date('05-02-2007', 'dd-mm-yyyy'), to_date('19-02-2007', 'dd-mm-yyyy'), 3, 4556, to_date('18-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517007403, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 10, 7911, to_date('19-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121023007404, to_date('23-10-2012', 'dd-mm-yyyy'), to_date('06-11-2012', 'dd-mm-yyyy'), 4, 9543, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719007405, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 6, 3204, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020519007406, to_date('19-05-2002', 'dd-mm-yyyy'), to_date('02-06-2002', 'dd-mm-yyyy'), 8, 3454, to_date('27-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050430007407, to_date('30-04-2005', 'dd-mm-yyyy'), to_date('14-05-2005', 'dd-mm-yyyy'), 8, 4884, to_date('09-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703007408, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 5, 3878, to_date('19-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120225007409, to_date('25-02-2012', 'dd-mm-yyyy'), to_date('10-03-2012', 'dd-mm-yyyy'), 6, 5828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060306007410, to_date('06-03-2006', 'dd-mm-yyyy'), to_date('20-03-2006', 'dd-mm-yyyy'), 3, 6839, to_date('19-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117007411, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 5, 11530, to_date('25-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040928007412, to_date('28-09-2004', 'dd-mm-yyyy'), to_date('12-10-2004', 'dd-mm-yyyy'), 3, 3590, to_date('08-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080521007413, to_date('21-05-2008', 'dd-mm-yyyy'), to_date('04-06-2008', 'dd-mm-yyyy'), 4, 8195, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060731007414, to_date('31-07-2006', 'dd-mm-yyyy'), to_date('14-08-2006', 'dd-mm-yyyy'), 4, 4456, to_date('19-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090611007415, to_date('11-06-2009', 'dd-mm-yyyy'), to_date('25-06-2009', 'dd-mm-yyyy'), 4, 5652, to_date('23-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011120007416, to_date('20-11-2001', 'dd-mm-yyyy'), to_date('04-12-2001', 'dd-mm-yyyy'), 5, 994, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091216007417, to_date('16-12-2009', 'dd-mm-yyyy'), to_date('30-12-2009', 'dd-mm-yyyy'), 6, 5026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070810007418, to_date('10-08-2007', 'dd-mm-yyyy'), to_date('24-08-2007', 'dd-mm-yyyy'), 10, 5526, to_date('30-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090804007419, to_date('04-08-2009', 'dd-mm-yyyy'), to_date('18-08-2009', 'dd-mm-yyyy'), 3, 8763, to_date('09-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130930007420, to_date('30-09-2013', 'dd-mm-yyyy'), to_date('14-10-2013', 'dd-mm-yyyy'), 8, 7636, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501007421, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 2, 3142, to_date('10-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131027007422, to_date('27-10-2013', 'dd-mm-yyyy'), to_date('10-11-2013', 'dd-mm-yyyy'), 6, 8637, to_date('03-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110915007423, to_date('15-09-2011', 'dd-mm-yyyy'), to_date('29-09-2011', 'dd-mm-yyyy'), 6, 8403, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090924007424, to_date('24-09-2009', 'dd-mm-yyyy'), to_date('08-10-2009', 'dd-mm-yyyy'), 5, 6628, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090727007425, to_date('27-07-2009', 'dd-mm-yyyy'), to_date('10-08-2009', 'dd-mm-yyyy'), 7, 6976, to_date('14-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210007426, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 3, 2167, to_date('28-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000314007427, to_date('14-03-2000', 'dd-mm-yyyy'), to_date('28-03-2000', 'dd-mm-yyyy'), 4, 985, to_date('01-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040922007428, to_date('22-09-2004', 'dd-mm-yyyy'), to_date('06-10-2004', 'dd-mm-yyyy'), 4, 2952, to_date('03-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713007429, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 8, 10734, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080828007430, to_date('28-08-2008', 'dd-mm-yyyy'), to_date('11-09-2008', 'dd-mm-yyyy'), 11, 6404, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123007431, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 3, 8686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619007432, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 9, 614, to_date('25-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060401007433, to_date('01-04-2006', 'dd-mm-yyyy'), to_date('15-04-2006', 'dd-mm-yyyy'), 8, 5822, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070805007434, to_date('05-08-2007', 'dd-mm-yyyy'), to_date('19-08-2007', 'dd-mm-yyyy'), 10, 5364, to_date('20-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218007435, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 8, 4522, to_date('26-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120731007436, to_date('31-07-2012', 'dd-mm-yyyy'), to_date('14-08-2012', 'dd-mm-yyyy'), 4, 7051, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081118007437, to_date('18-11-2008', 'dd-mm-yyyy'), to_date('02-12-2008', 'dd-mm-yyyy'), 3, 3853, to_date('22-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041108007438, to_date('08-11-2004', 'dd-mm-yyyy'), to_date('22-11-2004', 'dd-mm-yyyy'), 1, 3949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040105007439, to_date('05-01-2004', 'dd-mm-yyyy'), to_date('19-01-2004', 'dd-mm-yyyy'), 5, 4098, to_date('15-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060615007440, to_date('15-06-2006', 'dd-mm-yyyy'), to_date('29-06-2006', 'dd-mm-yyyy'), 8, 4099, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413007441, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 10, 10291, to_date('19-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213007442, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 6, 6937, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020422007443, to_date('22-04-2002', 'dd-mm-yyyy'), to_date('06-05-2002', 'dd-mm-yyyy'), 11, 3913, to_date('30-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011006007444, to_date('06-10-2001', 'dd-mm-yyyy'), to_date('20-10-2001', 'dd-mm-yyyy'), 4, 1559, to_date('24-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130906007445, to_date('06-09-2013', 'dd-mm-yyyy'), to_date('20-09-2013', 'dd-mm-yyyy'), 2, 7810, to_date('20-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120530007446, to_date('30-05-2012', 'dd-mm-yyyy'), to_date('13-06-2012', 'dd-mm-yyyy'), 3, 9362, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140314007447, to_date('14-03-2014', 'dd-mm-yyyy'), to_date('28-03-2014', 'dd-mm-yyyy'), 5, 11387, to_date('20-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061221007448, to_date('21-12-2006', 'dd-mm-yyyy'), to_date('04-01-2007', 'dd-mm-yyyy'), 4, 8537, to_date('05-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121125007449, to_date('25-11-2012', 'dd-mm-yyyy'), to_date('09-12-2012', 'dd-mm-yyyy'), 5, 11620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051020007450, to_date('20-10-2005', 'dd-mm-yyyy'), to_date('03-11-2005', 'dd-mm-yyyy'), 2, 4045, to_date('05-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101114007451, to_date('14-11-2010', 'dd-mm-yyyy'), to_date('28-11-2010', 'dd-mm-yyyy'), 11, 6388, to_date('29-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090611007452, to_date('11-06-2009', 'dd-mm-yyyy'), to_date('25-06-2009', 'dd-mm-yyyy'), 9, 4935, to_date('18-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000614007453, to_date('14-06-2000', 'dd-mm-yyyy'), to_date('28-06-2000', 'dd-mm-yyyy'), 4, 1301, to_date('02-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111007454, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 6, 6250, to_date('25-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071216007455, to_date('16-12-2007', 'dd-mm-yyyy'), to_date('30-12-2007', 'dd-mm-yyyy'), 10, 5290, to_date('18-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040818007456, to_date('18-08-2004', 'dd-mm-yyyy'), to_date('01-09-2004', 'dd-mm-yyyy'), 8, 3471, to_date('05-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030227007457, to_date('27-02-2003', 'dd-mm-yyyy'), to_date('13-03-2003', 'dd-mm-yyyy'), 11, 2217, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120517007458, to_date('17-05-2012', 'dd-mm-yyyy'), to_date('31-05-2012', 'dd-mm-yyyy'), 11, 6739, to_date('28-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100127007459, to_date('27-01-2010', 'dd-mm-yyyy'), to_date('10-02-2010', 'dd-mm-yyyy'), 6, 5094, to_date('29-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001013007460, to_date('13-10-2000', 'dd-mm-yyyy'), to_date('27-10-2000', 'dd-mm-yyyy'), 7, 615, to_date('18-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621007461, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 11, 277, to_date('09-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111024007462, to_date('24-10-2011', 'dd-mm-yyyy'), to_date('07-11-2011', 'dd-mm-yyyy'), 9, 8525, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130410007463, to_date('10-04-2013', 'dd-mm-yyyy'), to_date('24-04-2013', 'dd-mm-yyyy'), 4, 6549, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031029007464, to_date('29-10-2003', 'dd-mm-yyyy'), to_date('12-11-2003', 'dd-mm-yyyy'), 8, 3318, to_date('11-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040702007465, to_date('02-07-2004', 'dd-mm-yyyy'), to_date('16-07-2004', 'dd-mm-yyyy'), 6, 5316, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050929007466, to_date('29-09-2005', 'dd-mm-yyyy'), to_date('13-10-2005', 'dd-mm-yyyy'), 6, 2130, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010216007467, to_date('16-02-2001', 'dd-mm-yyyy'), to_date('02-03-2001', 'dd-mm-yyyy'), 9, 4096, to_date('01-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140315007468, to_date('15-03-2014', 'dd-mm-yyyy'), to_date('29-03-2014', 'dd-mm-yyyy'), 9, 6654, to_date('24-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040914007469, to_date('14-09-2004', 'dd-mm-yyyy'), to_date('28-09-2004', 'dd-mm-yyyy'), 1, 2483, to_date('18-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220007470, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 6, 4596, to_date('25-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906007471, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 5, 8145, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618007472, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 2, 1230, to_date('23-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130129007473, to_date('29-01-2013', 'dd-mm-yyyy'), to_date('12-02-2013', 'dd-mm-yyyy'), 10, 8506, to_date('06-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708007474, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 4, 6108, to_date('22-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130406007475, to_date('06-04-2013', 'dd-mm-yyyy'), to_date('20-04-2013', 'dd-mm-yyyy'), 7, 7843, to_date('14-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525007476, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 9, 8772, to_date('07-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020503007477, to_date('03-05-2002', 'dd-mm-yyyy'), to_date('17-05-2002', 'dd-mm-yyyy'), 11, 2331, to_date('18-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041115007478, to_date('15-11-2004', 'dd-mm-yyyy'), to_date('29-11-2004', 'dd-mm-yyyy'), 10, 2953, to_date('26-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120226007479, to_date('26-02-2012', 'dd-mm-yyyy'), to_date('11-03-2012', 'dd-mm-yyyy'), 8, 7442, to_date('17-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000804007480, to_date('04-08-2000', 'dd-mm-yyyy'), to_date('18-08-2000', 'dd-mm-yyyy'), 12, 2576, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121011007481, to_date('11-10-2012', 'dd-mm-yyyy'), to_date('25-10-2012', 'dd-mm-yyyy'), 7, 7516, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050106007482, to_date('06-01-2005', 'dd-mm-yyyy'), to_date('20-01-2005', 'dd-mm-yyyy'), 7, 6212, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140102007483, to_date('02-01-2014', 'dd-mm-yyyy'), to_date('16-01-2014', 'dd-mm-yyyy'), 2, 10138, to_date('05-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010410007484, to_date('10-04-2001', 'dd-mm-yyyy'), to_date('24-04-2001', 'dd-mm-yyyy'), 10, 4233, to_date('18-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071204007485, to_date('04-12-2007', 'dd-mm-yyyy'), to_date('18-12-2007', 'dd-mm-yyyy'), 4, 5721, to_date('10-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121115007486, to_date('15-11-2012', 'dd-mm-yyyy'), to_date('29-11-2012', 'dd-mm-yyyy'), 3, 6556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060417007487, to_date('17-04-2006', 'dd-mm-yyyy'), to_date('01-05-2006', 'dd-mm-yyyy'), 1, 1967, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130328007488, to_date('28-03-2013', 'dd-mm-yyyy'), to_date('11-04-2013', 'dd-mm-yyyy'), 11, 7757, to_date('01-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030329007489, to_date('29-03-2003', 'dd-mm-yyyy'), to_date('12-04-2003', 'dd-mm-yyyy'), 2, 2573, to_date('15-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070901007490, to_date('01-09-2007', 'dd-mm-yyyy'), to_date('15-09-2007', 'dd-mm-yyyy'), 1, 5245, to_date('05-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080822007491, to_date('22-08-2008', 'dd-mm-yyyy'), to_date('05-09-2008', 'dd-mm-yyyy'), 3, 6381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091201007492, to_date('01-12-2009', 'dd-mm-yyyy'), to_date('15-12-2009', 'dd-mm-yyyy'), 8, 6898, to_date('04-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011006007493, to_date('06-10-2001', 'dd-mm-yyyy'), to_date('20-10-2001', 'dd-mm-yyyy'), 5, 1979, to_date('16-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041027007494, to_date('27-10-2004', 'dd-mm-yyyy'), to_date('10-11-2004', 'dd-mm-yyyy'), 5, 5747, to_date('07-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111126007495, to_date('26-11-2011', 'dd-mm-yyyy'), to_date('10-12-2011', 'dd-mm-yyyy'), 11, 8425, to_date('28-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919007496, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 6, 6874, to_date('28-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110919000461, to_date('19-09-2011', 'dd-mm-yyyy'), to_date('03-10-2011', 'dd-mm-yyyy'), 2, 9283, to_date('04-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618000462, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 5, 7246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030705000463, to_date('05-07-2003', 'dd-mm-yyyy'), to_date('19-07-2003', 'dd-mm-yyyy'), 11, 2839, to_date('23-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030727000464, to_date('27-07-2003', 'dd-mm-yyyy'), to_date('10-08-2003', 'dd-mm-yyyy'), 6, 4696, to_date('10-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203000465, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 6, 4161, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317000466, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 3, 2080, to_date('24-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040831000467, to_date('31-08-2004', 'dd-mm-yyyy'), to_date('14-09-2004', 'dd-mm-yyyy'), 9, 2978, to_date('06-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120820000468, to_date('20-08-2012', 'dd-mm-yyyy'), to_date('03-09-2012', 'dd-mm-yyyy'), 10, 7171, to_date('28-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040705000469, to_date('05-07-2004', 'dd-mm-yyyy'), to_date('19-07-2004', 'dd-mm-yyyy'), 12, 2805, to_date('19-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010529000470, to_date('29-05-2001', 'dd-mm-yyyy'), to_date('12-06-2001', 'dd-mm-yyyy'), 3, 2649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020722000471, to_date('22-07-2002', 'dd-mm-yyyy'), to_date('05-08-2002', 'dd-mm-yyyy'), 10, 3565, to_date('29-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090605000472, to_date('05-06-2009', 'dd-mm-yyyy'), to_date('19-06-2009', 'dd-mm-yyyy'), 5, 5574, to_date('13-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031117000473, to_date('17-11-2003', 'dd-mm-yyyy'), to_date('01-12-2003', 'dd-mm-yyyy'), 10, 4083, to_date('20-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010517000474, to_date('17-05-2001', 'dd-mm-yyyy'), to_date('31-05-2001', 'dd-mm-yyyy'), 3, 2888, to_date('26-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080501000475, to_date('01-05-2008', 'dd-mm-yyyy'), to_date('15-05-2008', 'dd-mm-yyyy'), 12, 6016, to_date('08-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041106000476, to_date('06-11-2004', 'dd-mm-yyyy'), to_date('20-11-2004', 'dd-mm-yyyy'), 9, 5634, to_date('25-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010122000477, to_date('22-01-2001', 'dd-mm-yyyy'), to_date('05-02-2001', 'dd-mm-yyyy'), 9, 1674, to_date('10-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622000478, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 6, 4976, to_date('01-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120623000479, to_date('23-06-2012', 'dd-mm-yyyy'), to_date('07-07-2012', 'dd-mm-yyyy'), 3, 7351, to_date('06-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031211000480, to_date('11-12-2003', 'dd-mm-yyyy'), to_date('25-12-2003', 'dd-mm-yyyy'), 5, 2937, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130311000481, to_date('11-03-2013', 'dd-mm-yyyy'), to_date('25-03-2013', 'dd-mm-yyyy'), 2, 8070, to_date('29-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101208000482, to_date('08-12-2010', 'dd-mm-yyyy'), to_date('22-12-2010', 'dd-mm-yyyy'), 9, 7942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001103000483, to_date('03-11-2000', 'dd-mm-yyyy'), to_date('17-11-2000', 'dd-mm-yyyy'), 11, 471, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011022000484, to_date('22-10-2001', 'dd-mm-yyyy'), to_date('05-11-2001', 'dd-mm-yyyy'), 8, 2946, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041029000485, to_date('29-10-2004', 'dd-mm-yyyy'), to_date('12-11-2004', 'dd-mm-yyyy'), 1, 4848, to_date('07-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126000486, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 5, 5029, to_date('28-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090210000487, to_date('10-02-2009', 'dd-mm-yyyy'), to_date('24-02-2009', 'dd-mm-yyyy'), 9, 6940, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130914000488, to_date('14-09-2013', 'dd-mm-yyyy'), to_date('28-09-2013', 'dd-mm-yyyy'), 8, 9146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518000489, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 7, 7114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010415000490, to_date('15-04-2001', 'dd-mm-yyyy'), to_date('29-04-2001', 'dd-mm-yyyy'), 4, 3133, to_date('22-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101000491, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 5, 4935, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100514000492, to_date('14-05-2010', 'dd-mm-yyyy'), to_date('28-05-2010', 'dd-mm-yyyy'), 3, 6528, to_date('31-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423000493, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 10, 5212, to_date('26-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130916000494, to_date('16-09-2013', 'dd-mm-yyyy'), to_date('30-09-2013', 'dd-mm-yyyy'), 8, 7418, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316000495, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 4, 5229, to_date('26-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020110000496, to_date('10-01-2002', 'dd-mm-yyyy'), to_date('24-01-2002', 'dd-mm-yyyy'), 7, 2779, to_date('12-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010824000497, to_date('24-08-2001', 'dd-mm-yyyy'), to_date('07-09-2001', 'dd-mm-yyyy'), 1, 4194, to_date('06-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110129000498, to_date('29-01-2011', 'dd-mm-yyyy'), to_date('12-02-2011', 'dd-mm-yyyy'), 9, 7980, to_date('11-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010217000499, to_date('17-02-2001', 'dd-mm-yyyy'), to_date('03-03-2001', 'dd-mm-yyyy'), 5, 2705, to_date('01-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050720000500, to_date('20-07-2005', 'dd-mm-yyyy'), to_date('03-08-2005', 'dd-mm-yyyy'), 4, 4691, to_date('07-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621000501, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 1, 1164, to_date('06-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101202000502, to_date('02-12-2010', 'dd-mm-yyyy'), to_date('16-12-2010', 'dd-mm-yyyy'), 5, 9042, to_date('05-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120311000503, to_date('11-03-2012', 'dd-mm-yyyy'), to_date('25-03-2012', 'dd-mm-yyyy'), 8, 9206, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030105000504, to_date('05-01-2003', 'dd-mm-yyyy'), to_date('19-01-2003', 'dd-mm-yyyy'), 5, 2805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101022000505, to_date('22-10-2010', 'dd-mm-yyyy'), to_date('05-11-2010', 'dd-mm-yyyy'), 2, 7701, to_date('09-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050728000506, to_date('28-07-2005', 'dd-mm-yyyy'), to_date('11-08-2005', 'dd-mm-yyyy'), 11, 3635, to_date('11-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120523000507, to_date('23-05-2012', 'dd-mm-yyyy'), to_date('06-06-2012', 'dd-mm-yyyy'), 4, 8728, to_date('29-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060117000508, to_date('17-01-2006', 'dd-mm-yyyy'), to_date('31-01-2006', 'dd-mm-yyyy'), 4, 6248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000327000509, to_date('27-03-2000', 'dd-mm-yyyy'), to_date('10-04-2000', 'dd-mm-yyyy'), 7, 1031, to_date('04-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120524000510, to_date('24-05-2012', 'dd-mm-yyyy'), to_date('07-06-2012', 'dd-mm-yyyy'), 6, 8792, to_date('02-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050523000511, to_date('23-05-2005', 'dd-mm-yyyy'), to_date('06-06-2005', 'dd-mm-yyyy'), 5, 4506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100727000512, to_date('27-07-2010', 'dd-mm-yyyy'), to_date('10-08-2010', 'dd-mm-yyyy'), 11, 8446, to_date('11-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010802000513, to_date('02-08-2001', 'dd-mm-yyyy'), to_date('16-08-2001', 'dd-mm-yyyy'), 2, 2294, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090225000514, to_date('25-02-2009', 'dd-mm-yyyy'), to_date('11-03-2009', 'dd-mm-yyyy'), 9, 5910, to_date('08-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106000515, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 3, 9256, to_date('25-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060925000516, to_date('25-09-2006', 'dd-mm-yyyy'), to_date('09-10-2006', 'dd-mm-yyyy'), 4, 4142, to_date('30-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110830000517, to_date('30-08-2011', 'dd-mm-yyyy'), to_date('13-09-2011', 'dd-mm-yyyy'), 3, 8434, to_date('13-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126000518, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 6, 4952, to_date('11-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725000519, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 12, 2674, to_date('05-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040204000520, to_date('04-02-2004', 'dd-mm-yyyy'), to_date('18-02-2004', 'dd-mm-yyyy'), 8, 4559, to_date('07-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010925000521, to_date('25-09-2001', 'dd-mm-yyyy'), to_date('09-10-2001', 'dd-mm-yyyy'), 12, 3686, to_date('04-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010405000522, to_date('05-04-2001', 'dd-mm-yyyy'), to_date('19-04-2001', 'dd-mm-yyyy'), 11, 2264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031117000523, to_date('17-11-2003', 'dd-mm-yyyy'), to_date('01-12-2003', 'dd-mm-yyyy'), 11, 3634, to_date('18-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118000524, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 3, 6258, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080917000525, to_date('17-09-2008', 'dd-mm-yyyy'), to_date('01-10-2008', 'dd-mm-yyyy'), 2, 6982, to_date('20-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050206000526, to_date('06-02-2005', 'dd-mm-yyyy'), to_date('20-02-2005', 'dd-mm-yyyy'), 12, 2374, to_date('23-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070321000527, to_date('21-03-2007', 'dd-mm-yyyy'), to_date('04-04-2007', 'dd-mm-yyyy'), 6, 6886, to_date('29-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221000528, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 5, 9850, to_date('07-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713000529, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 2, 3586, to_date('31-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040718000530, to_date('18-07-2004', 'dd-mm-yyyy'), to_date('01-08-2004', 'dd-mm-yyyy'), 2, 5930, to_date('23-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926000531, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 9, 2118, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111231000532, to_date('31-12-2011', 'dd-mm-yyyy'), to_date('14-01-2012', 'dd-mm-yyyy'), 7, 8918, to_date('09-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050506000533, to_date('06-05-2005', 'dd-mm-yyyy'), to_date('20-05-2005', 'dd-mm-yyyy'), 11, 5194, to_date('14-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120918000534, to_date('18-09-2012', 'dd-mm-yyyy'), to_date('02-10-2012', 'dd-mm-yyyy'), 8, 8033, to_date('27-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071128000535, to_date('28-11-2007', 'dd-mm-yyyy'), to_date('12-12-2007', 'dd-mm-yyyy'), 9, 6162, to_date('29-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020526000536, to_date('26-05-2002', 'dd-mm-yyyy'), to_date('09-06-2002', 'dd-mm-yyyy'), 8, 2268, to_date('12-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010121000537, to_date('21-01-2001', 'dd-mm-yyyy'), to_date('04-02-2001', 'dd-mm-yyyy'), 2, 3902, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130505000538, to_date('05-05-2013', 'dd-mm-yyyy'), to_date('19-05-2013', 'dd-mm-yyyy'), 8, 8433, to_date('15-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331000539, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 6, 1918, to_date('05-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070217000540, to_date('17-02-2007', 'dd-mm-yyyy'), to_date('03-03-2007', 'dd-mm-yyyy'), 1, 6404, to_date('20-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110518000541, to_date('18-05-2011', 'dd-mm-yyyy'), to_date('01-06-2011', 'dd-mm-yyyy'), 2, 6719, to_date('03-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060605000542, to_date('05-06-2006', 'dd-mm-yyyy'), to_date('19-06-2006', 'dd-mm-yyyy'), 2, 5998, to_date('22-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130315000543, to_date('15-03-2013', 'dd-mm-yyyy'), to_date('29-03-2013', 'dd-mm-yyyy'), 9, 8566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010317000544, to_date('17-03-2001', 'dd-mm-yyyy'), to_date('31-03-2001', 'dd-mm-yyyy'), 11, 965, to_date('25-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916000545, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 8, 5709, to_date('03-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121201000546, to_date('01-12-2012', 'dd-mm-yyyy'), to_date('15-12-2012', 'dd-mm-yyyy'), 4, 10106, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120914000547, to_date('14-09-2012', 'dd-mm-yyyy'), to_date('28-09-2012', 'dd-mm-yyyy'), 8, 7435, to_date('15-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000407000548, to_date('07-04-2000', 'dd-mm-yyyy'), to_date('21-04-2000', 'dd-mm-yyyy'), 7, 1843, to_date('14-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050904000549, to_date('04-09-2005', 'dd-mm-yyyy'), to_date('18-09-2005', 'dd-mm-yyyy'), 2, 3926, to_date('13-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000329000550, to_date('29-03-2000', 'dd-mm-yyyy'), to_date('12-04-2000', 'dd-mm-yyyy'), 7, 817, to_date('16-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006000551, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 2, 6287, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081213000552, to_date('13-12-2008', 'dd-mm-yyyy'), to_date('27-12-2008', 'dd-mm-yyyy'), 4, 6321, to_date('17-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120000553, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 5, 5311, to_date('29-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020606000554, to_date('06-06-2002', 'dd-mm-yyyy'), to_date('20-06-2002', 'dd-mm-yyyy'), 5, 2359, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031228000555, to_date('28-12-2003', 'dd-mm-yyyy'), to_date('11-01-2004', 'dd-mm-yyyy'), 9, 3578, to_date('31-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120629000556, to_date('29-06-2012', 'dd-mm-yyyy'), to_date('13-07-2012', 'dd-mm-yyyy'), 9, 5882, to_date('18-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210000557, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 6, 3355, to_date('14-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140328000558, to_date('28-03-2014', 'dd-mm-yyyy'), to_date('11-04-2014', 'dd-mm-yyyy'), 9, 9731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507000559, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 6, 3707, to_date('16-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813000560, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 10, 6479, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010517000561, to_date('17-05-2001', 'dd-mm-yyyy'), to_date('31-05-2001', 'dd-mm-yyyy'), 8, 1463, to_date('27-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140124000562, to_date('24-01-2014', 'dd-mm-yyyy'), to_date('07-02-2014', 'dd-mm-yyyy'), 7, 10012, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121000563, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 2, 4614, to_date('06-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130303000564, to_date('03-03-2013', 'dd-mm-yyyy'), to_date('17-03-2013', 'dd-mm-yyyy'), 8, 8439, to_date('10-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090512000565, to_date('12-05-2009', 'dd-mm-yyyy'), to_date('26-05-2009', 'dd-mm-yyyy'), 9, 8805, to_date('17-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418000566, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 10, 2381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050706000567, to_date('06-07-2005', 'dd-mm-yyyy'), to_date('20-07-2005', 'dd-mm-yyyy'), 12, 6250, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050116000568, to_date('16-01-2005', 'dd-mm-yyyy'), to_date('30-01-2005', 'dd-mm-yyyy'), 3, 5514, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050914000569, to_date('14-09-2005', 'dd-mm-yyyy'), to_date('28-09-2005', 'dd-mm-yyyy'), 3, 5088, to_date('28-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061005000570, to_date('05-10-2006', 'dd-mm-yyyy'), to_date('19-10-2006', 'dd-mm-yyyy'), 4, 5652, to_date('21-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001219000571, to_date('19-12-2000', 'dd-mm-yyyy'), to_date('02-01-2001', 'dd-mm-yyyy'), 3, 1917, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030923000572, to_date('23-09-2003', 'dd-mm-yyyy'), to_date('07-10-2003', 'dd-mm-yyyy'), 4, 2746, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021212000573, to_date('12-12-2002', 'dd-mm-yyyy'), to_date('26-12-2002', 'dd-mm-yyyy'), 10, 1830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120302000574, to_date('02-03-2012', 'dd-mm-yyyy'), to_date('16-03-2012', 'dd-mm-yyyy'), 9, 8751, to_date('18-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030429000575, to_date('29-04-2003', 'dd-mm-yyyy'), to_date('13-05-2003', 'dd-mm-yyyy'), 6, 2854, to_date('18-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000826000576, to_date('26-08-2000', 'dd-mm-yyyy'), to_date('09-09-2000', 'dd-mm-yyyy'), 11, 1269, to_date('06-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090324000577, to_date('24-03-2009', 'dd-mm-yyyy'), to_date('07-04-2009', 'dd-mm-yyyy'), 10, 5141, to_date('10-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100730000578, to_date('30-07-2010', 'dd-mm-yyyy'), to_date('13-08-2010', 'dd-mm-yyyy'), 11, 8020, to_date('11-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091126000579, to_date('26-11-2009', 'dd-mm-yyyy'), to_date('10-12-2009', 'dd-mm-yyyy'), 12, 7683, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120809000580, to_date('09-08-2012', 'dd-mm-yyyy'), to_date('23-08-2012', 'dd-mm-yyyy'), 5, 10847, to_date('20-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080409000581, to_date('09-04-2008', 'dd-mm-yyyy'), to_date('23-04-2008', 'dd-mm-yyyy'), 3, 6014, to_date('21-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090712000582, to_date('12-07-2009', 'dd-mm-yyyy'), to_date('26-07-2009', 'dd-mm-yyyy'), 8, 6041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030307000583, to_date('07-03-2003', 'dd-mm-yyyy'), to_date('21-03-2003', 'dd-mm-yyyy'), 3, 4034, to_date('14-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041212000584, to_date('12-12-2004', 'dd-mm-yyyy'), to_date('26-12-2004', 'dd-mm-yyyy'), 7, 2729, to_date('19-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207000585, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 9, 2336, to_date('13-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011204000586, to_date('04-12-2001', 'dd-mm-yyyy'), to_date('18-12-2001', 'dd-mm-yyyy'), 3, 2980, to_date('06-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308000587, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 1, 1594, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070518000588, to_date('18-05-2007', 'dd-mm-yyyy'), to_date('01-06-2007', 'dd-mm-yyyy'), 8, 4695, to_date('03-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011128000589, to_date('28-11-2001', 'dd-mm-yyyy'), to_date('12-12-2001', 'dd-mm-yyyy'), 7, 4151, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021209000590, to_date('09-12-2002', 'dd-mm-yyyy'), to_date('23-12-2002', 'dd-mm-yyyy'), 7, 2796, to_date('12-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050402000591, to_date('02-04-2005', 'dd-mm-yyyy'), to_date('16-04-2005', 'dd-mm-yyyy'), 7, 3869, to_date('18-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050502000592, to_date('02-05-2005', 'dd-mm-yyyy'), to_date('16-05-2005', 'dd-mm-yyyy'), 3, 4124, to_date('08-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040526000593, to_date('26-05-2004', 'dd-mm-yyyy'), to_date('09-06-2004', 'dd-mm-yyyy'), 4, 2545, to_date('11-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080123000594, to_date('23-01-2008', 'dd-mm-yyyy'), to_date('06-02-2008', 'dd-mm-yyyy'), 8, 8349, to_date('03-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227000595, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 4, 9277, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090421000596, to_date('21-04-2009', 'dd-mm-yyyy'), to_date('05-05-2009', 'dd-mm-yyyy'), 10, 5858, to_date('27-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130210000597, to_date('10-02-2013', 'dd-mm-yyyy'), to_date('24-02-2013', 'dd-mm-yyyy'), 4, 8987, to_date('15-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050518000598, to_date('18-05-2005', 'dd-mm-yyyy'), to_date('01-06-2005', 'dd-mm-yyyy'), 3, 3520, to_date('25-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140411000599, to_date('11-04-2014', 'dd-mm-yyyy'), to_date('25-04-2014', 'dd-mm-yyyy'), 9, 9043, to_date('26-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202000600, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 7, 4638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306000601, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 10, 4375, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070309000602, to_date('09-03-2007', 'dd-mm-yyyy'), to_date('23-03-2007', 'dd-mm-yyyy'), 2, 6090, to_date('26-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020719000603, to_date('19-07-2002', 'dd-mm-yyyy'), to_date('02-08-2002', 'dd-mm-yyyy'), 1, 2723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090518000604, to_date('18-05-2009', 'dd-mm-yyyy'), to_date('01-06-2009', 'dd-mm-yyyy'), 3, 7090, to_date('03-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081113000605, to_date('13-11-2008', 'dd-mm-yyyy'), to_date('27-11-2008', 'dd-mm-yyyy'), 2, 4524, to_date('16-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104000606, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 3, 6931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050116000607, to_date('16-01-2005', 'dd-mm-yyyy'), to_date('30-01-2005', 'dd-mm-yyyy'), 3, 3365, to_date('30-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100111000608, to_date('11-01-2010', 'dd-mm-yyyy'), to_date('25-01-2010', 'dd-mm-yyyy'), 7, 5147, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041124000609, to_date('24-11-2004', 'dd-mm-yyyy'), to_date('08-12-2004', 'dd-mm-yyyy'), 2, 5232, to_date('13-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007000610, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 5, 1888, to_date('21-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217000611, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 8, 6401, to_date('22-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130727000612, to_date('27-07-2013', 'dd-mm-yyyy'), to_date('10-08-2013', 'dd-mm-yyyy'), 6, 7972, to_date('07-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130105002757, to_date('05-01-2013', 'dd-mm-yyyy'), to_date('19-01-2013', 'dd-mm-yyyy'), 5, 7721, to_date('11-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040918002758, to_date('18-09-2004', 'dd-mm-yyyy'), to_date('02-10-2004', 'dd-mm-yyyy'), 2, 6717, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130921002759, to_date('21-09-2013', 'dd-mm-yyyy'), to_date('05-10-2013', 'dd-mm-yyyy'), 4, 8082, to_date('30-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080812002760, to_date('12-08-2008', 'dd-mm-yyyy'), to_date('26-08-2008', 'dd-mm-yyyy'), 7, 5728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120529002761, to_date('29-05-2012', 'dd-mm-yyyy'), to_date('12-06-2012', 'dd-mm-yyyy'), 12, 7778, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131204002762, to_date('04-12-2013', 'dd-mm-yyyy'), to_date('18-12-2013', 'dd-mm-yyyy'), 9, 7305, to_date('08-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000123002763, to_date('23-01-2000', 'dd-mm-yyyy'), to_date('06-02-2000', 'dd-mm-yyyy'), 8, 952, to_date('05-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302002764, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 8, 7822, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061105002765, to_date('05-11-2006', 'dd-mm-yyyy'), to_date('19-11-2006', 'dd-mm-yyyy'), 8, 5188, to_date('19-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060723002766, to_date('23-07-2006', 'dd-mm-yyyy'), to_date('06-08-2006', 'dd-mm-yyyy'), 1, 3963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021106002767, to_date('06-11-2002', 'dd-mm-yyyy'), to_date('20-11-2002', 'dd-mm-yyyy'), 10, 3773, to_date('07-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100521002768, to_date('21-05-2010', 'dd-mm-yyyy'), to_date('04-06-2010', 'dd-mm-yyyy'), 11, 6673, to_date('05-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021122002769, to_date('22-11-2002', 'dd-mm-yyyy'), to_date('06-12-2002', 'dd-mm-yyyy'), 7, 3968, to_date('01-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030909002770, to_date('09-09-2003', 'dd-mm-yyyy'), to_date('23-09-2003', 'dd-mm-yyyy'), 2, 4093, to_date('17-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051024002771, to_date('24-10-2005', 'dd-mm-yyyy'), to_date('07-11-2005', 'dd-mm-yyyy'), 10, 5019, to_date('08-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111002772, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 3, 7937, to_date('18-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130908002773, to_date('08-09-2013', 'dd-mm-yyyy'), to_date('22-09-2013', 'dd-mm-yyyy'), 5, 9057, to_date('22-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222002774, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 3, 10161, to_date('05-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140330002775, to_date('30-03-2014', 'dd-mm-yyyy'), to_date('13-04-2014', 'dd-mm-yyyy'), 12, 9016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000126002776, to_date('26-01-2000', 'dd-mm-yyyy'), to_date('09-02-2000', 'dd-mm-yyyy'), 8, 3161, to_date('06-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215002777, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 3, 4077, to_date('26-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020731002778, to_date('31-07-2002', 'dd-mm-yyyy'), to_date('14-08-2002', 'dd-mm-yyyy'), 9, 4073, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010320002779, to_date('20-03-2001', 'dd-mm-yyyy'), to_date('03-04-2001', 'dd-mm-yyyy'), 8, 3075, to_date('02-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010415002780, to_date('15-04-2001', 'dd-mm-yyyy'), to_date('29-04-2001', 'dd-mm-yyyy'), 6, 2099, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080124002781, to_date('24-01-2008', 'dd-mm-yyyy'), to_date('07-02-2008', 'dd-mm-yyyy'), 2, 6443, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130002782, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 3, 4818, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091017002783, to_date('17-10-2009', 'dd-mm-yyyy'), to_date('31-10-2009', 'dd-mm-yyyy'), 8, 5418, to_date('05-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101124002784, to_date('24-11-2010', 'dd-mm-yyyy'), to_date('08-12-2010', 'dd-mm-yyyy'), 2, 10693, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110410002785, to_date('10-04-2011', 'dd-mm-yyyy'), to_date('24-04-2011', 'dd-mm-yyyy'), 10, 9930, to_date('25-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323002786, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 7, 4781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010325002787, to_date('25-03-2001', 'dd-mm-yyyy'), to_date('08-04-2001', 'dd-mm-yyyy'), 6, 1616, to_date('05-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010804002788, to_date('04-08-2001', 'dd-mm-yyyy'), to_date('18-08-2001', 'dd-mm-yyyy'), 2, 1572, to_date('22-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040212002789, to_date('12-02-2004', 'dd-mm-yyyy'), to_date('26-02-2004', 'dd-mm-yyyy'), 11, 3859, to_date('18-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050517002790, to_date('17-05-2005', 'dd-mm-yyyy'), to_date('31-05-2005', 'dd-mm-yyyy'), 12, 3555, to_date('29-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826002791, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 10, 4007, to_date('28-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510002792, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 11, 605, to_date('12-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030506002793, to_date('06-05-2003', 'dd-mm-yyyy'), to_date('20-05-2003', 'dd-mm-yyyy'), 2, 3532, to_date('25-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130705002794, to_date('05-07-2013', 'dd-mm-yyyy'), to_date('19-07-2013', 'dd-mm-yyyy'), 7, 9213, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726002795, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 1, 7924, to_date('29-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120702002796, to_date('02-07-2012', 'dd-mm-yyyy'), to_date('16-07-2012', 'dd-mm-yyyy'), 7, 11506, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824002797, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 11, 3772, to_date('07-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030621002798, to_date('21-06-2003', 'dd-mm-yyyy'), to_date('05-07-2003', 'dd-mm-yyyy'), 9, 3309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110510002799, to_date('10-05-2011', 'dd-mm-yyyy'), to_date('24-05-2011', 'dd-mm-yyyy'), 1, 9044, to_date('15-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050116002800, to_date('16-01-2005', 'dd-mm-yyyy'), to_date('30-01-2005', 'dd-mm-yyyy'), 11, 3062, to_date('24-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001229002801, to_date('29-12-2000', 'dd-mm-yyyy'), to_date('12-01-2001', 'dd-mm-yyyy'), 9, 2118, to_date('03-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030621002802, to_date('21-06-2003', 'dd-mm-yyyy'), to_date('05-07-2003', 'dd-mm-yyyy'), 1, 3670, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080630002803, to_date('30-06-2008', 'dd-mm-yyyy'), to_date('14-07-2008', 'dd-mm-yyyy'), 2, 4732, to_date('03-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201002804, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 12, 4459, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100610002805, to_date('10-06-2010', 'dd-mm-yyyy'), to_date('24-06-2010', 'dd-mm-yyyy'), 5, 9211, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090131002806, to_date('31-01-2009', 'dd-mm-yyyy'), to_date('14-02-2009', 'dd-mm-yyyy'), 2, 7142, to_date('19-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080907002807, to_date('07-09-2008', 'dd-mm-yyyy'), to_date('21-09-2008', 'dd-mm-yyyy'), 4, 3976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100422002808, to_date('22-04-2010', 'dd-mm-yyyy'), to_date('06-05-2010', 'dd-mm-yyyy'), 8, 7534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103002809, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 8, 4872, to_date('22-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100929002810, to_date('29-09-2010', 'dd-mm-yyyy'), to_date('13-10-2010', 'dd-mm-yyyy'), 2, 6336, to_date('13-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081023002811, to_date('23-10-2008', 'dd-mm-yyyy'), to_date('06-11-2008', 'dd-mm-yyyy'), 12, 5566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060730002812, to_date('30-07-2006', 'dd-mm-yyyy'), to_date('13-08-2006', 'dd-mm-yyyy'), 3, 4185, to_date('02-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000313002813, to_date('13-03-2000', 'dd-mm-yyyy'), to_date('27-03-2000', 'dd-mm-yyyy'), 7, 3615, to_date('01-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227002814, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 10, 8456, to_date('10-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011103002815, to_date('03-11-2001', 'dd-mm-yyyy'), to_date('17-11-2001', 'dd-mm-yyyy'), 3, 3323, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130828002816, to_date('28-08-2013', 'dd-mm-yyyy'), to_date('11-09-2013', 'dd-mm-yyyy'), 7, 8464, to_date('01-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010903002817, to_date('03-09-2001', 'dd-mm-yyyy'), to_date('17-09-2001', 'dd-mm-yyyy'), 10, 2688, to_date('15-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070107002818, to_date('07-01-2007', 'dd-mm-yyyy'), to_date('21-01-2007', 'dd-mm-yyyy'), 7, 5488, to_date('12-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041017002819, to_date('17-10-2004', 'dd-mm-yyyy'), to_date('31-10-2004', 'dd-mm-yyyy'), 6, 5917, to_date('19-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627002820, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 8, 9444, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130806002821, to_date('06-08-2013', 'dd-mm-yyyy'), to_date('20-08-2013', 'dd-mm-yyyy'), 12, 8874, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080812002822, to_date('12-08-2008', 'dd-mm-yyyy'), to_date('26-08-2008', 'dd-mm-yyyy'), 10, 7202, to_date('16-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010627002823, to_date('27-06-2001', 'dd-mm-yyyy'), to_date('11-07-2001', 'dd-mm-yyyy'), 9, 2867, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081213002824, to_date('13-12-2008', 'dd-mm-yyyy'), to_date('27-12-2008', 'dd-mm-yyyy'), 1, 6070, to_date('20-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110324002825, to_date('24-03-2011', 'dd-mm-yyyy'), to_date('07-04-2011', 'dd-mm-yyyy'), 8, 7073, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040129002826, to_date('29-01-2004', 'dd-mm-yyyy'), to_date('12-02-2004', 'dd-mm-yyyy'), 6, 3822, to_date('03-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090423002827, to_date('23-04-2009', 'dd-mm-yyyy'), to_date('07-05-2009', 'dd-mm-yyyy'), 3, 6253, to_date('25-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040423002828, to_date('23-04-2004', 'dd-mm-yyyy'), to_date('07-05-2004', 'dd-mm-yyyy'), 4, 4170, to_date('01-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321002829, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 4, 9488, to_date('03-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090722002830, to_date('22-07-2009', 'dd-mm-yyyy'), to_date('05-08-2009', 'dd-mm-yyyy'), 11, 3917, to_date('08-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011210002831, to_date('10-12-2001', 'dd-mm-yyyy'), to_date('24-12-2001', 'dd-mm-yyyy'), 6, 3383, to_date('21-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021124002832, to_date('24-11-2002', 'dd-mm-yyyy'), to_date('08-12-2002', 'dd-mm-yyyy'), 5, 2881, to_date('09-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228002833, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 3, 6340, to_date('07-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015002834, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 4, 3476, to_date('28-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120404002835, to_date('04-04-2012', 'dd-mm-yyyy'), to_date('18-04-2012', 'dd-mm-yyyy'), 3, 9305, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021110002836, to_date('10-11-2002', 'dd-mm-yyyy'), to_date('24-11-2002', 'dd-mm-yyyy'), 6, 3696, to_date('29-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803002837, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 5, 9874, to_date('17-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081129002838, to_date('29-11-2008', 'dd-mm-yyyy'), to_date('13-12-2008', 'dd-mm-yyyy'), 6, 6023, to_date('13-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407002839, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 5, 8579, to_date('18-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210002840, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 3, 5260, to_date('19-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015002841, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 7, 1353, to_date('17-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101220002842, to_date('20-12-2010', 'dd-mm-yyyy'), to_date('03-01-2011', 'dd-mm-yyyy'), 3, 8243, to_date('24-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618002843, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 3, 8441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108002844, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 10, 7225, to_date('19-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031126002845, to_date('26-11-2003', 'dd-mm-yyyy'), to_date('10-12-2003', 'dd-mm-yyyy'), 10, 5439, to_date('29-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090116002846, to_date('16-01-2009', 'dd-mm-yyyy'), to_date('30-01-2009', 'dd-mm-yyyy'), 2, 6417, to_date('18-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020629002847, to_date('29-06-2002', 'dd-mm-yyyy'), to_date('13-07-2002', 'dd-mm-yyyy'), 4, 3636, to_date('09-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618002848, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 9, 7724, to_date('30-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111008002849, to_date('08-10-2011', 'dd-mm-yyyy'), to_date('22-10-2011', 'dd-mm-yyyy'), 10, 8504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824002850, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 3, 4673, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120209002851, to_date('09-02-2012', 'dd-mm-yyyy'), to_date('23-02-2012', 'dd-mm-yyyy'), 1, 7915, to_date('23-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120429002852, to_date('29-04-2012', 'dd-mm-yyyy'), to_date('13-05-2012', 'dd-mm-yyyy'), 4, 10707, to_date('17-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608002853, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 4, 5571, to_date('24-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060819002854, to_date('19-08-2006', 'dd-mm-yyyy'), to_date('02-09-2006', 'dd-mm-yyyy'), 10, 4210, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050424002855, to_date('24-04-2005', 'dd-mm-yyyy'), to_date('08-05-2005', 'dd-mm-yyyy'), 7, 5388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040406002856, to_date('06-04-2004', 'dd-mm-yyyy'), to_date('20-04-2004', 'dd-mm-yyyy'), 12, 4854, to_date('13-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522002857, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 3, 7238, to_date('04-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011002002858, to_date('02-10-2001', 'dd-mm-yyyy'), to_date('16-10-2001', 'dd-mm-yyyy'), 10, 1488, to_date('03-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001113002859, to_date('13-11-2000', 'dd-mm-yyyy'), to_date('27-11-2000', 'dd-mm-yyyy'), 8, 1473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110808002860, to_date('08-08-2011', 'dd-mm-yyyy'), to_date('22-08-2011', 'dd-mm-yyyy'), 4, 7487, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061010002861, to_date('10-10-2006', 'dd-mm-yyyy'), to_date('24-10-2006', 'dd-mm-yyyy'), 10, 5315, to_date('26-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070702002862, to_date('02-07-2007', 'dd-mm-yyyy'), to_date('16-07-2007', 'dd-mm-yyyy'), 2, 3072, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020719002863, to_date('19-07-2002', 'dd-mm-yyyy'), to_date('02-08-2002', 'dd-mm-yyyy'), 11, 2255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205002864, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 1, 5803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417002865, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 8, 4322, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120425002866, to_date('25-04-2012', 'dd-mm-yyyy'), to_date('09-05-2012', 'dd-mm-yyyy'), 2, 7502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011213002867, to_date('13-12-2001', 'dd-mm-yyyy'), to_date('27-12-2001', 'dd-mm-yyyy'), 1, 3562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071009002868, to_date('09-10-2007', 'dd-mm-yyyy'), to_date('23-10-2007', 'dd-mm-yyyy'), 11, 4649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120114002869, to_date('14-01-2012', 'dd-mm-yyyy'), to_date('28-01-2012', 'dd-mm-yyyy'), 3, 7768, to_date('29-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081102002870, to_date('02-11-2008', 'dd-mm-yyyy'), to_date('16-11-2008', 'dd-mm-yyyy'), 11, 6419, to_date('17-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140319002871, to_date('19-03-2014', 'dd-mm-yyyy'), to_date('02-04-2014', 'dd-mm-yyyy'), 3, 7427, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120404002872, to_date('04-04-2012', 'dd-mm-yyyy'), to_date('18-04-2012', 'dd-mm-yyyy'), 7, 11531, to_date('06-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050110002873, to_date('10-01-2005', 'dd-mm-yyyy'), to_date('24-01-2005', 'dd-mm-yyyy'), 5, 6123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123002874, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 7, 2893, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020326002875, to_date('26-03-2002', 'dd-mm-yyyy'), to_date('09-04-2002', 'dd-mm-yyyy'), 6, 2775, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050120002876, to_date('20-01-2005', 'dd-mm-yyyy'), to_date('03-02-2005', 'dd-mm-yyyy'), 5, 6160, to_date('09-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040905002877, to_date('05-09-2004', 'dd-mm-yyyy'), to_date('19-09-2004', 'dd-mm-yyyy'), 8, 2930, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101122002878, to_date('22-11-2010', 'dd-mm-yyyy'), to_date('06-12-2010', 'dd-mm-yyyy'), 4, 7974, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015002879, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 5, 2687, to_date('02-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010405002880, to_date('05-04-2001', 'dd-mm-yyyy'), to_date('19-04-2001', 'dd-mm-yyyy'), 5, 3299, to_date('16-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011230002881, to_date('30-12-2001', 'dd-mm-yyyy'), to_date('13-01-2002', 'dd-mm-yyyy'), 4, 1225, to_date('31-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040120002882, to_date('20-01-2004', 'dd-mm-yyyy'), to_date('03-02-2004', 'dd-mm-yyyy'), 2, 3237, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080511002883, to_date('11-05-2008', 'dd-mm-yyyy'), to_date('25-05-2008', 'dd-mm-yyyy'), 7, 6960, to_date('19-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050820002884, to_date('20-08-2005', 'dd-mm-yyyy'), to_date('03-09-2005', 'dd-mm-yyyy'), 10, 6171, to_date('28-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031230002885, to_date('30-12-2003', 'dd-mm-yyyy'), to_date('13-01-2004', 'dd-mm-yyyy'), 11, 3006, to_date('04-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906002886, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 7, 8742, to_date('07-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217002887, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 3, 3430, to_date('03-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061221002888, to_date('21-12-2006', 'dd-mm-yyyy'), to_date('04-01-2007', 'dd-mm-yyyy'), 11, 3734, to_date('05-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010616002889, to_date('16-06-2001', 'dd-mm-yyyy'), to_date('30-06-2001', 'dd-mm-yyyy'), 4, 1052, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130901002890, to_date('01-09-2013', 'dd-mm-yyyy'), to_date('15-09-2013', 'dd-mm-yyyy'), 5, 9592, to_date('08-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060719002891, to_date('19-07-2006', 'dd-mm-yyyy'), to_date('02-08-2006', 'dd-mm-yyyy'), 8, 3873, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050819002892, to_date('19-08-2005', 'dd-mm-yyyy'), to_date('02-09-2005', 'dd-mm-yyyy'), 4, 5186, to_date('29-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112002893, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 8, 9561, to_date('31-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080512002894, to_date('12-05-2008', 'dd-mm-yyyy'), to_date('26-05-2008', 'dd-mm-yyyy'), 3, 5971, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060504002895, to_date('04-05-2006', 'dd-mm-yyyy'), to_date('18-05-2006', 'dd-mm-yyyy'), 12, 4876, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708002896, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 1, 4127, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000306002897, to_date('06-03-2000', 'dd-mm-yyyy'), to_date('20-03-2000', 'dd-mm-yyyy'), 8, 2203, to_date('14-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409002898, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 11, 7664, to_date('23-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030130002899, to_date('30-01-2003', 'dd-mm-yyyy'), to_date('13-02-2003', 'dd-mm-yyyy'), 8, 3470, to_date('18-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020128002900, to_date('28-01-2002', 'dd-mm-yyyy'), to_date('11-02-2002', 'dd-mm-yyyy'), 10, 2075, to_date('09-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010505002901, to_date('05-05-2001', 'dd-mm-yyyy'), to_date('19-05-2001', 'dd-mm-yyyy'), 5, 2715, to_date('18-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418002902, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 4, 7504, to_date('24-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060724002903, to_date('24-07-2006', 'dd-mm-yyyy'), to_date('07-08-2006', 'dd-mm-yyyy'), 6, 6694, to_date('13-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030316002904, to_date('16-03-2003', 'dd-mm-yyyy'), to_date('30-03-2003', 'dd-mm-yyyy'), 5, 3534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100528002905, to_date('28-05-2010', 'dd-mm-yyyy'), to_date('11-06-2010', 'dd-mm-yyyy'), 8, 5511, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000525002906, to_date('25-05-2000', 'dd-mm-yyyy'), to_date('08-06-2000', 'dd-mm-yyyy'), 8, 2983, to_date('29-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070125002907, to_date('25-01-2007', 'dd-mm-yyyy'), to_date('08-02-2007', 'dd-mm-yyyy'), 8, 7041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630002908, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 9, 3995, to_date('15-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071003002909, to_date('03-10-2007', 'dd-mm-yyyy'), to_date('17-10-2007', 'dd-mm-yyyy'), 8, 4509, to_date('07-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090114002910, to_date('14-01-2009', 'dd-mm-yyyy'), to_date('28-01-2009', 'dd-mm-yyyy'), 1, 4548, to_date('22-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060813005204, to_date('13-08-2006', 'dd-mm-yyyy'), to_date('27-08-2006', 'dd-mm-yyyy'), 6, 6116, to_date('01-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101023005205, to_date('23-10-2010', 'dd-mm-yyyy'), to_date('06-11-2010', 'dd-mm-yyyy'), 10, 8937, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304005206, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 4, 8076, to_date('07-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210005207, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 2, 3395, to_date('26-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410005208, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 12, 6144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090729005209, to_date('29-07-2009', 'dd-mm-yyyy'), to_date('12-08-2009', 'dd-mm-yyyy'), 7, 5226, to_date('10-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060208005210, to_date('08-02-2006', 'dd-mm-yyyy'), to_date('22-02-2006', 'dd-mm-yyyy'), 11, 3167, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120531005211, to_date('31-05-2012', 'dd-mm-yyyy'), to_date('14-06-2012', 'dd-mm-yyyy'), 4, 11246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121015005212, to_date('15-10-2012', 'dd-mm-yyyy'), to_date('29-10-2012', 'dd-mm-yyyy'), 5, 5606, to_date('23-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101005213, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 7, 7434, to_date('10-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000112005214, to_date('12-01-2000', 'dd-mm-yyyy'), to_date('26-01-2000', 'dd-mm-yyyy'), 7, 1435, to_date('24-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080918005215, to_date('18-09-2008', 'dd-mm-yyyy'), to_date('02-10-2008', 'dd-mm-yyyy'), 1, 6845, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090312005216, to_date('12-03-2009', 'dd-mm-yyyy'), to_date('26-03-2009', 'dd-mm-yyyy'), 4, 7231, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051228005217, to_date('28-12-2005', 'dd-mm-yyyy'), to_date('11-01-2006', 'dd-mm-yyyy'), 10, 6296, to_date('09-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210005218, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 6, 1060, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000918005219, to_date('18-09-2000', 'dd-mm-yyyy'), to_date('02-10-2000', 'dd-mm-yyyy'), 1, 3458, to_date('27-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104005220, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 9, 3790, to_date('10-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121227005221, to_date('27-12-2012', 'dd-mm-yyyy'), to_date('10-01-2013', 'dd-mm-yyyy'), 4, 8853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040318005222, to_date('18-03-2004', 'dd-mm-yyyy'), to_date('01-04-2004', 'dd-mm-yyyy'), 10, 5134, to_date('25-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070519005223, to_date('19-05-2007', 'dd-mm-yyyy'), to_date('02-06-2007', 'dd-mm-yyyy'), 9, 5291, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110523005224, to_date('23-05-2011', 'dd-mm-yyyy'), to_date('06-06-2011', 'dd-mm-yyyy'), 7, 6120, to_date('11-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111010005225, to_date('10-10-2011', 'dd-mm-yyyy'), to_date('24-10-2011', 'dd-mm-yyyy'), 6, 8170, to_date('22-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060423005226, to_date('23-04-2006', 'dd-mm-yyyy'), to_date('07-05-2006', 'dd-mm-yyyy'), 6, 5446, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101121005227, to_date('21-11-2010', 'dd-mm-yyyy'), to_date('05-12-2010', 'dd-mm-yyyy'), 7, 6777, to_date('03-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411005228, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 10, 5772, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011105005229, to_date('05-11-2001', 'dd-mm-yyyy'), to_date('19-11-2001', 'dd-mm-yyyy'), 9, 1847, to_date('19-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000617005230, to_date('17-06-2000', 'dd-mm-yyyy'), to_date('01-07-2000', 'dd-mm-yyyy'), 5, 1868, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140323005231, to_date('23-03-2014', 'dd-mm-yyyy'), to_date('06-04-2014', 'dd-mm-yyyy'), 2, 8679, to_date('01-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131023005232, to_date('23-10-2013', 'dd-mm-yyyy'), to_date('06-11-2013', 'dd-mm-yyyy'), 3, 10668, to_date('10-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601005233, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 5, 10118, to_date('17-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050930005234, to_date('30-09-2005', 'dd-mm-yyyy'), to_date('14-10-2005', 'dd-mm-yyyy'), 4, 3015, to_date('05-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030411005235, to_date('11-04-2003', 'dd-mm-yyyy'), to_date('25-04-2003', 'dd-mm-yyyy'), 7, 3077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050107005236, to_date('07-01-2005', 'dd-mm-yyyy'), to_date('21-01-2005', 'dd-mm-yyyy'), 7, 4127, to_date('15-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091105005237, to_date('05-11-2009', 'dd-mm-yyyy'), to_date('19-11-2009', 'dd-mm-yyyy'), 2, 5373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119005238, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 1, 1383, to_date('06-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130130005239, to_date('30-01-2013', 'dd-mm-yyyy'), to_date('13-02-2013', 'dd-mm-yyyy'), 1, 7122, to_date('05-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002005240, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 10, 737, to_date('15-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020720005241, to_date('20-07-2002', 'dd-mm-yyyy'), to_date('03-08-2002', 'dd-mm-yyyy'), 11, 3450, to_date('01-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031224005242, to_date('24-12-2003', 'dd-mm-yyyy'), to_date('07-01-2004', 'dd-mm-yyyy'), 4, 4529, to_date('05-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130005243, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 10, 2842, to_date('14-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110701005244, to_date('01-07-2011', 'dd-mm-yyyy'), to_date('15-07-2011', 'dd-mm-yyyy'), 6, 7968, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731005245, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 2, 5384, to_date('13-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040206005246, to_date('06-02-2004', 'dd-mm-yyyy'), to_date('20-02-2004', 'dd-mm-yyyy'), 2, 6151, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020309005247, to_date('09-03-2002', 'dd-mm-yyyy'), to_date('23-03-2002', 'dd-mm-yyyy'), 4, 3800, to_date('20-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140126005248, to_date('26-01-2014', 'dd-mm-yyyy'), to_date('09-02-2014', 'dd-mm-yyyy'), 5, 10724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521005249, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 7, 3412, to_date('22-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050307005250, to_date('07-03-2005', 'dd-mm-yyyy'), to_date('21-03-2005', 'dd-mm-yyyy'), 6, 3559, to_date('15-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060101005251, to_date('01-01-2006', 'dd-mm-yyyy'), to_date('15-01-2006', 'dd-mm-yyyy'), 6, 5430, to_date('05-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031110005252, to_date('10-11-2003', 'dd-mm-yyyy'), to_date('24-11-2003', 'dd-mm-yyyy'), 11, 5686, to_date('12-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215005253, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 6, 5515, to_date('03-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329005254, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 5, 4023, to_date('09-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020706005255, to_date('06-07-2002', 'dd-mm-yyyy'), to_date('20-07-2002', 'dd-mm-yyyy'), 6, 1967, to_date('25-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120625005256, to_date('25-06-2012', 'dd-mm-yyyy'), to_date('09-07-2012', 'dd-mm-yyyy'), 6, 5408, to_date('15-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110126005257, to_date('26-01-2011', 'dd-mm-yyyy'), to_date('09-02-2011', 'dd-mm-yyyy'), 9, 5811, to_date('29-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010719005258, to_date('19-07-2001', 'dd-mm-yyyy'), to_date('02-08-2001', 'dd-mm-yyyy'), 1, 2725, to_date('26-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130606005259, to_date('06-06-2013', 'dd-mm-yyyy'), to_date('20-06-2013', 'dd-mm-yyyy'), 5, 7395, to_date('25-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020316005260, to_date('16-03-2002', 'dd-mm-yyyy'), to_date('30-03-2002', 'dd-mm-yyyy'), 10, 2914, to_date('31-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919005261, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 3, 6508, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120205005262, to_date('05-02-2012', 'dd-mm-yyyy'), to_date('19-02-2012', 'dd-mm-yyyy'), 8, 5156, to_date('07-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090723005263, to_date('23-07-2009', 'dd-mm-yyyy'), to_date('06-08-2009', 'dd-mm-yyyy'), 11, 7952, to_date('29-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010716005264, to_date('16-07-2001', 'dd-mm-yyyy'), to_date('30-07-2001', 'dd-mm-yyyy'), 10, 3807, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120622005265, to_date('22-06-2012', 'dd-mm-yyyy'), to_date('06-07-2012', 'dd-mm-yyyy'), 5, 6662, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020730005266, to_date('30-07-2002', 'dd-mm-yyyy'), to_date('13-08-2002', 'dd-mm-yyyy'), 2, 2221, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319005267, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 4, 5289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071224005268, to_date('24-12-2007', 'dd-mm-yyyy'), to_date('07-01-2008', 'dd-mm-yyyy'), 6, 5739, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100924005269, to_date('24-09-2010', 'dd-mm-yyyy'), to_date('08-10-2010', 'dd-mm-yyyy'), 6, 5848, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020318005270, to_date('18-03-2002', 'dd-mm-yyyy'), to_date('01-04-2002', 'dd-mm-yyyy'), 7, 2909, to_date('21-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020101005271, to_date('01-01-2002', 'dd-mm-yyyy'), to_date('15-01-2002', 'dd-mm-yyyy'), 3, 2556, to_date('13-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080628005272, to_date('28-06-2008', 'dd-mm-yyyy'), to_date('12-07-2008', 'dd-mm-yyyy'), 10, 7127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080724005273, to_date('24-07-2008', 'dd-mm-yyyy'), to_date('07-08-2008', 'dd-mm-yyyy'), 7, 6412, to_date('02-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091220005274, to_date('20-12-2009', 'dd-mm-yyyy'), to_date('03-01-2010', 'dd-mm-yyyy'), 7, 5305, to_date('31-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070523005275, to_date('23-05-2007', 'dd-mm-yyyy'), to_date('06-06-2007', 'dd-mm-yyyy'), 4, 4433, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030911005276, to_date('11-09-2003', 'dd-mm-yyyy'), to_date('25-09-2003', 'dd-mm-yyyy'), 11, 2996, to_date('25-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120526005277, to_date('26-05-2012', 'dd-mm-yyyy'), to_date('09-06-2012', 'dd-mm-yyyy'), 5, 7771, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101210005278, to_date('10-12-2010', 'dd-mm-yyyy'), to_date('24-12-2010', 'dd-mm-yyyy'), 5, 7485, to_date('19-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408005279, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 6, 9998, to_date('12-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303005280, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 11, 5263, to_date('06-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130611005281, to_date('11-06-2013', 'dd-mm-yyyy'), to_date('25-06-2013', 'dd-mm-yyyy'), 8, 8148, to_date('23-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060218005282, to_date('18-02-2006', 'dd-mm-yyyy'), to_date('04-03-2006', 'dd-mm-yyyy'), 3, 6659, to_date('04-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041217005283, to_date('17-12-2004', 'dd-mm-yyyy'), to_date('31-12-2004', 'dd-mm-yyyy'), 5, 3766, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040226005284, to_date('26-02-2004', 'dd-mm-yyyy'), to_date('11-03-2004', 'dd-mm-yyyy'), 11, 3071, to_date('09-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226005285, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 2, 3299, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080407005286, to_date('07-04-2008', 'dd-mm-yyyy'), to_date('21-04-2008', 'dd-mm-yyyy'), 1, 6196, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041017005287, to_date('17-10-2004', 'dd-mm-yyyy'), to_date('31-10-2004', 'dd-mm-yyyy'), 9, 5823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060517005288, to_date('17-05-2006', 'dd-mm-yyyy'), to_date('31-05-2006', 'dd-mm-yyyy'), 4, 6540, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031113005289, to_date('13-11-2003', 'dd-mm-yyyy'), to_date('27-11-2003', 'dd-mm-yyyy'), 2, 3480, to_date('20-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140426005290, to_date('26-04-2014', 'dd-mm-yyyy'), to_date('10-05-2014', 'dd-mm-yyyy'), 6, 11704, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030921005291, to_date('21-09-2003', 'dd-mm-yyyy'), to_date('05-10-2003', 'dd-mm-yyyy'), 2, 2609, to_date('30-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319005292, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 5, 7482, to_date('30-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524005293, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 11, 9821, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010102005294, to_date('02-01-2001', 'dd-mm-yyyy'), to_date('16-01-2001', 'dd-mm-yyyy'), 4, 1634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011215005295, to_date('15-12-2001', 'dd-mm-yyyy'), to_date('29-12-2001', 'dd-mm-yyyy'), 10, 2571, to_date('29-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041219005296, to_date('19-12-2004', 'dd-mm-yyyy'), to_date('02-01-2005', 'dd-mm-yyyy'), 6, 3067, to_date('08-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018005297, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 7, 4965, to_date('03-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130328005298, to_date('28-03-2013', 'dd-mm-yyyy'), to_date('11-04-2013', 'dd-mm-yyyy'), 6, 8264, to_date('09-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007005299, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 6, 3347, to_date('09-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121030005300, to_date('30-10-2012', 'dd-mm-yyyy'), to_date('13-11-2012', 'dd-mm-yyyy'), 7, 9180, to_date('04-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020729005301, to_date('29-07-2002', 'dd-mm-yyyy'), to_date('12-08-2002', 'dd-mm-yyyy'), 10, 3212, to_date('05-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070918005302, to_date('18-09-2007', 'dd-mm-yyyy'), to_date('02-10-2007', 'dd-mm-yyyy'), 10, 6321, to_date('23-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080112005303, to_date('12-01-2008', 'dd-mm-yyyy'), to_date('26-01-2008', 'dd-mm-yyyy'), 2, 6922, to_date('30-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100504005304, to_date('04-05-2010', 'dd-mm-yyyy'), to_date('18-05-2010', 'dd-mm-yyyy'), 3, 7276, to_date('08-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110411005305, to_date('11-04-2011', 'dd-mm-yyyy'), to_date('25-04-2011', 'dd-mm-yyyy'), 9, 8020, to_date('29-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051023005306, to_date('23-10-2005', 'dd-mm-yyyy'), to_date('06-11-2005', 'dd-mm-yyyy'), 9, 4812, to_date('10-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031123005307, to_date('23-11-2003', 'dd-mm-yyyy'), to_date('07-12-2003', 'dd-mm-yyyy'), 9, 2771, to_date('11-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080715005308, to_date('15-07-2008', 'dd-mm-yyyy'), to_date('29-07-2008', 'dd-mm-yyyy'), 6, 4547, to_date('26-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123005309, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 4, 2974, to_date('30-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020905005310, to_date('05-09-2002', 'dd-mm-yyyy'), to_date('19-09-2002', 'dd-mm-yyyy'), 7, 3277, to_date('17-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080410005311, to_date('10-04-2008', 'dd-mm-yyyy'), to_date('24-04-2008', 'dd-mm-yyyy'), 11, 6765, to_date('20-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090616005312, to_date('16-06-2009', 'dd-mm-yyyy'), to_date('30-06-2009', 'dd-mm-yyyy'), 7, 5871, to_date('04-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100120005313, to_date('20-01-2010', 'dd-mm-yyyy'), to_date('03-02-2010', 'dd-mm-yyyy'), 9, 7403, to_date('03-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112005314, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 7, 4876, to_date('30-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071016005315, to_date('16-10-2007', 'dd-mm-yyyy'), to_date('30-10-2007', 'dd-mm-yyyy'), 12, 2858, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100421005316, to_date('21-04-2010', 'dd-mm-yyyy'), to_date('05-05-2010', 'dd-mm-yyyy'), 2, 7784, to_date('01-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021120005317, to_date('20-11-2002', 'dd-mm-yyyy'), to_date('04-12-2002', 'dd-mm-yyyy'), 9, 3325, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070105005318, to_date('05-01-2007', 'dd-mm-yyyy'), to_date('19-01-2007', 'dd-mm-yyyy'), 9, 4373, to_date('18-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010601005319, to_date('01-06-2001', 'dd-mm-yyyy'), to_date('15-06-2001', 'dd-mm-yyyy'), 9, 2010, to_date('16-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001030005320, to_date('30-10-2000', 'dd-mm-yyyy'), to_date('13-11-2000', 'dd-mm-yyyy'), 11, 1293, to_date('08-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601005321, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 10, 7633, to_date('19-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214005322, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 12, 5592, to_date('27-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130619005323, to_date('19-06-2013', 'dd-mm-yyyy'), to_date('03-07-2013', 'dd-mm-yyyy'), 7, 7274, to_date('28-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111108005324, to_date('08-11-2011', 'dd-mm-yyyy'), to_date('22-11-2011', 'dd-mm-yyyy'), 3, 8957, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080424005325, to_date('24-04-2008', 'dd-mm-yyyy'), to_date('08-05-2008', 'dd-mm-yyyy'), 11, 6341, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070404005326, to_date('04-04-2007', 'dd-mm-yyyy'), to_date('18-04-2007', 'dd-mm-yyyy'), 7, 4929, to_date('10-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041011005327, to_date('11-10-2004', 'dd-mm-yyyy'), to_date('25-10-2004', 'dd-mm-yyyy'), 3, 3661, to_date('22-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031003005328, to_date('03-10-2003', 'dd-mm-yyyy'), to_date('17-10-2003', 'dd-mm-yyyy'), 6, 3673, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060610005329, to_date('10-06-2006', 'dd-mm-yyyy'), to_date('24-06-2006', 'dd-mm-yyyy'), 10, 5734, to_date('25-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001107005330, to_date('07-11-2000', 'dd-mm-yyyy'), to_date('21-11-2000', 'dd-mm-yyyy'), 5, 1324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230005331, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 6, 2788, to_date('12-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013005332, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 2, 8380, to_date('29-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020714005333, to_date('14-07-2002', 'dd-mm-yyyy'), to_date('28-07-2002', 'dd-mm-yyyy'), 5, 2226, to_date('29-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080626005334, to_date('26-06-2008', 'dd-mm-yyyy'), to_date('10-07-2008', 'dd-mm-yyyy'), 6, 6327, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214005335, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 6, 7776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070816005336, to_date('16-08-2007', 'dd-mm-yyyy'), to_date('30-08-2007', 'dd-mm-yyyy'), 1, 5314, to_date('02-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213005337, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 8, 3600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901005338, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 11, 1400, to_date('15-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922005339, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 7, 8615, to_date('24-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100209005340, to_date('09-02-2010', 'dd-mm-yyyy'), to_date('23-02-2010', 'dd-mm-yyyy'), 2, 6560, to_date('18-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505005341, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 3, 4415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010802005342, to_date('02-08-2001', 'dd-mm-yyyy'), to_date('16-08-2001', 'dd-mm-yyyy'), 12, 4053, to_date('13-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120515005343, to_date('15-05-2012', 'dd-mm-yyyy'), to_date('29-05-2012', 'dd-mm-yyyy'), 7, 7194, to_date('28-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821005344, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 10, 8027, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090910005345, to_date('10-09-2009', 'dd-mm-yyyy'), to_date('24-09-2009', 'dd-mm-yyyy'), 1, 5964, to_date('17-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314005346, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 5, 6104, to_date('25-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503005347, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 8, 5297, to_date('04-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726005348, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 10, 6738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060320005349, to_date('20-03-2006', 'dd-mm-yyyy'), to_date('03-04-2006', 'dd-mm-yyyy'), 3, 4139, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080203005350, to_date('03-02-2008', 'dd-mm-yyyy'), to_date('17-02-2008', 'dd-mm-yyyy'), 5, 3367, to_date('12-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090907005351, to_date('07-09-2009', 'dd-mm-yyyy'), to_date('21-09-2009', 'dd-mm-yyyy'), 6, 9344, to_date('22-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209005352, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 8, 4077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041218005353, to_date('18-12-2004', 'dd-mm-yyyy'), to_date('01-01-2005', 'dd-mm-yyyy'), 10, 4646, to_date('30-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427005354, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 2, 3013, to_date('12-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601005355, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 3, 9607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100219007497, to_date('19-02-2010', 'dd-mm-yyyy'), to_date('05-03-2010', 'dd-mm-yyyy'), 6, 7750, to_date('10-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000826007498, to_date('26-08-2000', 'dd-mm-yyyy'), to_date('09-09-2000', 'dd-mm-yyyy'), 6, 3992, to_date('07-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031223007499, to_date('23-12-2003', 'dd-mm-yyyy'), to_date('06-01-2004', 'dd-mm-yyyy'), 3, 4135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060524007500, to_date('24-05-2006', 'dd-mm-yyyy'), to_date('07-06-2006', 'dd-mm-yyyy'), 7, 6694, to_date('07-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110925007501, to_date('25-09-2011', 'dd-mm-yyyy'), to_date('09-10-2011', 'dd-mm-yyyy'), 7, 7709, to_date('01-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010908007502, to_date('08-09-2001', 'dd-mm-yyyy'), to_date('22-09-2001', 'dd-mm-yyyy'), 4, 2718, to_date('14-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030509007503, to_date('09-05-2003', 'dd-mm-yyyy'), to_date('23-05-2003', 'dd-mm-yyyy'), 5, 1531, to_date('15-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080627007504, to_date('27-06-2008', 'dd-mm-yyyy'), to_date('11-07-2008', 'dd-mm-yyyy'), 3, 5965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040515007505, to_date('15-05-2004', 'dd-mm-yyyy'), to_date('29-05-2004', 'dd-mm-yyyy'), 7, 4235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120830007506, to_date('30-08-2012', 'dd-mm-yyyy'), to_date('13-09-2012', 'dd-mm-yyyy'), 7, 7029, to_date('08-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010216007507, to_date('16-02-2001', 'dd-mm-yyyy'), to_date('02-03-2001', 'dd-mm-yyyy'), 10, 2465, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070423007508, to_date('23-04-2007', 'dd-mm-yyyy'), to_date('07-05-2007', 'dd-mm-yyyy'), 2, 3889, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090108007509, to_date('08-01-2009', 'dd-mm-yyyy'), to_date('22-01-2009', 'dd-mm-yyyy'), 9, 5392, to_date('17-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050426007510, to_date('26-04-2005', 'dd-mm-yyyy'), to_date('10-05-2005', 'dd-mm-yyyy'), 7, 2958, to_date('09-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130609007511, to_date('09-06-2013', 'dd-mm-yyyy'), to_date('23-06-2013', 'dd-mm-yyyy'), 6, 8503, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210007512, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 7, 9278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040407007513, to_date('07-04-2004', 'dd-mm-yyyy'), to_date('21-04-2004', 'dd-mm-yyyy'), 7, 5413, to_date('14-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000908007514, to_date('08-09-2000', 'dd-mm-yyyy'), to_date('22-09-2000', 'dd-mm-yyyy'), 3, 1598, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130007515, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 9, 5827, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220007516, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 4, 8063, to_date('21-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110126007517, to_date('26-01-2011', 'dd-mm-yyyy'), to_date('09-02-2011', 'dd-mm-yyyy'), 10, 7798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040708007518, to_date('08-07-2004', 'dd-mm-yyyy'), to_date('22-07-2004', 'dd-mm-yyyy'), 5, 3901, to_date('16-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071208007519, to_date('08-12-2007', 'dd-mm-yyyy'), to_date('22-12-2007', 'dd-mm-yyyy'), 7, 5531, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110927007520, to_date('27-09-2011', 'dd-mm-yyyy'), to_date('11-10-2011', 'dd-mm-yyyy'), 3, 7384, to_date('02-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130113007521, to_date('13-01-2013', 'dd-mm-yyyy'), to_date('27-01-2013', 'dd-mm-yyyy'), 4, 6824, to_date('30-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050308007522, to_date('08-03-2005', 'dd-mm-yyyy'), to_date('22-03-2005', 'dd-mm-yyyy'), 2, 4015, to_date('23-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120816007523, to_date('16-08-2012', 'dd-mm-yyyy'), to_date('30-08-2012', 'dd-mm-yyyy'), 5, 7317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815007524, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 4, 6358, to_date('23-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060417007525, to_date('17-04-2006', 'dd-mm-yyyy'), to_date('01-05-2006', 'dd-mm-yyyy'), 11, 3132, to_date('05-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051030007526, to_date('30-10-2005', 'dd-mm-yyyy'), to_date('13-11-2005', 'dd-mm-yyyy'), 5, 7090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008007527, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 1, 7524, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090902007528, to_date('02-09-2009', 'dd-mm-yyyy'), to_date('16-09-2009', 'dd-mm-yyyy'), 1, 4332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000313007529, to_date('13-03-2000', 'dd-mm-yyyy'), to_date('27-03-2000', 'dd-mm-yyyy'), 2, 3697, to_date('01-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101216007530, to_date('16-12-2010', 'dd-mm-yyyy'), to_date('30-12-2010', 'dd-mm-yyyy'), 10, 6291, to_date('04-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061004007531, to_date('04-10-2006', 'dd-mm-yyyy'), to_date('18-10-2006', 'dd-mm-yyyy'), 6, 4115, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110222007532, to_date('22-02-2011', 'dd-mm-yyyy'), to_date('08-03-2011', 'dd-mm-yyyy'), 8, 6606, to_date('04-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119007533, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 4, 11004, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030820007534, to_date('20-08-2003', 'dd-mm-yyyy'), to_date('03-09-2003', 'dd-mm-yyyy'), 8, 2986, to_date('05-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080509007535, to_date('09-05-2008', 'dd-mm-yyyy'), to_date('23-05-2008', 'dd-mm-yyyy'), 8, 3676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080603007536, to_date('03-06-2008', 'dd-mm-yyyy'), to_date('17-06-2008', 'dd-mm-yyyy'), 9, 6311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050820007537, to_date('20-08-2005', 'dd-mm-yyyy'), to_date('03-09-2005', 'dd-mm-yyyy'), 3, 4514, to_date('24-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030613007538, to_date('13-06-2003', 'dd-mm-yyyy'), to_date('27-06-2003', 'dd-mm-yyyy'), 7, 2829, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725007539, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 2, 8992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080403007540, to_date('03-04-2008', 'dd-mm-yyyy'), to_date('17-04-2008', 'dd-mm-yyyy'), 8, 5305, to_date('09-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010331007541, to_date('31-03-2001', 'dd-mm-yyyy'), to_date('14-04-2001', 'dd-mm-yyyy'), 6, 4340, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000414007542, to_date('14-04-2000', 'dd-mm-yyyy'), to_date('28-04-2000', 'dd-mm-yyyy'), 3, 415, to_date('21-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140401007543, to_date('01-04-2014', 'dd-mm-yyyy'), to_date('15-04-2014', 'dd-mm-yyyy'), 8, 6942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080526007544, to_date('26-05-2008', 'dd-mm-yyyy'), to_date('09-06-2008', 'dd-mm-yyyy'), 9, 8262, to_date('14-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080831007545, to_date('31-08-2008', 'dd-mm-yyyy'), to_date('14-09-2008', 'dd-mm-yyyy'), 5, 5959, to_date('19-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927007546, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 12, 7812, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130312007547, to_date('12-03-2013', 'dd-mm-yyyy'), to_date('26-03-2013', 'dd-mm-yyyy'), 5, 7511, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127007548, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 9, 3080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071209007549, to_date('09-12-2007', 'dd-mm-yyyy'), to_date('23-12-2007', 'dd-mm-yyyy'), 3, 6343, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080813007550, to_date('13-08-2008', 'dd-mm-yyyy'), to_date('27-08-2008', 'dd-mm-yyyy'), 4, 5440, to_date('28-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031007007551, to_date('07-10-2003', 'dd-mm-yyyy'), to_date('21-10-2003', 'dd-mm-yyyy'), 12, 2128, to_date('15-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521007552, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 9, 2998, to_date('10-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060605007553, to_date('05-06-2006', 'dd-mm-yyyy'), to_date('19-06-2006', 'dd-mm-yyyy'), 9, 7452, to_date('13-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010108007554, to_date('08-01-2001', 'dd-mm-yyyy'), to_date('22-01-2001', 'dd-mm-yyyy'), 4, 5313, to_date('11-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912007555, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 4, 2235, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201007556, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 10, 2644, to_date('10-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050701007557, to_date('01-07-2005', 'dd-mm-yyyy'), to_date('15-07-2005', 'dd-mm-yyyy'), 9, 2681, to_date('09-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060705007558, to_date('05-07-2006', 'dd-mm-yyyy'), to_date('19-07-2006', 'dd-mm-yyyy'), 3, 4698, to_date('17-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030729007559, to_date('29-07-2003', 'dd-mm-yyyy'), to_date('12-08-2003', 'dd-mm-yyyy'), 4, 3098, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030709007560, to_date('09-07-2003', 'dd-mm-yyyy'), to_date('23-07-2003', 'dd-mm-yyyy'), 12, 3745, to_date('23-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903007561, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 9, 700, to_date('13-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208007562, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 2, 4335, to_date('16-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020807007563, to_date('07-08-2002', 'dd-mm-yyyy'), to_date('21-08-2002', 'dd-mm-yyyy'), 6, 2513, to_date('23-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002007564, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 2, 3475, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041017007565, to_date('17-10-2004', 'dd-mm-yyyy'), to_date('31-10-2004', 'dd-mm-yyyy'), 3, 2804, to_date('25-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100520007566, to_date('20-05-2010', 'dd-mm-yyyy'), to_date('03-06-2010', 'dd-mm-yyyy'), 6, 5289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070411007567, to_date('11-04-2007', 'dd-mm-yyyy'), to_date('25-04-2007', 'dd-mm-yyyy'), 5, 4425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426007568, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 6, 1768, to_date('10-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070321007569, to_date('21-03-2007', 'dd-mm-yyyy'), to_date('04-04-2007', 'dd-mm-yyyy'), 7, 5868, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120114007570, to_date('14-01-2012', 'dd-mm-yyyy'), to_date('28-01-2012', 'dd-mm-yyyy'), 12, 8327, to_date('31-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123007571, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 6, 11925, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509007572, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 1, 3732, to_date('11-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926007573, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 2, 4431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070508007574, to_date('08-05-2007', 'dd-mm-yyyy'), to_date('22-05-2007', 'dd-mm-yyyy'), 7, 5864, to_date('11-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110007575, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 6, 6088, to_date('30-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130131007576, to_date('31-01-2013', 'dd-mm-yyyy'), to_date('14-02-2013', 'dd-mm-yyyy'), 10, 7580, to_date('13-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041116007577, to_date('16-11-2004', 'dd-mm-yyyy'), to_date('30-11-2004', 'dd-mm-yyyy'), 6, 4114, to_date('30-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040707007578, to_date('07-07-2004', 'dd-mm-yyyy'), to_date('21-07-2004', 'dd-mm-yyyy'), 11, 3427, to_date('20-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061030007579, to_date('30-10-2006', 'dd-mm-yyyy'), to_date('13-11-2006', 'dd-mm-yyyy'), 5, 7362, to_date('17-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404007580, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 4, 2654, to_date('14-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507007581, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 9, 9753, to_date('14-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430007582, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 4, 8987, to_date('09-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121019007583, to_date('19-10-2012', 'dd-mm-yyyy'), to_date('02-11-2012', 'dd-mm-yyyy'), 7, 8108, to_date('25-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040604007584, to_date('04-06-2004', 'dd-mm-yyyy'), to_date('18-06-2004', 'dd-mm-yyyy'), 4, 2696, to_date('20-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100815007585, to_date('15-08-2010', 'dd-mm-yyyy'), to_date('29-08-2010', 'dd-mm-yyyy'), 8, 7981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615007586, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 7, 7013, to_date('30-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050415007587, to_date('15-04-2005', 'dd-mm-yyyy'), to_date('29-04-2005', 'dd-mm-yyyy'), 11, 2614, to_date('20-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212007588, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 8, 4226, to_date('24-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070312007589, to_date('12-03-2007', 'dd-mm-yyyy'), to_date('26-03-2007', 'dd-mm-yyyy'), 12, 5679, to_date('29-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060227007590, to_date('27-02-2006', 'dd-mm-yyyy'), to_date('13-03-2006', 'dd-mm-yyyy'), 8, 5569, to_date('16-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100504007591, to_date('04-05-2010', 'dd-mm-yyyy'), to_date('18-05-2010', 'dd-mm-yyyy'), 4, 5773, to_date('12-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801007592, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 10, 9844, to_date('07-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304007593, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 4, 1431, to_date('23-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090418007594, to_date('18-04-2009', 'dd-mm-yyyy'), to_date('02-05-2009', 'dd-mm-yyyy'), 3, 6476, to_date('30-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501007595, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 5, 2432, to_date('19-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010924007596, to_date('24-09-2001', 'dd-mm-yyyy'), to_date('08-10-2001', 'dd-mm-yyyy'), 10, 2284, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140502007597, to_date('02-05-2014', 'dd-mm-yyyy'), to_date('16-05-2014', 'dd-mm-yyyy'), 6, 6449, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070224007598, to_date('24-02-2007', 'dd-mm-yyyy'), to_date('10-03-2007', 'dd-mm-yyyy'), 12, 3755, to_date('08-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010830007599, to_date('30-08-2001', 'dd-mm-yyyy'), to_date('13-09-2001', 'dd-mm-yyyy'), 4, 4388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031107007600, to_date('07-11-2003', 'dd-mm-yyyy'), to_date('21-11-2003', 'dd-mm-yyyy'), 5, 2515, to_date('18-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030514007601, to_date('14-05-2003', 'dd-mm-yyyy'), to_date('28-05-2003', 'dd-mm-yyyy'), 8, 3972, to_date('20-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219007602, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 4, 1806, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001212007603, to_date('12-12-2000', 'dd-mm-yyyy'), to_date('26-12-2000', 'dd-mm-yyyy'), 5, 1438, to_date('21-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110916007604, to_date('16-09-2011', 'dd-mm-yyyy'), to_date('30-09-2011', 'dd-mm-yyyy'), 11, 5725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041004007605, to_date('04-10-2004', 'dd-mm-yyyy'), to_date('18-10-2004', 'dd-mm-yyyy'), 8, 3860, to_date('08-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130314007606, to_date('14-03-2013', 'dd-mm-yyyy'), to_date('28-03-2013', 'dd-mm-yyyy'), 2, 7136, to_date('15-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130222007607, to_date('22-02-2013', 'dd-mm-yyyy'), to_date('08-03-2013', 'dd-mm-yyyy'), 6, 8075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020720007608, to_date('20-07-2002', 'dd-mm-yyyy'), to_date('03-08-2002', 'dd-mm-yyyy'), 11, 2253, to_date('27-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040729007609, to_date('29-07-2004', 'dd-mm-yyyy'), to_date('12-08-2004', 'dd-mm-yyyy'), 12, 3607, to_date('15-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120113007610, to_date('13-01-2012', 'dd-mm-yyyy'), to_date('27-01-2012', 'dd-mm-yyyy'), 7, 7135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022007611, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 10, 3644, to_date('26-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921007612, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 8, 2757, to_date('01-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030723007613, to_date('23-07-2003', 'dd-mm-yyyy'), to_date('06-08-2003', 'dd-mm-yyyy'), 6, 5246, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120617007614, to_date('17-06-2012', 'dd-mm-yyyy'), to_date('01-07-2012', 'dd-mm-yyyy'), 6, 8490, to_date('19-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101217007615, to_date('17-12-2010', 'dd-mm-yyyy'), to_date('31-12-2010', 'dd-mm-yyyy'), 4, 6620, to_date('21-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706007616, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 12, 7317, to_date('16-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060721007617, to_date('21-07-2006', 'dd-mm-yyyy'), to_date('04-08-2006', 'dd-mm-yyyy'), 9, 6502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040712007618, to_date('12-07-2004', 'dd-mm-yyyy'), to_date('26-07-2004', 'dd-mm-yyyy'), 12, 3573, to_date('18-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001020007619, to_date('20-10-2000', 'dd-mm-yyyy'), to_date('03-11-2000', 'dd-mm-yyyy'), 10, 1312, to_date('05-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070304007620, to_date('04-03-2007', 'dd-mm-yyyy'), to_date('18-03-2007', 'dd-mm-yyyy'), 1, 6385, to_date('05-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050916007621, to_date('16-09-2005', 'dd-mm-yyyy'), to_date('30-09-2005', 'dd-mm-yyyy'), 4, 3805, to_date('30-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210007622, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 9, 7122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227007623, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 5, 4084, to_date('06-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090901007624, to_date('01-09-2009', 'dd-mm-yyyy'), to_date('15-09-2009', 'dd-mm-yyyy'), 9, 6289, to_date('14-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503007625, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 6, 4819, to_date('21-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080316007626, to_date('16-03-2008', 'dd-mm-yyyy'), to_date('30-03-2008', 'dd-mm-yyyy'), 5, 6480, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010101007627, to_date('01-01-2001', 'dd-mm-yyyy'), to_date('15-01-2001', 'dd-mm-yyyy'), 7, 1908, to_date('08-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318007628, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 10, 9369, to_date('02-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100816007629, to_date('16-08-2010', 'dd-mm-yyyy'), to_date('30-08-2010', 'dd-mm-yyyy'), 6, 8460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030326007630, to_date('26-03-2003', 'dd-mm-yyyy'), to_date('09-04-2003', 'dd-mm-yyyy'), 9, 4802, to_date('15-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030703007631, to_date('03-07-2003', 'dd-mm-yyyy'), to_date('17-07-2003', 'dd-mm-yyyy'), 5, 1222, to_date('11-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080704007632, to_date('04-07-2008', 'dd-mm-yyyy'), to_date('18-07-2008', 'dd-mm-yyyy'), 8, 5034, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031202007633, to_date('02-12-2003', 'dd-mm-yyyy'), to_date('16-12-2003', 'dd-mm-yyyy'), 1, 4779, to_date('08-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921007634, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 5, 2203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140427007635, to_date('27-04-2014', 'dd-mm-yyyy'), to_date('11-05-2014', 'dd-mm-yyyy'), 4, 5957, to_date('01-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111222007636, to_date('22-12-2011', 'dd-mm-yyyy'), to_date('05-01-2012', 'dd-mm-yyyy'), 5, 10599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080706007637, to_date('06-07-2008', 'dd-mm-yyyy'), to_date('20-07-2008', 'dd-mm-yyyy'), 6, 3806, to_date('16-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011127007638, to_date('27-11-2001', 'dd-mm-yyyy'), to_date('11-12-2001', 'dd-mm-yyyy'), 8, 3181, to_date('17-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060809007639, to_date('09-08-2006', 'dd-mm-yyyy'), to_date('23-08-2006', 'dd-mm-yyyy'), 10, 3588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070809007640, to_date('09-08-2007', 'dd-mm-yyyy'), to_date('23-08-2007', 'dd-mm-yyyy'), 1, 5651, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070215007641, to_date('15-02-2007', 'dd-mm-yyyy'), to_date('01-03-2007', 'dd-mm-yyyy'), 5, 5357, to_date('17-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001108007642, to_date('08-11-2000', 'dd-mm-yyyy'), to_date('22-11-2000', 'dd-mm-yyyy'), 11, 2012, to_date('18-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090327007643, to_date('27-03-2009', 'dd-mm-yyyy'), to_date('10-04-2009', 'dd-mm-yyyy'), 3, 4118, to_date('01-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111210007644, to_date('10-12-2011', 'dd-mm-yyyy'), to_date('24-12-2011', 'dd-mm-yyyy'), 10, 6325, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030729007645, to_date('29-07-2003', 'dd-mm-yyyy'), to_date('12-08-2003', 'dd-mm-yyyy'), 3, 2839, to_date('14-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051029007646, to_date('29-10-2005', 'dd-mm-yyyy'), to_date('12-11-2005', 'dd-mm-yyyy'), 10, 6641, to_date('13-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050922007647, to_date('22-09-2005', 'dd-mm-yyyy'), to_date('06-10-2005', 'dd-mm-yyyy'), 10, 3342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620007648, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 10, 8585, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823007649, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 6, 7587, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090812007650, to_date('12-08-2009', 'dd-mm-yyyy'), to_date('26-08-2009', 'dd-mm-yyyy'), 9, 8811, to_date('31-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050424000613, to_date('24-04-2005', 'dd-mm-yyyy'), to_date('08-05-2005', 'dd-mm-yyyy'), 6, 1740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090526000614, to_date('26-05-2009', 'dd-mm-yyyy'), to_date('09-06-2009', 'dd-mm-yyyy'), 6, 5313, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101000615, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 9, 3829, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080829000616, to_date('29-08-2008', 'dd-mm-yyyy'), to_date('12-09-2008', 'dd-mm-yyyy'), 6, 4848, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822000617, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 8, 8251, to_date('09-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509000618, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 5, 4331, to_date('24-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130409000619, to_date('09-04-2013', 'dd-mm-yyyy'), to_date('23-04-2013', 'dd-mm-yyyy'), 7, 9933, to_date('23-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916000620, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 3, 2665, to_date('25-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806000621, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 12, 4688, to_date('25-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080717000622, to_date('17-07-2008', 'dd-mm-yyyy'), to_date('31-07-2008', 'dd-mm-yyyy'), 8, 3009, to_date('21-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000918000623, to_date('18-09-2000', 'dd-mm-yyyy'), to_date('02-10-2000', 'dd-mm-yyyy'), 5, 522, to_date('04-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090428000624, to_date('28-04-2009', 'dd-mm-yyyy'), to_date('12-05-2009', 'dd-mm-yyyy'), 10, 5581, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011120000625, to_date('20-11-2001', 'dd-mm-yyyy'), to_date('04-12-2001', 'dd-mm-yyyy'), 2, 2458, to_date('24-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010715000626, to_date('15-07-2001', 'dd-mm-yyyy'), to_date('29-07-2001', 'dd-mm-yyyy'), 5, 3127, to_date('16-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100828000627, to_date('28-08-2010', 'dd-mm-yyyy'), to_date('11-09-2010', 'dd-mm-yyyy'), 9, 6552, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080502000628, to_date('02-05-2008', 'dd-mm-yyyy'), to_date('16-05-2008', 'dd-mm-yyyy'), 3, 3864, to_date('18-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504000629, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 2, 11145, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120509000630, to_date('09-05-2012', 'dd-mm-yyyy'), to_date('23-05-2012', 'dd-mm-yyyy'), 4, 10105, to_date('24-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090628000631, to_date('28-06-2009', 'dd-mm-yyyy'), to_date('12-07-2009', 'dd-mm-yyyy'), 1, 6552, to_date('08-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080728000632, to_date('28-07-2008', 'dd-mm-yyyy'), to_date('11-08-2008', 'dd-mm-yyyy'), 11, 6003, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110321000633, to_date('21-03-2011', 'dd-mm-yyyy'), to_date('04-04-2011', 'dd-mm-yyyy'), 5, 9764, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021002000634, to_date('02-10-2002', 'dd-mm-yyyy'), to_date('16-10-2002', 'dd-mm-yyyy'), 3, 4480, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040514000635, to_date('14-05-2004', 'dd-mm-yyyy'), to_date('28-05-2004', 'dd-mm-yyyy'), 11, 1086, to_date('02-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513000636, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 11, 6060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128000637, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 12, 12109, to_date('13-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120216000638, to_date('16-02-2012', 'dd-mm-yyyy'), to_date('01-03-2012', 'dd-mm-yyyy'), 6, 8882, to_date('06-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050610000639, to_date('10-06-2005', 'dd-mm-yyyy'), to_date('24-06-2005', 'dd-mm-yyyy'), 7, 4093, to_date('29-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071228000640, to_date('28-12-2007', 'dd-mm-yyyy'), to_date('11-01-2008', 'dd-mm-yyyy'), 6, 5741, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121103000641, to_date('03-11-2012', 'dd-mm-yyyy'), to_date('17-11-2012', 'dd-mm-yyyy'), 3, 7510, to_date('22-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140512000642, to_date('12-05-2014', 'dd-mm-yyyy'), to_date('26-05-2014', 'dd-mm-yyyy'), 2, 10179, to_date('21-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130902000643, to_date('02-09-2013', 'dd-mm-yyyy'), to_date('16-09-2013', 'dd-mm-yyyy'), 11, 10481, to_date('18-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131005000644, to_date('05-10-2013', 'dd-mm-yyyy'), to_date('19-10-2013', 'dd-mm-yyyy'), 4, 9179, to_date('13-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111122000645, to_date('22-11-2011', 'dd-mm-yyyy'), to_date('06-12-2011', 'dd-mm-yyyy'), 6, 6565, to_date('26-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080831000646, to_date('31-08-2008', 'dd-mm-yyyy'), to_date('14-09-2008', 'dd-mm-yyyy'), 2, 6731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140108000647, to_date('08-01-2014', 'dd-mm-yyyy'), to_date('22-01-2014', 'dd-mm-yyyy'), 5, 11723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060720000648, to_date('20-07-2006', 'dd-mm-yyyy'), to_date('03-08-2006', 'dd-mm-yyyy'), 10, 4390, to_date('31-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208000649, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 8, 6743, to_date('27-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809000650, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 3, 1986, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813000651, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 1, 5879, to_date('29-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000410000652, to_date('10-04-2000', 'dd-mm-yyyy'), to_date('24-04-2000', 'dd-mm-yyyy'), 3, 2057, to_date('23-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225000653, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 11, 5522, to_date('08-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601000654, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 6, 4110, to_date('14-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110304000655, to_date('04-03-2011', 'dd-mm-yyyy'), to_date('18-03-2011', 'dd-mm-yyyy'), 4, 8454, to_date('09-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406000656, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 3, 8658, to_date('18-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726000657, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 5, 4058, to_date('10-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071219000658, to_date('19-12-2007', 'dd-mm-yyyy'), to_date('02-01-2008', 'dd-mm-yyyy'), 7, 5172, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121105000659, to_date('05-11-2012', 'dd-mm-yyyy'), to_date('19-11-2012', 'dd-mm-yyyy'), 2, 7583, to_date('08-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080407000660, to_date('07-04-2008', 'dd-mm-yyyy'), to_date('21-04-2008', 'dd-mm-yyyy'), 10, 5302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617000661, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 11, 1254, to_date('19-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010422000662, to_date('22-04-2001', 'dd-mm-yyyy'), to_date('06-05-2001', 'dd-mm-yyyy'), 7, 1907, to_date('01-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120312000663, to_date('12-03-2012', 'dd-mm-yyyy'), to_date('26-03-2012', 'dd-mm-yyyy'), 2, 9331, to_date('19-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020422000664, to_date('22-04-2002', 'dd-mm-yyyy'), to_date('06-05-2002', 'dd-mm-yyyy'), 3, 2650, to_date('12-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000721000665, to_date('21-07-2000', 'dd-mm-yyyy'), to_date('04-08-2000', 'dd-mm-yyyy'), 12, 889, to_date('31-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031109000666, to_date('09-11-2003', 'dd-mm-yyyy'), to_date('23-11-2003', 'dd-mm-yyyy'), 9, 4761, to_date('25-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081226000667, to_date('26-12-2008', 'dd-mm-yyyy'), to_date('09-01-2009', 'dd-mm-yyyy'), 7, 7249, to_date('08-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021118000668, to_date('18-11-2002', 'dd-mm-yyyy'), to_date('02-12-2002', 'dd-mm-yyyy'), 12, 5135, to_date('04-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080526000669, to_date('26-05-2008', 'dd-mm-yyyy'), to_date('09-06-2008', 'dd-mm-yyyy'), 4, 5365, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121014000670, to_date('14-10-2012', 'dd-mm-yyyy'), to_date('28-10-2012', 'dd-mm-yyyy'), 8, 9769, to_date('18-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050108000671, to_date('08-01-2005', 'dd-mm-yyyy'), to_date('22-01-2005', 'dd-mm-yyyy'), 4, 5583, to_date('23-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031000672, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 8, 3628, to_date('09-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070106000673, to_date('06-01-2007', 'dd-mm-yyyy'), to_date('20-01-2007', 'dd-mm-yyyy'), 10, 6506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140314000674, to_date('14-03-2014', 'dd-mm-yyyy'), to_date('28-03-2014', 'dd-mm-yyyy'), 3, 7154, to_date('16-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021107000675, to_date('07-11-2002', 'dd-mm-yyyy'), to_date('21-11-2002', 'dd-mm-yyyy'), 8, 3065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050108000676, to_date('08-01-2005', 'dd-mm-yyyy'), to_date('22-01-2005', 'dd-mm-yyyy'), 12, 3650, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628000677, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 4, 9392, to_date('17-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041102000678, to_date('02-11-2004', 'dd-mm-yyyy'), to_date('16-11-2004', 'dd-mm-yyyy'), 11, 3440, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110828000679, to_date('28-08-2011', 'dd-mm-yyyy'), to_date('11-09-2011', 'dd-mm-yyyy'), 8, 10784, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041215000680, to_date('15-12-2004', 'dd-mm-yyyy'), to_date('29-12-2004', 'dd-mm-yyyy'), 12, 3969, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202000681, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 3, 5681, to_date('19-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070809000682, to_date('09-08-2007', 'dd-mm-yyyy'), to_date('23-08-2007', 'dd-mm-yyyy'), 3, 5378, to_date('25-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725000683, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 1, 9683, to_date('08-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050811000684, to_date('11-08-2005', 'dd-mm-yyyy'), to_date('25-08-2005', 'dd-mm-yyyy'), 2, 7321, to_date('16-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140120000685, to_date('20-01-2014', 'dd-mm-yyyy'), to_date('03-02-2014', 'dd-mm-yyyy'), 5, 8583, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822000686, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 7, 8464, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080326000687, to_date('26-03-2008', 'dd-mm-yyyy'), to_date('09-04-2008', 'dd-mm-yyyy'), 2, 7186, to_date('07-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050301000688, to_date('01-03-2005', 'dd-mm-yyyy'), to_date('15-03-2005', 'dd-mm-yyyy'), 7, 4639, to_date('09-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050911000689, to_date('11-09-2005', 'dd-mm-yyyy'), to_date('25-09-2005', 'dd-mm-yyyy'), 5, 4387, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000814000690, to_date('14-08-2000', 'dd-mm-yyyy'), to_date('28-08-2000', 'dd-mm-yyyy'), 7, 1767, to_date('20-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120223000691, to_date('23-02-2012', 'dd-mm-yyyy'), to_date('08-03-2012', 'dd-mm-yyyy'), 2, 7829, to_date('10-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051215000692, to_date('15-12-2005', 'dd-mm-yyyy'), to_date('29-12-2005', 'dd-mm-yyyy'), 6, 2037, to_date('27-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121222000693, to_date('22-12-2012', 'dd-mm-yyyy'), to_date('05-01-2013', 'dd-mm-yyyy'), 5, 9482, to_date('06-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030524000694, to_date('24-05-2003', 'dd-mm-yyyy'), to_date('07-06-2003', 'dd-mm-yyyy'), 10, 5192, to_date('29-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121014000695, to_date('14-10-2012', 'dd-mm-yyyy'), to_date('28-10-2012', 'dd-mm-yyyy'), 9, 8488, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716000696, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 3, 3522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915000697, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 3, 4552, to_date('24-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131226000698, to_date('26-12-2013', 'dd-mm-yyyy'), to_date('09-01-2014', 'dd-mm-yyyy'), 5, 9425, to_date('31-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090122000699, to_date('22-01-2009', 'dd-mm-yyyy'), to_date('05-02-2009', 'dd-mm-yyyy'), 2, 5527, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621000700, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 6, 2183, to_date('07-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010202000701, to_date('02-02-2001', 'dd-mm-yyyy'), to_date('16-02-2001', 'dd-mm-yyyy'), 7, 1608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011212000702, to_date('12-12-2001', 'dd-mm-yyyy'), to_date('26-12-2001', 'dd-mm-yyyy'), 10, 2023, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051008000703, to_date('08-10-2005', 'dd-mm-yyyy'), to_date('22-10-2005', 'dd-mm-yyyy'), 9, 3934, to_date('23-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225000704, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 3, 3293, to_date('06-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030216000705, to_date('16-02-2003', 'dd-mm-yyyy'), to_date('02-03-2003', 'dd-mm-yyyy'), 8, 2494, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071220000706, to_date('20-12-2007', 'dd-mm-yyyy'), to_date('03-01-2008', 'dd-mm-yyyy'), 4, 7277, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120331000707, to_date('31-03-2012', 'dd-mm-yyyy'), to_date('14-04-2012', 'dd-mm-yyyy'), 10, 8764, to_date('03-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140102000708, to_date('02-01-2014', 'dd-mm-yyyy'), to_date('16-01-2014', 'dd-mm-yyyy'), 3, 11520, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123000709, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 11, 9121, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121116000710, to_date('16-11-2012', 'dd-mm-yyyy'), to_date('30-11-2012', 'dd-mm-yyyy'), 2, 7023, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060707000711, to_date('07-07-2006', 'dd-mm-yyyy'), to_date('21-07-2006', 'dd-mm-yyyy'), 2, 5544, to_date('19-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517000712, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 6, 7840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070701000713, to_date('01-07-2007', 'dd-mm-yyyy'), to_date('15-07-2007', 'dd-mm-yyyy'), 4, 5335, to_date('13-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050224000714, to_date('24-02-2005', 'dd-mm-yyyy'), to_date('10-03-2005', 'dd-mm-yyyy'), 11, 5557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090504000715, to_date('04-05-2009', 'dd-mm-yyyy'), to_date('18-05-2009', 'dd-mm-yyyy'), 11, 7875, to_date('16-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030614000716, to_date('14-06-2003', 'dd-mm-yyyy'), to_date('28-06-2003', 'dd-mm-yyyy'), 11, 4404, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050618000717, to_date('18-06-2005', 'dd-mm-yyyy'), to_date('02-07-2005', 'dd-mm-yyyy'), 7, 4035, to_date('02-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081125000718, to_date('25-11-2008', 'dd-mm-yyyy'), to_date('09-12-2008', 'dd-mm-yyyy'), 5, 5475, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110831000719, to_date('31-08-2011', 'dd-mm-yyyy'), to_date('14-09-2011', 'dd-mm-yyyy'), 3, 8225, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040724000720, to_date('24-07-2004', 'dd-mm-yyyy'), to_date('07-08-2004', 'dd-mm-yyyy'), 4, 3829, to_date('29-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324000721, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 10, 2468, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070513000722, to_date('13-05-2007', 'dd-mm-yyyy'), to_date('27-05-2007', 'dd-mm-yyyy'), 7, 5513, to_date('23-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081106000723, to_date('06-11-2008', 'dd-mm-yyyy'), to_date('20-11-2008', 'dd-mm-yyyy'), 9, 4553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001013000724, to_date('13-10-2000', 'dd-mm-yyyy'), to_date('27-10-2000', 'dd-mm-yyyy'), 2, 1747, to_date('28-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225000725, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 12, 2430, to_date('29-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030105000726, to_date('05-01-2003', 'dd-mm-yyyy'), to_date('19-01-2003', 'dd-mm-yyyy'), 12, 4059, to_date('23-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806000727, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 4, 2998, to_date('12-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100523000728, to_date('23-05-2010', 'dd-mm-yyyy'), to_date('06-06-2010', 'dd-mm-yyyy'), 9, 4179, to_date('31-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120605000729, to_date('05-06-2012', 'dd-mm-yyyy'), to_date('19-06-2012', 'dd-mm-yyyy'), 7, 10070, to_date('08-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090407000730, to_date('07-04-2009', 'dd-mm-yyyy'), to_date('21-04-2009', 'dd-mm-yyyy'), 4, 7727, to_date('18-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070508000731, to_date('08-05-2007', 'dd-mm-yyyy'), to_date('22-05-2007', 'dd-mm-yyyy'), 11, 5645, to_date('13-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120405000732, to_date('05-04-2012', 'dd-mm-yyyy'), to_date('19-04-2012', 'dd-mm-yyyy'), 10, 9340, to_date('19-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405000733, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 10, 4552, to_date('23-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100718000734, to_date('18-07-2010', 'dd-mm-yyyy'), to_date('01-08-2010', 'dd-mm-yyyy'), 12, 6068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090828000735, to_date('28-08-2009', 'dd-mm-yyyy'), to_date('11-09-2009', 'dd-mm-yyyy'), 7, 4951, to_date('13-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051005000736, to_date('05-10-2005', 'dd-mm-yyyy'), to_date('19-10-2005', 'dd-mm-yyyy'), 7, 3175, to_date('12-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071130000737, to_date('30-11-2007', 'dd-mm-yyyy'), to_date('14-12-2007', 'dd-mm-yyyy'), 8, 7462, to_date('10-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328000738, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 8, 4029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060426000739, to_date('26-04-2006', 'dd-mm-yyyy'), to_date('10-05-2006', 'dd-mm-yyyy'), 12, 5749, to_date('28-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090908000740, to_date('08-09-2009', 'dd-mm-yyyy'), to_date('22-09-2009', 'dd-mm-yyyy'), 9, 6171, to_date('27-09-2009', 'dd-mm-yyyy'));
commit;
prompt 9000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100228000741, to_date('28-02-2010', 'dd-mm-yyyy'), to_date('14-03-2010', 'dd-mm-yyyy'), 6, 6441, to_date('18-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030507000742, to_date('07-05-2003', 'dd-mm-yyyy'), to_date('21-05-2003', 'dd-mm-yyyy'), 4, 3046, to_date('17-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010309000743, to_date('09-03-2001', 'dd-mm-yyyy'), to_date('23-03-2001', 'dd-mm-yyyy'), 11, 2107, to_date('24-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100714000744, to_date('14-07-2010', 'dd-mm-yyyy'), to_date('28-07-2010', 'dd-mm-yyyy'), 4, 7907, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140303000745, to_date('03-03-2014', 'dd-mm-yyyy'), to_date('17-03-2014', 'dd-mm-yyyy'), 5, 9613, to_date('10-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041018000746, to_date('18-10-2004', 'dd-mm-yyyy'), to_date('01-11-2004', 'dd-mm-yyyy'), 2, 3138, to_date('25-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303000747, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 1, 4246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010107000748, to_date('07-01-2001', 'dd-mm-yyyy'), to_date('21-01-2001', 'dd-mm-yyyy'), 9, 2226, to_date('12-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080505000749, to_date('05-05-2008', 'dd-mm-yyyy'), to_date('19-05-2008', 'dd-mm-yyyy'), 11, 5383, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080228000750, to_date('28-02-2008', 'dd-mm-yyyy'), to_date('13-03-2008', 'dd-mm-yyyy'), 2, 4999, to_date('15-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020420000751, to_date('20-04-2002', 'dd-mm-yyyy'), to_date('04-05-2002', 'dd-mm-yyyy'), 9, 1623, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419000752, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 11, 2969, to_date('20-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529000753, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 1, 4444, to_date('16-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090504000754, to_date('04-05-2009', 'dd-mm-yyyy'), to_date('18-05-2009', 'dd-mm-yyyy'), 4, 7852, to_date('09-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130715000755, to_date('15-07-2013', 'dd-mm-yyyy'), to_date('29-07-2013', 'dd-mm-yyyy'), 3, 6310, to_date('02-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702000756, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 8, 3302, to_date('11-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020702000757, to_date('02-07-2002', 'dd-mm-yyyy'), to_date('16-07-2002', 'dd-mm-yyyy'), 4, 2217, to_date('11-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120701000758, to_date('01-07-2012', 'dd-mm-yyyy'), to_date('15-07-2012', 'dd-mm-yyyy'), 7, 9648, to_date('21-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021027000759, to_date('27-10-2002', 'dd-mm-yyyy'), to_date('10-11-2002', 'dd-mm-yyyy'), 10, 2980, to_date('15-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041020000760, to_date('20-10-2004', 'dd-mm-yyyy'), to_date('03-11-2004', 'dd-mm-yyyy'), 5, 4833, to_date('01-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081015000761, to_date('15-10-2008', 'dd-mm-yyyy'), to_date('29-10-2008', 'dd-mm-yyyy'), 8, 5500, to_date('31-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010104000762, to_date('04-01-2001', 'dd-mm-yyyy'), to_date('18-01-2001', 'dd-mm-yyyy'), 11, 1790, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605000763, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 4, 1486, to_date('06-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101130000764, to_date('30-11-2010', 'dd-mm-yyyy'), to_date('14-12-2010', 'dd-mm-yyyy'), 6, 8707, to_date('15-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629002911, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 10, 3436, to_date('14-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110002912, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 12, 4695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104002913, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 5, 8093, to_date('09-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009002914, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 4, 2567, to_date('25-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040608002915, to_date('08-06-2004', 'dd-mm-yyyy'), to_date('22-06-2004', 'dd-mm-yyyy'), 8, 2838, to_date('22-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208002916, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 6, 6160, to_date('18-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525002917, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 4, 1580, to_date('06-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030820002918, to_date('20-08-2003', 'dd-mm-yyyy'), to_date('03-09-2003', 'dd-mm-yyyy'), 2, 3517, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021025002919, to_date('25-10-2002', 'dd-mm-yyyy'), to_date('08-11-2002', 'dd-mm-yyyy'), 8, 2644, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207002920, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 11, 5632, to_date('23-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120908002921, to_date('08-09-2012', 'dd-mm-yyyy'), to_date('22-09-2012', 'dd-mm-yyyy'), 4, 8001, to_date('17-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609002922, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 2, 6535, to_date('18-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120707002923, to_date('07-07-2012', 'dd-mm-yyyy'), to_date('21-07-2012', 'dd-mm-yyyy'), 1, 10679, to_date('17-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090704002924, to_date('04-07-2009', 'dd-mm-yyyy'), to_date('18-07-2009', 'dd-mm-yyyy'), 9, 5087, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620002925, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 3, 2145, to_date('02-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071124002926, to_date('24-11-2007', 'dd-mm-yyyy'), to_date('08-12-2007', 'dd-mm-yyyy'), 9, 5823, to_date('30-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000823002927, to_date('23-08-2000', 'dd-mm-yyyy'), to_date('06-09-2000', 'dd-mm-yyyy'), 6, 2418, to_date('28-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509002928, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 11, 2801, to_date('13-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000421002929, to_date('21-04-2000', 'dd-mm-yyyy'), to_date('05-05-2000', 'dd-mm-yyyy'), 4, 2487, to_date('24-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070718002930, to_date('18-07-2007', 'dd-mm-yyyy'), to_date('01-08-2007', 'dd-mm-yyyy'), 5, 8879, to_date('24-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050831002931, to_date('31-08-2005', 'dd-mm-yyyy'), to_date('14-09-2005', 'dd-mm-yyyy'), 11, 3857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120709002932, to_date('09-07-2012', 'dd-mm-yyyy'), to_date('23-07-2012', 'dd-mm-yyyy'), 3, 10288, to_date('27-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010522002933, to_date('22-05-2001', 'dd-mm-yyyy'), to_date('05-06-2001', 'dd-mm-yyyy'), 11, 1566, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131208002934, to_date('08-12-2013', 'dd-mm-yyyy'), to_date('22-12-2013', 'dd-mm-yyyy'), 6, 6296, to_date('25-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131022002935, to_date('22-10-2013', 'dd-mm-yyyy'), to_date('05-11-2013', 'dd-mm-yyyy'), 2, 9594, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614002936, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 9, 5546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030208002937, to_date('08-02-2003', 'dd-mm-yyyy'), to_date('22-02-2003', 'dd-mm-yyyy'), 3, 4164, to_date('27-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001207002938, to_date('07-12-2000', 'dd-mm-yyyy'), to_date('21-12-2000', 'dd-mm-yyyy'), 2, 1133, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041209002939, to_date('09-12-2004', 'dd-mm-yyyy'), to_date('23-12-2004', 'dd-mm-yyyy'), 3, 4152, to_date('12-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131228002940, to_date('28-12-2013', 'dd-mm-yyyy'), to_date('11-01-2014', 'dd-mm-yyyy'), 7, 6982, to_date('29-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021118002941, to_date('18-11-2002', 'dd-mm-yyyy'), to_date('02-12-2002', 'dd-mm-yyyy'), 6, 2480, to_date('20-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326002942, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 9, 6285, to_date('06-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000103002943, to_date('03-01-2000', 'dd-mm-yyyy'), to_date('17-01-2000', 'dd-mm-yyyy'), 12, 2798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081108002944, to_date('08-11-2008', 'dd-mm-yyyy'), to_date('22-11-2008', 'dd-mm-yyyy'), 3, 5818, to_date('18-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031025002945, to_date('25-10-2003', 'dd-mm-yyyy'), to_date('08-11-2003', 'dd-mm-yyyy'), 12, 3480, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000211002946, to_date('11-02-2000', 'dd-mm-yyyy'), to_date('25-02-2000', 'dd-mm-yyyy'), 9, 2056, to_date('01-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027002947, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 3, 4749, to_date('13-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811002948, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 6, 1436, to_date('15-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000423002949, to_date('23-04-2000', 'dd-mm-yyyy'), to_date('07-05-2000', 'dd-mm-yyyy'), 12, 865, to_date('01-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140126002950, to_date('26-01-2014', 'dd-mm-yyyy'), to_date('09-02-2014', 'dd-mm-yyyy'), 6, 9641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060830002951, to_date('30-08-2006', 'dd-mm-yyyy'), to_date('13-09-2006', 'dd-mm-yyyy'), 6, 5945, to_date('09-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030321002952, to_date('21-03-2003', 'dd-mm-yyyy'), to_date('04-04-2003', 'dd-mm-yyyy'), 6, 2715, to_date('23-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010914002953, to_date('14-09-2001', 'dd-mm-yyyy'), to_date('28-09-2001', 'dd-mm-yyyy'), 4, 3266, to_date('23-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404002954, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 6, 2607, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111002955, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 9, 8676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001124002956, to_date('24-11-2000', 'dd-mm-yyyy'), to_date('08-12-2000', 'dd-mm-yyyy'), 9, 1134, to_date('27-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121026002957, to_date('26-10-2012', 'dd-mm-yyyy'), to_date('09-11-2012', 'dd-mm-yyyy'), 4, 7381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020216002958, to_date('16-02-2002', 'dd-mm-yyyy'), to_date('02-03-2002', 'dd-mm-yyyy'), 9, 2798, to_date('05-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010914002959, to_date('14-09-2001', 'dd-mm-yyyy'), to_date('28-09-2001', 'dd-mm-yyyy'), 8, 2155, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041020002960, to_date('20-10-2004', 'dd-mm-yyyy'), to_date('03-11-2004', 'dd-mm-yyyy'), 3, 2553, to_date('07-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110510002961, to_date('10-05-2011', 'dd-mm-yyyy'), to_date('24-05-2011', 'dd-mm-yyyy'), 10, 9673, to_date('28-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041101002962, to_date('01-11-2004', 'dd-mm-yyyy'), to_date('15-11-2004', 'dd-mm-yyyy'), 9, 3631, to_date('05-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129002963, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 6, 2811, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228002964, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 7, 5884, to_date('10-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411002965, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 9, 6583, to_date('29-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091214002966, to_date('14-12-2009', 'dd-mm-yyyy'), to_date('28-12-2009', 'dd-mm-yyyy'), 5, 6902, to_date('31-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011228002967, to_date('28-12-2001', 'dd-mm-yyyy'), to_date('11-01-2002', 'dd-mm-yyyy'), 2, 3105, to_date('01-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000430002968, to_date('30-04-2000', 'dd-mm-yyyy'), to_date('14-05-2000', 'dd-mm-yyyy'), 9, 894, to_date('04-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010203002969, to_date('03-02-2001', 'dd-mm-yyyy'), to_date('17-02-2001', 'dd-mm-yyyy'), 5, 1757, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100913002970, to_date('13-09-2010', 'dd-mm-yyyy'), to_date('27-09-2010', 'dd-mm-yyyy'), 3, 7619, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020421002971, to_date('21-04-2002', 'dd-mm-yyyy'), to_date('05-05-2002', 'dd-mm-yyyy'), 4, 3158, to_date('06-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010430002972, to_date('30-04-2001', 'dd-mm-yyyy'), to_date('14-05-2001', 'dd-mm-yyyy'), 8, 2851, to_date('11-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215002973, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 8, 5318, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040819002974, to_date('19-08-2004', 'dd-mm-yyyy'), to_date('02-09-2004', 'dd-mm-yyyy'), 6, 3611, to_date('06-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110528002975, to_date('28-05-2011', 'dd-mm-yyyy'), to_date('11-06-2011', 'dd-mm-yyyy'), 4, 6297, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071026002976, to_date('26-10-2007', 'dd-mm-yyyy'), to_date('09-11-2007', 'dd-mm-yyyy'), 3, 7399, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030615002977, to_date('15-06-2003', 'dd-mm-yyyy'), to_date('29-06-2003', 'dd-mm-yyyy'), 11, 3574, to_date('30-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030506002978, to_date('06-05-2003', 'dd-mm-yyyy'), to_date('20-05-2003', 'dd-mm-yyyy'), 10, 3435, to_date('11-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050831002979, to_date('31-08-2005', 'dd-mm-yyyy'), to_date('14-09-2005', 'dd-mm-yyyy'), 4, 4252, to_date('18-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111020002980, to_date('20-10-2011', 'dd-mm-yyyy'), to_date('03-11-2011', 'dd-mm-yyyy'), 9, 9242, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806002981, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 1, 3070, to_date('25-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513002982, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 2, 1219, to_date('02-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018002983, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 10, 2308, to_date('04-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040503002984, to_date('03-05-2004', 'dd-mm-yyyy'), to_date('17-05-2004', 'dd-mm-yyyy'), 9, 5069, to_date('17-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090501002985, to_date('01-05-2009', 'dd-mm-yyyy'), to_date('15-05-2009', 'dd-mm-yyyy'), 5, 7118, to_date('12-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110310002986, to_date('10-03-2011', 'dd-mm-yyyy'), to_date('24-03-2011', 'dd-mm-yyyy'), 2, 9053, to_date('13-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070322002987, to_date('22-03-2007', 'dd-mm-yyyy'), to_date('05-04-2007', 'dd-mm-yyyy'), 8, 4600, to_date('31-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090102002988, to_date('02-01-2009', 'dd-mm-yyyy'), to_date('16-01-2009', 'dd-mm-yyyy'), 10, 7157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080122002989, to_date('22-01-2008', 'dd-mm-yyyy'), to_date('05-02-2008', 'dd-mm-yyyy'), 6, 4013, to_date('24-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716002990, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 4, 2386, to_date('30-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111014002991, to_date('14-10-2011', 'dd-mm-yyyy'), to_date('28-10-2011', 'dd-mm-yyyy'), 8, 7026, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060930002992, to_date('30-09-2006', 'dd-mm-yyyy'), to_date('14-10-2006', 'dd-mm-yyyy'), 6, 5243, to_date('19-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104002993, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 8, 4495, to_date('11-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813002994, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 9, 3591, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100531002995, to_date('31-05-2010', 'dd-mm-yyyy'), to_date('14-06-2010', 'dd-mm-yyyy'), 8, 7774, to_date('09-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101114002996, to_date('14-11-2010', 'dd-mm-yyyy'), to_date('28-11-2010', 'dd-mm-yyyy'), 9, 4343, to_date('26-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040115002997, to_date('15-01-2004', 'dd-mm-yyyy'), to_date('29-01-2004', 'dd-mm-yyyy'), 6, 5911, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101012002998, to_date('12-10-2010', 'dd-mm-yyyy'), to_date('26-10-2010', 'dd-mm-yyyy'), 1, 8207, to_date('17-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030209002999, to_date('09-02-2003', 'dd-mm-yyyy'), to_date('23-02-2003', 'dd-mm-yyyy'), 2, 6264, to_date('16-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140107003000, to_date('07-01-2014', 'dd-mm-yyyy'), to_date('21-01-2014', 'dd-mm-yyyy'), 5, 14124, to_date('21-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726003001, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 3, 1488, to_date('30-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121219003002, to_date('19-12-2012', 'dd-mm-yyyy'), to_date('02-01-2013', 'dd-mm-yyyy'), 6, 10615, to_date('05-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011023003003, to_date('23-10-2001', 'dd-mm-yyyy'), to_date('06-11-2001', 'dd-mm-yyyy'), 3, 1936, to_date('26-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011112003004, to_date('12-11-2001', 'dd-mm-yyyy'), to_date('26-11-2001', 'dd-mm-yyyy'), 6, 1205, to_date('26-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428003005, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 2, 3158, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110324003006, to_date('24-03-2011', 'dd-mm-yyyy'), to_date('07-04-2011', 'dd-mm-yyyy'), 4, 6531, to_date('02-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090802003007, to_date('02-08-2009', 'dd-mm-yyyy'), to_date('16-08-2009', 'dd-mm-yyyy'), 9, 6961, to_date('15-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123003008, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 7, 8132, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100419003009, to_date('19-04-2010', 'dd-mm-yyyy'), to_date('03-05-2010', 'dd-mm-yyyy'), 7, 6371, to_date('20-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822003010, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 2, 7777, to_date('05-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110625003011, to_date('25-06-2011', 'dd-mm-yyyy'), to_date('09-07-2011', 'dd-mm-yyyy'), 8, 8031, to_date('30-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020104003012, to_date('04-01-2002', 'dd-mm-yyyy'), to_date('18-01-2002', 'dd-mm-yyyy'), 1, 3074, to_date('13-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111019003013, to_date('19-10-2011', 'dd-mm-yyyy'), to_date('02-11-2011', 'dd-mm-yyyy'), 12, 6152, to_date('29-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327003014, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 11, 6408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712003015, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 2, 4169, to_date('29-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071019003016, to_date('19-10-2007', 'dd-mm-yyyy'), to_date('02-11-2007', 'dd-mm-yyyy'), 2, 5918, to_date('03-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060301003017, to_date('01-03-2006', 'dd-mm-yyyy'), to_date('15-03-2006', 'dd-mm-yyyy'), 3, 4999, to_date('18-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010320003018, to_date('20-03-2001', 'dd-mm-yyyy'), to_date('03-04-2001', 'dd-mm-yyyy'), 12, 4651, to_date('27-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030705003019, to_date('05-07-2003', 'dd-mm-yyyy'), to_date('19-07-2003', 'dd-mm-yyyy'), 9, 4281, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061114003020, to_date('14-11-2006', 'dd-mm-yyyy'), to_date('28-11-2006', 'dd-mm-yyyy'), 12, 5794, to_date('30-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051228003021, to_date('28-12-2005', 'dd-mm-yyyy'), to_date('11-01-2006', 'dd-mm-yyyy'), 2, 3833, to_date('08-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080228003022, to_date('28-02-2008', 'dd-mm-yyyy'), to_date('13-03-2008', 'dd-mm-yyyy'), 5, 6492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430003023, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 10, 1462, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001116003024, to_date('16-11-2000', 'dd-mm-yyyy'), to_date('30-11-2000', 'dd-mm-yyyy'), 8, 225, to_date('04-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120418003025, to_date('18-04-2012', 'dd-mm-yyyy'), to_date('02-05-2012', 'dd-mm-yyyy'), 9, 8042, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130708003026, to_date('08-07-2013', 'dd-mm-yyyy'), to_date('22-07-2013', 'dd-mm-yyyy'), 7, 9205, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110719003027, to_date('19-07-2011', 'dd-mm-yyyy'), to_date('02-08-2011', 'dd-mm-yyyy'), 6, 10048, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080930003028, to_date('30-09-2008', 'dd-mm-yyyy'), to_date('14-10-2008', 'dd-mm-yyyy'), 6, 6470, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030807003029, to_date('07-08-2003', 'dd-mm-yyyy'), to_date('21-08-2003', 'dd-mm-yyyy'), 5, 4561, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010109003030, to_date('09-01-2001', 'dd-mm-yyyy'), to_date('23-01-2001', 'dd-mm-yyyy'), 9, 2965, to_date('19-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511003031, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 9, 1622, to_date('29-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831003032, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 4, 6130, to_date('13-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050815003033, to_date('15-08-2005', 'dd-mm-yyyy'), to_date('29-08-2005', 'dd-mm-yyyy'), 3, 2915, to_date('20-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020624003034, to_date('24-06-2002', 'dd-mm-yyyy'), to_date('08-07-2002', 'dd-mm-yyyy'), 5, 2962, to_date('27-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000714003035, to_date('14-07-2000', 'dd-mm-yyyy'), to_date('28-07-2000', 'dd-mm-yyyy'), 2, 1928, to_date('18-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080124003036, to_date('24-01-2008', 'dd-mm-yyyy'), to_date('07-02-2008', 'dd-mm-yyyy'), 10, 8493, to_date('04-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010328003037, to_date('28-03-2001', 'dd-mm-yyyy'), to_date('11-04-2001', 'dd-mm-yyyy'), 1, 2158, to_date('13-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121122003038, to_date('22-11-2012', 'dd-mm-yyyy'), to_date('06-12-2012', 'dd-mm-yyyy'), 9, 9064, to_date('30-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928003039, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 9, 5161, to_date('30-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001204003040, to_date('04-12-2000', 'dd-mm-yyyy'), to_date('18-12-2000', 'dd-mm-yyyy'), 3, 1660, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523003041, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 1, 3059, to_date('02-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120604003042, to_date('04-06-2012', 'dd-mm-yyyy'), to_date('18-06-2012', 'dd-mm-yyyy'), 12, 9022, to_date('10-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031027003043, to_date('27-10-2003', 'dd-mm-yyyy'), to_date('10-11-2003', 'dd-mm-yyyy'), 7, 2385, to_date('08-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140203003044, to_date('03-02-2014', 'dd-mm-yyyy'), to_date('17-02-2014', 'dd-mm-yyyy'), 9, 8297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120315003045, to_date('15-03-2012', 'dd-mm-yyyy'), to_date('29-03-2012', 'dd-mm-yyyy'), 2, 9800, to_date('31-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025003046, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 10, 10404, to_date('05-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203003047, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 4, 4045, to_date('07-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061221003048, to_date('21-12-2006', 'dd-mm-yyyy'), to_date('04-01-2007', 'dd-mm-yyyy'), 9, 8136, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140422003049, to_date('22-04-2014', 'dd-mm-yyyy'), to_date('06-05-2014', 'dd-mm-yyyy'), 11, 10401, to_date('09-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502003050, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 12, 8843, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140218003051, to_date('18-02-2014', 'dd-mm-yyyy'), to_date('04-03-2014', 'dd-mm-yyyy'), 2, 8161, to_date('20-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140131003052, to_date('31-01-2014', 'dd-mm-yyyy'), to_date('14-02-2014', 'dd-mm-yyyy'), 10, 7124, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090822003053, to_date('22-08-2009', 'dd-mm-yyyy'), to_date('05-09-2009', 'dd-mm-yyyy'), 7, 5529, to_date('08-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000409003054, to_date('09-04-2000', 'dd-mm-yyyy'), to_date('23-04-2000', 'dd-mm-yyyy'), 11, 2253, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091014003055, to_date('14-10-2009', 'dd-mm-yyyy'), to_date('28-10-2009', 'dd-mm-yyyy'), 9, 5840, to_date('30-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120113003056, to_date('13-01-2012', 'dd-mm-yyyy'), to_date('27-01-2012', 'dd-mm-yyyy'), 2, 8800, to_date('28-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314003057, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 7, 6560, to_date('31-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030330003058, to_date('30-03-2003', 'dd-mm-yyyy'), to_date('13-04-2003', 'dd-mm-yyyy'), 9, 3747, to_date('10-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001105003059, to_date('05-11-2000', 'dd-mm-yyyy'), to_date('19-11-2000', 'dd-mm-yyyy'), 4, 1924, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010330003060, to_date('30-03-2001', 'dd-mm-yyyy'), to_date('13-04-2001', 'dd-mm-yyyy'), 6, 1916, to_date('10-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080310003061, to_date('10-03-2008', 'dd-mm-yyyy'), to_date('24-03-2008', 'dd-mm-yyyy'), 8, 7472, to_date('23-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314012694, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 4, 6581, to_date('16-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090722012695, to_date('22-07-2009', 'dd-mm-yyyy'), to_date('05-08-2009', 'dd-mm-yyyy'), 3, 6438, to_date('30-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910012696, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 2, 6459, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090505012697, to_date('05-05-2009', 'dd-mm-yyyy'), to_date('19-05-2009', 'dd-mm-yyyy'), 2, 6983, to_date('22-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915012698, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 2, 7817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050920012699, to_date('20-09-2005', 'dd-mm-yyyy'), to_date('04-10-2005', 'dd-mm-yyyy'), 3, 4134, to_date('03-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080901012700, to_date('01-09-2008', 'dd-mm-yyyy'), to_date('15-09-2008', 'dd-mm-yyyy'), 2, 6088, to_date('17-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121107012701, to_date('07-11-2012', 'dd-mm-yyyy'), to_date('21-11-2012', 'dd-mm-yyyy'), 3, 7547, to_date('24-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130619012702, to_date('19-06-2013', 'dd-mm-yyyy'), to_date('03-07-2013', 'dd-mm-yyyy'), 2, 9590, to_date('30-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908012703, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 1, 4823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091116012704, to_date('16-11-2009', 'dd-mm-yyyy'), to_date('30-11-2009', 'dd-mm-yyyy'), 2, 8313, to_date('22-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010310012705, to_date('10-03-2001', 'dd-mm-yyyy'), to_date('24-03-2001', 'dd-mm-yyyy'), 1, 1778, to_date('19-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081214012706, to_date('14-12-2008', 'dd-mm-yyyy'), to_date('28-12-2008', 'dd-mm-yyyy'), 2, 4958, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040101012707, to_date('01-01-2004', 'dd-mm-yyyy'), to_date('15-01-2004', 'dd-mm-yyyy'), 2, 2800, to_date('19-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020429012708, to_date('29-04-2002', 'dd-mm-yyyy'), to_date('13-05-2002', 'dd-mm-yyyy'), 4, 3375, to_date('02-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130314012709, to_date('14-03-2013', 'dd-mm-yyyy'), to_date('28-03-2013', 'dd-mm-yyyy'), 3, 9297, to_date('19-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140314012710, to_date('14-03-2014', 'dd-mm-yyyy'), to_date('28-03-2014', 'dd-mm-yyyy'), 2, 9209, to_date('20-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050929012711, to_date('29-09-2005', 'dd-mm-yyyy'), to_date('13-10-2005', 'dd-mm-yyyy'), 3, 4114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100703012712, to_date('03-07-2010', 'dd-mm-yyyy'), to_date('17-07-2010', 'dd-mm-yyyy'), 4, 7273, to_date('18-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000329012713, to_date('29-03-2000', 'dd-mm-yyyy'), to_date('12-04-2000', 'dd-mm-yyyy'), 3, 4390, to_date('18-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080907012714, to_date('07-09-2008', 'dd-mm-yyyy'), to_date('21-09-2008', 'dd-mm-yyyy'), 4, 5482, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010214012715, to_date('14-02-2001', 'dd-mm-yyyy'), to_date('28-02-2001', 'dd-mm-yyyy'), 2, 2234, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050601012716, to_date('01-06-2005', 'dd-mm-yyyy'), to_date('15-06-2005', 'dd-mm-yyyy'), 3, 6808, to_date('06-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406012717, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 3, 8961, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408012718, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 3, 5510, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030331012719, to_date('31-03-2003', 'dd-mm-yyyy'), to_date('14-04-2003', 'dd-mm-yyyy'), 4, 3020, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030610012720, to_date('10-06-2003', 'dd-mm-yyyy'), to_date('24-06-2003', 'dd-mm-yyyy'), 2, 3382, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131011012721, to_date('11-10-2013', 'dd-mm-yyyy'), to_date('25-10-2013', 'dd-mm-yyyy'), 3, 7072, to_date('18-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714012722, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 4, 5496, to_date('20-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926012723, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 3, 3890, to_date('15-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060830012724, to_date('30-08-2006', 'dd-mm-yyyy'), to_date('13-09-2006', 'dd-mm-yyyy'), 2, 3723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091105012725, to_date('05-11-2009', 'dd-mm-yyyy'), to_date('19-11-2009', 'dd-mm-yyyy'), 2, 7650, to_date('14-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713012726, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 3, 8497, to_date('26-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040131012727, to_date('31-01-2004', 'dd-mm-yyyy'), to_date('14-02-2004', 'dd-mm-yyyy'), 3, 3372, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040902012728, to_date('02-09-2004', 'dd-mm-yyyy'), to_date('16-09-2004', 'dd-mm-yyyy'), 4, 6359, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802012729, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 3, 2489, to_date('16-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618012730, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 2, 10015, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100523012731, to_date('23-05-2010', 'dd-mm-yyyy'), to_date('06-06-2010', 'dd-mm-yyyy'), 2, 6374, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050314012732, to_date('14-03-2005', 'dd-mm-yyyy'), to_date('28-03-2005', 'dd-mm-yyyy'), 2, 3899, to_date('16-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130605012733, to_date('05-06-2013', 'dd-mm-yyyy'), to_date('19-06-2013', 'dd-mm-yyyy'), 3, 8910, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129012734, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 3, 4869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120214012735, to_date('14-02-2012', 'dd-mm-yyyy'), to_date('28-02-2012', 'dd-mm-yyyy'), 1, 7842, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020717012736, to_date('17-07-2002', 'dd-mm-yyyy'), to_date('31-07-2002', 'dd-mm-yyyy'), 2, 1836, to_date('03-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021205012737, to_date('05-12-2002', 'dd-mm-yyyy'), to_date('19-12-2002', 'dd-mm-yyyy'), 2, 3447, to_date('07-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000721012738, to_date('21-07-2000', 'dd-mm-yyyy'), to_date('04-08-2000', 'dd-mm-yyyy'), 3, 996, to_date('09-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821012739, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 3, 3092, to_date('26-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120102012740, to_date('02-01-2012', 'dd-mm-yyyy'), to_date('16-01-2012', 'dd-mm-yyyy'), 4, 5976, to_date('11-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100427012741, to_date('27-04-2010', 'dd-mm-yyyy'), to_date('11-05-2010', 'dd-mm-yyyy'), 3, 5500, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051025012742, to_date('25-10-2005', 'dd-mm-yyyy'), to_date('08-11-2005', 'dd-mm-yyyy'), 3, 4962, to_date('09-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111009012743, to_date('09-10-2011', 'dd-mm-yyyy'), to_date('23-10-2011', 'dd-mm-yyyy'), 4, 7123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408012744, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 3, 4642, to_date('26-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050808012745, to_date('08-08-2005', 'dd-mm-yyyy'), to_date('22-08-2005', 'dd-mm-yyyy'), 2, 3857, to_date('26-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513012746, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 1, 9810, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080708012747, to_date('08-07-2008', 'dd-mm-yyyy'), to_date('22-07-2008', 'dd-mm-yyyy'), 2, 5638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040625012748, to_date('25-06-2004', 'dd-mm-yyyy'), to_date('09-07-2004', 'dd-mm-yyyy'), 2, 5634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601012749, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 2, 4857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101014012750, to_date('14-10-2010', 'dd-mm-yyyy'), to_date('28-10-2010', 'dd-mm-yyyy'), 4, 8370, to_date('01-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030703012751, to_date('03-07-2003', 'dd-mm-yyyy'), to_date('17-07-2003', 'dd-mm-yyyy'), 3, 2634, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061005012752, to_date('05-10-2006', 'dd-mm-yyyy'), to_date('19-10-2006', 'dd-mm-yyyy'), 2, 6513, to_date('24-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113012753, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 4, 1758, to_date('22-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011126012754, to_date('26-11-2001', 'dd-mm-yyyy'), to_date('10-12-2001', 'dd-mm-yyyy'), 4, 1128, to_date('01-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140512012755, to_date('12-05-2014', 'dd-mm-yyyy'), to_date('26-05-2014', 'dd-mm-yyyy'), 2, 12030, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040716012756, to_date('16-07-2004', 'dd-mm-yyyy'), to_date('30-07-2004', 'dd-mm-yyyy'), 4, 4913, to_date('26-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070517012757, to_date('17-05-2007', 'dd-mm-yyyy'), to_date('31-05-2007', 'dd-mm-yyyy'), 2, 5327, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051006012758, to_date('06-10-2005', 'dd-mm-yyyy'), to_date('20-10-2005', 'dd-mm-yyyy'), 1, 3941, to_date('13-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080519012759, to_date('19-05-2008', 'dd-mm-yyyy'), to_date('02-06-2008', 'dd-mm-yyyy'), 1, 5676, to_date('21-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106012760, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 1, 8289, to_date('15-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525012761, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 2, 9329, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000405012762, to_date('05-04-2000', 'dd-mm-yyyy'), to_date('19-04-2000', 'dd-mm-yyyy'), 3, 3366, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214012763, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 4, 6622, to_date('15-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031111012764, to_date('11-11-2003', 'dd-mm-yyyy'), to_date('25-11-2003', 'dd-mm-yyyy'), 2, 3432, to_date('21-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218012765, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 2, 6025, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030120012766, to_date('20-01-2003', 'dd-mm-yyyy'), to_date('03-02-2003', 'dd-mm-yyyy'), 4, 2695, to_date('06-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050322012767, to_date('22-03-2005', 'dd-mm-yyyy'), to_date('05-04-2005', 'dd-mm-yyyy'), 2, 4676, to_date('25-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050920012768, to_date('20-09-2005', 'dd-mm-yyyy'), to_date('04-10-2005', 'dd-mm-yyyy'), 3, 3284, to_date('06-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230012769, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 3, 1922, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090918012770, to_date('18-09-2009', 'dd-mm-yyyy'), to_date('02-10-2009', 'dd-mm-yyyy'), 3, 5533, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010120012771, to_date('20-01-2001', 'dd-mm-yyyy'), to_date('03-02-2001', 'dd-mm-yyyy'), 2, 1435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120412012772, to_date('12-04-2012', 'dd-mm-yyyy'), to_date('26-04-2012', 'dd-mm-yyyy'), 2, 7028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050302012773, to_date('02-03-2005', 'dd-mm-yyyy'), to_date('16-03-2005', 'dd-mm-yyyy'), 2, 6326, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070624012774, to_date('24-06-2007', 'dd-mm-yyyy'), to_date('08-07-2007', 'dd-mm-yyyy'), 1, 6780, to_date('29-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111014012775, to_date('14-10-2011', 'dd-mm-yyyy'), to_date('28-10-2011', 'dd-mm-yyyy'), 3, 8745, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010705012776, to_date('05-07-2001', 'dd-mm-yyyy'), to_date('19-07-2001', 'dd-mm-yyyy'), 2, 2809, to_date('16-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327012777, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 2, 4635, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020717012778, to_date('17-07-2002', 'dd-mm-yyyy'), to_date('31-07-2002', 'dd-mm-yyyy'), 2, 2093, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050828012779, to_date('28-08-2005', 'dd-mm-yyyy'), to_date('11-09-2005', 'dd-mm-yyyy'), 3, 6159, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110908012780, to_date('08-09-2011', 'dd-mm-yyyy'), to_date('22-09-2011', 'dd-mm-yyyy'), 3, 7014, to_date('16-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428012781, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 3, 2566, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050701012782, to_date('01-07-2005', 'dd-mm-yyyy'), to_date('15-07-2005', 'dd-mm-yyyy'), 1, 4358, to_date('03-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120709012783, to_date('09-07-2012', 'dd-mm-yyyy'), to_date('23-07-2012', 'dd-mm-yyyy'), 2, 9936, to_date('27-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020323012784, to_date('23-03-2002', 'dd-mm-yyyy'), to_date('06-04-2002', 'dd-mm-yyyy'), 2, 4704, to_date('01-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020112012785, to_date('12-01-2002', 'dd-mm-yyyy'), to_date('26-01-2002', 'dd-mm-yyyy'), 3, 1357, to_date('30-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119012786, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 3, 3576, to_date('05-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128012787, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 3, 3931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000607012788, to_date('07-06-2000', 'dd-mm-yyyy'), to_date('21-06-2000', 'dd-mm-yyyy'), 3, 2993, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110819012789, to_date('19-08-2011', 'dd-mm-yyyy'), to_date('02-09-2011', 'dd-mm-yyyy'), 1, 6972, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060616012790, to_date('16-06-2006', 'dd-mm-yyyy'), to_date('30-06-2006', 'dd-mm-yyyy'), 4, 5974, to_date('19-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020211012791, to_date('11-02-2002', 'dd-mm-yyyy'), to_date('25-02-2002', 'dd-mm-yyyy'), 1, 2942, to_date('26-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222012792, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 2, 1461, to_date('29-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031231012793, to_date('31-12-2003', 'dd-mm-yyyy'), to_date('14-01-2004', 'dd-mm-yyyy'), 2, 3734, to_date('09-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120925012794, to_date('25-09-2012', 'dd-mm-yyyy'), to_date('09-10-2012', 'dd-mm-yyyy'), 3, 10216, to_date('30-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070120012795, to_date('20-01-2007', 'dd-mm-yyyy'), to_date('03-02-2007', 'dd-mm-yyyy'), 2, 4798, to_date('01-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425012796, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 3, 6783, to_date('03-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101012797, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 4, 3480, to_date('11-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110616012798, to_date('16-06-2011', 'dd-mm-yyyy'), to_date('30-06-2011', 'dd-mm-yyyy'), 2, 8459, to_date('01-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015012799, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 4, 4415, to_date('18-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620012800, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 3, 7504, to_date('08-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031122012801, to_date('22-11-2003', 'dd-mm-yyyy'), to_date('06-12-2003', 'dd-mm-yyyy'), 4, 3134, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070402012802, to_date('02-04-2007', 'dd-mm-yyyy'), to_date('16-04-2007', 'dd-mm-yyyy'), 2, 7516, to_date('04-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222012803, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 3, 2689, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120111012804, to_date('11-01-2012', 'dd-mm-yyyy'), to_date('25-01-2012', 'dd-mm-yyyy'), 2, 8011, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070709012805, to_date('09-07-2007', 'dd-mm-yyyy'), to_date('23-07-2007', 'dd-mm-yyyy'), 1, 4618, to_date('16-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061125012806, to_date('25-11-2006', 'dd-mm-yyyy'), to_date('09-12-2006', 'dd-mm-yyyy'), 3, 4625, to_date('28-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703012807, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 3, 5539, to_date('19-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120605012808, to_date('05-06-2012', 'dd-mm-yyyy'), to_date('19-06-2012', 'dd-mm-yyyy'), 2, 6046, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120402012809, to_date('02-04-2012', 'dd-mm-yyyy'), to_date('16-04-2012', 'dd-mm-yyyy'), 4, 8642, to_date('07-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140323012810, to_date('23-03-2014', 'dd-mm-yyyy'), to_date('06-04-2014', 'dd-mm-yyyy'), 4, 11449, to_date('05-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000125012811, to_date('25-01-2000', 'dd-mm-yyyy'), to_date('08-02-2000', 'dd-mm-yyyy'), 4, 2237, to_date('12-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823012812, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 3, 10582, to_date('27-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050430012813, to_date('30-04-2005', 'dd-mm-yyyy'), to_date('14-05-2005', 'dd-mm-yyyy'), 2, 4591, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602012814, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 3, 6892, to_date('10-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001031012815, to_date('31-10-2000', 'dd-mm-yyyy'), to_date('14-11-2000', 'dd-mm-yyyy'), 3, 983, to_date('03-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090325012816, to_date('25-03-2009', 'dd-mm-yyyy'), to_date('08-04-2009', 'dd-mm-yyyy'), 3, 6981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060518012817, to_date('18-05-2006', 'dd-mm-yyyy'), to_date('01-06-2006', 'dd-mm-yyyy'), 3, 5512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030907012818, to_date('07-09-2003', 'dd-mm-yyyy'), to_date('21-09-2003', 'dd-mm-yyyy'), 1, 3158, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140114012819, to_date('14-01-2014', 'dd-mm-yyyy'), to_date('28-01-2014', 'dd-mm-yyyy'), 4, 7689, to_date('28-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823012820, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 2, 8776, to_date('03-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070630012821, to_date('30-06-2007', 'dd-mm-yyyy'), to_date('14-07-2007', 'dd-mm-yyyy'), 2, 6177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405012822, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 2, 5666, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826012823, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 2, 3752, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140514012824, to_date('14-05-2014', 'dd-mm-yyyy'), to_date('28-05-2014', 'dd-mm-yyyy'), 1, 8445, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902012825, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 3, 2430, to_date('10-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229012826, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 4, 1892, to_date('07-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130012827, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 3, 5264, to_date('09-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090914012828, to_date('14-09-2009', 'dd-mm-yyyy'), to_date('28-09-2009', 'dd-mm-yyyy'), 3, 7194, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050721012829, to_date('21-07-2005', 'dd-mm-yyyy'), to_date('04-08-2005', 'dd-mm-yyyy'), 3, 4868, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120123012830, to_date('23-01-2012', 'dd-mm-yyyy'), to_date('06-02-2012', 'dd-mm-yyyy'), 2, 9412, to_date('28-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031012012831, to_date('12-10-2003', 'dd-mm-yyyy'), to_date('26-10-2003', 'dd-mm-yyyy'), 2, 4458, to_date('31-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924012832, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 2, 9987, to_date('10-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503012833, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 2, 3940, to_date('17-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111012834, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 3, 4978, to_date('26-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621012835, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 1, 2232, to_date('25-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021108012836, to_date('08-11-2002', 'dd-mm-yyyy'), to_date('22-11-2002', 'dd-mm-yyyy'), 2, 1372, to_date('21-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100219012837, to_date('19-02-2010', 'dd-mm-yyyy'), to_date('05-03-2010', 'dd-mm-yyyy'), 3, 7332, to_date('07-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110318012838, to_date('18-03-2011', 'dd-mm-yyyy'), to_date('01-04-2011', 'dd-mm-yyyy'), 3, 7901, to_date('21-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827012839, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 3, 1260, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031130012840, to_date('30-11-2003', 'dd-mm-yyyy'), to_date('14-12-2003', 'dd-mm-yyyy'), 2, 3933, to_date('12-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050316012841, to_date('16-03-2005', 'dd-mm-yyyy'), to_date('30-03-2005', 'dd-mm-yyyy'), 4, 3616, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060324012842, to_date('24-03-2006', 'dd-mm-yyyy'), to_date('07-04-2006', 'dd-mm-yyyy'), 2, 4065, to_date('09-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130511012843, to_date('11-05-2013', 'dd-mm-yyyy'), to_date('25-05-2013', 'dd-mm-yyyy'), 4, 8097, to_date('19-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110507012844, to_date('07-05-2011', 'dd-mm-yyyy'), to_date('21-05-2011', 'dd-mm-yyyy'), 2, 9118, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030617012845, to_date('17-06-2003', 'dd-mm-yyyy'), to_date('01-07-2003', 'dd-mm-yyyy'), 4, 5000, to_date('27-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050927012846, to_date('27-09-2005', 'dd-mm-yyyy'), to_date('11-10-2005', 'dd-mm-yyyy'), 2, 6375, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060222012847, to_date('22-02-2006', 'dd-mm-yyyy'), to_date('08-03-2006', 'dd-mm-yyyy'), 1, 3884, to_date('28-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805012848, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 3, 4242, to_date('16-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051226012849, to_date('26-12-2005', 'dd-mm-yyyy'), to_date('09-01-2006', 'dd-mm-yyyy'), 3, 5663, to_date('06-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051129012850, to_date('29-11-2005', 'dd-mm-yyyy'), to_date('13-12-2005', 'dd-mm-yyyy'), 2, 3620, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120310012851, to_date('10-03-2012', 'dd-mm-yyyy'), to_date('24-03-2012', 'dd-mm-yyyy'), 3, 8107, to_date('20-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011026012852, to_date('26-10-2001', 'dd-mm-yyyy'), to_date('09-11-2001', 'dd-mm-yyyy'), 4, 3002, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081118012853, to_date('18-11-2008', 'dd-mm-yyyy'), to_date('02-12-2008', 'dd-mm-yyyy'), 2, 6452, to_date('20-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060303012854, to_date('03-03-2006', 'dd-mm-yyyy'), to_date('17-03-2006', 'dd-mm-yyyy'), 3, 3297, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118012855, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 4, 1684, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620012856, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 3, 2906, to_date('30-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131126012857, to_date('26-11-2013', 'dd-mm-yyyy'), to_date('10-12-2013', 'dd-mm-yyyy'), 1, 7797, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040211012858, to_date('11-02-2004', 'dd-mm-yyyy'), to_date('25-02-2004', 'dd-mm-yyyy'), 2, 2767, to_date('18-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100321012859, to_date('21-03-2010', 'dd-mm-yyyy'), to_date('04-04-2010', 'dd-mm-yyyy'), 3, 8748, to_date('06-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121114012860, to_date('14-11-2012', 'dd-mm-yyyy'), to_date('28-11-2012', 'dd-mm-yyyy'), 1, 8438, to_date('23-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140212012861, to_date('12-02-2014', 'dd-mm-yyyy'), to_date('26-02-2014', 'dd-mm-yyyy'), 4, 10634, to_date('16-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060102012862, to_date('02-01-2006', 'dd-mm-yyyy'), to_date('16-01-2006', 'dd-mm-yyyy'), 1, 6772, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130812012863, to_date('12-08-2013', 'dd-mm-yyyy'), to_date('26-08-2013', 'dd-mm-yyyy'), 2, 11544, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061019015389, to_date('19-10-2006', 'dd-mm-yyyy'), to_date('02-11-2006', 'dd-mm-yyyy'), 4, 3727, to_date('31-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210015390, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 3, 4527, to_date('11-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120305015391, to_date('05-03-2012', 'dd-mm-yyyy'), to_date('19-03-2012', 'dd-mm-yyyy'), 1, 9223, to_date('14-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060107015392, to_date('07-01-2006', 'dd-mm-yyyy'), to_date('21-01-2006', 'dd-mm-yyyy'), 2, 5865, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719015393, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 3, 1424, to_date('01-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020801015394, to_date('01-08-2002', 'dd-mm-yyyy'), to_date('15-08-2002', 'dd-mm-yyyy'), 3, 3250, to_date('09-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040909015395, to_date('09-09-2004', 'dd-mm-yyyy'), to_date('23-09-2004', 'dd-mm-yyyy'), 4, 3060, to_date('23-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061201015396, to_date('01-12-2006', 'dd-mm-yyyy'), to_date('15-12-2006', 'dd-mm-yyyy'), 3, 4348, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130604015397, to_date('04-06-2013', 'dd-mm-yyyy'), to_date('18-06-2013', 'dd-mm-yyyy'), 2, 9607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207015398, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 1, 5095, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070520015399, to_date('20-05-2007', 'dd-mm-yyyy'), to_date('03-06-2007', 'dd-mm-yyyy'), 2, 6597, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210015400, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 3, 2466, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100930015401, to_date('30-09-2010', 'dd-mm-yyyy'), to_date('14-10-2010', 'dd-mm-yyyy'), 2, 4833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130905015402, to_date('05-09-2013', 'dd-mm-yyyy'), to_date('19-09-2013', 'dd-mm-yyyy'), 3, 9204, to_date('08-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101223015403, to_date('23-12-2010', 'dd-mm-yyyy'), to_date('06-01-2011', 'dd-mm-yyyy'), 3, 6353, to_date('02-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129015404, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 1, 3828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109015405, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 4, 7502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050609015406, to_date('09-06-2005', 'dd-mm-yyyy'), to_date('23-06-2005', 'dd-mm-yyyy'), 3, 2452, to_date('24-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120921015407, to_date('21-09-2012', 'dd-mm-yyyy'), to_date('05-10-2012', 'dd-mm-yyyy'), 1, 9476, to_date('01-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131212015408, to_date('12-12-2013', 'dd-mm-yyyy'), to_date('26-12-2013', 'dd-mm-yyyy'), 2, 11699, to_date('18-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070604015409, to_date('04-06-2007', 'dd-mm-yyyy'), to_date('18-06-2007', 'dd-mm-yyyy'), 3, 5576, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040828015410, to_date('28-08-2004', 'dd-mm-yyyy'), to_date('11-09-2004', 'dd-mm-yyyy'), 1, 2831, to_date('07-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080802015411, to_date('02-08-2008', 'dd-mm-yyyy'), to_date('16-08-2008', 'dd-mm-yyyy'), 1, 6509, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730015412, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 4, 6883, to_date('16-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101123015413, to_date('23-11-2010', 'dd-mm-yyyy'), to_date('07-12-2010', 'dd-mm-yyyy'), 3, 6536, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070224015414, to_date('24-02-2007', 'dd-mm-yyyy'), to_date('10-03-2007', 'dd-mm-yyyy'), 3, 5053, to_date('03-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131125015415, to_date('25-11-2013', 'dd-mm-yyyy'), to_date('09-12-2013', 'dd-mm-yyyy'), 4, 7161, to_date('06-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010924015416, to_date('24-09-2001', 'dd-mm-yyyy'), to_date('08-10-2001', 'dd-mm-yyyy'), 1, 2894, to_date('09-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120928015417, to_date('28-09-2012', 'dd-mm-yyyy'), to_date('12-10-2012', 'dd-mm-yyyy'), 3, 11393, to_date('05-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110422015418, to_date('22-04-2011', 'dd-mm-yyyy'), to_date('06-05-2011', 'dd-mm-yyyy'), 1, 8502, to_date('27-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080114015419, to_date('14-01-2008', 'dd-mm-yyyy'), to_date('28-01-2008', 'dd-mm-yyyy'), 3, 4004, to_date('20-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010921015420, to_date('21-09-2001', 'dd-mm-yyyy'), to_date('05-10-2001', 'dd-mm-yyyy'), 3, 3366, to_date('25-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020301015421, to_date('01-03-2002', 'dd-mm-yyyy'), to_date('15-03-2002', 'dd-mm-yyyy'), 4, 4422, to_date('19-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121223015422, to_date('23-12-2012', 'dd-mm-yyyy'), to_date('06-01-2013', 'dd-mm-yyyy'), 2, 7752, to_date('01-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070210015423, to_date('10-02-2007', 'dd-mm-yyyy'), to_date('24-02-2007', 'dd-mm-yyyy'), 3, 3886, to_date('16-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021113015424, to_date('13-11-2002', 'dd-mm-yyyy'), to_date('27-11-2002', 'dd-mm-yyyy'), 1, 1814, to_date('24-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120215015425, to_date('15-02-2012', 'dd-mm-yyyy'), to_date('29-02-2012', 'dd-mm-yyyy'), 3, 10730, to_date('04-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104015426, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 4, 2730, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040522015427, to_date('22-05-2004', 'dd-mm-yyyy'), to_date('05-06-2004', 'dd-mm-yyyy'), 1, 3471, to_date('05-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509015428, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 2, 2999, to_date('12-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820015429, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 4, 6229, to_date('08-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050222015430, to_date('22-02-2005', 'dd-mm-yyyy'), to_date('08-03-2005', 'dd-mm-yyyy'), 2, 3006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040105015431, to_date('05-01-2004', 'dd-mm-yyyy'), to_date('19-01-2004', 'dd-mm-yyyy'), 2, 3092, to_date('09-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000305015432, to_date('05-03-2000', 'dd-mm-yyyy'), to_date('19-03-2000', 'dd-mm-yyyy'), 4, 838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130804015433, to_date('04-08-2013', 'dd-mm-yyyy'), to_date('18-08-2013', 'dd-mm-yyyy'), 2, 8653, to_date('14-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630015434, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 2, 10566, to_date('09-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100731015435, to_date('31-07-2010', 'dd-mm-yyyy'), to_date('14-08-2010', 'dd-mm-yyyy'), 4, 5656, to_date('03-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060812015436, to_date('12-08-2006', 'dd-mm-yyyy'), to_date('26-08-2006', 'dd-mm-yyyy'), 2, 4438, to_date('15-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090718015437, to_date('18-07-2009', 'dd-mm-yyyy'), to_date('01-08-2009', 'dd-mm-yyyy'), 3, 6356, to_date('28-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040524015438, to_date('24-05-2004', 'dd-mm-yyyy'), to_date('07-06-2004', 'dd-mm-yyyy'), 2, 5054, to_date('08-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120904015439, to_date('04-09-2012', 'dd-mm-yyyy'), to_date('18-09-2012', 'dd-mm-yyyy'), 4, 7286, to_date('18-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020122015440, to_date('22-01-2002', 'dd-mm-yyyy'), to_date('05-02-2002', 'dd-mm-yyyy'), 1, 5507, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209015441, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 3, 6949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030118015442, to_date('18-01-2003', 'dd-mm-yyyy'), to_date('01-02-2003', 'dd-mm-yyyy'), 2, 6145, to_date('31-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070126015443, to_date('26-01-2007', 'dd-mm-yyyy'), to_date('09-02-2007', 'dd-mm-yyyy'), 3, 4270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021020015444, to_date('20-10-2002', 'dd-mm-yyyy'), to_date('03-11-2002', 'dd-mm-yyyy'), 4, 3377, to_date('05-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070713015445, to_date('13-07-2007', 'dd-mm-yyyy'), to_date('27-07-2007', 'dd-mm-yyyy'), 3, 7889, to_date('23-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129015446, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 2, 3599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007015447, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 3, 5987, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708015448, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 1, 8239, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121104015449, to_date('04-11-2012', 'dd-mm-yyyy'), to_date('18-11-2012', 'dd-mm-yyyy'), 1, 8112, to_date('08-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030425015450, to_date('25-04-2003', 'dd-mm-yyyy'), to_date('09-05-2003', 'dd-mm-yyyy'), 2, 2918, to_date('08-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212015451, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 2, 2698, to_date('24-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020804015452, to_date('04-08-2002', 'dd-mm-yyyy'), to_date('18-08-2002', 'dd-mm-yyyy'), 3, 2877, to_date('14-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011203015453, to_date('03-12-2001', 'dd-mm-yyyy'), to_date('17-12-2001', 'dd-mm-yyyy'), 2, 4605, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040324015454, to_date('24-03-2004', 'dd-mm-yyyy'), to_date('07-04-2004', 'dd-mm-yyyy'), 2, 7125, to_date('08-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010704015455, to_date('04-07-2001', 'dd-mm-yyyy'), to_date('18-07-2001', 'dd-mm-yyyy'), 2, 3058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510015456, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 3, 7367, to_date('13-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090814015457, to_date('14-08-2009', 'dd-mm-yyyy'), to_date('28-08-2009', 'dd-mm-yyyy'), 2, 8892, to_date('03-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040922015458, to_date('22-09-2004', 'dd-mm-yyyy'), to_date('06-10-2004', 'dd-mm-yyyy'), 4, 4592, to_date('25-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020326015459, to_date('26-03-2002', 'dd-mm-yyyy'), to_date('09-04-2002', 'dd-mm-yyyy'), 2, 4164, to_date('08-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021225015460, to_date('25-12-2002', 'dd-mm-yyyy'), to_date('08-01-2003', 'dd-mm-yyyy'), 3, 2601, to_date('31-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040111015461, to_date('11-01-2004', 'dd-mm-yyyy'), to_date('25-01-2004', 'dd-mm-yyyy'), 2, 2344, to_date('28-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204015462, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 3, 7452, to_date('13-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061014015463, to_date('14-10-2006', 'dd-mm-yyyy'), to_date('28-10-2006', 'dd-mm-yyyy'), 2, 4136, to_date('17-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101114015464, to_date('14-11-2010', 'dd-mm-yyyy'), to_date('28-11-2010', 'dd-mm-yyyy'), 3, 9291, to_date('22-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201015465, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 4, 5947, to_date('17-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070111015466, to_date('11-01-2007', 'dd-mm-yyyy'), to_date('25-01-2007', 'dd-mm-yyyy'), 3, 6648, to_date('30-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010607015467, to_date('07-06-2001', 'dd-mm-yyyy'), to_date('21-06-2001', 'dd-mm-yyyy'), 3, 1598, to_date('12-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100525015468, to_date('25-05-2010', 'dd-mm-yyyy'), to_date('08-06-2010', 'dd-mm-yyyy'), 3, 8302, to_date('11-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011022015469, to_date('22-10-2001', 'dd-mm-yyyy'), to_date('05-11-2001', 'dd-mm-yyyy'), 2, 623, to_date('25-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081218015470, to_date('18-12-2008', 'dd-mm-yyyy'), to_date('01-01-2009', 'dd-mm-yyyy'), 4, 6069, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011228015471, to_date('28-12-2001', 'dd-mm-yyyy'), to_date('11-01-2002', 'dd-mm-yyyy'), 2, 1530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100530015472, to_date('30-05-2010', 'dd-mm-yyyy'), to_date('13-06-2010', 'dd-mm-yyyy'), 2, 6168, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121015473, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 3, 1228, to_date('08-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080120015474, to_date('20-01-2008', 'dd-mm-yyyy'), to_date('03-02-2008', 'dd-mm-yyyy'), 3, 6124, to_date('23-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011008015475, to_date('08-10-2001', 'dd-mm-yyyy'), to_date('22-10-2001', 'dd-mm-yyyy'), 2, 3707, to_date('22-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021018015476, to_date('18-10-2002', 'dd-mm-yyyy'), to_date('01-11-2002', 'dd-mm-yyyy'), 1, 1668, to_date('24-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041009015477, to_date('09-10-2004', 'dd-mm-yyyy'), to_date('23-10-2004', 'dd-mm-yyyy'), 1, 5237, to_date('25-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060322015478, to_date('22-03-2006', 'dd-mm-yyyy'), to_date('05-04-2006', 'dd-mm-yyyy'), 2, 5230, to_date('30-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202015479, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 2, 3341, to_date('05-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919015480, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 2, 7336, to_date('07-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120409015481, to_date('09-04-2012', 'dd-mm-yyyy'), to_date('23-04-2012', 'dd-mm-yyyy'), 3, 7137, to_date('22-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050808015482, to_date('08-08-2005', 'dd-mm-yyyy'), to_date('22-08-2005', 'dd-mm-yyyy'), 1, 3974, to_date('26-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011003015483, to_date('03-10-2001', 'dd-mm-yyyy'), to_date('17-10-2001', 'dd-mm-yyyy'), 3, 926, to_date('17-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007015484, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 2, 1810, to_date('26-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020418015485, to_date('18-04-2002', 'dd-mm-yyyy'), to_date('02-05-2002', 'dd-mm-yyyy'), 4, 2405, to_date('29-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090322015486, to_date('22-03-2009', 'dd-mm-yyyy'), to_date('05-04-2009', 'dd-mm-yyyy'), 3, 7360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010420015487, to_date('20-04-2001', 'dd-mm-yyyy'), to_date('04-05-2001', 'dd-mm-yyyy'), 4, 3156, to_date('29-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101022015488, to_date('22-10-2010', 'dd-mm-yyyy'), to_date('05-11-2010', 'dd-mm-yyyy'), 3, 8622, to_date('08-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090817015489, to_date('17-08-2009', 'dd-mm-yyyy'), to_date('31-08-2009', 'dd-mm-yyyy'), 3, 3472, to_date('03-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010606015490, to_date('06-06-2001', 'dd-mm-yyyy'), to_date('20-06-2001', 'dd-mm-yyyy'), 2, 3847, to_date('19-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226015491, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 2, 5173, to_date('02-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120409015492, to_date('09-04-2012', 'dd-mm-yyyy'), to_date('23-04-2012', 'dd-mm-yyyy'), 4, 8021, to_date('11-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031124015493, to_date('24-11-2003', 'dd-mm-yyyy'), to_date('08-12-2003', 'dd-mm-yyyy'), 2, 3501, to_date('11-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010107015494, to_date('07-01-2001', 'dd-mm-yyyy'), to_date('21-01-2001', 'dd-mm-yyyy'), 2, 884, to_date('09-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100403015495, to_date('03-04-2010', 'dd-mm-yyyy'), to_date('17-04-2010', 'dd-mm-yyyy'), 3, 11202, to_date('23-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024015496, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 4, 9822, to_date('11-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003015497, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 4, 6984, to_date('17-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202015498, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 3, 10603, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203015499, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 3, 6450, to_date('13-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100722015500, to_date('22-07-2010', 'dd-mm-yyyy'), to_date('05-08-2010', 'dd-mm-yyyy'), 2, 5703, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000501015501, to_date('01-05-2000', 'dd-mm-yyyy'), to_date('15-05-2000', 'dd-mm-yyyy'), 3, 2496, to_date('08-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225015502, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 1, 5424, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120221015503, to_date('21-02-2012', 'dd-mm-yyyy'), to_date('06-03-2012', 'dd-mm-yyyy'), 3, 9037, to_date('03-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021208015504, to_date('08-12-2002', 'dd-mm-yyyy'), to_date('22-12-2002', 'dd-mm-yyyy'), 4, 1221, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060621015505, to_date('21-06-2006', 'dd-mm-yyyy'), to_date('05-07-2006', 'dd-mm-yyyy'), 3, 2208, to_date('08-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040323015506, to_date('23-03-2004', 'dd-mm-yyyy'), to_date('06-04-2004', 'dd-mm-yyyy'), 2, 5926, to_date('05-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726015507, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 3, 7697, to_date('27-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060109015508, to_date('09-01-2006', 'dd-mm-yyyy'), to_date('23-01-2006', 'dd-mm-yyyy'), 4, 6872, to_date('17-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926015509, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 2, 5586, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224015510, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 1, 7130, to_date('29-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100613015511, to_date('13-06-2010', 'dd-mm-yyyy'), to_date('27-06-2010', 'dd-mm-yyyy'), 2, 7747, to_date('28-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219015512, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 4, 6394, to_date('02-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061018015513, to_date('18-10-2006', 'dd-mm-yyyy'), to_date('01-11-2006', 'dd-mm-yyyy'), 1, 5203, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070708015514, to_date('08-07-2007', 'dd-mm-yyyy'), to_date('22-07-2007', 'dd-mm-yyyy'), 2, 3547, to_date('15-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101202015515, to_date('02-12-2010', 'dd-mm-yyyy'), to_date('16-12-2010', 'dd-mm-yyyy'), 2, 7649, to_date('08-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050615015516, to_date('15-06-2005', 'dd-mm-yyyy'), to_date('29-06-2005', 'dd-mm-yyyy'), 2, 3854, to_date('17-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112015517, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 2, 4228, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418015518, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 2, 2463, to_date('01-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307015519, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 4, 5407, to_date('15-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060809015520, to_date('09-08-2006', 'dd-mm-yyyy'), to_date('23-08-2006', 'dd-mm-yyyy'), 2, 5454, to_date('25-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050822015521, to_date('22-08-2005', 'dd-mm-yyyy'), to_date('05-09-2005', 'dd-mm-yyyy'), 3, 3689, to_date('03-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040713015522, to_date('13-07-2004', 'dd-mm-yyyy'), to_date('27-07-2004', 'dd-mm-yyyy'), 3, 3763, to_date('30-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001221015523, to_date('21-12-2000', 'dd-mm-yyyy'), to_date('04-01-2001', 'dd-mm-yyyy'), 3, 1963, to_date('01-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040719015524, to_date('19-07-2004', 'dd-mm-yyyy'), to_date('02-08-2004', 'dd-mm-yyyy'), 2, 4716, to_date('22-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080220015525, to_date('20-02-2008', 'dd-mm-yyyy'), to_date('05-03-2008', 'dd-mm-yyyy'), 4, 5616, to_date('03-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050114015526, to_date('14-01-2005', 'dd-mm-yyyy'), to_date('28-01-2005', 'dd-mm-yyyy'), 3, 3658, to_date('16-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030802015527, to_date('02-08-2003', 'dd-mm-yyyy'), to_date('16-08-2003', 'dd-mm-yyyy'), 3, 2589, to_date('11-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060617015528, to_date('17-06-2006', 'dd-mm-yyyy'), to_date('01-07-2006', 'dd-mm-yyyy'), 3, 4252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608015529, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 4, 6548, to_date('23-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050630015530, to_date('30-06-2005', 'dd-mm-yyyy'), to_date('14-07-2005', 'dd-mm-yyyy'), 3, 4966, to_date('03-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020330015531, to_date('30-03-2002', 'dd-mm-yyyy'), to_date('13-04-2002', 'dd-mm-yyyy'), 3, 3018, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105015532, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 3, 3385, to_date('08-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061026015533, to_date('26-10-2006', 'dd-mm-yyyy'), to_date('09-11-2006', 'dd-mm-yyyy'), 3, 3009, to_date('14-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090123015534, to_date('23-01-2009', 'dd-mm-yyyy'), to_date('06-02-2009', 'dd-mm-yyyy'), 2, 8647, to_date('04-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090829015535, to_date('29-08-2009', 'dd-mm-yyyy'), to_date('12-09-2009', 'dd-mm-yyyy'), 3, 7271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080331015536, to_date('31-03-2008', 'dd-mm-yyyy'), to_date('14-04-2008', 'dd-mm-yyyy'), 3, 6541, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140323015537, to_date('23-03-2014', 'dd-mm-yyyy'), to_date('06-04-2014', 'dd-mm-yyyy'), 1, 10540, to_date('28-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130715015538, to_date('15-07-2013', 'dd-mm-yyyy'), to_date('29-07-2013', 'dd-mm-yyyy'), 3, 10168, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050412015539, to_date('12-04-2005', 'dd-mm-yyyy'), to_date('26-04-2005', 'dd-mm-yyyy'), 2, 5550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041005015540, to_date('05-10-2004', 'dd-mm-yyyy'), to_date('19-10-2004', 'dd-mm-yyyy'), 4, 3642, to_date('13-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100829015541, to_date('29-08-2010', 'dd-mm-yyyy'), to_date('12-09-2010', 'dd-mm-yyyy'), 1, 4671, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011002015542, to_date('02-10-2001', 'dd-mm-yyyy'), to_date('16-10-2001', 'dd-mm-yyyy'), 4, 2137, to_date('04-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040911015543, to_date('11-09-2004', 'dd-mm-yyyy'), to_date('25-09-2004', 'dd-mm-yyyy'), 4, 3213, to_date('15-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081205015544, to_date('05-12-2008', 'dd-mm-yyyy'), to_date('19-12-2008', 'dd-mm-yyyy'), 2, 4628, to_date('15-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001016015545, to_date('16-10-2000', 'dd-mm-yyyy'), to_date('30-10-2000', 'dd-mm-yyyy'), 2, 3103, to_date('02-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051121015546, to_date('21-11-2005', 'dd-mm-yyyy'), to_date('05-12-2005', 'dd-mm-yyyy'), 4, 5968, to_date('24-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091202015547, to_date('02-12-2009', 'dd-mm-yyyy'), to_date('16-12-2009', 'dd-mm-yyyy'), 4, 7530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090916015548, to_date('16-09-2009', 'dd-mm-yyyy'), to_date('30-09-2009', 'dd-mm-yyyy'), 1, 5738, to_date('30-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608015549, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 2, 7541, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110619015550, to_date('19-06-2011', 'dd-mm-yyyy'), to_date('03-07-2011', 'dd-mm-yyyy'), 4, 5880, to_date('02-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212015551, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 2, 3888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080628015552, to_date('28-06-2008', 'dd-mm-yyyy'), to_date('12-07-2008', 'dd-mm-yyyy'), 2, 6738, to_date('17-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111126015553, to_date('26-11-2011', 'dd-mm-yyyy'), to_date('10-12-2011', 'dd-mm-yyyy'), 3, 6390, to_date('08-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040120015554, to_date('20-01-2004', 'dd-mm-yyyy'), to_date('03-02-2004', 'dd-mm-yyyy'), 3, 5075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070403010103, to_date('03-04-2007', 'dd-mm-yyyy'), to_date('17-04-2007', 'dd-mm-yyyy'), 5, 4093, to_date('07-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080903010104, to_date('03-09-2008', 'dd-mm-yyyy'), to_date('17-09-2008', 'dd-mm-yyyy'), 4, 6971, to_date('14-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702010105, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 7, 2748, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100815010106, to_date('15-08-2010', 'dd-mm-yyyy'), to_date('29-08-2010', 'dd-mm-yyyy'), 7, 5752, to_date('20-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071222010107, to_date('22-12-2007', 'dd-mm-yyyy'), to_date('05-01-2008', 'dd-mm-yyyy'), 2, 3964, to_date('29-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060118010108, to_date('18-01-2006', 'dd-mm-yyyy'), to_date('01-02-2006', 'dd-mm-yyyy'), 11, 3073, to_date('01-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080807010109, to_date('07-08-2008', 'dd-mm-yyyy'), to_date('21-08-2008', 'dd-mm-yyyy'), 12, 6877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121026010110, to_date('26-10-2012', 'dd-mm-yyyy'), to_date('09-11-2012', 'dd-mm-yyyy'), 1, 7672, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613010111, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 2, 2143, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112010112, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 8, 5096, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020220010113, to_date('20-02-2002', 'dd-mm-yyyy'), to_date('06-03-2002', 'dd-mm-yyyy'), 2, 2161, to_date('03-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040315010114, to_date('15-03-2004', 'dd-mm-yyyy'), to_date('29-03-2004', 'dd-mm-yyyy'), 10, 4674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060708010115, to_date('08-07-2006', 'dd-mm-yyyy'), to_date('22-07-2006', 'dd-mm-yyyy'), 12, 5822, to_date('10-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020402010116, to_date('02-04-2002', 'dd-mm-yyyy'), to_date('16-04-2002', 'dd-mm-yyyy'), 10, 3257, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226010117, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 4, 4974, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021128010118, to_date('28-11-2002', 'dd-mm-yyyy'), to_date('12-12-2002', 'dd-mm-yyyy'), 7, 2620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080222010119, to_date('22-02-2008', 'dd-mm-yyyy'), to_date('07-03-2008', 'dd-mm-yyyy'), 8, 4644, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130502010120, to_date('02-05-2013', 'dd-mm-yyyy'), to_date('16-05-2013', 'dd-mm-yyyy'), 3, 9313, to_date('22-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527010121, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 10, 3482, to_date('10-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826010122, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 1, 7453, to_date('01-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070624010123, to_date('24-06-2007', 'dd-mm-yyyy'), to_date('08-07-2007', 'dd-mm-yyyy'), 2, 4428, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040121010124, to_date('21-01-2004', 'dd-mm-yyyy'), to_date('04-02-2004', 'dd-mm-yyyy'), 3, 4175, to_date('05-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020301010125, to_date('01-03-2002', 'dd-mm-yyyy'), to_date('15-03-2002', 'dd-mm-yyyy'), 3, 4184, to_date('18-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128010126, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 10, 10762, to_date('09-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130503010127, to_date('03-05-2013', 'dd-mm-yyyy'), to_date('17-05-2013', 'dd-mm-yyyy'), 4, 9541, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302010128, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 6, 3774, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120517010129, to_date('17-05-2012', 'dd-mm-yyyy'), to_date('31-05-2012', 'dd-mm-yyyy'), 5, 6067, to_date('22-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120105010130, to_date('05-01-2012', 'dd-mm-yyyy'), to_date('19-01-2012', 'dd-mm-yyyy'), 10, 7678, to_date('08-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901010131, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 3, 4366, to_date('17-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051025010132, to_date('25-10-2005', 'dd-mm-yyyy'), to_date('08-11-2005', 'dd-mm-yyyy'), 9, 4579, to_date('31-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000415010133, to_date('15-04-2000', 'dd-mm-yyyy'), to_date('29-04-2000', 'dd-mm-yyyy'), 10, 2108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061201010134, to_date('01-12-2006', 'dd-mm-yyyy'), to_date('15-12-2006', 'dd-mm-yyyy'), 4, 4582, to_date('02-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051103010135, to_date('03-11-2005', 'dd-mm-yyyy'), to_date('17-11-2005', 'dd-mm-yyyy'), 11, 4407, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080511010136, to_date('11-05-2008', 'dd-mm-yyyy'), to_date('25-05-2008', 'dd-mm-yyyy'), 11, 6651, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100819010137, to_date('19-08-2010', 'dd-mm-yyyy'), to_date('02-09-2010', 'dd-mm-yyyy'), 10, 6509, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040729010138, to_date('29-07-2004', 'dd-mm-yyyy'), to_date('12-08-2004', 'dd-mm-yyyy'), 6, 4392, to_date('17-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050627010139, to_date('27-06-2005', 'dd-mm-yyyy'), to_date('11-07-2005', 'dd-mm-yyyy'), 4, 3971, to_date('14-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071028010140, to_date('28-10-2007', 'dd-mm-yyyy'), to_date('11-11-2007', 'dd-mm-yyyy'), 8, 6669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000507010141, to_date('07-05-2000', 'dd-mm-yyyy'), to_date('21-05-2000', 'dd-mm-yyyy'), 7, 503, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110423010142, to_date('23-04-2011', 'dd-mm-yyyy'), to_date('07-05-2011', 'dd-mm-yyyy'), 6, 5162, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100531010143, to_date('31-05-2010', 'dd-mm-yyyy'), to_date('14-06-2010', 'dd-mm-yyyy'), 9, 7199, to_date('19-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228010144, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 10, 814, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121221010145, to_date('21-12-2012', 'dd-mm-yyyy'), to_date('04-01-2013', 'dd-mm-yyyy'), 9, 6815, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040107010146, to_date('07-01-2004', 'dd-mm-yyyy'), to_date('21-01-2004', 'dd-mm-yyyy'), 10, 3869, to_date('17-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060127010147, to_date('27-01-2006', 'dd-mm-yyyy'), to_date('10-02-2006', 'dd-mm-yyyy'), 11, 4639, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120811010148, to_date('11-08-2012', 'dd-mm-yyyy'), to_date('25-08-2012', 'dd-mm-yyyy'), 8, 6743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011013010149, to_date('13-10-2001', 'dd-mm-yyyy'), to_date('27-10-2001', 'dd-mm-yyyy'), 8, 3092, to_date('26-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000321010150, to_date('21-03-2000', 'dd-mm-yyyy'), to_date('04-04-2000', 'dd-mm-yyyy'), 10, 876, to_date('31-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000202010151, to_date('02-02-2000', 'dd-mm-yyyy'), to_date('16-02-2000', 'dd-mm-yyyy'), 8, 1226, to_date('18-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090908010152, to_date('08-09-2009', 'dd-mm-yyyy'), to_date('22-09-2009', 'dd-mm-yyyy'), 2, 5803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106010153, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 7, 4422, to_date('22-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706010154, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 8, 1109, to_date('17-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070815010155, to_date('15-08-2007', 'dd-mm-yyyy'), to_date('29-08-2007', 'dd-mm-yyyy'), 5, 7460, to_date('24-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090325010156, to_date('25-03-2009', 'dd-mm-yyyy'), to_date('08-04-2009', 'dd-mm-yyyy'), 12, 8579, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140303010157, to_date('03-03-2014', 'dd-mm-yyyy'), to_date('17-03-2014', 'dd-mm-yyyy'), 6, 11888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060423010158, to_date('23-04-2006', 'dd-mm-yyyy'), to_date('07-05-2006', 'dd-mm-yyyy'), 11, 4641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130010159, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 7, 7833, to_date('16-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110523010160, to_date('23-05-2011', 'dd-mm-yyyy'), to_date('06-06-2011', 'dd-mm-yyyy'), 5, 5562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050911010161, to_date('11-09-2005', 'dd-mm-yyyy'), to_date('25-09-2005', 'dd-mm-yyyy'), 5, 3649, to_date('24-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001117010162, to_date('17-11-2000', 'dd-mm-yyyy'), to_date('01-12-2000', 'dd-mm-yyyy'), 6, 702, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115010163, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 3, 2255, to_date('29-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031115010164, to_date('15-11-2003', 'dd-mm-yyyy'), to_date('29-11-2003', 'dd-mm-yyyy'), 8, 1645, to_date('17-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050124010165, to_date('24-01-2005', 'dd-mm-yyyy'), to_date('07-02-2005', 'dd-mm-yyyy'), 3, 4705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208010166, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 8, 3475, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502010167, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 3, 8745, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021223010168, to_date('23-12-2002', 'dd-mm-yyyy'), to_date('06-01-2003', 'dd-mm-yyyy'), 7, 3466, to_date('27-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000119010169, to_date('19-01-2000', 'dd-mm-yyyy'), to_date('02-02-2000', 'dd-mm-yyyy'), 3, 1957, to_date('23-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121022010170, to_date('22-10-2012', 'dd-mm-yyyy'), to_date('05-11-2012', 'dd-mm-yyyy'), 8, 9255, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060210010171, to_date('10-02-2006', 'dd-mm-yyyy'), to_date('24-02-2006', 'dd-mm-yyyy'), 8, 3475, to_date('25-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090222010172, to_date('22-02-2009', 'dd-mm-yyyy'), to_date('08-03-2009', 'dd-mm-yyyy'), 3, 6522, to_date('13-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090330010173, to_date('30-03-2009', 'dd-mm-yyyy'), to_date('13-04-2009', 'dd-mm-yyyy'), 9, 5490, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070804010174, to_date('04-08-2007', 'dd-mm-yyyy'), to_date('18-08-2007', 'dd-mm-yyyy'), 5, 6595, to_date('17-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060116010175, to_date('16-01-2006', 'dd-mm-yyyy'), to_date('30-01-2006', 'dd-mm-yyyy'), 10, 5902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090222010176, to_date('22-02-2009', 'dd-mm-yyyy'), to_date('08-03-2009', 'dd-mm-yyyy'), 5, 5797, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226010177, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 5, 2275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110829010178, to_date('29-08-2011', 'dd-mm-yyyy'), to_date('12-09-2011', 'dd-mm-yyyy'), 12, 10832, to_date('05-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001230010179, to_date('30-12-2000', 'dd-mm-yyyy'), to_date('13-01-2001', 'dd-mm-yyyy'), 2, 2569, to_date('10-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130707010180, to_date('07-07-2013', 'dd-mm-yyyy'), to_date('21-07-2013', 'dd-mm-yyyy'), 2, 10782, to_date('25-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040310010181, to_date('10-03-2004', 'dd-mm-yyyy'), to_date('24-03-2004', 'dd-mm-yyyy'), 9, 2623, to_date('27-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010916010182, to_date('16-09-2001', 'dd-mm-yyyy'), to_date('30-09-2001', 'dd-mm-yyyy'), 8, 2497, to_date('17-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206010183, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 4, 4309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000222010184, to_date('22-02-2000', 'dd-mm-yyyy'), to_date('07-03-2000', 'dd-mm-yyyy'), 12, 2789, to_date('12-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050609010185, to_date('09-06-2005', 'dd-mm-yyyy'), to_date('23-06-2005', 'dd-mm-yyyy'), 6, 5421, to_date('21-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040120010186, to_date('20-01-2004', 'dd-mm-yyyy'), to_date('03-02-2004', 'dd-mm-yyyy'), 5, 3458, to_date('25-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061231010187, to_date('31-12-2006', 'dd-mm-yyyy'), to_date('14-01-2007', 'dd-mm-yyyy'), 5, 4364, to_date('15-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010707010188, to_date('07-07-2001', 'dd-mm-yyyy'), to_date('21-07-2001', 'dd-mm-yyyy'), 2, 4169, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110702010189, to_date('02-07-2011', 'dd-mm-yyyy'), to_date('16-07-2011', 'dd-mm-yyyy'), 7, 5409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628010190, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 1, 1615, to_date('13-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000513010191, to_date('13-05-2000', 'dd-mm-yyyy'), to_date('27-05-2000', 'dd-mm-yyyy'), 10, 1992, to_date('22-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080501010192, to_date('01-05-2008', 'dd-mm-yyyy'), to_date('15-05-2008', 'dd-mm-yyyy'), 8, 4397, to_date('05-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020123010193, to_date('23-01-2002', 'dd-mm-yyyy'), to_date('06-02-2002', 'dd-mm-yyyy'), 11, 4534, to_date('28-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040224010194, to_date('24-02-2004', 'dd-mm-yyyy'), to_date('09-03-2004', 'dd-mm-yyyy'), 3, 4263, to_date('15-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070312010195, to_date('12-03-2007', 'dd-mm-yyyy'), to_date('26-03-2007', 'dd-mm-yyyy'), 8, 4647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040809010196, to_date('09-08-2004', 'dd-mm-yyyy'), to_date('23-08-2004', 'dd-mm-yyyy'), 6, 4803, to_date('22-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120702010197, to_date('02-07-2012', 'dd-mm-yyyy'), to_date('16-07-2012', 'dd-mm-yyyy'), 2, 7264, to_date('17-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511010198, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 3, 4210, to_date('17-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103010199, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 11, 5725, to_date('12-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301010200, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 1, 5580, to_date('15-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101024010201, to_date('24-10-2010', 'dd-mm-yyyy'), to_date('07-11-2010', 'dd-mm-yyyy'), 1, 7196, to_date('10-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815010202, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 8, 3530, to_date('17-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040624010203, to_date('24-06-2004', 'dd-mm-yyyy'), to_date('08-07-2004', 'dd-mm-yyyy'), 7, 5309, to_date('04-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031010204, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 4, 6088, to_date('19-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227010205, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 11, 6998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020618010206, to_date('18-06-2002', 'dd-mm-yyyy'), to_date('02-07-2002', 'dd-mm-yyyy'), 7, 3684, to_date('07-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021218010207, to_date('18-12-2002', 'dd-mm-yyyy'), to_date('01-01-2003', 'dd-mm-yyyy'), 12, 3298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120903010208, to_date('03-09-2012', 'dd-mm-yyyy'), to_date('17-09-2012', 'dd-mm-yyyy'), 6, 8317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513010209, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 4, 5483, to_date('17-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010501010210, to_date('01-05-2001', 'dd-mm-yyyy'), to_date('15-05-2001', 'dd-mm-yyyy'), 3, 1346, to_date('05-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061018010211, to_date('18-10-2006', 'dd-mm-yyyy'), to_date('01-11-2006', 'dd-mm-yyyy'), 3, 4744, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110426010212, to_date('26-04-2011', 'dd-mm-yyyy'), to_date('10-05-2011', 'dd-mm-yyyy'), 2, 8345, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091019010213, to_date('19-10-2009', 'dd-mm-yyyy'), to_date('02-11-2009', 'dd-mm-yyyy'), 12, 5841, to_date('03-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131024010214, to_date('24-10-2013', 'dd-mm-yyyy'), to_date('07-11-2013', 'dd-mm-yyyy'), 12, 6646, to_date('05-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071006010215, to_date('06-10-2007', 'dd-mm-yyyy'), to_date('20-10-2007', 'dd-mm-yyyy'), 11, 8121, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120226010216, to_date('26-02-2012', 'dd-mm-yyyy'), to_date('11-03-2012', 'dd-mm-yyyy'), 7, 7047, to_date('16-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010214010217, to_date('14-02-2001', 'dd-mm-yyyy'), to_date('28-02-2001', 'dd-mm-yyyy'), 4, 2719, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110120010218, to_date('20-01-2011', 'dd-mm-yyyy'), to_date('03-02-2011', 'dd-mm-yyyy'), 11, 5924, to_date('27-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010527010219, to_date('27-05-2001', 'dd-mm-yyyy'), to_date('10-06-2001', 'dd-mm-yyyy'), 10, 2599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011116010220, to_date('16-11-2001', 'dd-mm-yyyy'), to_date('30-11-2001', 'dd-mm-yyyy'), 11, 1413, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404010221, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 9, 6277, to_date('07-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131029010222, to_date('29-10-2013', 'dd-mm-yyyy'), to_date('12-11-2013', 'dd-mm-yyyy'), 10, 8696, to_date('02-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120312010223, to_date('12-03-2012', 'dd-mm-yyyy'), to_date('26-03-2012', 'dd-mm-yyyy'), 1, 8205, to_date('19-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430010224, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 9, 3379, to_date('14-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040418010225, to_date('18-04-2004', 'dd-mm-yyyy'), to_date('02-05-2004', 'dd-mm-yyyy'), 7, 2803, to_date('03-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070730010226, to_date('30-07-2007', 'dd-mm-yyyy'), to_date('13-08-2007', 'dd-mm-yyyy'), 2, 5264, to_date('31-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030329010227, to_date('29-03-2003', 'dd-mm-yyyy'), to_date('12-04-2003', 'dd-mm-yyyy'), 10, 3755, to_date('01-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110128010228, to_date('28-01-2011', 'dd-mm-yyyy'), to_date('11-02-2011', 'dd-mm-yyyy'), 3, 9251, to_date('12-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130116010229, to_date('16-01-2013', 'dd-mm-yyyy'), to_date('30-01-2013', 'dd-mm-yyyy'), 6, 7285, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080713010230, to_date('13-07-2008', 'dd-mm-yyyy'), to_date('27-07-2008', 'dd-mm-yyyy'), 2, 5868, to_date('26-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707010231, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 3, 6036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001104010232, to_date('04-11-2000', 'dd-mm-yyyy'), to_date('18-11-2000', 'dd-mm-yyyy'), 10, 220, to_date('06-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621010233, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 8, 1428, to_date('08-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040620010234, to_date('20-06-2004', 'dd-mm-yyyy'), to_date('04-07-2004', 'dd-mm-yyyy'), 8, 3440, to_date('03-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020313010235, to_date('13-03-2002', 'dd-mm-yyyy'), to_date('27-03-2002', 'dd-mm-yyyy'), 10, 4488, to_date('01-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071003010236, to_date('03-10-2007', 'dd-mm-yyyy'), to_date('17-10-2007', 'dd-mm-yyyy'), 10, 6245, to_date('16-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010627010237, to_date('27-06-2001', 'dd-mm-yyyy'), to_date('11-07-2001', 'dd-mm-yyyy'), 10, 2763, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318010238, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 7, 8912, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219010239, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 2, 5319, to_date('05-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120010240, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 8, 6855, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902010241, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 6, 4975, to_date('08-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020705010242, to_date('05-07-2002', 'dd-mm-yyyy'), to_date('19-07-2002', 'dd-mm-yyyy'), 5, 1968, to_date('07-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070511010243, to_date('11-05-2007', 'dd-mm-yyyy'), to_date('25-05-2007', 'dd-mm-yyyy'), 9, 5018, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225010244, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 3, 3023, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080301010245, to_date('01-03-2008', 'dd-mm-yyyy'), to_date('15-03-2008', 'dd-mm-yyyy'), 6, 7474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061003010246, to_date('03-10-2006', 'dd-mm-yyyy'), to_date('17-10-2006', 'dd-mm-yyyy'), 9, 4415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825010247, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 11, 5783, to_date('06-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926010248, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 3, 4220, to_date('02-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225010249, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 7, 2530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020112010250, to_date('12-01-2002', 'dd-mm-yyyy'), to_date('26-01-2002', 'dd-mm-yyyy'), 7, 4010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010127010251, to_date('27-01-2001', 'dd-mm-yyyy'), to_date('10-02-2001', 'dd-mm-yyyy'), 5, 2470, to_date('10-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000913010252, to_date('13-09-2000', 'dd-mm-yyyy'), to_date('27-09-2000', 'dd-mm-yyyy'), 7, 1692, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322010253, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 6, 3451, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000911010254, to_date('11-09-2000', 'dd-mm-yyyy'), to_date('25-09-2000', 'dd-mm-yyyy'), 3, 483, to_date('23-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501010255, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 4, 4539, to_date('14-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915010256, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 2, 6856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090521010257, to_date('21-05-2009', 'dd-mm-yyyy'), to_date('04-06-2009', 'dd-mm-yyyy'), 9, 6949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427012864, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 3, 5308, to_date('16-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010610012865, to_date('10-06-2001', 'dd-mm-yyyy'), to_date('24-06-2001', 'dd-mm-yyyy'), 2, 1842, to_date('17-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060801012866, to_date('01-08-2006', 'dd-mm-yyyy'), to_date('15-08-2006', 'dd-mm-yyyy'), 4, 5675, to_date('10-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813012867, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 3, 1213, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110606012868, to_date('06-06-2011', 'dd-mm-yyyy'), to_date('20-06-2011', 'dd-mm-yyyy'), 3, 6734, to_date('10-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051028012869, to_date('28-10-2005', 'dd-mm-yyyy'), to_date('11-11-2005', 'dd-mm-yyyy'), 3, 4534, to_date('06-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030223012870, to_date('23-02-2003', 'dd-mm-yyyy'), to_date('09-03-2003', 'dd-mm-yyyy'), 2, 4119, to_date('01-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110616012871, to_date('16-06-2011', 'dd-mm-yyyy'), to_date('30-06-2011', 'dd-mm-yyyy'), 4, 8540, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010319012872, to_date('19-03-2001', 'dd-mm-yyyy'), to_date('02-04-2001', 'dd-mm-yyyy'), 2, 3238, to_date('26-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111108012873, to_date('08-11-2011', 'dd-mm-yyyy'), to_date('22-11-2011', 'dd-mm-yyyy'), 2, 8354, to_date('15-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601012874, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 2, 6182, to_date('05-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100511012875, to_date('11-05-2010', 'dd-mm-yyyy'), to_date('25-05-2010', 'dd-mm-yyyy'), 4, 4776, to_date('24-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030529012876, to_date('29-05-2003', 'dd-mm-yyyy'), to_date('12-06-2003', 'dd-mm-yyyy'), 4, 3471, to_date('30-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070409012877, to_date('09-04-2007', 'dd-mm-yyyy'), to_date('23-04-2007', 'dd-mm-yyyy'), 2, 3840, to_date('19-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040508012878, to_date('08-05-2004', 'dd-mm-yyyy'), to_date('22-05-2004', 'dd-mm-yyyy'), 3, 3827, to_date('25-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050815012879, to_date('15-08-2005', 'dd-mm-yyyy'), to_date('29-08-2005', 'dd-mm-yyyy'), 4, 4164, to_date('02-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219012880, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 3, 2770, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101126012881, to_date('26-11-2010', 'dd-mm-yyyy'), to_date('10-12-2010', 'dd-mm-yyyy'), 3, 7268, to_date('11-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071230012882, to_date('30-12-2007', 'dd-mm-yyyy'), to_date('13-01-2008', 'dd-mm-yyyy'), 1, 4121, to_date('18-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070717012883, to_date('17-07-2007', 'dd-mm-yyyy'), to_date('31-07-2007', 'dd-mm-yyyy'), 2, 5096, to_date('27-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070401012884, to_date('01-04-2007', 'dd-mm-yyyy'), to_date('15-04-2007', 'dd-mm-yyyy'), 3, 5960, to_date('19-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070304012885, to_date('04-03-2007', 'dd-mm-yyyy'), to_date('18-03-2007', 'dd-mm-yyyy'), 4, 5386, to_date('19-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810012886, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 2, 3843, to_date('28-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926012887, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 1, 1218, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011013012888, to_date('13-10-2001', 'dd-mm-yyyy'), to_date('27-10-2001', 'dd-mm-yyyy'), 3, 1552, to_date('17-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204012889, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 3, 8651, to_date('22-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090630012890, to_date('30-06-2009', 'dd-mm-yyyy'), to_date('14-07-2009', 'dd-mm-yyyy'), 4, 4110, to_date('02-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010505012891, to_date('05-05-2001', 'dd-mm-yyyy'), to_date('19-05-2001', 'dd-mm-yyyy'), 2, 3289, to_date('19-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061009012892, to_date('09-10-2006', 'dd-mm-yyyy'), to_date('23-10-2006', 'dd-mm-yyyy'), 1, 4971, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001203012893, to_date('03-12-2000', 'dd-mm-yyyy'), to_date('17-12-2000', 'dd-mm-yyyy'), 2, 1494, to_date('18-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061125012894, to_date('25-11-2006', 'dd-mm-yyyy'), to_date('09-12-2006', 'dd-mm-yyyy'), 2, 3740, to_date('06-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823012895, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 4, 3945, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010510012896, to_date('10-05-2001', 'dd-mm-yyyy'), to_date('24-05-2001', 'dd-mm-yyyy'), 3, 2193, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615012897, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 2, 8086, to_date('29-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906012898, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 1, 7125, to_date('09-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130917012899, to_date('17-09-2013', 'dd-mm-yyyy'), to_date('01-10-2013', 'dd-mm-yyyy'), 3, 8609, to_date('25-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201012900, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 3, 8219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110107012901, to_date('07-01-2011', 'dd-mm-yyyy'), to_date('21-01-2011', 'dd-mm-yyyy'), 2, 8939, to_date('20-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061112012902, to_date('12-11-2006', 'dd-mm-yyyy'), to_date('26-11-2006', 'dd-mm-yyyy'), 2, 5005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000110012903, to_date('10-01-2000', 'dd-mm-yyyy'), to_date('24-01-2000', 'dd-mm-yyyy'), 3, 1871, to_date('20-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070801012904, to_date('01-08-2007', 'dd-mm-yyyy'), to_date('15-08-2007', 'dd-mm-yyyy'), 4, 5951, to_date('18-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050627012905, to_date('27-06-2005', 'dd-mm-yyyy'), to_date('11-07-2005', 'dd-mm-yyyy'), 3, 4194, to_date('03-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040309012906, to_date('09-03-2004', 'dd-mm-yyyy'), to_date('23-03-2004', 'dd-mm-yyyy'), 2, 4271, to_date('25-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040123012907, to_date('23-01-2004', 'dd-mm-yyyy'), to_date('06-02-2004', 'dd-mm-yyyy'), 4, 3355, to_date('07-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121104012908, to_date('04-11-2012', 'dd-mm-yyyy'), to_date('18-11-2012', 'dd-mm-yyyy'), 2, 7963, to_date('17-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130925012909, to_date('25-09-2013', 'dd-mm-yyyy'), to_date('09-10-2013', 'dd-mm-yyyy'), 3, 9996, to_date('03-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140131012910, to_date('31-01-2014', 'dd-mm-yyyy'), to_date('14-02-2014', 'dd-mm-yyyy'), 3, 6643, to_date('09-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101102012911, to_date('02-11-2010', 'dd-mm-yyyy'), to_date('16-11-2010', 'dd-mm-yyyy'), 3, 8502, to_date('12-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080819012912, to_date('19-08-2008', 'dd-mm-yyyy'), to_date('02-09-2008', 'dd-mm-yyyy'), 2, 5941, to_date('21-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120609012913, to_date('09-06-2012', 'dd-mm-yyyy'), to_date('23-06-2012', 'dd-mm-yyyy'), 4, 7953, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041127012914, to_date('27-11-2004', 'dd-mm-yyyy'), to_date('11-12-2004', 'dd-mm-yyyy'), 1, 3592, to_date('11-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140403012915, to_date('03-04-2014', 'dd-mm-yyyy'), to_date('17-04-2014', 'dd-mm-yyyy'), 3, 10634, to_date('10-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110128012916, to_date('28-01-2011', 'dd-mm-yyyy'), to_date('11-02-2011', 'dd-mm-yyyy'), 3, 8688, to_date('09-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060908012917, to_date('08-09-2006', 'dd-mm-yyyy'), to_date('22-09-2006', 'dd-mm-yyyy'), 2, 4548, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000907012918, to_date('07-09-2000', 'dd-mm-yyyy'), to_date('21-09-2000', 'dd-mm-yyyy'), 3, 1298, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129012919, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 2, 3751, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050510012920, to_date('10-05-2005', 'dd-mm-yyyy'), to_date('24-05-2005', 'dd-mm-yyyy'), 2, 6392, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116012921, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 4, 7875, to_date('19-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090611012922, to_date('11-06-2009', 'dd-mm-yyyy'), to_date('25-06-2009', 'dd-mm-yyyy'), 2, 7320, to_date('25-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130929012923, to_date('29-09-2013', 'dd-mm-yyyy'), to_date('13-10-2013', 'dd-mm-yyyy'), 2, 9175, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120504012924, to_date('04-05-2012', 'dd-mm-yyyy'), to_date('18-05-2012', 'dd-mm-yyyy'), 1, 7670, to_date('23-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030621012925, to_date('21-06-2003', 'dd-mm-yyyy'), to_date('05-07-2003', 'dd-mm-yyyy'), 2, 3890, to_date('11-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031126012926, to_date('26-11-2003', 'dd-mm-yyyy'), to_date('10-12-2003', 'dd-mm-yyyy'), 1, 2709, to_date('07-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218012927, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 3, 7258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100124012928, to_date('24-01-2010', 'dd-mm-yyyy'), to_date('07-02-2010', 'dd-mm-yyyy'), 3, 7362, to_date('26-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061117012929, to_date('17-11-2006', 'dd-mm-yyyy'), to_date('01-12-2006', 'dd-mm-yyyy'), 4, 7939, to_date('03-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100107012930, to_date('07-01-2010', 'dd-mm-yyyy'), to_date('21-01-2010', 'dd-mm-yyyy'), 1, 7408, to_date('11-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070515012931, to_date('15-05-2007', 'dd-mm-yyyy'), to_date('29-05-2007', 'dd-mm-yyyy'), 2, 6955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030308012932, to_date('08-03-2003', 'dd-mm-yyyy'), to_date('22-03-2003', 'dd-mm-yyyy'), 1, 3617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131211012933, to_date('11-12-2013', 'dd-mm-yyyy'), to_date('25-12-2013', 'dd-mm-yyyy'), 1, 6562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070125012934, to_date('25-01-2007', 'dd-mm-yyyy'), to_date('08-02-2007', 'dd-mm-yyyy'), 4, 5475, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120623012935, to_date('23-06-2012', 'dd-mm-yyyy'), to_date('07-07-2012', 'dd-mm-yyyy'), 3, 8172, to_date('27-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000919012936, to_date('19-09-2000', 'dd-mm-yyyy'), to_date('03-10-2000', 'dd-mm-yyyy'), 2, 1608, to_date('26-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530012937, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 3, 4666, to_date('15-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121223012938, to_date('23-12-2012', 'dd-mm-yyyy'), to_date('06-01-2013', 'dd-mm-yyyy'), 3, 7509, to_date('02-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071217012939, to_date('17-12-2007', 'dd-mm-yyyy'), to_date('31-12-2007', 'dd-mm-yyyy'), 3, 6303, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020421012940, to_date('21-04-2002', 'dd-mm-yyyy'), to_date('05-05-2002', 'dd-mm-yyyy'), 4, 4684, to_date('28-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902012941, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 3, 2162, to_date('13-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010303012942, to_date('03-03-2001', 'dd-mm-yyyy'), to_date('17-03-2001', 'dd-mm-yyyy'), 3, 2053, to_date('15-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121109012943, to_date('09-11-2012', 'dd-mm-yyyy'), to_date('23-11-2012', 'dd-mm-yyyy'), 2, 8784, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011107012944, to_date('07-11-2001', 'dd-mm-yyyy'), to_date('21-11-2001', 'dd-mm-yyyy'), 3, 2580, to_date('24-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929012945, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 4, 4826, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011013012946, to_date('13-10-2001', 'dd-mm-yyyy'), to_date('27-10-2001', 'dd-mm-yyyy'), 2, 1917, to_date('27-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000808012947, to_date('08-08-2000', 'dd-mm-yyyy'), to_date('22-08-2000', 'dd-mm-yyyy'), 2, 2000, to_date('10-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040706012948, to_date('06-07-2004', 'dd-mm-yyyy'), to_date('20-07-2004', 'dd-mm-yyyy'), 3, 5295, to_date('18-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060918012949, to_date('18-09-2006', 'dd-mm-yyyy'), to_date('02-10-2006', 'dd-mm-yyyy'), 2, 7169, to_date('05-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050925012950, to_date('25-09-2005', 'dd-mm-yyyy'), to_date('09-10-2005', 'dd-mm-yyyy'), 3, 5425, to_date('30-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505012951, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 3, 5429, to_date('25-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040224012952, to_date('24-02-2004', 'dd-mm-yyyy'), to_date('09-03-2004', 'dd-mm-yyyy'), 2, 7227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051007012953, to_date('07-10-2005', 'dd-mm-yyyy'), to_date('21-10-2005', 'dd-mm-yyyy'), 3, 5017, to_date('15-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040613012954, to_date('13-06-2004', 'dd-mm-yyyy'), to_date('27-06-2004', 'dd-mm-yyyy'), 4, 4240, to_date('14-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725012955, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 3, 4020, to_date('27-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060829012956, to_date('29-08-2006', 'dd-mm-yyyy'), to_date('12-09-2006', 'dd-mm-yyyy'), 2, 5176, to_date('12-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030910012957, to_date('10-09-2003', 'dd-mm-yyyy'), to_date('24-09-2003', 'dd-mm-yyyy'), 2, 4059, to_date('21-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020310012958, to_date('10-03-2002', 'dd-mm-yyyy'), to_date('24-03-2002', 'dd-mm-yyyy'), 1, 2145, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050618012959, to_date('18-06-2005', 'dd-mm-yyyy'), to_date('02-07-2005', 'dd-mm-yyyy'), 2, 4779, to_date('30-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040229012960, to_date('29-02-2004', 'dd-mm-yyyy'), to_date('14-03-2004', 'dd-mm-yyyy'), 2, 3653, to_date('04-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071228012961, to_date('28-12-2007', 'dd-mm-yyyy'), to_date('11-01-2008', 'dd-mm-yyyy'), 2, 6982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010805012962, to_date('05-08-2001', 'dd-mm-yyyy'), to_date('19-08-2001', 'dd-mm-yyyy'), 1, 3566, to_date('22-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030321012963, to_date('21-03-2003', 'dd-mm-yyyy'), to_date('04-04-2003', 'dd-mm-yyyy'), 3, 4943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000126012964, to_date('26-01-2000', 'dd-mm-yyyy'), to_date('09-02-2000', 'dd-mm-yyyy'), 4, 1156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614012965, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 3, 6441, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130312012966, to_date('12-03-2013', 'dd-mm-yyyy'), to_date('26-03-2013', 'dd-mm-yyyy'), 3, 8870, to_date('29-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011029012967, to_date('29-10-2001', 'dd-mm-yyyy'), to_date('12-11-2001', 'dd-mm-yyyy'), 3, 1056, to_date('12-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825012968, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 4, 7070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607012969, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 3, 2181, to_date('10-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070203012970, to_date('03-02-2007', 'dd-mm-yyyy'), to_date('17-02-2007', 'dd-mm-yyyy'), 1, 4461, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022012971, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 4, 4075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091117012972, to_date('17-11-2009', 'dd-mm-yyyy'), to_date('01-12-2009', 'dd-mm-yyyy'), 3, 7333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100625012973, to_date('25-06-2010', 'dd-mm-yyyy'), to_date('09-07-2010', 'dd-mm-yyyy'), 3, 6613, to_date('04-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204012974, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 4, 3591, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020415012975, to_date('15-04-2002', 'dd-mm-yyyy'), to_date('29-04-2002', 'dd-mm-yyyy'), 3, 1521, to_date('29-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080418012976, to_date('18-04-2008', 'dd-mm-yyyy'), to_date('02-05-2008', 'dd-mm-yyyy'), 2, 8911, to_date('27-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030929012977, to_date('29-09-2003', 'dd-mm-yyyy'), to_date('13-10-2003', 'dd-mm-yyyy'), 3, 4550, to_date('06-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130707012978, to_date('07-07-2013', 'dd-mm-yyyy'), to_date('21-07-2013', 'dd-mm-yyyy'), 4, 8025, to_date('22-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070514012979, to_date('14-05-2007', 'dd-mm-yyyy'), to_date('28-05-2007', 'dd-mm-yyyy'), 3, 4675, to_date('15-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060119012980, to_date('19-01-2006', 'dd-mm-yyyy'), to_date('02-02-2006', 'dd-mm-yyyy'), 2, 3349, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010206012981, to_date('06-02-2001', 'dd-mm-yyyy'), to_date('20-02-2001', 'dd-mm-yyyy'), 3, 3087, to_date('24-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100327012982, to_date('27-03-2010', 'dd-mm-yyyy'), to_date('10-04-2010', 'dd-mm-yyyy'), 1, 5489, to_date('29-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110115012983, to_date('15-01-2011', 'dd-mm-yyyy'), to_date('29-01-2011', 'dd-mm-yyyy'), 3, 5487, to_date('30-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090712012984, to_date('12-07-2009', 'dd-mm-yyyy'), to_date('26-07-2009', 'dd-mm-yyyy'), 3, 7166, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120723012985, to_date('23-07-2012', 'dd-mm-yyyy'), to_date('06-08-2012', 'dd-mm-yyyy'), 3, 11410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930012986, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 2, 588, to_date('19-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051215012987, to_date('15-12-2005', 'dd-mm-yyyy'), to_date('29-12-2005', 'dd-mm-yyyy'), 3, 4391, to_date('23-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000824012988, to_date('24-08-2000', 'dd-mm-yyyy'), to_date('07-09-2000', 'dd-mm-yyyy'), 1, 1517, to_date('01-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111207012989, to_date('07-12-2011', 'dd-mm-yyyy'), to_date('21-12-2011', 'dd-mm-yyyy'), 2, 8131, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030822012990, to_date('22-08-2003', 'dd-mm-yyyy'), to_date('05-09-2003', 'dd-mm-yyyy'), 2, 3655, to_date('09-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020414012991, to_date('14-04-2002', 'dd-mm-yyyy'), to_date('28-04-2002', 'dd-mm-yyyy'), 3, 2535, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081203012992, to_date('03-12-2008', 'dd-mm-yyyy'), to_date('17-12-2008', 'dd-mm-yyyy'), 2, 6520, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329012993, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 2, 554, to_date('15-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090625012994, to_date('25-06-2009', 'dd-mm-yyyy'), to_date('09-07-2009', 'dd-mm-yyyy'), 2, 7068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131213012995, to_date('13-12-2013', 'dd-mm-yyyy'), to_date('27-12-2013', 'dd-mm-yyyy'), 1, 9730, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109012996, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 3, 10791, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110531012997, to_date('31-05-2011', 'dd-mm-yyyy'), to_date('14-06-2011', 'dd-mm-yyyy'), 4, 6944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009012998, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 2, 8913, to_date('25-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050112012999, to_date('12-01-2005', 'dd-mm-yyyy'), to_date('26-01-2005', 'dd-mm-yyyy'), 1, 4757, to_date('15-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110401013000, to_date('01-04-2011', 'dd-mm-yyyy'), to_date('15-04-2011', 'dd-mm-yyyy'), 3, 8082, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121230013001, to_date('30-12-2012', 'dd-mm-yyyy'), to_date('13-01-2013', 'dd-mm-yyyy'), 4, 10529, to_date('10-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060728013002, to_date('28-07-2006', 'dd-mm-yyyy'), to_date('11-08-2006', 'dd-mm-yyyy'), 4, 5409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010907013003, to_date('07-09-2001', 'dd-mm-yyyy'), to_date('21-09-2001', 'dd-mm-yyyy'), 2, 1847, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060905013004, to_date('05-09-2006', 'dd-mm-yyyy'), to_date('19-09-2006', 'dd-mm-yyyy'), 3, 4138, to_date('17-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030418013005, to_date('18-04-2003', 'dd-mm-yyyy'), to_date('02-05-2003', 'dd-mm-yyyy'), 2, 5203, to_date('30-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424013006, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 4, 10218, to_date('30-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080515013007, to_date('15-05-2008', 'dd-mm-yyyy'), to_date('29-05-2008', 'dd-mm-yyyy'), 4, 5163, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050214013008, to_date('14-02-2005', 'dd-mm-yyyy'), to_date('28-02-2005', 'dd-mm-yyyy'), 3, 3983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111111013009, to_date('11-11-2011', 'dd-mm-yyyy'), to_date('25-11-2011', 'dd-mm-yyyy'), 3, 6847, to_date('19-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010819013010, to_date('19-08-2001', 'dd-mm-yyyy'), to_date('02-09-2001', 'dd-mm-yyyy'), 4, 2882, to_date('01-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140304013011, to_date('04-03-2014', 'dd-mm-yyyy'), to_date('18-03-2014', 'dd-mm-yyyy'), 4, 7720, to_date('16-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011123013012, to_date('23-11-2001', 'dd-mm-yyyy'), to_date('07-12-2001', 'dd-mm-yyyy'), 2, 3254, to_date('06-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080205013013, to_date('05-02-2008', 'dd-mm-yyyy'), to_date('19-02-2008', 'dd-mm-yyyy'), 4, 5499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030613013014, to_date('13-06-2003', 'dd-mm-yyyy'), to_date('27-06-2003', 'dd-mm-yyyy'), 2, 1797, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110512013015, to_date('12-05-2011', 'dd-mm-yyyy'), to_date('26-05-2011', 'dd-mm-yyyy'), 3, 7550, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714013016, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 1, 5652, to_date('18-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090714013017, to_date('14-07-2009', 'dd-mm-yyyy'), to_date('28-07-2009', 'dd-mm-yyyy'), 3, 5067, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090921013018, to_date('21-09-2009', 'dd-mm-yyyy'), to_date('05-10-2009', 'dd-mm-yyyy'), 2, 6600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130824013019, to_date('24-08-2013', 'dd-mm-yyyy'), to_date('07-09-2013', 'dd-mm-yyyy'), 2, 6436, to_date('10-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061220013020, to_date('20-12-2006', 'dd-mm-yyyy'), to_date('03-01-2007', 'dd-mm-yyyy'), 2, 6000, to_date('05-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031104013021, to_date('04-11-2003', 'dd-mm-yyyy'), to_date('18-11-2003', 'dd-mm-yyyy'), 2, 3489, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050304013022, to_date('04-03-2005', 'dd-mm-yyyy'), to_date('18-03-2005', 'dd-mm-yyyy'), 4, 3506, to_date('19-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130223013023, to_date('23-02-2013', 'dd-mm-yyyy'), to_date('09-03-2013', 'dd-mm-yyyy'), 3, 9752, to_date('05-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040510013024, to_date('10-05-2004', 'dd-mm-yyyy'), to_date('24-05-2004', 'dd-mm-yyyy'), 1, 4117, to_date('29-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000813013025, to_date('13-08-2000', 'dd-mm-yyyy'), to_date('27-08-2000', 'dd-mm-yyyy'), 2, 2467, to_date('19-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802013026, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 8771, to_date('04-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101201013027, to_date('01-12-2010', 'dd-mm-yyyy'), to_date('15-12-2010', 'dd-mm-yyyy'), 4, 6005, to_date('14-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010422013028, to_date('22-04-2001', 'dd-mm-yyyy'), to_date('06-05-2001', 'dd-mm-yyyy'), 2, 751, to_date('07-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070112013029, to_date('12-01-2007', 'dd-mm-yyyy'), to_date('26-01-2007', 'dd-mm-yyyy'), 3, 4548, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010715013030, to_date('15-07-2001', 'dd-mm-yyyy'), to_date('29-07-2001', 'dd-mm-yyyy'), 2, 1834, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000306013031, to_date('06-03-2000', 'dd-mm-yyyy'), to_date('20-03-2000', 'dd-mm-yyyy'), 3, 1889, to_date('19-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713015555, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 1, 9489, to_date('30-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829015556, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 2, 4217, to_date('03-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050106015557, to_date('06-01-2005', 'dd-mm-yyyy'), to_date('20-01-2005', 'dd-mm-yyyy'), 1, 4007, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124015558, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 2, 2098, to_date('03-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924015559, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 2, 8406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120110015560, to_date('10-01-2012', 'dd-mm-yyyy'), to_date('24-01-2012', 'dd-mm-yyyy'), 3, 9456, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050404015561, to_date('04-04-2005', 'dd-mm-yyyy'), to_date('18-04-2005', 'dd-mm-yyyy'), 3, 4211, to_date('21-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430015562, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 2, 6490, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121015563, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 3, 3427, to_date('11-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111015564, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 4, 1680, to_date('30-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110712015565, to_date('12-07-2011', 'dd-mm-yyyy'), to_date('26-07-2011', 'dd-mm-yyyy'), 2, 8087, to_date('15-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110416015566, to_date('16-04-2011', 'dd-mm-yyyy'), to_date('30-04-2011', 'dd-mm-yyyy'), 2, 5265, to_date('29-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905015567, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 3, 4616, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060312015568, to_date('12-03-2006', 'dd-mm-yyyy'), to_date('26-03-2006', 'dd-mm-yyyy'), 4, 3194, to_date('17-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001014015569, to_date('14-10-2000', 'dd-mm-yyyy'), to_date('28-10-2000', 'dd-mm-yyyy'), 1, 1089, to_date('27-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050913015570, to_date('13-09-2005', 'dd-mm-yyyy'), to_date('27-09-2005', 'dd-mm-yyyy'), 2, 4591, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030622015571, to_date('22-06-2003', 'dd-mm-yyyy'), to_date('06-07-2003', 'dd-mm-yyyy'), 3, 4537, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071221015572, to_date('21-12-2007', 'dd-mm-yyyy'), to_date('04-01-2008', 'dd-mm-yyyy'), 3, 6661, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051012015573, to_date('12-10-2005', 'dd-mm-yyyy'), to_date('26-10-2005', 'dd-mm-yyyy'), 1, 6761, to_date('18-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120213015574, to_date('13-02-2012', 'dd-mm-yyyy'), to_date('27-02-2012', 'dd-mm-yyyy'), 2, 7141, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030503015575, to_date('03-05-2003', 'dd-mm-yyyy'), to_date('17-05-2003', 'dd-mm-yyyy'), 2, 2471, to_date('14-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030424015576, to_date('24-04-2003', 'dd-mm-yyyy'), to_date('08-05-2003', 'dd-mm-yyyy'), 1, 2859, to_date('25-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070406015577, to_date('06-04-2007', 'dd-mm-yyyy'), to_date('20-04-2007', 'dd-mm-yyyy'), 2, 6203, to_date('23-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060730015578, to_date('30-07-2006', 'dd-mm-yyyy'), to_date('13-08-2006', 'dd-mm-yyyy'), 2, 4097, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906015579, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 3, 9008, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110927015580, to_date('27-09-2011', 'dd-mm-yyyy'), to_date('11-10-2011', 'dd-mm-yyyy'), 4, 6015, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091005015581, to_date('05-10-2009', 'dd-mm-yyyy'), to_date('19-10-2009', 'dd-mm-yyyy'), 4, 4599, to_date('13-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080530015582, to_date('30-05-2008', 'dd-mm-yyyy'), to_date('13-06-2008', 'dd-mm-yyyy'), 4, 6262, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130707015583, to_date('07-07-2013', 'dd-mm-yyyy'), to_date('21-07-2013', 'dd-mm-yyyy'), 2, 10151, to_date('11-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110015584, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 1, 6592, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101015585, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 4, 2669, to_date('13-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130015586, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 3, 4647, to_date('13-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108015587, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 2, 8984, to_date('24-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209015588, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 4, 8126, to_date('14-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110517015589, to_date('17-05-2011', 'dd-mm-yyyy'), to_date('31-05-2011', 'dd-mm-yyyy'), 1, 6225, to_date('28-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725015590, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 1, 2862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120504015591, to_date('04-05-2012', 'dd-mm-yyyy'), to_date('18-05-2012', 'dd-mm-yyyy'), 4, 7289, to_date('09-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221015592, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 3, 2412, to_date('24-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050314015593, to_date('14-03-2005', 'dd-mm-yyyy'), to_date('28-03-2005', 'dd-mm-yyyy'), 4, 6122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040213015594, to_date('13-02-2004', 'dd-mm-yyyy'), to_date('27-02-2004', 'dd-mm-yyyy'), 4, 3332, to_date('17-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030718015595, to_date('18-07-2003', 'dd-mm-yyyy'), to_date('01-08-2003', 'dd-mm-yyyy'), 3, 5118, to_date('03-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020605015596, to_date('05-06-2002', 'dd-mm-yyyy'), to_date('19-06-2002', 'dd-mm-yyyy'), 2, 2315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140503015597, to_date('03-05-2014', 'dd-mm-yyyy'), to_date('17-05-2014', 'dd-mm-yyyy'), 2, 9880, to_date('15-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040818015598, to_date('18-08-2004', 'dd-mm-yyyy'), to_date('01-09-2004', 'dd-mm-yyyy'), 2, 4759, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040604015599, to_date('04-06-2004', 'dd-mm-yyyy'), to_date('18-06-2004', 'dd-mm-yyyy'), 1, 3898, to_date('22-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091204015600, to_date('04-12-2009', 'dd-mm-yyyy'), to_date('18-12-2009', 'dd-mm-yyyy'), 3, 5839, to_date('16-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040115015601, to_date('15-01-2004', 'dd-mm-yyyy'), to_date('29-01-2004', 'dd-mm-yyyy'), 4, 4380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725015602, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 2, 8247, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120811015603, to_date('11-08-2012', 'dd-mm-yyyy'), to_date('25-08-2012', 'dd-mm-yyyy'), 3, 7680, to_date('23-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090227015604, to_date('27-02-2009', 'dd-mm-yyyy'), to_date('13-03-2009', 'dd-mm-yyyy'), 2, 6348, to_date('09-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070127015605, to_date('27-01-2007', 'dd-mm-yyyy'), to_date('10-02-2007', 'dd-mm-yyyy'), 4, 5806, to_date('30-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010720015606, to_date('20-07-2001', 'dd-mm-yyyy'), to_date('03-08-2001', 'dd-mm-yyyy'), 4, 2620, to_date('04-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105015607, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 3, 6193, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090811015608, to_date('11-08-2009', 'dd-mm-yyyy'), to_date('25-08-2009', 'dd-mm-yyyy'), 4, 7275, to_date('25-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060405015609, to_date('05-04-2006', 'dd-mm-yyyy'), to_date('19-04-2006', 'dd-mm-yyyy'), 4, 4514, to_date('14-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021009015610, to_date('09-10-2002', 'dd-mm-yyyy'), to_date('23-10-2002', 'dd-mm-yyyy'), 4, 2614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307015611, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 1, 10908, to_date('27-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120710015612, to_date('10-07-2012', 'dd-mm-yyyy'), to_date('24-07-2012', 'dd-mm-yyyy'), 2, 10510, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111116015613, to_date('16-11-2011', 'dd-mm-yyyy'), to_date('30-11-2011', 'dd-mm-yyyy'), 2, 8455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514015614, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 1, 6945, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001025015615, to_date('25-10-2000', 'dd-mm-yyyy'), to_date('08-11-2000', 'dd-mm-yyyy'), 3, 661, to_date('27-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010703015616, to_date('03-07-2001', 'dd-mm-yyyy'), to_date('17-07-2001', 'dd-mm-yyyy'), 2, 3898, to_date('23-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000327015617, to_date('27-03-2000', 'dd-mm-yyyy'), to_date('10-04-2000', 'dd-mm-yyyy'), 3, 450, to_date('30-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070627015618, to_date('27-06-2007', 'dd-mm-yyyy'), to_date('11-07-2007', 'dd-mm-yyyy'), 4, 4765, to_date('07-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121015619, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 2, 3867, to_date('24-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303015620, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 3, 4638, to_date('21-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090131015621, to_date('31-01-2009', 'dd-mm-yyyy'), to_date('14-02-2009', 'dd-mm-yyyy'), 2, 5844, to_date('11-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100124015622, to_date('24-01-2010', 'dd-mm-yyyy'), to_date('07-02-2010', 'dd-mm-yyyy'), 3, 5216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120827015623, to_date('27-08-2012', 'dd-mm-yyyy'), to_date('10-09-2012', 'dd-mm-yyyy'), 4, 7558, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100712015624, to_date('12-07-2010', 'dd-mm-yyyy'), to_date('26-07-2010', 'dd-mm-yyyy'), 3, 5578, to_date('22-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930015625, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 4, 3737, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916015626, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 2, 7584, to_date('27-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001116015627, to_date('16-11-2000', 'dd-mm-yyyy'), to_date('30-11-2000', 'dd-mm-yyyy'), 3, 2823, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526015628, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 2, 1040, to_date('27-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041006015629, to_date('06-10-2004', 'dd-mm-yyyy'), to_date('20-10-2004', 'dd-mm-yyyy'), 3, 3176, to_date('11-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026015630, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 3, 1101, to_date('29-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101107015631, to_date('07-11-2010', 'dd-mm-yyyy'), to_date('21-11-2010', 'dd-mm-yyyy'), 1, 4818, to_date('27-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050919015632, to_date('19-09-2005', 'dd-mm-yyyy'), to_date('03-10-2005', 'dd-mm-yyyy'), 2, 4404, to_date('01-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131122015633, to_date('22-11-2013', 'dd-mm-yyyy'), to_date('06-12-2013', 'dd-mm-yyyy'), 3, 13190, to_date('01-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040624015634, to_date('24-06-2004', 'dd-mm-yyyy'), to_date('08-07-2004', 'dd-mm-yyyy'), 2, 3108, to_date('07-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111103015635, to_date('03-11-2011', 'dd-mm-yyyy'), to_date('17-11-2011', 'dd-mm-yyyy'), 3, 8242, to_date('06-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100514015636, to_date('14-05-2010', 'dd-mm-yyyy'), to_date('28-05-2010', 'dd-mm-yyyy'), 2, 6467, to_date('02-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620015637, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 2, 7300, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070710015638, to_date('10-07-2007', 'dd-mm-yyyy'), to_date('24-07-2007', 'dd-mm-yyyy'), 3, 7029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000512015639, to_date('12-05-2000', 'dd-mm-yyyy'), to_date('26-05-2000', 'dd-mm-yyyy'), 1, 2282, to_date('21-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090818015640, to_date('18-08-2009', 'dd-mm-yyyy'), to_date('01-09-2009', 'dd-mm-yyyy'), 2, 4873, to_date('30-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030525015641, to_date('25-05-2003', 'dd-mm-yyyy'), to_date('08-06-2003', 'dd-mm-yyyy'), 1, 5682, to_date('04-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011129015642, to_date('29-11-2001', 'dd-mm-yyyy'), to_date('13-12-2001', 'dd-mm-yyyy'), 2, 2052, to_date('03-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040514015643, to_date('14-05-2004', 'dd-mm-yyyy'), to_date('28-05-2004', 'dd-mm-yyyy'), 3, 3344, to_date('01-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090608015644, to_date('08-06-2009', 'dd-mm-yyyy'), to_date('22-06-2009', 'dd-mm-yyyy'), 2, 5088, to_date('14-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070423015645, to_date('23-04-2007', 'dd-mm-yyyy'), to_date('07-05-2007', 'dd-mm-yyyy'), 2, 5509, to_date('25-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110422015646, to_date('22-04-2011', 'dd-mm-yyyy'), to_date('06-05-2011', 'dd-mm-yyyy'), 3, 5190, to_date('23-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120504015647, to_date('04-05-2012', 'dd-mm-yyyy'), to_date('18-05-2012', 'dd-mm-yyyy'), 2, 6860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523015648, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 1, 3800, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304015649, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 3, 7752, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020423015650, to_date('23-04-2002', 'dd-mm-yyyy'), to_date('07-05-2002', 'dd-mm-yyyy'), 2, 2710, to_date('28-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000103015651, to_date('03-01-2000', 'dd-mm-yyyy'), to_date('17-01-2000', 'dd-mm-yyyy'), 1, 737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130417015652, to_date('17-04-2013', 'dd-mm-yyyy'), to_date('01-05-2013', 'dd-mm-yyyy'), 2, 8725, to_date('30-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110417015653, to_date('17-04-2011', 'dd-mm-yyyy'), to_date('01-05-2011', 'dd-mm-yyyy'), 2, 6949, to_date('06-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029015654, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 2, 7057, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021117015655, to_date('17-11-2002', 'dd-mm-yyyy'), to_date('01-12-2002', 'dd-mm-yyyy'), 2, 2946, to_date('28-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130108015656, to_date('08-01-2013', 'dd-mm-yyyy'), to_date('22-01-2013', 'dd-mm-yyyy'), 2, 8017, to_date('15-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060722015657, to_date('22-07-2006', 'dd-mm-yyyy'), to_date('05-08-2006', 'dd-mm-yyyy'), 1, 5839, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120716015658, to_date('16-07-2012', 'dd-mm-yyyy'), to_date('30-07-2012', 'dd-mm-yyyy'), 1, 8248, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060502015659, to_date('02-05-2006', 'dd-mm-yyyy'), to_date('16-05-2006', 'dd-mm-yyyy'), 4, 5696, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110106015660, to_date('06-01-2011', 'dd-mm-yyyy'), to_date('20-01-2011', 'dd-mm-yyyy'), 3, 6092, to_date('20-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100430015661, to_date('30-04-2010', 'dd-mm-yyyy'), to_date('14-05-2010', 'dd-mm-yyyy'), 3, 8532, to_date('05-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071002015662, to_date('02-10-2007', 'dd-mm-yyyy'), to_date('16-10-2007', 'dd-mm-yyyy'), 2, 4008, to_date('08-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040810015663, to_date('10-08-2004', 'dd-mm-yyyy'), to_date('24-08-2004', 'dd-mm-yyyy'), 2, 6470, to_date('30-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430015664, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 4, 9619, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050815015665, to_date('15-08-2005', 'dd-mm-yyyy'), to_date('29-08-2005', 'dd-mm-yyyy'), 3, 5352, to_date('16-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707015666, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 3, 5832, to_date('11-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060714015667, to_date('14-07-2006', 'dd-mm-yyyy'), to_date('28-07-2006', 'dd-mm-yyyy'), 1, 5086, to_date('26-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040726015668, to_date('26-07-2004', 'dd-mm-yyyy'), to_date('09-08-2004', 'dd-mm-yyyy'), 2, 2461, to_date('02-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140426015669, to_date('26-04-2014', 'dd-mm-yyyy'), to_date('10-05-2014', 'dd-mm-yyyy'), 4, 8725, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010604015670, to_date('04-06-2001', 'dd-mm-yyyy'), to_date('18-06-2001', 'dd-mm-yyyy'), 3, 2411, to_date('15-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040905015671, to_date('05-09-2004', 'dd-mm-yyyy'), to_date('19-09-2004', 'dd-mm-yyyy'), 2, 3016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000621015672, to_date('21-06-2000', 'dd-mm-yyyy'), to_date('05-07-2000', 'dd-mm-yyyy'), 3, 3116, to_date('28-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140126015673, to_date('26-01-2014', 'dd-mm-yyyy'), to_date('09-02-2014', 'dd-mm-yyyy'), 4, 8435, to_date('29-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041223015674, to_date('23-12-2004', 'dd-mm-yyyy'), to_date('06-01-2005', 'dd-mm-yyyy'), 1, 4392, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029015675, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 4, 3925, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031001015676, to_date('01-10-2003', 'dd-mm-yyyy'), to_date('15-10-2003', 'dd-mm-yyyy'), 2, 3658, to_date('18-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100312015677, to_date('12-03-2010', 'dd-mm-yyyy'), to_date('26-03-2010', 'dd-mm-yyyy'), 3, 4907, to_date('14-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090514015678, to_date('14-05-2009', 'dd-mm-yyyy'), to_date('28-05-2009', 'dd-mm-yyyy'), 1, 7144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061227015679, to_date('27-12-2006', 'dd-mm-yyyy'), to_date('10-01-2007', 'dd-mm-yyyy'), 1, 5514, to_date('16-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120531015680, to_date('31-05-2012', 'dd-mm-yyyy'), to_date('14-06-2012', 'dd-mm-yyyy'), 2, 8199, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109015681, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 2, 7264, to_date('27-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223015682, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 2, 7513, to_date('05-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319015683, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 2, 1785, to_date('22-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909015684, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 3, 4788, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110613015685, to_date('13-06-2011', 'dd-mm-yyyy'), to_date('27-06-2011', 'dd-mm-yyyy'), 3, 8605, to_date('25-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130727015686, to_date('27-07-2013', 'dd-mm-yyyy'), to_date('10-08-2013', 'dd-mm-yyyy'), 3, 11637, to_date('31-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090106015687, to_date('06-01-2009', 'dd-mm-yyyy'), to_date('20-01-2009', 'dd-mm-yyyy'), 2, 8417, to_date('25-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071105015688, to_date('05-11-2007', 'dd-mm-yyyy'), to_date('19-11-2007', 'dd-mm-yyyy'), 2, 4034, to_date('25-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020609015689, to_date('09-06-2002', 'dd-mm-yyyy'), to_date('23-06-2002', 'dd-mm-yyyy'), 4, 2701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010822015690, to_date('22-08-2001', 'dd-mm-yyyy'), to_date('05-09-2001', 'dd-mm-yyyy'), 3, 2098, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060116015691, to_date('16-01-2006', 'dd-mm-yyyy'), to_date('30-01-2006', 'dd-mm-yyyy'), 3, 3965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110512015692, to_date('12-05-2011', 'dd-mm-yyyy'), to_date('26-05-2011', 'dd-mm-yyyy'), 2, 10092, to_date('18-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131130015693, to_date('30-11-2013', 'dd-mm-yyyy'), to_date('14-12-2013', 'dd-mm-yyyy'), 3, 8648, to_date('12-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000928015694, to_date('28-09-2000', 'dd-mm-yyyy'), to_date('12-10-2000', 'dd-mm-yyyy'), 1, 1621, to_date('03-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130501015695, to_date('01-05-2013', 'dd-mm-yyyy'), to_date('15-05-2013', 'dd-mm-yyyy'), 2, 8319, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023015696, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 3, 3194, to_date('08-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081214015697, to_date('14-12-2008', 'dd-mm-yyyy'), to_date('28-12-2008', 'dd-mm-yyyy'), 4, 7688, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060408015698, to_date('08-04-2006', 'dd-mm-yyyy'), to_date('22-04-2006', 'dd-mm-yyyy'), 3, 6715, to_date('19-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070301015699, to_date('01-03-2007', 'dd-mm-yyyy'), to_date('15-03-2007', 'dd-mm-yyyy'), 3, 6650, to_date('19-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000229015700, to_date('29-02-2000', 'dd-mm-yyyy'), to_date('14-03-2000', 'dd-mm-yyyy'), 1, 816, to_date('16-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080111015701, to_date('11-01-2008', 'dd-mm-yyyy'), to_date('25-01-2008', 'dd-mm-yyyy'), 2, 8547, to_date('31-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140101015702, to_date('01-01-2014', 'dd-mm-yyyy'), to_date('15-01-2014', 'dd-mm-yyyy'), 3, 9831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110920015703, to_date('20-09-2011', 'dd-mm-yyyy'), to_date('04-10-2011', 'dd-mm-yyyy'), 2, 8326, to_date('30-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218015704, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 3, 3655, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040507015705, to_date('07-05-2004', 'dd-mm-yyyy'), to_date('21-05-2004', 'dd-mm-yyyy'), 1, 3609, to_date('12-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000419015706, to_date('19-04-2000', 'dd-mm-yyyy'), to_date('03-05-2000', 'dd-mm-yyyy'), 3, 1536, to_date('27-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725015707, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 2, 7217, to_date('10-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000127015708, to_date('27-01-2000', 'dd-mm-yyyy'), to_date('10-02-2000', 'dd-mm-yyyy'), 1, 2392, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040106015709, to_date('06-01-2004', 'dd-mm-yyyy'), to_date('20-01-2004', 'dd-mm-yyyy'), 2, 3611, to_date('12-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081225015710, to_date('25-12-2008', 'dd-mm-yyyy'), to_date('08-01-2009', 'dd-mm-yyyy'), 4, 6031, to_date('04-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009015711, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 2, 9825, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010907015712, to_date('07-09-2001', 'dd-mm-yyyy'), to_date('21-09-2001', 'dd-mm-yyyy'), 4, 2306, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516015713, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 2, 2773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050629015714, to_date('29-06-2005', 'dd-mm-yyyy'), to_date('13-07-2005', 'dd-mm-yyyy'), 3, 4863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081218015715, to_date('18-12-2008', 'dd-mm-yyyy'), to_date('01-01-2009', 'dd-mm-yyyy'), 2, 5463, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224015716, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 1, 5090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000714015717, to_date('14-07-2000', 'dd-mm-yyyy'), to_date('28-07-2000', 'dd-mm-yyyy'), 3, 1600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061013015718, to_date('13-10-2006', 'dd-mm-yyyy'), to_date('27-10-2006', 'dd-mm-yyyy'), 4, 4111, to_date('22-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081123015719, to_date('23-11-2008', 'dd-mm-yyyy'), to_date('07-12-2008', 'dd-mm-yyyy'), 3, 6477, to_date('04-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523015720, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 1, 2762, to_date('07-06-2003', 'dd-mm-yyyy'));
commit;
prompt 10000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530015721, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 2, 8873, to_date('02-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101212015722, to_date('12-12-2010', 'dd-mm-yyyy'), to_date('26-12-2010', 'dd-mm-yyyy'), 2, 5040, to_date('28-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030707015723, to_date('07-07-2003', 'dd-mm-yyyy'), to_date('21-07-2003', 'dd-mm-yyyy'), 2, 2461, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110929010258, to_date('29-09-2011', 'dd-mm-yyyy'), to_date('13-10-2011', 'dd-mm-yyyy'), 2, 7641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011201010259, to_date('01-12-2001', 'dd-mm-yyyy'), to_date('15-12-2001', 'dd-mm-yyyy'), 12, 2426, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020413010260, to_date('13-04-2002', 'dd-mm-yyyy'), to_date('27-04-2002', 'dd-mm-yyyy'), 1, 4699, to_date('18-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140405010261, to_date('05-04-2014', 'dd-mm-yyyy'), to_date('19-04-2014', 'dd-mm-yyyy'), 8, 10287, to_date('10-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009010262, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 9, 5160, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131113010263, to_date('13-11-2013', 'dd-mm-yyyy'), to_date('27-11-2013', 'dd-mm-yyyy'), 6, 5430, to_date('28-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090208010264, to_date('08-02-2009', 'dd-mm-yyyy'), to_date('22-02-2009', 'dd-mm-yyyy'), 3, 3785, to_date('18-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081025010265, to_date('25-10-2008', 'dd-mm-yyyy'), to_date('08-11-2008', 'dd-mm-yyyy'), 5, 7293, to_date('06-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225010266, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 11, 10324, to_date('06-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110113010267, to_date('13-01-2011', 'dd-mm-yyyy'), to_date('27-01-2011', 'dd-mm-yyyy'), 6, 8217, to_date('23-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001219010268, to_date('19-12-2000', 'dd-mm-yyyy'), to_date('02-01-2001', 'dd-mm-yyyy'), 4, 1271, to_date('24-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011010269, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 12, 7405, to_date('13-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020301010270, to_date('01-03-2002', 'dd-mm-yyyy'), to_date('15-03-2002', 'dd-mm-yyyy'), 3, 2846, to_date('05-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030611010271, to_date('11-06-2003', 'dd-mm-yyyy'), to_date('25-06-2003', 'dd-mm-yyyy'), 7, 3160, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120526010272, to_date('26-05-2012', 'dd-mm-yyyy'), to_date('09-06-2012', 'dd-mm-yyyy'), 4, 7382, to_date('10-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090311010273, to_date('11-03-2009', 'dd-mm-yyyy'), to_date('25-03-2009', 'dd-mm-yyyy'), 1, 5385, to_date('13-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123010274, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 4, 7149, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050111010275, to_date('11-01-2005', 'dd-mm-yyyy'), to_date('25-01-2005', 'dd-mm-yyyy'), 6, 4890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000120010276, to_date('20-01-2000', 'dd-mm-yyyy'), to_date('03-02-2000', 'dd-mm-yyyy'), 11, 1100, to_date('02-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050717010277, to_date('17-07-2005', 'dd-mm-yyyy'), to_date('31-07-2005', 'dd-mm-yyyy'), 8, 7052, to_date('06-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060802010278, to_date('02-08-2006', 'dd-mm-yyyy'), to_date('16-08-2006', 'dd-mm-yyyy'), 6, 5411, to_date('14-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628010279, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 5, 1259, to_date('04-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011118010280, to_date('18-11-2001', 'dd-mm-yyyy'), to_date('02-12-2001', 'dd-mm-yyyy'), 7, 3289, to_date('21-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130325010281, to_date('25-03-2013', 'dd-mm-yyyy'), to_date('08-04-2013', 'dd-mm-yyyy'), 8, 9460, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707010282, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 11, 7291, to_date('20-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040102010283, to_date('02-01-2004', 'dd-mm-yyyy'), to_date('16-01-2004', 'dd-mm-yyyy'), 3, 5027, to_date('04-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060331010284, to_date('31-03-2006', 'dd-mm-yyyy'), to_date('14-04-2006', 'dd-mm-yyyy'), 6, 6371, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011122010285, to_date('22-11-2001', 'dd-mm-yyyy'), to_date('06-12-2001', 'dd-mm-yyyy'), 5, 2703, to_date('10-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129010286, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 2, 5134, to_date('10-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041127010287, to_date('27-11-2004', 'dd-mm-yyyy'), to_date('11-12-2004', 'dd-mm-yyyy'), 5, 3685, to_date('12-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220010288, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 8, 9980, to_date('04-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020410010289, to_date('10-04-2002', 'dd-mm-yyyy'), to_date('24-04-2002', 'dd-mm-yyyy'), 11, 2711, to_date('30-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111229010290, to_date('29-12-2011', 'dd-mm-yyyy'), to_date('12-01-2012', 'dd-mm-yyyy'), 10, 7211, to_date('03-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100723010291, to_date('23-07-2010', 'dd-mm-yyyy'), to_date('06-08-2010', 'dd-mm-yyyy'), 11, 7125, to_date('08-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001128010292, to_date('28-11-2000', 'dd-mm-yyyy'), to_date('12-12-2000', 'dd-mm-yyyy'), 4, 3697, to_date('13-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100131010293, to_date('31-01-2010', 'dd-mm-yyyy'), to_date('14-02-2010', 'dd-mm-yyyy'), 6, 7145, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000223010294, to_date('23-02-2000', 'dd-mm-yyyy'), to_date('08-03-2000', 'dd-mm-yyyy'), 2, 1359, to_date('27-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120529010295, to_date('29-05-2012', 'dd-mm-yyyy'), to_date('12-06-2012', 'dd-mm-yyyy'), 8, 9064, to_date('12-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010222010296, to_date('22-02-2001', 'dd-mm-yyyy'), to_date('08-03-2001', 'dd-mm-yyyy'), 4, 1312, to_date('28-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050823010297, to_date('23-08-2005', 'dd-mm-yyyy'), to_date('06-09-2005', 'dd-mm-yyyy'), 5, 3013, to_date('10-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140331010298, to_date('31-03-2014', 'dd-mm-yyyy'), to_date('14-04-2014', 'dd-mm-yyyy'), 4, 8755, to_date('02-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080810010299, to_date('10-08-2008', 'dd-mm-yyyy'), to_date('24-08-2008', 'dd-mm-yyyy'), 6, 4916, to_date('17-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201010300, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 1, 2829, to_date('12-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029010301, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 9, 5886, to_date('04-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220010302, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 7, 4372, to_date('22-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013010303, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 6, 3638, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120010304, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 5, 3845, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105010305, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 3, 8513, to_date('16-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080306010306, to_date('06-03-2008', 'dd-mm-yyyy'), to_date('20-03-2008', 'dd-mm-yyyy'), 6, 3657, to_date('17-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101029010307, to_date('29-10-2010', 'dd-mm-yyyy'), to_date('12-11-2010', 'dd-mm-yyyy'), 9, 8364, to_date('15-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031221010308, to_date('21-12-2003', 'dd-mm-yyyy'), to_date('04-01-2004', 'dd-mm-yyyy'), 3, 4006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040112010309, to_date('12-01-2004', 'dd-mm-yyyy'), to_date('26-01-2004', 'dd-mm-yyyy'), 2, 4137, to_date('20-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120111010310, to_date('11-01-2012', 'dd-mm-yyyy'), to_date('25-01-2012', 'dd-mm-yyyy'), 8, 10512, to_date('20-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030219010311, to_date('19-02-2003', 'dd-mm-yyyy'), to_date('05-03-2003', 'dd-mm-yyyy'), 7, 3741, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071007010312, to_date('07-10-2007', 'dd-mm-yyyy'), to_date('21-10-2007', 'dd-mm-yyyy'), 10, 5117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404010313, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 1, 2177, to_date('06-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000608010314, to_date('08-06-2000', 'dd-mm-yyyy'), to_date('22-06-2000', 'dd-mm-yyyy'), 7, 669, to_date('20-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030415010315, to_date('15-04-2003', 'dd-mm-yyyy'), to_date('29-04-2003', 'dd-mm-yyyy'), 11, 4232, to_date('26-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529010316, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 4, 7296, to_date('16-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106010317, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 4, 5115, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130806010318, to_date('06-08-2013', 'dd-mm-yyyy'), to_date('20-08-2013', 'dd-mm-yyyy'), 4, 9500, to_date('21-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318010319, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 8, 6792, to_date('30-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090326010320, to_date('26-03-2009', 'dd-mm-yyyy'), to_date('09-04-2009', 'dd-mm-yyyy'), 1, 5463, to_date('02-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070702010321, to_date('02-07-2007', 'dd-mm-yyyy'), to_date('16-07-2007', 'dd-mm-yyyy'), 12, 4827, to_date('06-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140511010322, to_date('11-05-2014', 'dd-mm-yyyy'), to_date('25-05-2014', 'dd-mm-yyyy'), 4, 9055, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061110010323, to_date('10-11-2006', 'dd-mm-yyyy'), to_date('24-11-2006', 'dd-mm-yyyy'), 2, 4213, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140401010324, to_date('01-04-2014', 'dd-mm-yyyy'), to_date('15-04-2014', 'dd-mm-yyyy'), 3, 9104, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010918010325, to_date('18-09-2001', 'dd-mm-yyyy'), to_date('02-10-2001', 'dd-mm-yyyy'), 10, 2306, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107010326, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 5, 3772, to_date('14-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111024010327, to_date('24-10-2011', 'dd-mm-yyyy'), to_date('07-11-2011', 'dd-mm-yyyy'), 4, 7959, to_date('07-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618010328, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 9, 1058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100810010329, to_date('10-08-2010', 'dd-mm-yyyy'), to_date('24-08-2010', 'dd-mm-yyyy'), 4, 8083, to_date('27-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081026010330, to_date('26-10-2008', 'dd-mm-yyyy'), to_date('09-11-2008', 'dd-mm-yyyy'), 10, 3783, to_date('28-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060809010331, to_date('09-08-2006', 'dd-mm-yyyy'), to_date('23-08-2006', 'dd-mm-yyyy'), 10, 6096, to_date('12-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041024010332, to_date('24-10-2004', 'dd-mm-yyyy'), to_date('07-11-2004', 'dd-mm-yyyy'), 3, 3463, to_date('27-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529010333, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 1, 10995, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050420010334, to_date('20-04-2005', 'dd-mm-yyyy'), to_date('04-05-2005', 'dd-mm-yyyy'), 1, 4984, to_date('10-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717010335, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 2, 4844, to_date('30-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010514010336, to_date('14-05-2001', 'dd-mm-yyyy'), to_date('28-05-2001', 'dd-mm-yyyy'), 1, 4259, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000819010337, to_date('19-08-2000', 'dd-mm-yyyy'), to_date('02-09-2000', 'dd-mm-yyyy'), 2, 2385, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121203010338, to_date('03-12-2012', 'dd-mm-yyyy'), to_date('17-12-2012', 'dd-mm-yyyy'), 3, 7635, to_date('22-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090818010339, to_date('18-08-2009', 'dd-mm-yyyy'), to_date('01-09-2009', 'dd-mm-yyyy'), 10, 5965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040719010340, to_date('19-07-2004', 'dd-mm-yyyy'), to_date('02-08-2004', 'dd-mm-yyyy'), 4, 3813, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026010341, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 2, 1258, to_date('14-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121002010342, to_date('02-10-2012', 'dd-mm-yyyy'), to_date('16-10-2012', 'dd-mm-yyyy'), 8, 5887, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327010343, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 6, 9203, to_date('11-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030927010344, to_date('27-09-2003', 'dd-mm-yyyy'), to_date('11-10-2003', 'dd-mm-yyyy'), 1, 3632, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901010345, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 8, 9734, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070228010346, to_date('28-02-2007', 'dd-mm-yyyy'), to_date('14-03-2007', 'dd-mm-yyyy'), 1, 8752, to_date('16-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080818010347, to_date('18-08-2008', 'dd-mm-yyyy'), to_date('01-09-2008', 'dd-mm-yyyy'), 11, 7054, to_date('20-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227010348, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 2, 3801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070122010349, to_date('22-01-2007', 'dd-mm-yyyy'), to_date('05-02-2007', 'dd-mm-yyyy'), 11, 5767, to_date('29-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111222010350, to_date('22-12-2011', 'dd-mm-yyyy'), to_date('05-01-2012', 'dd-mm-yyyy'), 5, 9661, to_date('04-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530010351, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 5, 2866, to_date('05-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040812010352, to_date('12-08-2004', 'dd-mm-yyyy'), to_date('26-08-2004', 'dd-mm-yyyy'), 4, 4047, to_date('25-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602010353, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 10, 2932, to_date('06-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050612010354, to_date('12-06-2005', 'dd-mm-yyyy'), to_date('26-06-2005', 'dd-mm-yyyy'), 3, 4032, to_date('23-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130730010355, to_date('30-07-2013', 'dd-mm-yyyy'), to_date('13-08-2013', 'dd-mm-yyyy'), 3, 10632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070530010356, to_date('30-05-2007', 'dd-mm-yyyy'), to_date('13-06-2007', 'dd-mm-yyyy'), 5, 8545, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010320010357, to_date('20-03-2001', 'dd-mm-yyyy'), to_date('03-04-2001', 'dd-mm-yyyy'), 5, 1247, to_date('25-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070307010358, to_date('07-03-2007', 'dd-mm-yyyy'), to_date('21-03-2007', 'dd-mm-yyyy'), 1, 3499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120421010359, to_date('21-04-2012', 'dd-mm-yyyy'), to_date('05-05-2012', 'dd-mm-yyyy'), 9, 6303, to_date('30-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021014010360, to_date('14-10-2002', 'dd-mm-yyyy'), to_date('28-10-2002', 'dd-mm-yyyy'), 10, 2000, to_date('15-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070206010361, to_date('06-02-2007', 'dd-mm-yyyy'), to_date('20-02-2007', 'dd-mm-yyyy'), 7, 7710, to_date('10-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128010362, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 7, 5966, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010523010363, to_date('23-05-2001', 'dd-mm-yyyy'), to_date('06-06-2001', 'dd-mm-yyyy'), 6, 2765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001121010364, to_date('21-11-2000', 'dd-mm-yyyy'), to_date('05-12-2000', 'dd-mm-yyyy'), 9, 3041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100630010365, to_date('30-06-2010', 'dd-mm-yyyy'), to_date('14-07-2010', 'dd-mm-yyyy'), 10, 7014, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902010366, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 7, 2240, to_date('05-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503010367, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 5, 7384, to_date('09-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080120010368, to_date('20-01-2008', 'dd-mm-yyyy'), to_date('03-02-2008', 'dd-mm-yyyy'), 4, 5663, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040910010369, to_date('10-09-2004', 'dd-mm-yyyy'), to_date('24-09-2004', 'dd-mm-yyyy'), 2, 2725, to_date('17-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000519010370, to_date('19-05-2000', 'dd-mm-yyyy'), to_date('02-06-2000', 'dd-mm-yyyy'), 8, 3109, to_date('27-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108010371, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 8, 6387, to_date('25-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090713010372, to_date('13-07-2009', 'dd-mm-yyyy'), to_date('27-07-2009', 'dd-mm-yyyy'), 9, 5658, to_date('25-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050118010373, to_date('18-01-2005', 'dd-mm-yyyy'), to_date('01-02-2005', 'dd-mm-yyyy'), 2, 4492, to_date('27-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030731010374, to_date('31-07-2003', 'dd-mm-yyyy'), to_date('14-08-2003', 'dd-mm-yyyy'), 7, 5339, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070612010375, to_date('12-06-2007', 'dd-mm-yyyy'), to_date('26-06-2007', 'dd-mm-yyyy'), 3, 5144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090307010376, to_date('07-03-2009', 'dd-mm-yyyy'), to_date('21-03-2009', 'dd-mm-yyyy'), 10, 4411, to_date('21-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080701010377, to_date('01-07-2008', 'dd-mm-yyyy'), to_date('15-07-2008', 'dd-mm-yyyy'), 6, 5583, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061110010378, to_date('10-11-2006', 'dd-mm-yyyy'), to_date('24-11-2006', 'dd-mm-yyyy'), 8, 4152, to_date('27-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001221010379, to_date('21-12-2000', 'dd-mm-yyyy'), to_date('04-01-2001', 'dd-mm-yyyy'), 11, 1976, to_date('04-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001207010380, to_date('07-12-2000', 'dd-mm-yyyy'), to_date('21-12-2000', 'dd-mm-yyyy'), 9, 1821, to_date('09-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090612010381, to_date('12-06-2009', 'dd-mm-yyyy'), to_date('26-06-2009', 'dd-mm-yyyy'), 7, 6093, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060213010382, to_date('13-02-2006', 'dd-mm-yyyy'), to_date('27-02-2006', 'dd-mm-yyyy'), 6, 5809, to_date('21-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051014010383, to_date('14-10-2005', 'dd-mm-yyyy'), to_date('28-10-2005', 'dd-mm-yyyy'), 9, 4015, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110102010384, to_date('02-01-2011', 'dd-mm-yyyy'), to_date('16-01-2011', 'dd-mm-yyyy'), 7, 7665, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130628010385, to_date('28-06-2013', 'dd-mm-yyyy'), to_date('12-07-2013', 'dd-mm-yyyy'), 2, 9087, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070709010386, to_date('09-07-2007', 'dd-mm-yyyy'), to_date('23-07-2007', 'dd-mm-yyyy'), 2, 5953, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100412010387, to_date('12-04-2010', 'dd-mm-yyyy'), to_date('26-04-2010', 'dd-mm-yyyy'), 6, 9352, to_date('30-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609010388, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 6, 7204, to_date('12-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406010389, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 5, 4279, to_date('18-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071103010390, to_date('03-11-2007', 'dd-mm-yyyy'), to_date('17-11-2007', 'dd-mm-yyyy'), 7, 6270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130222010391, to_date('22-02-2013', 'dd-mm-yyyy'), to_date('08-03-2013', 'dd-mm-yyyy'), 7, 7088, to_date('12-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100208010392, to_date('08-02-2010', 'dd-mm-yyyy'), to_date('22-02-2010', 'dd-mm-yyyy'), 2, 7429, to_date('23-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010918010393, to_date('18-09-2001', 'dd-mm-yyyy'), to_date('02-10-2001', 'dd-mm-yyyy'), 12, 3361, to_date('02-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010203010394, to_date('03-02-2001', 'dd-mm-yyyy'), to_date('17-02-2001', 'dd-mm-yyyy'), 8, 3429, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130913010395, to_date('13-09-2013', 'dd-mm-yyyy'), to_date('27-09-2013', 'dd-mm-yyyy'), 1, 6559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111221010396, to_date('21-12-2011', 'dd-mm-yyyy'), to_date('04-01-2012', 'dd-mm-yyyy'), 12, 7658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001205010397, to_date('05-12-2000', 'dd-mm-yyyy'), to_date('19-12-2000', 'dd-mm-yyyy'), 7, 2839, to_date('09-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080720010398, to_date('20-07-2008', 'dd-mm-yyyy'), to_date('03-08-2008', 'dd-mm-yyyy'), 11, 4995, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140107010399, to_date('07-01-2014', 'dd-mm-yyyy'), to_date('21-01-2014', 'dd-mm-yyyy'), 7, 10339, to_date('19-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100913010400, to_date('13-09-2010', 'dd-mm-yyyy'), to_date('27-09-2010', 'dd-mm-yyyy'), 2, 7432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815010401, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 8, 2258, to_date('20-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817010402, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 9, 5489, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060814010403, to_date('14-08-2006', 'dd-mm-yyyy'), to_date('28-08-2006', 'dd-mm-yyyy'), 4, 8508, to_date('03-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130313010404, to_date('13-03-2013', 'dd-mm-yyyy'), to_date('27-03-2013', 'dd-mm-yyyy'), 2, 8514, to_date('28-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090508010405, to_date('08-05-2009', 'dd-mm-yyyy'), to_date('22-05-2009', 'dd-mm-yyyy'), 8, 6162, to_date('24-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140219010406, to_date('19-02-2014', 'dd-mm-yyyy'), to_date('05-03-2014', 'dd-mm-yyyy'), 8, 11233, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090720010407, to_date('20-07-2009', 'dd-mm-yyyy'), to_date('03-08-2009', 'dd-mm-yyyy'), 11, 5176, to_date('04-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031014010408, to_date('14-10-2003', 'dd-mm-yyyy'), to_date('28-10-2003', 'dd-mm-yyyy'), 10, 1786, to_date('30-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101204010409, to_date('04-12-2010', 'dd-mm-yyyy'), to_date('18-12-2010', 'dd-mm-yyyy'), 7, 8100, to_date('10-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070713010410, to_date('13-07-2007', 'dd-mm-yyyy'), to_date('27-07-2007', 'dd-mm-yyyy'), 11, 5351, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130401010411, to_date('01-04-2013', 'dd-mm-yyyy'), to_date('15-04-2013', 'dd-mm-yyyy'), 12, 10219, to_date('21-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120405010412, to_date('05-04-2012', 'dd-mm-yyyy'), to_date('19-04-2012', 'dd-mm-yyyy'), 5, 7934, to_date('10-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121017013032, to_date('17-10-2012', 'dd-mm-yyyy'), to_date('31-10-2012', 'dd-mm-yyyy'), 4, 7726, to_date('29-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020321013033, to_date('21-03-2002', 'dd-mm-yyyy'), to_date('04-04-2002', 'dd-mm-yyyy'), 2, 2417, to_date('10-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111202013034, to_date('02-12-2011', 'dd-mm-yyyy'), to_date('16-12-2011', 'dd-mm-yyyy'), 4, 6803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040401013035, to_date('01-04-2004', 'dd-mm-yyyy'), to_date('15-04-2004', 'dd-mm-yyyy'), 1, 4788, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010801013036, to_date('01-08-2001', 'dd-mm-yyyy'), to_date('15-08-2001', 'dd-mm-yyyy'), 1, 2522, to_date('05-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091102013037, to_date('02-11-2009', 'dd-mm-yyyy'), to_date('16-11-2009', 'dd-mm-yyyy'), 1, 8213, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522013038, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 1, 6311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000701013039, to_date('01-07-2000', 'dd-mm-yyyy'), to_date('15-07-2000', 'dd-mm-yyyy'), 2, 2140, to_date('03-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423013040, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 2, 1316, to_date('13-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051228013041, to_date('28-12-2005', 'dd-mm-yyyy'), to_date('11-01-2006', 'dd-mm-yyyy'), 1, 3055, to_date('15-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430013042, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 3, 6151, to_date('05-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429013043, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 3, 4231, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070525013044, to_date('25-05-2007', 'dd-mm-yyyy'), to_date('08-06-2007', 'dd-mm-yyyy'), 3, 6448, to_date('04-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100710013045, to_date('10-07-2010', 'dd-mm-yyyy'), to_date('24-07-2010', 'dd-mm-yyyy'), 4, 8694, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302013046, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 3, 4573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040719013047, to_date('19-07-2004', 'dd-mm-yyyy'), to_date('02-08-2004', 'dd-mm-yyyy'), 4, 4703, to_date('23-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101013048, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 2, 7082, to_date('11-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091002013049, to_date('02-10-2009', 'dd-mm-yyyy'), to_date('16-10-2009', 'dd-mm-yyyy'), 2, 8142, to_date('10-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080702013050, to_date('02-07-2008', 'dd-mm-yyyy'), to_date('16-07-2008', 'dd-mm-yyyy'), 2, 3454, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010731013051, to_date('31-07-2001', 'dd-mm-yyyy'), to_date('14-08-2001', 'dd-mm-yyyy'), 2, 1979, to_date('03-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040428013052, to_date('28-04-2004', 'dd-mm-yyyy'), to_date('12-05-2004', 'dd-mm-yyyy'), 3, 4485, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100129013053, to_date('29-01-2010', 'dd-mm-yyyy'), to_date('12-02-2010', 'dd-mm-yyyy'), 2, 5982, to_date('07-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120422013054, to_date('22-04-2012', 'dd-mm-yyyy'), to_date('06-05-2012', 'dd-mm-yyyy'), 1, 8557, to_date('06-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071127013055, to_date('27-11-2007', 'dd-mm-yyyy'), to_date('11-12-2007', 'dd-mm-yyyy'), 1, 5043, to_date('17-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030816013056, to_date('16-08-2003', 'dd-mm-yyyy'), to_date('30-08-2003', 'dd-mm-yyyy'), 3, 4283, to_date('05-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211013057, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 3, 3458, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040226013058, to_date('26-02-2004', 'dd-mm-yyyy'), to_date('11-03-2004', 'dd-mm-yyyy'), 2, 4185, to_date('05-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061225013059, to_date('25-12-2006', 'dd-mm-yyyy'), to_date('08-01-2007', 'dd-mm-yyyy'), 2, 3219, to_date('27-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010613013060, to_date('13-06-2001', 'dd-mm-yyyy'), to_date('27-06-2001', 'dd-mm-yyyy'), 4, 2508, to_date('26-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010622013061, to_date('22-06-2001', 'dd-mm-yyyy'), to_date('06-07-2001', 'dd-mm-yyyy'), 3, 2034, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609013062, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 1, 8501, to_date('12-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109013063, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 3, 5074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223013064, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 3, 10096, to_date('29-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111009013065, to_date('09-10-2011', 'dd-mm-yyyy'), to_date('23-10-2011', 'dd-mm-yyyy'), 2, 5537, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000315013066, to_date('15-03-2000', 'dd-mm-yyyy'), to_date('29-03-2000', 'dd-mm-yyyy'), 2, 2152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220013067, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 2, 6393, to_date('01-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091207013068, to_date('07-12-2009', 'dd-mm-yyyy'), to_date('21-12-2009', 'dd-mm-yyyy'), 3, 7551, to_date('19-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050524013069, to_date('24-05-2005', 'dd-mm-yyyy'), to_date('07-06-2005', 'dd-mm-yyyy'), 1, 2763, to_date('04-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020125013070, to_date('25-01-2002', 'dd-mm-yyyy'), to_date('08-02-2002', 'dd-mm-yyyy'), 3, 1554, to_date('13-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060429013071, to_date('29-04-2006', 'dd-mm-yyyy'), to_date('13-05-2006', 'dd-mm-yyyy'), 3, 4614, to_date('03-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041124013072, to_date('24-11-2004', 'dd-mm-yyyy'), to_date('08-12-2004', 'dd-mm-yyyy'), 3, 3892, to_date('14-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020813013073, to_date('13-08-2002', 'dd-mm-yyyy'), to_date('27-08-2002', 'dd-mm-yyyy'), 2, 1785, to_date('14-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031029013074, to_date('29-10-2003', 'dd-mm-yyyy'), to_date('12-11-2003', 'dd-mm-yyyy'), 3, 4341, to_date('09-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090401013075, to_date('01-04-2009', 'dd-mm-yyyy'), to_date('15-04-2009', 'dd-mm-yyyy'), 4, 6696, to_date('08-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112013076, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 2, 5976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030309013077, to_date('09-03-2003', 'dd-mm-yyyy'), to_date('23-03-2003', 'dd-mm-yyyy'), 4, 3978, to_date('20-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111205013078, to_date('05-12-2011', 'dd-mm-yyyy'), to_date('19-12-2011', 'dd-mm-yyyy'), 2, 6093, to_date('07-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121210013079, to_date('10-12-2012', 'dd-mm-yyyy'), to_date('24-12-2012', 'dd-mm-yyyy'), 2, 8898, to_date('13-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020821013080, to_date('21-08-2002', 'dd-mm-yyyy'), to_date('04-09-2002', 'dd-mm-yyyy'), 3, 1729, to_date('24-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061102013081, to_date('02-11-2006', 'dd-mm-yyyy'), to_date('16-11-2006', 'dd-mm-yyyy'), 4, 5223, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120416013082, to_date('16-04-2012', 'dd-mm-yyyy'), to_date('30-04-2012', 'dd-mm-yyyy'), 1, 8314, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302013083, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 3, 2614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020714013084, to_date('14-07-2002', 'dd-mm-yyyy'), to_date('28-07-2002', 'dd-mm-yyyy'), 2, 3198, to_date('02-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140105013085, to_date('05-01-2014', 'dd-mm-yyyy'), to_date('19-01-2014', 'dd-mm-yyyy'), 4, 12510, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130222013086, to_date('22-02-2013', 'dd-mm-yyyy'), to_date('08-03-2013', 'dd-mm-yyyy'), 3, 7824, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030529013087, to_date('29-05-2003', 'dd-mm-yyyy'), to_date('12-06-2003', 'dd-mm-yyyy'), 2, 3342, to_date('31-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022013088, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 2, 6253, to_date('05-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030407013089, to_date('07-04-2003', 'dd-mm-yyyy'), to_date('21-04-2003', 'dd-mm-yyyy'), 1, 3191, to_date('14-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020915013090, to_date('15-09-2002', 'dd-mm-yyyy'), to_date('29-09-2002', 'dd-mm-yyyy'), 1, 1432, to_date('17-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081114013091, to_date('14-11-2008', 'dd-mm-yyyy'), to_date('28-11-2008', 'dd-mm-yyyy'), 3, 6850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080707013092, to_date('07-07-2008', 'dd-mm-yyyy'), to_date('21-07-2008', 'dd-mm-yyyy'), 1, 7113, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041029013093, to_date('29-10-2004', 'dd-mm-yyyy'), to_date('12-11-2004', 'dd-mm-yyyy'), 2, 6515, to_date('06-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090625013094, to_date('25-06-2009', 'dd-mm-yyyy'), to_date('09-07-2009', 'dd-mm-yyyy'), 2, 10059, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021013095, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 1, 6409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070816013096, to_date('16-08-2007', 'dd-mm-yyyy'), to_date('30-08-2007', 'dd-mm-yyyy'), 3, 5518, to_date('18-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426013097, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 4, 5019, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121201013098, to_date('01-12-2012', 'dd-mm-yyyy'), to_date('15-12-2012', 'dd-mm-yyyy'), 1, 7635, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010427013099, to_date('27-04-2001', 'dd-mm-yyyy'), to_date('11-05-2001', 'dd-mm-yyyy'), 3, 3560, to_date('07-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307013100, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 4, 6742, to_date('21-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140226013101, to_date('26-02-2014', 'dd-mm-yyyy'), to_date('12-03-2014', 'dd-mm-yyyy'), 3, 9549, to_date('12-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111120013102, to_date('20-11-2011', 'dd-mm-yyyy'), to_date('04-12-2011', 'dd-mm-yyyy'), 3, 6908, to_date('03-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208013103, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 3, 6038, to_date('15-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030616013104, to_date('16-06-2003', 'dd-mm-yyyy'), to_date('30-06-2003', 'dd-mm-yyyy'), 2, 3292, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000119013105, to_date('19-01-2000', 'dd-mm-yyyy'), to_date('02-02-2000', 'dd-mm-yyyy'), 4, 852, to_date('05-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090503013106, to_date('03-05-2009', 'dd-mm-yyyy'), to_date('17-05-2009', 'dd-mm-yyyy'), 3, 7070, to_date('09-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020914013107, to_date('14-09-2002', 'dd-mm-yyyy'), to_date('28-09-2002', 'dd-mm-yyyy'), 3, 3672, to_date('22-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907013108, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 3, 4019, to_date('14-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040925013109, to_date('25-09-2004', 'dd-mm-yyyy'), to_date('09-10-2004', 'dd-mm-yyyy'), 2, 4127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070412013110, to_date('12-04-2007', 'dd-mm-yyyy'), to_date('26-04-2007', 'dd-mm-yyyy'), 3, 6705, to_date('17-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327013111, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 4, 7396, to_date('12-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040401013112, to_date('01-04-2004', 'dd-mm-yyyy'), to_date('15-04-2004', 'dd-mm-yyyy'), 3, 4035, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050418013113, to_date('18-04-2005', 'dd-mm-yyyy'), to_date('02-05-2005', 'dd-mm-yyyy'), 3, 4058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120305013114, to_date('05-03-2012', 'dd-mm-yyyy'), to_date('19-03-2012', 'dd-mm-yyyy'), 3, 7251, to_date('12-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030122013115, to_date('22-01-2003', 'dd-mm-yyyy'), to_date('05-02-2003', 'dd-mm-yyyy'), 4, 5509, to_date('28-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101013116, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 2, 3674, to_date('20-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030430013117, to_date('30-04-2003', 'dd-mm-yyyy'), to_date('14-05-2003', 'dd-mm-yyyy'), 2, 2356, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120905013118, to_date('05-09-2012', 'dd-mm-yyyy'), to_date('19-09-2012', 'dd-mm-yyyy'), 3, 8912, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061021013119, to_date('21-10-2006', 'dd-mm-yyyy'), to_date('04-11-2006', 'dd-mm-yyyy'), 4, 4019, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140410013120, to_date('10-04-2014', 'dd-mm-yyyy'), to_date('24-04-2014', 'dd-mm-yyyy'), 2, 6592, to_date('26-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130218013121, to_date('18-02-2013', 'dd-mm-yyyy'), to_date('04-03-2013', 'dd-mm-yyyy'), 2, 8674, to_date('27-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070306013122, to_date('06-03-2007', 'dd-mm-yyyy'), to_date('20-03-2007', 'dd-mm-yyyy'), 3, 4105, to_date('16-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912013123, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 3, 3866, to_date('16-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103013124, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 4, 2396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214013125, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 1, 5887, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916013126, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 2, 3951, to_date('20-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323013127, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 3, 6253, to_date('11-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070911013128, to_date('11-09-2007', 'dd-mm-yyyy'), to_date('25-09-2007', 'dd-mm-yyyy'), 2, 4574, to_date('18-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100314013129, to_date('14-03-2010', 'dd-mm-yyyy'), to_date('28-03-2010', 'dd-mm-yyyy'), 4, 5095, to_date('02-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100721013130, to_date('21-07-2010', 'dd-mm-yyyy'), to_date('04-08-2010', 'dd-mm-yyyy'), 2, 5228, to_date('29-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030407013131, to_date('07-04-2003', 'dd-mm-yyyy'), to_date('21-04-2003', 'dd-mm-yyyy'), 4, 2685, to_date('16-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060321013132, to_date('21-03-2006', 'dd-mm-yyyy'), to_date('04-04-2006', 'dd-mm-yyyy'), 2, 4024, to_date('30-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070723013133, to_date('23-07-2007', 'dd-mm-yyyy'), to_date('06-08-2007', 'dd-mm-yyyy'), 1, 4524, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001203013134, to_date('03-12-2000', 'dd-mm-yyyy'), to_date('17-12-2000', 'dd-mm-yyyy'), 4, 1854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080302013135, to_date('02-03-2008', 'dd-mm-yyyy'), to_date('16-03-2008', 'dd-mm-yyyy'), 3, 5601, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140514013136, to_date('14-05-2014', 'dd-mm-yyyy'), to_date('28-05-2014', 'dd-mm-yyyy'), 4, 9382, to_date('18-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120523013137, to_date('23-05-2012', 'dd-mm-yyyy'), to_date('06-06-2012', 'dd-mm-yyyy'), 2, 8201, to_date('12-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031201013138, to_date('01-12-2003', 'dd-mm-yyyy'), to_date('15-12-2003', 'dd-mm-yyyy'), 1, 2849, to_date('09-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110512013139, to_date('12-05-2011', 'dd-mm-yyyy'), to_date('26-05-2011', 'dd-mm-yyyy'), 3, 8327, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227013140, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 4, 10233, to_date('14-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120925013141, to_date('25-09-2012', 'dd-mm-yyyy'), to_date('09-10-2012', 'dd-mm-yyyy'), 2, 9965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100924013142, to_date('24-09-2010', 'dd-mm-yyyy'), to_date('08-10-2010', 'dd-mm-yyyy'), 3, 6492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110605013143, to_date('05-06-2011', 'dd-mm-yyyy'), to_date('19-06-2011', 'dd-mm-yyyy'), 4, 7620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826013144, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 4, 6522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050702013145, to_date('02-07-2005', 'dd-mm-yyyy'), to_date('16-07-2005', 'dd-mm-yyyy'), 3, 6602, to_date('06-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050917013146, to_date('17-09-2005', 'dd-mm-yyyy'), to_date('01-10-2005', 'dd-mm-yyyy'), 1, 3505, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020415013147, to_date('15-04-2002', 'dd-mm-yyyy'), to_date('29-04-2002', 'dd-mm-yyyy'), 1, 3938, to_date('23-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050120013148, to_date('20-01-2005', 'dd-mm-yyyy'), to_date('03-02-2005', 'dd-mm-yyyy'), 3, 5588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118013149, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 2, 1920, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123013150, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 4, 9643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000322013151, to_date('22-03-2000', 'dd-mm-yyyy'), to_date('05-04-2000', 'dd-mm-yyyy'), 4, 1450, to_date('04-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208013152, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 3, 6618, to_date('11-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525013153, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 2, 1359, to_date('12-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121207013154, to_date('07-12-2012', 'dd-mm-yyyy'), to_date('21-12-2012', 'dd-mm-yyyy'), 1, 6886, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225013155, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 2, 1664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120802013156, to_date('02-08-2012', 'dd-mm-yyyy'), to_date('16-08-2012', 'dd-mm-yyyy'), 2, 8107, to_date('06-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060511013157, to_date('11-05-2006', 'dd-mm-yyyy'), to_date('25-05-2006', 'dd-mm-yyyy'), 3, 4605, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130703013158, to_date('03-07-2013', 'dd-mm-yyyy'), to_date('17-07-2013', 'dd-mm-yyyy'), 2, 12605, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120707013159, to_date('07-07-2012', 'dd-mm-yyyy'), to_date('21-07-2012', 'dd-mm-yyyy'), 2, 7631, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120914013160, to_date('14-09-2012', 'dd-mm-yyyy'), to_date('28-09-2012', 'dd-mm-yyyy'), 1, 7550, to_date('26-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020906013161, to_date('06-09-2002', 'dd-mm-yyyy'), to_date('20-09-2002', 'dd-mm-yyyy'), 2, 3249, to_date('13-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129013162, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 4, 4573, to_date('04-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060602013163, to_date('02-06-2006', 'dd-mm-yyyy'), to_date('16-06-2006', 'dd-mm-yyyy'), 2, 3990, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030110013164, to_date('10-01-2003', 'dd-mm-yyyy'), to_date('24-01-2003', 'dd-mm-yyyy'), 2, 5858, to_date('14-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090928013165, to_date('28-09-2009', 'dd-mm-yyyy'), to_date('12-10-2009', 'dd-mm-yyyy'), 1, 6294, to_date('06-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131024013166, to_date('24-10-2013', 'dd-mm-yyyy'), to_date('07-11-2013', 'dd-mm-yyyy'), 1, 8064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100324013167, to_date('24-03-2010', 'dd-mm-yyyy'), to_date('07-04-2010', 'dd-mm-yyyy'), 4, 9106, to_date('06-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410013168, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 2, 6199, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080927013169, to_date('27-09-2008', 'dd-mm-yyyy'), to_date('11-10-2008', 'dd-mm-yyyy'), 2, 3949, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050714013170, to_date('14-07-2005', 'dd-mm-yyyy'), to_date('28-07-2005', 'dd-mm-yyyy'), 4, 5994, to_date('29-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120206013171, to_date('06-02-2012', 'dd-mm-yyyy'), to_date('20-02-2012', 'dd-mm-yyyy'), 1, 7748, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121125013172, to_date('25-11-2012', 'dd-mm-yyyy'), to_date('09-12-2012', 'dd-mm-yyyy'), 1, 7370, to_date('29-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020718013173, to_date('18-07-2002', 'dd-mm-yyyy'), to_date('01-08-2002', 'dd-mm-yyyy'), 1, 3796, to_date('01-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026013174, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 2, 4875, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030711013175, to_date('11-07-2003', 'dd-mm-yyyy'), to_date('25-07-2003', 'dd-mm-yyyy'), 4, 4685, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060824013176, to_date('24-08-2006', 'dd-mm-yyyy'), to_date('07-09-2006', 'dd-mm-yyyy'), 2, 3846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010915013177, to_date('15-09-2001', 'dd-mm-yyyy'), to_date('29-09-2001', 'dd-mm-yyyy'), 1, 2806, to_date('16-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121017013178, to_date('17-10-2012', 'dd-mm-yyyy'), to_date('31-10-2012', 'dd-mm-yyyy'), 2, 6541, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318013179, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 4, 3985, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041125013180, to_date('25-11-2004', 'dd-mm-yyyy'), to_date('09-12-2004', 'dd-mm-yyyy'), 2, 3791, to_date('08-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071010013181, to_date('10-10-2007', 'dd-mm-yyyy'), to_date('24-10-2007', 'dd-mm-yyyy'), 2, 4359, to_date('27-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100725013182, to_date('25-07-2010', 'dd-mm-yyyy'), to_date('08-08-2010', 'dd-mm-yyyy'), 2, 7592, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080928013183, to_date('28-09-2008', 'dd-mm-yyyy'), to_date('12-10-2008', 'dd-mm-yyyy'), 3, 9076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214013184, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 1, 4446, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130310013185, to_date('10-03-2013', 'dd-mm-yyyy'), to_date('24-03-2013', 'dd-mm-yyyy'), 4, 6963, to_date('22-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050313013186, to_date('13-03-2005', 'dd-mm-yyyy'), to_date('27-03-2005', 'dd-mm-yyyy'), 3, 3811, to_date('30-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040113013187, to_date('13-01-2004', 'dd-mm-yyyy'), to_date('27-01-2004', 'dd-mm-yyyy'), 4, 3829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040604013188, to_date('04-06-2004', 'dd-mm-yyyy'), to_date('18-06-2004', 'dd-mm-yyyy'), 3, 3543, to_date('05-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070516013189, to_date('16-05-2007', 'dd-mm-yyyy'), to_date('30-05-2007', 'dd-mm-yyyy'), 3, 6532, to_date('29-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722013190, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 2, 8318, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040913013191, to_date('13-09-2004', 'dd-mm-yyyy'), to_date('27-09-2004', 'dd-mm-yyyy'), 2, 4295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217013192, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 3, 11360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011016013193, to_date('16-10-2001', 'dd-mm-yyyy'), to_date('30-10-2001', 'dd-mm-yyyy'), 3, 2176, to_date('23-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413013194, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 4, 3792, to_date('02-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081211013195, to_date('11-12-2008', 'dd-mm-yyyy'), to_date('25-12-2008', 'dd-mm-yyyy'), 2, 5495, to_date('21-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216013196, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 3, 5411, to_date('28-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027013197, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 1, 3778, to_date('30-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515013198, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 2, 4540, to_date('02-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080715013199, to_date('15-07-2008', 'dd-mm-yyyy'), to_date('29-07-2008', 'dd-mm-yyyy'), 4, 5733, to_date('22-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120802013200, to_date('02-08-2012', 'dd-mm-yyyy'), to_date('16-08-2012', 'dd-mm-yyyy'), 3, 10530, to_date('21-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110815013201, to_date('15-08-2011', 'dd-mm-yyyy'), to_date('29-08-2011', 'dd-mm-yyyy'), 1, 10263, to_date('22-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120809015724, to_date('09-08-2012', 'dd-mm-yyyy'), to_date('23-08-2012', 'dd-mm-yyyy'), 4, 8345, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061103015725, to_date('03-11-2006', 'dd-mm-yyyy'), to_date('17-11-2006', 'dd-mm-yyyy'), 4, 3652, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070522015726, to_date('22-05-2007', 'dd-mm-yyyy'), to_date('05-06-2007', 'dd-mm-yyyy'), 1, 5970, to_date('07-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110823015727, to_date('23-08-2011', 'dd-mm-yyyy'), to_date('06-09-2011', 'dd-mm-yyyy'), 2, 10361, to_date('30-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317015728, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 2, 8239, to_date('04-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020118015729, to_date('18-01-2002', 'dd-mm-yyyy'), to_date('01-02-2002', 'dd-mm-yyyy'), 4, 4030, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031117015730, to_date('17-11-2003', 'dd-mm-yyyy'), to_date('01-12-2003', 'dd-mm-yyyy'), 3, 2177, to_date('26-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100108015731, to_date('08-01-2010', 'dd-mm-yyyy'), to_date('22-01-2010', 'dd-mm-yyyy'), 3, 6602, to_date('23-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060704015732, to_date('04-07-2006', 'dd-mm-yyyy'), to_date('18-07-2006', 'dd-mm-yyyy'), 3, 5636, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010801015733, to_date('01-08-2001', 'dd-mm-yyyy'), to_date('15-08-2001', 'dd-mm-yyyy'), 4, 2219, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091017015734, to_date('17-10-2009', 'dd-mm-yyyy'), to_date('31-10-2009', 'dd-mm-yyyy'), 3, 6761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131027015735, to_date('27-10-2013', 'dd-mm-yyyy'), to_date('10-11-2013', 'dd-mm-yyyy'), 1, 8723, to_date('31-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100514015736, to_date('14-05-2010', 'dd-mm-yyyy'), to_date('28-05-2010', 'dd-mm-yyyy'), 3, 7030, to_date('31-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316015737, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 4, 8386, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060721015738, to_date('21-07-2006', 'dd-mm-yyyy'), to_date('04-08-2006', 'dd-mm-yyyy'), 2, 5236, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051003015739, to_date('03-10-2005', 'dd-mm-yyyy'), to_date('17-10-2005', 'dd-mm-yyyy'), 3, 4074, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060504015740, to_date('04-05-2006', 'dd-mm-yyyy'), to_date('18-05-2006', 'dd-mm-yyyy'), 2, 3338, to_date('08-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080923015741, to_date('23-09-2008', 'dd-mm-yyyy'), to_date('07-10-2008', 'dd-mm-yyyy'), 4, 4658, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090910015742, to_date('10-09-2009', 'dd-mm-yyyy'), to_date('24-09-2009', 'dd-mm-yyyy'), 3, 7245, to_date('23-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206015743, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 4, 7028, to_date('17-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010729015744, to_date('29-07-2001', 'dd-mm-yyyy'), to_date('12-08-2001', 'dd-mm-yyyy'), 3, 1691, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111015745, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 3, 9797, to_date('01-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021201015746, to_date('01-12-2002', 'dd-mm-yyyy'), to_date('15-12-2002', 'dd-mm-yyyy'), 1, 3395, to_date('17-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050521015747, to_date('21-05-2005', 'dd-mm-yyyy'), to_date('04-06-2005', 'dd-mm-yyyy'), 1, 6761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311015748, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 2, 7427, to_date('30-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040304015749, to_date('04-03-2004', 'dd-mm-yyyy'), to_date('18-03-2004', 'dd-mm-yyyy'), 1, 3269, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020722015750, to_date('22-07-2002', 'dd-mm-yyyy'), to_date('05-08-2002', 'dd-mm-yyyy'), 1, 2259, to_date('30-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019015751, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 2, 4725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070418015752, to_date('18-04-2007', 'dd-mm-yyyy'), to_date('02-05-2007', 'dd-mm-yyyy'), 1, 6012, to_date('01-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050209015753, to_date('09-02-2005', 'dd-mm-yyyy'), to_date('23-02-2005', 'dd-mm-yyyy'), 2, 4512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427015754, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 2, 3364, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120505015755, to_date('05-05-2012', 'dd-mm-yyyy'), to_date('19-05-2012', 'dd-mm-yyyy'), 3, 7279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090221015756, to_date('21-02-2009', 'dd-mm-yyyy'), to_date('07-03-2009', 'dd-mm-yyyy'), 2, 5573, to_date('01-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060606015757, to_date('06-06-2006', 'dd-mm-yyyy'), to_date('20-06-2006', 'dd-mm-yyyy'), 2, 4716, to_date('24-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140319015758, to_date('19-03-2014', 'dd-mm-yyyy'), to_date('02-04-2014', 'dd-mm-yyyy'), 2, 7355, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031102015759, to_date('02-11-2003', 'dd-mm-yyyy'), to_date('16-11-2003', 'dd-mm-yyyy'), 4, 4989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007015760, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 1, 6012, to_date('26-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071217015761, to_date('17-12-2007', 'dd-mm-yyyy'), to_date('31-12-2007', 'dd-mm-yyyy'), 3, 4374, to_date('22-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100131015762, to_date('31-01-2010', 'dd-mm-yyyy'), to_date('14-02-2010', 'dd-mm-yyyy'), 4, 6490, to_date('02-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081001015763, to_date('01-10-2008', 'dd-mm-yyyy'), to_date('15-10-2008', 'dd-mm-yyyy'), 1, 6090, to_date('02-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100623015764, to_date('23-06-2010', 'dd-mm-yyyy'), to_date('07-07-2010', 'dd-mm-yyyy'), 2, 6337, to_date('03-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100806015765, to_date('06-08-2010', 'dd-mm-yyyy'), to_date('20-08-2010', 'dd-mm-yyyy'), 4, 6332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008015766, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 1, 4592, to_date('14-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110305015767, to_date('05-03-2011', 'dd-mm-yyyy'), to_date('19-03-2011', 'dd-mm-yyyy'), 3, 5614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119015768, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 3, 4221, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080823015769, to_date('23-08-2008', 'dd-mm-yyyy'), to_date('06-09-2008', 'dd-mm-yyyy'), 2, 6621, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100226015770, to_date('26-02-2010', 'dd-mm-yyyy'), to_date('12-03-2010', 'dd-mm-yyyy'), 2, 6794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041117015771, to_date('17-11-2004', 'dd-mm-yyyy'), to_date('01-12-2004', 'dd-mm-yyyy'), 4, 2663, to_date('05-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040423015772, to_date('23-04-2004', 'dd-mm-yyyy'), to_date('07-05-2004', 'dd-mm-yyyy'), 1, 3544, to_date('27-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627015773, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 1, 6969, to_date('14-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070731015774, to_date('31-07-2007', 'dd-mm-yyyy'), to_date('14-08-2007', 'dd-mm-yyyy'), 1, 3519, to_date('12-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021205015775, to_date('05-12-2002', 'dd-mm-yyyy'), to_date('19-12-2002', 'dd-mm-yyyy'), 3, 5607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120712015776, to_date('12-07-2012', 'dd-mm-yyyy'), to_date('26-07-2012', 'dd-mm-yyyy'), 2, 6754, to_date('30-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020520015777, to_date('20-05-2002', 'dd-mm-yyyy'), to_date('03-06-2002', 'dd-mm-yyyy'), 1, 2219, to_date('31-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070623015778, to_date('23-06-2007', 'dd-mm-yyyy'), to_date('07-07-2007', 'dd-mm-yyyy'), 2, 4907, to_date('07-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100328015779, to_date('28-03-2010', 'dd-mm-yyyy'), to_date('11-04-2010', 'dd-mm-yyyy'), 1, 6607, to_date('05-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521015780, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 2, 4514, to_date('09-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021219015781, to_date('19-12-2002', 'dd-mm-yyyy'), to_date('02-01-2003', 'dd-mm-yyyy'), 3, 1213, to_date('28-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526015782, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 2, 8570, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060909015783, to_date('09-09-2006', 'dd-mm-yyyy'), to_date('23-09-2006', 'dd-mm-yyyy'), 1, 5259, to_date('16-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120916015784, to_date('16-09-2012', 'dd-mm-yyyy'), to_date('30-09-2012', 'dd-mm-yyyy'), 2, 6982, to_date('01-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071021015785, to_date('21-10-2007', 'dd-mm-yyyy'), to_date('04-11-2007', 'dd-mm-yyyy'), 1, 3856, to_date('27-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030818015786, to_date('18-08-2003', 'dd-mm-yyyy'), to_date('01-09-2003', 'dd-mm-yyyy'), 2, 2565, to_date('04-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101205015787, to_date('05-12-2010', 'dd-mm-yyyy'), to_date('19-12-2010', 'dd-mm-yyyy'), 2, 7664, to_date('22-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011027015788, to_date('27-10-2001', 'dd-mm-yyyy'), to_date('10-11-2001', 'dd-mm-yyyy'), 2, 3443, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010309015789, to_date('09-03-2001', 'dd-mm-yyyy'), to_date('23-03-2001', 'dd-mm-yyyy'), 2, 3630, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131125015790, to_date('25-11-2013', 'dd-mm-yyyy'), to_date('09-12-2013', 'dd-mm-yyyy'), 2, 9374, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010723015791, to_date('23-07-2001', 'dd-mm-yyyy'), to_date('06-08-2001', 'dd-mm-yyyy'), 2, 2252, to_date('10-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101201015792, to_date('01-12-2010', 'dd-mm-yyyy'), to_date('15-12-2010', 'dd-mm-yyyy'), 4, 5900, to_date('17-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040908015793, to_date('08-09-2004', 'dd-mm-yyyy'), to_date('22-09-2004', 'dd-mm-yyyy'), 2, 5171, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130626015794, to_date('26-06-2013', 'dd-mm-yyyy'), to_date('10-07-2013', 'dd-mm-yyyy'), 4, 9070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030731015795, to_date('31-07-2003', 'dd-mm-yyyy'), to_date('14-08-2003', 'dd-mm-yyyy'), 1, 3419, to_date('02-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090523015796, to_date('23-05-2009', 'dd-mm-yyyy'), to_date('06-06-2009', 'dd-mm-yyyy'), 1, 6940, to_date('06-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040817015797, to_date('17-08-2004', 'dd-mm-yyyy'), to_date('31-08-2004', 'dd-mm-yyyy'), 2, 5080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131109015798, to_date('09-11-2013', 'dd-mm-yyyy'), to_date('23-11-2013', 'dd-mm-yyyy'), 2, 7764, to_date('17-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120718015799, to_date('18-07-2012', 'dd-mm-yyyy'), to_date('01-08-2012', 'dd-mm-yyyy'), 2, 6619, to_date('05-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080505015800, to_date('05-05-2008', 'dd-mm-yyyy'), to_date('19-05-2008', 'dd-mm-yyyy'), 2, 3344, to_date('24-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040405015801, to_date('05-04-2004', 'dd-mm-yyyy'), to_date('19-04-2004', 'dd-mm-yyyy'), 3, 2962, to_date('17-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319015802, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 1, 1007, to_date('05-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000225015803, to_date('25-02-2000', 'dd-mm-yyyy'), to_date('10-03-2000', 'dd-mm-yyyy'), 2, 1050, to_date('04-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080313015804, to_date('13-03-2008', 'dd-mm-yyyy'), to_date('27-03-2008', 'dd-mm-yyyy'), 2, 6825, to_date('23-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620015805, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 1, 2563, to_date('24-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130125015806, to_date('25-01-2013', 'dd-mm-yyyy'), to_date('08-02-2013', 'dd-mm-yyyy'), 3, 12100, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921015807, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 4, 3817, to_date('04-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010707015808, to_date('07-07-2001', 'dd-mm-yyyy'), to_date('21-07-2001', 'dd-mm-yyyy'), 2, 2786, to_date('23-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000610015809, to_date('10-06-2000', 'dd-mm-yyyy'), to_date('24-06-2000', 'dd-mm-yyyy'), 4, 1022, to_date('26-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011214015810, to_date('14-12-2001', 'dd-mm-yyyy'), to_date('28-12-2001', 'dd-mm-yyyy'), 3, 1526, to_date('28-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427015811, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 1, 2415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120907015812, to_date('07-09-2012', 'dd-mm-yyyy'), to_date('21-09-2012', 'dd-mm-yyyy'), 2, 7984, to_date('17-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050203015813, to_date('03-02-2005', 'dd-mm-yyyy'), to_date('17-02-2005', 'dd-mm-yyyy'), 3, 4174, to_date('21-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030606015814, to_date('06-06-2003', 'dd-mm-yyyy'), to_date('20-06-2003', 'dd-mm-yyyy'), 1, 2541, to_date('09-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522015815, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 3, 9228, to_date('07-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518015816, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 2, 4943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111122015817, to_date('22-11-2011', 'dd-mm-yyyy'), to_date('06-12-2011', 'dd-mm-yyyy'), 2, 7701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528015818, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 2, 6574, to_date('14-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050828015819, to_date('28-08-2005', 'dd-mm-yyyy'), to_date('11-09-2005', 'dd-mm-yyyy'), 1, 4465, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110705015820, to_date('05-07-2011', 'dd-mm-yyyy'), to_date('19-07-2011', 'dd-mm-yyyy'), 1, 8218, to_date('18-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120626015821, to_date('26-06-2012', 'dd-mm-yyyy'), to_date('10-07-2012', 'dd-mm-yyyy'), 2, 6350, to_date('01-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231015822, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 3, 5299, to_date('06-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213015823, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 3, 7994, to_date('18-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120329015824, to_date('29-03-2012', 'dd-mm-yyyy'), to_date('12-04-2012', 'dd-mm-yyyy'), 3, 9403, to_date('16-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010926015825, to_date('26-09-2001', 'dd-mm-yyyy'), to_date('10-10-2001', 'dd-mm-yyyy'), 1, 3074, to_date('13-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130426015826, to_date('26-04-2013', 'dd-mm-yyyy'), to_date('10-05-2013', 'dd-mm-yyyy'), 2, 7847, to_date('05-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020112015827, to_date('12-01-2002', 'dd-mm-yyyy'), to_date('26-01-2002', 'dd-mm-yyyy'), 2, 3708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130909015828, to_date('09-09-2013', 'dd-mm-yyyy'), to_date('23-09-2013', 'dd-mm-yyyy'), 3, 6697, to_date('13-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080918015829, to_date('18-09-2008', 'dd-mm-yyyy'), to_date('02-10-2008', 'dd-mm-yyyy'), 3, 8580, to_date('29-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090705015830, to_date('05-07-2009', 'dd-mm-yyyy'), to_date('19-07-2009', 'dd-mm-yyyy'), 4, 7587, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060323015831, to_date('23-03-2006', 'dd-mm-yyyy'), to_date('06-04-2006', 'dd-mm-yyyy'), 1, 5817, to_date('09-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081013015832, to_date('13-10-2008', 'dd-mm-yyyy'), to_date('27-10-2008', 'dd-mm-yyyy'), 4, 7265, to_date('26-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222015833, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 4, 11921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060616015834, to_date('16-06-2006', 'dd-mm-yyyy'), to_date('30-06-2006', 'dd-mm-yyyy'), 3, 5952, to_date('27-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120417015835, to_date('17-04-2012', 'dd-mm-yyyy'), to_date('01-05-2012', 'dd-mm-yyyy'), 3, 8166, to_date('27-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120103015836, to_date('03-01-2012', 'dd-mm-yyyy'), to_date('17-01-2012', 'dd-mm-yyyy'), 1, 10161, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060312015837, to_date('12-03-2006', 'dd-mm-yyyy'), to_date('26-03-2006', 'dd-mm-yyyy'), 3, 4999, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020903015838, to_date('03-09-2002', 'dd-mm-yyyy'), to_date('17-09-2002', 'dd-mm-yyyy'), 1, 3160, to_date('08-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121217015839, to_date('17-12-2012', 'dd-mm-yyyy'), to_date('31-12-2012', 'dd-mm-yyyy'), 4, 7864, to_date('18-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120712015840, to_date('12-07-2012', 'dd-mm-yyyy'), to_date('26-07-2012', 'dd-mm-yyyy'), 2, 7524, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050318015841, to_date('18-03-2005', 'dd-mm-yyyy'), to_date('01-04-2005', 'dd-mm-yyyy'), 2, 2729, to_date('06-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001207015842, to_date('07-12-2000', 'dd-mm-yyyy'), to_date('21-12-2000', 'dd-mm-yyyy'), 1, 1253, to_date('11-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011030015843, to_date('30-10-2001', 'dd-mm-yyyy'), to_date('13-11-2001', 'dd-mm-yyyy'), 4, 2705, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090604015844, to_date('04-06-2009', 'dd-mm-yyyy'), to_date('18-06-2009', 'dd-mm-yyyy'), 3, 10168, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060705015845, to_date('05-07-2006', 'dd-mm-yyyy'), to_date('19-07-2006', 'dd-mm-yyyy'), 4, 6696, to_date('12-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021212015846, to_date('12-12-2002', 'dd-mm-yyyy'), to_date('26-12-2002', 'dd-mm-yyyy'), 3, 1803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021019015847, to_date('19-10-2002', 'dd-mm-yyyy'), to_date('02-11-2002', 'dd-mm-yyyy'), 3, 1975, to_date('07-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110912015848, to_date('12-09-2011', 'dd-mm-yyyy'), to_date('26-09-2011', 'dd-mm-yyyy'), 2, 6319, to_date('15-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061121015849, to_date('21-11-2006', 'dd-mm-yyyy'), to_date('05-12-2006', 'dd-mm-yyyy'), 4, 4250, to_date('30-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021015015850, to_date('15-10-2002', 'dd-mm-yyyy'), to_date('29-10-2002', 'dd-mm-yyyy'), 4, 1891, to_date('30-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071220015851, to_date('20-12-2007', 'dd-mm-yyyy'), to_date('03-01-2008', 'dd-mm-yyyy'), 2, 4937, to_date('29-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106015852, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 2, 9620, to_date('23-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001213015853, to_date('13-12-2000', 'dd-mm-yyyy'), to_date('27-12-2000', 'dd-mm-yyyy'), 2, 2031, to_date('24-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061018015854, to_date('18-10-2006', 'dd-mm-yyyy'), to_date('01-11-2006', 'dd-mm-yyyy'), 3, 5014, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106015855, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 1, 10916, to_date('21-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030808015856, to_date('08-08-2003', 'dd-mm-yyyy'), to_date('22-08-2003', 'dd-mm-yyyy'), 4, 5614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919015857, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 3, 9384, to_date('04-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070601015858, to_date('01-06-2007', 'dd-mm-yyyy'), to_date('15-06-2007', 'dd-mm-yyyy'), 3, 7660, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110814015859, to_date('14-08-2011', 'dd-mm-yyyy'), to_date('28-08-2011', 'dd-mm-yyyy'), 2, 5778, to_date('27-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010218015860, to_date('18-02-2001', 'dd-mm-yyyy'), to_date('04-03-2001', 'dd-mm-yyyy'), 2, 1959, to_date('21-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010331015861, to_date('31-03-2001', 'dd-mm-yyyy'), to_date('14-04-2001', 'dd-mm-yyyy'), 3, 1732, to_date('02-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100305015862, to_date('05-03-2010', 'dd-mm-yyyy'), to_date('19-03-2010', 'dd-mm-yyyy'), 4, 8485, to_date('17-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001218015863, to_date('18-12-2000', 'dd-mm-yyyy'), to_date('01-01-2001', 'dd-mm-yyyy'), 2, 2548, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120108015864, to_date('08-01-2012', 'dd-mm-yyyy'), to_date('22-01-2012', 'dd-mm-yyyy'), 2, 9806, to_date('12-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120218015865, to_date('18-02-2012', 'dd-mm-yyyy'), to_date('03-03-2012', 'dd-mm-yyyy'), 3, 7588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020401015866, to_date('01-04-2002', 'dd-mm-yyyy'), to_date('15-04-2002', 'dd-mm-yyyy'), 3, 2531, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110228015867, to_date('28-02-2011', 'dd-mm-yyyy'), to_date('14-03-2011', 'dd-mm-yyyy'), 4, 7630, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001231015868, to_date('31-12-2000', 'dd-mm-yyyy'), to_date('14-01-2001', 'dd-mm-yyyy'), 3, 918, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120616015869, to_date('16-06-2012', 'dd-mm-yyyy'), to_date('30-06-2012', 'dd-mm-yyyy'), 4, 8308, to_date('18-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090505015870, to_date('05-05-2009', 'dd-mm-yyyy'), to_date('19-05-2009', 'dd-mm-yyyy'), 2, 6127, to_date('16-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071005015871, to_date('05-10-2007', 'dd-mm-yyyy'), to_date('19-10-2007', 'dd-mm-yyyy'), 2, 5899, to_date('17-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001107015872, to_date('07-11-2000', 'dd-mm-yyyy'), to_date('21-11-2000', 'dd-mm-yyyy'), 4, 2149, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041128015873, to_date('28-11-2004', 'dd-mm-yyyy'), to_date('12-12-2004', 'dd-mm-yyyy'), 3, 3266, to_date('02-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010430015874, to_date('30-04-2001', 'dd-mm-yyyy'), to_date('14-05-2001', 'dd-mm-yyyy'), 3, 2688, to_date('08-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070224015875, to_date('24-02-2007', 'dd-mm-yyyy'), to_date('10-03-2007', 'dd-mm-yyyy'), 3, 4176, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061211015876, to_date('11-12-2006', 'dd-mm-yyyy'), to_date('25-12-2006', 'dd-mm-yyyy'), 4, 4472, to_date('24-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016015877, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 1, 8361, to_date('18-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090315015878, to_date('15-03-2009', 'dd-mm-yyyy'), to_date('29-03-2009', 'dd-mm-yyyy'), 4, 6756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030128015879, to_date('28-01-2003', 'dd-mm-yyyy'), to_date('11-02-2003', 'dd-mm-yyyy'), 1, 3424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070721015880, to_date('21-07-2007', 'dd-mm-yyyy'), to_date('04-08-2007', 'dd-mm-yyyy'), 3, 6771, to_date('08-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010225015881, to_date('25-02-2001', 'dd-mm-yyyy'), to_date('11-03-2001', 'dd-mm-yyyy'), 3, 5830, to_date('15-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061014015882, to_date('14-10-2006', 'dd-mm-yyyy'), to_date('28-10-2006', 'dd-mm-yyyy'), 3, 5991, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000720015883, to_date('20-07-2000', 'dd-mm-yyyy'), to_date('03-08-2000', 'dd-mm-yyyy'), 2, 2851, to_date('22-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090414015884, to_date('14-04-2009', 'dd-mm-yyyy'), to_date('28-04-2009', 'dd-mm-yyyy'), 4, 8710, to_date('28-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020630015885, to_date('30-06-2002', 'dd-mm-yyyy'), to_date('14-07-2002', 'dd-mm-yyyy'), 4, 2736, to_date('07-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001017015886, to_date('17-10-2000', 'dd-mm-yyyy'), to_date('31-10-2000', 'dd-mm-yyyy'), 4, 4208, to_date('24-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110920015887, to_date('20-09-2011', 'dd-mm-yyyy'), to_date('04-10-2011', 'dd-mm-yyyy'), 4, 11926, to_date('25-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120201015888, to_date('01-02-2012', 'dd-mm-yyyy'), to_date('15-02-2012', 'dd-mm-yyyy'), 3, 9934, to_date('19-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000822015889, to_date('22-08-2000', 'dd-mm-yyyy'), to_date('05-09-2000', 'dd-mm-yyyy'), 3, 1774, to_date('26-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208015890, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 2, 6441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121030015891, to_date('30-10-2012', 'dd-mm-yyyy'), to_date('13-11-2012', 'dd-mm-yyyy'), 3, 8166, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081028010413, to_date('28-10-2008', 'dd-mm-yyyy'), to_date('11-11-2008', 'dd-mm-yyyy'), 9, 4740, to_date('13-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120726010414, to_date('26-07-2012', 'dd-mm-yyyy'), to_date('09-08-2012', 'dd-mm-yyyy'), 7, 9910, to_date('14-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513010415, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 3, 7426, to_date('28-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110713010416, to_date('13-07-2011', 'dd-mm-yyyy'), to_date('27-07-2011', 'dd-mm-yyyy'), 11, 8037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070903010417, to_date('03-09-2007', 'dd-mm-yyyy'), to_date('17-09-2007', 'dd-mm-yyyy'), 11, 7855, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020519010418, to_date('19-05-2002', 'dd-mm-yyyy'), to_date('02-06-2002', 'dd-mm-yyyy'), 5, 4084, to_date('30-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090517010419, to_date('17-05-2009', 'dd-mm-yyyy'), to_date('31-05-2009', 'dd-mm-yyyy'), 9, 7244, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130105010420, to_date('05-01-2013', 'dd-mm-yyyy'), to_date('19-01-2013', 'dd-mm-yyyy'), 11, 9409, to_date('16-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110314010421, to_date('14-03-2011', 'dd-mm-yyyy'), to_date('28-03-2011', 'dd-mm-yyyy'), 12, 6494, to_date('25-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041029010422, to_date('29-10-2004', 'dd-mm-yyyy'), to_date('12-11-2004', 'dd-mm-yyyy'), 11, 2853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090620010423, to_date('20-06-2009', 'dd-mm-yyyy'), to_date('04-07-2009', 'dd-mm-yyyy'), 3, 5676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020617010424, to_date('17-06-2002', 'dd-mm-yyyy'), to_date('01-07-2002', 'dd-mm-yyyy'), 4, 2996, to_date('28-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041119010425, to_date('19-11-2004', 'dd-mm-yyyy'), to_date('03-12-2004', 'dd-mm-yyyy'), 5, 2470, to_date('21-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031121010426, to_date('21-11-2003', 'dd-mm-yyyy'), to_date('05-12-2003', 'dd-mm-yyyy'), 10, 3576, to_date('02-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214010427, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 6, 10110, to_date('19-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130703010428, to_date('03-07-2013', 'dd-mm-yyyy'), to_date('17-07-2013', 'dd-mm-yyyy'), 3, 9829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130226010429, to_date('26-02-2013', 'dd-mm-yyyy'), to_date('12-03-2013', 'dd-mm-yyyy'), 2, 8268, to_date('04-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725010430, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 8, 6370, to_date('10-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326010431, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 7, 2130, to_date('06-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120614010432, to_date('14-06-2012', 'dd-mm-yyyy'), to_date('28-06-2012', 'dd-mm-yyyy'), 8, 7342, to_date('17-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020818010433, to_date('18-08-2002', 'dd-mm-yyyy'), to_date('01-09-2002', 'dd-mm-yyyy'), 7, 2838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090713010434, to_date('13-07-2009', 'dd-mm-yyyy'), to_date('27-07-2009', 'dd-mm-yyyy'), 4, 9539, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531010435, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 11, 3022, to_date('09-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928010436, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 1, 6997, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328010437, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 7, 5463, to_date('08-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031111010438, to_date('11-11-2003', 'dd-mm-yyyy'), to_date('25-11-2003', 'dd-mm-yyyy'), 7, 1704, to_date('16-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121228010439, to_date('28-12-2012', 'dd-mm-yyyy'), to_date('11-01-2013', 'dd-mm-yyyy'), 7, 9686, to_date('29-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041215010440, to_date('15-12-2004', 'dd-mm-yyyy'), to_date('29-12-2004', 'dd-mm-yyyy'), 9, 4123, to_date('19-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100308010441, to_date('08-03-2010', 'dd-mm-yyyy'), to_date('22-03-2010', 'dd-mm-yyyy'), 2, 8873, to_date('23-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010624010442, to_date('24-06-2001', 'dd-mm-yyyy'), to_date('08-07-2001', 'dd-mm-yyyy'), 6, 2546, to_date('09-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621010443, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 7, 1357, to_date('27-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021121010444, to_date('21-11-2002', 'dd-mm-yyyy'), to_date('05-12-2002', 'dd-mm-yyyy'), 6, 3927, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408010445, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 10, 2910, to_date('25-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519010446, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 10, 4041, to_date('01-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100216010447, to_date('16-02-2010', 'dd-mm-yyyy'), to_date('02-03-2010', 'dd-mm-yyyy'), 7, 7364, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050523010448, to_date('23-05-2005', 'dd-mm-yyyy'), to_date('06-06-2005', 'dd-mm-yyyy'), 1, 5450, to_date('08-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060205010449, to_date('05-02-2006', 'dd-mm-yyyy'), to_date('19-02-2006', 'dd-mm-yyyy'), 11, 4721, to_date('08-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060128010450, to_date('28-01-2006', 'dd-mm-yyyy'), to_date('11-02-2006', 'dd-mm-yyyy'), 11, 5606, to_date('05-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060205010451, to_date('05-02-2006', 'dd-mm-yyyy'), to_date('19-02-2006', 'dd-mm-yyyy'), 1, 3395, to_date('16-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070106010452, to_date('06-01-2007', 'dd-mm-yyyy'), to_date('20-01-2007', 'dd-mm-yyyy'), 5, 7514, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090508010453, to_date('08-05-2009', 'dd-mm-yyyy'), to_date('22-05-2009', 'dd-mm-yyyy'), 6, 8211, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000620010454, to_date('20-06-2000', 'dd-mm-yyyy'), to_date('04-07-2000', 'dd-mm-yyyy'), 2, 1360, to_date('27-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011225010455, to_date('25-12-2001', 'dd-mm-yyyy'), to_date('08-01-2002', 'dd-mm-yyyy'), 10, 1664, to_date('06-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021209010456, to_date('09-12-2002', 'dd-mm-yyyy'), to_date('23-12-2002', 'dd-mm-yyyy'), 5, 2804, to_date('26-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001106010457, to_date('06-11-2000', 'dd-mm-yyyy'), to_date('20-11-2000', 'dd-mm-yyyy'), 4, 1901, to_date('11-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022010458, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 5, 3836, to_date('07-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070621010459, to_date('21-06-2007', 'dd-mm-yyyy'), to_date('05-07-2007', 'dd-mm-yyyy'), 7, 5513, to_date('26-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070130010460, to_date('30-01-2007', 'dd-mm-yyyy'), to_date('13-02-2007', 'dd-mm-yyyy'), 4, 5462, to_date('04-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061226010461, to_date('26-12-2006', 'dd-mm-yyyy'), to_date('09-01-2007', 'dd-mm-yyyy'), 5, 6828, to_date('29-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406010462, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 4, 5788, to_date('19-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070125010463, to_date('25-01-2007', 'dd-mm-yyyy'), to_date('08-02-2007', 'dd-mm-yyyy'), 9, 7336, to_date('29-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902010464, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 11, 4147, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080117010465, to_date('17-01-2008', 'dd-mm-yyyy'), to_date('31-01-2008', 'dd-mm-yyyy'), 8, 5866, to_date('21-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130403010466, to_date('03-04-2013', 'dd-mm-yyyy'), to_date('17-04-2013', 'dd-mm-yyyy'), 8, 13313, to_date('22-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090906010467, to_date('06-09-2009', 'dd-mm-yyyy'), to_date('20-09-2009', 'dd-mm-yyyy'), 11, 6294, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000521010468, to_date('21-05-2000', 'dd-mm-yyyy'), to_date('04-06-2000', 'dd-mm-yyyy'), 9, 3290, to_date('24-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040106010469, to_date('06-01-2004', 'dd-mm-yyyy'), to_date('20-01-2004', 'dd-mm-yyyy'), 7, 3267, to_date('15-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060804010470, to_date('04-08-2006', 'dd-mm-yyyy'), to_date('18-08-2006', 'dd-mm-yyyy'), 9, 5992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131218010471, to_date('18-12-2013', 'dd-mm-yyyy'), to_date('01-01-2014', 'dd-mm-yyyy'), 11, 7688, to_date('28-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100825010472, to_date('25-08-2010', 'dd-mm-yyyy'), to_date('08-09-2010', 'dd-mm-yyyy'), 7, 5291, to_date('29-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100428010473, to_date('28-04-2010', 'dd-mm-yyyy'), to_date('12-05-2010', 'dd-mm-yyyy'), 10, 8052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100321010474, to_date('21-03-2010', 'dd-mm-yyyy'), to_date('04-04-2010', 'dd-mm-yyyy'), 5, 7046, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131008010475, to_date('08-10-2013', 'dd-mm-yyyy'), to_date('22-10-2013', 'dd-mm-yyyy'), 11, 8965, to_date('24-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021217010476, to_date('17-12-2002', 'dd-mm-yyyy'), to_date('31-12-2002', 'dd-mm-yyyy'), 10, 5393, to_date('21-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228010477, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 10, 964, to_date('07-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031114010478, to_date('14-11-2003', 'dd-mm-yyyy'), to_date('28-11-2003', 'dd-mm-yyyy'), 9, 3997, to_date('26-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080621010479, to_date('21-06-2008', 'dd-mm-yyyy'), to_date('05-07-2008', 'dd-mm-yyyy'), 6, 6889, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609010480, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 2, 5219, to_date('24-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020216010481, to_date('16-02-2002', 'dd-mm-yyyy'), to_date('02-03-2002', 'dd-mm-yyyy'), 5, 4645, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010521010482, to_date('21-05-2001', 'dd-mm-yyyy'), to_date('04-06-2001', 'dd-mm-yyyy'), 1, 2944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020414010483, to_date('14-04-2002', 'dd-mm-yyyy'), to_date('28-04-2002', 'dd-mm-yyyy'), 1, 2833, to_date('25-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061009010484, to_date('09-10-2006', 'dd-mm-yyyy'), to_date('23-10-2006', 'dd-mm-yyyy'), 9, 3397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050514010485, to_date('14-05-2005', 'dd-mm-yyyy'), to_date('28-05-2005', 'dd-mm-yyyy'), 9, 3551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090703010486, to_date('03-07-2009', 'dd-mm-yyyy'), to_date('17-07-2009', 'dd-mm-yyyy'), 5, 7179, to_date('14-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040310010487, to_date('10-03-2004', 'dd-mm-yyyy'), to_date('24-03-2004', 'dd-mm-yyyy'), 2, 4964, to_date('28-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218010488, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 1, 4016, to_date('06-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010214010489, to_date('14-02-2001', 'dd-mm-yyyy'), to_date('28-02-2001', 'dd-mm-yyyy'), 8, 1454, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050106010490, to_date('06-01-2005', 'dd-mm-yyyy'), to_date('20-01-2005', 'dd-mm-yyyy'), 11, 6793, to_date('19-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001121010491, to_date('21-11-2000', 'dd-mm-yyyy'), to_date('05-12-2000', 'dd-mm-yyyy'), 7, 1894, to_date('30-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050629010492, to_date('29-06-2005', 'dd-mm-yyyy'), to_date('13-07-2005', 'dd-mm-yyyy'), 4, 5613, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121128010493, to_date('28-11-2012', 'dd-mm-yyyy'), to_date('12-12-2012', 'dd-mm-yyyy'), 9, 9716, to_date('08-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000517010494, to_date('17-05-2000', 'dd-mm-yyyy'), to_date('31-05-2000', 'dd-mm-yyyy'), 1, 1376, to_date('30-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111010495, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 3, 6528, to_date('20-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131115010496, to_date('15-11-2013', 'dd-mm-yyyy'), to_date('29-11-2013', 'dd-mm-yyyy'), 7, 9370, to_date('30-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000109010497, to_date('09-01-2000', 'dd-mm-yyyy'), to_date('23-01-2000', 'dd-mm-yyyy'), 12, 2501, to_date('26-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110403010498, to_date('03-04-2011', 'dd-mm-yyyy'), to_date('17-04-2011', 'dd-mm-yyyy'), 12, 8549, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060613010499, to_date('13-06-2006', 'dd-mm-yyyy'), to_date('27-06-2006', 'dd-mm-yyyy'), 9, 5025, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090906010500, to_date('06-09-2009', 'dd-mm-yyyy'), to_date('20-09-2009', 'dd-mm-yyyy'), 11, 6139, to_date('12-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001102010501, to_date('02-11-2000', 'dd-mm-yyyy'), to_date('16-11-2000', 'dd-mm-yyyy'), 9, 3315, to_date('09-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015010502, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 5, 3067, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130626010503, to_date('26-06-2013', 'dd-mm-yyyy'), to_date('10-07-2013', 'dd-mm-yyyy'), 9, 8255, to_date('15-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070121010504, to_date('21-01-2007', 'dd-mm-yyyy'), to_date('04-02-2007', 'dd-mm-yyyy'), 4, 5662, to_date('02-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051213010505, to_date('13-12-2005', 'dd-mm-yyyy'), to_date('27-12-2005', 'dd-mm-yyyy'), 8, 3480, to_date('16-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001112010506, to_date('12-11-2000', 'dd-mm-yyyy'), to_date('26-11-2000', 'dd-mm-yyyy'), 7, 352, to_date('15-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020921010507, to_date('21-09-2002', 'dd-mm-yyyy'), to_date('05-10-2002', 'dd-mm-yyyy'), 1, 2615, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030912010508, to_date('12-09-2003', 'dd-mm-yyyy'), to_date('26-09-2003', 'dd-mm-yyyy'), 2, 2967, to_date('17-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061119010509, to_date('19-11-2006', 'dd-mm-yyyy'), to_date('03-12-2006', 'dd-mm-yyyy'), 9, 3991, to_date('05-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514010510, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 11, 6852, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120531010511, to_date('31-05-2012', 'dd-mm-yyyy'), to_date('14-06-2012', 'dd-mm-yyyy'), 7, 6509, to_date('09-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080703010512, to_date('03-07-2008', 'dd-mm-yyyy'), to_date('17-07-2008', 'dd-mm-yyyy'), 5, 7007, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110318010513, to_date('18-03-2011', 'dd-mm-yyyy'), to_date('01-04-2011', 'dd-mm-yyyy'), 4, 6668, to_date('28-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004010514, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 9, 5936, to_date('14-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809010515, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 7, 5412, to_date('18-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030912010516, to_date('12-09-2003', 'dd-mm-yyyy'), to_date('26-09-2003', 'dd-mm-yyyy'), 11, 2631, to_date('27-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100616010517, to_date('16-06-2010', 'dd-mm-yyyy'), to_date('30-06-2010', 'dd-mm-yyyy'), 7, 8560, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090828010518, to_date('28-08-2009', 'dd-mm-yyyy'), to_date('11-09-2009', 'dd-mm-yyyy'), 3, 6405, to_date('02-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060201010519, to_date('01-02-2006', 'dd-mm-yyyy'), to_date('15-02-2006', 'dd-mm-yyyy'), 3, 7972, to_date('17-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140305010520, to_date('05-03-2014', 'dd-mm-yyyy'), to_date('19-03-2014', 'dd-mm-yyyy'), 8, 7813, to_date('10-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100907010521, to_date('07-09-2010', 'dd-mm-yyyy'), to_date('21-09-2010', 'dd-mm-yyyy'), 8, 8153, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110201010522, to_date('01-02-2011', 'dd-mm-yyyy'), to_date('15-02-2011', 'dd-mm-yyyy'), 5, 6637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020418010523, to_date('18-04-2002', 'dd-mm-yyyy'), to_date('02-05-2002', 'dd-mm-yyyy'), 5, 4873, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030717010524, to_date('17-07-2003', 'dd-mm-yyyy'), to_date('31-07-2003', 'dd-mm-yyyy'), 11, 1415, to_date('19-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119010525, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 4, 4232, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111015010526, to_date('15-10-2011', 'dd-mm-yyyy'), to_date('29-10-2011', 'dd-mm-yyyy'), 3, 7957, to_date('25-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910010527, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 4, 7489, to_date('30-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080625010528, to_date('25-06-2008', 'dd-mm-yyyy'), to_date('09-07-2008', 'dd-mm-yyyy'), 7, 5749, to_date('28-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110215010529, to_date('15-02-2011', 'dd-mm-yyyy'), to_date('01-03-2011', 'dd-mm-yyyy'), 6, 6659, to_date('22-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140307010530, to_date('07-03-2014', 'dd-mm-yyyy'), to_date('21-03-2014', 'dd-mm-yyyy'), 11, 9620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051204010531, to_date('04-12-2005', 'dd-mm-yyyy'), to_date('18-12-2005', 'dd-mm-yyyy'), 2, 4300, to_date('10-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120805010532, to_date('05-08-2012', 'dd-mm-yyyy'), to_date('19-08-2012', 'dd-mm-yyyy'), 2, 8944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111229010533, to_date('29-12-2011', 'dd-mm-yyyy'), to_date('12-01-2012', 'dd-mm-yyyy'), 6, 7156, to_date('06-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528010534, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 9, 3901, to_date('10-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221010535, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 12, 6931, to_date('05-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101010536, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 10, 6928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030205010537, to_date('05-02-2003', 'dd-mm-yyyy'), to_date('19-02-2003', 'dd-mm-yyyy'), 9, 3713, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060115010538, to_date('15-01-2006', 'dd-mm-yyyy'), to_date('29-01-2006', 'dd-mm-yyyy'), 6, 6383, to_date('26-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002010539, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 10, 2877, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100206010540, to_date('06-02-2010', 'dd-mm-yyyy'), to_date('20-02-2010', 'dd-mm-yyyy'), 10, 7965, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121030010541, to_date('30-10-2012', 'dd-mm-yyyy'), to_date('13-11-2012', 'dd-mm-yyyy'), 12, 10348, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000918010542, to_date('18-09-2000', 'dd-mm-yyyy'), to_date('02-10-2000', 'dd-mm-yyyy'), 6, 2941, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091015010543, to_date('15-10-2009', 'dd-mm-yyyy'), to_date('29-10-2009', 'dd-mm-yyyy'), 7, 5366, to_date('31-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040210010544, to_date('10-02-2004', 'dd-mm-yyyy'), to_date('24-02-2004', 'dd-mm-yyyy'), 6, 2819, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010217010545, to_date('17-02-2001', 'dd-mm-yyyy'), to_date('03-03-2001', 'dd-mm-yyyy'), 10, 2223, to_date('03-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110309010546, to_date('09-03-2011', 'dd-mm-yyyy'), to_date('23-03-2011', 'dd-mm-yyyy'), 3, 8603, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081011010547, to_date('11-10-2008', 'dd-mm-yyyy'), to_date('25-10-2008', 'dd-mm-yyyy'), 7, 8562, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723010548, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 11, 4812, to_date('05-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208010549, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 8, 7913, to_date('09-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121011010550, to_date('11-10-2012', 'dd-mm-yyyy'), to_date('25-10-2012', 'dd-mm-yyyy'), 2, 6927, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212010551, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 8, 5430, to_date('15-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130710010552, to_date('10-07-2013', 'dd-mm-yyyy'), to_date('24-07-2013', 'dd-mm-yyyy'), 12, 10129, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929010553, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 8, 1340, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060809010554, to_date('09-08-2006', 'dd-mm-yyyy'), to_date('23-08-2006', 'dd-mm-yyyy'), 11, 5519, to_date('16-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031105010555, to_date('05-11-2003', 'dd-mm-yyyy'), to_date('19-11-2003', 'dd-mm-yyyy'), 8, 3684, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226010556, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 2, 3400, to_date('01-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011003010557, to_date('03-10-2001', 'dd-mm-yyyy'), to_date('17-10-2001', 'dd-mm-yyyy'), 2, 2363, to_date('13-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011010010558, to_date('10-10-2001', 'dd-mm-yyyy'), to_date('24-10-2001', 'dd-mm-yyyy'), 11, 3101, to_date('19-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060101010559, to_date('01-01-2006', 'dd-mm-yyyy'), to_date('15-01-2006', 'dd-mm-yyyy'), 5, 4127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020125010560, to_date('25-01-2002', 'dd-mm-yyyy'), to_date('08-02-2002', 'dd-mm-yyyy'), 12, 4853, to_date('31-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000306010561, to_date('06-03-2000', 'dd-mm-yyyy'), to_date('20-03-2000', 'dd-mm-yyyy'), 3, 956, to_date('16-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070619010562, to_date('19-06-2007', 'dd-mm-yyyy'), to_date('03-07-2007', 'dd-mm-yyyy'), 8, 8396, to_date('23-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827010563, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 2, 5184, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081128010564, to_date('28-11-2008', 'dd-mm-yyyy'), to_date('12-12-2008', 'dd-mm-yyyy'), 9, 7179, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000115010565, to_date('15-01-2000', 'dd-mm-yyyy'), to_date('29-01-2000', 'dd-mm-yyyy'), 8, 1634, to_date('17-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308010566, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 10, 5490, to_date('18-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090321010567, to_date('21-03-2009', 'dd-mm-yyyy'), to_date('04-04-2009', 'dd-mm-yyyy'), 2, 6164, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080823013202, to_date('23-08-2008', 'dd-mm-yyyy'), to_date('06-09-2008', 'dd-mm-yyyy'), 3, 4216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505013203, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 1, 5068, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004013204, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 1, 1435, to_date('12-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031016013205, to_date('16-10-2003', 'dd-mm-yyyy'), to_date('30-10-2003', 'dd-mm-yyyy'), 4, 3749, to_date('26-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061230013206, to_date('30-12-2006', 'dd-mm-yyyy'), to_date('13-01-2007', 'dd-mm-yyyy'), 1, 2620, to_date('03-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110805013207, to_date('05-08-2011', 'dd-mm-yyyy'), to_date('19-08-2011', 'dd-mm-yyyy'), 2, 8829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100728013208, to_date('28-07-2010', 'dd-mm-yyyy'), to_date('11-08-2010', 'dd-mm-yyyy'), 2, 9926, to_date('02-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030130013209, to_date('30-01-2003', 'dd-mm-yyyy'), to_date('13-02-2003', 'dd-mm-yyyy'), 2, 4794, to_date('10-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080715013210, to_date('15-07-2008', 'dd-mm-yyyy'), to_date('29-07-2008', 'dd-mm-yyyy'), 2, 6161, to_date('20-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021228013211, to_date('28-12-2002', 'dd-mm-yyyy'), to_date('11-01-2003', 'dd-mm-yyyy'), 3, 2425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110710013212, to_date('10-07-2011', 'dd-mm-yyyy'), to_date('24-07-2011', 'dd-mm-yyyy'), 1, 5955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706013213, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 3, 6695, to_date('19-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041022013214, to_date('22-10-2004', 'dd-mm-yyyy'), to_date('05-11-2004', 'dd-mm-yyyy'), 3, 2934, to_date('04-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908013215, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 3, 1826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010506013216, to_date('06-05-2001', 'dd-mm-yyyy'), to_date('20-05-2001', 'dd-mm-yyyy'), 1, 2023, to_date('15-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004013217, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 3, 2099, to_date('09-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008013218, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 3, 4198, to_date('17-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030206013219, to_date('06-02-2003', 'dd-mm-yyyy'), to_date('20-02-2003', 'dd-mm-yyyy'), 4, 3693, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140503013220, to_date('03-05-2014', 'dd-mm-yyyy'), to_date('17-05-2014', 'dd-mm-yyyy'), 4, 7414, to_date('16-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118013221, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 3, 6773, to_date('30-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060114013222, to_date('14-01-2006', 'dd-mm-yyyy'), to_date('28-01-2006', 'dd-mm-yyyy'), 3, 2724, to_date('27-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110013223, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 3, 9193, to_date('17-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050210013224, to_date('10-02-2005', 'dd-mm-yyyy'), to_date('24-02-2005', 'dd-mm-yyyy'), 2, 4719, to_date('14-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090728013225, to_date('28-07-2009', 'dd-mm-yyyy'), to_date('11-08-2009', 'dd-mm-yyyy'), 2, 5614, to_date('10-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040330013226, to_date('30-03-2004', 'dd-mm-yyyy'), to_date('13-04-2004', 'dd-mm-yyyy'), 2, 4133, to_date('04-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030630013227, to_date('30-06-2003', 'dd-mm-yyyy'), to_date('14-07-2003', 'dd-mm-yyyy'), 1, 5909, to_date('09-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070721013228, to_date('21-07-2007', 'dd-mm-yyyy'), to_date('04-08-2007', 'dd-mm-yyyy'), 2, 7280, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060914013229, to_date('14-09-2006', 'dd-mm-yyyy'), to_date('28-09-2006', 'dd-mm-yyyy'), 2, 4351, to_date('24-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020125013230, to_date('25-01-2002', 'dd-mm-yyyy'), to_date('08-02-2002', 'dd-mm-yyyy'), 3, 1963, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021217013231, to_date('17-12-2002', 'dd-mm-yyyy'), to_date('31-12-2002', 'dd-mm-yyyy'), 4, 3318, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030126013232, to_date('26-01-2003', 'dd-mm-yyyy'), to_date('09-02-2003', 'dd-mm-yyyy'), 2, 4512, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111008013233, to_date('08-10-2011', 'dd-mm-yyyy'), to_date('22-10-2011', 'dd-mm-yyyy'), 2, 7404, to_date('22-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108013234, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 2, 6686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060702013235, to_date('02-07-2006', 'dd-mm-yyyy'), to_date('16-07-2006', 'dd-mm-yyyy'), 3, 3303, to_date('22-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111206013236, to_date('06-12-2011', 'dd-mm-yyyy'), to_date('20-12-2011', 'dd-mm-yyyy'), 4, 7192, to_date('12-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211013237, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 2, 2785, to_date('20-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505013238, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 4, 3633, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903013239, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 2, 962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030228013240, to_date('28-02-2003', 'dd-mm-yyyy'), to_date('14-03-2003', 'dd-mm-yyyy'), 1, 2775, to_date('08-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081015013241, to_date('15-10-2008', 'dd-mm-yyyy'), to_date('29-10-2008', 'dd-mm-yyyy'), 2, 8540, to_date('24-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130412013242, to_date('12-04-2013', 'dd-mm-yyyy'), to_date('26-04-2013', 'dd-mm-yyyy'), 3, 10280, to_date('22-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070616013243, to_date('16-06-2007', 'dd-mm-yyyy'), to_date('30-06-2007', 'dd-mm-yyyy'), 1, 7588, to_date('04-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060928013244, to_date('28-09-2006', 'dd-mm-yyyy'), to_date('12-10-2006', 'dd-mm-yyyy'), 2, 6377, to_date('05-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030716013245, to_date('16-07-2003', 'dd-mm-yyyy'), to_date('30-07-2003', 'dd-mm-yyyy'), 1, 3453, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222013246, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 4, 9991, to_date('02-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530013247, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 3, 8880, to_date('31-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050813013248, to_date('13-08-2005', 'dd-mm-yyyy'), to_date('27-08-2005', 'dd-mm-yyyy'), 2, 4674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051005013249, to_date('05-10-2005', 'dd-mm-yyyy'), to_date('19-10-2005', 'dd-mm-yyyy'), 2, 4227, to_date('19-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210013250, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 4, 5667, to_date('17-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071217013251, to_date('17-12-2007', 'dd-mm-yyyy'), to_date('31-12-2007', 'dd-mm-yyyy'), 1, 6838, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000104013252, to_date('04-01-2000', 'dd-mm-yyyy'), to_date('18-01-2000', 'dd-mm-yyyy'), 2, 3221, to_date('21-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040722013253, to_date('22-07-2004', 'dd-mm-yyyy'), to_date('05-08-2004', 'dd-mm-yyyy'), 3, 4476, to_date('05-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080223013254, to_date('23-02-2008', 'dd-mm-yyyy'), to_date('08-03-2008', 'dd-mm-yyyy'), 4, 7291, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040106013255, to_date('06-01-2004', 'dd-mm-yyyy'), to_date('20-01-2004', 'dd-mm-yyyy'), 2, 3409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026013256, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 3, 5718, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004013257, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 3, 1775, to_date('21-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011022013258, to_date('22-10-2001', 'dd-mm-yyyy'), to_date('05-11-2001', 'dd-mm-yyyy'), 4, 2064, to_date('29-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040131013259, to_date('31-01-2004', 'dd-mm-yyyy'), to_date('14-02-2004', 'dd-mm-yyyy'), 3, 3345, to_date('16-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618013260, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 3, 6744, to_date('25-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120324013261, to_date('24-03-2012', 'dd-mm-yyyy'), to_date('07-04-2012', 'dd-mm-yyyy'), 3, 9530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020920013262, to_date('20-09-2002', 'dd-mm-yyyy'), to_date('04-10-2002', 'dd-mm-yyyy'), 2, 1095, to_date('25-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080409013263, to_date('09-04-2008', 'dd-mm-yyyy'), to_date('23-04-2008', 'dd-mm-yyyy'), 1, 5681, to_date('22-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050427013264, to_date('27-04-2005', 'dd-mm-yyyy'), to_date('11-05-2005', 'dd-mm-yyyy'), 1, 3251, to_date('28-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011102013265, to_date('02-11-2001', 'dd-mm-yyyy'), to_date('16-11-2001', 'dd-mm-yyyy'), 3, 1856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515013266, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 4, 3356, to_date('24-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100407013267, to_date('07-04-2010', 'dd-mm-yyyy'), to_date('21-04-2010', 'dd-mm-yyyy'), 3, 10496, to_date('16-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120506013268, to_date('06-05-2012', 'dd-mm-yyyy'), to_date('20-05-2012', 'dd-mm-yyyy'), 3, 8119, to_date('18-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000911013269, to_date('11-09-2000', 'dd-mm-yyyy'), to_date('25-09-2000', 'dd-mm-yyyy'), 2, 1656, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607013270, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 2, 4959, to_date('13-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323013271, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 3, 6111, to_date('28-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021004013272, to_date('04-10-2002', 'dd-mm-yyyy'), to_date('18-10-2002', 'dd-mm-yyyy'), 2, 2690, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104013273, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 3, 8932, to_date('20-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120309013274, to_date('09-03-2012', 'dd-mm-yyyy'), to_date('23-03-2012', 'dd-mm-yyyy'), 2, 10116, to_date('16-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125013275, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 2, 7234, to_date('08-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007013276, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 3, 3394, to_date('14-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100402013277, to_date('02-04-2010', 'dd-mm-yyyy'), to_date('16-04-2010', 'dd-mm-yyyy'), 3, 9342, to_date('13-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120428013278, to_date('28-04-2012', 'dd-mm-yyyy'), to_date('12-05-2012', 'dd-mm-yyyy'), 1, 5858, to_date('06-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131214013279, to_date('14-12-2013', 'dd-mm-yyyy'), to_date('28-12-2013', 'dd-mm-yyyy'), 2, 6300, to_date('18-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030919013280, to_date('19-09-2003', 'dd-mm-yyyy'), to_date('03-10-2003', 'dd-mm-yyyy'), 2, 3889, to_date('08-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101211013281, to_date('11-12-2010', 'dd-mm-yyyy'), to_date('25-12-2010', 'dd-mm-yyyy'), 3, 6046, to_date('18-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001101013282, to_date('01-11-2000', 'dd-mm-yyyy'), to_date('15-11-2000', 'dd-mm-yyyy'), 3, 2002, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030130013283, to_date('30-01-2003', 'dd-mm-yyyy'), to_date('13-02-2003', 'dd-mm-yyyy'), 2, 2280, to_date('16-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122013284, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 3, 5490, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121013013285, to_date('13-10-2012', 'dd-mm-yyyy'), to_date('27-10-2012', 'dd-mm-yyyy'), 2, 6330, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421013286, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 2, 4903, to_date('27-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070916013287, to_date('16-09-2007', 'dd-mm-yyyy'), to_date('30-09-2007', 'dd-mm-yyyy'), 2, 5241, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021228013288, to_date('28-12-2002', 'dd-mm-yyyy'), to_date('11-01-2003', 'dd-mm-yyyy'), 3, 3738, to_date('14-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405013289, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 1, 6841, to_date('13-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050824013290, to_date('24-08-2005', 'dd-mm-yyyy'), to_date('07-09-2005', 'dd-mm-yyyy'), 3, 5715, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111013291, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 2, 5635, to_date('13-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060421013292, to_date('21-04-2006', 'dd-mm-yyyy'), to_date('05-05-2006', 'dd-mm-yyyy'), 3, 5067, to_date('30-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409013293, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 2, 8144, to_date('26-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100528013294, to_date('28-05-2010', 'dd-mm-yyyy'), to_date('11-06-2010', 'dd-mm-yyyy'), 4, 4219, to_date('30-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601013295, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 3, 5511, to_date('07-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090319013296, to_date('19-03-2009', 'dd-mm-yyyy'), to_date('02-04-2009', 'dd-mm-yyyy'), 4, 6681, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000630013297, to_date('30-06-2000', 'dd-mm-yyyy'), to_date('14-07-2000', 'dd-mm-yyyy'), 2, 2346, to_date('17-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070904013298, to_date('04-09-2007', 'dd-mm-yyyy'), to_date('18-09-2007', 'dd-mm-yyyy'), 3, 5066, to_date('14-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122013299, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 3, 2616, to_date('04-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100830013300, to_date('30-08-2010', 'dd-mm-yyyy'), to_date('13-09-2010', 'dd-mm-yyyy'), 2, 7291, to_date('10-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091208013301, to_date('08-12-2009', 'dd-mm-yyyy'), to_date('22-12-2009', 'dd-mm-yyyy'), 2, 5480, to_date('09-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110716013302, to_date('16-07-2011', 'dd-mm-yyyy'), to_date('30-07-2011', 'dd-mm-yyyy'), 1, 5450, to_date('20-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021013303, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 1, 6086, to_date('28-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031116013304, to_date('16-11-2003', 'dd-mm-yyyy'), to_date('30-11-2003', 'dd-mm-yyyy'), 3, 2966, to_date('29-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031020013305, to_date('20-10-2003', 'dd-mm-yyyy'), to_date('03-11-2003', 'dd-mm-yyyy'), 3, 3411, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041220013306, to_date('20-12-2004', 'dd-mm-yyyy'), to_date('03-01-2005', 'dd-mm-yyyy'), 3, 4382, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120819013307, to_date('19-08-2012', 'dd-mm-yyyy'), to_date('02-09-2012', 'dd-mm-yyyy'), 2, 6868, to_date('27-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000816013308, to_date('16-08-2000', 'dd-mm-yyyy'), to_date('30-08-2000', 'dd-mm-yyyy'), 4, 1207, to_date('19-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090706013309, to_date('06-07-2009', 'dd-mm-yyyy'), to_date('20-07-2009', 'dd-mm-yyyy'), 2, 6621, to_date('18-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131219013310, to_date('19-12-2013', 'dd-mm-yyyy'), to_date('02-01-2014', 'dd-mm-yyyy'), 2, 10263, to_date('27-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100308013311, to_date('08-03-2010', 'dd-mm-yyyy'), to_date('22-03-2010', 'dd-mm-yyyy'), 2, 9924, to_date('28-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322013312, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 1, 2537, to_date('25-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050106013313, to_date('06-01-2005', 'dd-mm-yyyy'), to_date('20-01-2005', 'dd-mm-yyyy'), 2, 6342, to_date('11-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513013314, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 2, 4499, to_date('19-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512013315, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 2, 4369, to_date('18-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620013316, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 3, 6842, to_date('03-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209013317, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 1, 9135, to_date('28-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530013318, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 3, 1214, to_date('18-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010727013319, to_date('27-07-2001', 'dd-mm-yyyy'), to_date('10-08-2001', 'dd-mm-yyyy'), 4, 2582, to_date('05-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020419013320, to_date('19-04-2002', 'dd-mm-yyyy'), to_date('03-05-2002', 'dd-mm-yyyy'), 1, 4029, to_date('23-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020407013321, to_date('07-04-2002', 'dd-mm-yyyy'), to_date('21-04-2002', 'dd-mm-yyyy'), 4, 4576, to_date('26-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090902013322, to_date('02-09-2009', 'dd-mm-yyyy'), to_date('16-09-2009', 'dd-mm-yyyy'), 3, 9397, to_date('15-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026013323, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 3, 5603, to_date('12-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130612013324, to_date('12-06-2013', 'dd-mm-yyyy'), to_date('26-06-2013', 'dd-mm-yyyy'), 3, 8946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010223013325, to_date('23-02-2001', 'dd-mm-yyyy'), to_date('09-03-2001', 'dd-mm-yyyy'), 2, 3006, to_date('06-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000314013326, to_date('14-03-2000', 'dd-mm-yyyy'), to_date('28-03-2000', 'dd-mm-yyyy'), 2, 2381, to_date('23-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902013327, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 2, 4762, to_date('20-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060210013328, to_date('10-02-2006', 'dd-mm-yyyy'), to_date('24-02-2006', 'dd-mm-yyyy'), 4, 4647, to_date('28-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041121013329, to_date('21-11-2004', 'dd-mm-yyyy'), to_date('05-12-2004', 'dd-mm-yyyy'), 2, 4056, to_date('04-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212013330, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 3, 1902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070919013331, to_date('19-09-2007', 'dd-mm-yyyy'), to_date('03-10-2007', 'dd-mm-yyyy'), 4, 4319, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070116013332, to_date('16-01-2007', 'dd-mm-yyyy'), to_date('30-01-2007', 'dd-mm-yyyy'), 4, 5781, to_date('19-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123013333, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 3, 7145, to_date('11-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061224013334, to_date('24-12-2006', 'dd-mm-yyyy'), to_date('07-01-2007', 'dd-mm-yyyy'), 2, 5695, to_date('30-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000522013335, to_date('22-05-2000', 'dd-mm-yyyy'), to_date('05-06-2000', 'dd-mm-yyyy'), 2, 2767, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050402013336, to_date('02-04-2005', 'dd-mm-yyyy'), to_date('16-04-2005', 'dd-mm-yyyy'), 3, 3398, to_date('13-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030221013337, to_date('21-02-2003', 'dd-mm-yyyy'), to_date('07-03-2003', 'dd-mm-yyyy'), 2, 6128, to_date('07-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111013338, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 1, 8603, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030517013339, to_date('17-05-2003', 'dd-mm-yyyy'), to_date('31-05-2003', 'dd-mm-yyyy'), 2, 2653, to_date('24-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000412013340, to_date('12-04-2000', 'dd-mm-yyyy'), to_date('26-04-2000', 'dd-mm-yyyy'), 4, 1600, to_date('13-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131230013341, to_date('30-12-2013', 'dd-mm-yyyy'), to_date('13-01-2014', 'dd-mm-yyyy'), 4, 7601, to_date('15-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040613013342, to_date('13-06-2004', 'dd-mm-yyyy'), to_date('27-06-2004', 'dd-mm-yyyy'), 3, 3321, to_date('16-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090422013343, to_date('22-04-2009', 'dd-mm-yyyy'), to_date('06-05-2009', 'dd-mm-yyyy'), 3, 7747, to_date('07-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080930013344, to_date('30-09-2008', 'dd-mm-yyyy'), to_date('14-10-2008', 'dd-mm-yyyy'), 2, 8018, to_date('02-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115013345, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 2, 1642, to_date('03-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010731013346, to_date('31-07-2001', 'dd-mm-yyyy'), to_date('14-08-2001', 'dd-mm-yyyy'), 2, 3562, to_date('07-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060424013347, to_date('24-04-2006', 'dd-mm-yyyy'), to_date('08-05-2006', 'dd-mm-yyyy'), 3, 5998, to_date('03-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060901013348, to_date('01-09-2006', 'dd-mm-yyyy'), to_date('15-09-2006', 'dd-mm-yyyy'), 2, 6929, to_date('03-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031122013349, to_date('22-11-2003', 'dd-mm-yyyy'), to_date('06-12-2003', 'dd-mm-yyyy'), 3, 5618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050707013350, to_date('07-07-2005', 'dd-mm-yyyy'), to_date('21-07-2005', 'dd-mm-yyyy'), 3, 2782, to_date('19-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021116013351, to_date('16-11-2002', 'dd-mm-yyyy'), to_date('30-11-2002', 'dd-mm-yyyy'), 2, 2532, to_date('01-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020119013352, to_date('19-01-2002', 'dd-mm-yyyy'), to_date('02-02-2002', 'dd-mm-yyyy'), 1, 2926, to_date('01-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113013353, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 4, 3644, to_date('25-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825013354, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 2, 3702, to_date('03-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000817013355, to_date('17-08-2000', 'dd-mm-yyyy'), to_date('31-08-2000', 'dd-mm-yyyy'), 1, 1284, to_date('29-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227013356, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 2, 4392, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110316013357, to_date('16-03-2011', 'dd-mm-yyyy'), to_date('30-03-2011', 'dd-mm-yyyy'), 4, 8413, to_date('18-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003013358, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 3, 9074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130128013359, to_date('28-01-2013', 'dd-mm-yyyy'), to_date('11-02-2013', 'dd-mm-yyyy'), 2, 6860, to_date('09-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040612013360, to_date('12-06-2004', 'dd-mm-yyyy'), to_date('26-06-2004', 'dd-mm-yyyy'), 3, 5416, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120311013361, to_date('11-03-2012', 'dd-mm-yyyy'), to_date('25-03-2012', 'dd-mm-yyyy'), 2, 8691, to_date('14-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130404013362, to_date('04-04-2013', 'dd-mm-yyyy'), to_date('18-04-2013', 'dd-mm-yyyy'), 4, 9936, to_date('19-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217013363, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 3, 8377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926013364, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 3, 3967, to_date('14-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040524013365, to_date('24-05-2004', 'dd-mm-yyyy'), to_date('07-06-2004', 'dd-mm-yyyy'), 3, 4217, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090528013366, to_date('28-05-2009', 'dd-mm-yyyy'), to_date('11-06-2009', 'dd-mm-yyyy'), 1, 6613, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070923013367, to_date('23-09-2007', 'dd-mm-yyyy'), to_date('07-10-2007', 'dd-mm-yyyy'), 3, 4512, to_date('01-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111016013368, to_date('16-10-2011', 'dd-mm-yyyy'), to_date('30-10-2011', 'dd-mm-yyyy'), 3, 9535, to_date('30-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031019015892, to_date('19-10-2003', 'dd-mm-yyyy'), to_date('02-11-2003', 'dd-mm-yyyy'), 4, 3587, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206015893, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 2, 6965, to_date('17-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070510015894, to_date('10-05-2007', 'dd-mm-yyyy'), to_date('24-05-2007', 'dd-mm-yyyy'), 3, 5875, to_date('16-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100515015895, to_date('15-05-2010', 'dd-mm-yyyy'), to_date('29-05-2010', 'dd-mm-yyyy'), 1, 6506, to_date('17-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000212015896, to_date('12-02-2000', 'dd-mm-yyyy'), to_date('26-02-2000', 'dd-mm-yyyy'), 4, 1204, to_date('22-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030921015897, to_date('21-09-2003', 'dd-mm-yyyy'), to_date('05-10-2003', 'dd-mm-yyyy'), 2, 2093, to_date('28-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011110015898, to_date('10-11-2001', 'dd-mm-yyyy'), to_date('24-11-2001', 'dd-mm-yyyy'), 2, 3623, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100121015899, to_date('21-01-2010', 'dd-mm-yyyy'), to_date('04-02-2010', 'dd-mm-yyyy'), 3, 6933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090620015900, to_date('20-06-2009', 'dd-mm-yyyy'), to_date('04-07-2009', 'dd-mm-yyyy'), 1, 7707, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060114015901, to_date('14-01-2006', 'dd-mm-yyyy'), to_date('28-01-2006', 'dd-mm-yyyy'), 4, 5303, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502015902, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 1, 7713, to_date('05-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071214015903, to_date('14-12-2007', 'dd-mm-yyyy'), to_date('28-12-2007', 'dd-mm-yyyy'), 2, 6451, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011205015904, to_date('05-12-2001', 'dd-mm-yyyy'), to_date('19-12-2001', 'dd-mm-yyyy'), 3, 2154, to_date('16-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603015905, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 1, 5229, to_date('22-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101212015906, to_date('12-12-2010', 'dd-mm-yyyy'), to_date('26-12-2010', 'dd-mm-yyyy'), 1, 6312, to_date('26-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813015907, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 3, 6227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070314015908, to_date('14-03-2007', 'dd-mm-yyyy'), to_date('28-03-2007', 'dd-mm-yyyy'), 4, 5669, to_date('30-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061212015909, to_date('12-12-2006', 'dd-mm-yyyy'), to_date('26-12-2006', 'dd-mm-yyyy'), 3, 6736, to_date('25-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010825015910, to_date('25-08-2001', 'dd-mm-yyyy'), to_date('08-09-2001', 'dd-mm-yyyy'), 2, 2085, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050424015911, to_date('24-04-2005', 'dd-mm-yyyy'), to_date('08-05-2005', 'dd-mm-yyyy'), 3, 6429, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118015912, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 2, 2106, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050711015913, to_date('11-07-2005', 'dd-mm-yyyy'), to_date('25-07-2005', 'dd-mm-yyyy'), 3, 2698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090712015914, to_date('12-07-2009', 'dd-mm-yyyy'), to_date('26-07-2009', 'dd-mm-yyyy'), 4, 9043, to_date('28-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110922015915, to_date('22-09-2011', 'dd-mm-yyyy'), to_date('06-10-2011', 'dd-mm-yyyy'), 2, 8313, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000521015916, to_date('21-05-2000', 'dd-mm-yyyy'), to_date('04-06-2000', 'dd-mm-yyyy'), 2, 544, to_date('31-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130015917, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 3, 2325, to_date('16-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118015918, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 3, 2996, to_date('27-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000818015919, to_date('18-08-2000', 'dd-mm-yyyy'), to_date('01-09-2000', 'dd-mm-yyyy'), 2, 1046, to_date('01-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000504015920, to_date('04-05-2000', 'dd-mm-yyyy'), to_date('18-05-2000', 'dd-mm-yyyy'), 2, 1228, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011214015921, to_date('14-12-2001', 'dd-mm-yyyy'), to_date('28-12-2001', 'dd-mm-yyyy'), 2, 1509, to_date('01-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080408015922, to_date('08-04-2008', 'dd-mm-yyyy'), to_date('22-04-2008', 'dd-mm-yyyy'), 3, 7254, to_date('18-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119015923, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 3, 8230, to_date('31-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060423015924, to_date('23-04-2006', 'dd-mm-yyyy'), to_date('07-05-2006', 'dd-mm-yyyy'), 4, 4920, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110207015925, to_date('07-02-2011', 'dd-mm-yyyy'), to_date('21-02-2011', 'dd-mm-yyyy'), 1, 8698, to_date('13-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207015926, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 2, 2674, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030309015927, to_date('09-03-2003', 'dd-mm-yyyy'), to_date('23-03-2003', 'dd-mm-yyyy'), 1, 2665, to_date('26-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504015928, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 2, 7816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101002015929, to_date('02-10-2010', 'dd-mm-yyyy'), to_date('16-10-2010', 'dd-mm-yyyy'), 2, 6725, to_date('08-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071101015930, to_date('01-11-2007', 'dd-mm-yyyy'), to_date('15-11-2007', 'dd-mm-yyyy'), 1, 7616, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024015931, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 3, 8747, to_date('12-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111116015932, to_date('16-11-2011', 'dd-mm-yyyy'), to_date('30-11-2011', 'dd-mm-yyyy'), 4, 8691, to_date('29-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090526015933, to_date('26-05-2009', 'dd-mm-yyyy'), to_date('09-06-2009', 'dd-mm-yyyy'), 3, 4400, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120814015934, to_date('14-08-2012', 'dd-mm-yyyy'), to_date('28-08-2012', 'dd-mm-yyyy'), 4, 6720, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216015935, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 4, 5432, to_date('04-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120107015936, to_date('07-01-2012', 'dd-mm-yyyy'), to_date('21-01-2012', 'dd-mm-yyyy'), 2, 6520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081126015937, to_date('26-11-2008', 'dd-mm-yyyy'), to_date('10-12-2008', 'dd-mm-yyyy'), 4, 4509, to_date('16-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061115015938, to_date('15-11-2006', 'dd-mm-yyyy'), to_date('29-11-2006', 'dd-mm-yyyy'), 3, 6854, to_date('27-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131221015939, to_date('21-12-2013', 'dd-mm-yyyy'), to_date('04-01-2014', 'dd-mm-yyyy'), 4, 7235, to_date('22-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226015940, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 3, 2094, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080920015941, to_date('20-09-2008', 'dd-mm-yyyy'), to_date('04-10-2008', 'dd-mm-yyyy'), 1, 5262, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070416015942, to_date('16-04-2007', 'dd-mm-yyyy'), to_date('30-04-2007', 'dd-mm-yyyy'), 4, 8004, to_date('25-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030530015943, to_date('30-05-2003', 'dd-mm-yyyy'), to_date('13-06-2003', 'dd-mm-yyyy'), 2, 5567, to_date('14-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010910015944, to_date('10-09-2001', 'dd-mm-yyyy'), to_date('24-09-2001', 'dd-mm-yyyy'), 1, 2140, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100519015945, to_date('19-05-2010', 'dd-mm-yyyy'), to_date('02-06-2010', 'dd-mm-yyyy'), 3, 9486, to_date('06-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031010015946, to_date('10-10-2003', 'dd-mm-yyyy'), to_date('24-10-2003', 'dd-mm-yyyy'), 3, 3865, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041011015947, to_date('11-10-2004', 'dd-mm-yyyy'), to_date('25-10-2004', 'dd-mm-yyyy'), 3, 3993, to_date('27-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227015948, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 1, 2216, to_date('08-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031019015949, to_date('19-10-2003', 'dd-mm-yyyy'), to_date('02-11-2003', 'dd-mm-yyyy'), 3, 3843, to_date('04-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030710015950, to_date('10-07-2003', 'dd-mm-yyyy'), to_date('24-07-2003', 'dd-mm-yyyy'), 2, 4633, to_date('19-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000226015951, to_date('26-02-2000', 'dd-mm-yyyy'), to_date('11-03-2000', 'dd-mm-yyyy'), 3, 3013, to_date('14-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105015952, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 3, 6883, to_date('21-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070213015953, to_date('13-02-2007', 'dd-mm-yyyy'), to_date('27-02-2007', 'dd-mm-yyyy'), 2, 5622, to_date('15-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070121015954, to_date('21-01-2007', 'dd-mm-yyyy'), to_date('04-02-2007', 'dd-mm-yyyy'), 3, 4006, to_date('26-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021031015955, to_date('31-10-2002', 'dd-mm-yyyy'), to_date('14-11-2002', 'dd-mm-yyyy'), 2, 1777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830015956, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 1, 1959, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921015957, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 1, 5384, to_date('11-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821015958, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 2, 7622, to_date('31-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603015959, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 1, 1192, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130830015960, to_date('30-08-2013', 'dd-mm-yyyy'), to_date('13-09-2013', 'dd-mm-yyyy'), 1, 6894, to_date('16-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000211015961, to_date('11-02-2000', 'dd-mm-yyyy'), to_date('25-02-2000', 'dd-mm-yyyy'), 3, 656, to_date('21-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040429015962, to_date('29-04-2004', 'dd-mm-yyyy'), to_date('13-05-2004', 'dd-mm-yyyy'), 2, 2533, to_date('10-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825015963, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 3, 4227, to_date('13-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120120015964, to_date('20-01-2012', 'dd-mm-yyyy'), to_date('03-02-2012', 'dd-mm-yyyy'), 2, 6756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815015965, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 3, 5140, to_date('24-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130930015966, to_date('30-09-2013', 'dd-mm-yyyy'), to_date('14-10-2013', 'dd-mm-yyyy'), 2, 5097, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116015967, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 2, 4884, to_date('18-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325015968, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 3, 5876, to_date('02-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010505015969, to_date('05-05-2001', 'dd-mm-yyyy'), to_date('19-05-2001', 'dd-mm-yyyy'), 1, 1273, to_date('20-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040901015970, to_date('01-09-2004', 'dd-mm-yyyy'), to_date('15-09-2004', 'dd-mm-yyyy'), 3, 4632, to_date('16-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050325015971, to_date('25-03-2005', 'dd-mm-yyyy'), to_date('08-04-2005', 'dd-mm-yyyy'), 3, 4438, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090706015972, to_date('06-07-2009', 'dd-mm-yyyy'), to_date('20-07-2009', 'dd-mm-yyyy'), 2, 5938, to_date('10-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050201015973, to_date('01-02-2005', 'dd-mm-yyyy'), to_date('15-02-2005', 'dd-mm-yyyy'), 2, 4455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091012015974, to_date('12-10-2009', 'dd-mm-yyyy'), to_date('26-10-2009', 'dd-mm-yyyy'), 3, 6953, to_date('19-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110806015975, to_date('06-08-2011', 'dd-mm-yyyy'), to_date('20-08-2011', 'dd-mm-yyyy'), 1, 6803, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111015976, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 1, 7024, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010803015977, to_date('03-08-2001', 'dd-mm-yyyy'), to_date('17-08-2001', 'dd-mm-yyyy'), 4, 2876, to_date('04-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040624015978, to_date('24-06-2004', 'dd-mm-yyyy'), to_date('08-07-2004', 'dd-mm-yyyy'), 4, 3372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041012015979, to_date('12-10-2004', 'dd-mm-yyyy'), to_date('26-10-2004', 'dd-mm-yyyy'), 1, 4703, to_date('21-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070915015980, to_date('15-09-2007', 'dd-mm-yyyy'), to_date('29-09-2007', 'dd-mm-yyyy'), 3, 5119, to_date('26-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111027015981, to_date('27-10-2011', 'dd-mm-yyyy'), to_date('10-11-2011', 'dd-mm-yyyy'), 1, 8694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010420015982, to_date('20-04-2001', 'dd-mm-yyyy'), to_date('04-05-2001', 'dd-mm-yyyy'), 1, 2318, to_date('30-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001027015983, to_date('27-10-2000', 'dd-mm-yyyy'), to_date('10-11-2000', 'dd-mm-yyyy'), 2, 1574, to_date('03-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131021015984, to_date('21-10-2013', 'dd-mm-yyyy'), to_date('04-11-2013', 'dd-mm-yyyy'), 4, 10056, to_date('25-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020524015985, to_date('24-05-2002', 'dd-mm-yyyy'), to_date('07-06-2002', 'dd-mm-yyyy'), 1, 2930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080915015986, to_date('15-09-2008', 'dd-mm-yyyy'), to_date('29-09-2008', 'dd-mm-yyyy'), 3, 6281, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110308015987, to_date('08-03-2011', 'dd-mm-yyyy'), to_date('22-03-2011', 'dd-mm-yyyy'), 2, 9479, to_date('12-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070914015988, to_date('14-09-2007', 'dd-mm-yyyy'), to_date('28-09-2007', 'dd-mm-yyyy'), 4, 3384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050822015989, to_date('22-08-2005', 'dd-mm-yyyy'), to_date('05-09-2005', 'dd-mm-yyyy'), 2, 4671, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140328015990, to_date('28-03-2014', 'dd-mm-yyyy'), to_date('11-04-2014', 'dd-mm-yyyy'), 3, 7213, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090319015991, to_date('19-03-2009', 'dd-mm-yyyy'), to_date('02-04-2009', 'dd-mm-yyyy'), 3, 9314, to_date('20-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131014015992, to_date('14-10-2013', 'dd-mm-yyyy'), to_date('28-10-2013', 'dd-mm-yyyy'), 1, 9567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080821015993, to_date('21-08-2008', 'dd-mm-yyyy'), to_date('04-09-2008', 'dd-mm-yyyy'), 3, 7224, to_date('08-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010625015994, to_date('25-06-2001', 'dd-mm-yyyy'), to_date('09-07-2001', 'dd-mm-yyyy'), 1, 2519, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215015995, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 1, 5040, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040728015996, to_date('28-07-2004', 'dd-mm-yyyy'), to_date('11-08-2004', 'dd-mm-yyyy'), 2, 3800, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080103015997, to_date('03-01-2008', 'dd-mm-yyyy'), to_date('17-01-2008', 'dd-mm-yyyy'), 3, 7472, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040121015998, to_date('21-01-2004', 'dd-mm-yyyy'), to_date('04-02-2004', 'dd-mm-yyyy'), 2, 5236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120113015999, to_date('13-01-2012', 'dd-mm-yyyy'), to_date('27-01-2012', 'dd-mm-yyyy'), 2, 8926, to_date('23-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121016000, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 4, 6426, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041203016001, to_date('03-12-2004', 'dd-mm-yyyy'), to_date('17-12-2004', 'dd-mm-yyyy'), 3, 4895, to_date('12-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010425016002, to_date('25-04-2001', 'dd-mm-yyyy'), to_date('09-05-2001', 'dd-mm-yyyy'), 1, 1409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111016003, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 1, 10159, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070130016004, to_date('30-01-2007', 'dd-mm-yyyy'), to_date('13-02-2007', 'dd-mm-yyyy'), 2, 6064, to_date('02-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080523016005, to_date('23-05-2008', 'dd-mm-yyyy'), to_date('06-06-2008', 'dd-mm-yyyy'), 2, 5428, to_date('12-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050304016006, to_date('04-03-2005', 'dd-mm-yyyy'), to_date('18-03-2005', 'dd-mm-yyyy'), 2, 3637, to_date('20-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100402016007, to_date('02-04-2010', 'dd-mm-yyyy'), to_date('16-04-2010', 'dd-mm-yyyy'), 1, 7930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020103016008, to_date('03-01-2002', 'dd-mm-yyyy'), to_date('17-01-2002', 'dd-mm-yyyy'), 1, 2684, to_date('10-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060415016009, to_date('15-04-2006', 'dd-mm-yyyy'), to_date('29-04-2006', 'dd-mm-yyyy'), 2, 5972, to_date('25-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020424016010, to_date('24-04-2002', 'dd-mm-yyyy'), to_date('08-05-2002', 'dd-mm-yyyy'), 2, 4467, to_date('29-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060915016011, to_date('15-09-2006', 'dd-mm-yyyy'), to_date('29-09-2006', 'dd-mm-yyyy'), 2, 4236, to_date('01-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713016012, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 2, 1831, to_date('23-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219016013, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 1, 4224, to_date('29-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040408016014, to_date('08-04-2004', 'dd-mm-yyyy'), to_date('22-04-2004', 'dd-mm-yyyy'), 1, 5534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061013016015, to_date('13-10-2006', 'dd-mm-yyyy'), to_date('27-10-2006', 'dd-mm-yyyy'), 1, 6953, to_date('31-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712016016, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 1, 4200, to_date('28-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100319016017, to_date('19-03-2010', 'dd-mm-yyyy'), to_date('02-04-2010', 'dd-mm-yyyy'), 1, 6910, to_date('01-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090124016018, to_date('24-01-2009', 'dd-mm-yyyy'), to_date('07-02-2009', 'dd-mm-yyyy'), 1, 8234, to_date('04-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104016019, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 2, 3569, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111011016020, to_date('11-10-2011', 'dd-mm-yyyy'), to_date('25-10-2011', 'dd-mm-yyyy'), 2, 9885, to_date('13-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917016021, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 1, 7763, to_date('23-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050118016022, to_date('18-01-2005', 'dd-mm-yyyy'), to_date('01-02-2005', 'dd-mm-yyyy'), 1, 5565, to_date('19-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130506016023, to_date('06-05-2013', 'dd-mm-yyyy'), to_date('20-05-2013', 'dd-mm-yyyy'), 2, 11337, to_date('14-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020615016024, to_date('15-06-2002', 'dd-mm-yyyy'), to_date('29-06-2002', 'dd-mm-yyyy'), 2, 3322, to_date('21-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040708016025, to_date('08-07-2004', 'dd-mm-yyyy'), to_date('22-07-2004', 'dd-mm-yyyy'), 2, 4083, to_date('15-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040809016026, to_date('09-08-2004', 'dd-mm-yyyy'), to_date('23-08-2004', 'dd-mm-yyyy'), 2, 4639, to_date('27-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030925016027, to_date('25-09-2003', 'dd-mm-yyyy'), to_date('09-10-2003', 'dd-mm-yyyy'), 2, 1860, to_date('11-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051031016028, to_date('31-10-2005', 'dd-mm-yyyy'), to_date('14-11-2005', 'dd-mm-yyyy'), 1, 1455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525016029, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 2, 7250, to_date('10-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000518016030, to_date('18-05-2000', 'dd-mm-yyyy'), to_date('01-06-2000', 'dd-mm-yyyy'), 1, 1135, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108016031, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 2, 4798, to_date('11-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090116016032, to_date('16-01-2009', 'dd-mm-yyyy'), to_date('30-01-2009', 'dd-mm-yyyy'), 1, 8491, to_date('01-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121125016033, to_date('25-11-2012', 'dd-mm-yyyy'), to_date('09-12-2012', 'dd-mm-yyyy'), 1, 8667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081126016034, to_date('26-11-2008', 'dd-mm-yyyy'), to_date('10-12-2008', 'dd-mm-yyyy'), 1, 6785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130320016035, to_date('20-03-2013', 'dd-mm-yyyy'), to_date('03-04-2013', 'dd-mm-yyyy'), 2, 12105, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140409016036, to_date('09-04-2014', 'dd-mm-yyyy'), to_date('23-04-2014', 'dd-mm-yyyy'), 1, 7279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130213016037, to_date('13-02-2013', 'dd-mm-yyyy'), to_date('27-02-2013', 'dd-mm-yyyy'), 2, 8494, to_date('24-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020905016038, to_date('05-09-2002', 'dd-mm-yyyy'), to_date('19-09-2002', 'dd-mm-yyyy'), 1, 3951, to_date('09-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050520016039, to_date('20-05-2005', 'dd-mm-yyyy'), to_date('03-06-2005', 'dd-mm-yyyy'), 1, 4429, to_date('04-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130016040, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 1, 1554, to_date('08-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080930016041, to_date('30-09-2008', 'dd-mm-yyyy'), to_date('14-10-2008', 'dd-mm-yyyy'), 2, 5209, to_date('15-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011116016042, to_date('16-11-2001', 'dd-mm-yyyy'), to_date('30-11-2001', 'dd-mm-yyyy'), 2, 1875, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070318016043, to_date('18-03-2007', 'dd-mm-yyyy'), to_date('01-04-2007', 'dd-mm-yyyy'), 2, 4862, to_date('06-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131022016044, to_date('22-10-2013', 'dd-mm-yyyy'), to_date('05-11-2013', 'dd-mm-yyyy'), 2, 6409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129016045, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 2, 3514, to_date('31-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050517016046, to_date('17-05-2005', 'dd-mm-yyyy'), to_date('31-05-2005', 'dd-mm-yyyy'), 1, 4645, to_date('06-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120805016047, to_date('05-08-2012', 'dd-mm-yyyy'), to_date('19-08-2012', 'dd-mm-yyyy'), 1, 6975, to_date('15-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020320016048, to_date('20-03-2002', 'dd-mm-yyyy'), to_date('03-04-2002', 'dd-mm-yyyy'), 1, 871, to_date('21-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081028016049, to_date('28-10-2008', 'dd-mm-yyyy'), to_date('11-11-2008', 'dd-mm-yyyy'), 2, 4949, to_date('15-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070303016050, to_date('03-03-2007', 'dd-mm-yyyy'), to_date('17-03-2007', 'dd-mm-yyyy'), 2, 6553, to_date('07-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607016051, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 1, 6502, to_date('26-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621016052, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 1, 6661, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020523016053, to_date('23-05-2002', 'dd-mm-yyyy'), to_date('06-06-2002', 'dd-mm-yyyy'), 1, 1319, to_date('12-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030811016054, to_date('11-08-2003', 'dd-mm-yyyy'), to_date('25-08-2003', 'dd-mm-yyyy'), 2, 3640, to_date('27-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727016055, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 2, 2811, to_date('16-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000320016056, to_date('20-03-2000', 'dd-mm-yyyy'), to_date('03-04-2000', 'dd-mm-yyyy'), 1, 355, to_date('04-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000622016057, to_date('22-06-2000', 'dd-mm-yyyy'), to_date('06-07-2000', 'dd-mm-yyyy'), 1, 1709, to_date('29-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121230016058, to_date('30-12-2012', 'dd-mm-yyyy'), to_date('13-01-2013', 'dd-mm-yyyy'), 2, 9141, to_date('13-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110426016059, to_date('26-04-2011', 'dd-mm-yyyy'), to_date('10-05-2011', 'dd-mm-yyyy'), 1, 7284, to_date('15-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010311016060, to_date('11-03-2001', 'dd-mm-yyyy'), to_date('25-03-2001', 'dd-mm-yyyy'), 2, 1467, to_date('17-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231010568, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 3, 6404, to_date('10-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110202010569, to_date('02-02-2011', 'dd-mm-yyyy'), to_date('16-02-2011', 'dd-mm-yyyy'), 12, 5745, to_date('06-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723010570, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 7, 8105, to_date('01-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605010571, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 12, 1252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813010572, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 5, 5626, to_date('17-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000414010573, to_date('14-04-2000', 'dd-mm-yyyy'), to_date('28-04-2000', 'dd-mm-yyyy'), 9, 794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110705010574, to_date('05-07-2011', 'dd-mm-yyyy'), to_date('19-07-2011', 'dd-mm-yyyy'), 7, 7960, to_date('17-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091106010575, to_date('06-11-2009', 'dd-mm-yyyy'), to_date('20-11-2009', 'dd-mm-yyyy'), 10, 4664, to_date('14-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021218010576, to_date('18-12-2002', 'dd-mm-yyyy'), to_date('01-01-2003', 'dd-mm-yyyy'), 8, 4604, to_date('20-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815010577, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 9, 3276, to_date('20-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025010578, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 12, 11664, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100108010579, to_date('08-01-2010', 'dd-mm-yyyy'), to_date('22-01-2010', 'dd-mm-yyyy'), 9, 8873, to_date('23-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207010580, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 6, 6232, to_date('11-02-2009', 'dd-mm-yyyy'));
commit;
prompt 11000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100215010581, to_date('15-02-2010', 'dd-mm-yyyy'), to_date('01-03-2010', 'dd-mm-yyyy'), 3, 7164, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120512010582, to_date('12-05-2012', 'dd-mm-yyyy'), to_date('26-05-2012', 'dd-mm-yyyy'), 9, 7581, to_date('14-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121126010583, to_date('26-11-2012', 'dd-mm-yyyy'), to_date('10-12-2012', 'dd-mm-yyyy'), 7, 8166, to_date('11-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091231010584, to_date('31-12-2009', 'dd-mm-yyyy'), to_date('14-01-2010', 'dd-mm-yyyy'), 3, 5210, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130218010585, to_date('18-02-2013', 'dd-mm-yyyy'), to_date('04-03-2013', 'dd-mm-yyyy'), 4, 9179, to_date('24-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130509010586, to_date('09-05-2013', 'dd-mm-yyyy'), to_date('23-05-2013', 'dd-mm-yyyy'), 3, 10521, to_date('19-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080531010587, to_date('31-05-2008', 'dd-mm-yyyy'), to_date('14-06-2008', 'dd-mm-yyyy'), 2, 5811, to_date('07-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040819010588, to_date('19-08-2004', 'dd-mm-yyyy'), to_date('02-09-2004', 'dd-mm-yyyy'), 11, 3778, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806010589, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 2, 3632, to_date('20-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125010590, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 7, 1833, to_date('05-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140223010591, to_date('23-02-2014', 'dd-mm-yyyy'), to_date('09-03-2014', 'dd-mm-yyyy'), 12, 9056, to_date('11-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090706010592, to_date('06-07-2009', 'dd-mm-yyyy'), to_date('20-07-2009', 'dd-mm-yyyy'), 8, 6590, to_date('09-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061204010593, to_date('04-12-2006', 'dd-mm-yyyy'), to_date('18-12-2006', 'dd-mm-yyyy'), 6, 4744, to_date('07-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050605010594, to_date('05-06-2005', 'dd-mm-yyyy'), to_date('19-06-2005', 'dd-mm-yyyy'), 10, 3323, to_date('23-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060428010595, to_date('28-04-2006', 'dd-mm-yyyy'), to_date('12-05-2006', 'dd-mm-yyyy'), 3, 3512, to_date('01-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080218010596, to_date('18-02-2008', 'dd-mm-yyyy'), to_date('03-03-2008', 'dd-mm-yyyy'), 5, 5797, to_date('08-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620010597, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 7, 7043, to_date('08-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001130010598, to_date('30-11-2000', 'dd-mm-yyyy'), to_date('14-12-2000', 'dd-mm-yyyy'), 5, 1081, to_date('08-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090111010599, to_date('11-01-2009', 'dd-mm-yyyy'), to_date('25-01-2009', 'dd-mm-yyyy'), 4, 4700, to_date('28-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131030010600, to_date('30-10-2013', 'dd-mm-yyyy'), to_date('13-11-2013', 'dd-mm-yyyy'), 4, 11026, to_date('03-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070823010601, to_date('23-08-2007', 'dd-mm-yyyy'), to_date('06-09-2007', 'dd-mm-yyyy'), 11, 3125, to_date('10-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010411010602, to_date('11-04-2001', 'dd-mm-yyyy'), to_date('25-04-2001', 'dd-mm-yyyy'), 10, 2346, to_date('14-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020720010603, to_date('20-07-2002', 'dd-mm-yyyy'), to_date('03-08-2002', 'dd-mm-yyyy'), 9, 2765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080601010604, to_date('01-06-2008', 'dd-mm-yyyy'), to_date('15-06-2008', 'dd-mm-yyyy'), 9, 4301, to_date('06-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000514010605, to_date('14-05-2000', 'dd-mm-yyyy'), to_date('28-05-2000', 'dd-mm-yyyy'), 8, 906, to_date('25-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011219010606, to_date('19-12-2001', 'dd-mm-yyyy'), to_date('02-01-2002', 'dd-mm-yyyy'), 2, 3133, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130317010607, to_date('17-03-2013', 'dd-mm-yyyy'), to_date('31-03-2013', 'dd-mm-yyyy'), 10, 8313, to_date('24-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010822010608, to_date('22-08-2001', 'dd-mm-yyyy'), to_date('05-09-2001', 'dd-mm-yyyy'), 8, 1634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010010609, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 3, 7368, to_date('15-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000106010610, to_date('06-01-2000', 'dd-mm-yyyy'), to_date('20-01-2000', 'dd-mm-yyyy'), 3, 780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080205010611, to_date('05-02-2008', 'dd-mm-yyyy'), to_date('19-02-2008', 'dd-mm-yyyy'), 10, 8415, to_date('14-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040820010612, to_date('20-08-2004', 'dd-mm-yyyy'), to_date('03-09-2004', 'dd-mm-yyyy'), 4, 5973, to_date('29-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090416010613, to_date('16-04-2009', 'dd-mm-yyyy'), to_date('30-04-2009', 'dd-mm-yyyy'), 5, 7542, to_date('18-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031113010614, to_date('13-11-2003', 'dd-mm-yyyy'), to_date('27-11-2003', 'dd-mm-yyyy'), 12, 5141, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617010615, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 6, 2713, to_date('02-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004010616, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 10, 8542, to_date('21-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060907010617, to_date('07-09-2006', 'dd-mm-yyyy'), to_date('21-09-2006', 'dd-mm-yyyy'), 4, 5590, to_date('16-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708010618, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 5, 4336, to_date('26-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001126010619, to_date('26-11-2000', 'dd-mm-yyyy'), to_date('10-12-2000', 'dd-mm-yyyy'), 8, 2204, to_date('03-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091103010620, to_date('03-11-2009', 'dd-mm-yyyy'), to_date('17-11-2009', 'dd-mm-yyyy'), 8, 8458, to_date('08-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001103010621, to_date('03-11-2000', 'dd-mm-yyyy'), to_date('17-11-2000', 'dd-mm-yyyy'), 11, 944, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802010622, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 10, 6595, to_date('19-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040825010623, to_date('25-08-2004', 'dd-mm-yyyy'), to_date('08-09-2004', 'dd-mm-yyyy'), 11, 1821, to_date('31-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001010624, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 4, 1391, to_date('04-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010923010625, to_date('23-09-2001', 'dd-mm-yyyy'), to_date('07-10-2001', 'dd-mm-yyyy'), 12, 1305, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050906010626, to_date('06-09-2005', 'dd-mm-yyyy'), to_date('20-09-2005', 'dd-mm-yyyy'), 11, 5038, to_date('25-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304010627, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 8, 1594, to_date('20-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100209010628, to_date('09-02-2010', 'dd-mm-yyyy'), to_date('23-02-2010', 'dd-mm-yyyy'), 4, 6765, to_date('21-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010413010629, to_date('13-04-2001', 'dd-mm-yyyy'), to_date('27-04-2001', 'dd-mm-yyyy'), 3, 3633, to_date('15-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627010630, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 2, 10687, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030127010631, to_date('27-01-2003', 'dd-mm-yyyy'), to_date('10-02-2003', 'dd-mm-yyyy'), 12, 4245, to_date('01-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070301010632, to_date('01-03-2007', 'dd-mm-yyyy'), to_date('15-03-2007', 'dd-mm-yyyy'), 2, 6297, to_date('06-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030323010633, to_date('23-03-2003', 'dd-mm-yyyy'), to_date('06-04-2003', 'dd-mm-yyyy'), 2, 1989, to_date('31-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511010634, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 11, 2810, to_date('12-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120408010635, to_date('08-04-2012', 'dd-mm-yyyy'), to_date('22-04-2012', 'dd-mm-yyyy'), 9, 7463, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131228010636, to_date('28-12-2013', 'dd-mm-yyyy'), to_date('11-01-2014', 'dd-mm-yyyy'), 4, 8879, to_date('11-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130528010637, to_date('28-05-2013', 'dd-mm-yyyy'), to_date('11-06-2013', 'dd-mm-yyyy'), 5, 8479, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130303010638, to_date('03-03-2013', 'dd-mm-yyyy'), to_date('17-03-2013', 'dd-mm-yyyy'), 5, 10358, to_date('22-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120426010639, to_date('26-04-2012', 'dd-mm-yyyy'), to_date('10-05-2012', 'dd-mm-yyyy'), 9, 6887, to_date('11-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110102010640, to_date('02-01-2011', 'dd-mm-yyyy'), to_date('16-01-2011', 'dd-mm-yyyy'), 8, 7568, to_date('10-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060726010641, to_date('26-07-2006', 'dd-mm-yyyy'), to_date('09-08-2006', 'dd-mm-yyyy'), 9, 6256, to_date('01-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000816010642, to_date('16-08-2000', 'dd-mm-yyyy'), to_date('30-08-2000', 'dd-mm-yyyy'), 2, 2788, to_date('04-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060920010643, to_date('20-09-2006', 'dd-mm-yyyy'), to_date('04-10-2006', 'dd-mm-yyyy'), 2, 4592, to_date('28-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140307010644, to_date('07-03-2014', 'dd-mm-yyyy'), to_date('21-03-2014', 'dd-mm-yyyy'), 2, 10213, to_date('22-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070103010645, to_date('03-01-2007', 'dd-mm-yyyy'), to_date('17-01-2007', 'dd-mm-yyyy'), 6, 5530, to_date('04-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919010646, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 2, 7236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714010647, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 3, 8965, to_date('18-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050717010648, to_date('17-07-2005', 'dd-mm-yyyy'), to_date('31-07-2005', 'dd-mm-yyyy'), 7, 5340, to_date('26-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101024010649, to_date('24-10-2010', 'dd-mm-yyyy'), to_date('07-11-2010', 'dd-mm-yyyy'), 4, 6590, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030905010650, to_date('05-09-2003', 'dd-mm-yyyy'), to_date('19-09-2003', 'dd-mm-yyyy'), 9, 3195, to_date('14-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011010651, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 4, 4539, to_date('21-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140412010652, to_date('12-04-2014', 'dd-mm-yyyy'), to_date('26-04-2014', 'dd-mm-yyyy'), 7, 9593, to_date('17-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213010653, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 4, 7842, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120331010654, to_date('31-03-2012', 'dd-mm-yyyy'), to_date('14-04-2012', 'dd-mm-yyyy'), 10, 7578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602010655, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 2, 7107, to_date('20-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000821010656, to_date('21-08-2000', 'dd-mm-yyyy'), to_date('04-09-2000', 'dd-mm-yyyy'), 8, 2721, to_date('25-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050831010657, to_date('31-08-2005', 'dd-mm-yyyy'), to_date('14-09-2005', 'dd-mm-yyyy'), 2, 2899, to_date('14-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070621010658, to_date('21-06-2007', 'dd-mm-yyyy'), to_date('05-07-2007', 'dd-mm-yyyy'), 3, 7900, to_date('26-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020617010659, to_date('17-06-2002', 'dd-mm-yyyy'), to_date('01-07-2002', 'dd-mm-yyyy'), 8, 2756, to_date('28-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417010660, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 6, 3755, to_date('27-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608010661, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 10, 5776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024010662, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 9, 8509, to_date('05-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617010663, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 10, 3266, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090118010664, to_date('18-01-2009', 'dd-mm-yyyy'), to_date('01-02-2009', 'dd-mm-yyyy'), 2, 5553, to_date('26-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050515010665, to_date('15-05-2005', 'dd-mm-yyyy'), to_date('29-05-2005', 'dd-mm-yyyy'), 9, 5153, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131010666, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 10, 3001, to_date('13-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000226010667, to_date('26-02-2000', 'dd-mm-yyyy'), to_date('11-03-2000', 'dd-mm-yyyy'), 5, 2486, to_date('08-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422010668, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 4, 4078, to_date('05-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110617010669, to_date('17-06-2011', 'dd-mm-yyyy'), to_date('01-07-2011', 'dd-mm-yyyy'), 11, 8713, to_date('27-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140505010670, to_date('05-05-2014', 'dd-mm-yyyy'), to_date('19-05-2014', 'dd-mm-yyyy'), 2, 9830, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413010671, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 4, 4129, to_date('15-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110329010672, to_date('29-03-2011', 'dd-mm-yyyy'), to_date('12-04-2011', 'dd-mm-yyyy'), 5, 10118, to_date('09-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101024010673, to_date('24-10-2010', 'dd-mm-yyyy'), to_date('07-11-2010', 'dd-mm-yyyy'), 3, 8497, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105010674, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 11, 7452, to_date('19-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126010675, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 5, 5636, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091009010676, to_date('09-10-2009', 'dd-mm-yyyy'), to_date('23-10-2009', 'dd-mm-yyyy'), 11, 4847, to_date('17-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001217010677, to_date('17-12-2000', 'dd-mm-yyyy'), to_date('31-12-2000', 'dd-mm-yyyy'), 10, 1910, to_date('22-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101121010678, to_date('21-11-2010', 'dd-mm-yyyy'), to_date('05-12-2010', 'dd-mm-yyyy'), 3, 10321, to_date('28-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010502010679, to_date('02-05-2001', 'dd-mm-yyyy'), to_date('16-05-2001', 'dd-mm-yyyy'), 2, 915, to_date('18-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060531010680, to_date('31-05-2006', 'dd-mm-yyyy'), to_date('14-06-2006', 'dd-mm-yyyy'), 3, 4299, to_date('16-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110103010681, to_date('03-01-2011', 'dd-mm-yyyy'), to_date('17-01-2011', 'dd-mm-yyyy'), 2, 6736, to_date('21-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100708010682, to_date('08-07-2010', 'dd-mm-yyyy'), to_date('22-07-2010', 'dd-mm-yyyy'), 8, 6887, to_date('17-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081129010683, to_date('29-11-2008', 'dd-mm-yyyy'), to_date('13-12-2008', 'dd-mm-yyyy'), 3, 4784, to_date('18-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070830010684, to_date('30-08-2007', 'dd-mm-yyyy'), to_date('13-09-2007', 'dd-mm-yyyy'), 2, 6510, to_date('09-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120830010685, to_date('30-08-2012', 'dd-mm-yyyy'), to_date('13-09-2012', 'dd-mm-yyyy'), 6, 8157, to_date('06-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090424010686, to_date('24-04-2009', 'dd-mm-yyyy'), to_date('08-05-2009', 'dd-mm-yyyy'), 4, 8095, to_date('09-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140310010687, to_date('10-03-2014', 'dd-mm-yyyy'), to_date('24-03-2014', 'dd-mm-yyyy'), 10, 8765, to_date('18-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120825010688, to_date('25-08-2012', 'dd-mm-yyyy'), to_date('08-09-2012', 'dd-mm-yyyy'), 7, 7585, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070620010689, to_date('20-06-2007', 'dd-mm-yyyy'), to_date('04-07-2007', 'dd-mm-yyyy'), 3, 6527, to_date('24-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070615010690, to_date('15-06-2007', 'dd-mm-yyyy'), to_date('29-06-2007', 'dd-mm-yyyy'), 4, 5541, to_date('22-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018010691, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 11, 4627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080122010692, to_date('22-01-2008', 'dd-mm-yyyy'), to_date('05-02-2008', 'dd-mm-yyyy'), 9, 6496, to_date('10-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120306010693, to_date('06-03-2012', 'dd-mm-yyyy'), to_date('20-03-2012', 'dd-mm-yyyy'), 3, 7465, to_date('17-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050203010694, to_date('03-02-2005', 'dd-mm-yyyy'), to_date('17-02-2005', 'dd-mm-yyyy'), 2, 4425, to_date('18-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011109010695, to_date('09-11-2001', 'dd-mm-yyyy'), to_date('23-11-2001', 'dd-mm-yyyy'), 11, 2771, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051121010696, to_date('21-11-2005', 'dd-mm-yyyy'), to_date('05-12-2005', 'dd-mm-yyyy'), 12, 3857, to_date('30-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061223010697, to_date('23-12-2006', 'dd-mm-yyyy'), to_date('06-01-2007', 'dd-mm-yyyy'), 12, 6184, to_date('06-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081229010698, to_date('29-12-2008', 'dd-mm-yyyy'), to_date('12-01-2009', 'dd-mm-yyyy'), 10, 7339, to_date('30-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090520010699, to_date('20-05-2009', 'dd-mm-yyyy'), to_date('03-06-2009', 'dd-mm-yyyy'), 7, 9100, to_date('22-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090521010700, to_date('21-05-2009', 'dd-mm-yyyy'), to_date('04-06-2009', 'dd-mm-yyyy'), 1, 6493, to_date('02-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100223010701, to_date('23-02-2010', 'dd-mm-yyyy'), to_date('09-03-2010', 'dd-mm-yyyy'), 5, 7663, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020809010702, to_date('09-08-2002', 'dd-mm-yyyy'), to_date('23-08-2002', 'dd-mm-yyyy'), 9, 3648, to_date('18-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130508010703, to_date('08-05-2013', 'dd-mm-yyyy'), to_date('22-05-2013', 'dd-mm-yyyy'), 6, 9953, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317010704, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 5, 6387, to_date('02-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525010705, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 1, 4927, to_date('28-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031105010706, to_date('05-11-2003', 'dd-mm-yyyy'), to_date('19-11-2003', 'dd-mm-yyyy'), 3, 2369, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513010707, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 9, 4959, to_date('24-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710010708, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 3, 3936, to_date('17-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110717010709, to_date('17-07-2011', 'dd-mm-yyyy'), to_date('31-07-2011', 'dd-mm-yyyy'), 5, 8109, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111105010710, to_date('05-11-2011', 'dd-mm-yyyy'), to_date('19-11-2011', 'dd-mm-yyyy'), 11, 7110, to_date('22-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111129010711, to_date('29-11-2011', 'dd-mm-yyyy'), to_date('13-12-2011', 'dd-mm-yyyy'), 9, 7224, to_date('14-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100420010712, to_date('20-04-2010', 'dd-mm-yyyy'), to_date('04-05-2010', 'dd-mm-yyyy'), 4, 7867, to_date('04-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302010713, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 4, 1464, to_date('06-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716010714, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 1, 6458, to_date('31-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100518010715, to_date('18-05-2010', 'dd-mm-yyyy'), to_date('01-06-2010', 'dd-mm-yyyy'), 5, 9526, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000904010716, to_date('04-09-2000', 'dd-mm-yyyy'), to_date('18-09-2000', 'dd-mm-yyyy'), 3, 951, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030626010717, to_date('26-06-2003', 'dd-mm-yyyy'), to_date('10-07-2003', 'dd-mm-yyyy'), 6, 7171, to_date('11-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050108010718, to_date('08-01-2005', 'dd-mm-yyyy'), to_date('22-01-2005', 'dd-mm-yyyy'), 11, 5038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050301010719, to_date('01-03-2005', 'dd-mm-yyyy'), to_date('15-03-2005', 'dd-mm-yyyy'), 4, 5820, to_date('16-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927013369, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 4, 4845, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010715013370, to_date('15-07-2001', 'dd-mm-yyyy'), to_date('29-07-2001', 'dd-mm-yyyy'), 4, 3010, to_date('18-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030906013371, to_date('06-09-2003', 'dd-mm-yyyy'), to_date('20-09-2003', 'dd-mm-yyyy'), 3, 2768, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031105013372, to_date('05-11-2003', 'dd-mm-yyyy'), to_date('19-11-2003', 'dd-mm-yyyy'), 4, 1165, to_date('20-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081014013373, to_date('14-10-2008', 'dd-mm-yyyy'), to_date('28-10-2008', 'dd-mm-yyyy'), 1, 5271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725013374, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 1, 8435, to_date('28-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020130013375, to_date('30-01-2002', 'dd-mm-yyyy'), to_date('13-02-2002', 'dd-mm-yyyy'), 3, 3266, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110123013376, to_date('23-01-2011', 'dd-mm-yyyy'), to_date('06-02-2011', 'dd-mm-yyyy'), 3, 9632, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008013377, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 3, 3399, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010613013378, to_date('13-06-2001', 'dd-mm-yyyy'), to_date('27-06-2001', 'dd-mm-yyyy'), 1, 2332, to_date('26-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020313013379, to_date('13-03-2002', 'dd-mm-yyyy'), to_date('27-03-2002', 'dd-mm-yyyy'), 2, 3160, to_date('30-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100317013380, to_date('17-03-2010', 'dd-mm-yyyy'), to_date('31-03-2010', 'dd-mm-yyyy'), 4, 7004, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001121013381, to_date('21-11-2000', 'dd-mm-yyyy'), to_date('05-12-2000', 'dd-mm-yyyy'), 3, 2874, to_date('08-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061224013382, to_date('24-12-2006', 'dd-mm-yyyy'), to_date('07-01-2007', 'dd-mm-yyyy'), 2, 4400, to_date('02-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021015013383, to_date('15-10-2002', 'dd-mm-yyyy'), to_date('29-10-2002', 'dd-mm-yyyy'), 1, 1717, to_date('18-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140212013384, to_date('12-02-2014', 'dd-mm-yyyy'), to_date('26-02-2014', 'dd-mm-yyyy'), 4, 9522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100614013385, to_date('14-06-2010', 'dd-mm-yyyy'), to_date('28-06-2010', 'dd-mm-yyyy'), 2, 9756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110311013386, to_date('11-03-2011', 'dd-mm-yyyy'), to_date('25-03-2011', 'dd-mm-yyyy'), 1, 6519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050417013387, to_date('17-04-2005', 'dd-mm-yyyy'), to_date('01-05-2005', 'dd-mm-yyyy'), 3, 6289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070422013388, to_date('22-04-2007', 'dd-mm-yyyy'), to_date('06-05-2007', 'dd-mm-yyyy'), 2, 6545, to_date('04-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060814013389, to_date('14-08-2006', 'dd-mm-yyyy'), to_date('28-08-2006', 'dd-mm-yyyy'), 3, 6966, to_date('22-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202013390, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 3, 5005, to_date('10-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906013391, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 2, 7474, to_date('11-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010930013392, to_date('30-09-2001', 'dd-mm-yyyy'), to_date('14-10-2001', 'dd-mm-yyyy'), 1, 1106, to_date('05-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130416013393, to_date('16-04-2013', 'dd-mm-yyyy'), to_date('30-04-2013', 'dd-mm-yyyy'), 3, 11186, to_date('26-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120126013394, to_date('26-01-2012', 'dd-mm-yyyy'), to_date('09-02-2012', 'dd-mm-yyyy'), 1, 6716, to_date('12-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926013395, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 4, 646, to_date('29-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060129013396, to_date('29-01-2006', 'dd-mm-yyyy'), to_date('12-02-2006', 'dd-mm-yyyy'), 4, 5179, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011210013397, to_date('10-12-2001', 'dd-mm-yyyy'), to_date('24-12-2001', 'dd-mm-yyyy'), 3, 3184, to_date('17-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070213013398, to_date('13-02-2007', 'dd-mm-yyyy'), to_date('27-02-2007', 'dd-mm-yyyy'), 3, 4229, to_date('28-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080623013399, to_date('23-06-2008', 'dd-mm-yyyy'), to_date('07-07-2008', 'dd-mm-yyyy'), 3, 7074, to_date('05-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120828013400, to_date('28-08-2012', 'dd-mm-yyyy'), to_date('11-09-2012', 'dd-mm-yyyy'), 3, 7610, to_date('05-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100318013401, to_date('18-03-2010', 'dd-mm-yyyy'), to_date('01-04-2010', 'dd-mm-yyyy'), 4, 8165, to_date('04-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041201013402, to_date('01-12-2004', 'dd-mm-yyyy'), to_date('15-12-2004', 'dd-mm-yyyy'), 3, 4014, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603013403, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 1, 2806, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040607013404, to_date('07-06-2004', 'dd-mm-yyyy'), to_date('21-06-2004', 'dd-mm-yyyy'), 2, 3681, to_date('20-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100728013405, to_date('28-07-2010', 'dd-mm-yyyy'), to_date('11-08-2010', 'dd-mm-yyyy'), 3, 6409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031114013406, to_date('14-11-2003', 'dd-mm-yyyy'), to_date('28-11-2003', 'dd-mm-yyyy'), 2, 3429, to_date('28-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071231013407, to_date('31-12-2007', 'dd-mm-yyyy'), to_date('14-01-2008', 'dd-mm-yyyy'), 1, 5870, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110224013408, to_date('24-02-2011', 'dd-mm-yyyy'), to_date('10-03-2011', 'dd-mm-yyyy'), 2, 8188, to_date('07-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011216013409, to_date('16-12-2001', 'dd-mm-yyyy'), to_date('30-12-2001', 'dd-mm-yyyy'), 3, 2197, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224013410, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 2, 6193, to_date('06-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728013411, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 3, 7061, to_date('16-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006013412, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 3, 7292, to_date('23-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020905013413, to_date('05-09-2002', 'dd-mm-yyyy'), to_date('19-09-2002', 'dd-mm-yyyy'), 3, 1060, to_date('15-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090105013414, to_date('05-01-2009', 'dd-mm-yyyy'), to_date('19-01-2009', 'dd-mm-yyyy'), 3, 7535, to_date('11-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020806013415, to_date('06-08-2002', 'dd-mm-yyyy'), to_date('20-08-2002', 'dd-mm-yyyy'), 3, 4648, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080414013416, to_date('14-04-2008', 'dd-mm-yyyy'), to_date('28-04-2008', 'dd-mm-yyyy'), 1, 8857, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130307013417, to_date('07-03-2013', 'dd-mm-yyyy'), to_date('21-03-2013', 'dd-mm-yyyy'), 4, 10297, to_date('22-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070527013418, to_date('27-05-2007', 'dd-mm-yyyy'), to_date('10-06-2007', 'dd-mm-yyyy'), 1, 3626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201013419, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 3, 2270, to_date('11-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051220013420, to_date('20-12-2005', 'dd-mm-yyyy'), to_date('03-01-2006', 'dd-mm-yyyy'), 3, 5875, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100428013421, to_date('28-04-2010', 'dd-mm-yyyy'), to_date('12-05-2010', 'dd-mm-yyyy'), 1, 5508, to_date('08-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010728013422, to_date('28-07-2001', 'dd-mm-yyyy'), to_date('11-08-2001', 'dd-mm-yyyy'), 2, 2163, to_date('29-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817013423, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 1, 9972, to_date('27-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602013424, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 4, 6106, to_date('19-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010823013425, to_date('23-08-2001', 'dd-mm-yyyy'), to_date('06-09-2001', 'dd-mm-yyyy'), 1, 1076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080617013426, to_date('17-06-2008', 'dd-mm-yyyy'), to_date('01-07-2008', 'dd-mm-yyyy'), 4, 7445, to_date('03-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120609013427, to_date('09-06-2012', 'dd-mm-yyyy'), to_date('23-06-2012', 'dd-mm-yyyy'), 1, 8644, to_date('14-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030705013428, to_date('05-07-2003', 'dd-mm-yyyy'), to_date('19-07-2003', 'dd-mm-yyyy'), 2, 4286, to_date('14-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011211013429, to_date('11-12-2001', 'dd-mm-yyyy'), to_date('25-12-2001', 'dd-mm-yyyy'), 2, 3819, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070514013430, to_date('14-05-2007', 'dd-mm-yyyy'), to_date('28-05-2007', 'dd-mm-yyyy'), 1, 3702, to_date('17-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060204013431, to_date('04-02-2006', 'dd-mm-yyyy'), to_date('18-02-2006', 'dd-mm-yyyy'), 4, 5754, to_date('06-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050215013432, to_date('15-02-2005', 'dd-mm-yyyy'), to_date('01-03-2005', 'dd-mm-yyyy'), 4, 3695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090211013433, to_date('11-02-2009', 'dd-mm-yyyy'), to_date('25-02-2009', 'dd-mm-yyyy'), 4, 7346, to_date('22-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513013434, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 3, 3980, to_date('30-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040508013435, to_date('08-05-2004', 'dd-mm-yyyy'), to_date('22-05-2004', 'dd-mm-yyyy'), 1, 5884, to_date('10-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080518013436, to_date('18-05-2008', 'dd-mm-yyyy'), to_date('01-06-2008', 'dd-mm-yyyy'), 2, 4286, to_date('26-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226013437, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 3, 1360, to_date('30-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826013438, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 4, 7920, to_date('14-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060407013439, to_date('07-04-2006', 'dd-mm-yyyy'), to_date('21-04-2006', 'dd-mm-yyyy'), 3, 5013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411013440, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 1, 3021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130204013441, to_date('04-02-2013', 'dd-mm-yyyy'), to_date('18-02-2013', 'dd-mm-yyyy'), 1, 7349, to_date('20-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011012013442, to_date('12-10-2001', 'dd-mm-yyyy'), to_date('26-10-2001', 'dd-mm-yyyy'), 2, 3011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110609013443, to_date('09-06-2011', 'dd-mm-yyyy'), to_date('23-06-2011', 'dd-mm-yyyy'), 3, 5944, to_date('25-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060714013444, to_date('14-07-2006', 'dd-mm-yyyy'), to_date('28-07-2006', 'dd-mm-yyyy'), 2, 5510, to_date('31-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061003013445, to_date('03-10-2006', 'dd-mm-yyyy'), to_date('17-10-2006', 'dd-mm-yyyy'), 3, 4059, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926013446, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 4, 4706, to_date('15-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140105013447, to_date('05-01-2014', 'dd-mm-yyyy'), to_date('19-01-2014', 'dd-mm-yyyy'), 1, 8171, to_date('25-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130625013448, to_date('25-06-2013', 'dd-mm-yyyy'), to_date('09-07-2013', 'dd-mm-yyyy'), 4, 7608, to_date('04-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051003013449, to_date('03-10-2005', 'dd-mm-yyyy'), to_date('17-10-2005', 'dd-mm-yyyy'), 3, 4588, to_date('06-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070807013450, to_date('07-08-2007', 'dd-mm-yyyy'), to_date('21-08-2007', 'dd-mm-yyyy'), 3, 6172, to_date('27-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801013451, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 2, 11788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205013452, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 4, 3337, to_date('18-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020219013453, to_date('19-02-2002', 'dd-mm-yyyy'), to_date('05-03-2002', 'dd-mm-yyyy'), 3, 3377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125013454, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 2, 6480, to_date('13-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031105013455, to_date('05-11-2003', 'dd-mm-yyyy'), to_date('19-11-2003', 'dd-mm-yyyy'), 1, 2594, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021227013456, to_date('27-12-2002', 'dd-mm-yyyy'), to_date('10-01-2003', 'dd-mm-yyyy'), 3, 3689, to_date('10-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071103013457, to_date('03-11-2007', 'dd-mm-yyyy'), to_date('17-11-2007', 'dd-mm-yyyy'), 4, 7876, to_date('05-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090528013458, to_date('28-05-2009', 'dd-mm-yyyy'), to_date('11-06-2009', 'dd-mm-yyyy'), 2, 7268, to_date('11-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091225013459, to_date('25-12-2009', 'dd-mm-yyyy'), to_date('08-01-2010', 'dd-mm-yyyy'), 3, 7023, to_date('30-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101106013460, to_date('06-11-2010', 'dd-mm-yyyy'), to_date('20-11-2010', 'dd-mm-yyyy'), 2, 6576, to_date('13-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140104013461, to_date('04-01-2014', 'dd-mm-yyyy'), to_date('18-01-2014', 'dd-mm-yyyy'), 3, 7942, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140317013462, to_date('17-03-2014', 'dd-mm-yyyy'), to_date('31-03-2014', 'dd-mm-yyyy'), 2, 7938, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060526013463, to_date('26-05-2006', 'dd-mm-yyyy'), to_date('09-06-2006', 'dd-mm-yyyy'), 1, 5838, to_date('30-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040411013464, to_date('11-04-2004', 'dd-mm-yyyy'), to_date('25-04-2004', 'dd-mm-yyyy'), 1, 2483, to_date('25-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050131013465, to_date('31-01-2005', 'dd-mm-yyyy'), to_date('14-02-2005', 'dd-mm-yyyy'), 3, 5796, to_date('08-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050728013466, to_date('28-07-2005', 'dd-mm-yyyy'), to_date('11-08-2005', 'dd-mm-yyyy'), 3, 3896, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110907013467, to_date('07-09-2011', 'dd-mm-yyyy'), to_date('21-09-2011', 'dd-mm-yyyy'), 2, 8320, to_date('26-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227013468, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 2, 9816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031129013469, to_date('29-11-2003', 'dd-mm-yyyy'), to_date('13-12-2003', 'dd-mm-yyyy'), 2, 3489, to_date('06-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021110013470, to_date('10-11-2002', 'dd-mm-yyyy'), to_date('24-11-2002', 'dd-mm-yyyy'), 3, 2374, to_date('16-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120929013471, to_date('29-09-2012', 'dd-mm-yyyy'), to_date('13-10-2012', 'dd-mm-yyyy'), 3, 9350, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121018013472, to_date('18-10-2012', 'dd-mm-yyyy'), to_date('01-11-2012', 'dd-mm-yyyy'), 3, 8150, to_date('28-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329013473, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 2, 5433, to_date('10-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120112013474, to_date('12-01-2012', 'dd-mm-yyyy'), to_date('26-01-2012', 'dd-mm-yyyy'), 2, 7581, to_date('25-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011013475, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 4, 924, to_date('30-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110329013476, to_date('29-03-2011', 'dd-mm-yyyy'), to_date('12-04-2011', 'dd-mm-yyyy'), 2, 9296, to_date('11-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060630013477, to_date('30-06-2006', 'dd-mm-yyyy'), to_date('14-07-2006', 'dd-mm-yyyy'), 3, 5756, to_date('02-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060203013478, to_date('03-02-2006', 'dd-mm-yyyy'), to_date('17-02-2006', 'dd-mm-yyyy'), 3, 6588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120716013479, to_date('16-07-2012', 'dd-mm-yyyy'), to_date('30-07-2012', 'dd-mm-yyyy'), 3, 5000, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117013480, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 3, 8733, to_date('22-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040515013481, to_date('15-05-2004', 'dd-mm-yyyy'), to_date('29-05-2004', 'dd-mm-yyyy'), 1, 4360, to_date('01-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060802013482, to_date('02-08-2006', 'dd-mm-yyyy'), to_date('16-08-2006', 'dd-mm-yyyy'), 4, 6434, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010107013483, to_date('07-01-2001', 'dd-mm-yyyy'), to_date('21-01-2001', 'dd-mm-yyyy'), 1, 1865, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131106013484, to_date('06-11-2013', 'dd-mm-yyyy'), to_date('20-11-2013', 'dd-mm-yyyy'), 2, 6436, to_date('26-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000305013485, to_date('05-03-2000', 'dd-mm-yyyy'), to_date('19-03-2000', 'dd-mm-yyyy'), 4, 2198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020622013486, to_date('22-06-2002', 'dd-mm-yyyy'), to_date('06-07-2002', 'dd-mm-yyyy'), 4, 2921, to_date('04-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050410013487, to_date('10-04-2005', 'dd-mm-yyyy'), to_date('24-04-2005', 'dd-mm-yyyy'), 3, 4321, to_date('28-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010901013488, to_date('01-09-2001', 'dd-mm-yyyy'), to_date('15-09-2001', 'dd-mm-yyyy'), 1, 2020, to_date('13-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060804013489, to_date('04-08-2006', 'dd-mm-yyyy'), to_date('18-08-2006', 'dd-mm-yyyy'), 3, 4029, to_date('23-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090922013490, to_date('22-09-2009', 'dd-mm-yyyy'), to_date('06-10-2009', 'dd-mm-yyyy'), 4, 5746, to_date('11-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100824013491, to_date('24-08-2010', 'dd-mm-yyyy'), to_date('07-09-2010', 'dd-mm-yyyy'), 4, 6412, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130819013492, to_date('19-08-2013', 'dd-mm-yyyy'), to_date('02-09-2013', 'dd-mm-yyyy'), 3, 8579, to_date('06-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911013493, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 1, 7213, to_date('23-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110920013494, to_date('20-09-2011', 'dd-mm-yyyy'), to_date('04-10-2011', 'dd-mm-yyyy'), 3, 10036, to_date('06-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000514013495, to_date('14-05-2000', 'dd-mm-yyyy'), to_date('28-05-2000', 'dd-mm-yyyy'), 3, 2400, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001006013496, to_date('06-10-2000', 'dd-mm-yyyy'), to_date('20-10-2000', 'dd-mm-yyyy'), 2, 1976, to_date('10-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080531013497, to_date('31-05-2008', 'dd-mm-yyyy'), to_date('14-06-2008', 'dd-mm-yyyy'), 2, 6130, to_date('09-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519013498, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 3, 7504, to_date('26-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111013499, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 3, 4421, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041019013500, to_date('19-10-2004', 'dd-mm-yyyy'), to_date('02-11-2004', 'dd-mm-yyyy'), 4, 2682, to_date('04-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728013501, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 3, 6385, to_date('01-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000326013502, to_date('26-03-2000', 'dd-mm-yyyy'), to_date('09-04-2000', 'dd-mm-yyyy'), 3, 1235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070622013503, to_date('22-06-2007', 'dd-mm-yyyy'), to_date('06-07-2007', 'dd-mm-yyyy'), 3, 5600, to_date('01-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080117013504, to_date('17-01-2008', 'dd-mm-yyyy'), to_date('31-01-2008', 'dd-mm-yyyy'), 2, 3245, to_date('27-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061213013505, to_date('13-12-2006', 'dd-mm-yyyy'), to_date('27-12-2006', 'dd-mm-yyyy'), 3, 3452, to_date('22-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041128013506, to_date('28-11-2004', 'dd-mm-yyyy'), to_date('12-12-2004', 'dd-mm-yyyy'), 2, 4153, to_date('10-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100728013507, to_date('28-07-2010', 'dd-mm-yyyy'), to_date('11-08-2010', 'dd-mm-yyyy'), 3, 9659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060325013508, to_date('25-03-2006', 'dd-mm-yyyy'), to_date('08-04-2006', 'dd-mm-yyyy'), 1, 5286, to_date('09-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100225013509, to_date('25-02-2010', 'dd-mm-yyyy'), to_date('11-03-2010', 'dd-mm-yyyy'), 2, 4999, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030901013510, to_date('01-09-2003', 'dd-mm-yyyy'), to_date('15-09-2003', 'dd-mm-yyyy'), 1, 3702, to_date('06-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010829013511, to_date('29-08-2001', 'dd-mm-yyyy'), to_date('12-09-2001', 'dd-mm-yyyy'), 3, 1668, to_date('03-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090324013512, to_date('24-03-2009', 'dd-mm-yyyy'), to_date('07-04-2009', 'dd-mm-yyyy'), 3, 5877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120724013513, to_date('24-07-2012', 'dd-mm-yyyy'), to_date('07-08-2012', 'dd-mm-yyyy'), 1, 7810, to_date('12-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051128013514, to_date('28-11-2005', 'dd-mm-yyyy'), to_date('12-12-2005', 'dd-mm-yyyy'), 2, 2799, to_date('05-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120117013515, to_date('17-01-2012', 'dd-mm-yyyy'), to_date('31-01-2012', 'dd-mm-yyyy'), 4, 7808, to_date('20-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030627013516, to_date('27-06-2003', 'dd-mm-yyyy'), to_date('11-07-2003', 'dd-mm-yyyy'), 1, 2899, to_date('11-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040419013517, to_date('19-04-2004', 'dd-mm-yyyy'), to_date('03-05-2004', 'dd-mm-yyyy'), 2, 3067, to_date('23-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060826013518, to_date('26-08-2006', 'dd-mm-yyyy'), to_date('09-09-2006', 'dd-mm-yyyy'), 3, 6459, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110627013519, to_date('27-06-2011', 'dd-mm-yyyy'), to_date('11-07-2011', 'dd-mm-yyyy'), 3, 6850, to_date('05-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050430013520, to_date('30-04-2005', 'dd-mm-yyyy'), to_date('14-05-2005', 'dd-mm-yyyy'), 2, 5788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040526013521, to_date('26-05-2004', 'dd-mm-yyyy'), to_date('09-06-2004', 'dd-mm-yyyy'), 2, 2855, to_date('03-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090525013522, to_date('25-05-2009', 'dd-mm-yyyy'), to_date('08-06-2009', 'dd-mm-yyyy'), 1, 6060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121019013523, to_date('19-10-2012', 'dd-mm-yyyy'), to_date('02-11-2012', 'dd-mm-yyyy'), 4, 6249, to_date('26-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110209013524, to_date('09-02-2011', 'dd-mm-yyyy'), to_date('23-02-2011', 'dd-mm-yyyy'), 2, 8236, to_date('24-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140331013525, to_date('31-03-2014', 'dd-mm-yyyy'), to_date('14-04-2014', 'dd-mm-yyyy'), 2, 8518, to_date('16-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921013526, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 3, 8562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070602013527, to_date('02-06-2007', 'dd-mm-yyyy'), to_date('16-06-2007', 'dd-mm-yyyy'), 3, 5528, to_date('21-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080529013528, to_date('29-05-2008', 'dd-mm-yyyy'), to_date('12-06-2008', 'dd-mm-yyyy'), 2, 5749, to_date('16-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030422013529, to_date('22-04-2003', 'dd-mm-yyyy'), to_date('06-05-2003', 'dd-mm-yyyy'), 3, 4062, to_date('12-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010908013530, to_date('08-09-2001', 'dd-mm-yyyy'), to_date('22-09-2001', 'dd-mm-yyyy'), 3, 1758, to_date('09-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212013531, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 4, 2245, to_date('15-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051001013532, to_date('01-10-2005', 'dd-mm-yyyy'), to_date('15-10-2005', 'dd-mm-yyyy'), 3, 5825, to_date('12-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228013533, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 3, 2878, to_date('13-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602013534, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 3, 6510, to_date('07-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050208013535, to_date('08-02-2005', 'dd-mm-yyyy'), to_date('22-02-2005', 'dd-mm-yyyy'), 3, 6031, to_date('12-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021129013536, to_date('29-11-2002', 'dd-mm-yyyy'), to_date('13-12-2002', 'dd-mm-yyyy'), 1, 3925, to_date('06-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120524016061, to_date('24-05-2012', 'dd-mm-yyyy'), to_date('07-06-2012', 'dd-mm-yyyy'), 2, 9089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000308016062, to_date('08-03-2000', 'dd-mm-yyyy'), to_date('22-03-2000', 'dd-mm-yyyy'), 1, 1176, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070803016063, to_date('03-08-2007', 'dd-mm-yyyy'), to_date('17-08-2007', 'dd-mm-yyyy'), 1, 6737, to_date('08-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521016064, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 2, 4637, to_date('03-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071115016065, to_date('15-11-2007', 'dd-mm-yyyy'), to_date('29-11-2007', 'dd-mm-yyyy'), 1, 5442, to_date('18-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050326016066, to_date('26-03-2005', 'dd-mm-yyyy'), to_date('09-04-2005', 'dd-mm-yyyy'), 2, 5374, to_date('31-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124016067, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 1, 7293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021004016068, to_date('04-10-2002', 'dd-mm-yyyy'), to_date('18-10-2002', 'dd-mm-yyyy'), 2, 3105, to_date('19-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317016069, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 2, 5542, to_date('20-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030714016070, to_date('14-07-2003', 'dd-mm-yyyy'), to_date('28-07-2003', 'dd-mm-yyyy'), 2, 2896, to_date('19-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020928016071, to_date('28-09-2002', 'dd-mm-yyyy'), to_date('12-10-2002', 'dd-mm-yyyy'), 2, 1701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029016072, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 1, 4808, to_date('15-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081226016073, to_date('26-12-2008', 'dd-mm-yyyy'), to_date('09-01-2009', 'dd-mm-yyyy'), 2, 5108, to_date('03-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070227016074, to_date('27-02-2007', 'dd-mm-yyyy'), to_date('13-03-2007', 'dd-mm-yyyy'), 2, 6476, to_date('04-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080305016075, to_date('05-03-2008', 'dd-mm-yyyy'), to_date('19-03-2008', 'dd-mm-yyyy'), 2, 6204, to_date('11-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110615016076, to_date('15-06-2011', 'dd-mm-yyyy'), to_date('29-06-2011', 'dd-mm-yyyy'), 1, 10094, to_date('27-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050208016077, to_date('08-02-2005', 'dd-mm-yyyy'), to_date('22-02-2005', 'dd-mm-yyyy'), 2, 4778, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030313016078, to_date('13-03-2003', 'dd-mm-yyyy'), to_date('27-03-2003', 'dd-mm-yyyy'), 2, 3614, to_date('30-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060205016079, to_date('05-02-2006', 'dd-mm-yyyy'), to_date('19-02-2006', 'dd-mm-yyyy'), 2, 5323, to_date('10-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000420016080, to_date('20-04-2000', 'dd-mm-yyyy'), to_date('04-05-2000', 'dd-mm-yyyy'), 2, 618, to_date('01-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020609016081, to_date('09-06-2002', 'dd-mm-yyyy'), to_date('23-06-2002', 'dd-mm-yyyy'), 1, 2817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090530016082, to_date('30-05-2009', 'dd-mm-yyyy'), to_date('13-06-2009', 'dd-mm-yyyy'), 1, 6329, to_date('10-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130214016083, to_date('14-02-2013', 'dd-mm-yyyy'), to_date('28-02-2013', 'dd-mm-yyyy'), 2, 7520, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130318016084, to_date('18-03-2013', 'dd-mm-yyyy'), to_date('01-04-2013', 'dd-mm-yyyy'), 1, 7064, to_date('27-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130206016085, to_date('06-02-2013', 'dd-mm-yyyy'), to_date('20-02-2013', 'dd-mm-yyyy'), 1, 9146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090412016086, to_date('12-04-2009', 'dd-mm-yyyy'), to_date('26-04-2009', 'dd-mm-yyyy'), 2, 6231, to_date('20-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130516016087, to_date('16-05-2013', 'dd-mm-yyyy'), to_date('30-05-2013', 'dd-mm-yyyy'), 1, 8289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101008016088, to_date('08-10-2010', 'dd-mm-yyyy'), to_date('22-10-2010', 'dd-mm-yyyy'), 1, 8437, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000807016089, to_date('07-08-2000', 'dd-mm-yyyy'), to_date('21-08-2000', 'dd-mm-yyyy'), 1, 3610, to_date('16-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080427016090, to_date('27-04-2008', 'dd-mm-yyyy'), to_date('11-05-2008', 'dd-mm-yyyy'), 2, 4726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090819016091, to_date('19-08-2009', 'dd-mm-yyyy'), to_date('02-09-2009', 'dd-mm-yyyy'), 1, 6174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001127016092, to_date('27-11-2000', 'dd-mm-yyyy'), to_date('11-12-2000', 'dd-mm-yyyy'), 1, 2491, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110522016093, to_date('22-05-2011', 'dd-mm-yyyy'), to_date('05-06-2011', 'dd-mm-yyyy'), 1, 7417, to_date('08-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090214016094, to_date('14-02-2009', 'dd-mm-yyyy'), to_date('28-02-2009', 'dd-mm-yyyy'), 2, 6020, to_date('04-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020916016095, to_date('16-09-2002', 'dd-mm-yyyy'), to_date('30-09-2002', 'dd-mm-yyyy'), 2, 3140, to_date('22-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315016096, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 1, 6026, to_date('30-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001212016097, to_date('12-12-2000', 'dd-mm-yyyy'), to_date('26-12-2000', 'dd-mm-yyyy'), 2, 778, to_date('26-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071112016098, to_date('12-11-2007', 'dd-mm-yyyy'), to_date('26-11-2007', 'dd-mm-yyyy'), 2, 4711, to_date('25-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021112016099, to_date('12-11-2002', 'dd-mm-yyyy'), to_date('26-11-2002', 'dd-mm-yyyy'), 1, 3199, to_date('27-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100421016100, to_date('21-04-2010', 'dd-mm-yyyy'), to_date('05-05-2010', 'dd-mm-yyyy'), 2, 10498, to_date('04-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050705016101, to_date('05-07-2005', 'dd-mm-yyyy'), to_date('19-07-2005', 'dd-mm-yyyy'), 2, 3911, to_date('21-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001125016102, to_date('25-11-2000', 'dd-mm-yyyy'), to_date('09-12-2000', 'dd-mm-yyyy'), 2, 1031, to_date('03-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050328016103, to_date('28-03-2005', 'dd-mm-yyyy'), to_date('11-04-2005', 'dd-mm-yyyy'), 2, 3793, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110806016104, to_date('06-08-2011', 'dd-mm-yyyy'), to_date('20-08-2011', 'dd-mm-yyyy'), 1, 9235, to_date('21-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006016105, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 2, 6071, to_date('10-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118016106, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 2, 1178, to_date('24-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000725016107, to_date('25-07-2000', 'dd-mm-yyyy'), to_date('08-08-2000', 'dd-mm-yyyy'), 1, 470, to_date('28-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140322016108, to_date('22-03-2014', 'dd-mm-yyyy'), to_date('05-04-2014', 'dd-mm-yyyy'), 1, 11437, to_date('29-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711016109, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 1, 10993, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040201016110, to_date('01-02-2004', 'dd-mm-yyyy'), to_date('15-02-2004', 'dd-mm-yyyy'), 2, 5607, to_date('02-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130522016111, to_date('22-05-2013', 'dd-mm-yyyy'), to_date('05-06-2013', 'dd-mm-yyyy'), 2, 8980, to_date('28-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010421016112, to_date('21-04-2001', 'dd-mm-yyyy'), to_date('05-05-2001', 'dd-mm-yyyy'), 2, 1247, to_date('28-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206016113, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 2, 5616, to_date('08-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227016114, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 1, 3790, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070626016115, to_date('26-06-2007', 'dd-mm-yyyy'), to_date('10-07-2007', 'dd-mm-yyyy'), 2, 6199, to_date('03-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205016116, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 2, 4854, to_date('13-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000209016117, to_date('09-02-2000', 'dd-mm-yyyy'), to_date('23-02-2000', 'dd-mm-yyyy'), 2, 1131, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050306016118, to_date('06-03-2005', 'dd-mm-yyyy'), to_date('20-03-2005', 'dd-mm-yyyy'), 1, 4792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080616016119, to_date('16-06-2008', 'dd-mm-yyyy'), to_date('30-06-2008', 'dd-mm-yyyy'), 1, 6406, to_date('19-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140320016120, to_date('20-03-2014', 'dd-mm-yyyy'), to_date('03-04-2014', 'dd-mm-yyyy'), 2, 10858, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020226016121, to_date('26-02-2002', 'dd-mm-yyyy'), to_date('12-03-2002', 'dd-mm-yyyy'), 1, 4168, to_date('05-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030824016122, to_date('24-08-2003', 'dd-mm-yyyy'), to_date('07-09-2003', 'dd-mm-yyyy'), 2, 1750, to_date('31-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080128016123, to_date('28-01-2008', 'dd-mm-yyyy'), to_date('11-02-2008', 'dd-mm-yyyy'), 1, 6555, to_date('05-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100507016124, to_date('07-05-2010', 'dd-mm-yyyy'), to_date('21-05-2010', 'dd-mm-yyyy'), 1, 5050, to_date('27-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101009016125, to_date('09-10-2010', 'dd-mm-yyyy'), to_date('23-10-2010', 'dd-mm-yyyy'), 2, 7274, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510016126, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 1, 2694, to_date('14-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031116016127, to_date('16-11-2003', 'dd-mm-yyyy'), to_date('30-11-2003', 'dd-mm-yyyy'), 2, 2656, to_date('05-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110926016128, to_date('26-09-2011', 'dd-mm-yyyy'), to_date('10-10-2011', 'dd-mm-yyyy'), 1, 8101, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011231016129, to_date('31-12-2001', 'dd-mm-yyyy'), to_date('14-01-2002', 'dd-mm-yyyy'), 1, 1804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080112016130, to_date('12-01-2008', 'dd-mm-yyyy'), to_date('26-01-2008', 'dd-mm-yyyy'), 2, 5305, to_date('30-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070614016131, to_date('14-06-2007', 'dd-mm-yyyy'), to_date('28-06-2007', 'dd-mm-yyyy'), 2, 4623, to_date('24-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140423016132, to_date('23-04-2014', 'dd-mm-yyyy'), to_date('07-05-2014', 'dd-mm-yyyy'), 1, 6499, to_date('12-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120329016133, to_date('29-03-2012', 'dd-mm-yyyy'), to_date('12-04-2012', 'dd-mm-yyyy'), 1, 6553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111106016134, to_date('06-11-2011', 'dd-mm-yyyy'), to_date('20-11-2011', 'dd-mm-yyyy'), 1, 7626, to_date('24-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111016135, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 2, 2913, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090919016136, to_date('19-09-2009', 'dd-mm-yyyy'), to_date('03-10-2009', 'dd-mm-yyyy'), 1, 9511, to_date('23-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080319016137, to_date('19-03-2008', 'dd-mm-yyyy'), to_date('02-04-2008', 'dd-mm-yyyy'), 2, 6178, to_date('24-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011010016138, to_date('10-10-2001', 'dd-mm-yyyy'), to_date('24-10-2001', 'dd-mm-yyyy'), 2, 1781, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090409016139, to_date('09-04-2009', 'dd-mm-yyyy'), to_date('23-04-2009', 'dd-mm-yyyy'), 2, 5926, to_date('17-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070413016140, to_date('13-04-2007', 'dd-mm-yyyy'), to_date('27-04-2007', 'dd-mm-yyyy'), 2, 7377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050925016141, to_date('25-09-2005', 'dd-mm-yyyy'), to_date('09-10-2005', 'dd-mm-yyyy'), 2, 3466, to_date('14-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110605016142, to_date('05-06-2011', 'dd-mm-yyyy'), to_date('19-06-2011', 'dd-mm-yyyy'), 1, 6460, to_date('09-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010825016143, to_date('25-08-2001', 'dd-mm-yyyy'), to_date('08-09-2001', 'dd-mm-yyyy'), 1, 3246, to_date('06-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020805016144, to_date('05-08-2002', 'dd-mm-yyyy'), to_date('19-08-2002', 'dd-mm-yyyy'), 1, 3751, to_date('08-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100606016145, to_date('06-06-2010', 'dd-mm-yyyy'), to_date('20-06-2010', 'dd-mm-yyyy'), 2, 7961, to_date('14-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030629016146, to_date('29-06-2003', 'dd-mm-yyyy'), to_date('13-07-2003', 'dd-mm-yyyy'), 1, 4358, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120827016147, to_date('27-08-2012', 'dd-mm-yyyy'), to_date('10-09-2012', 'dd-mm-yyyy'), 1, 6759, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090808016148, to_date('08-08-2009', 'dd-mm-yyyy'), to_date('22-08-2009', 'dd-mm-yyyy'), 2, 4970, to_date('20-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000607016149, to_date('07-06-2000', 'dd-mm-yyyy'), to_date('21-06-2000', 'dd-mm-yyyy'), 1, 1891, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060110016150, to_date('10-01-2006', 'dd-mm-yyyy'), to_date('24-01-2006', 'dd-mm-yyyy'), 1, 4854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120625016151, to_date('25-06-2012', 'dd-mm-yyyy'), to_date('09-07-2012', 'dd-mm-yyyy'), 2, 9507, to_date('14-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413016152, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 1, 7822, to_date('15-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209016153, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 2, 3037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030830016154, to_date('30-08-2003', 'dd-mm-yyyy'), to_date('13-09-2003', 'dd-mm-yyyy'), 1, 3907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040930016155, to_date('30-09-2004', 'dd-mm-yyyy'), to_date('14-10-2004', 'dd-mm-yyyy'), 1, 3387, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020222016156, to_date('22-02-2002', 'dd-mm-yyyy'), to_date('08-03-2002', 'dd-mm-yyyy'), 2, 3048, to_date('06-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070416016157, to_date('16-04-2007', 'dd-mm-yyyy'), to_date('30-04-2007', 'dd-mm-yyyy'), 2, 5107, to_date('03-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010016158, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 1, 6838, to_date('27-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090619016159, to_date('19-06-2009', 'dd-mm-yyyy'), to_date('03-07-2009', 'dd-mm-yyyy'), 2, 7281, to_date('28-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140103016160, to_date('03-01-2014', 'dd-mm-yyyy'), to_date('17-01-2014', 'dd-mm-yyyy'), 2, 9113, to_date('05-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010124016161, to_date('24-01-2001', 'dd-mm-yyyy'), to_date('07-02-2001', 'dd-mm-yyyy'), 1, 2313, to_date('01-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090419016162, to_date('19-04-2009', 'dd-mm-yyyy'), to_date('03-05-2009', 'dd-mm-yyyy'), 1, 6708, to_date('24-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110701016163, to_date('01-07-2011', 'dd-mm-yyyy'), to_date('15-07-2011', 'dd-mm-yyyy'), 1, 7429, to_date('19-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806016164, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 2, 4556, to_date('11-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111010016165, to_date('10-10-2011', 'dd-mm-yyyy'), to_date('24-10-2011', 'dd-mm-yyyy'), 2, 8125, to_date('20-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000905016166, to_date('05-09-2000', 'dd-mm-yyyy'), to_date('19-09-2000', 'dd-mm-yyyy'), 2, 3118, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821016167, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 2, 4815, to_date('24-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121016168, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 2, 1458, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110719016169, to_date('19-07-2011', 'dd-mm-yyyy'), to_date('02-08-2011', 'dd-mm-yyyy'), 1, 6569, to_date('27-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101218016170, to_date('18-12-2010', 'dd-mm-yyyy'), to_date('01-01-2011', 'dd-mm-yyyy'), 2, 5005, to_date('21-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050519016171, to_date('19-05-2005', 'dd-mm-yyyy'), to_date('02-06-2005', 'dd-mm-yyyy'), 1, 3479, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090323016172, to_date('23-03-2009', 'dd-mm-yyyy'), to_date('06-04-2009', 'dd-mm-yyyy'), 1, 8083, to_date('04-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090403016173, to_date('03-04-2009', 'dd-mm-yyyy'), to_date('17-04-2009', 'dd-mm-yyyy'), 2, 5564, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030602016174, to_date('02-06-2003', 'dd-mm-yyyy'), to_date('16-06-2003', 'dd-mm-yyyy'), 2, 2312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070701016175, to_date('01-07-2007', 'dd-mm-yyyy'), to_date('15-07-2007', 'dd-mm-yyyy'), 2, 9290, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008016176, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 1, 3064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140418016177, to_date('18-04-2014', 'dd-mm-yyyy'), to_date('02-05-2014', 'dd-mm-yyyy'), 1, 10131, to_date('04-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601016178, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 2, 5928, to_date('09-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112016179, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 2, 10550, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811016180, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 2, 6425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010401016181, to_date('01-04-2001', 'dd-mm-yyyy'), to_date('15-04-2001', 'dd-mm-yyyy'), 2, 1610, to_date('17-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111114016182, to_date('14-11-2011', 'dd-mm-yyyy'), to_date('28-11-2011', 'dd-mm-yyyy'), 2, 9013, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090408016183, to_date('08-04-2009', 'dd-mm-yyyy'), to_date('22-04-2009', 'dd-mm-yyyy'), 2, 6806, to_date('19-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001130016184, to_date('30-11-2000', 'dd-mm-yyyy'), to_date('14-12-2000', 'dd-mm-yyyy'), 1, 1617, to_date('04-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010703016185, to_date('03-07-2001', 'dd-mm-yyyy'), to_date('17-07-2001', 'dd-mm-yyyy'), 2, 1882, to_date('09-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100518016186, to_date('18-05-2010', 'dd-mm-yyyy'), to_date('01-06-2010', 'dd-mm-yyyy'), 1, 7674, to_date('02-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212016187, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 2, 2717, to_date('19-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120828016188, to_date('28-08-2012', 'dd-mm-yyyy'), to_date('11-09-2012', 'dd-mm-yyyy'), 1, 10976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031207016189, to_date('07-12-2003', 'dd-mm-yyyy'), to_date('21-12-2003', 'dd-mm-yyyy'), 2, 4049, to_date('15-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030608016190, to_date('08-06-2003', 'dd-mm-yyyy'), to_date('22-06-2003', 'dd-mm-yyyy'), 1, 2368, to_date('17-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130219016191, to_date('19-02-2013', 'dd-mm-yyyy'), to_date('05-03-2013', 'dd-mm-yyyy'), 2, 10691, to_date('07-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140516016192, to_date('16-05-2014', 'dd-mm-yyyy'), to_date('30-05-2014', 'dd-mm-yyyy'), 2, 9840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070821016193, to_date('21-08-2007', 'dd-mm-yyyy'), to_date('04-09-2007', 'dd-mm-yyyy'), 2, 5419, to_date('01-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130404016194, to_date('04-04-2013', 'dd-mm-yyyy'), to_date('18-04-2013', 'dd-mm-yyyy'), 2, 9468, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061218016195, to_date('18-12-2006', 'dd-mm-yyyy'), to_date('01-01-2007', 'dd-mm-yyyy'), 1, 3481, to_date('30-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020817016196, to_date('17-08-2002', 'dd-mm-yyyy'), to_date('31-08-2002', 'dd-mm-yyyy'), 1, 1485, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601016197, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 1, 5402, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000208016198, to_date('08-02-2000', 'dd-mm-yyyy'), to_date('22-02-2000', 'dd-mm-yyyy'), 1, 3033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050826016199, to_date('26-08-2005', 'dd-mm-yyyy'), to_date('09-09-2005', 'dd-mm-yyyy'), 1, 5088, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110212016200, to_date('12-02-2011', 'dd-mm-yyyy'), to_date('26-02-2011', 'dd-mm-yyyy'), 2, 5912, to_date('17-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030720016201, to_date('20-07-2003', 'dd-mm-yyyy'), to_date('03-08-2003', 'dd-mm-yyyy'), 2, 3446, to_date('08-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105016202, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 2, 2688, to_date('16-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140428016203, to_date('28-04-2014', 'dd-mm-yyyy'), to_date('12-05-2014', 'dd-mm-yyyy'), 1, 10006, to_date('06-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210016204, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 2, 2667, to_date('18-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712016205, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 2, 4352, to_date('23-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080710016206, to_date('10-07-2008', 'dd-mm-yyyy'), to_date('24-07-2008', 'dd-mm-yyyy'), 1, 4594, to_date('23-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219016207, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 1, 5659, to_date('05-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110402016208, to_date('02-04-2011', 'dd-mm-yyyy'), to_date('16-04-2011', 'dd-mm-yyyy'), 2, 5675, to_date('16-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100206016209, to_date('06-02-2010', 'dd-mm-yyyy'), to_date('20-02-2010', 'dd-mm-yyyy'), 1, 6060, to_date('25-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011113016210, to_date('13-11-2001', 'dd-mm-yyyy'), to_date('27-11-2001', 'dd-mm-yyyy'), 1, 1372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070807016211, to_date('07-08-2007', 'dd-mm-yyyy'), to_date('21-08-2007', 'dd-mm-yyyy'), 1, 4170, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020204016212, to_date('04-02-2002', 'dd-mm-yyyy'), to_date('18-02-2002', 'dd-mm-yyyy'), 2, 3974, to_date('13-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061208016213, to_date('08-12-2006', 'dd-mm-yyyy'), to_date('22-12-2006', 'dd-mm-yyyy'), 1, 6975, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100223016214, to_date('23-02-2010', 'dd-mm-yyyy'), to_date('09-03-2010', 'dd-mm-yyyy'), 1, 6723, to_date('24-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080706016215, to_date('06-07-2008', 'dd-mm-yyyy'), to_date('20-07-2008', 'dd-mm-yyyy'), 1, 7888, to_date('17-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051220016216, to_date('20-12-2005', 'dd-mm-yyyy'), to_date('03-01-2006', 'dd-mm-yyyy'), 2, 3798, to_date('26-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091104016217, to_date('04-11-2009', 'dd-mm-yyyy'), to_date('18-11-2009', 'dd-mm-yyyy'), 1, 6827, to_date('07-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210016218, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 2, 3247, to_date('19-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090913016219, to_date('13-09-2009', 'dd-mm-yyyy'), to_date('27-09-2009', 'dd-mm-yyyy'), 1, 4918, to_date('23-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120201016220, to_date('01-02-2012', 'dd-mm-yyyy'), to_date('15-02-2012', 'dd-mm-yyyy'), 1, 7258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040813016221, to_date('13-08-2004', 'dd-mm-yyyy'), to_date('27-08-2004', 'dd-mm-yyyy'), 1, 3550, to_date('14-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031221016222, to_date('21-12-2003', 'dd-mm-yyyy'), to_date('04-01-2004', 'dd-mm-yyyy'), 2, 2626, to_date('30-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030927016223, to_date('27-09-2003', 'dd-mm-yyyy'), to_date('11-10-2003', 'dd-mm-yyyy'), 2, 2895, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010826016224, to_date('26-08-2001', 'dd-mm-yyyy'), to_date('09-09-2001', 'dd-mm-yyyy'), 2, 1530, to_date('08-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101002016225, to_date('02-10-2010', 'dd-mm-yyyy'), to_date('16-10-2010', 'dd-mm-yyyy'), 2, 5006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120116016226, to_date('16-01-2012', 'dd-mm-yyyy'), to_date('30-01-2012', 'dd-mm-yyyy'), 2, 5587, to_date('28-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051205016227, to_date('05-12-2005', 'dd-mm-yyyy'), to_date('19-12-2005', 'dd-mm-yyyy'), 1, 2781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130708016228, to_date('08-07-2013', 'dd-mm-yyyy'), to_date('22-07-2013', 'dd-mm-yyyy'), 1, 8714, to_date('23-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030908016229, to_date('08-09-2003', 'dd-mm-yyyy'), to_date('22-09-2003', 'dd-mm-yyyy'), 1, 4156, to_date('24-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204010720, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 1, 6139, to_date('22-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041217010721, to_date('17-12-2004', 'dd-mm-yyyy'), to_date('31-12-2004', 'dd-mm-yyyy'), 1, 3825, to_date('28-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121229010722, to_date('29-12-2012', 'dd-mm-yyyy'), to_date('12-01-2013', 'dd-mm-yyyy'), 9, 7791, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071115010723, to_date('15-11-2007', 'dd-mm-yyyy'), to_date('29-11-2007', 'dd-mm-yyyy'), 5, 4647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000324010724, to_date('24-03-2000', 'dd-mm-yyyy'), to_date('07-04-2000', 'dd-mm-yyyy'), 8, 2016, to_date('30-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112010725, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 6, 2621, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091013010726, to_date('13-10-2009', 'dd-mm-yyyy'), to_date('27-10-2009', 'dd-mm-yyyy'), 10, 11125, to_date('18-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100811010727, to_date('11-08-2010', 'dd-mm-yyyy'), to_date('25-08-2010', 'dd-mm-yyyy'), 2, 8089, to_date('31-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050120010728, to_date('20-01-2005', 'dd-mm-yyyy'), to_date('03-02-2005', 'dd-mm-yyyy'), 9, 4163, to_date('06-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130412010729, to_date('12-04-2013', 'dd-mm-yyyy'), to_date('26-04-2013', 'dd-mm-yyyy'), 2, 9998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100929010730, to_date('29-09-2010', 'dd-mm-yyyy'), to_date('13-10-2010', 'dd-mm-yyyy'), 7, 8798, to_date('07-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131107010731, to_date('07-11-2013', 'dd-mm-yyyy'), to_date('21-11-2013', 'dd-mm-yyyy'), 4, 8574, to_date('13-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031126010732, to_date('26-11-2003', 'dd-mm-yyyy'), to_date('10-12-2003', 'dd-mm-yyyy'), 7, 2901, to_date('05-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070218010733, to_date('18-02-2007', 'dd-mm-yyyy'), to_date('04-03-2007', 'dd-mm-yyyy'), 9, 5288, to_date('28-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050205010734, to_date('05-02-2005', 'dd-mm-yyyy'), to_date('19-02-2005', 'dd-mm-yyyy'), 10, 3255, to_date('13-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111010735, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 1, 10433, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130625010736, to_date('25-06-2013', 'dd-mm-yyyy'), to_date('09-07-2013', 'dd-mm-yyyy'), 9, 8463, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601010737, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 5, 9796, to_date('15-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100531010738, to_date('31-05-2010', 'dd-mm-yyyy'), to_date('14-06-2010', 'dd-mm-yyyy'), 9, 8008, to_date('20-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930010739, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 2, 5157, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121216010740, to_date('16-12-2012', 'dd-mm-yyyy'), to_date('30-12-2012', 'dd-mm-yyyy'), 3, 9776, to_date('05-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030122010741, to_date('22-01-2003', 'dd-mm-yyyy'), to_date('05-02-2003', 'dd-mm-yyyy'), 7, 3929, to_date('07-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021010742, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 2, 6370, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108010743, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 11, 6579, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070531010744, to_date('31-05-2007', 'dd-mm-yyyy'), to_date('14-06-2007', 'dd-mm-yyyy'), 2, 6103, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020128010745, to_date('28-01-2002', 'dd-mm-yyyy'), to_date('11-02-2002', 'dd-mm-yyyy'), 9, 2665, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000902010746, to_date('02-09-2000', 'dd-mm-yyyy'), to_date('16-09-2000', 'dd-mm-yyyy'), 4, 1631, to_date('15-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040905010747, to_date('05-09-2004', 'dd-mm-yyyy'), to_date('19-09-2004', 'dd-mm-yyyy'), 6, 3361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100823010748, to_date('23-08-2010', 'dd-mm-yyyy'), to_date('06-09-2010', 'dd-mm-yyyy'), 12, 4660, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111115010749, to_date('15-11-2011', 'dd-mm-yyyy'), to_date('29-11-2011', 'dd-mm-yyyy'), 10, 8342, to_date('25-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111219010750, to_date('19-12-2011', 'dd-mm-yyyy'), to_date('02-01-2012', 'dd-mm-yyyy'), 2, 6298, to_date('01-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010224010751, to_date('24-02-2001', 'dd-mm-yyyy'), to_date('10-03-2001', 'dd-mm-yyyy'), 7, 2473, to_date('28-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060619010752, to_date('19-06-2006', 'dd-mm-yyyy'), to_date('03-07-2006', 'dd-mm-yyyy'), 7, 4349, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618010753, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 7, 6774, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515010754, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 8, 1771, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031224010755, to_date('24-12-2003', 'dd-mm-yyyy'), to_date('07-01-2004', 'dd-mm-yyyy'), 7, 2488, to_date('11-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130416010756, to_date('16-04-2013', 'dd-mm-yyyy'), to_date('30-04-2013', 'dd-mm-yyyy'), 2, 8217, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121019010757, to_date('19-10-2012', 'dd-mm-yyyy'), to_date('02-11-2012', 'dd-mm-yyyy'), 11, 7459, to_date('28-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061008010758, to_date('08-10-2006', 'dd-mm-yyyy'), to_date('22-10-2006', 'dd-mm-yyyy'), 3, 5075, to_date('19-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040727010759, to_date('27-07-2004', 'dd-mm-yyyy'), to_date('10-08-2004', 'dd-mm-yyyy'), 5, 4629, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100627010760, to_date('27-06-2010', 'dd-mm-yyyy'), to_date('11-07-2010', 'dd-mm-yyyy'), 10, 6850, to_date('01-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131128010761, to_date('28-11-2013', 'dd-mm-yyyy'), to_date('12-12-2013', 'dd-mm-yyyy'), 6, 7081, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050316010762, to_date('16-03-2005', 'dd-mm-yyyy'), to_date('30-03-2005', 'dd-mm-yyyy'), 6, 2331, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090411010763, to_date('11-04-2009', 'dd-mm-yyyy'), to_date('25-04-2009', 'dd-mm-yyyy'), 8, 8582, to_date('15-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111010764, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 7, 11278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130620010765, to_date('20-06-2013', 'dd-mm-yyyy'), to_date('04-07-2013', 'dd-mm-yyyy'), 6, 11182, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031123010766, to_date('23-11-2003', 'dd-mm-yyyy'), to_date('07-12-2003', 'dd-mm-yyyy'), 7, 4606, to_date('01-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020215010767, to_date('15-02-2002', 'dd-mm-yyyy'), to_date('01-03-2002', 'dd-mm-yyyy'), 10, 2066, to_date('24-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070212010768, to_date('12-02-2007', 'dd-mm-yyyy'), to_date('26-02-2007', 'dd-mm-yyyy'), 2, 6820, to_date('23-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060618010769, to_date('18-06-2006', 'dd-mm-yyyy'), to_date('02-07-2006', 'dd-mm-yyyy'), 2, 3235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000708010770, to_date('08-07-2000', 'dd-mm-yyyy'), to_date('22-07-2000', 'dd-mm-yyyy'), 2, 540, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713010771, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 3, 5580, to_date('02-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120610010772, to_date('10-06-2012', 'dd-mm-yyyy'), to_date('24-06-2012', 'dd-mm-yyyy'), 2, 9723, to_date('12-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120507010773, to_date('07-05-2012', 'dd-mm-yyyy'), to_date('21-05-2012', 'dd-mm-yyyy'), 2, 5973, to_date('12-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020620010774, to_date('20-06-2002', 'dd-mm-yyyy'), to_date('04-07-2002', 'dd-mm-yyyy'), 9, 2980, to_date('24-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000717010775, to_date('17-07-2000', 'dd-mm-yyyy'), to_date('31-07-2000', 'dd-mm-yyyy'), 2, 2836, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121112010776, to_date('12-11-2012', 'dd-mm-yyyy'), to_date('26-11-2012', 'dd-mm-yyyy'), 6, 9685, to_date('13-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130427010777, to_date('27-04-2013', 'dd-mm-yyyy'), to_date('11-05-2013', 'dd-mm-yyyy'), 3, 11457, to_date('15-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061119010778, to_date('19-11-2006', 'dd-mm-yyyy'), to_date('03-12-2006', 'dd-mm-yyyy'), 9, 4231, to_date('25-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020919010779, to_date('19-09-2002', 'dd-mm-yyyy'), to_date('03-10-2002', 'dd-mm-yyyy'), 2, 2519, to_date('05-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110527010780, to_date('27-05-2011', 'dd-mm-yyyy'), to_date('10-06-2011', 'dd-mm-yyyy'), 2, 8975, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130626010781, to_date('26-06-2013', 'dd-mm-yyyy'), to_date('10-07-2013', 'dd-mm-yyyy'), 11, 11540, to_date('08-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060907010782, to_date('07-09-2006', 'dd-mm-yyyy'), to_date('21-09-2006', 'dd-mm-yyyy'), 8, 4828, to_date('18-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825010783, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 6, 8561, to_date('01-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226010784, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 7, 9770, to_date('01-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010128010785, to_date('28-01-2001', 'dd-mm-yyyy'), to_date('11-02-2001', 'dd-mm-yyyy'), 9, 1969, to_date('31-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041111010786, to_date('11-11-2004', 'dd-mm-yyyy'), to_date('25-11-2004', 'dd-mm-yyyy'), 9, 3076, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000804010787, to_date('04-08-2000', 'dd-mm-yyyy'), to_date('18-08-2000', 'dd-mm-yyyy'), 3, 3002, to_date('16-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029010788, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 2, 4575, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121015010789, to_date('15-10-2012', 'dd-mm-yyyy'), to_date('29-10-2012', 'dd-mm-yyyy'), 1, 4868, to_date('23-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329010790, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 8, 5584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100821010791, to_date('21-08-2010', 'dd-mm-yyyy'), to_date('04-09-2010', 'dd-mm-yyyy'), 5, 5737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080417010792, to_date('17-04-2008', 'dd-mm-yyyy'), to_date('01-05-2008', 'dd-mm-yyyy'), 2, 5633, to_date('23-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051127010793, to_date('27-11-2005', 'dd-mm-yyyy'), to_date('11-12-2005', 'dd-mm-yyyy'), 5, 7037, to_date('01-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090930010794, to_date('30-09-2009', 'dd-mm-yyyy'), to_date('14-10-2009', 'dd-mm-yyyy'), 4, 5524, to_date('10-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010218010795, to_date('18-02-2001', 'dd-mm-yyyy'), to_date('04-03-2001', 'dd-mm-yyyy'), 7, 697, to_date('09-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061118010796, to_date('18-11-2006', 'dd-mm-yyyy'), to_date('02-12-2006', 'dd-mm-yyyy'), 1, 4539, to_date('28-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020710010797, to_date('10-07-2002', 'dd-mm-yyyy'), to_date('24-07-2002', 'dd-mm-yyyy'), 4, 4624, to_date('22-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041030010798, to_date('30-10-2004', 'dd-mm-yyyy'), to_date('13-11-2004', 'dd-mm-yyyy'), 4, 3595, to_date('04-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100310010799, to_date('10-03-2010', 'dd-mm-yyyy'), to_date('24-03-2010', 'dd-mm-yyyy'), 3, 8332, to_date('18-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020612010800, to_date('12-06-2002', 'dd-mm-yyyy'), to_date('26-06-2002', 'dd-mm-yyyy'), 2, 5276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040625010801, to_date('25-06-2004', 'dd-mm-yyyy'), to_date('09-07-2004', 'dd-mm-yyyy'), 7, 4022, to_date('14-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040228010802, to_date('28-02-2004', 'dd-mm-yyyy'), to_date('13-03-2004', 'dd-mm-yyyy'), 6, 3408, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516010803, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 5, 7393, to_date('21-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070506010804, to_date('06-05-2007', 'dd-mm-yyyy'), to_date('20-05-2007', 'dd-mm-yyyy'), 1, 5861, to_date('16-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090706010805, to_date('06-07-2009', 'dd-mm-yyyy'), to_date('20-07-2009', 'dd-mm-yyyy'), 6, 6056, to_date('12-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021028010806, to_date('28-10-2002', 'dd-mm-yyyy'), to_date('11-11-2002', 'dd-mm-yyyy'), 9, 747, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070614010807, to_date('14-06-2007', 'dd-mm-yyyy'), to_date('28-06-2007', 'dd-mm-yyyy'), 3, 6986, to_date('24-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820010808, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 4, 650, to_date('05-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120517010809, to_date('17-05-2012', 'dd-mm-yyyy'), to_date('31-05-2012', 'dd-mm-yyyy'), 10, 7920, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101207010810, to_date('07-12-2010', 'dd-mm-yyyy'), to_date('21-12-2010', 'dd-mm-yyyy'), 9, 7850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140305010811, to_date('05-03-2014', 'dd-mm-yyyy'), to_date('19-03-2014', 'dd-mm-yyyy'), 4, 8695, to_date('10-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000916010812, to_date('16-09-2000', 'dd-mm-yyyy'), to_date('30-09-2000', 'dd-mm-yyyy'), 8, 857, to_date('22-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090802010813, to_date('02-08-2009', 'dd-mm-yyyy'), to_date('16-08-2009', 'dd-mm-yyyy'), 11, 7195, to_date('12-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110911010814, to_date('11-09-2011', 'dd-mm-yyyy'), to_date('25-09-2011', 'dd-mm-yyyy'), 7, 7483, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926010815, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 9, 5377, to_date('14-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707010816, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 9, 4963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110406010817, to_date('06-04-2011', 'dd-mm-yyyy'), to_date('20-04-2011', 'dd-mm-yyyy'), 12, 9630, to_date('24-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030703010818, to_date('03-07-2003', 'dd-mm-yyyy'), to_date('17-07-2003', 'dd-mm-yyyy'), 6, 2381, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120405010819, to_date('05-04-2012', 'dd-mm-yyyy'), to_date('19-04-2012', 'dd-mm-yyyy'), 2, 7511, to_date('12-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120510010820, to_date('10-05-2012', 'dd-mm-yyyy'), to_date('24-05-2012', 'dd-mm-yyyy'), 1, 5904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329010821, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 10, 5903, to_date('01-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091023010822, to_date('23-10-2009', 'dd-mm-yyyy'), to_date('06-11-2009', 'dd-mm-yyyy'), 6, 6003, to_date('30-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413010823, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 7, 4193, to_date('28-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121109010824, to_date('09-11-2012', 'dd-mm-yyyy'), to_date('23-11-2012', 'dd-mm-yyyy'), 6, 7024, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530010825, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 5, 2064, to_date('03-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051207010826, to_date('07-12-2005', 'dd-mm-yyyy'), to_date('21-12-2005', 'dd-mm-yyyy'), 3, 5665, to_date('19-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722010827, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 4, 1378, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101119010828, to_date('19-11-2010', 'dd-mm-yyyy'), to_date('03-12-2010', 'dd-mm-yyyy'), 12, 5354, to_date('24-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726010829, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 4, 6756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050515010830, to_date('15-05-2005', 'dd-mm-yyyy'), to_date('29-05-2005', 'dd-mm-yyyy'), 5, 3724, to_date('29-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050807010831, to_date('07-08-2005', 'dd-mm-yyyy'), to_date('21-08-2005', 'dd-mm-yyyy'), 11, 5132, to_date('16-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031009010832, to_date('09-10-2003', 'dd-mm-yyyy'), to_date('23-10-2003', 'dd-mm-yyyy'), 8, 5268, to_date('17-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090114010833, to_date('14-01-2009', 'dd-mm-yyyy'), to_date('28-01-2009', 'dd-mm-yyyy'), 4, 8775, to_date('02-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050204010834, to_date('04-02-2005', 'dd-mm-yyyy'), to_date('18-02-2005', 'dd-mm-yyyy'), 10, 3452, to_date('12-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101227010835, to_date('27-12-2010', 'dd-mm-yyyy'), to_date('10-01-2011', 'dd-mm-yyyy'), 8, 6048, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020420010836, to_date('20-04-2002', 'dd-mm-yyyy'), to_date('04-05-2002', 'dd-mm-yyyy'), 9, 1050, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504010837, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 11, 8464, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080312010838, to_date('12-03-2008', 'dd-mm-yyyy'), to_date('26-03-2008', 'dd-mm-yyyy'), 3, 5826, to_date('23-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101010839, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 8, 2248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507010840, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 8, 9604, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080120010841, to_date('20-01-2008', 'dd-mm-yyyy'), to_date('03-02-2008', 'dd-mm-yyyy'), 7, 8391, to_date('02-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119010842, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 10, 5509, to_date('27-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060630010843, to_date('30-06-2006', 'dd-mm-yyyy'), to_date('14-07-2006', 'dd-mm-yyyy'), 9, 2210, to_date('18-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111030010844, to_date('30-10-2011', 'dd-mm-yyyy'), to_date('13-11-2011', 'dd-mm-yyyy'), 5, 7164, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601010845, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 10, 10080, to_date('11-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081011010846, to_date('11-10-2008', 'dd-mm-yyyy'), to_date('25-10-2008', 'dd-mm-yyyy'), 1, 8275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080214010847, to_date('14-02-2008', 'dd-mm-yyyy'), to_date('28-02-2008', 'dd-mm-yyyy'), 9, 7802, to_date('21-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090415010848, to_date('15-04-2009', 'dd-mm-yyyy'), to_date('29-04-2009', 'dd-mm-yyyy'), 10, 7092, to_date('25-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213010849, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 2, 6614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313010850, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 7, 4033, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209010851, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 2, 9571, to_date('16-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020219010852, to_date('19-02-2002', 'dd-mm-yyyy'), to_date('05-03-2002', 'dd-mm-yyyy'), 5, 1834, to_date('11-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303010853, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 8, 9289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809010854, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 9, 2029, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110704010855, to_date('04-07-2011', 'dd-mm-yyyy'), to_date('18-07-2011', 'dd-mm-yyyy'), 5, 6030, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111124010856, to_date('24-11-2011', 'dd-mm-yyyy'), to_date('08-12-2011', 'dd-mm-yyyy'), 3, 7466, to_date('03-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030927010857, to_date('27-09-2003', 'dd-mm-yyyy'), to_date('11-10-2003', 'dd-mm-yyyy'), 10, 3181, to_date('02-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040418010858, to_date('18-04-2004', 'dd-mm-yyyy'), to_date('02-05-2004', 'dd-mm-yyyy'), 5, 3806, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309010859, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 9, 5774, to_date('28-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602010860, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 7, 1710, to_date('16-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413010861, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 10, 3937, to_date('17-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050724010862, to_date('24-07-2005', 'dd-mm-yyyy'), to_date('07-08-2005', 'dd-mm-yyyy'), 5, 4278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040216010863, to_date('16-02-2004', 'dd-mm-yyyy'), to_date('01-03-2004', 'dd-mm-yyyy'), 5, 3750, to_date('26-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090922010864, to_date('22-09-2009', 'dd-mm-yyyy'), to_date('06-10-2009', 'dd-mm-yyyy'), 6, 4670, to_date('09-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060816010865, to_date('16-08-2006', 'dd-mm-yyyy'), to_date('30-08-2006', 'dd-mm-yyyy'), 6, 7807, to_date('24-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080229010866, to_date('29-02-2008', 'dd-mm-yyyy'), to_date('14-03-2008', 'dd-mm-yyyy'), 2, 4415, to_date('18-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041203010867, to_date('03-12-2004', 'dd-mm-yyyy'), to_date('17-12-2004', 'dd-mm-yyyy'), 2, 2357, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104010868, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 7, 4759, to_date('20-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051210010869, to_date('10-12-2005', 'dd-mm-yyyy'), to_date('24-12-2005', 'dd-mm-yyyy'), 12, 4660, to_date('12-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130606010870, to_date('06-06-2013', 'dd-mm-yyyy'), to_date('20-06-2013', 'dd-mm-yyyy'), 1, 10063, to_date('15-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130123010871, to_date('23-01-2013', 'dd-mm-yyyy'), to_date('06-02-2013', 'dd-mm-yyyy'), 3, 7971, to_date('02-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011102010872, to_date('02-11-2001', 'dd-mm-yyyy'), to_date('16-11-2001', 'dd-mm-yyyy'), 1, 4271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140210010873, to_date('10-02-2014', 'dd-mm-yyyy'), to_date('24-02-2014', 'dd-mm-yyyy'), 12, 7671, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130913010874, to_date('13-09-2013', 'dd-mm-yyyy'), to_date('27-09-2013', 'dd-mm-yyyy'), 7, 8681, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010213013537, to_date('13-02-2001', 'dd-mm-yyyy'), to_date('27-02-2001', 'dd-mm-yyyy'), 1, 3814, to_date('04-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100313013538, to_date('13-03-2010', 'dd-mm-yyyy'), to_date('27-03-2010', 'dd-mm-yyyy'), 3, 5100, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114013539, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 4, 2331, to_date('24-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050312013540, to_date('12-03-2005', 'dd-mm-yyyy'), to_date('26-03-2005', 'dd-mm-yyyy'), 4, 2029, to_date('27-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119013541, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 2, 4757, to_date('03-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090223013542, to_date('23-02-2009', 'dd-mm-yyyy'), to_date('09-03-2009', 'dd-mm-yyyy'), 4, 7651, to_date('12-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223013543, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 2, 6813, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110919013544, to_date('19-09-2011', 'dd-mm-yyyy'), to_date('03-10-2011', 'dd-mm-yyyy'), 3, 7590, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090511013545, to_date('11-05-2009', 'dd-mm-yyyy'), to_date('25-05-2009', 'dd-mm-yyyy'), 1, 7265, to_date('15-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318013546, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 4, 6980, to_date('31-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091128013547, to_date('28-11-2009', 'dd-mm-yyyy'), to_date('12-12-2009', 'dd-mm-yyyy'), 3, 5254, to_date('05-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050619013548, to_date('19-06-2005', 'dd-mm-yyyy'), to_date('03-07-2005', 'dd-mm-yyyy'), 2, 4497, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110208013549, to_date('08-02-2011', 'dd-mm-yyyy'), to_date('22-02-2011', 'dd-mm-yyyy'), 3, 6818, to_date('16-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121119013550, to_date('19-11-2012', 'dd-mm-yyyy'), to_date('03-12-2012', 'dd-mm-yyyy'), 2, 8675, to_date('08-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110713013551, to_date('13-07-2011', 'dd-mm-yyyy'), to_date('27-07-2011', 'dd-mm-yyyy'), 2, 6605, to_date('14-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008013552, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 2, 7314, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070224013553, to_date('24-02-2007', 'dd-mm-yyyy'), to_date('10-03-2007', 'dd-mm-yyyy'), 2, 5144, to_date('12-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130721013554, to_date('21-07-2013', 'dd-mm-yyyy'), to_date('04-08-2013', 'dd-mm-yyyy'), 2, 10496, to_date('01-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000902013555, to_date('02-09-2000', 'dd-mm-yyyy'), to_date('16-09-2000', 'dd-mm-yyyy'), 4, 2167, to_date('16-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130213013556, to_date('13-02-2013', 'dd-mm-yyyy'), to_date('27-02-2013', 'dd-mm-yyyy'), 3, 8005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302013557, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 2, 4044, to_date('05-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080520013558, to_date('20-05-2008', 'dd-mm-yyyy'), to_date('03-06-2008', 'dd-mm-yyyy'), 2, 5972, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080402013559, to_date('02-04-2008', 'dd-mm-yyyy'), to_date('16-04-2008', 'dd-mm-yyyy'), 3, 5941, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040320013560, to_date('20-03-2004', 'dd-mm-yyyy'), to_date('03-04-2004', 'dd-mm-yyyy'), 3, 2272, to_date('25-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110907013561, to_date('07-09-2011', 'dd-mm-yyyy'), to_date('21-09-2011', 'dd-mm-yyyy'), 2, 8760, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070625013562, to_date('25-06-2007', 'dd-mm-yyyy'), to_date('09-07-2007', 'dd-mm-yyyy'), 2, 6697, to_date('07-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030720013563, to_date('20-07-2003', 'dd-mm-yyyy'), to_date('03-08-2003', 'dd-mm-yyyy'), 4, 3461, to_date('22-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030514013564, to_date('14-05-2003', 'dd-mm-yyyy'), to_date('28-05-2003', 'dd-mm-yyyy'), 2, 1897, to_date('22-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080630013565, to_date('30-06-2008', 'dd-mm-yyyy'), to_date('14-07-2008', 'dd-mm-yyyy'), 3, 4386, to_date('05-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116013566, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 2, 4216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100304013567, to_date('04-03-2010', 'dd-mm-yyyy'), to_date('18-03-2010', 'dd-mm-yyyy'), 1, 7509, to_date('20-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060906013568, to_date('06-09-2006', 'dd-mm-yyyy'), to_date('20-09-2006', 'dd-mm-yyyy'), 1, 3557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060321013569, to_date('21-03-2006', 'dd-mm-yyyy'), to_date('04-04-2006', 'dd-mm-yyyy'), 1, 6431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010706013570, to_date('06-07-2001', 'dd-mm-yyyy'), to_date('20-07-2001', 'dd-mm-yyyy'), 2, 3259, to_date('20-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110413013571, to_date('13-04-2011', 'dd-mm-yyyy'), to_date('27-04-2011', 'dd-mm-yyyy'), 2, 6544, to_date('29-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060322013572, to_date('22-03-2006', 'dd-mm-yyyy'), to_date('05-04-2006', 'dd-mm-yyyy'), 2, 4232, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817013573, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 2, 11522, to_date('01-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020121013574, to_date('21-01-2002', 'dd-mm-yyyy'), to_date('04-02-2002', 'dd-mm-yyyy'), 3, 3544, to_date('08-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100221013575, to_date('21-02-2010', 'dd-mm-yyyy'), to_date('07-03-2010', 'dd-mm-yyyy'), 3, 8238, to_date('23-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090307013576, to_date('07-03-2009', 'dd-mm-yyyy'), to_date('21-03-2009', 'dd-mm-yyyy'), 2, 7058, to_date('23-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120608013577, to_date('08-06-2012', 'dd-mm-yyyy'), to_date('22-06-2012', 'dd-mm-yyyy'), 4, 9027, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090929013578, to_date('29-09-2009', 'dd-mm-yyyy'), to_date('13-10-2009', 'dd-mm-yyyy'), 2, 4893, to_date('10-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090712013579, to_date('12-07-2009', 'dd-mm-yyyy'), to_date('26-07-2009', 'dd-mm-yyyy'), 2, 7187, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525013580, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 4, 6557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130807013581, to_date('07-08-2013', 'dd-mm-yyyy'), to_date('21-08-2013', 'dd-mm-yyyy'), 2, 6877, to_date('18-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311013582, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 3, 8191, to_date('27-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120520013583, to_date('20-05-2012', 'dd-mm-yyyy'), to_date('03-06-2012', 'dd-mm-yyyy'), 1, 8234, to_date('02-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015013584, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 2, 2020, to_date('23-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521013585, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 1, 1716, to_date('04-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120529013586, to_date('29-05-2012', 'dd-mm-yyyy'), to_date('12-06-2012', 'dd-mm-yyyy'), 2, 6862, to_date('12-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018013587, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 1, 2154, to_date('28-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100211013588, to_date('11-02-2010', 'dd-mm-yyyy'), to_date('25-02-2010', 'dd-mm-yyyy'), 3, 7501, to_date('15-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121029013589, to_date('29-10-2012', 'dd-mm-yyyy'), to_date('12-11-2012', 'dd-mm-yyyy'), 1, 12855, to_date('07-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030313013590, to_date('13-03-2003', 'dd-mm-yyyy'), to_date('27-03-2003', 'dd-mm-yyyy'), 4, 3391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603013591, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 3, 6671, to_date('22-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000605013592, to_date('05-06-2000', 'dd-mm-yyyy'), to_date('19-06-2000', 'dd-mm-yyyy'), 3, 794, to_date('24-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011102013593, to_date('02-11-2001', 'dd-mm-yyyy'), to_date('16-11-2001', 'dd-mm-yyyy'), 2, 3761, to_date('18-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050508013594, to_date('08-05-2005', 'dd-mm-yyyy'), to_date('22-05-2005', 'dd-mm-yyyy'), 3, 4129, to_date('17-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120122013595, to_date('22-01-2012', 'dd-mm-yyyy'), to_date('05-02-2012', 'dd-mm-yyyy'), 1, 9147, to_date('09-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319013596, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 3, 2138, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010806013597, to_date('06-08-2001', 'dd-mm-yyyy'), to_date('20-08-2001', 'dd-mm-yyyy'), 3, 4871, to_date('08-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050701013598, to_date('01-07-2005', 'dd-mm-yyyy'), to_date('15-07-2005', 'dd-mm-yyyy'), 2, 5064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061205013599, to_date('05-12-2006', 'dd-mm-yyyy'), to_date('19-12-2006', 'dd-mm-yyyy'), 2, 6176, to_date('19-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010527013600, to_date('27-05-2001', 'dd-mm-yyyy'), to_date('10-06-2001', 'dd-mm-yyyy'), 4, 2658, to_date('15-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100210013601, to_date('10-02-2010', 'dd-mm-yyyy'), to_date('24-02-2010', 'dd-mm-yyyy'), 1, 8324, to_date('21-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120814013602, to_date('14-08-2012', 'dd-mm-yyyy'), to_date('28-08-2012', 'dd-mm-yyyy'), 3, 7020, to_date('17-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010524013603, to_date('24-05-2001', 'dd-mm-yyyy'), to_date('07-06-2001', 'dd-mm-yyyy'), 2, 2635, to_date('06-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090907013604, to_date('07-09-2009', 'dd-mm-yyyy'), to_date('21-09-2009', 'dd-mm-yyyy'), 2, 5156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011215013605, to_date('15-12-2001', 'dd-mm-yyyy'), to_date('29-12-2001', 'dd-mm-yyyy'), 2, 1990, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040320013606, to_date('20-03-2004', 'dd-mm-yyyy'), to_date('03-04-2004', 'dd-mm-yyyy'), 2, 3603, to_date('01-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000228013607, to_date('28-02-2000', 'dd-mm-yyyy'), to_date('13-03-2000', 'dd-mm-yyyy'), 2, 1666, to_date('08-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218013608, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 1, 5749, to_date('26-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100729013609, to_date('29-07-2010', 'dd-mm-yyyy'), to_date('12-08-2010', 'dd-mm-yyyy'), 3, 8434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060605013610, to_date('05-06-2006', 'dd-mm-yyyy'), to_date('19-06-2006', 'dd-mm-yyyy'), 3, 5677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608013611, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 2, 9998, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010709013612, to_date('09-07-2001', 'dd-mm-yyyy'), to_date('23-07-2001', 'dd-mm-yyyy'), 1, 1688, to_date('26-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071126013613, to_date('26-11-2007', 'dd-mm-yyyy'), to_date('10-12-2007', 'dd-mm-yyyy'), 4, 4845, to_date('16-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817013614, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 3, 8081, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020926013615, to_date('26-09-2002', 'dd-mm-yyyy'), to_date('10-10-2002', 'dd-mm-yyyy'), 3, 3235, to_date('02-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050611013616, to_date('11-06-2005', 'dd-mm-yyyy'), to_date('25-06-2005', 'dd-mm-yyyy'), 1, 4919, to_date('13-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041120013617, to_date('20-11-2004', 'dd-mm-yyyy'), to_date('04-12-2004', 'dd-mm-yyyy'), 1, 4244, to_date('29-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020926013618, to_date('26-09-2002', 'dd-mm-yyyy'), to_date('10-10-2002', 'dd-mm-yyyy'), 2, 2588, to_date('11-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070616013619, to_date('16-06-2007', 'dd-mm-yyyy'), to_date('30-06-2007', 'dd-mm-yyyy'), 1, 6861, to_date('04-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090714013620, to_date('14-07-2009', 'dd-mm-yyyy'), to_date('28-07-2009', 'dd-mm-yyyy'), 3, 6017, to_date('30-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061231013621, to_date('31-12-2006', 'dd-mm-yyyy'), to_date('14-01-2007', 'dd-mm-yyyy'), 4, 5811, to_date('04-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050219013622, to_date('19-02-2005', 'dd-mm-yyyy'), to_date('05-03-2005', 'dd-mm-yyyy'), 3, 4370, to_date('21-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061221013623, to_date('21-12-2006', 'dd-mm-yyyy'), to_date('04-01-2007', 'dd-mm-yyyy'), 2, 5597, to_date('09-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060225013624, to_date('25-02-2006', 'dd-mm-yyyy'), to_date('11-03-2006', 'dd-mm-yyyy'), 4, 5370, to_date('02-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426013625, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 3, 2243, to_date('08-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070205013626, to_date('05-02-2007', 'dd-mm-yyyy'), to_date('19-02-2007', 'dd-mm-yyyy'), 1, 6723, to_date('20-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090707013627, to_date('07-07-2009', 'dd-mm-yyyy'), to_date('21-07-2009', 'dd-mm-yyyy'), 2, 7415, to_date('25-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020731013628, to_date('31-07-2002', 'dd-mm-yyyy'), to_date('14-08-2002', 'dd-mm-yyyy'), 2, 2875, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040823013629, to_date('23-08-2004', 'dd-mm-yyyy'), to_date('06-09-2004', 'dd-mm-yyyy'), 1, 5752, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010417013630, to_date('17-04-2001', 'dd-mm-yyyy'), to_date('01-05-2001', 'dd-mm-yyyy'), 3, 4274, to_date('22-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041220013631, to_date('20-12-2004', 'dd-mm-yyyy'), to_date('03-01-2005', 'dd-mm-yyyy'), 4, 3846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530013632, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 4, 855, to_date('05-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090925013633, to_date('25-09-2009', 'dd-mm-yyyy'), to_date('09-10-2009', 'dd-mm-yyyy'), 3, 7555, to_date('13-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080604013634, to_date('04-06-2008', 'dd-mm-yyyy'), to_date('18-06-2008', 'dd-mm-yyyy'), 2, 6389, to_date('10-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130712013635, to_date('12-07-2013', 'dd-mm-yyyy'), to_date('26-07-2013', 'dd-mm-yyyy'), 2, 12035, to_date('24-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140215013636, to_date('15-02-2014', 'dd-mm-yyyy'), to_date('01-03-2014', 'dd-mm-yyyy'), 4, 10884, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071001013637, to_date('01-10-2007', 'dd-mm-yyyy'), to_date('15-10-2007', 'dd-mm-yyyy'), 3, 5327, to_date('09-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010424013638, to_date('24-04-2001', 'dd-mm-yyyy'), to_date('08-05-2001', 'dd-mm-yyyy'), 1, 2511, to_date('29-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030103013639, to_date('03-01-2003', 'dd-mm-yyyy'), to_date('17-01-2003', 'dd-mm-yyyy'), 1, 3752, to_date('15-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020213013640, to_date('13-02-2002', 'dd-mm-yyyy'), to_date('27-02-2002', 'dd-mm-yyyy'), 1, 3120, to_date('25-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040806013641, to_date('06-08-2004', 'dd-mm-yyyy'), to_date('20-08-2004', 'dd-mm-yyyy'), 2, 3502, to_date('24-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530013642, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 3, 4882, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070904013643, to_date('04-09-2007', 'dd-mm-yyyy'), to_date('18-09-2007', 'dd-mm-yyyy'), 3, 5538, to_date('08-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090318013644, to_date('18-03-2009', 'dd-mm-yyyy'), to_date('01-04-2009', 'dd-mm-yyyy'), 1, 7172, to_date('25-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020506013645, to_date('06-05-2002', 'dd-mm-yyyy'), to_date('20-05-2002', 'dd-mm-yyyy'), 2, 3244, to_date('24-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111012013646, to_date('12-10-2011', 'dd-mm-yyyy'), to_date('26-10-2011', 'dd-mm-yyyy'), 3, 6205, to_date('30-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121226013647, to_date('26-12-2012', 'dd-mm-yyyy'), to_date('09-01-2013', 'dd-mm-yyyy'), 3, 6465, to_date('09-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020712013648, to_date('12-07-2002', 'dd-mm-yyyy'), to_date('26-07-2002', 'dd-mm-yyyy'), 2, 2074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070504013649, to_date('04-05-2007', 'dd-mm-yyyy'), to_date('18-05-2007', 'dd-mm-yyyy'), 3, 4646, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080416013650, to_date('16-04-2008', 'dd-mm-yyyy'), to_date('30-04-2008', 'dd-mm-yyyy'), 3, 5403, to_date('21-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725013651, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 2, 7116, to_date('01-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010513013652, to_date('13-05-2001', 'dd-mm-yyyy'), to_date('27-05-2001', 'dd-mm-yyyy'), 1, 2548, to_date('19-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070707013653, to_date('07-07-2007', 'dd-mm-yyyy'), to_date('21-07-2007', 'dd-mm-yyyy'), 3, 5272, to_date('21-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604013654, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 3, 5761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130602013655, to_date('02-06-2013', 'dd-mm-yyyy'), to_date('16-06-2013', 'dd-mm-yyyy'), 3, 11762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120318013656, to_date('18-03-2012', 'dd-mm-yyyy'), to_date('01-04-2012', 'dd-mm-yyyy'), 4, 11191, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050529013657, to_date('29-05-2005', 'dd-mm-yyyy'), to_date('12-06-2005', 'dd-mm-yyyy'), 2, 6162, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050227013658, to_date('27-02-2005', 'dd-mm-yyyy'), to_date('13-03-2005', 'dd-mm-yyyy'), 3, 3822, to_date('10-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827013659, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 1, 2967, to_date('03-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121103013660, to_date('03-11-2012', 'dd-mm-yyyy'), to_date('17-11-2012', 'dd-mm-yyyy'), 3, 7649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130326013661, to_date('26-03-2013', 'dd-mm-yyyy'), to_date('09-04-2013', 'dd-mm-yyyy'), 4, 6949, to_date('04-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525013662, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 4, 2796, to_date('12-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110224013663, to_date('24-02-2011', 'dd-mm-yyyy'), to_date('10-03-2011', 'dd-mm-yyyy'), 2, 7536, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110301013664, to_date('01-03-2011', 'dd-mm-yyyy'), to_date('15-03-2011', 'dd-mm-yyyy'), 4, 8693, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020706013665, to_date('06-07-2002', 'dd-mm-yyyy'), to_date('20-07-2002', 'dd-mm-yyyy'), 3, 2707, to_date('17-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111013666, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 3, 7997, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902013667, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 3, 2582, to_date('04-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070918013668, to_date('18-09-2007', 'dd-mm-yyyy'), to_date('02-10-2007', 'dd-mm-yyyy'), 2, 6874, to_date('28-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329013669, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 2, 3283, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100218013670, to_date('18-02-2010', 'dd-mm-yyyy'), to_date('04-03-2010', 'dd-mm-yyyy'), 4, 6930, to_date('25-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020804013671, to_date('04-08-2002', 'dd-mm-yyyy'), to_date('18-08-2002', 'dd-mm-yyyy'), 3, 3895, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091212013672, to_date('12-12-2009', 'dd-mm-yyyy'), to_date('26-12-2009', 'dd-mm-yyyy'), 3, 4190, to_date('24-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061011013673, to_date('11-10-2006', 'dd-mm-yyyy'), to_date('25-10-2006', 'dd-mm-yyyy'), 1, 5314, to_date('20-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100120013674, to_date('20-01-2010', 'dd-mm-yyyy'), to_date('03-02-2010', 'dd-mm-yyyy'), 3, 7527, to_date('08-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010816013675, to_date('16-08-2001', 'dd-mm-yyyy'), to_date('30-08-2001', 'dd-mm-yyyy'), 3, 2000, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100602013676, to_date('02-06-2010', 'dd-mm-yyyy'), to_date('16-06-2010', 'dd-mm-yyyy'), 2, 11181, to_date('14-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130903013677, to_date('03-09-2013', 'dd-mm-yyyy'), to_date('17-09-2013', 'dd-mm-yyyy'), 3, 9389, to_date('12-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826013678, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 4, 4445, to_date('28-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050103013679, to_date('03-01-2005', 'dd-mm-yyyy'), to_date('17-01-2005', 'dd-mm-yyyy'), 4, 7970, to_date('19-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080914013680, to_date('14-09-2008', 'dd-mm-yyyy'), to_date('28-09-2008', 'dd-mm-yyyy'), 1, 5306, to_date('21-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010207013681, to_date('07-02-2001', 'dd-mm-yyyy'), to_date('21-02-2001', 'dd-mm-yyyy'), 4, 2217, to_date('12-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101215013682, to_date('15-12-2010', 'dd-mm-yyyy'), to_date('29-12-2010', 'dd-mm-yyyy'), 3, 5926, to_date('31-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051001013683, to_date('01-10-2005', 'dd-mm-yyyy'), to_date('15-10-2005', 'dd-mm-yyyy'), 2, 5629, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521013684, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 2, 3911, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010626013685, to_date('26-06-2001', 'dd-mm-yyyy'), to_date('10-07-2001', 'dd-mm-yyyy'), 2, 2033, to_date('05-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001024013686, to_date('24-10-2000', 'dd-mm-yyyy'), to_date('07-11-2000', 'dd-mm-yyyy'), 4, 1346, to_date('11-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091018013687, to_date('18-10-2009', 'dd-mm-yyyy'), to_date('01-11-2009', 'dd-mm-yyyy'), 3, 6347, to_date('24-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080306013688, to_date('06-03-2008', 'dd-mm-yyyy'), to_date('20-03-2008', 'dd-mm-yyyy'), 1, 5649, to_date('23-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070504013689, to_date('04-05-2007', 'dd-mm-yyyy'), to_date('18-05-2007', 'dd-mm-yyyy'), 3, 8678, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080616013690, to_date('16-06-2008', 'dd-mm-yyyy'), to_date('30-06-2008', 'dd-mm-yyyy'), 3, 6133, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130914013691, to_date('14-09-2013', 'dd-mm-yyyy'), to_date('28-09-2013', 'dd-mm-yyyy'), 3, 8789, to_date('20-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070701013692, to_date('01-07-2007', 'dd-mm-yyyy'), to_date('15-07-2007', 'dd-mm-yyyy'), 2, 5633, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116013693, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 4, 7434, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060316013694, to_date('16-03-2006', 'dd-mm-yyyy'), to_date('30-03-2006', 'dd-mm-yyyy'), 3, 3420, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120912013695, to_date('12-09-2012', 'dd-mm-yyyy'), to_date('26-09-2012', 'dd-mm-yyyy'), 3, 9265, to_date('14-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010617013696, to_date('17-06-2001', 'dd-mm-yyyy'), to_date('01-07-2001', 'dd-mm-yyyy'), 3, 1881, to_date('26-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090901013697, to_date('01-09-2009', 'dd-mm-yyyy'), to_date('15-09-2009', 'dd-mm-yyyy'), 1, 5485, to_date('04-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030624013698, to_date('24-06-2003', 'dd-mm-yyyy'), to_date('08-07-2003', 'dd-mm-yyyy'), 4, 3367, to_date('06-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040328013699, to_date('28-03-2004', 'dd-mm-yyyy'), to_date('11-04-2004', 'dd-mm-yyyy'), 1, 2071, to_date('13-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120103013700, to_date('03-01-2012', 'dd-mm-yyyy'), to_date('17-01-2012', 'dd-mm-yyyy'), 1, 11463, to_date('13-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110118013701, to_date('18-01-2011', 'dd-mm-yyyy'), to_date('01-02-2011', 'dd-mm-yyyy'), 3, 8886, to_date('19-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416013702, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 3, 4290, to_date('05-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131108013703, to_date('08-11-2013', 'dd-mm-yyyy'), to_date('22-11-2013', 'dd-mm-yyyy'), 3, 5136, to_date('19-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110109013704, to_date('09-01-2011', 'dd-mm-yyyy'), to_date('23-01-2011', 'dd-mm-yyyy'), 4, 6856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110425013705, to_date('25-04-2011', 'dd-mm-yyyy'), to_date('09-05-2011', 'dd-mm-yyyy'), 3, 5958, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409016231, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 1, 3930, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091030016232, to_date('30-10-2009', 'dd-mm-yyyy'), to_date('13-11-2009', 'dd-mm-yyyy'), 2, 7503, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131220016233, to_date('20-12-2013', 'dd-mm-yyyy'), to_date('03-01-2014', 'dd-mm-yyyy'), 1, 12222, to_date('26-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120921016234, to_date('21-09-2012', 'dd-mm-yyyy'), to_date('05-10-2012', 'dd-mm-yyyy'), 1, 8601, to_date('30-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020626016235, to_date('26-06-2002', 'dd-mm-yyyy'), to_date('10-07-2002', 'dd-mm-yyyy'), 2, 3132, to_date('01-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060212016236, to_date('12-02-2006', 'dd-mm-yyyy'), to_date('26-02-2006', 'dd-mm-yyyy'), 2, 8982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110203016237, to_date('03-02-2011', 'dd-mm-yyyy'), to_date('17-02-2011', 'dd-mm-yyyy'), 2, 7827, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131023016238, to_date('23-10-2013', 'dd-mm-yyyy'), to_date('06-11-2013', 'dd-mm-yyyy'), 1, 9218, to_date('09-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090213016239, to_date('13-02-2009', 'dd-mm-yyyy'), to_date('27-02-2009', 'dd-mm-yyyy'), 1, 7431, to_date('04-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090517016240, to_date('17-05-2009', 'dd-mm-yyyy'), to_date('31-05-2009', 'dd-mm-yyyy'), 2, 6775, to_date('26-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070402016241, to_date('02-04-2007', 'dd-mm-yyyy'), to_date('16-04-2007', 'dd-mm-yyyy'), 2, 4753, to_date('09-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218016242, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 1, 7362, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040215016243, to_date('15-02-2004', 'dd-mm-yyyy'), to_date('29-02-2004', 'dd-mm-yyyy'), 2, 4471, to_date('18-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110016244, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 2, 3882, to_date('21-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090901016245, to_date('01-09-2009', 'dd-mm-yyyy'), to_date('15-09-2009', 'dd-mm-yyyy'), 2, 6367, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209016246, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 2, 4222, to_date('18-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040914016247, to_date('14-09-2004', 'dd-mm-yyyy'), to_date('28-09-2004', 'dd-mm-yyyy'), 1, 4622, to_date('04-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427016248, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 2, 4457, to_date('06-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040517016249, to_date('17-05-2004', 'dd-mm-yyyy'), to_date('31-05-2004', 'dd-mm-yyyy'), 1, 3042, to_date('26-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060101016250, to_date('01-01-2006', 'dd-mm-yyyy'), to_date('15-01-2006', 'dd-mm-yyyy'), 2, 6891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071017016251, to_date('17-10-2007', 'dd-mm-yyyy'), to_date('31-10-2007', 'dd-mm-yyyy'), 2, 4707, to_date('30-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020515016252, to_date('15-05-2002', 'dd-mm-yyyy'), to_date('29-05-2002', 'dd-mm-yyyy'), 1, 1707, to_date('30-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130905016253, to_date('05-09-2013', 'dd-mm-yyyy'), to_date('19-09-2013', 'dd-mm-yyyy'), 2, 8740, to_date('14-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110623016254, to_date('23-06-2011', 'dd-mm-yyyy'), to_date('07-07-2011', 'dd-mm-yyyy'), 2, 7577, to_date('05-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526016255, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 2, 8247, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000302016256, to_date('02-03-2000', 'dd-mm-yyyy'), to_date('16-03-2000', 'dd-mm-yyyy'), 1, 820, to_date('11-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000121016257, to_date('21-01-2000', 'dd-mm-yyyy'), to_date('04-02-2000', 'dd-mm-yyyy'), 2, 891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913016258, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 1, 4323, to_date('28-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091113016259, to_date('13-11-2009', 'dd-mm-yyyy'), to_date('27-11-2009', 'dd-mm-yyyy'), 2, 5626, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030404016260, to_date('04-04-2003', 'dd-mm-yyyy'), to_date('18-04-2003', 'dd-mm-yyyy'), 2, 2424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120324016261, to_date('24-03-2012', 'dd-mm-yyyy'), to_date('07-04-2012', 'dd-mm-yyyy'), 1, 6039, to_date('29-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110101016262, to_date('01-01-2011', 'dd-mm-yyyy'), to_date('15-01-2011', 'dd-mm-yyyy'), 1, 7650, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010308016263, to_date('08-03-2001', 'dd-mm-yyyy'), to_date('22-03-2001', 'dd-mm-yyyy'), 1, 2001, to_date('14-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110119016264, to_date('19-01-2011', 'dd-mm-yyyy'), to_date('02-02-2011', 'dd-mm-yyyy'), 1, 8032, to_date('05-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729016265, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 1, 7581, to_date('05-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000529016266, to_date('29-05-2000', 'dd-mm-yyyy'), to_date('12-06-2000', 'dd-mm-yyyy'), 1, 2529, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813016267, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 2, 5037, to_date('17-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010524016268, to_date('24-05-2001', 'dd-mm-yyyy'), to_date('07-06-2001', 'dd-mm-yyyy'), 1, 1838, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060911016269, to_date('11-09-2006', 'dd-mm-yyyy'), to_date('25-09-2006', 'dd-mm-yyyy'), 1, 3364, to_date('27-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071225016270, to_date('25-12-2007', 'dd-mm-yyyy'), to_date('08-01-2008', 'dd-mm-yyyy'), 2, 6121, to_date('29-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100107016271, to_date('07-01-2010', 'dd-mm-yyyy'), to_date('21-01-2010', 'dd-mm-yyyy'), 2, 6552, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916016272, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 1, 5367, to_date('18-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121204016273, to_date('04-12-2012', 'dd-mm-yyyy'), to_date('18-12-2012', 'dd-mm-yyyy'), 2, 7126, to_date('13-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202016274, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 2, 3694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060518016275, to_date('18-05-2006', 'dd-mm-yyyy'), to_date('01-06-2006', 'dd-mm-yyyy'), 2, 3695, to_date('31-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061120016276, to_date('20-11-2006', 'dd-mm-yyyy'), to_date('04-12-2006', 'dd-mm-yyyy'), 1, 4543, to_date('09-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080708016277, to_date('08-07-2008', 'dd-mm-yyyy'), to_date('22-07-2008', 'dd-mm-yyyy'), 2, 5882, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050617016278, to_date('17-06-2005', 'dd-mm-yyyy'), to_date('01-07-2005', 'dd-mm-yyyy'), 2, 2943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110813016279, to_date('13-08-2011', 'dd-mm-yyyy'), to_date('27-08-2011', 'dd-mm-yyyy'), 2, 8085, to_date('31-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120607016280, to_date('07-06-2012', 'dd-mm-yyyy'), to_date('21-06-2012', 'dd-mm-yyyy'), 2, 8485, to_date('25-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071006016281, to_date('06-10-2007', 'dd-mm-yyyy'), to_date('20-10-2007', 'dd-mm-yyyy'), 1, 6505, to_date('09-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101202016282, to_date('02-12-2010', 'dd-mm-yyyy'), to_date('16-12-2010', 'dd-mm-yyyy'), 1, 6258, to_date('18-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202016283, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 1, 3346, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110506016284, to_date('06-05-2011', 'dd-mm-yyyy'), to_date('20-05-2011', 'dd-mm-yyyy'), 2, 5831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010414016285, to_date('14-04-2001', 'dd-mm-yyyy'), to_date('28-04-2001', 'dd-mm-yyyy'), 2, 2403, to_date('15-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131016286, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 2, 4053, to_date('03-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040405016287, to_date('05-04-2004', 'dd-mm-yyyy'), to_date('19-04-2004', 'dd-mm-yyyy'), 2, 3820, to_date('24-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090121016288, to_date('21-01-2009', 'dd-mm-yyyy'), to_date('04-02-2009', 'dd-mm-yyyy'), 1, 6672, to_date('24-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110831016289, to_date('31-08-2011', 'dd-mm-yyyy'), to_date('14-09-2011', 'dd-mm-yyyy'), 1, 7223, to_date('16-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628016290, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 2, 8036, to_date('13-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901016291, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 2, 7585, to_date('06-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120307016292, to_date('07-03-2012', 'dd-mm-yyyy'), to_date('21-03-2012', 'dd-mm-yyyy'), 2, 11976, to_date('24-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040724016293, to_date('24-07-2004', 'dd-mm-yyyy'), to_date('07-08-2004', 'dd-mm-yyyy'), 2, 4379, to_date('02-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140322016294, to_date('22-03-2014', 'dd-mm-yyyy'), to_date('05-04-2014', 'dd-mm-yyyy'), 2, 8150, to_date('31-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030606016295, to_date('06-06-2003', 'dd-mm-yyyy'), to_date('20-06-2003', 'dd-mm-yyyy'), 2, 2860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011208016296, to_date('08-12-2001', 'dd-mm-yyyy'), to_date('22-12-2001', 'dd-mm-yyyy'), 1, 2000, to_date('19-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711016297, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 2, 10719, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070415016298, to_date('15-04-2007', 'dd-mm-yyyy'), to_date('29-04-2007', 'dd-mm-yyyy'), 2, 6317, to_date('27-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120324016299, to_date('24-03-2012', 'dd-mm-yyyy'), to_date('07-04-2012', 'dd-mm-yyyy'), 1, 9724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410016300, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 2, 2742, to_date('19-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050213016301, to_date('13-02-2005', 'dd-mm-yyyy'), to_date('27-02-2005', 'dd-mm-yyyy'), 2, 4462, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070525016302, to_date('25-05-2007', 'dd-mm-yyyy'), to_date('08-06-2007', 'dd-mm-yyyy'), 2, 5888, to_date('06-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070415016303, to_date('15-04-2007', 'dd-mm-yyyy'), to_date('29-04-2007', 'dd-mm-yyyy'), 2, 5954, to_date('19-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090418016304, to_date('18-04-2009', 'dd-mm-yyyy'), to_date('02-05-2009', 'dd-mm-yyyy'), 2, 6414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050318016305, to_date('18-03-2005', 'dd-mm-yyyy'), to_date('01-04-2005', 'dd-mm-yyyy'), 2, 4204, to_date('03-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050205016306, to_date('05-02-2005', 'dd-mm-yyyy'), to_date('19-02-2005', 'dd-mm-yyyy'), 1, 4145, to_date('18-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110924016307, to_date('24-09-2011', 'dd-mm-yyyy'), to_date('08-10-2011', 'dd-mm-yyyy'), 1, 6269, to_date('06-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080623016308, to_date('23-06-2008', 'dd-mm-yyyy'), to_date('07-07-2008', 'dd-mm-yyyy'), 2, 7466, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040517016309, to_date('17-05-2004', 'dd-mm-yyyy'), to_date('31-05-2004', 'dd-mm-yyyy'), 2, 3282, to_date('03-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000105016310, to_date('05-01-2000', 'dd-mm-yyyy'), to_date('19-01-2000', 'dd-mm-yyyy'), 2, 1284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051015016311, to_date('15-10-2005', 'dd-mm-yyyy'), to_date('29-10-2005', 'dd-mm-yyyy'), 2, 3781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080913016312, to_date('13-09-2008', 'dd-mm-yyyy'), to_date('27-09-2008', 'dd-mm-yyyy'), 1, 5054, to_date('03-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000722016313, to_date('22-07-2000', 'dd-mm-yyyy'), to_date('05-08-2000', 'dd-mm-yyyy'), 1, 2985, to_date('01-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060810016314, to_date('10-08-2006', 'dd-mm-yyyy'), to_date('24-08-2006', 'dd-mm-yyyy'), 2, 5974, to_date('29-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130518016315, to_date('18-05-2013', 'dd-mm-yyyy'), to_date('01-06-2013', 'dd-mm-yyyy'), 2, 7818, to_date('26-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111118016316, to_date('18-11-2011', 'dd-mm-yyyy'), to_date('02-12-2011', 'dd-mm-yyyy'), 2, 7601, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218016317, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 2, 2522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020218016318, to_date('18-02-2002', 'dd-mm-yyyy'), to_date('04-03-2002', 'dd-mm-yyyy'), 2, 4931, to_date('06-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827016319, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 2, 3015, to_date('05-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050707016320, to_date('07-07-2005', 'dd-mm-yyyy'), to_date('21-07-2005', 'dd-mm-yyyy'), 2, 3243, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906016321, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 2, 4912, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429016322, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 1, 4414, to_date('06-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061114016323, to_date('14-11-2006', 'dd-mm-yyyy'), to_date('28-11-2006', 'dd-mm-yyyy'), 2, 6476, to_date('02-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010016324, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 2, 5588, to_date('12-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010403016325, to_date('03-04-2001', 'dd-mm-yyyy'), to_date('17-04-2001', 'dd-mm-yyyy'), 1, 1470, to_date('22-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427016326, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 2, 3145, to_date('07-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060319016327, to_date('19-03-2006', 'dd-mm-yyyy'), to_date('02-04-2006', 'dd-mm-yyyy'), 2, 5898, to_date('07-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080407016328, to_date('07-04-2008', 'dd-mm-yyyy'), to_date('21-04-2008', 'dd-mm-yyyy'), 2, 5197, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110201016329, to_date('01-02-2011', 'dd-mm-yyyy'), to_date('15-02-2011', 'dd-mm-yyyy'), 2, 7495, to_date('09-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041024016330, to_date('24-10-2004', 'dd-mm-yyyy'), to_date('07-11-2004', 'dd-mm-yyyy'), 1, 3666, to_date('30-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050428016331, to_date('28-04-2005', 'dd-mm-yyyy'), to_date('12-05-2005', 'dd-mm-yyyy'), 1, 3966, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040719016332, to_date('19-07-2004', 'dd-mm-yyyy'), to_date('02-08-2004', 'dd-mm-yyyy'), 2, 5424, to_date('02-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100308016333, to_date('08-03-2010', 'dd-mm-yyyy'), to_date('22-03-2010', 'dd-mm-yyyy'), 2, 9899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405016334, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 2, 4155, to_date('06-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111116016335, to_date('16-11-2011', 'dd-mm-yyyy'), to_date('30-11-2011', 'dd-mm-yyyy'), 2, 9719, to_date('26-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201016336, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 1, 4758, to_date('09-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040115016337, to_date('15-01-2004', 'dd-mm-yyyy'), to_date('29-01-2004', 'dd-mm-yyyy'), 1, 4584, to_date('26-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140317016338, to_date('17-03-2014', 'dd-mm-yyyy'), to_date('31-03-2014', 'dd-mm-yyyy'), 2, 10438, to_date('20-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110830016339, to_date('30-08-2011', 'dd-mm-yyyy'), to_date('13-09-2011', 'dd-mm-yyyy'), 1, 7288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090828016340, to_date('28-08-2009', 'dd-mm-yyyy'), to_date('11-09-2009', 'dd-mm-yyyy'), 2, 6532, to_date('12-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030704016341, to_date('04-07-2003', 'dd-mm-yyyy'), to_date('18-07-2003', 'dd-mm-yyyy'), 2, 4271, to_date('21-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050610016342, to_date('10-06-2005', 'dd-mm-yyyy'), to_date('24-06-2005', 'dd-mm-yyyy'), 2, 3650, to_date('11-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010430016343, to_date('30-04-2001', 'dd-mm-yyyy'), to_date('14-05-2001', 'dd-mm-yyyy'), 1, 2026, to_date('03-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120211016344, to_date('11-02-2012', 'dd-mm-yyyy'), to_date('25-02-2012', 'dd-mm-yyyy'), 2, 8823, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000502016345, to_date('02-05-2000', 'dd-mm-yyyy'), to_date('16-05-2000', 'dd-mm-yyyy'), 2, 968, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206016346, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 1, 6540, to_date('15-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531016347, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 1, 2150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020706016348, to_date('06-07-2002', 'dd-mm-yyyy'), to_date('20-07-2002', 'dd-mm-yyyy'), 2, 4356, to_date('22-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040503016349, to_date('03-05-2004', 'dd-mm-yyyy'), to_date('17-05-2004', 'dd-mm-yyyy'), 2, 4919, to_date('20-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111103016350, to_date('03-11-2011', 'dd-mm-yyyy'), to_date('17-11-2011', 'dd-mm-yyyy'), 1, 9558, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130315016351, to_date('15-03-2013', 'dd-mm-yyyy'), to_date('29-03-2013', 'dd-mm-yyyy'), 2, 10217, to_date('02-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120628016352, to_date('28-06-2012', 'dd-mm-yyyy'), to_date('12-07-2012', 'dd-mm-yyyy'), 2, 4680, to_date('17-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050304016353, to_date('04-03-2005', 'dd-mm-yyyy'), to_date('18-03-2005', 'dd-mm-yyyy'), 1, 4403, to_date('07-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091219016354, to_date('19-12-2009', 'dd-mm-yyyy'), to_date('02-01-2010', 'dd-mm-yyyy'), 2, 7298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000722016355, to_date('22-07-2000', 'dd-mm-yyyy'), to_date('05-08-2000', 'dd-mm-yyyy'), 2, 3746, to_date('06-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110125016356, to_date('25-01-2011', 'dd-mm-yyyy'), to_date('08-02-2011', 'dd-mm-yyyy'), 2, 4615, to_date('03-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120316016357, to_date('16-03-2012', 'dd-mm-yyyy'), to_date('30-03-2012', 'dd-mm-yyyy'), 1, 6531, to_date('03-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020214016358, to_date('14-02-2002', 'dd-mm-yyyy'), to_date('28-02-2002', 'dd-mm-yyyy'), 2, 2649, to_date('17-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040208016359, to_date('08-02-2004', 'dd-mm-yyyy'), to_date('22-02-2004', 'dd-mm-yyyy'), 2, 4289, to_date('28-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000306016360, to_date('06-03-2000', 'dd-mm-yyyy'), to_date('20-03-2000', 'dd-mm-yyyy'), 2, 3069, to_date('09-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120124016361, to_date('24-01-2012', 'dd-mm-yyyy'), to_date('07-02-2012', 'dd-mm-yyyy'), 1, 6409, to_date('12-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101113016362, to_date('13-11-2010', 'dd-mm-yyyy'), to_date('27-11-2010', 'dd-mm-yyyy'), 1, 5235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080308016363, to_date('08-03-2008', 'dd-mm-yyyy'), to_date('22-03-2008', 'dd-mm-yyyy'), 1, 8505, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080427016364, to_date('27-04-2008', 'dd-mm-yyyy'), to_date('11-05-2008', 'dd-mm-yyyy'), 1, 7069, to_date('14-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070227016365, to_date('27-02-2007', 'dd-mm-yyyy'), to_date('13-03-2007', 'dd-mm-yyyy'), 2, 6349, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061211016366, to_date('11-12-2006', 'dd-mm-yyyy'), to_date('25-12-2006', 'dd-mm-yyyy'), 1, 5660, to_date('20-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100605016367, to_date('05-06-2010', 'dd-mm-yyyy'), to_date('19-06-2010', 'dd-mm-yyyy'), 2, 7472, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903016368, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 1, 5590, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021123016369, to_date('23-11-2002', 'dd-mm-yyyy'), to_date('07-12-2002', 'dd-mm-yyyy'), 1, 1793, to_date('26-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302016370, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 2, 3397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206016371, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 1, 6183, to_date('24-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020202016372, to_date('02-02-2002', 'dd-mm-yyyy'), to_date('16-02-2002', 'dd-mm-yyyy'), 1, 3645, to_date('19-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010626016373, to_date('26-06-2001', 'dd-mm-yyyy'), to_date('10-07-2001', 'dd-mm-yyyy'), 2, 3368, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001203016374, to_date('03-12-2000', 'dd-mm-yyyy'), to_date('17-12-2000', 'dd-mm-yyyy'), 1, 1771, to_date('12-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131121016375, to_date('21-11-2013', 'dd-mm-yyyy'), to_date('05-12-2013', 'dd-mm-yyyy'), 1, 9782, to_date('25-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000303016376, to_date('03-03-2000', 'dd-mm-yyyy'), to_date('17-03-2000', 'dd-mm-yyyy'), 2, 1260, to_date('07-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131011016377, to_date('11-10-2013', 'dd-mm-yyyy'), to_date('25-10-2013', 'dd-mm-yyyy'), 1, 10133, to_date('26-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128016378, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 2, 8271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041213016379, to_date('13-12-2004', 'dd-mm-yyyy'), to_date('27-12-2004', 'dd-mm-yyyy'), 2, 3518, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121217016380, to_date('17-12-2012', 'dd-mm-yyyy'), to_date('31-12-2012', 'dd-mm-yyyy'), 1, 4702, to_date('19-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223016381, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 2, 7586, to_date('27-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080804016382, to_date('04-08-2008', 'dd-mm-yyyy'), to_date('18-08-2008', 'dd-mm-yyyy'), 2, 7532, to_date('20-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011217016383, to_date('17-12-2001', 'dd-mm-yyyy'), to_date('31-12-2001', 'dd-mm-yyyy'), 1, 3135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001105016384, to_date('05-11-2000', 'dd-mm-yyyy'), to_date('19-11-2000', 'dd-mm-yyyy'), 2, 1006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725016385, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 2, 5911, to_date('11-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015016386, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 1, 3217, to_date('23-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100325016387, to_date('25-03-2010', 'dd-mm-yyyy'), to_date('08-04-2010', 'dd-mm-yyyy'), 2, 6694, to_date('12-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111124016388, to_date('24-11-2011', 'dd-mm-yyyy'), to_date('08-12-2011', 'dd-mm-yyyy'), 1, 9070, to_date('09-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090727016389, to_date('27-07-2009', 'dd-mm-yyyy'), to_date('10-08-2009', 'dd-mm-yyyy'), 2, 8991, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091003016390, to_date('03-10-2009', 'dd-mm-yyyy'), to_date('17-10-2009', 'dd-mm-yyyy'), 2, 8587, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030528016391, to_date('28-05-2003', 'dd-mm-yyyy'), to_date('11-06-2003', 'dd-mm-yyyy'), 2, 3190, to_date('30-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130422016392, to_date('22-04-2013', 'dd-mm-yyyy'), to_date('06-05-2013', 'dd-mm-yyyy'), 1, 7953, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020710016393, to_date('10-07-2002', 'dd-mm-yyyy'), to_date('24-07-2002', 'dd-mm-yyyy'), 1, 3867, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100326016394, to_date('26-03-2010', 'dd-mm-yyyy'), to_date('09-04-2010', 'dd-mm-yyyy'), 2, 7221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023016395, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 1, 3329, to_date('28-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003016396, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 2, 7333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051125016397, to_date('25-11-2005', 'dd-mm-yyyy'), to_date('09-12-2005', 'dd-mm-yyyy'), 1, 4770, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110214016398, to_date('14-02-2011', 'dd-mm-yyyy'), to_date('28-02-2011', 'dd-mm-yyyy'), 2, 5773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030425016230, to_date('25-04-2003', 'dd-mm-yyyy'), to_date('09-05-2003', 'dd-mm-yyyy'), 1, 4737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110815010875, to_date('15-08-2011', 'dd-mm-yyyy'), to_date('29-08-2011', 'dd-mm-yyyy'), 5, 9153, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110401010876, to_date('01-04-2011', 'dd-mm-yyyy'), to_date('15-04-2011', 'dd-mm-yyyy'), 5, 4273, to_date('14-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010831010877, to_date('31-08-2001', 'dd-mm-yyyy'), to_date('14-09-2001', 'dd-mm-yyyy'), 5, 2445, to_date('06-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120930010878, to_date('30-09-2012', 'dd-mm-yyyy'), to_date('14-10-2012', 'dd-mm-yyyy'), 12, 10224, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430010879, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 9, 8130, to_date('01-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215010880, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 5, 5550, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100116010881, to_date('16-01-2010', 'dd-mm-yyyy'), to_date('30-01-2010', 'dd-mm-yyyy'), 11, 8020, to_date('21-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041220010882, to_date('20-12-2004', 'dd-mm-yyyy'), to_date('03-01-2005', 'dd-mm-yyyy'), 6, 2078, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140309010883, to_date('09-03-2014', 'dd-mm-yyyy'), to_date('23-03-2014', 'dd-mm-yyyy'), 2, 7435, to_date('22-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915010884, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 6, 11928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070223010885, to_date('23-02-2007', 'dd-mm-yyyy'), to_date('09-03-2007', 'dd-mm-yyyy'), 8, 6888, to_date('01-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110419010886, to_date('19-04-2011', 'dd-mm-yyyy'), to_date('03-05-2011', 'dd-mm-yyyy'), 9, 8587, to_date('05-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040112010887, to_date('12-01-2004', 'dd-mm-yyyy'), to_date('26-01-2004', 'dd-mm-yyyy'), 8, 2562, to_date('18-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130917010888, to_date('17-09-2013', 'dd-mm-yyyy'), to_date('01-10-2013', 'dd-mm-yyyy'), 8, 9407, to_date('19-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030421010889, to_date('21-04-2003', 'dd-mm-yyyy'), to_date('05-05-2003', 'dd-mm-yyyy'), 9, 4439, to_date('23-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051215010890, to_date('15-12-2005', 'dd-mm-yyyy'), to_date('29-12-2005', 'dd-mm-yyyy'), 3, 4016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060208010891, to_date('08-02-2006', 'dd-mm-yyyy'), to_date('22-02-2006', 'dd-mm-yyyy'), 3, 4525, to_date('14-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010520010892, to_date('20-05-2001', 'dd-mm-yyyy'), to_date('03-06-2001', 'dd-mm-yyyy'), 9, 2947, to_date('29-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726010893, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 2, 7914, to_date('05-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129010894, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 11, 5664, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040803010895, to_date('03-08-2004', 'dd-mm-yyyy'), to_date('17-08-2004', 'dd-mm-yyyy'), 1, 2353, to_date('18-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105010896, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 3, 5607, to_date('21-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100521010897, to_date('21-05-2010', 'dd-mm-yyyy'), to_date('04-06-2010', 'dd-mm-yyyy'), 1, 10259, to_date('04-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906010898, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 1, 6821, to_date('24-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108010899, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 4, 2151, to_date('23-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013010900, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 10, 3522, to_date('26-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120319010901, to_date('19-03-2012', 'dd-mm-yyyy'), to_date('02-04-2012', 'dd-mm-yyyy'), 11, 6711, to_date('08-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907010902, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 11, 2077, to_date('19-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090923010903, to_date('23-09-2009', 'dd-mm-yyyy'), to_date('07-10-2009', 'dd-mm-yyyy'), 1, 7463, to_date('02-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511010904, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 4, 2044, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090724010905, to_date('24-07-2009', 'dd-mm-yyyy'), to_date('07-08-2009', 'dd-mm-yyyy'), 4, 8305, to_date('02-08-2009', 'dd-mm-yyyy'));
commit;
prompt 12000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030228010906, to_date('28-02-2003', 'dd-mm-yyyy'), to_date('14-03-2003', 'dd-mm-yyyy'), 5, 4550, to_date('12-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119010907, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 10, 1069, to_date('08-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070121010908, to_date('21-01-2007', 'dd-mm-yyyy'), to_date('04-02-2007', 'dd-mm-yyyy'), 5, 5056, to_date('08-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060708010909, to_date('08-07-2006', 'dd-mm-yyyy'), to_date('22-07-2006', 'dd-mm-yyyy'), 4, 4090, to_date('15-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803010910, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 11, 9488, to_date('17-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030115010911, to_date('15-01-2003', 'dd-mm-yyyy'), to_date('29-01-2003', 'dd-mm-yyyy'), 11, 2149, to_date('19-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110129010912, to_date('29-01-2011', 'dd-mm-yyyy'), to_date('12-02-2011', 'dd-mm-yyyy'), 5, 6387, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040104010913, to_date('04-01-2004', 'dd-mm-yyyy'), to_date('18-01-2004', 'dd-mm-yyyy'), 11, 4250, to_date('15-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050609010914, to_date('09-06-2005', 'dd-mm-yyyy'), to_date('23-06-2005', 'dd-mm-yyyy'), 3, 3883, to_date('27-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106010915, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 12, 6654, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101222010916, to_date('22-12-2010', 'dd-mm-yyyy'), to_date('05-01-2011', 'dd-mm-yyyy'), 8, 5856, to_date('07-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080316010917, to_date('16-03-2008', 'dd-mm-yyyy'), to_date('30-03-2008', 'dd-mm-yyyy'), 2, 5162, to_date('22-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110104010918, to_date('04-01-2011', 'dd-mm-yyyy'), to_date('18-01-2011', 'dd-mm-yyyy'), 4, 6663, to_date('15-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040304010919, to_date('04-03-2004', 'dd-mm-yyyy'), to_date('18-03-2004', 'dd-mm-yyyy'), 7, 4139, to_date('11-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707010920, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 9, 9632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100318010921, to_date('18-03-2010', 'dd-mm-yyyy'), to_date('01-04-2010', 'dd-mm-yyyy'), 6, 8272, to_date('06-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030307010922, to_date('07-03-2003', 'dd-mm-yyyy'), to_date('21-03-2003', 'dd-mm-yyyy'), 5, 2656, to_date('20-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051220010923, to_date('20-12-2005', 'dd-mm-yyyy'), to_date('03-01-2006', 'dd-mm-yyyy'), 5, 5310, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010428010924, to_date('28-04-2001', 'dd-mm-yyyy'), to_date('12-05-2001', 'dd-mm-yyyy'), 1, 3528, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070205010925, to_date('05-02-2007', 'dd-mm-yyyy'), to_date('19-02-2007', 'dd-mm-yyyy'), 7, 4842, to_date('22-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213010926, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 8, 5558, to_date('15-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060608010927, to_date('08-06-2006', 'dd-mm-yyyy'), to_date('22-06-2006', 'dd-mm-yyyy'), 7, 3719, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727010928, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 3, 3397, to_date('13-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131020010929, to_date('20-10-2013', 'dd-mm-yyyy'), to_date('03-11-2013', 'dd-mm-yyyy'), 4, 11026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121108010930, to_date('08-11-2012', 'dd-mm-yyyy'), to_date('22-11-2012', 'dd-mm-yyyy'), 10, 8717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100505010931, to_date('05-05-2010', 'dd-mm-yyyy'), to_date('19-05-2010', 'dd-mm-yyyy'), 11, 6996, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100803010932, to_date('03-08-2010', 'dd-mm-yyyy'), to_date('17-08-2010', 'dd-mm-yyyy'), 12, 7522, to_date('13-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728010933, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 5, 8075, to_date('31-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827010934, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 9, 3269, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010827010935, to_date('27-08-2001', 'dd-mm-yyyy'), to_date('10-09-2001', 'dd-mm-yyyy'), 10, 1552, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070612010936, to_date('12-06-2007', 'dd-mm-yyyy'), to_date('26-06-2007', 'dd-mm-yyyy'), 4, 5610, to_date('22-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140428010937, to_date('28-04-2014', 'dd-mm-yyyy'), to_date('12-05-2014', 'dd-mm-yyyy'), 6, 8408, to_date('13-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528010938, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 12, 6397, to_date('07-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010521010939, to_date('21-05-2001', 'dd-mm-yyyy'), to_date('04-06-2001', 'dd-mm-yyyy'), 4, 2649, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060121010940, to_date('21-01-2006', 'dd-mm-yyyy'), to_date('04-02-2006', 'dd-mm-yyyy'), 8, 5151, to_date('01-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050101010941, to_date('01-01-2005', 'dd-mm-yyyy'), to_date('15-01-2005', 'dd-mm-yyyy'), 12, 2471, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001110010942, to_date('10-11-2000', 'dd-mm-yyyy'), to_date('24-11-2000', 'dd-mm-yyyy'), 2, 735, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040425010943, to_date('25-04-2004', 'dd-mm-yyyy'), to_date('09-05-2004', 'dd-mm-yyyy'), 11, 4260, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403010944, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 4, 1535, to_date('13-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090127010945, to_date('27-01-2009', 'dd-mm-yyyy'), to_date('10-02-2009', 'dd-mm-yyyy'), 5, 8711, to_date('08-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120428010946, to_date('28-04-2012', 'dd-mm-yyyy'), to_date('12-05-2012', 'dd-mm-yyyy'), 11, 8657, to_date('29-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071010010947, to_date('10-10-2007', 'dd-mm-yyyy'), to_date('24-10-2007', 'dd-mm-yyyy'), 3, 5597, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030606010948, to_date('06-06-2003', 'dd-mm-yyyy'), to_date('20-06-2003', 'dd-mm-yyyy'), 3, 2423, to_date('21-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090619010949, to_date('19-06-2009', 'dd-mm-yyyy'), to_date('03-07-2009', 'dd-mm-yyyy'), 6, 11385, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710010950, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 5, 5631, to_date('18-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000318010951, to_date('18-03-2000', 'dd-mm-yyyy'), to_date('01-04-2000', 'dd-mm-yyyy'), 10, 2826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050505010952, to_date('05-05-2005', 'dd-mm-yyyy'), to_date('19-05-2005', 'dd-mm-yyyy'), 8, 3740, to_date('06-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050514010953, to_date('14-05-2005', 'dd-mm-yyyy'), to_date('28-05-2005', 'dd-mm-yyyy'), 8, 3174, to_date('16-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408010954, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 4, 8246, to_date('21-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010727010955, to_date('27-07-2001', 'dd-mm-yyyy'), to_date('10-08-2001', 'dd-mm-yyyy'), 4, 1103, to_date('29-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530010956, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 10, 5652, to_date('02-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000725010957, to_date('25-07-2000', 'dd-mm-yyyy'), to_date('08-08-2000', 'dd-mm-yyyy'), 11, 2092, to_date('05-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323010958, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 1, 11565, to_date('28-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804010959, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 7, 8512, to_date('23-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008010960, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 10, 4069, to_date('25-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131201010961, to_date('01-12-2013', 'dd-mm-yyyy'), to_date('15-12-2013', 'dd-mm-yyyy'), 8, 9036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110010962, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 9, 8348, to_date('22-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110303010963, to_date('03-03-2011', 'dd-mm-yyyy'), to_date('17-03-2011', 'dd-mm-yyyy'), 11, 6123, to_date('06-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090520010964, to_date('20-05-2009', 'dd-mm-yyyy'), to_date('03-06-2009', 'dd-mm-yyyy'), 6, 6645, to_date('24-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020729010965, to_date('29-07-2002', 'dd-mm-yyyy'), to_date('12-08-2002', 'dd-mm-yyyy'), 1, 2941, to_date('12-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041016010966, to_date('16-10-2004', 'dd-mm-yyyy'), to_date('30-10-2004', 'dd-mm-yyyy'), 8, 3435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091111010967, to_date('11-11-2009', 'dd-mm-yyyy'), to_date('25-11-2009', 'dd-mm-yyyy'), 4, 6690, to_date('28-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812010968, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 8, 7860, to_date('27-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111105010969, to_date('05-11-2011', 'dd-mm-yyyy'), to_date('19-11-2011', 'dd-mm-yyyy'), 10, 5949, to_date('07-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110103010970, to_date('03-01-2011', 'dd-mm-yyyy'), to_date('17-01-2011', 'dd-mm-yyyy'), 9, 8295, to_date('20-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081231010971, to_date('31-12-2008', 'dd-mm-yyyy'), to_date('14-01-2009', 'dd-mm-yyyy'), 6, 6202, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130430010972, to_date('30-04-2013', 'dd-mm-yyyy'), to_date('14-05-2013', 'dd-mm-yyyy'), 4, 10551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004010973, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 8, 1683, to_date('24-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090430010974, to_date('30-04-2009', 'dd-mm-yyyy'), to_date('14-05-2009', 'dd-mm-yyyy'), 3, 7826, to_date('11-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080519010975, to_date('19-05-2008', 'dd-mm-yyyy'), to_date('02-06-2008', 'dd-mm-yyyy'), 11, 7435, to_date('08-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130329010976, to_date('29-03-2013', 'dd-mm-yyyy'), to_date('12-04-2013', 'dd-mm-yyyy'), 7, 9328, to_date('15-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110422010977, to_date('22-04-2011', 'dd-mm-yyyy'), to_date('06-05-2011', 'dd-mm-yyyy'), 9, 8737, to_date('12-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090206010978, to_date('06-02-2009', 'dd-mm-yyyy'), to_date('20-02-2009', 'dd-mm-yyyy'), 12, 3928, to_date('13-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030303010979, to_date('03-03-2003', 'dd-mm-yyyy'), to_date('17-03-2003', 'dd-mm-yyyy'), 7, 3196, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131230010980, to_date('30-12-2013', 'dd-mm-yyyy'), to_date('13-01-2014', 'dd-mm-yyyy'), 12, 8298, to_date('14-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091221010981, to_date('21-12-2009', 'dd-mm-yyyy'), to_date('04-01-2010', 'dd-mm-yyyy'), 7, 7943, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130725010982, to_date('25-07-2013', 'dd-mm-yyyy'), to_date('08-08-2013', 'dd-mm-yyyy'), 5, 8738, to_date('30-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120904010983, to_date('04-09-2012', 'dd-mm-yyyy'), to_date('18-09-2012', 'dd-mm-yyyy'), 8, 6824, to_date('14-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111102010984, to_date('02-11-2011', 'dd-mm-yyyy'), to_date('16-11-2011', 'dd-mm-yyyy'), 4, 7777, to_date('11-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313010985, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 3, 2166, to_date('22-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091216010986, to_date('16-12-2009', 'dd-mm-yyyy'), to_date('30-12-2009', 'dd-mm-yyyy'), 11, 8341, to_date('20-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070518010987, to_date('18-05-2007', 'dd-mm-yyyy'), to_date('01-06-2007', 'dd-mm-yyyy'), 7, 4905, to_date('20-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131105010988, to_date('05-11-2013', 'dd-mm-yyyy'), to_date('19-11-2013', 'dd-mm-yyyy'), 5, 7881, to_date('23-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023010989, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 6, 2575, to_date('07-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601010990, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 11, 8602, to_date('12-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020911010991, to_date('11-09-2002', 'dd-mm-yyyy'), to_date('25-09-2002', 'dd-mm-yyyy'), 9, 2523, to_date('14-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021020010992, to_date('20-10-2002', 'dd-mm-yyyy'), to_date('03-11-2002', 'dd-mm-yyyy'), 10, 3255, to_date('21-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119010993, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 10, 1826, to_date('21-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020711010994, to_date('11-07-2002', 'dd-mm-yyyy'), to_date('25-07-2002', 'dd-mm-yyyy'), 4, 3077, to_date('18-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030120010995, to_date('20-01-2003', 'dd-mm-yyyy'), to_date('03-02-2003', 'dd-mm-yyyy'), 7, 2986, to_date('23-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111217010996, to_date('17-12-2011', 'dd-mm-yyyy'), to_date('31-12-2011', 'dd-mm-yyyy'), 1, 9144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000816010997, to_date('16-08-2000', 'dd-mm-yyyy'), to_date('30-08-2000', 'dd-mm-yyyy'), 9, 2198, to_date('31-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060404010998, to_date('04-04-2006', 'dd-mm-yyyy'), to_date('18-04-2006', 'dd-mm-yyyy'), 7, 4750, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010319010999, to_date('19-03-2001', 'dd-mm-yyyy'), to_date('02-04-2001', 'dd-mm-yyyy'), 2, 1944, to_date('27-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100527011000, to_date('27-05-2010', 'dd-mm-yyyy'), to_date('10-06-2010', 'dd-mm-yyyy'), 7, 6697, to_date('15-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060701011001, to_date('01-07-2006', 'dd-mm-yyyy'), to_date('15-07-2006', 'dd-mm-yyyy'), 1, 4383, to_date('19-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406011002, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 5, 4277, to_date('21-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216011003, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 5, 7625, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030514011004, to_date('14-05-2003', 'dd-mm-yyyy'), to_date('28-05-2003', 'dd-mm-yyyy'), 6, 4344, to_date('16-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010821011005, to_date('21-08-2001', 'dd-mm-yyyy'), to_date('04-09-2001', 'dd-mm-yyyy'), 6, 1481, to_date('08-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130825011006, to_date('25-08-2013', 'dd-mm-yyyy'), to_date('08-09-2013', 'dd-mm-yyyy'), 11, 7814, to_date('08-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130428011007, to_date('28-04-2013', 'dd-mm-yyyy'), to_date('12-05-2013', 'dd-mm-yyyy'), 7, 5764, to_date('15-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030725011008, to_date('25-07-2003', 'dd-mm-yyyy'), to_date('08-08-2003', 'dd-mm-yyyy'), 9, 4044, to_date('27-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110909011009, to_date('09-09-2011', 'dd-mm-yyyy'), to_date('23-09-2011', 'dd-mm-yyyy'), 2, 5889, to_date('23-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020114011010, to_date('14-01-2002', 'dd-mm-yyyy'), to_date('28-01-2002', 'dd-mm-yyyy'), 3, 2718, to_date('18-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130819011011, to_date('19-08-2013', 'dd-mm-yyyy'), to_date('02-09-2013', 'dd-mm-yyyy'), 12, 10741, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060305011012, to_date('05-03-2006', 'dd-mm-yyyy'), to_date('19-03-2006', 'dd-mm-yyyy'), 11, 3243, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511011013, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 10, 1830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080827011014, to_date('27-08-2008', 'dd-mm-yyyy'), to_date('10-09-2008', 'dd-mm-yyyy'), 9, 7032, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041019011015, to_date('19-10-2004', 'dd-mm-yyyy'), to_date('02-11-2004', 'dd-mm-yyyy'), 10, 3920, to_date('07-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327011016, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 3, 3889, to_date('05-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120701011017, to_date('01-07-2012', 'dd-mm-yyyy'), to_date('15-07-2012', 'dd-mm-yyyy'), 6, 10813, to_date('18-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120925011018, to_date('25-09-2012', 'dd-mm-yyyy'), to_date('09-10-2012', 'dd-mm-yyyy'), 12, 8033, to_date('10-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091120011019, to_date('20-11-2009', 'dd-mm-yyyy'), to_date('04-12-2009', 'dd-mm-yyyy'), 7, 6400, to_date('05-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222011020, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 6, 4809, to_date('09-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121209011021, to_date('09-12-2012', 'dd-mm-yyyy'), to_date('23-12-2012', 'dd-mm-yyyy'), 9, 11084, to_date('27-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100824011022, to_date('24-08-2010', 'dd-mm-yyyy'), to_date('07-09-2010', 'dd-mm-yyyy'), 8, 6669, to_date('13-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140310011023, to_date('10-03-2014', 'dd-mm-yyyy'), to_date('24-03-2014', 'dd-mm-yyyy'), 7, 7778, to_date('27-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928011024, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 3, 4720, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202011025, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 11, 2249, to_date('17-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101118011026, to_date('18-11-2010', 'dd-mm-yyyy'), to_date('02-12-2010', 'dd-mm-yyyy'), 11, 4715, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090508011027, to_date('08-05-2009', 'dd-mm-yyyy'), to_date('22-05-2009', 'dd-mm-yyyy'), 4, 8237, to_date('17-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130829013706, to_date('29-08-2013', 'dd-mm-yyyy'), to_date('12-09-2013', 'dd-mm-yyyy'), 2, 7473, to_date('13-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070511013707, to_date('11-05-2007', 'dd-mm-yyyy'), to_date('25-05-2007', 'dd-mm-yyyy'), 1, 6262, to_date('20-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110807013708, to_date('07-08-2011', 'dd-mm-yyyy'), to_date('21-08-2011', 'dd-mm-yyyy'), 3, 8504, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004013709, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 3, 999, to_date('10-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121005013710, to_date('05-10-2012', 'dd-mm-yyyy'), to_date('19-10-2012', 'dd-mm-yyyy'), 4, 9832, to_date('07-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071015013711, to_date('15-10-2007', 'dd-mm-yyyy'), to_date('29-10-2007', 'dd-mm-yyyy'), 1, 4178, to_date('01-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021009013712, to_date('09-10-2002', 'dd-mm-yyyy'), to_date('23-10-2002', 'dd-mm-yyyy'), 2, 2977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120407013713, to_date('07-04-2012', 'dd-mm-yyyy'), to_date('21-04-2012', 'dd-mm-yyyy'), 2, 7588, to_date('26-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021018013714, to_date('18-10-2002', 'dd-mm-yyyy'), to_date('01-11-2002', 'dd-mm-yyyy'), 2, 2131, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612013715, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 3, 6098, to_date('30-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050203013716, to_date('03-02-2005', 'dd-mm-yyyy'), to_date('17-02-2005', 'dd-mm-yyyy'), 4, 5008, to_date('15-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090308013717, to_date('08-03-2009', 'dd-mm-yyyy'), to_date('22-03-2009', 'dd-mm-yyyy'), 2, 8877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120513013718, to_date('13-05-2012', 'dd-mm-yyyy'), to_date('27-05-2012', 'dd-mm-yyyy'), 3, 4116, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120705013719, to_date('05-07-2012', 'dd-mm-yyyy'), to_date('19-07-2012', 'dd-mm-yyyy'), 3, 6125, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030117013720, to_date('17-01-2003', 'dd-mm-yyyy'), to_date('31-01-2003', 'dd-mm-yyyy'), 2, 3963, to_date('21-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110829013721, to_date('29-08-2011', 'dd-mm-yyyy'), to_date('12-09-2011', 'dd-mm-yyyy'), 2, 6878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060824013722, to_date('24-08-2006', 'dd-mm-yyyy'), to_date('07-09-2006', 'dd-mm-yyyy'), 1, 5766, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050611013723, to_date('11-06-2005', 'dd-mm-yyyy'), to_date('25-06-2005', 'dd-mm-yyyy'), 3, 3475, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030521013724, to_date('21-05-2003', 'dd-mm-yyyy'), to_date('04-06-2003', 'dd-mm-yyyy'), 3, 3850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070201013725, to_date('01-02-2007', 'dd-mm-yyyy'), to_date('15-02-2007', 'dd-mm-yyyy'), 2, 5052, to_date('10-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080303013726, to_date('03-03-2008', 'dd-mm-yyyy'), to_date('17-03-2008', 'dd-mm-yyyy'), 3, 7152, to_date('10-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090527013727, to_date('27-05-2009', 'dd-mm-yyyy'), to_date('10-06-2009', 'dd-mm-yyyy'), 3, 7648, to_date('09-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602013728, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 4, 2168, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110013729, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 2, 1586, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070731013730, to_date('31-07-2007', 'dd-mm-yyyy'), to_date('14-08-2007', 'dd-mm-yyyy'), 1, 4910, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070924013731, to_date('24-09-2007', 'dd-mm-yyyy'), to_date('08-10-2007', 'dd-mm-yyyy'), 2, 5347, to_date('03-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060823013732, to_date('23-08-2006', 'dd-mm-yyyy'), to_date('06-09-2006', 'dd-mm-yyyy'), 4, 5235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050614013733, to_date('14-06-2005', 'dd-mm-yyyy'), to_date('28-06-2005', 'dd-mm-yyyy'), 2, 3087, to_date('24-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040205013734, to_date('05-02-2004', 'dd-mm-yyyy'), to_date('19-02-2004', 'dd-mm-yyyy'), 3, 3174, to_date('22-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061117013735, to_date('17-11-2006', 'dd-mm-yyyy'), to_date('01-12-2006', 'dd-mm-yyyy'), 1, 6293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726013736, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 3, 3026, to_date('13-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020528013737, to_date('28-05-2002', 'dd-mm-yyyy'), to_date('11-06-2002', 'dd-mm-yyyy'), 1, 3039, to_date('07-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090312013738, to_date('12-03-2009', 'dd-mm-yyyy'), to_date('26-03-2009', 'dd-mm-yyyy'), 1, 7927, to_date('19-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030811013739, to_date('11-08-2003', 'dd-mm-yyyy'), to_date('25-08-2003', 'dd-mm-yyyy'), 1, 2158, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040929013740, to_date('29-09-2004', 'dd-mm-yyyy'), to_date('13-10-2004', 'dd-mm-yyyy'), 2, 4188, to_date('03-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071104013741, to_date('04-11-2007', 'dd-mm-yyyy'), to_date('18-11-2007', 'dd-mm-yyyy'), 4, 6158, to_date('19-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090301013742, to_date('01-03-2009', 'dd-mm-yyyy'), to_date('15-03-2009', 'dd-mm-yyyy'), 2, 6576, to_date('06-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210013743, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 2, 2332, to_date('21-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020716013744, to_date('16-07-2002', 'dd-mm-yyyy'), to_date('30-07-2002', 'dd-mm-yyyy'), 4, 2415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030725013745, to_date('25-07-2003', 'dd-mm-yyyy'), to_date('08-08-2003', 'dd-mm-yyyy'), 2, 2561, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620013746, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 2, 6976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000201013747, to_date('01-02-2000', 'dd-mm-yyyy'), to_date('15-02-2000', 'dd-mm-yyyy'), 1, 721, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140410013748, to_date('10-04-2014', 'dd-mm-yyyy'), to_date('24-04-2014', 'dd-mm-yyyy'), 1, 7520, to_date('22-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070519013749, to_date('19-05-2007', 'dd-mm-yyyy'), to_date('02-06-2007', 'dd-mm-yyyy'), 3, 3554, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050314013750, to_date('14-03-2005', 'dd-mm-yyyy'), to_date('28-03-2005', 'dd-mm-yyyy'), 2, 5020, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070930013751, to_date('30-09-2007', 'dd-mm-yyyy'), to_date('14-10-2007', 'dd-mm-yyyy'), 3, 4528, to_date('06-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020306013752, to_date('06-03-2002', 'dd-mm-yyyy'), to_date('20-03-2002', 'dd-mm-yyyy'), 2, 1382, to_date('08-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090923013753, to_date('23-09-2009', 'dd-mm-yyyy'), to_date('07-10-2009', 'dd-mm-yyyy'), 2, 6926, to_date('25-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215013754, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 1, 8285, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040621013755, to_date('21-06-2004', 'dd-mm-yyyy'), to_date('05-07-2004', 'dd-mm-yyyy'), 3, 4981, to_date('07-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081012013756, to_date('12-10-2008', 'dd-mm-yyyy'), to_date('26-10-2008', 'dd-mm-yyyy'), 2, 6261, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090915013757, to_date('15-09-2009', 'dd-mm-yyyy'), to_date('29-09-2009', 'dd-mm-yyyy'), 3, 4585, to_date('27-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111118013758, to_date('18-11-2011', 'dd-mm-yyyy'), to_date('02-12-2011', 'dd-mm-yyyy'), 2, 9934, to_date('03-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111108013759, to_date('08-11-2011', 'dd-mm-yyyy'), to_date('22-11-2011', 'dd-mm-yyyy'), 3, 5307, to_date('12-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100514013760, to_date('14-05-2010', 'dd-mm-yyyy'), to_date('28-05-2010', 'dd-mm-yyyy'), 1, 5273, to_date('15-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070916013761, to_date('16-09-2007', 'dd-mm-yyyy'), to_date('30-09-2007', 'dd-mm-yyyy'), 1, 5186, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050404013762, to_date('04-04-2005', 'dd-mm-yyyy'), to_date('18-04-2005', 'dd-mm-yyyy'), 1, 5378, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120625013763, to_date('25-06-2012', 'dd-mm-yyyy'), to_date('09-07-2012', 'dd-mm-yyyy'), 3, 7237, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090423013764, to_date('23-04-2009', 'dd-mm-yyyy'), to_date('07-05-2009', 'dd-mm-yyyy'), 2, 6928, to_date('04-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050606013765, to_date('06-06-2005', 'dd-mm-yyyy'), to_date('20-06-2005', 'dd-mm-yyyy'), 2, 5408, to_date('13-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060801013766, to_date('01-08-2006', 'dd-mm-yyyy'), to_date('15-08-2006', 'dd-mm-yyyy'), 3, 6273, to_date('21-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060117013767, to_date('17-01-2006', 'dd-mm-yyyy'), to_date('31-01-2006', 'dd-mm-yyyy'), 4, 4241, to_date('29-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040314013768, to_date('14-03-2004', 'dd-mm-yyyy'), to_date('28-03-2004', 'dd-mm-yyyy'), 2, 4771, to_date('18-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130720013769, to_date('20-07-2013', 'dd-mm-yyyy'), to_date('03-08-2013', 'dd-mm-yyyy'), 1, 8607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110627013770, to_date('27-06-2011', 'dd-mm-yyyy'), to_date('11-07-2011', 'dd-mm-yyyy'), 2, 7062, to_date('30-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607013771, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 4, 6155, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040420013772, to_date('20-04-2004', 'dd-mm-yyyy'), to_date('04-05-2004', 'dd-mm-yyyy'), 2, 4020, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080812013773, to_date('12-08-2008', 'dd-mm-yyyy'), to_date('26-08-2008', 'dd-mm-yyyy'), 2, 6406, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706013774, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 2, 9363, to_date('14-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070517013775, to_date('17-05-2007', 'dd-mm-yyyy'), to_date('31-05-2007', 'dd-mm-yyyy'), 1, 6464, to_date('03-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080922013776, to_date('22-09-2008', 'dd-mm-yyyy'), to_date('06-10-2008', 'dd-mm-yyyy'), 3, 6281, to_date('07-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131129013777, to_date('29-11-2013', 'dd-mm-yyyy'), to_date('13-12-2013', 'dd-mm-yyyy'), 1, 8003, to_date('15-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001110013778, to_date('10-11-2000', 'dd-mm-yyyy'), to_date('24-11-2000', 'dd-mm-yyyy'), 4, 3678, to_date('22-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061229013779, to_date('29-12-2006', 'dd-mm-yyyy'), to_date('12-01-2007', 'dd-mm-yyyy'), 1, 3493, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311013780, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 3, 7212, to_date('19-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031209013781, to_date('09-12-2003', 'dd-mm-yyyy'), to_date('23-12-2003', 'dd-mm-yyyy'), 2, 1773, to_date('28-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110728013782, to_date('28-07-2011', 'dd-mm-yyyy'), to_date('11-08-2011', 'dd-mm-yyyy'), 3, 8796, to_date('12-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120225013783, to_date('25-02-2012', 'dd-mm-yyyy'), to_date('10-03-2012', 'dd-mm-yyyy'), 2, 8029, to_date('13-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327013784, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 1, 7851, to_date('31-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020302013785, to_date('02-03-2002', 'dd-mm-yyyy'), to_date('16-03-2002', 'dd-mm-yyyy'), 2, 3975, to_date('14-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001110013786, to_date('10-11-2000', 'dd-mm-yyyy'), to_date('24-11-2000', 'dd-mm-yyyy'), 2, 608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000708013787, to_date('08-07-2000', 'dd-mm-yyyy'), to_date('22-07-2000', 'dd-mm-yyyy'), 2, 952, to_date('12-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217013788, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 1, 9430, to_date('27-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011013789, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 2, 5654, to_date('25-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081017013790, to_date('17-10-2008', 'dd-mm-yyyy'), to_date('31-10-2008', 'dd-mm-yyyy'), 2, 4669, to_date('01-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413013791, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 4, 5307, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050114013792, to_date('14-01-2005', 'dd-mm-yyyy'), to_date('28-01-2005', 'dd-mm-yyyy'), 3, 5554, to_date('24-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020801013793, to_date('01-08-2002', 'dd-mm-yyyy'), to_date('15-08-2002', 'dd-mm-yyyy'), 3, 2585, to_date('20-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108013794, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 2, 8074, to_date('22-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030313013795, to_date('13-03-2003', 'dd-mm-yyyy'), to_date('27-03-2003', 'dd-mm-yyyy'), 4, 4255, to_date('17-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050324013796, to_date('24-03-2005', 'dd-mm-yyyy'), to_date('07-04-2005', 'dd-mm-yyyy'), 3, 5502, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001121013797, to_date('21-11-2000', 'dd-mm-yyyy'), to_date('05-12-2000', 'dd-mm-yyyy'), 4, 1647, to_date('28-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120916013798, to_date('16-09-2012', 'dd-mm-yyyy'), to_date('30-09-2012', 'dd-mm-yyyy'), 4, 10425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025013799, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 3, 10164, to_date('26-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104013800, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 1, 3137, to_date('24-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140316013801, to_date('16-03-2014', 'dd-mm-yyyy'), to_date('30-03-2014', 'dd-mm-yyyy'), 2, 8675, to_date('02-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070708013802, to_date('08-07-2007', 'dd-mm-yyyy'), to_date('22-07-2007', 'dd-mm-yyyy'), 2, 4940, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110923013803, to_date('23-09-2011', 'dd-mm-yyyy'), to_date('07-10-2011', 'dd-mm-yyyy'), 1, 6450, to_date('28-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091203013804, to_date('03-12-2009', 'dd-mm-yyyy'), to_date('17-12-2009', 'dd-mm-yyyy'), 4, 6337, to_date('06-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000326013805, to_date('26-03-2000', 'dd-mm-yyyy'), to_date('09-04-2000', 'dd-mm-yyyy'), 3, 1095, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011114013806, to_date('14-11-2001', 'dd-mm-yyyy'), to_date('28-11-2001', 'dd-mm-yyyy'), 2, 1965, to_date('26-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110708013807, to_date('08-07-2011', 'dd-mm-yyyy'), to_date('22-07-2011', 'dd-mm-yyyy'), 4, 9012, to_date('09-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000910013808, to_date('10-09-2000', 'dd-mm-yyyy'), to_date('24-09-2000', 'dd-mm-yyyy'), 3, 2808, to_date('21-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051023013809, to_date('23-10-2005', 'dd-mm-yyyy'), to_date('06-11-2005', 'dd-mm-yyyy'), 3, 4068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209013810, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 4, 3338, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020525013811, to_date('25-05-2002', 'dd-mm-yyyy'), to_date('08-06-2002', 'dd-mm-yyyy'), 2, 2537, to_date('05-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010411013812, to_date('11-04-2001', 'dd-mm-yyyy'), to_date('25-04-2001', 'dd-mm-yyyy'), 1, 896, to_date('12-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040804013813, to_date('04-08-2004', 'dd-mm-yyyy'), to_date('18-08-2004', 'dd-mm-yyyy'), 2, 5129, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305013814, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 2, 10249, to_date('09-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121219013815, to_date('19-12-2012', 'dd-mm-yyyy'), to_date('02-01-2013', 'dd-mm-yyyy'), 2, 7328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021228013816, to_date('28-12-2002', 'dd-mm-yyyy'), to_date('11-01-2003', 'dd-mm-yyyy'), 1, 1895, to_date('17-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070118013817, to_date('18-01-2007', 'dd-mm-yyyy'), to_date('01-02-2007', 'dd-mm-yyyy'), 3, 4105, to_date('03-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013013818, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 2, 4487, to_date('27-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020917013819, to_date('17-09-2002', 'dd-mm-yyyy'), to_date('01-10-2002', 'dd-mm-yyyy'), 2, 5212, to_date('19-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051013013820, to_date('13-10-2005', 'dd-mm-yyyy'), to_date('27-10-2005', 'dd-mm-yyyy'), 2, 2828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011029013821, to_date('29-10-2001', 'dd-mm-yyyy'), to_date('12-11-2001', 'dd-mm-yyyy'), 3, 2574, to_date('04-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227013822, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 2, 1746, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105013823, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 3, 3452, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001119013824, to_date('19-11-2000', 'dd-mm-yyyy'), to_date('03-12-2000', 'dd-mm-yyyy'), 4, 1479, to_date('23-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906013825, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 3, 7146, to_date('22-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010130013826, to_date('30-01-2001', 'dd-mm-yyyy'), to_date('13-02-2001', 'dd-mm-yyyy'), 2, 1989, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100107013827, to_date('07-01-2010', 'dd-mm-yyyy'), to_date('21-01-2010', 'dd-mm-yyyy'), 3, 8376, to_date('11-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110623013828, to_date('23-06-2011', 'dd-mm-yyyy'), to_date('07-07-2011', 'dd-mm-yyyy'), 4, 6137, to_date('09-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071120013829, to_date('20-11-2007', 'dd-mm-yyyy'), to_date('04-12-2007', 'dd-mm-yyyy'), 4, 6760, to_date('27-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061003013830, to_date('03-10-2006', 'dd-mm-yyyy'), to_date('17-10-2006', 'dd-mm-yyyy'), 1, 4560, to_date('09-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100714013831, to_date('14-07-2010', 'dd-mm-yyyy'), to_date('28-07-2010', 'dd-mm-yyyy'), 2, 5400, to_date('30-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061108013832, to_date('08-11-2006', 'dd-mm-yyyy'), to_date('22-11-2006', 'dd-mm-yyyy'), 1, 5373, to_date('10-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031207013833, to_date('07-12-2003', 'dd-mm-yyyy'), to_date('21-12-2003', 'dd-mm-yyyy'), 3, 5132, to_date('08-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080517013834, to_date('17-05-2008', 'dd-mm-yyyy'), to_date('31-05-2008', 'dd-mm-yyyy'), 1, 5218, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802013835, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 8482, to_date('09-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120424013836, to_date('24-04-2012', 'dd-mm-yyyy'), to_date('08-05-2012', 'dd-mm-yyyy'), 2, 7293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104013837, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 3, 3669, to_date('22-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060907013838, to_date('07-09-2006', 'dd-mm-yyyy'), to_date('21-09-2006', 'dd-mm-yyyy'), 2, 6436, to_date('21-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130716013839, to_date('16-07-2013', 'dd-mm-yyyy'), to_date('30-07-2013', 'dd-mm-yyyy'), 3, 11080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825013840, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 1, 2250, to_date('08-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081117013841, to_date('17-11-2008', 'dd-mm-yyyy'), to_date('01-12-2008', 'dd-mm-yyyy'), 3, 5987, to_date('04-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215013842, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 2, 3656, to_date('29-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100410013843, to_date('10-04-2010', 'dd-mm-yyyy'), to_date('24-04-2010', 'dd-mm-yyyy'), 1, 6869, to_date('20-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031009013844, to_date('09-10-2003', 'dd-mm-yyyy'), to_date('23-10-2003', 'dd-mm-yyyy'), 3, 3413, to_date('12-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110602013845, to_date('02-06-2011', 'dd-mm-yyyy'), to_date('16-06-2011', 'dd-mm-yyyy'), 3, 8744, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051214013846, to_date('14-12-2005', 'dd-mm-yyyy'), to_date('28-12-2005', 'dd-mm-yyyy'), 3, 5547, to_date('17-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070422013847, to_date('22-04-2007', 'dd-mm-yyyy'), to_date('06-05-2007', 'dd-mm-yyyy'), 3, 3429, to_date('06-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090530013848, to_date('30-05-2009', 'dd-mm-yyyy'), to_date('13-06-2009', 'dd-mm-yyyy'), 1, 8557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100116013849, to_date('16-01-2010', 'dd-mm-yyyy'), to_date('30-01-2010', 'dd-mm-yyyy'), 3, 5637, to_date('20-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000122013850, to_date('22-01-2000', 'dd-mm-yyyy'), to_date('05-02-2000', 'dd-mm-yyyy'), 4, 980, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020120013851, to_date('20-01-2002', 'dd-mm-yyyy'), to_date('03-02-2002', 'dd-mm-yyyy'), 4, 2015, to_date('22-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020117013852, to_date('17-01-2002', 'dd-mm-yyyy'), to_date('31-01-2002', 'dd-mm-yyyy'), 4, 2361, to_date('19-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121012013853, to_date('12-10-2012', 'dd-mm-yyyy'), to_date('26-10-2012', 'dd-mm-yyyy'), 1, 7300, to_date('28-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031228013854, to_date('28-12-2003', 'dd-mm-yyyy'), to_date('11-01-2004', 'dd-mm-yyyy'), 2, 2757, to_date('12-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131112013855, to_date('12-11-2013', 'dd-mm-yyyy'), to_date('26-11-2013', 'dd-mm-yyyy'), 3, 9802, to_date('30-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101203013856, to_date('03-12-2010', 'dd-mm-yyyy'), to_date('17-12-2010', 'dd-mm-yyyy'), 2, 7441, to_date('22-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051213013857, to_date('13-12-2005', 'dd-mm-yyyy'), to_date('27-12-2005', 'dd-mm-yyyy'), 4, 3595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090531013858, to_date('31-05-2009', 'dd-mm-yyyy'), to_date('14-06-2009', 'dd-mm-yyyy'), 3, 5133, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040124013859, to_date('24-01-2004', 'dd-mm-yyyy'), to_date('07-02-2004', 'dd-mm-yyyy'), 1, 5000, to_date('28-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000617013860, to_date('17-06-2000', 'dd-mm-yyyy'), to_date('01-07-2000', 'dd-mm-yyyy'), 3, 2156, to_date('07-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015013861, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 2, 4640, to_date('17-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110724013862, to_date('24-07-2011', 'dd-mm-yyyy'), to_date('07-08-2011', 'dd-mm-yyyy'), 4, 10035, to_date('10-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130730013863, to_date('30-07-2013', 'dd-mm-yyyy'), to_date('13-08-2013', 'dd-mm-yyyy'), 2, 6748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105013864, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 4, 8052, to_date('19-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081221013865, to_date('21-12-2008', 'dd-mm-yyyy'), to_date('04-01-2009', 'dd-mm-yyyy'), 1, 5637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408013866, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 3, 11697, to_date('20-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011105013867, to_date('05-11-2001', 'dd-mm-yyyy'), to_date('19-11-2001', 'dd-mm-yyyy'), 3, 1982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120707013868, to_date('07-07-2012', 'dd-mm-yyyy'), to_date('21-07-2012', 'dd-mm-yyyy'), 3, 9021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101008013869, to_date('08-10-2010', 'dd-mm-yyyy'), to_date('22-10-2010', 'dd-mm-yyyy'), 4, 5723, to_date('13-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030428013870, to_date('28-04-2003', 'dd-mm-yyyy'), to_date('12-05-2003', 'dd-mm-yyyy'), 3, 3102, to_date('09-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620013871, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 3, 6880, to_date('04-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110311013872, to_date('11-03-2011', 'dd-mm-yyyy'), to_date('25-03-2011', 'dd-mm-yyyy'), 1, 6067, to_date('20-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111121013873, to_date('21-11-2011', 'dd-mm-yyyy'), to_date('05-12-2011', 'dd-mm-yyyy'), 3, 8569, to_date('04-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040630013874, to_date('30-06-2004', 'dd-mm-yyyy'), to_date('14-07-2004', 'dd-mm-yyyy'), 3, 2624, to_date('07-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040406016399, to_date('06-04-2004', 'dd-mm-yyyy'), to_date('20-04-2004', 'dd-mm-yyyy'), 2, 2779, to_date('22-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130726016400, to_date('26-07-2013', 'dd-mm-yyyy'), to_date('09-08-2013', 'dd-mm-yyyy'), 2, 9156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050626016401, to_date('26-06-2005', 'dd-mm-yyyy'), to_date('10-07-2005', 'dd-mm-yyyy'), 2, 5252, to_date('13-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040613016402, to_date('13-06-2004', 'dd-mm-yyyy'), to_date('27-06-2004', 'dd-mm-yyyy'), 2, 3783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020314016403, to_date('14-03-2002', 'dd-mm-yyyy'), to_date('28-03-2002', 'dd-mm-yyyy'), 1, 2994, to_date('17-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030411016404, to_date('11-04-2003', 'dd-mm-yyyy'), to_date('25-04-2003', 'dd-mm-yyyy'), 1, 2622, to_date('25-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030201016405, to_date('01-02-2003', 'dd-mm-yyyy'), to_date('15-02-2003', 'dd-mm-yyyy'), 1, 2833, to_date('05-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121010016406, to_date('10-10-2012', 'dd-mm-yyyy'), to_date('24-10-2012', 'dd-mm-yyyy'), 1, 10723, to_date('17-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110520016407, to_date('20-05-2011', 'dd-mm-yyyy'), to_date('03-06-2011', 'dd-mm-yyyy'), 2, 9789, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040217016408, to_date('17-02-2004', 'dd-mm-yyyy'), to_date('02-03-2004', 'dd-mm-yyyy'), 2, 4407, to_date('26-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019016409, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 2, 8859, to_date('25-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140203016410, to_date('03-02-2014', 'dd-mm-yyyy'), to_date('17-02-2014', 'dd-mm-yyyy'), 2, 7588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109016411, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 1, 8722, to_date('26-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061218016412, to_date('18-12-2006', 'dd-mm-yyyy'), to_date('01-01-2007', 'dd-mm-yyyy'), 1, 3061, to_date('03-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030226016413, to_date('26-02-2003', 'dd-mm-yyyy'), to_date('12-03-2003', 'dd-mm-yyyy'), 1, 2182, to_date('03-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111204016414, to_date('04-12-2011', 'dd-mm-yyyy'), to_date('18-12-2011', 'dd-mm-yyyy'), 1, 7361, to_date('21-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120602016415, to_date('02-06-2012', 'dd-mm-yyyy'), to_date('16-06-2012', 'dd-mm-yyyy'), 1, 7273, to_date('04-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091227016416, to_date('27-12-2009', 'dd-mm-yyyy'), to_date('10-01-2010', 'dd-mm-yyyy'), 2, 6584, to_date('29-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212016417, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 1, 2984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000121016418, to_date('21-01-2000', 'dd-mm-yyyy'), to_date('04-02-2000', 'dd-mm-yyyy'), 1, 371, to_date('25-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603016419, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 1, 9093, to_date('14-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001027016420, to_date('27-10-2000', 'dd-mm-yyyy'), to_date('10-11-2000', 'dd-mm-yyyy'), 1, 1630, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010419016421, to_date('19-04-2001', 'dd-mm-yyyy'), to_date('03-05-2001', 'dd-mm-yyyy'), 2, 3359, to_date('02-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121105016422, to_date('05-11-2012', 'dd-mm-yyyy'), to_date('19-11-2012', 'dd-mm-yyyy'), 2, 9332, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050303016423, to_date('03-03-2005', 'dd-mm-yyyy'), to_date('17-03-2005', 'dd-mm-yyyy'), 2, 4596, to_date('09-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080608016424, to_date('08-06-2008', 'dd-mm-yyyy'), to_date('22-06-2008', 'dd-mm-yyyy'), 1, 5072, to_date('23-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620016425, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 1, 9209, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917016426, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 2, 8586, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020331016427, to_date('31-03-2002', 'dd-mm-yyyy'), to_date('14-04-2002', 'dd-mm-yyyy'), 1, 2956, to_date('04-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504016428, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 1, 3530, to_date('16-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080308016429, to_date('08-03-2008', 'dd-mm-yyyy'), to_date('22-03-2008', 'dd-mm-yyyy'), 2, 6146, to_date('11-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302016430, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 2, 1037, to_date('13-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627016431, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 2, 7711, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120622016432, to_date('22-06-2012', 'dd-mm-yyyy'), to_date('06-07-2012', 'dd-mm-yyyy'), 1, 7124, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000113016433, to_date('13-01-2000', 'dd-mm-yyyy'), to_date('27-01-2000', 'dd-mm-yyyy'), 1, 1863, to_date('01-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426016434, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 1, 2211, to_date('05-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070117016435, to_date('17-01-2007', 'dd-mm-yyyy'), to_date('31-01-2007', 'dd-mm-yyyy'), 1, 6085, to_date('19-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040425016436, to_date('25-04-2004', 'dd-mm-yyyy'), to_date('09-05-2004', 'dd-mm-yyyy'), 2, 3591, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080110016437, to_date('10-01-2008', 'dd-mm-yyyy'), to_date('24-01-2008', 'dd-mm-yyyy'), 2, 6297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071025016438, to_date('25-10-2007', 'dd-mm-yyyy'), to_date('08-11-2007', 'dd-mm-yyyy'), 1, 6386, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120121016439, to_date('21-01-2012', 'dd-mm-yyyy'), to_date('04-02-2012', 'dd-mm-yyyy'), 1, 5650, to_date('24-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618016440, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 1, 5136, to_date('26-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060805016441, to_date('05-08-2006', 'dd-mm-yyyy'), to_date('19-08-2006', 'dd-mm-yyyy'), 2, 4933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040811016442, to_date('11-08-2004', 'dd-mm-yyyy'), to_date('25-08-2004', 'dd-mm-yyyy'), 1, 2931, to_date('27-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140404016443, to_date('04-04-2014', 'dd-mm-yyyy'), to_date('18-04-2014', 'dd-mm-yyyy'), 1, 8767, to_date('24-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229016444, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 1, 3648, to_date('14-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060811016445, to_date('11-08-2006', 'dd-mm-yyyy'), to_date('25-08-2006', 'dd-mm-yyyy'), 1, 6486, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606016446, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 2, 3097, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110506016447, to_date('06-05-2011', 'dd-mm-yyyy'), to_date('20-05-2011', 'dd-mm-yyyy'), 1, 8293, to_date('16-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909016448, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 1, 6041, to_date('21-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050807016449, to_date('07-08-2005', 'dd-mm-yyyy'), to_date('21-08-2005', 'dd-mm-yyyy'), 2, 4832, to_date('10-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000504016450, to_date('04-05-2000', 'dd-mm-yyyy'), to_date('18-05-2000', 'dd-mm-yyyy'), 2, 2434, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030118016451, to_date('18-01-2003', 'dd-mm-yyyy'), to_date('01-02-2003', 'dd-mm-yyyy'), 1, 3190, to_date('28-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050928016452, to_date('28-09-2005', 'dd-mm-yyyy'), to_date('12-10-2005', 'dd-mm-yyyy'), 1, 5458, to_date('12-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040330016453, to_date('30-03-2004', 'dd-mm-yyyy'), to_date('13-04-2004', 'dd-mm-yyyy'), 2, 3183, to_date('19-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030228016454, to_date('28-02-2003', 'dd-mm-yyyy'), to_date('14-03-2003', 'dd-mm-yyyy'), 1, 4558, to_date('11-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311016455, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 1, 9443, to_date('20-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090218016456, to_date('18-02-2009', 'dd-mm-yyyy'), to_date('04-03-2009', 'dd-mm-yyyy'), 2, 6930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070428016457, to_date('28-04-2007', 'dd-mm-yyyy'), to_date('12-05-2007', 'dd-mm-yyyy'), 2, 3931, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070207016458, to_date('07-02-2007', 'dd-mm-yyyy'), to_date('21-02-2007', 'dd-mm-yyyy'), 2, 3005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101212016459, to_date('12-12-2010', 'dd-mm-yyyy'), to_date('26-12-2010', 'dd-mm-yyyy'), 2, 5433, to_date('17-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120220016460, to_date('20-02-2012', 'dd-mm-yyyy'), to_date('05-03-2012', 'dd-mm-yyyy'), 2, 8125, to_date('26-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120611016461, to_date('11-06-2012', 'dd-mm-yyyy'), to_date('25-06-2012', 'dd-mm-yyyy'), 2, 7886, to_date('24-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040404016462, to_date('04-04-2004', 'dd-mm-yyyy'), to_date('18-04-2004', 'dd-mm-yyyy'), 2, 4184, to_date('09-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110321016463, to_date('21-03-2011', 'dd-mm-yyyy'), to_date('04-04-2011', 'dd-mm-yyyy'), 1, 8118, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081020016464, to_date('20-10-2008', 'dd-mm-yyyy'), to_date('03-11-2008', 'dd-mm-yyyy'), 2, 5437, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926016465, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 1, 5826, to_date('13-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110317016466, to_date('17-03-2011', 'dd-mm-yyyy'), to_date('31-03-2011', 'dd-mm-yyyy'), 1, 6753, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050122016467, to_date('22-01-2005', 'dd-mm-yyyy'), to_date('05-02-2005', 'dd-mm-yyyy'), 1, 4016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071227016468, to_date('27-12-2007', 'dd-mm-yyyy'), to_date('10-01-2008', 'dd-mm-yyyy'), 2, 3487, to_date('31-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050927016469, to_date('27-09-2005', 'dd-mm-yyyy'), to_date('11-10-2005', 'dd-mm-yyyy'), 2, 4660, to_date('29-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140322016470, to_date('22-03-2014', 'dd-mm-yyyy'), to_date('05-04-2014', 'dd-mm-yyyy'), 2, 6801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060116016471, to_date('16-01-2006', 'dd-mm-yyyy'), to_date('30-01-2006', 'dd-mm-yyyy'), 2, 6864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000111016472, to_date('11-01-2000', 'dd-mm-yyyy'), to_date('25-01-2000', 'dd-mm-yyyy'), 1, 2323, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723016473, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 1, 2858, to_date('08-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817016474, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 1, 6068, to_date('20-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130910016475, to_date('10-09-2013', 'dd-mm-yyyy'), to_date('24-09-2013', 'dd-mm-yyyy'), 2, 7446, to_date('18-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111129016476, to_date('29-11-2011', 'dd-mm-yyyy'), to_date('13-12-2011', 'dd-mm-yyyy'), 2, 9851, to_date('12-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226016477, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 2, 1746, to_date('03-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106016478, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 1, 6957, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112016479, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 2, 7028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000706016480, to_date('06-07-2000', 'dd-mm-yyyy'), to_date('20-07-2000', 'dd-mm-yyyy'), 1, 3089, to_date('16-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030216016481, to_date('16-02-2003', 'dd-mm-yyyy'), to_date('02-03-2003', 'dd-mm-yyyy'), 2, 3793, to_date('22-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110129016482, to_date('29-01-2011', 'dd-mm-yyyy'), to_date('12-02-2011', 'dd-mm-yyyy'), 1, 8867, to_date('08-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030326016483, to_date('26-03-2003', 'dd-mm-yyyy'), to_date('09-04-2003', 'dd-mm-yyyy'), 1, 4506, to_date('01-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100618016484, to_date('18-06-2010', 'dd-mm-yyyy'), to_date('02-07-2010', 'dd-mm-yyyy'), 1, 6953, to_date('19-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081013016485, to_date('13-10-2008', 'dd-mm-yyyy'), to_date('27-10-2008', 'dd-mm-yyyy'), 1, 5976, to_date('19-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120409016486, to_date('09-04-2012', 'dd-mm-yyyy'), to_date('23-04-2012', 'dd-mm-yyyy'), 1, 5234, to_date('27-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020904016487, to_date('04-09-2002', 'dd-mm-yyyy'), to_date('18-09-2002', 'dd-mm-yyyy'), 2, 3529, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050527016488, to_date('27-05-2005', 'dd-mm-yyyy'), to_date('10-06-2005', 'dd-mm-yyyy'), 2, 3786, to_date('14-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080119016489, to_date('19-01-2008', 'dd-mm-yyyy'), to_date('02-02-2008', 'dd-mm-yyyy'), 1, 5501, to_date('23-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010407016490, to_date('07-04-2001', 'dd-mm-yyyy'), to_date('21-04-2001', 'dd-mm-yyyy'), 2, 2049, to_date('19-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130704016491, to_date('04-07-2013', 'dd-mm-yyyy'), to_date('18-07-2013', 'dd-mm-yyyy'), 2, 7368, to_date('16-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130420016492, to_date('20-04-2013', 'dd-mm-yyyy'), to_date('04-05-2013', 'dd-mm-yyyy'), 1, 8854, to_date('30-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120917016493, to_date('17-09-2012', 'dd-mm-yyyy'), to_date('01-10-2012', 'dd-mm-yyyy'), 2, 9271, to_date('30-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130403016494, to_date('03-04-2013', 'dd-mm-yyyy'), to_date('17-04-2013', 'dd-mm-yyyy'), 1, 9836, to_date('14-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010221016495, to_date('21-02-2001', 'dd-mm-yyyy'), to_date('07-03-2001', 'dd-mm-yyyy'), 2, 1813, to_date('22-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210016496, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 1, 8247, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060910016497, to_date('10-09-2006', 'dd-mm-yyyy'), to_date('24-09-2006', 'dd-mm-yyyy'), 2, 6122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930016498, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 1, 1977, to_date('20-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001114016499, to_date('14-11-2000', 'dd-mm-yyyy'), to_date('28-11-2000', 'dd-mm-yyyy'), 1, 970, to_date('26-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070310016500, to_date('10-03-2007', 'dd-mm-yyyy'), to_date('24-03-2007', 'dd-mm-yyyy'), 1, 4241, to_date('19-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080711016501, to_date('11-07-2008', 'dd-mm-yyyy'), to_date('25-07-2008', 'dd-mm-yyyy'), 2, 6173, to_date('23-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903016502, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 1, 6879, to_date('14-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708016503, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 2, 1162, to_date('10-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507016504, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 1, 7047, to_date('20-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060801016505, to_date('01-08-2006', 'dd-mm-yyyy'), to_date('15-08-2006', 'dd-mm-yyyy'), 2, 6844, to_date('04-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119016506, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 1, 2370, to_date('30-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070804016507, to_date('04-08-2007', 'dd-mm-yyyy'), to_date('18-08-2007', 'dd-mm-yyyy'), 1, 7253, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071021016508, to_date('21-10-2007', 'dd-mm-yyyy'), to_date('04-11-2007', 'dd-mm-yyyy'), 1, 3952, to_date('09-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090209016509, to_date('09-02-2009', 'dd-mm-yyyy'), to_date('23-02-2009', 'dd-mm-yyyy'), 2, 5254, to_date('12-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060706016510, to_date('06-07-2006', 'dd-mm-yyyy'), to_date('20-07-2006', 'dd-mm-yyyy'), 2, 4963, to_date('21-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060630016511, to_date('30-06-2006', 'dd-mm-yyyy'), to_date('14-07-2006', 'dd-mm-yyyy'), 1, 4525, to_date('02-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140515016512, to_date('15-05-2014', 'dd-mm-yyyy'), to_date('29-05-2014', 'dd-mm-yyyy'), 1, 9026, to_date('28-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051014016513, to_date('14-10-2005', 'dd-mm-yyyy'), to_date('28-10-2005', 'dd-mm-yyyy'), 1, 5407, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030127016514, to_date('27-01-2003', 'dd-mm-yyyy'), to_date('10-02-2003', 'dd-mm-yyyy'), 1, 2609, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121226016515, to_date('26-12-2012', 'dd-mm-yyyy'), to_date('09-01-2013', 'dd-mm-yyyy'), 1, 9903, to_date('27-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110716016516, to_date('16-07-2011', 'dd-mm-yyyy'), to_date('30-07-2011', 'dd-mm-yyyy'), 1, 5332, to_date('20-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060418016517, to_date('18-04-2006', 'dd-mm-yyyy'), to_date('02-05-2006', 'dd-mm-yyyy'), 2, 5520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140315016518, to_date('15-03-2014', 'dd-mm-yyyy'), to_date('29-03-2014', 'dd-mm-yyyy'), 2, 9271, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130911016519, to_date('11-09-2013', 'dd-mm-yyyy'), to_date('25-09-2013', 'dd-mm-yyyy'), 1, 9064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222016520, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 1, 9973, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001016521, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 1, 2576, to_date('19-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010606016522, to_date('06-06-2001', 'dd-mm-yyyy'), to_date('20-06-2001', 'dd-mm-yyyy'), 1, 1907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120208016523, to_date('08-02-2012', 'dd-mm-yyyy'), to_date('22-02-2012', 'dd-mm-yyyy'), 2, 7652, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080320016524, to_date('20-03-2008', 'dd-mm-yyyy'), to_date('03-04-2008', 'dd-mm-yyyy'), 2, 6368, to_date('04-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725016525, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 1, 4699, to_date('11-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100727016526, to_date('27-07-2010', 'dd-mm-yyyy'), to_date('10-08-2010', 'dd-mm-yyyy'), 1, 7270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080403016527, to_date('03-04-2008', 'dd-mm-yyyy'), to_date('17-04-2008', 'dd-mm-yyyy'), 1, 5913, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130616016528, to_date('16-06-2013', 'dd-mm-yyyy'), to_date('30-06-2013', 'dd-mm-yyyy'), 1, 10463, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051031016529, to_date('31-10-2005', 'dd-mm-yyyy'), to_date('14-11-2005', 'dd-mm-yyyy'), 2, 7327, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040301016530, to_date('01-03-2004', 'dd-mm-yyyy'), to_date('15-03-2004', 'dd-mm-yyyy'), 1, 4120, to_date('05-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081123016531, to_date('23-11-2008', 'dd-mm-yyyy'), to_date('07-12-2008', 'dd-mm-yyyy'), 1, 5742, to_date('08-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010220016532, to_date('20-02-2001', 'dd-mm-yyyy'), to_date('06-03-2001', 'dd-mm-yyyy'), 2, 2805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080406016533, to_date('06-04-2008', 'dd-mm-yyyy'), to_date('20-04-2008', 'dd-mm-yyyy'), 1, 7373, to_date('07-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060415016534, to_date('15-04-2006', 'dd-mm-yyyy'), to_date('29-04-2006', 'dd-mm-yyyy'), 2, 4942, to_date('01-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108016535, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 2, 5639, to_date('18-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120727016536, to_date('27-07-2012', 'dd-mm-yyyy'), to_date('10-08-2012', 'dd-mm-yyyy'), 1, 8639, to_date('01-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080629016537, to_date('29-06-2008', 'dd-mm-yyyy'), to_date('13-07-2008', 'dd-mm-yyyy'), 2, 5858, to_date('10-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080815016538, to_date('15-08-2008', 'dd-mm-yyyy'), to_date('29-08-2008', 'dd-mm-yyyy'), 1, 7223, to_date('20-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070925016539, to_date('25-09-2007', 'dd-mm-yyyy'), to_date('09-10-2007', 'dd-mm-yyyy'), 1, 5515, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020423016540, to_date('23-04-2002', 'dd-mm-yyyy'), to_date('07-05-2002', 'dd-mm-yyyy'), 2, 1498, to_date('10-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110622016541, to_date('22-06-2011', 'dd-mm-yyyy'), to_date('06-07-2011', 'dd-mm-yyyy'), 1, 10577, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041028016542, to_date('28-10-2004', 'dd-mm-yyyy'), to_date('11-11-2004', 'dd-mm-yyyy'), 2, 5243, to_date('01-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090501016543, to_date('01-05-2009', 'dd-mm-yyyy'), to_date('15-05-2009', 'dd-mm-yyyy'), 2, 5032, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004016544, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 2, 4981, to_date('11-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000327016545, to_date('27-03-2000', 'dd-mm-yyyy'), to_date('10-04-2000', 'dd-mm-yyyy'), 1, 3462, to_date('15-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121128016546, to_date('28-11-2012', 'dd-mm-yyyy'), to_date('12-12-2012', 'dd-mm-yyyy'), 1, 7792, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011213016547, to_date('13-12-2001', 'dd-mm-yyyy'), to_date('27-12-2001', 'dd-mm-yyyy'), 2, 2867, to_date('26-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060706016548, to_date('06-07-2006', 'dd-mm-yyyy'), to_date('20-07-2006', 'dd-mm-yyyy'), 2, 4798, to_date('22-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100720016549, to_date('20-07-2010', 'dd-mm-yyyy'), to_date('03-08-2010', 'dd-mm-yyyy'), 2, 6460, to_date('05-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730016550, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 2, 7117, to_date('09-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010827016551, to_date('27-08-2001', 'dd-mm-yyyy'), to_date('10-09-2001', 'dd-mm-yyyy'), 2, 3584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020311016552, to_date('11-03-2002', 'dd-mm-yyyy'), to_date('25-03-2002', 'dd-mm-yyyy'), 1, 1342, to_date('13-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080719016553, to_date('19-07-2008', 'dd-mm-yyyy'), to_date('02-08-2008', 'dd-mm-yyyy'), 1, 5710, to_date('22-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031230016554, to_date('30-12-2003', 'dd-mm-yyyy'), to_date('13-01-2004', 'dd-mm-yyyy'), 2, 3416, to_date('17-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810016555, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 1, 2735, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090801016556, to_date('01-08-2009', 'dd-mm-yyyy'), to_date('15-08-2009', 'dd-mm-yyyy'), 1, 5578, to_date('06-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050731016557, to_date('31-07-2005', 'dd-mm-yyyy'), to_date('14-08-2005', 'dd-mm-yyyy'), 1, 5847, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100811016558, to_date('11-08-2010', 'dd-mm-yyyy'), to_date('25-08-2010', 'dd-mm-yyyy'), 2, 9578, to_date('20-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070421016559, to_date('21-04-2007', 'dd-mm-yyyy'), to_date('05-05-2007', 'dd-mm-yyyy'), 2, 4804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140517016560, to_date('17-05-2014', 'dd-mm-yyyy'), to_date('31-05-2014', 'dd-mm-yyyy'), 1, 9335, to_date('04-06-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912016561, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 1, 2160, to_date('13-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070810016562, to_date('10-08-2007', 'dd-mm-yyyy'), to_date('24-08-2007', 'dd-mm-yyyy'), 2, 6545, to_date('13-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000721016563, to_date('21-07-2000', 'dd-mm-yyyy'), to_date('04-08-2000', 'dd-mm-yyyy'), 1, 1264, to_date('08-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030124016564, to_date('24-01-2003', 'dd-mm-yyyy'), to_date('07-02-2003', 'dd-mm-yyyy'), 2, 2720, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010601016565, to_date('01-06-2001', 'dd-mm-yyyy'), to_date('15-06-2001', 'dd-mm-yyyy'), 2, 2037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421016566, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 2, 3036, to_date('03-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921016567, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 2, 6497, to_date('10-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070117011028, to_date('17-01-2007', 'dd-mm-yyyy'), to_date('31-01-2007', 'dd-mm-yyyy'), 10, 6340, to_date('31-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100909011029, to_date('09-09-2010', 'dd-mm-yyyy'), to_date('23-09-2010', 'dd-mm-yyyy'), 8, 9961, to_date('23-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120424011030, to_date('24-04-2012', 'dd-mm-yyyy'), to_date('08-05-2012', 'dd-mm-yyyy'), 1, 6564, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091024011031, to_date('24-10-2009', 'dd-mm-yyyy'), to_date('07-11-2009', 'dd-mm-yyyy'), 11, 7801, to_date('02-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080606011032, to_date('06-06-2008', 'dd-mm-yyyy'), to_date('20-06-2008', 'dd-mm-yyyy'), 3, 5997, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030706011033, to_date('06-07-2003', 'dd-mm-yyyy'), to_date('20-07-2003', 'dd-mm-yyyy'), 8, 4905, to_date('25-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702011034, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 8, 3443, to_date('18-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020107011035, to_date('07-01-2002', 'dd-mm-yyyy'), to_date('21-01-2002', 'dd-mm-yyyy'), 7, 4295, to_date('14-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060829011036, to_date('29-08-2006', 'dd-mm-yyyy'), to_date('12-09-2006', 'dd-mm-yyyy'), 7, 6834, to_date('08-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110601011037, to_date('01-06-2011', 'dd-mm-yyyy'), to_date('15-06-2011', 'dd-mm-yyyy'), 4, 6972, to_date('08-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080310011038, to_date('10-03-2008', 'dd-mm-yyyy'), to_date('24-03-2008', 'dd-mm-yyyy'), 8, 4448, to_date('18-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011015011039, to_date('15-10-2001', 'dd-mm-yyyy'), to_date('29-10-2001', 'dd-mm-yyyy'), 7, 3684, to_date('18-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130602011040, to_date('02-06-2013', 'dd-mm-yyyy'), to_date('16-06-2013', 'dd-mm-yyyy'), 7, 10798, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111023011041, to_date('23-10-2011', 'dd-mm-yyyy'), to_date('06-11-2011', 'dd-mm-yyyy'), 5, 6965, to_date('08-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070917011042, to_date('17-09-2007', 'dd-mm-yyyy'), to_date('01-10-2007', 'dd-mm-yyyy'), 9, 4827, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120526011043, to_date('26-05-2012', 'dd-mm-yyyy'), to_date('09-06-2012', 'dd-mm-yyyy'), 5, 7703, to_date('03-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000519011044, to_date('19-05-2000', 'dd-mm-yyyy'), to_date('02-06-2000', 'dd-mm-yyyy'), 6, 481, to_date('31-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120523011045, to_date('23-05-2012', 'dd-mm-yyyy'), to_date('06-06-2012', 'dd-mm-yyyy'), 9, 9065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010726011046, to_date('26-07-2001', 'dd-mm-yyyy'), to_date('09-08-2001', 'dd-mm-yyyy'), 4, 2579, to_date('15-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091028011047, to_date('28-10-2009', 'dd-mm-yyyy'), to_date('11-11-2009', 'dd-mm-yyyy'), 8, 7692, to_date('01-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110611011048, to_date('11-06-2011', 'dd-mm-yyyy'), to_date('25-06-2011', 'dd-mm-yyyy'), 7, 6492, to_date('28-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131229011049, to_date('29-12-2013', 'dd-mm-yyyy'), to_date('12-01-2014', 'dd-mm-yyyy'), 6, 10680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513011050, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 2, 6417, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021005011051, to_date('05-10-2002', 'dd-mm-yyyy'), to_date('19-10-2002', 'dd-mm-yyyy'), 8, 3553, to_date('08-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010822011052, to_date('22-08-2001', 'dd-mm-yyyy'), to_date('05-09-2001', 'dd-mm-yyyy'), 1, 2504, to_date('29-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001129011053, to_date('29-11-2000', 'dd-mm-yyyy'), to_date('13-12-2000', 'dd-mm-yyyy'), 11, 2694, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912011054, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 9, 5225, to_date('19-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041228011055, to_date('28-12-2004', 'dd-mm-yyyy'), to_date('11-01-2005', 'dd-mm-yyyy'), 1, 4514, to_date('10-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010725011056, to_date('25-07-2001', 'dd-mm-yyyy'), to_date('08-08-2001', 'dd-mm-yyyy'), 11, 3518, to_date('06-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225011057, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 1, 5775, to_date('12-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020328011058, to_date('28-03-2002', 'dd-mm-yyyy'), to_date('11-04-2002', 'dd-mm-yyyy'), 1, 4184, to_date('08-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080312011059, to_date('12-03-2008', 'dd-mm-yyyy'), to_date('26-03-2008', 'dd-mm-yyyy'), 7, 5504, to_date('17-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130717011060, to_date('17-07-2013', 'dd-mm-yyyy'), to_date('31-07-2013', 'dd-mm-yyyy'), 3, 8486, to_date('24-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071011011061, to_date('11-10-2007', 'dd-mm-yyyy'), to_date('25-10-2007', 'dd-mm-yyyy'), 3, 7101, to_date('26-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609011062, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 8, 4411, to_date('25-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040628011063, to_date('28-06-2004', 'dd-mm-yyyy'), to_date('12-07-2004', 'dd-mm-yyyy'), 8, 3977, to_date('05-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004011064, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 11, 5454, to_date('16-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101020011065, to_date('20-10-2010', 'dd-mm-yyyy'), to_date('03-11-2010', 'dd-mm-yyyy'), 3, 3834, to_date('06-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080820011066, to_date('20-08-2008', 'dd-mm-yyyy'), to_date('03-09-2008', 'dd-mm-yyyy'), 8, 6558, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228011067, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 4, 7455, to_date('31-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020306011068, to_date('06-03-2002', 'dd-mm-yyyy'), to_date('20-03-2002', 'dd-mm-yyyy'), 10, 2585, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629011069, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 6, 4110, to_date('03-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120907011070, to_date('07-09-2012', 'dd-mm-yyyy'), to_date('21-09-2012', 'dd-mm-yyyy'), 8, 8274, to_date('25-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091025011071, to_date('25-10-2009', 'dd-mm-yyyy'), to_date('08-11-2009', 'dd-mm-yyyy'), 10, 6132, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330011072, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 7, 8582, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000522011073, to_date('22-05-2000', 'dd-mm-yyyy'), to_date('05-06-2000', 'dd-mm-yyyy'), 3, 2427, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210011074, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 6, 2745, to_date('01-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081020011075, to_date('20-10-2008', 'dd-mm-yyyy'), to_date('03-11-2008', 'dd-mm-yyyy'), 4, 6047, to_date('28-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105011076, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 10, 2122, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120621011077, to_date('21-06-2012', 'dd-mm-yyyy'), to_date('05-07-2012', 'dd-mm-yyyy'), 11, 7388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060228011078, to_date('28-02-2006', 'dd-mm-yyyy'), to_date('14-03-2006', 'dd-mm-yyyy'), 4, 3546, to_date('07-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912011079, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 3, 5282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813011080, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 3, 7425, to_date('21-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419011081, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 8, 4018, to_date('01-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416011082, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 3, 5265, to_date('25-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111012011083, to_date('12-10-2011', 'dd-mm-yyyy'), to_date('26-10-2011', 'dd-mm-yyyy'), 1, 5362, to_date('28-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050807011084, to_date('07-08-2005', 'dd-mm-yyyy'), to_date('21-08-2005', 'dd-mm-yyyy'), 6, 3312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100114011085, to_date('14-01-2010', 'dd-mm-yyyy'), to_date('28-01-2010', 'dd-mm-yyyy'), 11, 8005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020324011086, to_date('24-03-2002', 'dd-mm-yyyy'), to_date('07-04-2002', 'dd-mm-yyyy'), 11, 2867, to_date('11-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001011087, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 6, 3714, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226011088, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 7, 6526, to_date('08-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080729011089, to_date('29-07-2008', 'dd-mm-yyyy'), to_date('12-08-2008', 'dd-mm-yyyy'), 4, 5660, to_date('10-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901011090, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 10, 3850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000711011091, to_date('11-07-2000', 'dd-mm-yyyy'), to_date('25-07-2000', 'dd-mm-yyyy'), 9, 2515, to_date('26-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815011092, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 7, 3971, to_date('18-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050803011093, to_date('03-08-2005', 'dd-mm-yyyy'), to_date('17-08-2005', 'dd-mm-yyyy'), 5, 4318, to_date('18-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130117011094, to_date('17-01-2013', 'dd-mm-yyyy'), to_date('31-01-2013', 'dd-mm-yyyy'), 10, 10780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111011095, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 6, 9131, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026011096, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 2, 3642, to_date('02-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020125011097, to_date('25-01-2002', 'dd-mm-yyyy'), to_date('08-02-2002', 'dd-mm-yyyy'), 10, 1555, to_date('11-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031213011098, to_date('13-12-2003', 'dd-mm-yyyy'), to_date('27-12-2003', 'dd-mm-yyyy'), 12, 3545, to_date('15-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120416011099, to_date('16-04-2012', 'dd-mm-yyyy'), to_date('30-04-2012', 'dd-mm-yyyy'), 9, 8775, to_date('28-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503011100, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 2, 5130, to_date('17-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000505011101, to_date('05-05-2000', 'dd-mm-yyyy'), to_date('19-05-2000', 'dd-mm-yyyy'), 5, 3400, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061212011102, to_date('12-12-2006', 'dd-mm-yyyy'), to_date('26-12-2006', 'dd-mm-yyyy'), 10, 3372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804011103, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 9, 8152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217011104, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 4, 3422, to_date('21-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020219011105, to_date('19-02-2002', 'dd-mm-yyyy'), to_date('05-03-2002', 'dd-mm-yyyy'), 5, 3504, to_date('01-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110312011106, to_date('12-03-2011', 'dd-mm-yyyy'), to_date('26-03-2011', 'dd-mm-yyyy'), 10, 8499, to_date('17-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204011107, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 2, 10620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120121011108, to_date('21-01-2012', 'dd-mm-yyyy'), to_date('04-02-2012', 'dd-mm-yyyy'), 2, 9005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010011109, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 8, 7428, to_date('15-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060323011110, to_date('23-03-2006', 'dd-mm-yyyy'), to_date('06-04-2006', 'dd-mm-yyyy'), 11, 4977, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060613011111, to_date('13-06-2006', 'dd-mm-yyyy'), to_date('27-06-2006', 'dd-mm-yyyy'), 8, 4722, to_date('18-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515011112, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 9, 2927, to_date('28-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130909011113, to_date('09-09-2013', 'dd-mm-yyyy'), to_date('23-09-2013', 'dd-mm-yyyy'), 1, 7343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100603011114, to_date('03-06-2010', 'dd-mm-yyyy'), to_date('17-06-2010', 'dd-mm-yyyy'), 7, 8307, to_date('13-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040724011115, to_date('24-07-2004', 'dd-mm-yyyy'), to_date('07-08-2004', 'dd-mm-yyyy'), 11, 4139, to_date('28-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051118011116, to_date('18-11-2005', 'dd-mm-yyyy'), to_date('02-12-2005', 'dd-mm-yyyy'), 8, 4765, to_date('22-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140108011117, to_date('08-01-2014', 'dd-mm-yyyy'), to_date('22-01-2014', 'dd-mm-yyyy'), 1, 7057, to_date('23-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210011118, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 11, 4840, to_date('28-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040127011119, to_date('27-01-2004', 'dd-mm-yyyy'), to_date('10-02-2004', 'dd-mm-yyyy'), 3, 5430, to_date('02-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725011120, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 2, 9443, to_date('06-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031029011121, to_date('29-10-2003', 'dd-mm-yyyy'), to_date('12-11-2003', 'dd-mm-yyyy'), 11, 6393, to_date('31-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080409011122, to_date('09-04-2008', 'dd-mm-yyyy'), to_date('23-04-2008', 'dd-mm-yyyy'), 7, 5216, to_date('17-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000313011123, to_date('13-03-2000', 'dd-mm-yyyy'), to_date('27-03-2000', 'dd-mm-yyyy'), 9, 1763, to_date('01-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100925011124, to_date('25-09-2010', 'dd-mm-yyyy'), to_date('09-10-2010', 'dd-mm-yyyy'), 5, 7142, to_date('15-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011005011125, to_date('05-10-2001', 'dd-mm-yyyy'), to_date('19-10-2001', 'dd-mm-yyyy'), 11, 976, to_date('08-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131218011126, to_date('18-12-2013', 'dd-mm-yyyy'), to_date('01-01-2014', 'dd-mm-yyyy'), 3, 6036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824011127, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 4, 7672, to_date('26-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060827011128, to_date('27-08-2006', 'dd-mm-yyyy'), to_date('10-09-2006', 'dd-mm-yyyy'), 2, 5255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130309011129, to_date('09-03-2013', 'dd-mm-yyyy'), to_date('23-03-2013', 'dd-mm-yyyy'), 2, 9516, to_date('27-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090225011130, to_date('25-02-2009', 'dd-mm-yyyy'), to_date('11-03-2009', 'dd-mm-yyyy'), 2, 6526, to_date('11-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091130011131, to_date('30-11-2009', 'dd-mm-yyyy'), to_date('14-12-2009', 'dd-mm-yyyy'), 5, 5580, to_date('07-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070119011132, to_date('19-01-2007', 'dd-mm-yyyy'), to_date('02-02-2007', 'dd-mm-yyyy'), 9, 4981, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050726011133, to_date('26-07-2005', 'dd-mm-yyyy'), to_date('09-08-2005', 'dd-mm-yyyy'), 9, 3716, to_date('31-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111011134, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 1, 3287, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031027011135, to_date('27-10-2003', 'dd-mm-yyyy'), to_date('10-11-2003', 'dd-mm-yyyy'), 3, 3558, to_date('07-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830011136, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 11, 4762, to_date('09-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100906011137, to_date('06-09-2010', 'dd-mm-yyyy'), to_date('20-09-2010', 'dd-mm-yyyy'), 6, 6547, to_date('13-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604011138, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 8, 9531, to_date('12-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110107011139, to_date('07-01-2011', 'dd-mm-yyyy'), to_date('21-01-2011', 'dd-mm-yyyy'), 9, 8708, to_date('26-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129011140, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 6, 2543, to_date('14-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130805011141, to_date('05-08-2013', 'dd-mm-yyyy'), to_date('19-08-2013', 'dd-mm-yyyy'), 4, 9321, to_date('10-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020804011142, to_date('04-08-2002', 'dd-mm-yyyy'), to_date('18-08-2002', 'dd-mm-yyyy'), 2, 3740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000430011143, to_date('30-04-2000', 'dd-mm-yyyy'), to_date('14-05-2000', 'dd-mm-yyyy'), 12, 1738, to_date('12-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215011144, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 1, 7492, to_date('26-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917011145, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 8, 7122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070913011146, to_date('13-09-2007', 'dd-mm-yyyy'), to_date('27-09-2007', 'dd-mm-yyyy'), 10, 7999, to_date('03-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120223011147, to_date('23-02-2012', 'dd-mm-yyyy'), to_date('08-03-2012', 'dd-mm-yyyy'), 2, 8032, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090714011148, to_date('14-07-2009', 'dd-mm-yyyy'), to_date('28-07-2009', 'dd-mm-yyyy'), 5, 7132, to_date('17-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060624011149, to_date('24-06-2006', 'dd-mm-yyyy'), to_date('08-07-2006', 'dd-mm-yyyy'), 5, 4267, to_date('26-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050624011150, to_date('24-06-2005', 'dd-mm-yyyy'), to_date('08-07-2005', 'dd-mm-yyyy'), 3, 2666, to_date('05-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504011151, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 3, 7921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405011152, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 8, 5774, to_date('21-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110722011153, to_date('22-07-2011', 'dd-mm-yyyy'), to_date('05-08-2011', 'dd-mm-yyyy'), 3, 8379, to_date('28-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060506011154, to_date('06-05-2006', 'dd-mm-yyyy'), to_date('20-05-2006', 'dd-mm-yyyy'), 2, 5871, to_date('26-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921011155, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 7, 1812, to_date('09-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090206011156, to_date('06-02-2009', 'dd-mm-yyyy'), to_date('20-02-2009', 'dd-mm-yyyy'), 6, 5874, to_date('07-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100210011157, to_date('10-02-2010', 'dd-mm-yyyy'), to_date('24-02-2010', 'dd-mm-yyyy'), 3, 8818, to_date('16-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121207011158, to_date('07-12-2012', 'dd-mm-yyyy'), to_date('21-12-2012', 'dd-mm-yyyy'), 11, 9278, to_date('10-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130926011159, to_date('26-09-2013', 'dd-mm-yyyy'), to_date('10-10-2013', 'dd-mm-yyyy'), 8, 7365, to_date('11-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020710011160, to_date('10-07-2002', 'dd-mm-yyyy'), to_date('24-07-2002', 'dd-mm-yyyy'), 9, 1920, to_date('24-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130320011161, to_date('20-03-2013', 'dd-mm-yyyy'), to_date('03-04-2013', 'dd-mm-yyyy'), 3, 8685, to_date('23-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131125011162, to_date('25-11-2013', 'dd-mm-yyyy'), to_date('09-12-2013', 'dd-mm-yyyy'), 11, 9708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526011163, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 8, 986, to_date('12-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111211011164, to_date('11-12-2011', 'dd-mm-yyyy'), to_date('25-12-2011', 'dd-mm-yyyy'), 4, 11028, to_date('18-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130308011165, to_date('08-03-2013', 'dd-mm-yyyy'), to_date('22-03-2013', 'dd-mm-yyyy'), 4, 7740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080502011166, to_date('02-05-2008', 'dd-mm-yyyy'), to_date('16-05-2008', 'dd-mm-yyyy'), 8, 8580, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030712011167, to_date('12-07-2003', 'dd-mm-yyyy'), to_date('26-07-2003', 'dd-mm-yyyy'), 10, 4422, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020602011168, to_date('02-06-2002', 'dd-mm-yyyy'), to_date('16-06-2002', 'dd-mm-yyyy'), 3, 3014, to_date('14-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110504011169, to_date('04-05-2011', 'dd-mm-yyyy'), to_date('18-05-2011', 'dd-mm-yyyy'), 4, 5753, to_date('17-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040301011170, to_date('01-03-2004', 'dd-mm-yyyy'), to_date('15-03-2004', 'dd-mm-yyyy'), 10, 4372, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121020011171, to_date('20-10-2012', 'dd-mm-yyyy'), to_date('03-11-2012', 'dd-mm-yyyy'), 11, 5846, to_date('07-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100415011172, to_date('15-04-2010', 'dd-mm-yyyy'), to_date('29-04-2010', 'dd-mm-yyyy'), 4, 7827, to_date('16-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010907011173, to_date('07-09-2001', 'dd-mm-yyyy'), to_date('21-09-2001', 'dd-mm-yyyy'), 8, 1858, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105011174, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 5, 7335, to_date('16-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120011175, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 7, 2812, to_date('22-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217011176, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 6, 6240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001201011177, to_date('01-12-2000', 'dd-mm-yyyy'), to_date('15-12-2000', 'dd-mm-yyyy'), 8, 4304, to_date('17-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001114011178, to_date('14-11-2000', 'dd-mm-yyyy'), to_date('28-11-2000', 'dd-mm-yyyy'), 9, 1444, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030411011179, to_date('11-04-2003', 'dd-mm-yyyy'), to_date('25-04-2003', 'dd-mm-yyyy'), 4, 2925, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605011180, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 2, 848, to_date('21-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091116011181, to_date('16-11-2009', 'dd-mm-yyyy'), to_date('30-11-2009', 'dd-mm-yyyy'), 8, 7289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620013876, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 2, 8690, to_date('24-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090629013877, to_date('29-06-2009', 'dd-mm-yyyy'), to_date('13-07-2009', 'dd-mm-yyyy'), 4, 4178, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000124013878, to_date('24-01-2000', 'dd-mm-yyyy'), to_date('07-02-2000', 'dd-mm-yyyy'), 3, 2118, to_date('05-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110203013879, to_date('03-02-2011', 'dd-mm-yyyy'), to_date('17-02-2011', 'dd-mm-yyyy'), 2, 6970, to_date('16-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303013880, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 1, 8228, to_date('14-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000108013881, to_date('08-01-2000', 'dd-mm-yyyy'), to_date('22-01-2000', 'dd-mm-yyyy'), 3, 3847, to_date('11-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120624013882, to_date('24-06-2012', 'dd-mm-yyyy'), to_date('08-07-2012', 'dd-mm-yyyy'), 4, 8564, to_date('06-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130628013883, to_date('28-06-2013', 'dd-mm-yyyy'), to_date('12-07-2013', 'dd-mm-yyyy'), 3, 9515, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030410013884, to_date('10-04-2003', 'dd-mm-yyyy'), to_date('24-04-2003', 'dd-mm-yyyy'), 1, 2441, to_date('15-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060429013885, to_date('29-04-2006', 'dd-mm-yyyy'), to_date('13-05-2006', 'dd-mm-yyyy'), 3, 4474, to_date('11-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030808013886, to_date('08-08-2003', 'dd-mm-yyyy'), to_date('22-08-2003', 'dd-mm-yyyy'), 2, 4231, to_date('19-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121105013887, to_date('05-11-2012', 'dd-mm-yyyy'), to_date('19-11-2012', 'dd-mm-yyyy'), 4, 8139, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018013888, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 3, 2910, to_date('28-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507013889, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 4, 3116, to_date('22-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040712013890, to_date('12-07-2004', 'dd-mm-yyyy'), to_date('26-07-2004', 'dd-mm-yyyy'), 2, 2836, to_date('25-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031211013891, to_date('11-12-2003', 'dd-mm-yyyy'), to_date('25-12-2003', 'dd-mm-yyyy'), 4, 1791, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061005013892, to_date('05-10-2006', 'dd-mm-yyyy'), to_date('19-10-2006', 'dd-mm-yyyy'), 3, 3855, to_date('10-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402013893, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 2, 2598, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020819013894, to_date('19-08-2002', 'dd-mm-yyyy'), to_date('02-09-2002', 'dd-mm-yyyy'), 4, 1660, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020522013895, to_date('22-05-2002', 'dd-mm-yyyy'), to_date('05-06-2002', 'dd-mm-yyyy'), 3, 1860, to_date('30-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080302013896, to_date('02-03-2008', 'dd-mm-yyyy'), to_date('16-03-2008', 'dd-mm-yyyy'), 3, 5631, to_date('13-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003013897, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 4, 1867, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020804013898, to_date('04-08-2002', 'dd-mm-yyyy'), to_date('18-08-2002', 'dd-mm-yyyy'), 2, 2194, to_date('24-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110508013899, to_date('08-05-2011', 'dd-mm-yyyy'), to_date('22-05-2011', 'dd-mm-yyyy'), 1, 9329, to_date('23-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121003013900, to_date('03-10-2012', 'dd-mm-yyyy'), to_date('17-10-2012', 'dd-mm-yyyy'), 2, 6621, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130829013901, to_date('29-08-2013', 'dd-mm-yyyy'), to_date('12-09-2013', 'dd-mm-yyyy'), 3, 8837, to_date('13-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020111013902, to_date('11-01-2002', 'dd-mm-yyyy'), to_date('25-01-2002', 'dd-mm-yyyy'), 2, 2475, to_date('19-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130302013903, to_date('02-03-2013', 'dd-mm-yyyy'), to_date('16-03-2013', 'dd-mm-yyyy'), 3, 9785, to_date('04-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090603013904, to_date('03-06-2009', 'dd-mm-yyyy'), to_date('17-06-2009', 'dd-mm-yyyy'), 2, 6962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111115013905, to_date('15-11-2011', 'dd-mm-yyyy'), to_date('29-11-2011', 'dd-mm-yyyy'), 2, 8356, to_date('25-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120623013906, to_date('23-06-2012', 'dd-mm-yyyy'), to_date('07-07-2012', 'dd-mm-yyyy'), 2, 8776, to_date('02-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120924013907, to_date('24-09-2012', 'dd-mm-yyyy'), to_date('08-10-2012', 'dd-mm-yyyy'), 1, 4964, to_date('09-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121020013908, to_date('20-10-2012', 'dd-mm-yyyy'), to_date('03-11-2012', 'dd-mm-yyyy'), 3, 7744, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000310013909, to_date('10-03-2000', 'dd-mm-yyyy'), to_date('24-03-2000', 'dd-mm-yyyy'), 3, 2986, to_date('11-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516013910, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 2, 5048, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130426013911, to_date('26-04-2013', 'dd-mm-yyyy'), to_date('10-05-2013', 'dd-mm-yyyy'), 3, 7912, to_date('05-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204013912, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 3, 7484, to_date('17-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050801013913, to_date('01-08-2005', 'dd-mm-yyyy'), to_date('15-08-2005', 'dd-mm-yyyy'), 2, 4252, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120913013914, to_date('13-09-2012', 'dd-mm-yyyy'), to_date('27-09-2012', 'dd-mm-yyyy'), 4, 8824, to_date('25-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091020013915, to_date('20-10-2009', 'dd-mm-yyyy'), to_date('03-11-2009', 'dd-mm-yyyy'), 3, 8223, to_date('09-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120013916, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 3, 1605, to_date('22-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000929013917, to_date('29-09-2000', 'dd-mm-yyyy'), to_date('13-10-2000', 'dd-mm-yyyy'), 2, 2303, to_date('14-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504013918, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 3, 8562, to_date('10-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031229013919, to_date('29-12-2003', 'dd-mm-yyyy'), to_date('12-01-2004', 'dd-mm-yyyy'), 3, 5009, to_date('09-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081126013920, to_date('26-11-2008', 'dd-mm-yyyy'), to_date('10-12-2008', 'dd-mm-yyyy'), 4, 9072, to_date('30-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000205013921, to_date('05-02-2000', 'dd-mm-yyyy'), to_date('19-02-2000', 'dd-mm-yyyy'), 2, 1426, to_date('21-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091019013922, to_date('19-10-2009', 'dd-mm-yyyy'), to_date('02-11-2009', 'dd-mm-yyyy'), 1, 7500, to_date('24-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030322013923, to_date('22-03-2003', 'dd-mm-yyyy'), to_date('05-04-2003', 'dd-mm-yyyy'), 4, 1823, to_date('01-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000408013924, to_date('08-04-2000', 'dd-mm-yyyy'), to_date('22-04-2000', 'dd-mm-yyyy'), 3, 1813, to_date('12-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120712013925, to_date('12-07-2012', 'dd-mm-yyyy'), to_date('26-07-2012', 'dd-mm-yyyy'), 3, 10684, to_date('31-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050604013926, to_date('04-06-2005', 'dd-mm-yyyy'), to_date('18-06-2005', 'dd-mm-yyyy'), 3, 2976, to_date('11-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050605013927, to_date('05-06-2005', 'dd-mm-yyyy'), to_date('19-06-2005', 'dd-mm-yyyy'), 3, 4300, to_date('08-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041209013928, to_date('09-12-2004', 'dd-mm-yyyy'), to_date('23-12-2004', 'dd-mm-yyyy'), 2, 4045, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120013929, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 1, 1388, to_date('27-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104013930, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 1, 3139, to_date('24-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407013931, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 4, 11282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100720013932, to_date('20-07-2010', 'dd-mm-yyyy'), to_date('03-08-2010', 'dd-mm-yyyy'), 1, 6717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906013933, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 3, 5801, to_date('12-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730013934, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 4, 6274, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111228013935, to_date('28-12-2011', 'dd-mm-yyyy'), to_date('11-01-2012', 'dd-mm-yyyy'), 3, 5558, to_date('14-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002013936, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 4, 6078, to_date('17-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504013937, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 3, 6837, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011023013938, to_date('23-10-2001', 'dd-mm-yyyy'), to_date('06-11-2001', 'dd-mm-yyyy'), 4, 1218, to_date('01-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041015013939, to_date('15-10-2004', 'dd-mm-yyyy'), to_date('29-10-2004', 'dd-mm-yyyy'), 4, 3491, to_date('28-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050927013940, to_date('27-09-2005', 'dd-mm-yyyy'), to_date('11-10-2005', 'dd-mm-yyyy'), 4, 6272, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031215013941, to_date('15-12-2003', 'dd-mm-yyyy'), to_date('29-12-2003', 'dd-mm-yyyy'), 2, 3122, to_date('25-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011202013942, to_date('02-12-2001', 'dd-mm-yyyy'), to_date('16-12-2001', 'dd-mm-yyyy'), 4, 2892, to_date('06-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010913013943, to_date('13-09-2001', 'dd-mm-yyyy'), to_date('27-09-2001', 'dd-mm-yyyy'), 4, 1942, to_date('29-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000520013944, to_date('20-05-2000', 'dd-mm-yyyy'), to_date('03-06-2000', 'dd-mm-yyyy'), 2, 744, to_date('03-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231013945, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 3, 5779, to_date('14-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061023013946, to_date('23-10-2006', 'dd-mm-yyyy'), to_date('06-11-2006', 'dd-mm-yyyy'), 1, 5083, to_date('06-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050728013947, to_date('28-07-2005', 'dd-mm-yyyy'), to_date('11-08-2005', 'dd-mm-yyyy'), 3, 3782, to_date('08-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050916013948, to_date('16-09-2005', 'dd-mm-yyyy'), to_date('30-09-2005', 'dd-mm-yyyy'), 4, 3195, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100803013949, to_date('03-08-2010', 'dd-mm-yyyy'), to_date('17-08-2010', 'dd-mm-yyyy'), 3, 7337, to_date('17-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010204013950, to_date('04-02-2001', 'dd-mm-yyyy'), to_date('18-02-2001', 'dd-mm-yyyy'), 4, 1693, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000218013951, to_date('18-02-2000', 'dd-mm-yyyy'), to_date('03-03-2000', 'dd-mm-yyyy'), 4, 828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100430013952, to_date('30-04-2010', 'dd-mm-yyyy'), to_date('14-05-2010', 'dd-mm-yyyy'), 4, 9655, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131128013953, to_date('28-11-2013', 'dd-mm-yyyy'), to_date('12-12-2013', 'dd-mm-yyyy'), 3, 8344, to_date('14-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000120013954, to_date('20-01-2000', 'dd-mm-yyyy'), to_date('03-02-2000', 'dd-mm-yyyy'), 4, 3631, to_date('30-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020815013955, to_date('15-08-2002', 'dd-mm-yyyy'), to_date('29-08-2002', 'dd-mm-yyyy'), 1, 2282, to_date('21-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130322013956, to_date('22-03-2013', 'dd-mm-yyyy'), to_date('05-04-2013', 'dd-mm-yyyy'), 2, 10552, to_date('04-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130129013957, to_date('29-01-2013', 'dd-mm-yyyy'), to_date('12-02-2013', 'dd-mm-yyyy'), 3, 9594, to_date('17-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021217013958, to_date('17-12-2002', 'dd-mm-yyyy'), to_date('31-12-2002', 'dd-mm-yyyy'), 4, 4753, to_date('03-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020416013959, to_date('16-04-2002', 'dd-mm-yyyy'), to_date('30-04-2002', 'dd-mm-yyyy'), 3, 5342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100308013960, to_date('08-03-2010', 'dd-mm-yyyy'), to_date('22-03-2010', 'dd-mm-yyyy'), 2, 8060, to_date('16-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020325013961, to_date('25-03-2002', 'dd-mm-yyyy'), to_date('08-04-2002', 'dd-mm-yyyy'), 3, 3151, to_date('27-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121010013962, to_date('10-10-2012', 'dd-mm-yyyy'), to_date('24-10-2012', 'dd-mm-yyyy'), 2, 8287, to_date('18-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110013963, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 4, 1962, to_date('28-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060210013964, to_date('10-02-2006', 'dd-mm-yyyy'), to_date('24-02-2006', 'dd-mm-yyyy'), 3, 5119, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020218013965, to_date('18-02-2002', 'dd-mm-yyyy'), to_date('04-03-2002', 'dd-mm-yyyy'), 1, 5214, to_date('26-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051202013966, to_date('02-12-2005', 'dd-mm-yyyy'), to_date('16-12-2005', 'dd-mm-yyyy'), 3, 5872, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016013967, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 3, 2574, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110924013968, to_date('24-09-2011', 'dd-mm-yyyy'), to_date('08-10-2011', 'dd-mm-yyyy'), 1, 8502, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101216013969, to_date('16-12-2010', 'dd-mm-yyyy'), to_date('30-12-2010', 'dd-mm-yyyy'), 4, 4788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130304013970, to_date('04-03-2013', 'dd-mm-yyyy'), to_date('18-03-2013', 'dd-mm-yyyy'), 3, 5988, to_date('14-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119013971, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 2, 2499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070123013972, to_date('23-01-2007', 'dd-mm-yyyy'), to_date('06-02-2007', 'dd-mm-yyyy'), 4, 5138, to_date('08-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010719013973, to_date('19-07-2001', 'dd-mm-yyyy'), to_date('02-08-2001', 'dd-mm-yyyy'), 1, 2398, to_date('28-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031025013974, to_date('25-10-2003', 'dd-mm-yyyy'), to_date('08-11-2003', 'dd-mm-yyyy'), 1, 4144, to_date('11-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120925013975, to_date('25-09-2012', 'dd-mm-yyyy'), to_date('09-10-2012', 'dd-mm-yyyy'), 2, 7315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000720013976, to_date('20-07-2000', 'dd-mm-yyyy'), to_date('03-08-2000', 'dd-mm-yyyy'), 4, 1711, to_date('02-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111229013977, to_date('29-12-2011', 'dd-mm-yyyy'), to_date('12-01-2012', 'dd-mm-yyyy'), 1, 6111, to_date('16-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100125013978, to_date('25-01-2010', 'dd-mm-yyyy'), to_date('08-02-2010', 'dd-mm-yyyy'), 4, 8455, to_date('11-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229013979, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 2, 5275, to_date('07-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040327013980, to_date('27-03-2004', 'dd-mm-yyyy'), to_date('10-04-2004', 'dd-mm-yyyy'), 1, 4245, to_date('07-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051113013981, to_date('13-11-2005', 'dd-mm-yyyy'), to_date('27-11-2005', 'dd-mm-yyyy'), 1, 3936, to_date('29-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060924013982, to_date('24-09-2006', 'dd-mm-yyyy'), to_date('08-10-2006', 'dd-mm-yyyy'), 2, 3529, to_date('02-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011226013983, to_date('26-12-2001', 'dd-mm-yyyy'), to_date('09-01-2002', 'dd-mm-yyyy'), 1, 1849, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110731013984, to_date('31-07-2011', 'dd-mm-yyyy'), to_date('14-08-2011', 'dd-mm-yyyy'), 1, 7129, to_date('17-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050329013985, to_date('29-03-2005', 'dd-mm-yyyy'), to_date('12-04-2005', 'dd-mm-yyyy'), 2, 3714, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040519013986, to_date('19-05-2004', 'dd-mm-yyyy'), to_date('02-06-2004', 'dd-mm-yyyy'), 3, 3192, to_date('29-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530013987, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 2, 6215, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802013988, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 2, 2393, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110013989, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 4, 7424, to_date('27-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729013990, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 3, 6585, to_date('08-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100127013991, to_date('27-01-2010', 'dd-mm-yyyy'), to_date('10-02-2010', 'dd-mm-yyyy'), 2, 5380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100524013992, to_date('24-05-2010', 'dd-mm-yyyy'), to_date('07-06-2010', 'dd-mm-yyyy'), 1, 8551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218013993, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 2, 6843, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021113013994, to_date('13-11-2002', 'dd-mm-yyyy'), to_date('27-11-2002', 'dd-mm-yyyy'), 1, 2623, to_date('16-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000613013995, to_date('13-06-2000', 'dd-mm-yyyy'), to_date('27-06-2000', 'dd-mm-yyyy'), 3, 2601, to_date('24-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080902013996, to_date('02-09-2008', 'dd-mm-yyyy'), to_date('16-09-2008', 'dd-mm-yyyy'), 1, 5405, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070611013997, to_date('11-06-2007', 'dd-mm-yyyy'), to_date('25-06-2007', 'dd-mm-yyyy'), 2, 6633, to_date('20-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041229013998, to_date('29-12-2004', 'dd-mm-yyyy'), to_date('12-01-2005', 'dd-mm-yyyy'), 2, 5335, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010325013999, to_date('25-03-2001', 'dd-mm-yyyy'), to_date('08-04-2001', 'dd-mm-yyyy'), 3, 1124, to_date('09-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021002014000, to_date('02-10-2002', 'dd-mm-yyyy'), to_date('16-10-2002', 'dd-mm-yyyy'), 2, 3370, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031014001, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 4, 4354, to_date('14-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140109014002, to_date('09-01-2014', 'dd-mm-yyyy'), to_date('23-01-2014', 'dd-mm-yyyy'), 3, 10595, to_date('17-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050125014003, to_date('25-01-2005', 'dd-mm-yyyy'), to_date('08-02-2005', 'dd-mm-yyyy'), 4, 2746, to_date('10-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080611014004, to_date('11-06-2008', 'dd-mm-yyyy'), to_date('25-06-2008', 'dd-mm-yyyy'), 3, 7930, to_date('01-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130728014005, to_date('28-07-2013', 'dd-mm-yyyy'), to_date('11-08-2013', 'dd-mm-yyyy'), 1, 7393, to_date('15-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227014006, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 4, 7223, to_date('08-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221014007, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 2, 9788, to_date('27-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071008014008, to_date('08-10-2007', 'dd-mm-yyyy'), to_date('22-10-2007', 'dd-mm-yyyy'), 2, 5504, to_date('16-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228014009, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 3, 6768, to_date('03-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030922014010, to_date('22-09-2003', 'dd-mm-yyyy'), to_date('06-10-2003', 'dd-mm-yyyy'), 3, 2700, to_date('27-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000129014011, to_date('29-01-2000', 'dd-mm-yyyy'), to_date('12-02-2000', 'dd-mm-yyyy'), 2, 2484, to_date('01-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130113014012, to_date('13-01-2013', 'dd-mm-yyyy'), to_date('27-01-2013', 'dd-mm-yyyy'), 2, 7650, to_date('22-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427014013, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 3, 2159, to_date('15-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060505014014, to_date('05-05-2006', 'dd-mm-yyyy'), to_date('19-05-2006', 'dd-mm-yyyy'), 3, 3220, to_date('17-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802014015, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 9654, to_date('11-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123014016, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 1, 11029, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030830014017, to_date('30-08-2003', 'dd-mm-yyyy'), to_date('13-09-2003', 'dd-mm-yyyy'), 4, 3598, to_date('02-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081224014018, to_date('24-12-2008', 'dd-mm-yyyy'), to_date('07-01-2009', 'dd-mm-yyyy'), 3, 7328, to_date('02-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208014019, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 3, 1235, to_date('25-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090507014020, to_date('07-05-2009', 'dd-mm-yyyy'), to_date('21-05-2009', 'dd-mm-yyyy'), 3, 4317, to_date('27-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050909014021, to_date('09-09-2005', 'dd-mm-yyyy'), to_date('23-09-2005', 'dd-mm-yyyy'), 2, 3666, to_date('23-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607014022, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 1, 4752, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112014023, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 2, 4233, to_date('23-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081115014024, to_date('15-11-2008', 'dd-mm-yyyy'), to_date('29-11-2008', 'dd-mm-yyyy'), 2, 6497, to_date('22-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030918014025, to_date('18-09-2003', 'dd-mm-yyyy'), to_date('02-10-2003', 'dd-mm-yyyy'), 3, 4018, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130628014026, to_date('28-06-2013', 'dd-mm-yyyy'), to_date('12-07-2013', 'dd-mm-yyyy'), 3, 8899, to_date('06-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130617014027, to_date('17-06-2013', 'dd-mm-yyyy'), to_date('01-07-2013', 'dd-mm-yyyy'), 2, 5758, to_date('05-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213014028, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 4, 7714, to_date('23-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513014029, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 3, 3121, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111230014030, to_date('30-12-2011', 'dd-mm-yyyy'), to_date('13-01-2012', 'dd-mm-yyyy'), 2, 5241, to_date('03-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020116014031, to_date('16-01-2002', 'dd-mm-yyyy'), to_date('30-01-2002', 'dd-mm-yyyy'), 2, 2111, to_date('25-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324014032, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 4, 3585, to_date('31-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040104014033, to_date('04-01-2004', 'dd-mm-yyyy'), to_date('18-01-2004', 'dd-mm-yyyy'), 4, 4672, to_date('18-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020826014034, to_date('26-08-2002', 'dd-mm-yyyy'), to_date('09-09-2002', 'dd-mm-yyyy'), 2, 3925, to_date('02-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050910014035, to_date('10-09-2005', 'dd-mm-yyyy'), to_date('24-09-2005', 'dd-mm-yyyy'), 3, 6577, to_date('22-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081102014036, to_date('02-11-2008', 'dd-mm-yyyy'), to_date('16-11-2008', 'dd-mm-yyyy'), 2, 6188, to_date('16-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130905014037, to_date('05-09-2013', 'dd-mm-yyyy'), to_date('19-09-2013', 'dd-mm-yyyy'), 4, 7751, to_date('10-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130111014038, to_date('11-01-2013', 'dd-mm-yyyy'), to_date('25-01-2013', 'dd-mm-yyyy'), 3, 8258, to_date('21-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121217014039, to_date('17-12-2012', 'dd-mm-yyyy'), to_date('31-12-2012', 'dd-mm-yyyy'), 3, 7640, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070219014040, to_date('19-02-2007', 'dd-mm-yyyy'), to_date('05-03-2007', 'dd-mm-yyyy'), 3, 3237, to_date('24-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070513014041, to_date('13-05-2007', 'dd-mm-yyyy'), to_date('27-05-2007', 'dd-mm-yyyy'), 3, 7847, to_date('20-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071002013875, to_date('02-10-2007', 'dd-mm-yyyy'), to_date('16-10-2007', 'dd-mm-yyyy'), 4, 4466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331016568, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 1, 3132, to_date('04-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080517016569, to_date('17-05-2008', 'dd-mm-yyyy'), to_date('31-05-2008', 'dd-mm-yyyy'), 1, 7304, to_date('02-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905016570, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 1, 2506, to_date('16-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120403016571, to_date('03-04-2012', 'dd-mm-yyyy'), to_date('17-04-2012', 'dd-mm-yyyy'), 1, 7009, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140317016572, to_date('17-03-2014', 'dd-mm-yyyy'), to_date('31-03-2014', 'dd-mm-yyyy'), 1, 7849, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130127016573, to_date('27-01-2013', 'dd-mm-yyyy'), to_date('10-02-2013', 'dd-mm-yyyy'), 1, 10058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230016574, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 2, 1856, to_date('03-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040402016575, to_date('02-04-2004', 'dd-mm-yyyy'), to_date('16-04-2004', 'dd-mm-yyyy'), 2, 3862, to_date('09-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110016576, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 2, 10275, to_date('18-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324016577, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 1, 1184, to_date('08-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404016578, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 1, 7737, to_date('16-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100817016579, to_date('17-08-2010', 'dd-mm-yyyy'), to_date('31-08-2010', 'dd-mm-yyyy'), 1, 6224, to_date('22-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111129016580, to_date('29-11-2011', 'dd-mm-yyyy'), to_date('13-12-2011', 'dd-mm-yyyy'), 2, 6047, to_date('07-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080617016581, to_date('17-06-2008', 'dd-mm-yyyy'), to_date('01-07-2008', 'dd-mm-yyyy'), 1, 6136, to_date('23-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703016582, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 2, 3723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130324016583, to_date('24-03-2013', 'dd-mm-yyyy'), to_date('07-04-2013', 'dd-mm-yyyy'), 2, 8638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041026016584, to_date('26-10-2004', 'dd-mm-yyyy'), to_date('09-11-2004', 'dd-mm-yyyy'), 2, 4484, to_date('05-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120808016585, to_date('08-08-2012', 'dd-mm-yyyy'), to_date('22-08-2012', 'dd-mm-yyyy'), 1, 8178, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080310016586, to_date('10-03-2008', 'dd-mm-yyyy'), to_date('24-03-2008', 'dd-mm-yyyy'), 1, 4466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103016587, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 2, 3557, to_date('23-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041016016588, to_date('16-10-2004', 'dd-mm-yyyy'), to_date('30-10-2004', 'dd-mm-yyyy'), 1, 4379, to_date('28-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113016589, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 2, 10259, to_date('20-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140501016590, to_date('01-05-2014', 'dd-mm-yyyy'), to_date('15-05-2014', 'dd-mm-yyyy'), 2, 9736, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130908016591, to_date('08-09-2013', 'dd-mm-yyyy'), to_date('22-09-2013', 'dd-mm-yyyy'), 2, 8759, to_date('18-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124016592, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 2, 7615, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001224016593, to_date('24-12-2000', 'dd-mm-yyyy'), to_date('07-01-2001', 'dd-mm-yyyy'), 2, 3164, to_date('27-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030619016594, to_date('19-06-2003', 'dd-mm-yyyy'), to_date('03-07-2003', 'dd-mm-yyyy'), 2, 3676, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702016595, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 1, 1308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090426016596, to_date('26-04-2009', 'dd-mm-yyyy'), to_date('10-05-2009', 'dd-mm-yyyy'), 2, 8663, to_date('01-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031222016597, to_date('22-12-2003', 'dd-mm-yyyy'), to_date('05-01-2004', 'dd-mm-yyyy'), 2, 2970, to_date('24-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123016598, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 2, 3708, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926016599, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 2, 1312, to_date('13-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000313016600, to_date('13-03-2000', 'dd-mm-yyyy'), to_date('27-03-2000', 'dd-mm-yyyy'), 2, 1873, to_date('15-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101211016601, to_date('11-12-2010', 'dd-mm-yyyy'), to_date('25-12-2010', 'dd-mm-yyyy'), 2, 7510, to_date('23-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130713016602, to_date('13-07-2013', 'dd-mm-yyyy'), to_date('27-07-2013', 'dd-mm-yyyy'), 1, 10657, to_date('22-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903016603, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 2, 1743, to_date('15-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071115016604, to_date('15-11-2007', 'dd-mm-yyyy'), to_date('29-11-2007', 'dd-mm-yyyy'), 2, 5357, to_date('04-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110919016605, to_date('19-09-2011', 'dd-mm-yyyy'), to_date('03-10-2011', 'dd-mm-yyyy'), 2, 6742, to_date('22-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040219016606, to_date('19-02-2004', 'dd-mm-yyyy'), to_date('04-03-2004', 'dd-mm-yyyy'), 1, 2427, to_date('08-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080602016607, to_date('02-06-2008', 'dd-mm-yyyy'), to_date('16-06-2008', 'dd-mm-yyyy'), 1, 6416, to_date('08-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081020016608, to_date('20-10-2008', 'dd-mm-yyyy'), to_date('03-11-2008', 'dd-mm-yyyy'), 2, 7829, to_date('23-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090406016609, to_date('06-04-2009', 'dd-mm-yyyy'), to_date('20-04-2009', 'dd-mm-yyyy'), 1, 4738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041214016610, to_date('14-12-2004', 'dd-mm-yyyy'), to_date('28-12-2004', 'dd-mm-yyyy'), 1, 3521, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030607016611, to_date('07-06-2003', 'dd-mm-yyyy'), to_date('21-06-2003', 'dd-mm-yyyy'), 2, 3012, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111003016612, to_date('03-10-2011', 'dd-mm-yyyy'), to_date('17-10-2011', 'dd-mm-yyyy'), 2, 6330, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019016613, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 1, 2556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021018016614, to_date('18-10-2002', 'dd-mm-yyyy'), to_date('01-11-2002', 'dd-mm-yyyy'), 1, 3181, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011201016615, to_date('01-12-2001', 'dd-mm-yyyy'), to_date('15-12-2001', 'dd-mm-yyyy'), 1, 2436, to_date('04-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120115016616, to_date('15-01-2012', 'dd-mm-yyyy'), to_date('29-01-2012', 'dd-mm-yyyy'), 1, 9241, to_date('28-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140206016617, to_date('06-02-2014', 'dd-mm-yyyy'), to_date('20-02-2014', 'dd-mm-yyyy'), 1, 6555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070330016618, to_date('30-03-2007', 'dd-mm-yyyy'), to_date('13-04-2007', 'dd-mm-yyyy'), 1, 7116, to_date('10-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313016619, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 1, 4865, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000228016620, to_date('28-02-2000', 'dd-mm-yyyy'), to_date('13-03-2000', 'dd-mm-yyyy'), 1, 3230, to_date('16-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070621016621, to_date('21-06-2007', 'dd-mm-yyyy'), to_date('05-07-2007', 'dd-mm-yyyy'), 1, 4598, to_date('08-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130816016622, to_date('16-08-2013', 'dd-mm-yyyy'), to_date('30-08-2013', 'dd-mm-yyyy'), 2, 8455, to_date('20-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101223016623, to_date('23-12-2010', 'dd-mm-yyyy'), to_date('06-01-2011', 'dd-mm-yyyy'), 1, 8181, to_date('27-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091002016624, to_date('02-10-2009', 'dd-mm-yyyy'), to_date('16-10-2009', 'dd-mm-yyyy'), 1, 7283, to_date('15-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404016625, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 1, 5817, to_date('14-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010928016626, to_date('28-09-2001', 'dd-mm-yyyy'), to_date('12-10-2001', 'dd-mm-yyyy'), 1, 3037, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070331016627, to_date('31-03-2007', 'dd-mm-yyyy'), to_date('14-04-2007', 'dd-mm-yyyy'), 2, 3994, to_date('14-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215016628, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 1, 5569, to_date('22-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130827016629, to_date('27-08-2013', 'dd-mm-yyyy'), to_date('10-09-2013', 'dd-mm-yyyy'), 2, 7402, to_date('02-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050820016630, to_date('20-08-2005', 'dd-mm-yyyy'), to_date('03-09-2005', 'dd-mm-yyyy'), 2, 4487, to_date('24-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041027016631, to_date('27-10-2004', 'dd-mm-yyyy'), to_date('10-11-2004', 'dd-mm-yyyy'), 1, 3184, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011103016632, to_date('03-11-2001', 'dd-mm-yyyy'), to_date('17-11-2001', 'dd-mm-yyyy'), 1, 496, to_date('22-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110531016633, to_date('31-05-2011', 'dd-mm-yyyy'), to_date('14-06-2011', 'dd-mm-yyyy'), 1, 6960, to_date('14-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060520016634, to_date('20-05-2006', 'dd-mm-yyyy'), to_date('03-06-2006', 'dd-mm-yyyy'), 2, 4443, to_date('25-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040404016635, to_date('04-04-2004', 'dd-mm-yyyy'), to_date('18-04-2004', 'dd-mm-yyyy'), 1, 4432, to_date('15-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130514016636, to_date('14-05-2013', 'dd-mm-yyyy'), to_date('28-05-2013', 'dd-mm-yyyy'), 1, 7076, to_date('23-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213016637, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 2, 4941, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916016638, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 1, 3360, to_date('06-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110421016639, to_date('21-04-2011', 'dd-mm-yyyy'), to_date('05-05-2011', 'dd-mm-yyyy'), 2, 10166, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131214016640, to_date('14-12-2013', 'dd-mm-yyyy'), to_date('28-12-2013', 'dd-mm-yyyy'), 1, 8117, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050411016641, to_date('11-04-2005', 'dd-mm-yyyy'), to_date('25-04-2005', 'dd-mm-yyyy'), 1, 2853, to_date('20-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120426016642, to_date('26-04-2012', 'dd-mm-yyyy'), to_date('10-05-2012', 'dd-mm-yyyy'), 1, 7038, to_date('15-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040701016643, to_date('01-07-2004', 'dd-mm-yyyy'), to_date('15-07-2004', 'dd-mm-yyyy'), 1, 2826, to_date('08-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100507016644, to_date('07-05-2010', 'dd-mm-yyyy'), to_date('21-05-2010', 'dd-mm-yyyy'), 1, 8841, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101205016645, to_date('05-12-2010', 'dd-mm-yyyy'), to_date('19-12-2010', 'dd-mm-yyyy'), 2, 7038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302016646, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 1, 7466, to_date('15-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050310016647, to_date('10-03-2005', 'dd-mm-yyyy'), to_date('24-03-2005', 'dd-mm-yyyy'), 1, 6705, to_date('26-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116016648, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 1, 7211, to_date('22-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050119016649, to_date('19-01-2005', 'dd-mm-yyyy'), to_date('02-02-2005', 'dd-mm-yyyy'), 2, 5656, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071015016650, to_date('15-10-2007', 'dd-mm-yyyy'), to_date('29-10-2007', 'dd-mm-yyyy'), 1, 6015, to_date('29-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327016651, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 1, 6436, to_date('09-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101213016652, to_date('13-12-2010', 'dd-mm-yyyy'), to_date('27-12-2010', 'dd-mm-yyyy'), 2, 7554, to_date('22-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060923016653, to_date('23-09-2006', 'dd-mm-yyyy'), to_date('07-10-2006', 'dd-mm-yyyy'), 1, 3217, to_date('07-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203016654, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 2, 7769, to_date('22-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120805016655, to_date('05-08-2012', 'dd-mm-yyyy'), to_date('19-08-2012', 'dd-mm-yyyy'), 2, 7109, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120016656, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 1, 5588, to_date('02-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130409016657, to_date('09-04-2013', 'dd-mm-yyyy'), to_date('23-04-2013', 'dd-mm-yyyy'), 2, 8179, to_date('29-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000818016658, to_date('18-08-2000', 'dd-mm-yyyy'), to_date('01-09-2000', 'dd-mm-yyyy'), 1, 948, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130511016659, to_date('11-05-2013', 'dd-mm-yyyy'), to_date('25-05-2013', 'dd-mm-yyyy'), 1, 7177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050912016660, to_date('12-09-2005', 'dd-mm-yyyy'), to_date('26-09-2005', 'dd-mm-yyyy'), 1, 3305, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823016661, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 2, 6240, to_date('06-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090716016662, to_date('16-07-2009', 'dd-mm-yyyy'), to_date('30-07-2009', 'dd-mm-yyyy'), 1, 5695, to_date('30-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417016663, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 2, 7227, to_date('29-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020130016664, to_date('30-01-2002', 'dd-mm-yyyy'), to_date('13-02-2002', 'dd-mm-yyyy'), 1, 3117, to_date('06-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080402016665, to_date('02-04-2008', 'dd-mm-yyyy'), to_date('16-04-2008', 'dd-mm-yyyy'), 2, 4795, to_date('19-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516016666, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 1, 6801, to_date('19-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130621016667, to_date('21-06-2013', 'dd-mm-yyyy'), to_date('05-07-2013', 'dd-mm-yyyy'), 2, 8292, to_date('23-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021103016668, to_date('03-11-2002', 'dd-mm-yyyy'), to_date('17-11-2002', 'dd-mm-yyyy'), 2, 1879, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050325016669, to_date('25-03-2005', 'dd-mm-yyyy'), to_date('08-04-2005', 'dd-mm-yyyy'), 2, 3048, to_date('06-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091119016670, to_date('19-11-2009', 'dd-mm-yyyy'), to_date('03-12-2009', 'dd-mm-yyyy'), 1, 6556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124016671, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 2, 3228, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060404016672, to_date('04-04-2006', 'dd-mm-yyyy'), to_date('18-04-2006', 'dd-mm-yyyy'), 2, 1895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050401016673, to_date('01-04-2005', 'dd-mm-yyyy'), to_date('15-04-2005', 'dd-mm-yyyy'), 1, 4731, to_date('15-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629016674, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 1, 3455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051113016675, to_date('13-11-2005', 'dd-mm-yyyy'), to_date('27-11-2005', 'dd-mm-yyyy'), 2, 4903, to_date('26-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111112016676, to_date('12-11-2011', 'dd-mm-yyyy'), to_date('26-11-2011', 'dd-mm-yyyy'), 2, 6777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061118016677, to_date('18-11-2006', 'dd-mm-yyyy'), to_date('02-12-2006', 'dd-mm-yyyy'), 2, 5993, to_date('08-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030223016678, to_date('23-02-2003', 'dd-mm-yyyy'), to_date('09-03-2003', 'dd-mm-yyyy'), 2, 1982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021010016679, to_date('10-10-2002', 'dd-mm-yyyy'), to_date('24-10-2002', 'dd-mm-yyyy'), 2, 2240, to_date('25-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210016680, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 2, 4289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218016681, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 1, 2633, to_date('10-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030927016682, to_date('27-09-2003', 'dd-mm-yyyy'), to_date('11-10-2003', 'dd-mm-yyyy'), 2, 5102, to_date('10-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080209016683, to_date('09-02-2008', 'dd-mm-yyyy'), to_date('23-02-2008', 'dd-mm-yyyy'), 2, 5724, to_date('11-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020409016684, to_date('09-04-2002', 'dd-mm-yyyy'), to_date('23-04-2002', 'dd-mm-yyyy'), 1, 3474, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030117016685, to_date('17-01-2003', 'dd-mm-yyyy'), to_date('31-01-2003', 'dd-mm-yyyy'), 1, 4448, to_date('22-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030213016686, to_date('13-02-2003', 'dd-mm-yyyy'), to_date('27-02-2003', 'dd-mm-yyyy'), 1, 3522, to_date('18-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825016687, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 1, 1134, to_date('29-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110726016688, to_date('26-07-2011', 'dd-mm-yyyy'), to_date('09-08-2011', 'dd-mm-yyyy'), 2, 8036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129016689, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 2, 5194, to_date('07-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140119016690, to_date('19-01-2014', 'dd-mm-yyyy'), to_date('02-02-2014', 'dd-mm-yyyy'), 2, 11483, to_date('08-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110721016691, to_date('21-07-2011', 'dd-mm-yyyy'), to_date('04-08-2011', 'dd-mm-yyyy'), 2, 7800, to_date('06-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130316016692, to_date('16-03-2013', 'dd-mm-yyyy'), to_date('30-03-2013', 'dd-mm-yyyy'), 1, 6700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208016693, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 2, 2814, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060306016694, to_date('06-03-2006', 'dd-mm-yyyy'), to_date('20-03-2006', 'dd-mm-yyyy'), 2, 4985, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030802016695, to_date('02-08-2003', 'dd-mm-yyyy'), to_date('16-08-2003', 'dd-mm-yyyy'), 2, 4466, to_date('15-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070922016696, to_date('22-09-2007', 'dd-mm-yyyy'), to_date('06-10-2007', 'dd-mm-yyyy'), 1, 6902, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080604016697, to_date('04-06-2008', 'dd-mm-yyyy'), to_date('18-06-2008', 'dd-mm-yyyy'), 1, 4650, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091128016698, to_date('28-11-2009', 'dd-mm-yyyy'), to_date('12-12-2009', 'dd-mm-yyyy'), 1, 4660, to_date('16-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030526016699, to_date('26-05-2003', 'dd-mm-yyyy'), to_date('09-06-2003', 'dd-mm-yyyy'), 1, 4369, to_date('03-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010810016700, to_date('10-08-2001', 'dd-mm-yyyy'), to_date('24-08-2001', 'dd-mm-yyyy'), 1, 2573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030823016701, to_date('23-08-2003', 'dd-mm-yyyy'), to_date('06-09-2003', 'dd-mm-yyyy'), 1, 2603, to_date('03-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130214016702, to_date('14-02-2013', 'dd-mm-yyyy'), to_date('28-02-2013', 'dd-mm-yyyy'), 2, 7917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081129016703, to_date('29-11-2008', 'dd-mm-yyyy'), to_date('13-12-2008', 'dd-mm-yyyy'), 2, 7231, to_date('16-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080813016704, to_date('13-08-2008', 'dd-mm-yyyy'), to_date('27-08-2008', 'dd-mm-yyyy'), 1, 5584, to_date('29-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303016705, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 2, 9252, to_date('22-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021231016706, to_date('31-12-2002', 'dd-mm-yyyy'), to_date('14-01-2003', 'dd-mm-yyyy'), 1, 1590, to_date('02-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000623016707, to_date('23-06-2000', 'dd-mm-yyyy'), to_date('07-07-2000', 'dd-mm-yyyy'), 1, 407, to_date('01-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040113016708, to_date('13-01-2004', 'dd-mm-yyyy'), to_date('27-01-2004', 'dd-mm-yyyy'), 2, 4686, to_date('24-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120805016709, to_date('05-08-2012', 'dd-mm-yyyy'), to_date('19-08-2012', 'dd-mm-yyyy'), 2, 8263, to_date('06-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051223016710, to_date('23-12-2005', 'dd-mm-yyyy'), to_date('06-01-2006', 'dd-mm-yyyy'), 2, 4127, to_date('08-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103016711, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 1, 5494, to_date('06-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080615016712, to_date('15-06-2008', 'dd-mm-yyyy'), to_date('29-06-2008', 'dd-mm-yyyy'), 1, 7235, to_date('25-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001121016713, to_date('21-11-2000', 'dd-mm-yyyy'), to_date('05-12-2000', 'dd-mm-yyyy'), 2, 3578, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010214016714, to_date('14-02-2001', 'dd-mm-yyyy'), to_date('28-02-2001', 'dd-mm-yyyy'), 2, 3443, to_date('18-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040410016715, to_date('10-04-2004', 'dd-mm-yyyy'), to_date('24-04-2004', 'dd-mm-yyyy'), 2, 3151, to_date('20-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901016716, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 2, 5018, to_date('13-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060322016717, to_date('22-03-2006', 'dd-mm-yyyy'), to_date('05-04-2006', 'dd-mm-yyyy'), 2, 3603, to_date('03-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121221016718, to_date('21-12-2012', 'dd-mm-yyyy'), to_date('04-01-2013', 'dd-mm-yyyy'), 2, 9634, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930016719, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 1, 1708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101220016720, to_date('20-12-2010', 'dd-mm-yyyy'), to_date('03-01-2011', 'dd-mm-yyyy'), 1, 8485, to_date('08-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100105016721, to_date('05-01-2010', 'dd-mm-yyyy'), to_date('19-01-2010', 'dd-mm-yyyy'), 1, 6804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000122016722, to_date('22-01-2000', 'dd-mm-yyyy'), to_date('05-02-2000', 'dd-mm-yyyy'), 2, 1846, to_date('06-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113016723, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 2, 3694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110609016724, to_date('09-06-2011', 'dd-mm-yyyy'), to_date('23-06-2011', 'dd-mm-yyyy'), 2, 6462, to_date('29-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217016725, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 2, 2457, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060704016726, to_date('04-07-2006', 'dd-mm-yyyy'), to_date('18-07-2006', 'dd-mm-yyyy'), 2, 6197, to_date('21-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919016727, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 1, 8044, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120311016728, to_date('11-03-2012', 'dd-mm-yyyy'), to_date('25-03-2012', 'dd-mm-yyyy'), 1, 6588, to_date('29-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080923016729, to_date('23-09-2008', 'dd-mm-yyyy'), to_date('07-10-2008', 'dd-mm-yyyy'), 1, 5592, to_date('03-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000127016730, to_date('27-01-2000', 'dd-mm-yyyy'), to_date('10-02-2000', 'dd-mm-yyyy'), 1, 2913, to_date('14-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013016731, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 2, 6178, to_date('28-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130016732, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 2, 3669, to_date('02-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110119016733, to_date('19-01-2011', 'dd-mm-yyyy'), to_date('02-02-2011', 'dd-mm-yyyy'), 1, 9993, to_date('23-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208016734, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 2, 8185, to_date('24-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711016735, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 1, 5725, to_date('25-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030105011182, to_date('05-01-2003', 'dd-mm-yyyy'), to_date('19-01-2003', 'dd-mm-yyyy'), 6, 4146, to_date('06-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060713011183, to_date('13-07-2006', 'dd-mm-yyyy'), to_date('27-07-2006', 'dd-mm-yyyy'), 6, 4533, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906011184, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 5, 8453, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020729011185, to_date('29-07-2002', 'dd-mm-yyyy'), to_date('12-08-2002', 'dd-mm-yyyy'), 7, 2430, to_date('10-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110222011186, to_date('22-02-2011', 'dd-mm-yyyy'), to_date('08-03-2011', 'dd-mm-yyyy'), 8, 8316, to_date('04-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119011187, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 8, 1921, to_date('02-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060111011188, to_date('11-01-2006', 'dd-mm-yyyy'), to_date('25-01-2006', 'dd-mm-yyyy'), 8, 3188, to_date('23-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060807011189, to_date('07-08-2006', 'dd-mm-yyyy'), to_date('21-08-2006', 'dd-mm-yyyy'), 10, 3719, to_date('18-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070312011190, to_date('12-03-2007', 'dd-mm-yyyy'), to_date('26-03-2007', 'dd-mm-yyyy'), 1, 6830, to_date('21-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051127011191, to_date('27-11-2005', 'dd-mm-yyyy'), to_date('11-12-2005', 'dd-mm-yyyy'), 2, 3084, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061112011192, to_date('12-11-2006', 'dd-mm-yyyy'), to_date('26-11-2006', 'dd-mm-yyyy'), 8, 5193, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031027011193, to_date('27-10-2003', 'dd-mm-yyyy'), to_date('10-11-2003', 'dd-mm-yyyy'), 1, 1918, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123011194, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 5, 648, to_date('08-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826011195, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 9, 5271, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061124011196, to_date('24-11-2006', 'dd-mm-yyyy'), to_date('08-12-2006', 'dd-mm-yyyy'), 8, 5140, to_date('10-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080910011197, to_date('10-09-2008', 'dd-mm-yyyy'), to_date('24-09-2008', 'dd-mm-yyyy'), 3, 8213, to_date('12-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050216011198, to_date('16-02-2005', 'dd-mm-yyyy'), to_date('02-03-2005', 'dd-mm-yyyy'), 8, 5208, to_date('05-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090611011199, to_date('11-06-2009', 'dd-mm-yyyy'), to_date('25-06-2009', 'dd-mm-yyyy'), 7, 7119, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010102011200, to_date('02-01-2001', 'dd-mm-yyyy'), to_date('16-01-2001', 'dd-mm-yyyy'), 4, 1183, to_date('17-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050212011201, to_date('12-02-2005', 'dd-mm-yyyy'), to_date('26-02-2005', 'dd-mm-yyyy'), 6, 3475, to_date('27-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130118011202, to_date('18-01-2013', 'dd-mm-yyyy'), to_date('01-02-2013', 'dd-mm-yyyy'), 11, 11729, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050427011203, to_date('27-04-2005', 'dd-mm-yyyy'), to_date('11-05-2005', 'dd-mm-yyyy'), 5, 7018, to_date('14-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030920011204, to_date('20-09-2003', 'dd-mm-yyyy'), to_date('04-10-2003', 'dd-mm-yyyy'), 10, 4034, to_date('02-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007011205, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 6, 2945, to_date('09-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020829011206, to_date('29-08-2002', 'dd-mm-yyyy'), to_date('12-09-2002', 'dd-mm-yyyy'), 8, 2515, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130110011207, to_date('10-01-2013', 'dd-mm-yyyy'), to_date('24-01-2013', 'dd-mm-yyyy'), 10, 8258, to_date('17-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110209011208, to_date('09-02-2011', 'dd-mm-yyyy'), to_date('23-02-2011', 'dd-mm-yyyy'), 5, 8125, to_date('27-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040730011209, to_date('30-07-2004', 'dd-mm-yyyy'), to_date('13-08-2004', 'dd-mm-yyyy'), 8, 3918, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071119011210, to_date('19-11-2007', 'dd-mm-yyyy'), to_date('03-12-2007', 'dd-mm-yyyy'), 6, 6581, to_date('03-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110525011211, to_date('25-05-2011', 'dd-mm-yyyy'), to_date('08-06-2011', 'dd-mm-yyyy'), 5, 8705, to_date('13-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224011212, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 12, 8718, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140412011213, to_date('12-04-2014', 'dd-mm-yyyy'), to_date('26-04-2014', 'dd-mm-yyyy'), 12, 9890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030806011214, to_date('06-08-2003', 'dd-mm-yyyy'), to_date('20-08-2003', 'dd-mm-yyyy'), 9, 2837, to_date('24-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119011215, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 12, 8154, to_date('30-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000929011216, to_date('29-09-2000', 'dd-mm-yyyy'), to_date('13-10-2000', 'dd-mm-yyyy'), 7, 287, to_date('18-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130620011217, to_date('20-06-2013', 'dd-mm-yyyy'), to_date('04-07-2013', 'dd-mm-yyyy'), 4, 8514, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020601011218, to_date('01-06-2002', 'dd-mm-yyyy'), to_date('15-06-2002', 'dd-mm-yyyy'), 6, 3289, to_date('14-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130618011219, to_date('18-06-2013', 'dd-mm-yyyy'), to_date('02-07-2013', 'dd-mm-yyyy'), 2, 8564, to_date('21-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040905011220, to_date('05-09-2004', 'dd-mm-yyyy'), to_date('19-09-2004', 'dd-mm-yyyy'), 7, 4146, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013011221, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 4, 2367, to_date('23-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040930011222, to_date('30-09-2004', 'dd-mm-yyyy'), to_date('14-10-2004', 'dd-mm-yyyy'), 10, 6071, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120909011223, to_date('09-09-2012', 'dd-mm-yyyy'), to_date('23-09-2012', 'dd-mm-yyyy'), 8, 6970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111011224, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 10, 6283, to_date('14-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050715011225, to_date('15-07-2005', 'dd-mm-yyyy'), to_date('29-07-2005', 'dd-mm-yyyy'), 7, 3771, to_date('21-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010615011226, to_date('15-06-2001', 'dd-mm-yyyy'), to_date('29-06-2001', 'dd-mm-yyyy'), 4, 3699, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080509011227, to_date('09-05-2008', 'dd-mm-yyyy'), to_date('23-05-2008', 'dd-mm-yyyy'), 7, 7855, to_date('28-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090210011228, to_date('10-02-2009', 'dd-mm-yyyy'), to_date('24-02-2009', 'dd-mm-yyyy'), 4, 7011, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080122011229, to_date('22-01-2008', 'dd-mm-yyyy'), to_date('05-02-2008', 'dd-mm-yyyy'), 11, 4906, to_date('31-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020326011230, to_date('26-03-2002', 'dd-mm-yyyy'), to_date('09-04-2002', 'dd-mm-yyyy'), 6, 2431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020419011231, to_date('19-04-2002', 'dd-mm-yyyy'), to_date('03-05-2002', 'dd-mm-yyyy'), 10, 2900, to_date('08-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314011232, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 2, 7116, null);
commit;
prompt 13000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090125011233, to_date('25-01-2009', 'dd-mm-yyyy'), to_date('08-02-2009', 'dd-mm-yyyy'), 3, 6267, to_date('29-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080801011234, to_date('01-08-2008', 'dd-mm-yyyy'), to_date('15-08-2008', 'dd-mm-yyyy'), 2, 8065, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626011235, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 10, 6692, to_date('02-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101011236, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 9, 3453, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100910011237, to_date('10-09-2010', 'dd-mm-yyyy'), to_date('24-09-2010', 'dd-mm-yyyy'), 5, 8571, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609011238, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 4, 7087, to_date('21-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040223011239, to_date('23-02-2004', 'dd-mm-yyyy'), to_date('08-03-2004', 'dd-mm-yyyy'), 4, 3859, to_date('28-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519011240, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 8, 4652, to_date('03-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100125011241, to_date('25-01-2010', 'dd-mm-yyyy'), to_date('08-02-2010', 'dd-mm-yyyy'), 8, 7953, to_date('09-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071118011242, to_date('18-11-2007', 'dd-mm-yyyy'), to_date('02-12-2007', 'dd-mm-yyyy'), 3, 9115, to_date('24-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319011243, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 10, 5565, to_date('31-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100904011244, to_date('04-09-2010', 'dd-mm-yyyy'), to_date('18-09-2010', 'dd-mm-yyyy'), 7, 6609, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021125011245, to_date('25-11-2002', 'dd-mm-yyyy'), to_date('09-12-2002', 'dd-mm-yyyy'), 7, 2369, to_date('01-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050427011246, to_date('27-04-2005', 'dd-mm-yyyy'), to_date('11-05-2005', 'dd-mm-yyyy'), 11, 2548, to_date('16-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128011247, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 1, 4155, to_date('03-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040801011248, to_date('01-08-2004', 'dd-mm-yyyy'), to_date('15-08-2004', 'dd-mm-yyyy'), 7, 3332, to_date('10-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011105011249, to_date('05-11-2001', 'dd-mm-yyyy'), to_date('19-11-2001', 'dd-mm-yyyy'), 3, 1345, to_date('13-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011018011250, to_date('18-10-2001', 'dd-mm-yyyy'), to_date('01-11-2001', 'dd-mm-yyyy'), 7, 2676, to_date('31-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104011251, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 2, 7715, to_date('22-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820011252, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 10, 7234, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061021011253, to_date('21-10-2006', 'dd-mm-yyyy'), to_date('04-11-2006', 'dd-mm-yyyy'), 10, 5403, to_date('30-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215011254, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 1, 5354, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120903011255, to_date('03-09-2012', 'dd-mm-yyyy'), to_date('17-09-2012', 'dd-mm-yyyy'), 6, 9463, to_date('04-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130404011256, to_date('04-04-2013', 'dd-mm-yyyy'), to_date('18-04-2013', 'dd-mm-yyyy'), 5, 8504, to_date('16-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040915011257, to_date('15-09-2004', 'dd-mm-yyyy'), to_date('29-09-2004', 'dd-mm-yyyy'), 12, 740, to_date('04-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702011258, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 11, 2923, to_date('20-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227011259, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 9, 2736, to_date('13-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080218011260, to_date('18-02-2008', 'dd-mm-yyyy'), to_date('03-03-2008', 'dd-mm-yyyy'), 8, 5728, to_date('03-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070616011261, to_date('16-06-2007', 'dd-mm-yyyy'), to_date('30-06-2007', 'dd-mm-yyyy'), 11, 4256, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710011262, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 12, 2696, to_date('13-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030801011263, to_date('01-08-2003', 'dd-mm-yyyy'), to_date('15-08-2003', 'dd-mm-yyyy'), 4, 2722, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130924011264, to_date('24-09-2013', 'dd-mm-yyyy'), to_date('08-10-2013', 'dd-mm-yyyy'), 7, 8722, to_date('12-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010906011265, to_date('06-09-2001', 'dd-mm-yyyy'), to_date('20-09-2001', 'dd-mm-yyyy'), 8, 1845, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061102011266, to_date('02-11-2006', 'dd-mm-yyyy'), to_date('16-11-2006', 'dd-mm-yyyy'), 6, 5477, to_date('11-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010810011267, to_date('10-08-2001', 'dd-mm-yyyy'), to_date('24-08-2001', 'dd-mm-yyyy'), 5, 1422, to_date('15-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081013011268, to_date('13-10-2008', 'dd-mm-yyyy'), to_date('27-10-2008', 'dd-mm-yyyy'), 7, 3863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112011269, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 2, 6664, to_date('29-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010903011270, to_date('03-09-2001', 'dd-mm-yyyy'), to_date('17-09-2001', 'dd-mm-yyyy'), 11, 1821, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100816011271, to_date('16-08-2010', 'dd-mm-yyyy'), to_date('30-08-2010', 'dd-mm-yyyy'), 10, 10356, to_date('29-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323011272, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 11, 9304, to_date('03-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081118011273, to_date('18-11-2008', 'dd-mm-yyyy'), to_date('02-12-2008', 'dd-mm-yyyy'), 10, 9763, to_date('19-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030318011274, to_date('18-03-2003', 'dd-mm-yyyy'), to_date('01-04-2003', 'dd-mm-yyyy'), 8, 3463, to_date('06-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040802011275, to_date('02-08-2004', 'dd-mm-yyyy'), to_date('16-08-2004', 'dd-mm-yyyy'), 9, 5166, to_date('15-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140113011276, to_date('13-01-2014', 'dd-mm-yyyy'), to_date('27-01-2014', 'dd-mm-yyyy'), 2, 9437, to_date('19-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030515011277, to_date('15-05-2003', 'dd-mm-yyyy'), to_date('29-05-2003', 'dd-mm-yyyy'), 5, 3664, to_date('20-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090206011278, to_date('06-02-2009', 'dd-mm-yyyy'), to_date('20-02-2009', 'dd-mm-yyyy'), 2, 3976, to_date('21-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416011279, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 7, 5459, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060803011280, to_date('03-08-2006', 'dd-mm-yyyy'), to_date('17-08-2006', 'dd-mm-yyyy'), 3, 6485, to_date('07-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013011281, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 3, 5419, to_date('18-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630011282, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 5, 6829, to_date('19-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130716011283, to_date('16-07-2013', 'dd-mm-yyyy'), to_date('30-07-2013', 'dd-mm-yyyy'), 5, 8963, to_date('21-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071031011284, to_date('31-10-2007', 'dd-mm-yyyy'), to_date('14-11-2007', 'dd-mm-yyyy'), 3, 4580, to_date('15-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050723011285, to_date('23-07-2005', 'dd-mm-yyyy'), to_date('06-08-2005', 'dd-mm-yyyy'), 2, 2716, to_date('02-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121205011286, to_date('05-12-2012', 'dd-mm-yyyy'), to_date('19-12-2012', 'dd-mm-yyyy'), 6, 6591, to_date('24-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100205011287, to_date('05-02-2010', 'dd-mm-yyyy'), to_date('19-02-2010', 'dd-mm-yyyy'), 8, 5787, to_date('08-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020817011288, to_date('17-08-2002', 'dd-mm-yyyy'), to_date('31-08-2002', 'dd-mm-yyyy'), 5, 2463, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110609011289, to_date('09-06-2011', 'dd-mm-yyyy'), to_date('23-06-2011', 'dd-mm-yyyy'), 4, 8293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041119011290, to_date('19-11-2004', 'dd-mm-yyyy'), to_date('03-12-2004', 'dd-mm-yyyy'), 6, 3139, to_date('25-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630011291, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 3, 7605, to_date('11-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061006011292, to_date('06-10-2006', 'dd-mm-yyyy'), to_date('20-10-2006', 'dd-mm-yyyy'), 11, 6291, to_date('09-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130209011293, to_date('09-02-2013', 'dd-mm-yyyy'), to_date('23-02-2013', 'dd-mm-yyyy'), 1, 9177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070508011294, to_date('08-05-2007', 'dd-mm-yyyy'), to_date('22-05-2007', 'dd-mm-yyyy'), 11, 6123, to_date('12-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071128011295, to_date('28-11-2007', 'dd-mm-yyyy'), to_date('12-12-2007', 'dd-mm-yyyy'), 9, 4680, to_date('12-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010521011296, to_date('21-05-2001', 'dd-mm-yyyy'), to_date('04-06-2001', 'dd-mm-yyyy'), 12, 3058, to_date('24-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222011297, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 6, 3145, to_date('24-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513011298, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 8, 2860, to_date('19-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060428011299, to_date('28-04-2006', 'dd-mm-yyyy'), to_date('12-05-2006', 'dd-mm-yyyy'), 8, 6029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031022011300, to_date('22-10-2003', 'dd-mm-yyyy'), to_date('05-11-2003', 'dd-mm-yyyy'), 5, 2486, to_date('24-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120602011301, to_date('02-06-2012', 'dd-mm-yyyy'), to_date('16-06-2012', 'dd-mm-yyyy'), 3, 7048, to_date('06-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120522011302, to_date('22-05-2012', 'dd-mm-yyyy'), to_date('05-06-2012', 'dd-mm-yyyy'), 8, 9169, to_date('08-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302011303, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 6, 3497, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060423011304, to_date('23-04-2006', 'dd-mm-yyyy'), to_date('07-05-2006', 'dd-mm-yyyy'), 7, 3091, to_date('03-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040704011305, to_date('04-07-2004', 'dd-mm-yyyy'), to_date('18-07-2004', 'dd-mm-yyyy'), 12, 3720, to_date('21-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030331011306, to_date('31-03-2003', 'dd-mm-yyyy'), to_date('14-04-2003', 'dd-mm-yyyy'), 10, 2940, to_date('06-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080721011307, to_date('21-07-2008', 'dd-mm-yyyy'), to_date('04-08-2008', 'dd-mm-yyyy'), 11, 5097, to_date('27-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060301011308, to_date('01-03-2006', 'dd-mm-yyyy'), to_date('15-03-2006', 'dd-mm-yyyy'), 3, 8135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000528011309, to_date('28-05-2000', 'dd-mm-yyyy'), to_date('11-06-2000', 'dd-mm-yyyy'), 8, 1196, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000704011310, to_date('04-07-2000', 'dd-mm-yyyy'), to_date('18-07-2000', 'dd-mm-yyyy'), 9, 3033, to_date('09-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010208011311, to_date('08-02-2001', 'dd-mm-yyyy'), to_date('22-02-2001', 'dd-mm-yyyy'), 3, 1786, to_date('19-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121217011312, to_date('17-12-2012', 'dd-mm-yyyy'), to_date('31-12-2012', 'dd-mm-yyyy'), 10, 7603, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804011313, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 6, 10446, to_date('18-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050403011314, to_date('03-04-2005', 'dd-mm-yyyy'), to_date('17-04-2005', 'dd-mm-yyyy'), 4, 4441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121215011315, to_date('15-12-2012', 'dd-mm-yyyy'), to_date('29-12-2012', 'dd-mm-yyyy'), 9, 9219, to_date('20-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031129011316, to_date('29-11-2003', 'dd-mm-yyyy'), to_date('13-12-2003', 'dd-mm-yyyy'), 6, 2840, to_date('19-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319011317, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 6, 5839, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041103011318, to_date('03-11-2004', 'dd-mm-yyyy'), to_date('17-11-2004', 'dd-mm-yyyy'), 9, 2514, to_date('14-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031112011319, to_date('12-11-2003', 'dd-mm-yyyy'), to_date('26-11-2003', 'dd-mm-yyyy'), 3, 2930, to_date('15-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010716011320, to_date('16-07-2001', 'dd-mm-yyyy'), to_date('30-07-2001', 'dd-mm-yyyy'), 7, 2171, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060321011321, to_date('21-03-2006', 'dd-mm-yyyy'), to_date('04-04-2006', 'dd-mm-yyyy'), 1, 4234, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090321011322, to_date('21-03-2009', 'dd-mm-yyyy'), to_date('04-04-2009', 'dd-mm-yyyy'), 5, 6740, to_date('24-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026011323, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 2, 978, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106011324, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 3, 6383, to_date('17-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110710011325, to_date('10-07-2011', 'dd-mm-yyyy'), to_date('24-07-2011', 'dd-mm-yyyy'), 9, 5897, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061120011326, to_date('20-11-2006', 'dd-mm-yyyy'), to_date('04-12-2006', 'dd-mm-yyyy'), 1, 5176, to_date('24-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100419011327, to_date('19-04-2010', 'dd-mm-yyyy'), to_date('03-05-2010', 'dd-mm-yyyy'), 8, 5155, to_date('05-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120915011328, to_date('15-09-2012', 'dd-mm-yyyy'), to_date('29-09-2012', 'dd-mm-yyyy'), 1, 9701, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000115011329, to_date('15-01-2000', 'dd-mm-yyyy'), to_date('29-01-2000', 'dd-mm-yyyy'), 8, 1767, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140106011330, to_date('06-01-2014', 'dd-mm-yyyy'), to_date('20-01-2014', 'dd-mm-yyyy'), 2, 9216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131107011331, to_date('07-11-2013', 'dd-mm-yyyy'), to_date('21-11-2013', 'dd-mm-yyyy'), 10, 9008, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021110011332, to_date('10-11-2002', 'dd-mm-yyyy'), to_date('24-11-2002', 'dd-mm-yyyy'), 3, 2812, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000427011333, to_date('27-04-2000', 'dd-mm-yyyy'), to_date('11-05-2000', 'dd-mm-yyyy'), 10, 1045, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000130011334, to_date('30-01-2000', 'dd-mm-yyyy'), to_date('13-02-2000', 'dd-mm-yyyy'), 2, 909, to_date('07-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070526011335, to_date('26-05-2007', 'dd-mm-yyyy'), to_date('09-06-2007', 'dd-mm-yyyy'), 11, 5540, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015011336, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 9, 1152, to_date('28-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001214011337, to_date('14-12-2000', 'dd-mm-yyyy'), to_date('28-12-2000', 'dd-mm-yyyy'), 3, 2019, to_date('16-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060227011338, to_date('27-02-2006', 'dd-mm-yyyy'), to_date('13-03-2006', 'dd-mm-yyyy'), 4, 4975, to_date('04-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111006011339, to_date('06-10-2011', 'dd-mm-yyyy'), to_date('20-10-2011', 'dd-mm-yyyy'), 8, 8474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130130011340, to_date('30-01-2013', 'dd-mm-yyyy'), to_date('13-02-2013', 'dd-mm-yyyy'), 10, 8301, to_date('03-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060324011341, to_date('24-03-2006', 'dd-mm-yyyy'), to_date('07-04-2006', 'dd-mm-yyyy'), 5, 3148, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100916011342, to_date('16-09-2010', 'dd-mm-yyyy'), to_date('30-09-2010', 'dd-mm-yyyy'), 4, 8099, to_date('01-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203011343, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 7, 7171, to_date('23-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210011344, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 2, 10644, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809011345, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 3, 2125, to_date('11-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926011346, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 4, 2238, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040805011347, to_date('05-08-2004', 'dd-mm-yyyy'), to_date('19-08-2004', 'dd-mm-yyyy'), 7, 2432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821011348, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 2, 4381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040910014042, to_date('10-09-2004', 'dd-mm-yyyy'), to_date('24-09-2004', 'dd-mm-yyyy'), 3, 5972, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081003014043, to_date('03-10-2008', 'dd-mm-yyyy'), to_date('17-10-2008', 'dd-mm-yyyy'), 2, 8111, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070920014044, to_date('20-09-2007', 'dd-mm-yyyy'), to_date('04-10-2007', 'dd-mm-yyyy'), 3, 6024, to_date('04-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101126014045, to_date('26-11-2010', 'dd-mm-yyyy'), to_date('10-12-2010', 'dd-mm-yyyy'), 4, 5253, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060330014046, to_date('30-03-2006', 'dd-mm-yyyy'), to_date('13-04-2006', 'dd-mm-yyyy'), 1, 4518, to_date('08-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131220014047, to_date('20-12-2013', 'dd-mm-yyyy'), to_date('03-01-2014', 'dd-mm-yyyy'), 4, 8433, to_date('26-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090328014048, to_date('28-03-2009', 'dd-mm-yyyy'), to_date('11-04-2009', 'dd-mm-yyyy'), 2, 6017, to_date('01-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612014049, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 2, 1304, to_date('28-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231014050, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 2, 8236, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040721014051, to_date('21-07-2004', 'dd-mm-yyyy'), to_date('04-08-2004', 'dd-mm-yyyy'), 2, 2580, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081120014052, to_date('20-11-2008', 'dd-mm-yyyy'), to_date('04-12-2008', 'dd-mm-yyyy'), 3, 6324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080114014053, to_date('14-01-2008', 'dd-mm-yyyy'), to_date('28-01-2008', 'dd-mm-yyyy'), 1, 3665, to_date('30-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040927014054, to_date('27-09-2004', 'dd-mm-yyyy'), to_date('11-10-2004', 'dd-mm-yyyy'), 3, 5058, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070105014055, to_date('05-01-2007', 'dd-mm-yyyy'), to_date('19-01-2007', 'dd-mm-yyyy'), 1, 4798, to_date('09-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001113014056, to_date('13-11-2000', 'dd-mm-yyyy'), to_date('27-11-2000', 'dd-mm-yyyy'), 4, 1795, to_date('22-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115014057, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 2, 6081, to_date('26-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020308014058, to_date('08-03-2002', 'dd-mm-yyyy'), to_date('22-03-2002', 'dd-mm-yyyy'), 1, 2529, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060209014059, to_date('09-02-2006', 'dd-mm-yyyy'), to_date('23-02-2006', 'dd-mm-yyyy'), 3, 6172, to_date('01-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060701014060, to_date('01-07-2006', 'dd-mm-yyyy'), to_date('15-07-2006', 'dd-mm-yyyy'), 4, 7042, to_date('16-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901014061, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 1, 2534, to_date('03-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130401014062, to_date('01-04-2013', 'dd-mm-yyyy'), to_date('15-04-2013', 'dd-mm-yyyy'), 2, 12037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070306014063, to_date('06-03-2007', 'dd-mm-yyyy'), to_date('20-03-2007', 'dd-mm-yyyy'), 3, 6938, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915014064, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 3, 6292, to_date('23-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120419014065, to_date('19-04-2012', 'dd-mm-yyyy'), to_date('03-05-2012', 'dd-mm-yyyy'), 3, 9467, to_date('07-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000527014066, to_date('27-05-2000', 'dd-mm-yyyy'), to_date('10-06-2000', 'dd-mm-yyyy'), 2, 1070, to_date('09-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100306014067, to_date('06-03-2010', 'dd-mm-yyyy'), to_date('20-03-2010', 'dd-mm-yyyy'), 4, 6976, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091222014068, to_date('22-12-2009', 'dd-mm-yyyy'), to_date('05-01-2010', 'dd-mm-yyyy'), 3, 5848, to_date('26-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120304014069, to_date('04-03-2012', 'dd-mm-yyyy'), to_date('18-03-2012', 'dd-mm-yyyy'), 3, 8029, to_date('19-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020822014070, to_date('22-08-2002', 'dd-mm-yyyy'), to_date('05-09-2002', 'dd-mm-yyyy'), 2, 3405, to_date('31-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040624014071, to_date('24-06-2004', 'dd-mm-yyyy'), to_date('08-07-2004', 'dd-mm-yyyy'), 4, 4763, to_date('03-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109014072, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 1, 2290, to_date('21-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080806014073, to_date('06-08-2008', 'dd-mm-yyyy'), to_date('20-08-2008', 'dd-mm-yyyy'), 2, 7010, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081208014074, to_date('08-12-2008', 'dd-mm-yyyy'), to_date('22-12-2008', 'dd-mm-yyyy'), 3, 6448, to_date('23-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110217014075, to_date('17-02-2011', 'dd-mm-yyyy'), to_date('03-03-2011', 'dd-mm-yyyy'), 3, 4733, to_date('03-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130306014076, to_date('06-03-2013', 'dd-mm-yyyy'), to_date('20-03-2013', 'dd-mm-yyyy'), 3, 5842, to_date('23-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051029014077, to_date('29-10-2005', 'dd-mm-yyyy'), to_date('12-11-2005', 'dd-mm-yyyy'), 2, 3658, to_date('15-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628014078, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 2, 1932, to_date('14-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101022014079, to_date('22-10-2010', 'dd-mm-yyyy'), to_date('05-11-2010', 'dd-mm-yyyy'), 2, 6482, to_date('03-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120407014080, to_date('07-04-2012', 'dd-mm-yyyy'), to_date('21-04-2012', 'dd-mm-yyyy'), 4, 9728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110613014081, to_date('13-06-2011', 'dd-mm-yyyy'), to_date('27-06-2011', 'dd-mm-yyyy'), 3, 6731, to_date('29-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121014014082, to_date('14-10-2012', 'dd-mm-yyyy'), to_date('28-10-2012', 'dd-mm-yyyy'), 3, 8800, to_date('24-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041113014083, to_date('13-11-2004', 'dd-mm-yyyy'), to_date('27-11-2004', 'dd-mm-yyyy'), 2, 4912, to_date('29-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703014084, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 4, 5103, to_date('22-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110219014085, to_date('19-02-2011', 'dd-mm-yyyy'), to_date('05-03-2011', 'dd-mm-yyyy'), 2, 8738, to_date('25-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110414014086, to_date('14-04-2011', 'dd-mm-yyyy'), to_date('28-04-2011', 'dd-mm-yyyy'), 3, 7593, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409014087, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 2, 7698, to_date('26-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000530014088, to_date('30-05-2000', 'dd-mm-yyyy'), to_date('13-06-2000', 'dd-mm-yyyy'), 3, 1032, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120227014089, to_date('27-02-2012', 'dd-mm-yyyy'), to_date('12-03-2012', 'dd-mm-yyyy'), 2, 9088, to_date('02-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070918014090, to_date('18-09-2007', 'dd-mm-yyyy'), to_date('02-10-2007', 'dd-mm-yyyy'), 4, 6569, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040214014091, to_date('14-02-2004', 'dd-mm-yyyy'), to_date('28-02-2004', 'dd-mm-yyyy'), 1, 4105, to_date('20-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100211014092, to_date('11-02-2010', 'dd-mm-yyyy'), to_date('25-02-2010', 'dd-mm-yyyy'), 1, 6553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021013014093, to_date('13-10-2002', 'dd-mm-yyyy'), to_date('27-10-2002', 'dd-mm-yyyy'), 4, 2174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100210014094, to_date('10-02-2010', 'dd-mm-yyyy'), to_date('24-02-2010', 'dd-mm-yyyy'), 2, 6850, to_date('13-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060216014095, to_date('16-02-2006', 'dd-mm-yyyy'), to_date('02-03-2006', 'dd-mm-yyyy'), 2, 3522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010608014096, to_date('08-06-2001', 'dd-mm-yyyy'), to_date('22-06-2001', 'dd-mm-yyyy'), 2, 2556, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131226014097, to_date('26-12-2013', 'dd-mm-yyyy'), to_date('09-01-2014', 'dd-mm-yyyy'), 2, 10155, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802014098, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 3, 8812, to_date('15-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000411014099, to_date('11-04-2000', 'dd-mm-yyyy'), to_date('25-04-2000', 'dd-mm-yyyy'), 2, 2640, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130328014100, to_date('28-03-2013', 'dd-mm-yyyy'), to_date('11-04-2013', 'dd-mm-yyyy'), 2, 8869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000208014101, to_date('08-02-2000', 'dd-mm-yyyy'), to_date('22-02-2000', 'dd-mm-yyyy'), 2, 2305, to_date('12-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050120014102, to_date('20-01-2005', 'dd-mm-yyyy'), to_date('03-02-2005', 'dd-mm-yyyy'), 3, 3892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130130014103, to_date('30-01-2013', 'dd-mm-yyyy'), to_date('13-02-2013', 'dd-mm-yyyy'), 2, 9447, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010416014104, to_date('16-04-2001', 'dd-mm-yyyy'), to_date('30-04-2001', 'dd-mm-yyyy'), 2, 3120, to_date('19-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041018014105, to_date('18-10-2004', 'dd-mm-yyyy'), to_date('01-11-2004', 'dd-mm-yyyy'), 4, 4862, to_date('03-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224014106, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 4, 9802, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030528014107, to_date('28-05-2003', 'dd-mm-yyyy'), to_date('11-06-2003', 'dd-mm-yyyy'), 3, 2687, to_date('15-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000605014108, to_date('05-06-2000', 'dd-mm-yyyy'), to_date('19-06-2000', 'dd-mm-yyyy'), 3, 1547, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318014109, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 3, 3577, to_date('01-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060109014110, to_date('09-01-2006', 'dd-mm-yyyy'), to_date('23-01-2006', 'dd-mm-yyyy'), 3, 3987, to_date('15-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050410014111, to_date('10-04-2005', 'dd-mm-yyyy'), to_date('24-04-2005', 'dd-mm-yyyy'), 3, 3880, to_date('26-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020106014112, to_date('06-01-2002', 'dd-mm-yyyy'), to_date('20-01-2002', 'dd-mm-yyyy'), 3, 3166, to_date('20-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100424014113, to_date('24-04-2010', 'dd-mm-yyyy'), to_date('08-05-2010', 'dd-mm-yyyy'), 1, 10820, to_date('02-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204014114, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 3, 2954, to_date('19-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020415014115, to_date('15-04-2002', 'dd-mm-yyyy'), to_date('29-04-2002', 'dd-mm-yyyy'), 2, 2424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090411014116, to_date('11-04-2009', 'dd-mm-yyyy'), to_date('25-04-2009', 'dd-mm-yyyy'), 1, 6625, to_date('19-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130408014117, to_date('08-04-2013', 'dd-mm-yyyy'), to_date('22-04-2013', 'dd-mm-yyyy'), 2, 10995, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090605014118, to_date('05-06-2009', 'dd-mm-yyyy'), to_date('19-06-2009', 'dd-mm-yyyy'), 3, 8308, to_date('14-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111014119, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 2, 6367, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216014120, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 4, 4800, to_date('24-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140407014121, to_date('07-04-2014', 'dd-mm-yyyy'), to_date('21-04-2014', 'dd-mm-yyyy'), 3, 6939, to_date('27-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903014122, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 1, 6941, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031014123, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 3, 1372, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050210014124, to_date('10-02-2005', 'dd-mm-yyyy'), to_date('24-02-2005', 'dd-mm-yyyy'), 3, 5104, to_date('20-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081025014125, to_date('25-10-2008', 'dd-mm-yyyy'), to_date('08-11-2008', 'dd-mm-yyyy'), 3, 5237, to_date('01-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041218014126, to_date('18-12-2004', 'dd-mm-yyyy'), to_date('01-01-2005', 'dd-mm-yyyy'), 3, 3270, to_date('31-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080831014127, to_date('31-08-2008', 'dd-mm-yyyy'), to_date('14-09-2008', 'dd-mm-yyyy'), 4, 7187, to_date('11-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131231014128, to_date('31-12-2013', 'dd-mm-yyyy'), to_date('14-01-2014', 'dd-mm-yyyy'), 4, 9769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080923014129, to_date('23-09-2008', 'dd-mm-yyyy'), to_date('07-10-2008', 'dd-mm-yyyy'), 1, 5372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013014130, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 1, 2423, to_date('15-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131018014131, to_date('18-10-2013', 'dd-mm-yyyy'), to_date('01-11-2013', 'dd-mm-yyyy'), 2, 8106, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206014132, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 2, 5853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100619014133, to_date('19-06-2010', 'dd-mm-yyyy'), to_date('03-07-2010', 'dd-mm-yyyy'), 3, 7238, to_date('09-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712014134, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 3, 5526, to_date('25-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108014135, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 2, 2425, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041230014136, to_date('30-12-2004', 'dd-mm-yyyy'), to_date('13-01-2005', 'dd-mm-yyyy'), 4, 5908, to_date('17-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501014137, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 3, 4859, to_date('11-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011211014138, to_date('11-12-2001', 'dd-mm-yyyy'), to_date('25-12-2001', 'dd-mm-yyyy'), 4, 2127, to_date('31-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130617014139, to_date('17-06-2013', 'dd-mm-yyyy'), to_date('01-07-2013', 'dd-mm-yyyy'), 4, 8754, to_date('19-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116014140, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 3, 7763, to_date('22-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071026014141, to_date('26-10-2007', 'dd-mm-yyyy'), to_date('09-11-2007', 'dd-mm-yyyy'), 2, 4657, to_date('12-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121206014142, to_date('06-12-2012', 'dd-mm-yyyy'), to_date('20-12-2012', 'dd-mm-yyyy'), 1, 6999, to_date('24-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110711014143, to_date('11-07-2011', 'dd-mm-yyyy'), to_date('25-07-2011', 'dd-mm-yyyy'), 3, 10585, to_date('28-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907014144, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 4, 4909, to_date('10-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080209014145, to_date('09-02-2008', 'dd-mm-yyyy'), to_date('23-02-2008', 'dd-mm-yyyy'), 4, 4628, to_date('11-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120310014146, to_date('10-03-2012', 'dd-mm-yyyy'), to_date('24-03-2012', 'dd-mm-yyyy'), 2, 8509, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050930014147, to_date('30-09-2005', 'dd-mm-yyyy'), to_date('14-10-2005', 'dd-mm-yyyy'), 3, 3461, to_date('15-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020319014148, to_date('19-03-2002', 'dd-mm-yyyy'), to_date('02-04-2002', 'dd-mm-yyyy'), 2, 2223, to_date('04-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605014149, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 4, 3594, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627014150, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 3, 3626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061127014151, to_date('27-11-2006', 'dd-mm-yyyy'), to_date('11-12-2006', 'dd-mm-yyyy'), 3, 5712, to_date('14-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060616014152, to_date('16-06-2006', 'dd-mm-yyyy'), to_date('30-06-2006', 'dd-mm-yyyy'), 3, 6655, to_date('30-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110924014153, to_date('24-09-2011', 'dd-mm-yyyy'), to_date('08-10-2011', 'dd-mm-yyyy'), 2, 6836, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070608014154, to_date('08-06-2007', 'dd-mm-yyyy'), to_date('22-06-2007', 'dd-mm-yyyy'), 3, 3729, to_date('15-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010911014155, to_date('11-09-2001', 'dd-mm-yyyy'), to_date('25-09-2001', 'dd-mm-yyyy'), 3, 2584, to_date('14-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000323014156, to_date('23-03-2000', 'dd-mm-yyyy'), to_date('06-04-2000', 'dd-mm-yyyy'), 3, 2857, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121104014157, to_date('04-11-2012', 'dd-mm-yyyy'), to_date('18-11-2012', 'dd-mm-yyyy'), 3, 6704, to_date('15-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817014158, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 3, 3924, to_date('26-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130207014159, to_date('07-02-2013', 'dd-mm-yyyy'), to_date('21-02-2013', 'dd-mm-yyyy'), 3, 9219, to_date('12-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121129014160, to_date('29-11-2012', 'dd-mm-yyyy'), to_date('13-12-2012', 'dd-mm-yyyy'), 3, 7177, to_date('18-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061115014161, to_date('15-11-2006', 'dd-mm-yyyy'), to_date('29-11-2006', 'dd-mm-yyyy'), 2, 4089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130122014162, to_date('22-01-2013', 'dd-mm-yyyy'), to_date('05-02-2013', 'dd-mm-yyyy'), 2, 9755, to_date('04-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010927014163, to_date('27-09-2001', 'dd-mm-yyyy'), to_date('11-10-2001', 'dd-mm-yyyy'), 4, 2436, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000610014164, to_date('10-06-2000', 'dd-mm-yyyy'), to_date('24-06-2000', 'dd-mm-yyyy'), 4, 1296, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100707014165, to_date('07-07-2010', 'dd-mm-yyyy'), to_date('21-07-2010', 'dd-mm-yyyy'), 2, 7506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041206014166, to_date('06-12-2004', 'dd-mm-yyyy'), to_date('20-12-2004', 'dd-mm-yyyy'), 1, 4114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070828014167, to_date('28-08-2007', 'dd-mm-yyyy'), to_date('11-09-2007', 'dd-mm-yyyy'), 2, 4476, to_date('31-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090321014168, to_date('21-03-2009', 'dd-mm-yyyy'), to_date('04-04-2009', 'dd-mm-yyyy'), 3, 6621, to_date('06-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100629014169, to_date('29-06-2010', 'dd-mm-yyyy'), to_date('13-07-2010', 'dd-mm-yyyy'), 4, 7285, to_date('30-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130728014170, to_date('28-07-2013', 'dd-mm-yyyy'), to_date('11-08-2013', 'dd-mm-yyyy'), 3, 9301, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229014171, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 4, 6788, to_date('08-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130630014172, to_date('30-06-2013', 'dd-mm-yyyy'), to_date('14-07-2013', 'dd-mm-yyyy'), 1, 8130, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218014173, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 2, 4134, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040312014174, to_date('12-03-2004', 'dd-mm-yyyy'), to_date('26-03-2004', 'dd-mm-yyyy'), 2, 3929, to_date('15-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090804014175, to_date('04-08-2009', 'dd-mm-yyyy'), to_date('18-08-2009', 'dd-mm-yyyy'), 1, 6610, to_date('05-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000618014176, to_date('18-06-2000', 'dd-mm-yyyy'), to_date('02-07-2000', 'dd-mm-yyyy'), 1, 1112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021104014177, to_date('04-11-2002', 'dd-mm-yyyy'), to_date('18-11-2002', 'dd-mm-yyyy'), 1, 4637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214014178, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 3, 9043, to_date('29-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202014179, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 3, 4314, to_date('17-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726014180, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 3, 2336, to_date('11-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041026014181, to_date('26-10-2004', 'dd-mm-yyyy'), to_date('09-11-2004', 'dd-mm-yyyy'), 3, 2850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090627014182, to_date('27-06-2009', 'dd-mm-yyyy'), to_date('11-07-2009', 'dd-mm-yyyy'), 3, 6015, to_date('14-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041210014183, to_date('10-12-2004', 'dd-mm-yyyy'), to_date('24-12-2004', 'dd-mm-yyyy'), 3, 3041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030317014184, to_date('17-03-2003', 'dd-mm-yyyy'), to_date('31-03-2003', 'dd-mm-yyyy'), 1, 3185, to_date('30-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130223014185, to_date('23-02-2013', 'dd-mm-yyyy'), to_date('09-03-2013', 'dd-mm-yyyy'), 2, 12411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080925014186, to_date('25-09-2008', 'dd-mm-yyyy'), to_date('09-10-2008', 'dd-mm-yyyy'), 3, 6652, to_date('10-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529014187, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 2, 6709, to_date('13-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000728014188, to_date('28-07-2000', 'dd-mm-yyyy'), to_date('11-08-2000', 'dd-mm-yyyy'), 3, 2549, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030410014189, to_date('10-04-2003', 'dd-mm-yyyy'), to_date('24-04-2003', 'dd-mm-yyyy'), 2, 3720, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050323014190, to_date('23-03-2005', 'dd-mm-yyyy'), to_date('06-04-2005', 'dd-mm-yyyy'), 3, 2674, to_date('24-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821014191, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 2, 7417, to_date('04-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100307014192, to_date('07-03-2010', 'dd-mm-yyyy'), to_date('21-03-2010', 'dd-mm-yyyy'), 2, 5783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140428014193, to_date('28-04-2014', 'dd-mm-yyyy'), to_date('12-05-2014', 'dd-mm-yyyy'), 2, 7831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120228014194, to_date('28-02-2012', 'dd-mm-yyyy'), to_date('13-03-2012', 'dd-mm-yyyy'), 3, 7716, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020828014195, to_date('28-08-2002', 'dd-mm-yyyy'), to_date('11-09-2002', 'dd-mm-yyyy'), 3, 4016, to_date('08-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111004014196, to_date('04-10-2011', 'dd-mm-yyyy'), to_date('18-10-2011', 'dd-mm-yyyy'), 2, 7033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080111014197, to_date('11-01-2008', 'dd-mm-yyyy'), to_date('25-01-2008', 'dd-mm-yyyy'), 2, 7164, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020925014198, to_date('25-09-2002', 'dd-mm-yyyy'), to_date('09-10-2002', 'dd-mm-yyyy'), 2, 4127, to_date('29-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130329014199, to_date('29-03-2013', 'dd-mm-yyyy'), to_date('12-04-2013', 'dd-mm-yyyy'), 4, 9364, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021014200, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 2, 4082, to_date('30-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071224014201, to_date('24-12-2007', 'dd-mm-yyyy'), to_date('07-01-2008', 'dd-mm-yyyy'), 4, 3840, to_date('07-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000707014202, to_date('07-07-2000', 'dd-mm-yyyy'), to_date('21-07-2000', 'dd-mm-yyyy'), 4, 1556, to_date('18-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090108014203, to_date('08-01-2009', 'dd-mm-yyyy'), to_date('22-01-2009', 'dd-mm-yyyy'), 3, 4924, to_date('27-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101014204, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 4, 5339, to_date('04-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040724014205, to_date('24-07-2004', 'dd-mm-yyyy'), to_date('07-08-2004', 'dd-mm-yyyy'), 1, 2711, to_date('06-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031128014206, to_date('28-11-2003', 'dd-mm-yyyy'), to_date('12-12-2003', 'dd-mm-yyyy'), 3, 3372, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612014207, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 3, 1612, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021022014208, to_date('22-10-2002', 'dd-mm-yyyy'), to_date('05-11-2002', 'dd-mm-yyyy'), 2, 2801, to_date('01-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020624014209, to_date('24-06-2002', 'dd-mm-yyyy'), to_date('08-07-2002', 'dd-mm-yyyy'), 2, 2705, to_date('14-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090924014210, to_date('24-09-2009', 'dd-mm-yyyy'), to_date('08-10-2009', 'dd-mm-yyyy'), 3, 8458, to_date('11-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425016737, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 1, 4689, to_date('02-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060312016738, to_date('12-03-2006', 'dd-mm-yyyy'), to_date('26-03-2006', 'dd-mm-yyyy'), 2, 4846, to_date('30-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000927016739, to_date('27-09-2000', 'dd-mm-yyyy'), to_date('11-10-2000', 'dd-mm-yyyy'), 2, 2259, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507016740, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 2, 2748, to_date('10-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020507016741, to_date('07-05-2002', 'dd-mm-yyyy'), to_date('21-05-2002', 'dd-mm-yyyy'), 2, 2974, to_date('22-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000711016742, to_date('11-07-2000', 'dd-mm-yyyy'), to_date('25-07-2000', 'dd-mm-yyyy'), 2, 1357, to_date('14-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050211016743, to_date('11-02-2005', 'dd-mm-yyyy'), to_date('25-02-2005', 'dd-mm-yyyy'), 2, 4632, to_date('24-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070907016744, to_date('07-09-2007', 'dd-mm-yyyy'), to_date('21-09-2007', 'dd-mm-yyyy'), 1, 8598, to_date('19-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101031016745, to_date('31-10-2010', 'dd-mm-yyyy'), to_date('14-11-2010', 'dd-mm-yyyy'), 2, 7343, to_date('15-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010904016746, to_date('04-09-2001', 'dd-mm-yyyy'), to_date('18-09-2001', 'dd-mm-yyyy'), 2, 1677, to_date('22-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000614016747, to_date('14-06-2000', 'dd-mm-yyyy'), to_date('28-06-2000', 'dd-mm-yyyy'), 1, 1096, to_date('23-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227016748, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 1, 4964, to_date('04-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091015016749, to_date('15-10-2009', 'dd-mm-yyyy'), to_date('29-10-2009', 'dd-mm-yyyy'), 2, 5667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090527016750, to_date('27-05-2009', 'dd-mm-yyyy'), to_date('10-06-2009', 'dd-mm-yyyy'), 2, 7529, to_date('12-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081023016751, to_date('23-10-2008', 'dd-mm-yyyy'), to_date('06-11-2008', 'dd-mm-yyyy'), 2, 6102, to_date('09-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020126016752, to_date('26-01-2002', 'dd-mm-yyyy'), to_date('09-02-2002', 'dd-mm-yyyy'), 2, 2793, to_date('07-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060128016753, to_date('28-01-2006', 'dd-mm-yyyy'), to_date('11-02-2006', 'dd-mm-yyyy'), 2, 5224, to_date('05-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030813016754, to_date('13-08-2003', 'dd-mm-yyyy'), to_date('27-08-2003', 'dd-mm-yyyy'), 1, 3493, to_date('26-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030205016755, to_date('05-02-2003', 'dd-mm-yyyy'), to_date('19-02-2003', 'dd-mm-yyyy'), 1, 4223, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130016756, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 2, 1509, to_date('18-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003016757, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 2, 2219, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100705016758, to_date('05-07-2010', 'dd-mm-yyyy'), to_date('19-07-2010', 'dd-mm-yyyy'), 1, 8694, to_date('14-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121124016759, to_date('24-11-2012', 'dd-mm-yyyy'), to_date('08-12-2012', 'dd-mm-yyyy'), 2, 7050, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051018016760, to_date('18-10-2005', 'dd-mm-yyyy'), to_date('01-11-2005', 'dd-mm-yyyy'), 1, 3621, to_date('31-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020216016761, to_date('16-02-2002', 'dd-mm-yyyy'), to_date('02-03-2002', 'dd-mm-yyyy'), 2, 1355, to_date('23-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301016762, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 2, 2282, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060915016763, to_date('15-09-2006', 'dd-mm-yyyy'), to_date('29-09-2006', 'dd-mm-yyyy'), 2, 4217, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040721016764, to_date('21-07-2004', 'dd-mm-yyyy'), to_date('04-08-2004', 'dd-mm-yyyy'), 1, 3456, to_date('03-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041107016765, to_date('07-11-2004', 'dd-mm-yyyy'), to_date('21-11-2004', 'dd-mm-yyyy'), 2, 5950, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030804016766, to_date('04-08-2003', 'dd-mm-yyyy'), to_date('18-08-2003', 'dd-mm-yyyy'), 2, 2815, to_date('09-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714016767, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 2, 7384, to_date('21-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030321016768, to_date('21-03-2003', 'dd-mm-yyyy'), to_date('04-04-2003', 'dd-mm-yyyy'), 1, 4208, to_date('31-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120513016769, to_date('13-05-2012', 'dd-mm-yyyy'), to_date('27-05-2012', 'dd-mm-yyyy'), 1, 5563, to_date('16-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214016770, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 2, 2817, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007016771, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 1, 4955, to_date('17-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111215016772, to_date('15-12-2011', 'dd-mm-yyyy'), to_date('29-12-2011', 'dd-mm-yyyy'), 1, 8656, to_date('28-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070425016773, to_date('25-04-2007', 'dd-mm-yyyy'), to_date('09-05-2007', 'dd-mm-yyyy'), 2, 2910, to_date('09-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100324016774, to_date('24-03-2010', 'dd-mm-yyyy'), to_date('07-04-2010', 'dd-mm-yyyy'), 2, 7352, to_date('10-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030625016775, to_date('25-06-2003', 'dd-mm-yyyy'), to_date('09-07-2003', 'dd-mm-yyyy'), 1, 1901, to_date('04-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051106016776, to_date('06-11-2005', 'dd-mm-yyyy'), to_date('20-11-2005', 'dd-mm-yyyy'), 2, 8432, to_date('13-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110713016777, to_date('13-07-2011', 'dd-mm-yyyy'), to_date('27-07-2011', 'dd-mm-yyyy'), 1, 8998, to_date('14-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020016778, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 2, 5880, to_date('25-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091006016779, to_date('06-10-2009', 'dd-mm-yyyy'), to_date('20-10-2009', 'dd-mm-yyyy'), 1, 5125, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090125016780, to_date('25-01-2009', 'dd-mm-yyyy'), to_date('08-02-2009', 'dd-mm-yyyy'), 2, 8875, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011005016781, to_date('05-10-2001', 'dd-mm-yyyy'), to_date('19-10-2001', 'dd-mm-yyyy'), 1, 4398, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051124016782, to_date('24-11-2005', 'dd-mm-yyyy'), to_date('08-12-2005', 'dd-mm-yyyy'), 1, 5155, to_date('05-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050429016783, to_date('29-04-2005', 'dd-mm-yyyy'), to_date('13-05-2005', 'dd-mm-yyyy'), 2, 5007, to_date('02-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000926016784, to_date('26-09-2000', 'dd-mm-yyyy'), to_date('10-10-2000', 'dd-mm-yyyy'), 1, 2799, to_date('06-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917016785, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 2, 7742, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121205016786, to_date('05-12-2012', 'dd-mm-yyyy'), to_date('19-12-2012', 'dd-mm-yyyy'), 2, 6573, to_date('12-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040402016787, to_date('02-04-2004', 'dd-mm-yyyy'), to_date('16-04-2004', 'dd-mm-yyyy'), 2, 4021, to_date('07-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100110016788, to_date('10-01-2010', 'dd-mm-yyyy'), to_date('24-01-2010', 'dd-mm-yyyy'), 2, 8939, to_date('24-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051015016789, to_date('15-10-2005', 'dd-mm-yyyy'), to_date('29-10-2005', 'dd-mm-yyyy'), 2, 3219, to_date('20-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040819016790, to_date('19-08-2004', 'dd-mm-yyyy'), to_date('02-09-2004', 'dd-mm-yyyy'), 1, 5233, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020613016791, to_date('13-06-2002', 'dd-mm-yyyy'), to_date('27-06-2002', 'dd-mm-yyyy'), 2, 1412, to_date('26-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120824016792, to_date('24-08-2012', 'dd-mm-yyyy'), to_date('07-09-2012', 'dd-mm-yyyy'), 1, 7362, to_date('12-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130819016793, to_date('19-08-2013', 'dd-mm-yyyy'), to_date('02-09-2013', 'dd-mm-yyyy'), 1, 7953, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110808016794, to_date('08-08-2011', 'dd-mm-yyyy'), to_date('22-08-2011', 'dd-mm-yyyy'), 2, 6924, to_date('26-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020731016795, to_date('31-07-2002', 'dd-mm-yyyy'), to_date('14-08-2002', 'dd-mm-yyyy'), 2, 2420, to_date('19-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100111016796, to_date('11-01-2010', 'dd-mm-yyyy'), to_date('25-01-2010', 'dd-mm-yyyy'), 1, 9614, to_date('28-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002016797, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 1, 2721, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010111016798, to_date('11-01-2001', 'dd-mm-yyyy'), to_date('25-01-2001', 'dd-mm-yyyy'), 1, 1867, to_date('28-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101012016799, to_date('12-10-2010', 'dd-mm-yyyy'), to_date('26-10-2010', 'dd-mm-yyyy'), 2, 6889, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140502016800, to_date('02-05-2014', 'dd-mm-yyyy'), to_date('16-05-2014', 'dd-mm-yyyy'), 1, 7639, to_date('18-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711016801, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 2, 9613, to_date('19-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020928016802, to_date('28-09-2002', 'dd-mm-yyyy'), to_date('12-10-2002', 'dd-mm-yyyy'), 2, 4066, to_date('16-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000106016803, to_date('06-01-2000', 'dd-mm-yyyy'), to_date('20-01-2000', 'dd-mm-yyyy'), 1, 1221, to_date('15-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020118016804, to_date('18-01-2002', 'dd-mm-yyyy'), to_date('01-02-2002', 'dd-mm-yyyy'), 1, 1649, to_date('29-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040320016805, to_date('20-03-2004', 'dd-mm-yyyy'), to_date('03-04-2004', 'dd-mm-yyyy'), 2, 5695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040702016806, to_date('02-07-2004', 'dd-mm-yyyy'), to_date('16-07-2004', 'dd-mm-yyyy'), 1, 4837, to_date('22-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321016807, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 2, 8985, to_date('09-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001204016808, to_date('04-12-2000', 'dd-mm-yyyy'), to_date('18-12-2000', 'dd-mm-yyyy'), 1, 1531, to_date('10-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080809016809, to_date('09-08-2008', 'dd-mm-yyyy'), to_date('23-08-2008', 'dd-mm-yyyy'), 1, 6433, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020131016810, to_date('31-01-2002', 'dd-mm-yyyy'), to_date('14-02-2002', 'dd-mm-yyyy'), 1, 1656, to_date('03-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081109016811, to_date('09-11-2008', 'dd-mm-yyyy'), to_date('23-11-2008', 'dd-mm-yyyy'), 2, 6497, to_date('18-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030909016812, to_date('09-09-2003', 'dd-mm-yyyy'), to_date('23-09-2003', 'dd-mm-yyyy'), 2, 3547, to_date('20-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040503016813, to_date('03-05-2004', 'dd-mm-yyyy'), to_date('17-05-2004', 'dd-mm-yyyy'), 1, 3414, to_date('14-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040610016814, to_date('10-06-2004', 'dd-mm-yyyy'), to_date('24-06-2004', 'dd-mm-yyyy'), 1, 3135, to_date('24-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051121016815, to_date('21-11-2005', 'dd-mm-yyyy'), to_date('05-12-2005', 'dd-mm-yyyy'), 2, 3138, to_date('07-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020602016816, to_date('02-06-2002', 'dd-mm-yyyy'), to_date('16-06-2002', 'dd-mm-yyyy'), 2, 2844, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010412016817, to_date('12-04-2001', 'dd-mm-yyyy'), to_date('26-04-2001', 'dd-mm-yyyy'), 1, 750, to_date('27-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031117016818, to_date('17-11-2003', 'dd-mm-yyyy'), to_date('01-12-2003', 'dd-mm-yyyy'), 1, 4061, to_date('24-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607016819, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 1, 8979, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000220016820, to_date('20-02-2000', 'dd-mm-yyyy'), to_date('05-03-2000', 'dd-mm-yyyy'), 2, 2327, to_date('08-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140419016821, to_date('19-04-2014', 'dd-mm-yyyy'), to_date('03-05-2014', 'dd-mm-yyyy'), 1, 8377, to_date('29-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041014016822, to_date('14-10-2004', 'dd-mm-yyyy'), to_date('28-10-2004', 'dd-mm-yyyy'), 1, 4249, to_date('24-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000104016823, to_date('04-01-2000', 'dd-mm-yyyy'), to_date('18-01-2000', 'dd-mm-yyyy'), 1, 1714, to_date('12-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921016824, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 2, 7565, to_date('25-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000628016825, to_date('28-06-2000', 'dd-mm-yyyy'), to_date('12-07-2000', 'dd-mm-yyyy'), 1, 1357, to_date('04-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020306016826, to_date('06-03-2002', 'dd-mm-yyyy'), to_date('20-03-2002', 'dd-mm-yyyy'), 1, 2186, to_date('19-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080925016827, to_date('25-09-2008', 'dd-mm-yyyy'), to_date('09-10-2008', 'dd-mm-yyyy'), 2, 6442, to_date('28-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030720016828, to_date('20-07-2003', 'dd-mm-yyyy'), to_date('03-08-2003', 'dd-mm-yyyy'), 2, 4190, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000805016829, to_date('05-08-2000', 'dd-mm-yyyy'), to_date('19-08-2000', 'dd-mm-yyyy'), 2, 3880, to_date('19-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110016830, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 2, 7113, to_date('30-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041010016831, to_date('10-10-2004', 'dd-mm-yyyy'), to_date('24-10-2004', 'dd-mm-yyyy'), 2, 4247, to_date('22-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130420016832, to_date('20-04-2013', 'dd-mm-yyyy'), to_date('04-05-2013', 'dd-mm-yyyy'), 1, 10734, to_date('08-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040831016833, to_date('31-08-2004', 'dd-mm-yyyy'), to_date('14-09-2004', 'dd-mm-yyyy'), 2, 4139, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825016834, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 1, 808, to_date('10-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101104016835, to_date('04-11-2010', 'dd-mm-yyyy'), to_date('18-11-2010', 'dd-mm-yyyy'), 2, 8681, to_date('23-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061005016836, to_date('05-10-2006', 'dd-mm-yyyy'), to_date('19-10-2006', 'dd-mm-yyyy'), 2, 3196, to_date('06-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000220016837, to_date('20-02-2000', 'dd-mm-yyyy'), to_date('05-03-2000', 'dd-mm-yyyy'), 2, 969, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131016838, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 2, 5668, to_date('12-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051214016839, to_date('14-12-2005', 'dd-mm-yyyy'), to_date('28-12-2005', 'dd-mm-yyyy'), 2, 3720, to_date('28-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071027016840, to_date('27-10-2007', 'dd-mm-yyyy'), to_date('10-11-2007', 'dd-mm-yyyy'), 1, 9571, to_date('15-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100520016841, to_date('20-05-2010', 'dd-mm-yyyy'), to_date('03-06-2010', 'dd-mm-yyyy'), 1, 6265, to_date('02-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131224016842, to_date('24-12-2013', 'dd-mm-yyyy'), to_date('07-01-2014', 'dd-mm-yyyy'), 2, 7599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050101016843, to_date('01-01-2005', 'dd-mm-yyyy'), to_date('15-01-2005', 'dd-mm-yyyy'), 1, 4236, to_date('06-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120110016844, to_date('10-01-2012', 'dd-mm-yyyy'), to_date('24-01-2012', 'dd-mm-yyyy'), 1, 9617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111213016845, to_date('13-12-2011', 'dd-mm-yyyy'), to_date('27-12-2011', 'dd-mm-yyyy'), 1, 7809, to_date('15-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060921016846, to_date('21-09-2006', 'dd-mm-yyyy'), to_date('05-10-2006', 'dd-mm-yyyy'), 1, 4603, to_date('01-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906016847, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 2, 4649, to_date('12-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004016848, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 2, 4055, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722016849, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 2, 2710, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020523016850, to_date('23-05-2002', 'dd-mm-yyyy'), to_date('06-06-2002', 'dd-mm-yyyy'), 1, 3222, to_date('12-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101129016851, to_date('29-11-2010', 'dd-mm-yyyy'), to_date('13-12-2010', 'dd-mm-yyyy'), 2, 6226, to_date('05-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030220016852, to_date('20-02-2003', 'dd-mm-yyyy'), to_date('06-03-2003', 'dd-mm-yyyy'), 2, 3380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051013016853, to_date('13-10-2005', 'dd-mm-yyyy'), to_date('27-10-2005', 'dd-mm-yyyy'), 1, 7664, to_date('23-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609016854, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 1, 4396, to_date('10-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130225016855, to_date('25-02-2013', 'dd-mm-yyyy'), to_date('11-03-2013', 'dd-mm-yyyy'), 2, 9798, to_date('14-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050723016856, to_date('23-07-2005', 'dd-mm-yyyy'), to_date('06-08-2005', 'dd-mm-yyyy'), 1, 3839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111220016857, to_date('20-12-2011', 'dd-mm-yyyy'), to_date('03-01-2012', 'dd-mm-yyyy'), 1, 6837, to_date('09-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108016858, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 1, 7795, to_date('23-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517016859, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 2, 8826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102016860, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 2, 2828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110721016861, to_date('21-07-2011', 'dd-mm-yyyy'), to_date('04-08-2011', 'dd-mm-yyyy'), 1, 7076, to_date('02-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325016862, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 2, 6679, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040503016863, to_date('03-05-2004', 'dd-mm-yyyy'), to_date('17-05-2004', 'dd-mm-yyyy'), 1, 4425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130808016864, to_date('08-08-2013', 'dd-mm-yyyy'), to_date('22-08-2013', 'dd-mm-yyyy'), 2, 6971, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040627016865, to_date('27-06-2004', 'dd-mm-yyyy'), to_date('11-07-2004', 'dd-mm-yyyy'), 2, 3096, to_date('06-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090901016866, to_date('01-09-2009', 'dd-mm-yyyy'), to_date('15-09-2009', 'dd-mm-yyyy'), 1, 6127, to_date('15-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050107016867, to_date('07-01-2005', 'dd-mm-yyyy'), to_date('21-01-2005', 'dd-mm-yyyy'), 2, 3917, to_date('25-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020615016868, to_date('15-06-2002', 'dd-mm-yyyy'), to_date('29-06-2002', 'dd-mm-yyyy'), 1, 932, to_date('24-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070809016869, to_date('09-08-2007', 'dd-mm-yyyy'), to_date('23-08-2007', 'dd-mm-yyyy'), 2, 6734, to_date('26-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612016870, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 2, 6891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060913016871, to_date('13-09-2006', 'dd-mm-yyyy'), to_date('27-09-2006', 'dd-mm-yyyy'), 2, 5856, to_date('19-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051224016872, to_date('24-12-2005', 'dd-mm-yyyy'), to_date('07-01-2006', 'dd-mm-yyyy'), 2, 3793, to_date('29-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130112016873, to_date('12-01-2013', 'dd-mm-yyyy'), to_date('26-01-2013', 'dd-mm-yyyy'), 1, 6372, to_date('01-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111111016874, to_date('11-11-2011', 'dd-mm-yyyy'), to_date('25-11-2011', 'dd-mm-yyyy'), 2, 7359, to_date('01-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101016875, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 2, 5573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090911016876, to_date('11-09-2009', 'dd-mm-yyyy'), to_date('25-09-2009', 'dd-mm-yyyy'), 2, 6245, to_date('29-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020617016877, to_date('17-06-2002', 'dd-mm-yyyy'), to_date('01-07-2002', 'dd-mm-yyyy'), 1, 1381, to_date('30-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111127016878, to_date('27-11-2011', 'dd-mm-yyyy'), to_date('11-12-2011', 'dd-mm-yyyy'), 2, 3965, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824016879, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 1, 7781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050430016880, to_date('30-04-2005', 'dd-mm-yyyy'), to_date('14-05-2005', 'dd-mm-yyyy'), 1, 4763, to_date('05-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091107016881, to_date('07-11-2009', 'dd-mm-yyyy'), to_date('21-11-2009', 'dd-mm-yyyy'), 1, 5337, to_date('24-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021028016882, to_date('28-10-2002', 'dd-mm-yyyy'), to_date('11-11-2002', 'dd-mm-yyyy'), 1, 3026, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070101016883, to_date('01-01-2007', 'dd-mm-yyyy'), to_date('15-01-2007', 'dd-mm-yyyy'), 2, 4846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030706016884, to_date('06-07-2003', 'dd-mm-yyyy'), to_date('20-07-2003', 'dd-mm-yyyy'), 1, 4881, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020704016885, to_date('04-07-2002', 'dd-mm-yyyy'), to_date('18-07-2002', 'dd-mm-yyyy'), 1, 2442, to_date('14-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130609016886, to_date('09-06-2013', 'dd-mm-yyyy'), to_date('23-06-2013', 'dd-mm-yyyy'), 1, 10060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090127016887, to_date('27-01-2009', 'dd-mm-yyyy'), to_date('10-02-2009', 'dd-mm-yyyy'), 1, 5935, to_date('13-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218016888, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 2, 6036, to_date('09-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030604016889, to_date('04-06-2003', 'dd-mm-yyyy'), to_date('18-06-2003', 'dd-mm-yyyy'), 1, 2333, to_date('07-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120114016890, to_date('14-01-2012', 'dd-mm-yyyy'), to_date('28-01-2012', 'dd-mm-yyyy'), 2, 10083, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140308016891, to_date('08-03-2014', 'dd-mm-yyyy'), to_date('22-03-2014', 'dd-mm-yyyy'), 1, 7963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001209016892, to_date('09-12-2000', 'dd-mm-yyyy'), to_date('23-12-2000', 'dd-mm-yyyy'), 1, 1167, to_date('18-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020122016893, to_date('22-01-2002', 'dd-mm-yyyy'), to_date('05-02-2002', 'dd-mm-yyyy'), 2, 1757, to_date('01-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426016894, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 2, 4123, to_date('15-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020915016895, to_date('15-09-2002', 'dd-mm-yyyy'), to_date('29-09-2002', 'dd-mm-yyyy'), 2, 1765, to_date('22-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040308016896, to_date('08-03-2004', 'dd-mm-yyyy'), to_date('22-03-2004', 'dd-mm-yyyy'), 1, 4757, to_date('18-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050216016897, to_date('16-02-2005', 'dd-mm-yyyy'), to_date('02-03-2005', 'dd-mm-yyyy'), 1, 3350, to_date('25-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040214016898, to_date('14-02-2004', 'dd-mm-yyyy'), to_date('28-02-2004', 'dd-mm-yyyy'), 1, 4822, to_date('16-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313016899, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 2, 6718, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009016900, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 2, 1561, to_date('17-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090117016901, to_date('17-01-2009', 'dd-mm-yyyy'), to_date('31-01-2009', 'dd-mm-yyyy'), 2, 5730, to_date('25-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090225016902, to_date('25-02-2009', 'dd-mm-yyyy'), to_date('11-03-2009', 'dd-mm-yyyy'), 1, 7532, to_date('28-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100606016736, to_date('06-06-2010', 'dd-mm-yyyy'), to_date('20-06-2010', 'dd-mm-yyyy'), 2, 8002, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010913011349, to_date('13-09-2001', 'dd-mm-yyyy'), to_date('27-09-2001', 'dd-mm-yyyy'), 12, 2135, to_date('25-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100829011350, to_date('29-08-2010', 'dd-mm-yyyy'), to_date('12-09-2010', 'dd-mm-yyyy'), 9, 8596, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060903011351, to_date('03-09-2006', 'dd-mm-yyyy'), to_date('17-09-2006', 'dd-mm-yyyy'), 5, 4658, to_date('18-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070430011352, to_date('30-04-2007', 'dd-mm-yyyy'), to_date('14-05-2007', 'dd-mm-yyyy'), 2, 6490, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130505011353, to_date('05-05-2013', 'dd-mm-yyyy'), to_date('19-05-2013', 'dd-mm-yyyy'), 10, 8334, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040227011354, to_date('27-02-2004', 'dd-mm-yyyy'), to_date('12-03-2004', 'dd-mm-yyyy'), 10, 2626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121011355, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 7, 6054, to_date('05-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424011356, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 5, 6767, to_date('26-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071210011357, to_date('10-12-2007', 'dd-mm-yyyy'), to_date('24-12-2007', 'dd-mm-yyyy'), 6, 3736, to_date('19-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100214011358, to_date('14-02-2010', 'dd-mm-yyyy'), to_date('28-02-2010', 'dd-mm-yyyy'), 4, 4807, to_date('04-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080507011359, to_date('07-05-2008', 'dd-mm-yyyy'), to_date('21-05-2008', 'dd-mm-yyyy'), 9, 4663, to_date('09-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071011011360, to_date('11-10-2007', 'dd-mm-yyyy'), to_date('25-10-2007', 'dd-mm-yyyy'), 11, 5924, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040612011361, to_date('12-06-2004', 'dd-mm-yyyy'), to_date('26-06-2004', 'dd-mm-yyyy'), 3, 4821, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060702011362, to_date('02-07-2006', 'dd-mm-yyyy'), to_date('16-07-2006', 'dd-mm-yyyy'), 2, 4333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001223011363, to_date('23-12-2000', 'dd-mm-yyyy'), to_date('06-01-2001', 'dd-mm-yyyy'), 7, 2047, to_date('04-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040411011364, to_date('11-04-2004', 'dd-mm-yyyy'), to_date('25-04-2004', 'dd-mm-yyyy'), 8, 5137, to_date('16-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130412011365, to_date('12-04-2013', 'dd-mm-yyyy'), to_date('26-04-2013', 'dd-mm-yyyy'), 7, 7072, to_date('30-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010317011366, to_date('17-03-2001', 'dd-mm-yyyy'), to_date('31-03-2001', 'dd-mm-yyyy'), 2, 3366, to_date('30-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120406011367, to_date('06-04-2012', 'dd-mm-yyyy'), to_date('20-04-2012', 'dd-mm-yyyy'), 5, 6053, to_date('16-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060317011368, to_date('17-03-2006', 'dd-mm-yyyy'), to_date('31-03-2006', 'dd-mm-yyyy'), 10, 4693, to_date('03-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110531011369, to_date('31-05-2011', 'dd-mm-yyyy'), to_date('14-06-2011', 'dd-mm-yyyy'), 7, 8335, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060920011370, to_date('20-09-2006', 'dd-mm-yyyy'), to_date('04-10-2006', 'dd-mm-yyyy'), 8, 7282, to_date('24-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020309011371, to_date('09-03-2002', 'dd-mm-yyyy'), to_date('23-03-2002', 'dd-mm-yyyy'), 12, 2638, to_date('25-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091125011372, to_date('25-11-2009', 'dd-mm-yyyy'), to_date('09-12-2009', 'dd-mm-yyyy'), 11, 5497, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229011373, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 7, 9099, to_date('17-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020520011374, to_date('20-05-2002', 'dd-mm-yyyy'), to_date('03-06-2002', 'dd-mm-yyyy'), 11, 4333, to_date('02-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121019011375, to_date('19-10-2012', 'dd-mm-yyyy'), to_date('02-11-2012', 'dd-mm-yyyy'), 7, 9408, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040401011376, to_date('01-04-2004', 'dd-mm-yyyy'), to_date('15-04-2004', 'dd-mm-yyyy'), 4, 2071, to_date('02-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010211011377, to_date('11-02-2001', 'dd-mm-yyyy'), to_date('25-02-2001', 'dd-mm-yyyy'), 3, 4140, to_date('22-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071213011378, to_date('13-12-2007', 'dd-mm-yyyy'), to_date('27-12-2007', 'dd-mm-yyyy'), 2, 5677, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121215011379, to_date('15-12-2012', 'dd-mm-yyyy'), to_date('29-12-2012', 'dd-mm-yyyy'), 9, 8750, to_date('20-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051009011380, to_date('09-10-2005', 'dd-mm-yyyy'), to_date('23-10-2005', 'dd-mm-yyyy'), 11, 3551, to_date('11-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001023011381, to_date('23-10-2000', 'dd-mm-yyyy'), to_date('06-11-2000', 'dd-mm-yyyy'), 9, 1208, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021208011382, to_date('08-12-2002', 'dd-mm-yyyy'), to_date('22-12-2002', 'dd-mm-yyyy'), 4, 3756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110308011383, to_date('08-03-2011', 'dd-mm-yyyy'), to_date('22-03-2011', 'dd-mm-yyyy'), 10, 6724, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080624011384, to_date('24-06-2008', 'dd-mm-yyyy'), to_date('08-07-2008', 'dd-mm-yyyy'), 9, 7559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040220011385, to_date('20-02-2004', 'dd-mm-yyyy'), to_date('05-03-2004', 'dd-mm-yyyy'), 11, 6622, to_date('11-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070720011386, to_date('20-07-2007', 'dd-mm-yyyy'), to_date('03-08-2007', 'dd-mm-yyyy'), 6, 5045, to_date('01-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001031011387, to_date('31-10-2000', 'dd-mm-yyyy'), to_date('14-11-2000', 'dd-mm-yyyy'), 3, 2249, to_date('11-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303011388, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 4, 4109, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020303011389, to_date('03-03-2002', 'dd-mm-yyyy'), to_date('17-03-2002', 'dd-mm-yyyy'), 6, 3148, to_date('22-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110430011390, to_date('30-04-2011', 'dd-mm-yyyy'), to_date('14-05-2011', 'dd-mm-yyyy'), 7, 9441, to_date('13-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060828011391, to_date('28-08-2006', 'dd-mm-yyyy'), to_date('11-09-2006', 'dd-mm-yyyy'), 4, 4638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071212011392, to_date('12-12-2007', 'dd-mm-yyyy'), to_date('26-12-2007', 'dd-mm-yyyy'), 7, 5202, to_date('13-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041124011393, to_date('24-11-2004', 'dd-mm-yyyy'), to_date('08-12-2004', 'dd-mm-yyyy'), 5, 2578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000224011394, to_date('24-02-2000', 'dd-mm-yyyy'), to_date('09-03-2000', 'dd-mm-yyyy'), 7, 2048, to_date('13-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080116011395, to_date('16-01-2008', 'dd-mm-yyyy'), to_date('30-01-2008', 'dd-mm-yyyy'), 4, 4322, to_date('26-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110716011396, to_date('16-07-2011', 'dd-mm-yyyy'), to_date('30-07-2011', 'dd-mm-yyyy'), 12, 6693, to_date('24-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050311011397, to_date('11-03-2005', 'dd-mm-yyyy'), to_date('25-03-2005', 'dd-mm-yyyy'), 10, 6871, to_date('29-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011215011398, to_date('15-12-2001', 'dd-mm-yyyy'), to_date('29-12-2001', 'dd-mm-yyyy'), 4, 3084, to_date('22-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118011399, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 11, 2724, to_date('25-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060813011400, to_date('13-08-2006', 'dd-mm-yyyy'), to_date('27-08-2006', 'dd-mm-yyyy'), 1, 7319, to_date('19-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010215011401, to_date('15-02-2001', 'dd-mm-yyyy'), to_date('01-03-2001', 'dd-mm-yyyy'), 8, 3045, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110704011402, to_date('04-07-2011', 'dd-mm-yyyy'), to_date('18-07-2011', 'dd-mm-yyyy'), 2, 6778, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041024011403, to_date('24-10-2004', 'dd-mm-yyyy'), to_date('07-11-2004', 'dd-mm-yyyy'), 3, 2093, to_date('29-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070411011404, to_date('11-04-2007', 'dd-mm-yyyy'), to_date('25-04-2007', 'dd-mm-yyyy'), 2, 6647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081020011405, to_date('20-10-2008', 'dd-mm-yyyy'), to_date('03-11-2008', 'dd-mm-yyyy'), 12, 6506, to_date('01-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010427011406, to_date('27-04-2001', 'dd-mm-yyyy'), to_date('11-05-2001', 'dd-mm-yyyy'), 6, 1374, to_date('08-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090417011407, to_date('17-04-2009', 'dd-mm-yyyy'), to_date('01-05-2009', 'dd-mm-yyyy'), 7, 6241, to_date('25-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060123011408, to_date('23-01-2006', 'dd-mm-yyyy'), to_date('06-02-2006', 'dd-mm-yyyy'), 2, 6194, to_date('27-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913011409, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 2, 2354, to_date('25-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051112011410, to_date('12-11-2005', 'dd-mm-yyyy'), to_date('26-11-2005', 'dd-mm-yyyy'), 3, 2392, to_date('18-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091201011411, to_date('01-12-2009', 'dd-mm-yyyy'), to_date('15-12-2009', 'dd-mm-yyyy'), 8, 9380, to_date('15-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060213011412, to_date('13-02-2006', 'dd-mm-yyyy'), to_date('27-02-2006', 'dd-mm-yyyy'), 11, 5476, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071208011413, to_date('08-12-2007', 'dd-mm-yyyy'), to_date('22-12-2007', 'dd-mm-yyyy'), 9, 5352, to_date('25-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070623011414, to_date('23-06-2007', 'dd-mm-yyyy'), to_date('07-07-2007', 'dd-mm-yyyy'), 6, 8054, to_date('01-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071109011415, to_date('09-11-2007', 'dd-mm-yyyy'), to_date('23-11-2007', 'dd-mm-yyyy'), 5, 2747, to_date('19-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313011416, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 7, 9214, to_date('17-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423011417, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 4, 2996, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120808011418, to_date('08-08-2012', 'dd-mm-yyyy'), to_date('22-08-2012', 'dd-mm-yyyy'), 6, 7399, to_date('26-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112011419, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 5, 7403, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061218011420, to_date('18-12-2006', 'dd-mm-yyyy'), to_date('01-01-2007', 'dd-mm-yyyy'), 3, 4594, to_date('04-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070128011421, to_date('28-01-2007', 'dd-mm-yyyy'), to_date('11-02-2007', 'dd-mm-yyyy'), 3, 5525, to_date('07-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011118011422, to_date('18-11-2001', 'dd-mm-yyyy'), to_date('02-12-2001', 'dd-mm-yyyy'), 10, 2376, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041009011423, to_date('09-10-2004', 'dd-mm-yyyy'), to_date('23-10-2004', 'dd-mm-yyyy'), 4, 5713, to_date('22-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522011424, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 8, 4478, to_date('31-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021031011425, to_date('31-10-2002', 'dd-mm-yyyy'), to_date('14-11-2002', 'dd-mm-yyyy'), 2, 3056, to_date('14-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040201011426, to_date('01-02-2004', 'dd-mm-yyyy'), to_date('15-02-2004', 'dd-mm-yyyy'), 3, 3019, to_date('03-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060103011427, to_date('03-01-2006', 'dd-mm-yyyy'), to_date('17-01-2006', 'dd-mm-yyyy'), 10, 4353, to_date('07-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070321011428, to_date('21-03-2007', 'dd-mm-yyyy'), to_date('04-04-2007', 'dd-mm-yyyy'), 4, 6547, to_date('09-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071222011429, to_date('22-12-2007', 'dd-mm-yyyy'), to_date('05-01-2008', 'dd-mm-yyyy'), 5, 4625, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060803011430, to_date('03-08-2006', 'dd-mm-yyyy'), to_date('17-08-2006', 'dd-mm-yyyy'), 7, 5098, to_date('08-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130510011431, to_date('10-05-2013', 'dd-mm-yyyy'), to_date('24-05-2013', 'dd-mm-yyyy'), 9, 11157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130204011432, to_date('04-02-2013', 'dd-mm-yyyy'), to_date('18-02-2013', 'dd-mm-yyyy'), 4, 8011, to_date('18-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024011433, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 11, 7036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100710011434, to_date('10-07-2010', 'dd-mm-yyyy'), to_date('24-07-2010', 'dd-mm-yyyy'), 2, 8522, to_date('27-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001016011435, to_date('16-10-2000', 'dd-mm-yyyy'), to_date('30-10-2000', 'dd-mm-yyyy'), 7, 2641, to_date('18-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513011436, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 8, 4278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060629011437, to_date('29-06-2006', 'dd-mm-yyyy'), to_date('13-07-2006', 'dd-mm-yyyy'), 9, 4685, to_date('04-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031129011438, to_date('29-11-2003', 'dd-mm-yyyy'), to_date('13-12-2003', 'dd-mm-yyyy'), 11, 5071, to_date('14-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041229011439, to_date('29-12-2004', 'dd-mm-yyyy'), to_date('12-01-2005', 'dd-mm-yyyy'), 7, 4743, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120624011440, to_date('24-06-2012', 'dd-mm-yyyy'), to_date('08-07-2012', 'dd-mm-yyyy'), 3, 7567, to_date('14-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070404011441, to_date('04-04-2007', 'dd-mm-yyyy'), to_date('18-04-2007', 'dd-mm-yyyy'), 4, 5020, to_date('09-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000201011442, to_date('01-02-2000', 'dd-mm-yyyy'), to_date('15-02-2000', 'dd-mm-yyyy'), 2, 1379, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041129011443, to_date('29-11-2004', 'dd-mm-yyyy'), to_date('13-12-2004', 'dd-mm-yyyy'), 8, 5708, to_date('15-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080615011444, to_date('15-06-2008', 'dd-mm-yyyy'), to_date('29-06-2008', 'dd-mm-yyyy'), 6, 5511, to_date('26-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030114011445, to_date('14-01-2003', 'dd-mm-yyyy'), to_date('28-01-2003', 'dd-mm-yyyy'), 7, 3841, to_date('21-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080913011446, to_date('13-09-2008', 'dd-mm-yyyy'), to_date('27-09-2008', 'dd-mm-yyyy'), 9, 5725, to_date('26-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121021011447, to_date('21-10-2012', 'dd-mm-yyyy'), to_date('04-11-2012', 'dd-mm-yyyy'), 1, 6273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110516011448, to_date('16-05-2011', 'dd-mm-yyyy'), to_date('30-05-2011', 'dd-mm-yyyy'), 2, 8552, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111210011449, to_date('10-12-2011', 'dd-mm-yyyy'), to_date('24-12-2011', 'dd-mm-yyyy'), 6, 8771, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218011450, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 3, 7293, to_date('06-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061207011451, to_date('07-12-2006', 'dd-mm-yyyy'), to_date('21-12-2006', 'dd-mm-yyyy'), 11, 5414, to_date('24-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405011452, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 9, 4953, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070926011453, to_date('26-09-2007', 'dd-mm-yyyy'), to_date('10-10-2007', 'dd-mm-yyyy'), 9, 6856, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040619011454, to_date('19-06-2004', 'dd-mm-yyyy'), to_date('03-07-2004', 'dd-mm-yyyy'), 12, 4337, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030424011455, to_date('24-04-2003', 'dd-mm-yyyy'), to_date('08-05-2003', 'dd-mm-yyyy'), 9, 5413, to_date('01-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080617011456, to_date('17-06-2008', 'dd-mm-yyyy'), to_date('01-07-2008', 'dd-mm-yyyy'), 11, 6482, to_date('25-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421011457, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 4, 3329, to_date('27-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140120011458, to_date('20-01-2014', 'dd-mm-yyyy'), to_date('03-02-2014', 'dd-mm-yyyy'), 11, 10386, to_date('02-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020516011459, to_date('16-05-2002', 'dd-mm-yyyy'), to_date('30-05-2002', 'dd-mm-yyyy'), 5, 4880, to_date('05-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513011460, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 5, 6120, to_date('30-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030611011461, to_date('11-06-2003', 'dd-mm-yyyy'), to_date('25-06-2003', 'dd-mm-yyyy'), 10, 2478, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140228011462, to_date('28-02-2014', 'dd-mm-yyyy'), to_date('14-03-2014', 'dd-mm-yyyy'), 4, 7808, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070605011463, to_date('05-06-2007', 'dd-mm-yyyy'), to_date('19-06-2007', 'dd-mm-yyyy'), 4, 6437, to_date('07-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111229011464, to_date('29-12-2011', 'dd-mm-yyyy'), to_date('12-01-2012', 'dd-mm-yyyy'), 11, 7074, to_date('07-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101117011465, to_date('17-11-2010', 'dd-mm-yyyy'), to_date('01-12-2010', 'dd-mm-yyyy'), 2, 8714, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061208011466, to_date('08-12-2006', 'dd-mm-yyyy'), to_date('22-12-2006', 'dd-mm-yyyy'), 3, 6038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101217011467, to_date('17-12-2010', 'dd-mm-yyyy'), to_date('31-12-2010', 'dd-mm-yyyy'), 11, 7444, to_date('01-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040708011468, to_date('08-07-2004', 'dd-mm-yyyy'), to_date('22-07-2004', 'dd-mm-yyyy'), 11, 4441, to_date('24-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000512011469, to_date('12-05-2000', 'dd-mm-yyyy'), to_date('26-05-2000', 'dd-mm-yyyy'), 12, 1744, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130328011470, to_date('28-03-2013', 'dd-mm-yyyy'), to_date('11-04-2013', 'dd-mm-yyyy'), 3, 11592, to_date('09-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070210011471, to_date('10-02-2007', 'dd-mm-yyyy'), to_date('24-02-2007', 'dd-mm-yyyy'), 9, 5275, to_date('24-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405011472, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 10, 1920, to_date('09-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071112011473, to_date('12-11-2007', 'dd-mm-yyyy'), to_date('26-11-2007', 'dd-mm-yyyy'), 1, 6833, to_date('26-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100220011474, to_date('20-02-2010', 'dd-mm-yyyy'), to_date('06-03-2010', 'dd-mm-yyyy'), 10, 8919, to_date('07-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030303011475, to_date('03-03-2003', 'dd-mm-yyyy'), to_date('17-03-2003', 'dd-mm-yyyy'), 8, 2394, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090509011476, to_date('09-05-2009', 'dd-mm-yyyy'), to_date('23-05-2009', 'dd-mm-yyyy'), 7, 7453, to_date('28-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100409011477, to_date('09-04-2010', 'dd-mm-yyyy'), to_date('23-04-2010', 'dd-mm-yyyy'), 6, 6545, to_date('19-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130427011478, to_date('27-04-2013', 'dd-mm-yyyy'), to_date('11-05-2013', 'dd-mm-yyyy'), 8, 7157, to_date('02-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116011479, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 12, 4057, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060830011480, to_date('30-08-2006', 'dd-mm-yyyy'), to_date('13-09-2006', 'dd-mm-yyyy'), 8, 2993, to_date('13-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080117011481, to_date('17-01-2008', 'dd-mm-yyyy'), to_date('31-01-2008', 'dd-mm-yyyy'), 10, 6776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080125011482, to_date('25-01-2008', 'dd-mm-yyyy'), to_date('08-02-2008', 'dd-mm-yyyy'), 2, 6959, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050512011483, to_date('12-05-2005', 'dd-mm-yyyy'), to_date('26-05-2005', 'dd-mm-yyyy'), 4, 3782, to_date('15-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041224011484, to_date('24-12-2004', 'dd-mm-yyyy'), to_date('07-01-2005', 'dd-mm-yyyy'), 9, 4524, to_date('02-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071023011485, to_date('23-10-2007', 'dd-mm-yyyy'), to_date('06-11-2007', 'dd-mm-yyyy'), 11, 2885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090921011486, to_date('21-09-2009', 'dd-mm-yyyy'), to_date('05-10-2009', 'dd-mm-yyyy'), 3, 7200, to_date('22-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081110011487, to_date('10-11-2008', 'dd-mm-yyyy'), to_date('24-11-2008', 'dd-mm-yyyy'), 7, 6379, to_date('20-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226011488, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 8, 2874, to_date('03-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090807011489, to_date('07-08-2009', 'dd-mm-yyyy'), to_date('21-08-2009', 'dd-mm-yyyy'), 7, 7050, to_date('21-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090726011490, to_date('26-07-2009', 'dd-mm-yyyy'), to_date('09-08-2009', 'dd-mm-yyyy'), 12, 9442, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090709011491, to_date('09-07-2009', 'dd-mm-yyyy'), to_date('23-07-2009', 'dd-mm-yyyy'), 8, 6136, to_date('24-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060629011492, to_date('29-06-2006', 'dd-mm-yyyy'), to_date('13-07-2006', 'dd-mm-yyyy'), 1, 3342, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000928011493, to_date('28-09-2000', 'dd-mm-yyyy'), to_date('12-10-2000', 'dd-mm-yyyy'), 1, 2689, to_date('08-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070516011494, to_date('16-05-2007', 'dd-mm-yyyy'), to_date('30-05-2007', 'dd-mm-yyyy'), 2, 4294, to_date('18-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060324011495, to_date('24-03-2006', 'dd-mm-yyyy'), to_date('07-04-2006', 'dd-mm-yyyy'), 10, 4783, to_date('03-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030912011496, to_date('12-09-2003', 'dd-mm-yyyy'), to_date('26-09-2003', 'dd-mm-yyyy'), 4, 4852, to_date('21-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031019011497, to_date('19-10-2003', 'dd-mm-yyyy'), to_date('02-11-2003', 'dd-mm-yyyy'), 4, 3638, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070921011498, to_date('21-09-2007', 'dd-mm-yyyy'), to_date('05-10-2007', 'dd-mm-yyyy'), 2, 3322, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120318011499, to_date('18-03-2012', 'dd-mm-yyyy'), to_date('01-04-2012', 'dd-mm-yyyy'), 11, 8713, to_date('23-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081112011500, to_date('12-11-2008', 'dd-mm-yyyy'), to_date('26-11-2008', 'dd-mm-yyyy'), 10, 7006, to_date('02-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110811011501, to_date('11-08-2011', 'dd-mm-yyyy'), to_date('25-08-2011', 'dd-mm-yyyy'), 4, 7071, to_date('27-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030528011502, to_date('28-05-2003', 'dd-mm-yyyy'), to_date('11-06-2003', 'dd-mm-yyyy'), 10, 4164, to_date('16-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070812011503, to_date('12-08-2007', 'dd-mm-yyyy'), to_date('26-08-2007', 'dd-mm-yyyy'), 10, 6397, to_date('20-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050321011504, to_date('21-03-2005', 'dd-mm-yyyy'), to_date('04-04-2005', 'dd-mm-yyyy'), 11, 4587, to_date('25-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207011505, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 10, 2543, to_date('26-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050421011506, to_date('21-04-2005', 'dd-mm-yyyy'), to_date('05-05-2005', 'dd-mm-yyyy'), 4, 3854, to_date('01-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081015011507, to_date('15-10-2008', 'dd-mm-yyyy'), to_date('29-10-2008', 'dd-mm-yyyy'), 10, 5741, to_date('26-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722011508, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 2, 8137, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110703011509, to_date('03-07-2011', 'dd-mm-yyyy'), to_date('17-07-2011', 'dd-mm-yyyy'), 9, 7972, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912011510, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 8, 3481, to_date('28-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100107011511, to_date('07-01-2010', 'dd-mm-yyyy'), to_date('21-01-2010', 'dd-mm-yyyy'), 11, 6338, to_date('19-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103011512, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 5, 8029, to_date('22-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505011513, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 5, 6307, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020315011514, to_date('15-03-2002', 'dd-mm-yyyy'), to_date('29-03-2002', 'dd-mm-yyyy'), 1, 4243, to_date('29-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201011515, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 3, 7631, to_date('12-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051123011516, to_date('23-11-2005', 'dd-mm-yyyy'), to_date('07-12-2005', 'dd-mm-yyyy'), 9, 3185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130501014211, to_date('01-05-2013', 'dd-mm-yyyy'), to_date('15-05-2013', 'dd-mm-yyyy'), 4, 7184, to_date('11-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030613014212, to_date('13-06-2003', 'dd-mm-yyyy'), to_date('27-06-2003', 'dd-mm-yyyy'), 2, 1639, to_date('20-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060430014213, to_date('30-04-2006', 'dd-mm-yyyy'), to_date('14-05-2006', 'dd-mm-yyyy'), 3, 4348, to_date('08-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030215014214, to_date('15-02-2003', 'dd-mm-yyyy'), to_date('01-03-2003', 'dd-mm-yyyy'), 4, 4265, to_date('23-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010811014215, to_date('11-08-2001', 'dd-mm-yyyy'), to_date('25-08-2001', 'dd-mm-yyyy'), 1, 1531, to_date('14-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080827014216, to_date('27-08-2008', 'dd-mm-yyyy'), to_date('10-09-2008', 'dd-mm-yyyy'), 1, 5427, to_date('10-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000122014217, to_date('22-01-2000', 'dd-mm-yyyy'), to_date('05-02-2000', 'dd-mm-yyyy'), 2, 3286, to_date('26-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120509014218, to_date('09-05-2012', 'dd-mm-yyyy'), to_date('23-05-2012', 'dd-mm-yyyy'), 4, 6867, to_date('28-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070921014219, to_date('21-09-2007', 'dd-mm-yyyy'), to_date('05-10-2007', 'dd-mm-yyyy'), 2, 6029, to_date('07-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020220014220, to_date('20-02-2002', 'dd-mm-yyyy'), to_date('06-03-2002', 'dd-mm-yyyy'), 4, 3410, to_date('24-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130905014221, to_date('05-09-2013', 'dd-mm-yyyy'), to_date('19-09-2013', 'dd-mm-yyyy'), 2, 12224, to_date('07-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131015014222, to_date('15-10-2013', 'dd-mm-yyyy'), to_date('29-10-2013', 'dd-mm-yyyy'), 3, 9011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100403014223, to_date('03-04-2010', 'dd-mm-yyyy'), to_date('17-04-2010', 'dd-mm-yyyy'), 2, 6591, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121203014224, to_date('03-12-2012', 'dd-mm-yyyy'), to_date('17-12-2012', 'dd-mm-yyyy'), 4, 9716, to_date('16-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110420014225, to_date('20-04-2011', 'dd-mm-yyyy'), to_date('04-05-2011', 'dd-mm-yyyy'), 2, 7638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091105014226, to_date('05-11-2009', 'dd-mm-yyyy'), to_date('19-11-2009', 'dd-mm-yyyy'), 3, 7436, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525014227, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 1, 5298, to_date('28-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524014228, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 2, 7833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130210014229, to_date('10-02-2013', 'dd-mm-yyyy'), to_date('24-02-2013', 'dd-mm-yyyy'), 2, 8923, to_date('14-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100619014230, to_date('19-06-2010', 'dd-mm-yyyy'), to_date('03-07-2010', 'dd-mm-yyyy'), 1, 7670, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010114014231, to_date('14-01-2001', 'dd-mm-yyyy'), to_date('28-01-2001', 'dd-mm-yyyy'), 3, 3823, to_date('17-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020716014232, to_date('16-07-2002', 'dd-mm-yyyy'), to_date('30-07-2002', 'dd-mm-yyyy'), 4, 4880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091117014233, to_date('17-11-2009', 'dd-mm-yyyy'), to_date('01-12-2009', 'dd-mm-yyyy'), 1, 6396, to_date('07-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000503014234, to_date('03-05-2000', 'dd-mm-yyyy'), to_date('17-05-2000', 'dd-mm-yyyy'), 2, 895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130314014235, to_date('14-03-2013', 'dd-mm-yyyy'), to_date('28-03-2013', 'dd-mm-yyyy'), 2, 7759, to_date('03-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926014236, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 1, 9291, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060721014237, to_date('21-07-2006', 'dd-mm-yyyy'), to_date('04-08-2006', 'dd-mm-yyyy'), 2, 5138, to_date('04-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100906014238, to_date('06-09-2010', 'dd-mm-yyyy'), to_date('20-09-2010', 'dd-mm-yyyy'), 1, 7347, to_date('24-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030113014239, to_date('13-01-2003', 'dd-mm-yyyy'), to_date('27-01-2003', 'dd-mm-yyyy'), 4, 4644, to_date('19-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100208014240, to_date('08-02-2010', 'dd-mm-yyyy'), to_date('22-02-2010', 'dd-mm-yyyy'), 2, 6174, to_date('26-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120824014241, to_date('24-08-2012', 'dd-mm-yyyy'), to_date('07-09-2012', 'dd-mm-yyyy'), 2, 11240, to_date('05-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603014242, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 3, 5510, to_date('17-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080126014243, to_date('26-01-2008', 'dd-mm-yyyy'), to_date('09-02-2008', 'dd-mm-yyyy'), 4, 7336, to_date('08-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130711014244, to_date('11-07-2013', 'dd-mm-yyyy'), to_date('25-07-2013', 'dd-mm-yyyy'), 2, 10881, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010514014245, to_date('14-05-2001', 'dd-mm-yyyy'), to_date('28-05-2001', 'dd-mm-yyyy'), 3, 1931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030906014246, to_date('06-09-2003', 'dd-mm-yyyy'), to_date('20-09-2003', 'dd-mm-yyyy'), 1, 3567, to_date('13-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124014247, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 1, 7181, to_date('30-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111219014248, to_date('19-12-2011', 'dd-mm-yyyy'), to_date('02-01-2012', 'dd-mm-yyyy'), 3, 6779, to_date('02-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101004014249, to_date('04-10-2010', 'dd-mm-yyyy'), to_date('18-10-2010', 'dd-mm-yyyy'), 1, 8485, to_date('18-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031221014250, to_date('21-12-2003', 'dd-mm-yyyy'), to_date('04-01-2004', 'dd-mm-yyyy'), 1, 5524, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221014251, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 3, 1112, to_date('03-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080523014252, to_date('23-05-2008', 'dd-mm-yyyy'), to_date('06-06-2008', 'dd-mm-yyyy'), 1, 8616, to_date('12-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100204014253, to_date('04-02-2010', 'dd-mm-yyyy'), to_date('18-02-2010', 'dd-mm-yyyy'), 3, 8706, to_date('06-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071214014254, to_date('14-12-2007', 'dd-mm-yyyy'), to_date('28-12-2007', 'dd-mm-yyyy'), 3, 5143, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020524014255, to_date('24-05-2002', 'dd-mm-yyyy'), to_date('07-06-2002', 'dd-mm-yyyy'), 4, 896, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030124014256, to_date('24-01-2003', 'dd-mm-yyyy'), to_date('07-02-2003', 'dd-mm-yyyy'), 3, 3993, to_date('25-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325014257, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 2, 3946, to_date('30-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000912014258, to_date('12-09-2000', 'dd-mm-yyyy'), to_date('26-09-2000', 'dd-mm-yyyy'), 3, 2129, to_date('21-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140301014259, to_date('01-03-2014', 'dd-mm-yyyy'), to_date('15-03-2014', 'dd-mm-yyyy'), 2, 9540, to_date('14-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830014260, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 4, 3568, to_date('03-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101029014261, to_date('29-10-2010', 'dd-mm-yyyy'), to_date('12-11-2010', 'dd-mm-yyyy'), 3, 8302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020221014262, to_date('21-02-2002', 'dd-mm-yyyy'), to_date('07-03-2002', 'dd-mm-yyyy'), 1, 4763, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409014263, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 3, 4204, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110817014264, to_date('17-08-2011', 'dd-mm-yyyy'), to_date('31-08-2011', 'dd-mm-yyyy'), 2, 10719, to_date('29-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131014265, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 4, 3524, to_date('16-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001130014266, to_date('30-11-2000', 'dd-mm-yyyy'), to_date('14-12-2000', 'dd-mm-yyyy'), 3, 2720, to_date('15-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918014267, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 4, 6016, to_date('23-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090802014268, to_date('02-08-2009', 'dd-mm-yyyy'), to_date('16-08-2009', 'dd-mm-yyyy'), 2, 8882, to_date('17-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021126014269, to_date('26-11-2002', 'dd-mm-yyyy'), to_date('10-12-2002', 'dd-mm-yyyy'), 2, 3963, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010725014270, to_date('25-07-2001', 'dd-mm-yyyy'), to_date('08-08-2001', 'dd-mm-yyyy'), 4, 3399, to_date('01-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040121014271, to_date('21-01-2004', 'dd-mm-yyyy'), to_date('04-02-2004', 'dd-mm-yyyy'), 3, 3425, to_date('06-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050217014272, to_date('17-02-2005', 'dd-mm-yyyy'), to_date('03-03-2005', 'dd-mm-yyyy'), 2, 4675, to_date('27-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071221014273, to_date('21-12-2007', 'dd-mm-yyyy'), to_date('04-01-2008', 'dd-mm-yyyy'), 3, 4153, to_date('23-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081115014274, to_date('15-11-2008', 'dd-mm-yyyy'), to_date('29-11-2008', 'dd-mm-yyyy'), 2, 6120, to_date('20-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090610014275, to_date('10-06-2009', 'dd-mm-yyyy'), to_date('24-06-2009', 'dd-mm-yyyy'), 1, 7049, to_date('15-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001025014276, to_date('25-10-2000', 'dd-mm-yyyy'), to_date('08-11-2000', 'dd-mm-yyyy'), 2, 3697, to_date('04-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008014277, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 2, 4135, to_date('14-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130222014278, to_date('22-02-2013', 'dd-mm-yyyy'), to_date('08-03-2013', 'dd-mm-yyyy'), 4, 10693, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110528014279, to_date('28-05-2011', 'dd-mm-yyyy'), to_date('11-06-2011', 'dd-mm-yyyy'), 3, 7960, to_date('03-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714014280, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 2, 5488, to_date('23-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000302014281, to_date('02-03-2000', 'dd-mm-yyyy'), to_date('16-03-2000', 'dd-mm-yyyy'), 2, 1254, to_date('05-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510014282, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 2, 5015, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090405014283, to_date('05-04-2009', 'dd-mm-yyyy'), to_date('19-04-2009', 'dd-mm-yyyy'), 4, 6539, to_date('14-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130102014284, to_date('02-01-2013', 'dd-mm-yyyy'), to_date('16-01-2013', 'dd-mm-yyyy'), 2, 9016, to_date('14-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001222014285, to_date('22-12-2000', 'dd-mm-yyyy'), to_date('05-01-2001', 'dd-mm-yyyy'), 3, 2262, to_date('29-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060202014286, to_date('02-02-2006', 'dd-mm-yyyy'), to_date('16-02-2006', 'dd-mm-yyyy'), 4, 6712, to_date('06-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000325014287, to_date('25-03-2000', 'dd-mm-yyyy'), to_date('08-04-2000', 'dd-mm-yyyy'), 4, 1771, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020523014288, to_date('23-05-2002', 'dd-mm-yyyy'), to_date('06-06-2002', 'dd-mm-yyyy'), 2, 3266, to_date('10-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021010014289, to_date('10-10-2002', 'dd-mm-yyyy'), to_date('24-10-2002', 'dd-mm-yyyy'), 2, 1946, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091102014290, to_date('02-11-2009', 'dd-mm-yyyy'), to_date('16-11-2009', 'dd-mm-yyyy'), 1, 5185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203014291, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 3, 8017, to_date('21-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120403014292, to_date('03-04-2012', 'dd-mm-yyyy'), to_date('17-04-2012', 'dd-mm-yyyy'), 3, 8138, to_date('17-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110109014293, to_date('09-01-2011', 'dd-mm-yyyy'), to_date('23-01-2011', 'dd-mm-yyyy'), 3, 7004, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071205014294, to_date('05-12-2007', 'dd-mm-yyyy'), to_date('19-12-2007', 'dd-mm-yyyy'), 3, 6763, to_date('08-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120014295, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 3, 1476, to_date('06-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100711014296, to_date('11-07-2010', 'dd-mm-yyyy'), to_date('25-07-2010', 'dd-mm-yyyy'), 3, 6680, to_date('15-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091230014297, to_date('30-12-2009', 'dd-mm-yyyy'), to_date('13-01-2010', 'dd-mm-yyyy'), 2, 5765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804014298, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 4, 6315, to_date('09-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130803014299, to_date('03-08-2013', 'dd-mm-yyyy'), to_date('17-08-2013', 'dd-mm-yyyy'), 4, 9716, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121009014300, to_date('09-10-2012', 'dd-mm-yyyy'), to_date('23-10-2012', 'dd-mm-yyyy'), 1, 7391, to_date('23-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110418014301, to_date('18-04-2011', 'dd-mm-yyyy'), to_date('02-05-2011', 'dd-mm-yyyy'), 1, 7370, to_date('05-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120117014302, to_date('17-01-2012', 'dd-mm-yyyy'), to_date('31-01-2012', 'dd-mm-yyyy'), 3, 6706, to_date('18-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080131014303, to_date('31-01-2008', 'dd-mm-yyyy'), to_date('14-02-2008', 'dd-mm-yyyy'), 2, 5832, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101207014304, to_date('07-12-2010', 'dd-mm-yyyy'), to_date('21-12-2010', 'dd-mm-yyyy'), 2, 9051, to_date('15-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020608014305, to_date('08-06-2002', 'dd-mm-yyyy'), to_date('22-06-2002', 'dd-mm-yyyy'), 1, 3611, to_date('19-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000323014306, to_date('23-03-2000', 'dd-mm-yyyy'), to_date('06-04-2000', 'dd-mm-yyyy'), 4, 927, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041125014307, to_date('25-11-2004', 'dd-mm-yyyy'), to_date('09-12-2004', 'dd-mm-yyyy'), 3, 3989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821014308, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 3, 5766, to_date('07-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110618014309, to_date('18-06-2011', 'dd-mm-yyyy'), to_date('02-07-2011', 'dd-mm-yyyy'), 3, 7758, to_date('22-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010820014310, to_date('20-08-2001', 'dd-mm-yyyy'), to_date('03-09-2001', 'dd-mm-yyyy'), 2, 1487, to_date('25-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120224014311, to_date('24-02-2012', 'dd-mm-yyyy'), to_date('09-03-2012', 'dd-mm-yyyy'), 3, 7173, to_date('14-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010406014312, to_date('06-04-2001', 'dd-mm-yyyy'), to_date('20-04-2001', 'dd-mm-yyyy'), 1, 3651, to_date('08-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101112014313, to_date('12-11-2010', 'dd-mm-yyyy'), to_date('26-11-2010', 'dd-mm-yyyy'), 4, 7475, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040404014314, to_date('04-04-2004', 'dd-mm-yyyy'), to_date('18-04-2004', 'dd-mm-yyyy'), 3, 3437, to_date('15-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130808014315, to_date('08-08-2013', 'dd-mm-yyyy'), to_date('22-08-2013', 'dd-mm-yyyy'), 4, 10397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725014316, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 3, 10165, to_date('09-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140326014317, to_date('26-03-2014', 'dd-mm-yyyy'), to_date('09-04-2014', 'dd-mm-yyyy'), 2, 8479, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030819014318, to_date('19-08-2003', 'dd-mm-yyyy'), to_date('02-09-2003', 'dd-mm-yyyy'), 3, 2981, to_date('21-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130202014319, to_date('02-02-2013', 'dd-mm-yyyy'), to_date('16-02-2013', 'dd-mm-yyyy'), 3, 9504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080801014320, to_date('01-08-2008', 'dd-mm-yyyy'), to_date('15-08-2008', 'dd-mm-yyyy'), 4, 5308, to_date('19-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117014321, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 2, 8182, to_date('28-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051110014322, to_date('10-11-2005', 'dd-mm-yyyy'), to_date('24-11-2005', 'dd-mm-yyyy'), 1, 5884, to_date('18-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429014323, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 1, 4515, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090818014324, to_date('18-08-2009', 'dd-mm-yyyy'), to_date('01-09-2009', 'dd-mm-yyyy'), 3, 8042, to_date('26-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040617014325, to_date('17-06-2004', 'dd-mm-yyyy'), to_date('01-07-2004', 'dd-mm-yyyy'), 3, 4654, to_date('24-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000716014326, to_date('16-07-2000', 'dd-mm-yyyy'), to_date('30-07-2000', 'dd-mm-yyyy'), 1, 2647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524014327, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 3, 7044, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070606014328, to_date('06-06-2007', 'dd-mm-yyyy'), to_date('20-06-2007', 'dd-mm-yyyy'), 1, 4945, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081012014329, to_date('12-10-2008', 'dd-mm-yyyy'), to_date('26-10-2008', 'dd-mm-yyyy'), 2, 6738, to_date('25-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050903014330, to_date('03-09-2005', 'dd-mm-yyyy'), to_date('17-09-2005', 'dd-mm-yyyy'), 1, 3136, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090415014331, to_date('15-04-2009', 'dd-mm-yyyy'), to_date('29-04-2009', 'dd-mm-yyyy'), 1, 6058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090903014332, to_date('03-09-2009', 'dd-mm-yyyy'), to_date('17-09-2009', 'dd-mm-yyyy'), 3, 6979, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090316014333, to_date('16-03-2009', 'dd-mm-yyyy'), to_date('30-03-2009', 'dd-mm-yyyy'), 4, 6976, to_date('01-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030928014334, to_date('28-09-2003', 'dd-mm-yyyy'), to_date('12-10-2003', 'dd-mm-yyyy'), 2, 2551, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070415014335, to_date('15-04-2007', 'dd-mm-yyyy'), to_date('29-04-2007', 'dd-mm-yyyy'), 3, 5259, to_date('27-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809014336, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 2, 1078, to_date('11-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111002014337, to_date('02-10-2011', 'dd-mm-yyyy'), to_date('16-10-2011', 'dd-mm-yyyy'), 4, 5785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130923014338, to_date('23-09-2013', 'dd-mm-yyyy'), to_date('07-10-2013', 'dd-mm-yyyy'), 4, 10397, to_date('12-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070702014339, to_date('02-07-2007', 'dd-mm-yyyy'), to_date('16-07-2007', 'dd-mm-yyyy'), 2, 4546, to_date('16-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130621014340, to_date('21-06-2013', 'dd-mm-yyyy'), to_date('05-07-2013', 'dd-mm-yyyy'), 2, 7604, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040410014341, to_date('10-04-2004', 'dd-mm-yyyy'), to_date('24-04-2004', 'dd-mm-yyyy'), 3, 6773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001024014342, to_date('24-10-2000', 'dd-mm-yyyy'), to_date('07-11-2000', 'dd-mm-yyyy'), 3, 1926, to_date('28-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402014343, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 3, 9567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526014344, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 3, 1770, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020718014345, to_date('18-07-2002', 'dd-mm-yyyy'), to_date('01-08-2002', 'dd-mm-yyyy'), 1, 2175, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090617014346, to_date('17-06-2009', 'dd-mm-yyyy'), to_date('01-07-2009', 'dd-mm-yyyy'), 3, 7548, to_date('30-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116014347, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 3, 7650, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831014348, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 3, 8696, to_date('12-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050110014349, to_date('10-01-2005', 'dd-mm-yyyy'), to_date('24-01-2005', 'dd-mm-yyyy'), 1, 5174, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030918014350, to_date('18-09-2003', 'dd-mm-yyyy'), to_date('02-10-2003', 'dd-mm-yyyy'), 3, 4712, to_date('27-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120402014351, to_date('02-04-2012', 'dd-mm-yyyy'), to_date('16-04-2012', 'dd-mm-yyyy'), 4, 5449, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020123014352, to_date('23-01-2002', 'dd-mm-yyyy'), to_date('06-02-2002', 'dd-mm-yyyy'), 3, 3485, to_date('26-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100801014353, to_date('01-08-2010', 'dd-mm-yyyy'), to_date('15-08-2010', 'dd-mm-yyyy'), 4, 8468, to_date('08-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110525014354, to_date('25-05-2011', 'dd-mm-yyyy'), to_date('08-06-2011', 'dd-mm-yyyy'), 2, 6430, to_date('03-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717014355, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 2, 7220, to_date('20-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111019014356, to_date('19-10-2011', 'dd-mm-yyyy'), to_date('02-11-2011', 'dd-mm-yyyy'), 1, 7219, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030316014357, to_date('16-03-2003', 'dd-mm-yyyy'), to_date('30-03-2003', 'dd-mm-yyyy'), 2, 2158, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050610014358, to_date('10-06-2005', 'dd-mm-yyyy'), to_date('24-06-2005', 'dd-mm-yyyy'), 2, 6083, to_date('18-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020910014359, to_date('10-09-2002', 'dd-mm-yyyy'), to_date('24-09-2002', 'dd-mm-yyyy'), 4, 2199, to_date('28-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011231014360, to_date('31-12-2001', 'dd-mm-yyyy'), to_date('14-01-2002', 'dd-mm-yyyy'), 3, 2266, to_date('08-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010305014361, to_date('05-03-2001', 'dd-mm-yyyy'), to_date('19-03-2001', 'dd-mm-yyyy'), 4, 3555, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020803014362, to_date('03-08-2002', 'dd-mm-yyyy'), to_date('17-08-2002', 'dd-mm-yyyy'), 3, 3854, to_date('22-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021106014363, to_date('06-11-2002', 'dd-mm-yyyy'), to_date('20-11-2002', 'dd-mm-yyyy'), 2, 2776, to_date('26-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031208014364, to_date('08-12-2003', 'dd-mm-yyyy'), to_date('22-12-2003', 'dd-mm-yyyy'), 1, 3832, to_date('13-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130727014365, to_date('27-07-2013', 'dd-mm-yyyy'), to_date('10-08-2013', 'dd-mm-yyyy'), 2, 8245, to_date('03-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717014366, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 1, 7862, to_date('26-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060220014367, to_date('20-02-2006', 'dd-mm-yyyy'), to_date('06-03-2006', 'dd-mm-yyyy'), 2, 5772, to_date('26-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120310014368, to_date('10-03-2012', 'dd-mm-yyyy'), to_date('24-03-2012', 'dd-mm-yyyy'), 2, 9459, to_date('24-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713014369, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 4, 6112, to_date('18-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926014370, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 4, 5930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050507014371, to_date('07-05-2005', 'dd-mm-yyyy'), to_date('21-05-2005', 'dd-mm-yyyy'), 2, 4449, to_date('26-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101213014372, to_date('13-12-2010', 'dd-mm-yyyy'), to_date('27-12-2010', 'dd-mm-yyyy'), 3, 9197, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100505014373, to_date('05-05-2010', 'dd-mm-yyyy'), to_date('19-05-2010', 'dd-mm-yyyy'), 2, 6136, to_date('20-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131028014374, to_date('28-10-2013', 'dd-mm-yyyy'), to_date('11-11-2013', 'dd-mm-yyyy'), 3, 9440, to_date('04-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040328014375, to_date('28-03-2004', 'dd-mm-yyyy'), to_date('11-04-2004', 'dd-mm-yyyy'), 2, 3966, to_date('09-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070701014376, to_date('01-07-2007', 'dd-mm-yyyy'), to_date('15-07-2007', 'dd-mm-yyyy'), 4, 4470, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922014377, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 4, 9793, to_date('12-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010210014378, to_date('10-02-2001', 'dd-mm-yyyy'), to_date('24-02-2001', 'dd-mm-yyyy'), 3, 2704, to_date('24-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020612014379, to_date('12-06-2002', 'dd-mm-yyyy'), to_date('26-06-2002', 'dd-mm-yyyy'), 4, 3052, to_date('22-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070604016903, to_date('04-06-2007', 'dd-mm-yyyy'), to_date('18-06-2007', 'dd-mm-yyyy'), 2, 7017, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061202016904, to_date('02-12-2006', 'dd-mm-yyyy'), to_date('16-12-2006', 'dd-mm-yyyy'), 1, 4775, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030728016905, to_date('28-07-2003', 'dd-mm-yyyy'), to_date('11-08-2003', 'dd-mm-yyyy'), 1, 1738, to_date('30-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130606016906, to_date('06-06-2013', 'dd-mm-yyyy'), to_date('20-06-2013', 'dd-mm-yyyy'), 1, 5360, to_date('10-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001106016907, to_date('06-11-2000', 'dd-mm-yyyy'), to_date('20-11-2000', 'dd-mm-yyyy'), 2, 2537, to_date('22-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100703016908, to_date('03-07-2010', 'dd-mm-yyyy'), to_date('17-07-2010', 'dd-mm-yyyy'), 1, 6311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010724016909, to_date('24-07-2001', 'dd-mm-yyyy'), to_date('07-08-2001', 'dd-mm-yyyy'), 1, 2399, to_date('02-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725016910, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 1, 2476, to_date('05-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020926016911, to_date('26-09-2002', 'dd-mm-yyyy'), to_date('10-10-2002', 'dd-mm-yyyy'), 1, 3902, to_date('09-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404016912, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 2, 6160, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061129016913, to_date('29-11-2006', 'dd-mm-yyyy'), to_date('13-12-2006', 'dd-mm-yyyy'), 2, 4277, to_date('16-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428016914, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 1, 4741, to_date('10-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090511016915, to_date('11-05-2009', 'dd-mm-yyyy'), to_date('25-05-2009', 'dd-mm-yyyy'), 1, 7377, to_date('28-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081205016916, to_date('05-12-2008', 'dd-mm-yyyy'), to_date('19-12-2008', 'dd-mm-yyyy'), 1, 5348, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121223016917, to_date('23-12-2012', 'dd-mm-yyyy'), to_date('06-01-2013', 'dd-mm-yyyy'), 1, 8750, to_date('03-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090415016918, to_date('15-04-2009', 'dd-mm-yyyy'), to_date('29-04-2009', 'dd-mm-yyyy'), 2, 5884, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051210016919, to_date('10-12-2005', 'dd-mm-yyyy'), to_date('24-12-2005', 'dd-mm-yyyy'), 1, 3412, to_date('15-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080210016920, to_date('10-02-2008', 'dd-mm-yyyy'), to_date('24-02-2008', 'dd-mm-yyyy'), 1, 5694, to_date('24-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070111016921, to_date('11-01-2007', 'dd-mm-yyyy'), to_date('25-01-2007', 'dd-mm-yyyy'), 1, 6718, to_date('14-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823016922, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 1, 9374, to_date('12-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206016923, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 2, 4455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120520016924, to_date('20-05-2012', 'dd-mm-yyyy'), to_date('03-06-2012', 'dd-mm-yyyy'), 2, 9378, to_date('04-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001016016925, to_date('16-10-2000', 'dd-mm-yyyy'), to_date('30-10-2000', 'dd-mm-yyyy'), 1, 1525, to_date('05-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020819016926, to_date('19-08-2002', 'dd-mm-yyyy'), to_date('02-09-2002', 'dd-mm-yyyy'), 2, 694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322016927, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 2, 3654, to_date('06-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080412016928, to_date('12-04-2008', 'dd-mm-yyyy'), to_date('26-04-2008', 'dd-mm-yyyy'), 1, 5641, to_date('28-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010109016929, to_date('09-01-2001', 'dd-mm-yyyy'), to_date('23-01-2001', 'dd-mm-yyyy'), 1, 2788, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040229016930, to_date('29-02-2004', 'dd-mm-yyyy'), to_date('14-03-2004', 'dd-mm-yyyy'), 1, 3234, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306016931, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 1, 5291, to_date('07-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000506016932, to_date('06-05-2000', 'dd-mm-yyyy'), to_date('20-05-2000', 'dd-mm-yyyy'), 1, 1236, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120408016933, to_date('08-04-2012', 'dd-mm-yyyy'), to_date('22-04-2012', 'dd-mm-yyyy'), 2, 10216, to_date('13-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131031016934, to_date('31-10-2013', 'dd-mm-yyyy'), to_date('14-11-2013', 'dd-mm-yyyy'), 2, 7448, to_date('07-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130516016935, to_date('16-05-2013', 'dd-mm-yyyy'), to_date('30-05-2013', 'dd-mm-yyyy'), 2, 8782, to_date('22-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222016936, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 1, 4240, to_date('03-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001224016937, to_date('24-12-2000', 'dd-mm-yyyy'), to_date('07-01-2001', 'dd-mm-yyyy'), 1, 1974, to_date('31-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031010016938, to_date('10-10-2003', 'dd-mm-yyyy'), to_date('24-10-2003', 'dd-mm-yyyy'), 2, 4364, to_date('29-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070304016939, to_date('04-03-2007', 'dd-mm-yyyy'), to_date('18-03-2007', 'dd-mm-yyyy'), 2, 4147, to_date('12-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071018016940, to_date('18-10-2007', 'dd-mm-yyyy'), to_date('01-11-2007', 'dd-mm-yyyy'), 2, 5155, to_date('06-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110805016941, to_date('05-08-2011', 'dd-mm-yyyy'), to_date('19-08-2011', 'dd-mm-yyyy'), 1, 8870, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040531016942, to_date('31-05-2004', 'dd-mm-yyyy'), to_date('14-06-2004', 'dd-mm-yyyy'), 2, 6874, to_date('09-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080812016943, to_date('12-08-2008', 'dd-mm-yyyy'), to_date('26-08-2008', 'dd-mm-yyyy'), 2, 5695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060528016944, to_date('28-05-2006', 'dd-mm-yyyy'), to_date('11-06-2006', 'dd-mm-yyyy'), 1, 6503, to_date('31-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061231016945, to_date('31-12-2006', 'dd-mm-yyyy'), to_date('14-01-2007', 'dd-mm-yyyy'), 2, 7201, to_date('16-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080117016946, to_date('17-01-2008', 'dd-mm-yyyy'), to_date('31-01-2008', 'dd-mm-yyyy'), 2, 3738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091211016947, to_date('11-12-2009', 'dd-mm-yyyy'), to_date('25-12-2009', 'dd-mm-yyyy'), 2, 6737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110909016948, to_date('09-09-2011', 'dd-mm-yyyy'), to_date('23-09-2011', 'dd-mm-yyyy'), 2, 6524, to_date('24-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020609016949, to_date('09-06-2002', 'dd-mm-yyyy'), to_date('23-06-2002', 'dd-mm-yyyy'), 2, 1618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000513016950, to_date('13-05-2000', 'dd-mm-yyyy'), to_date('27-05-2000', 'dd-mm-yyyy'), 2, 1184, to_date('16-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071121016951, to_date('21-11-2007', 'dd-mm-yyyy'), to_date('05-12-2007', 'dd-mm-yyyy'), 2, 4749, to_date('30-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130016952, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 2, 4171, to_date('14-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031112016953, to_date('12-11-2003', 'dd-mm-yyyy'), to_date('26-11-2003', 'dd-mm-yyyy'), 1, 4188, to_date('20-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060306016954, to_date('06-03-2006', 'dd-mm-yyyy'), to_date('20-03-2006', 'dd-mm-yyyy'), 2, 6948, to_date('12-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091114016955, to_date('14-11-2009', 'dd-mm-yyyy'), to_date('28-11-2009', 'dd-mm-yyyy'), 2, 4535, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221016956, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 1, 8553, to_date('22-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120016957, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 1, 6682, to_date('22-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826016958, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 2, 5390, to_date('12-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090511016959, to_date('11-05-2009', 'dd-mm-yyyy'), to_date('25-05-2009', 'dd-mm-yyyy'), 1, 6846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000611016960, to_date('11-06-2000', 'dd-mm-yyyy'), to_date('25-06-2000', 'dd-mm-yyyy'), 1, 2175, to_date('30-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000116016961, to_date('16-01-2000', 'dd-mm-yyyy'), to_date('30-01-2000', 'dd-mm-yyyy'), 1, 2017, to_date('22-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917016962, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 1, 6795, to_date('18-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203016963, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 1, 2707, to_date('15-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100701016964, to_date('01-07-2010', 'dd-mm-yyyy'), to_date('15-07-2010', 'dd-mm-yyyy'), 1, 7462, to_date('04-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130228016965, to_date('28-02-2013', 'dd-mm-yyyy'), to_date('14-03-2013', 'dd-mm-yyyy'), 1, 9198, to_date('09-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080525016966, to_date('25-05-2008', 'dd-mm-yyyy'), to_date('08-06-2008', 'dd-mm-yyyy'), 2, 7317, to_date('09-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090419016967, to_date('19-04-2009', 'dd-mm-yyyy'), to_date('03-05-2009', 'dd-mm-yyyy'), 2, 7172, to_date('22-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050523016968, to_date('23-05-2005', 'dd-mm-yyyy'), to_date('06-06-2005', 'dd-mm-yyyy'), 1, 5081, to_date('07-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050315016969, to_date('15-03-2005', 'dd-mm-yyyy'), to_date('29-03-2005', 'dd-mm-yyyy'), 1, 3770, to_date('31-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060628016970, to_date('28-06-2006', 'dd-mm-yyyy'), to_date('12-07-2006', 'dd-mm-yyyy'), 2, 6979, to_date('17-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060523016971, to_date('23-05-2006', 'dd-mm-yyyy'), to_date('06-06-2006', 'dd-mm-yyyy'), 2, 5170, to_date('04-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051003016972, to_date('03-10-2005', 'dd-mm-yyyy'), to_date('17-10-2005', 'dd-mm-yyyy'), 1, 4198, to_date('20-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031221016973, to_date('21-12-2003', 'dd-mm-yyyy'), to_date('04-01-2004', 'dd-mm-yyyy'), 2, 3135, to_date('03-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060325016974, to_date('25-03-2006', 'dd-mm-yyyy'), to_date('08-04-2006', 'dd-mm-yyyy'), 1, 3670, to_date('03-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708016975, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 2, 1952, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131126016976, to_date('26-11-2013', 'dd-mm-yyyy'), to_date('10-12-2013', 'dd-mm-yyyy'), 2, 9661, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101115016977, to_date('15-11-2010', 'dd-mm-yyyy'), to_date('29-11-2010', 'dd-mm-yyyy'), 1, 6765, to_date('05-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070618016978, to_date('18-06-2007', 'dd-mm-yyyy'), to_date('02-07-2007', 'dd-mm-yyyy'), 2, 3412, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117016979, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 2, 7446, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061226016980, to_date('26-12-2006', 'dd-mm-yyyy'), to_date('09-01-2007', 'dd-mm-yyyy'), 2, 3543, to_date('14-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040823016981, to_date('23-08-2004', 'dd-mm-yyyy'), to_date('06-09-2004', 'dd-mm-yyyy'), 1, 4260, to_date('28-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626016982, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 2, 7282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116016983, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 1, 10933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010226016984, to_date('26-02-2001', 'dd-mm-yyyy'), to_date('12-03-2001', 'dd-mm-yyyy'), 2, 2476, to_date('05-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622016985, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 2, 7052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010224016986, to_date('24-02-2001', 'dd-mm-yyyy'), to_date('10-03-2001', 'dd-mm-yyyy'), 1, 2438, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060328016987, to_date('28-03-2006', 'dd-mm-yyyy'), to_date('11-04-2006', 'dd-mm-yyyy'), 1, 3066, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806016988, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 1, 6072, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725016989, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 2, 8395, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120911016990, to_date('11-09-2012', 'dd-mm-yyyy'), to_date('25-09-2012', 'dd-mm-yyyy'), 2, 8654, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030508016991, to_date('08-05-2003', 'dd-mm-yyyy'), to_date('22-05-2003', 'dd-mm-yyyy'), 2, 2229, to_date('23-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090913016992, to_date('13-09-2009', 'dd-mm-yyyy'), to_date('27-09-2009', 'dd-mm-yyyy'), 1, 5239, to_date('03-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100824016993, to_date('24-08-2010', 'dd-mm-yyyy'), to_date('07-09-2010', 'dd-mm-yyyy'), 2, 6762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001207016994, to_date('07-12-2000', 'dd-mm-yyyy'), to_date('21-12-2000', 'dd-mm-yyyy'), 2, 2313, to_date('19-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140127016995, to_date('27-01-2014', 'dd-mm-yyyy'), to_date('10-02-2014', 'dd-mm-yyyy'), 2, 8319, to_date('28-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112016996, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 2, 6870, to_date('23-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071218016997, to_date('18-12-2007', 'dd-mm-yyyy'), to_date('01-01-2008', 'dd-mm-yyyy'), 1, 5523, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918016998, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 1, 4173, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060602016999, to_date('02-06-2006', 'dd-mm-yyyy'), to_date('16-06-2006', 'dd-mm-yyyy'), 1, 4946, to_date('12-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050426017000, to_date('26-04-2005', 'dd-mm-yyyy'), to_date('10-05-2005', 'dd-mm-yyyy'), 1, 5705, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040223017001, to_date('23-02-2004', 'dd-mm-yyyy'), to_date('08-03-2004', 'dd-mm-yyyy'), 1, 2885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901017002, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 2, 5113, to_date('18-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091222017003, to_date('22-12-2009', 'dd-mm-yyyy'), to_date('05-01-2010', 'dd-mm-yyyy'), 1, 7958, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120322017004, to_date('22-03-2012', 'dd-mm-yyyy'), to_date('05-04-2012', 'dd-mm-yyyy'), 1, 8088, to_date('30-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140224017005, to_date('24-02-2014', 'dd-mm-yyyy'), to_date('10-03-2014', 'dd-mm-yyyy'), 1, 7101, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008017006, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 1, 6030, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050401017007, to_date('01-04-2005', 'dd-mm-yyyy'), to_date('15-04-2005', 'dd-mm-yyyy'), 1, 5188, to_date('15-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070513017008, to_date('13-05-2007', 'dd-mm-yyyy'), to_date('27-05-2007', 'dd-mm-yyyy'), 1, 3936, to_date('01-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090326017009, to_date('26-03-2009', 'dd-mm-yyyy'), to_date('09-04-2009', 'dd-mm-yyyy'), 2, 8015, to_date('08-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221017010, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 2, 3422, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001017011, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 2, 1428, to_date('09-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060127017012, to_date('27-01-2006', 'dd-mm-yyyy'), to_date('10-02-2006', 'dd-mm-yyyy'), 1, 7560, to_date('03-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000331017013, to_date('31-03-2000', 'dd-mm-yyyy'), to_date('14-04-2000', 'dd-mm-yyyy'), 2, 4492, to_date('11-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080911017014, to_date('11-09-2008', 'dd-mm-yyyy'), to_date('25-09-2008', 'dd-mm-yyyy'), 2, 6675, to_date('25-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080524017015, to_date('24-05-2008', 'dd-mm-yyyy'), to_date('07-06-2008', 'dd-mm-yyyy'), 2, 6670, to_date('29-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111224017016, to_date('24-12-2011', 'dd-mm-yyyy'), to_date('07-01-2012', 'dd-mm-yyyy'), 1, 6692, to_date('26-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030210017017, to_date('10-02-2003', 'dd-mm-yyyy'), to_date('24-02-2003', 'dd-mm-yyyy'), 1, 3641, to_date('21-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031015017018, to_date('15-10-2003', 'dd-mm-yyyy'), to_date('29-10-2003', 'dd-mm-yyyy'), 1, 3377, to_date('18-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130308017019, to_date('08-03-2013', 'dd-mm-yyyy'), to_date('22-03-2013', 'dd-mm-yyyy'), 1, 6416, to_date('24-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070901017020, to_date('01-09-2007', 'dd-mm-yyyy'), to_date('15-09-2007', 'dd-mm-yyyy'), 2, 9203, to_date('07-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120918017021, to_date('18-09-2012', 'dd-mm-yyyy'), to_date('02-10-2012', 'dd-mm-yyyy'), 2, 10541, to_date('22-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030211017022, to_date('11-02-2003', 'dd-mm-yyyy'), to_date('25-02-2003', 'dd-mm-yyyy'), 2, 3684, to_date('24-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051023017023, to_date('23-10-2005', 'dd-mm-yyyy'), to_date('06-11-2005', 'dd-mm-yyyy'), 2, 5805, to_date('12-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100313017024, to_date('13-03-2010', 'dd-mm-yyyy'), to_date('27-03-2010', 'dd-mm-yyyy'), 2, 4767, to_date('21-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051202017025, to_date('02-12-2005', 'dd-mm-yyyy'), to_date('16-12-2005', 'dd-mm-yyyy'), 2, 5297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626017026, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 1, 8021, to_date('29-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106017027, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 2, 6595, to_date('16-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001204017028, to_date('04-12-2000', 'dd-mm-yyyy'), to_date('18-12-2000', 'dd-mm-yyyy'), 1, 2098, to_date('15-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022017029, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 1, 2937, to_date('07-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108017030, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 1, 6249, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090114017031, to_date('14-01-2009', 'dd-mm-yyyy'), to_date('28-01-2009', 'dd-mm-yyyy'), 2, 7364, to_date('03-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040930017032, to_date('30-09-2004', 'dd-mm-yyyy'), to_date('14-10-2004', 'dd-mm-yyyy'), 2, 2979, to_date('19-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070627017033, to_date('27-06-2007', 'dd-mm-yyyy'), to_date('11-07-2007', 'dd-mm-yyyy'), 2, 7288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008017034, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 2, 2417, to_date('15-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021005017035, to_date('05-10-2002', 'dd-mm-yyyy'), to_date('19-10-2002', 'dd-mm-yyyy'), 1, 3579, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040504017036, to_date('04-05-2004', 'dd-mm-yyyy'), to_date('18-05-2004', 'dd-mm-yyyy'), 1, 2603, to_date('08-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071025017037, to_date('25-10-2007', 'dd-mm-yyyy'), to_date('08-11-2007', 'dd-mm-yyyy'), 2, 6033, to_date('01-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090125017038, to_date('25-01-2009', 'dd-mm-yyyy'), to_date('08-02-2009', 'dd-mm-yyyy'), 2, 8141, to_date('26-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030523017039, to_date('23-05-2003', 'dd-mm-yyyy'), to_date('06-06-2003', 'dd-mm-yyyy'), 2, 3767, to_date('29-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010404017040, to_date('04-04-2001', 'dd-mm-yyyy'), to_date('18-04-2001', 'dd-mm-yyyy'), 2, 2267, to_date('20-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729017041, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 1, 6024, to_date('05-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040429017042, to_date('29-04-2004', 'dd-mm-yyyy'), to_date('13-05-2004', 'dd-mm-yyyy'), 2, 4086, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100825017043, to_date('25-08-2010', 'dd-mm-yyyy'), to_date('08-09-2010', 'dd-mm-yyyy'), 1, 6116, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219017044, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 2, 4488, to_date('04-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081008017045, to_date('08-10-2008', 'dd-mm-yyyy'), to_date('22-10-2008', 'dd-mm-yyyy'), 2, 4937, to_date('27-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040618017046, to_date('18-06-2004', 'dd-mm-yyyy'), to_date('02-07-2004', 'dd-mm-yyyy'), 1, 4854, to_date('23-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130811017047, to_date('11-08-2013', 'dd-mm-yyyy'), to_date('25-08-2013', 'dd-mm-yyyy'), 1, 8042, to_date('25-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120706017048, to_date('06-07-2012', 'dd-mm-yyyy'), to_date('20-07-2012', 'dd-mm-yyyy'), 2, 7297, to_date('16-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091019017049, to_date('19-10-2009', 'dd-mm-yyyy'), to_date('02-11-2009', 'dd-mm-yyyy'), 2, 5223, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120808017050, to_date('08-08-2012', 'dd-mm-yyyy'), to_date('22-08-2012', 'dd-mm-yyyy'), 2, 11213, to_date('20-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130630017051, to_date('30-06-2013', 'dd-mm-yyyy'), to_date('14-07-2013', 'dd-mm-yyyy'), 2, 7628, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021205017052, to_date('05-12-2002', 'dd-mm-yyyy'), to_date('19-12-2002', 'dd-mm-yyyy'), 1, 3677, to_date('16-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813017053, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 2, 8327, to_date('02-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090301017054, to_date('01-03-2009', 'dd-mm-yyyy'), to_date('15-03-2009', 'dd-mm-yyyy'), 1, 6969, to_date('03-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020522017055, to_date('22-05-2002', 'dd-mm-yyyy'), to_date('05-06-2002', 'dd-mm-yyyy'), 1, 3433, to_date('02-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104017056, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 1, 6505, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110803017057, to_date('03-08-2011', 'dd-mm-yyyy'), to_date('17-08-2011', 'dd-mm-yyyy'), 2, 8474, to_date('14-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060917017058, to_date('17-09-2006', 'dd-mm-yyyy'), to_date('01-10-2006', 'dd-mm-yyyy'), 2, 5233, to_date('07-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091117017059, to_date('17-11-2009', 'dd-mm-yyyy'), to_date('01-12-2009', 'dd-mm-yyyy'), 1, 6091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090613017060, to_date('13-06-2009', 'dd-mm-yyyy'), to_date('27-06-2009', 'dd-mm-yyyy'), 2, 6886, to_date('27-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031124017061, to_date('24-11-2003', 'dd-mm-yyyy'), to_date('08-12-2003', 'dd-mm-yyyy'), 1, 4587, to_date('28-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021215017062, to_date('15-12-2002', 'dd-mm-yyyy'), to_date('29-12-2002', 'dd-mm-yyyy'), 1, 2124, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060628017063, to_date('28-06-2006', 'dd-mm-yyyy'), to_date('12-07-2006', 'dd-mm-yyyy'), 1, 4540, to_date('03-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116017064, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 1, 4646, to_date('22-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040509017065, to_date('09-05-2004', 'dd-mm-yyyy'), to_date('23-05-2004', 'dd-mm-yyyy'), 2, 2471, to_date('11-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041201017066, to_date('01-12-2004', 'dd-mm-yyyy'), to_date('15-12-2004', 'dd-mm-yyyy'), 1, 2955, to_date('03-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120803017067, to_date('03-08-2012', 'dd-mm-yyyy'), to_date('17-08-2012', 'dd-mm-yyyy'), 2, 7151, to_date('14-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020312017068, to_date('12-03-2002', 'dd-mm-yyyy'), to_date('26-03-2002', 'dd-mm-yyyy'), 1, 1799, to_date('20-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111217017069, to_date('17-12-2011', 'dd-mm-yyyy'), to_date('31-12-2011', 'dd-mm-yyyy'), 2, 8968, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030319017070, to_date('19-03-2003', 'dd-mm-yyyy'), to_date('02-04-2003', 'dd-mm-yyyy'), 1, 1900, to_date('02-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110610011517, to_date('10-06-2011', 'dd-mm-yyyy'), to_date('24-06-2011', 'dd-mm-yyyy'), 11, 9241, to_date('16-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031220011518, to_date('20-12-2003', 'dd-mm-yyyy'), to_date('03-01-2004', 'dd-mm-yyyy'), 6, 3673, to_date('07-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000203011519, to_date('03-02-2000', 'dd-mm-yyyy'), to_date('17-02-2000', 'dd-mm-yyyy'), 6, 1886, to_date('21-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331011520, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 6, 5036, to_date('17-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090306011521, to_date('06-03-2009', 'dd-mm-yyyy'), to_date('20-03-2009', 'dd-mm-yyyy'), 3, 7111, to_date('22-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627011522, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 4, 7052, to_date('11-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040811011523, to_date('11-08-2004', 'dd-mm-yyyy'), to_date('25-08-2004', 'dd-mm-yyyy'), 12, 2565, to_date('25-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129011524, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 6, 8460, to_date('04-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050413011525, to_date('13-04-2005', 'dd-mm-yyyy'), to_date('27-04-2005', 'dd-mm-yyyy'), 5, 2788, to_date('27-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010312011526, to_date('12-03-2001', 'dd-mm-yyyy'), to_date('26-03-2001', 'dd-mm-yyyy'), 11, 3184, to_date('30-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090203011527, to_date('03-02-2009', 'dd-mm-yyyy'), to_date('17-02-2009', 'dd-mm-yyyy'), 11, 5839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100415011528, to_date('15-04-2010', 'dd-mm-yyyy'), to_date('29-04-2010', 'dd-mm-yyyy'), 5, 6730, to_date('01-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040425011529, to_date('25-04-2004', 'dd-mm-yyyy'), to_date('09-05-2004', 'dd-mm-yyyy'), 2, 3893, to_date('09-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070104011530, to_date('04-01-2007', 'dd-mm-yyyy'), to_date('18-01-2007', 'dd-mm-yyyy'), 10, 4904, to_date('17-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100117011531, to_date('17-01-2010', 'dd-mm-yyyy'), to_date('31-01-2010', 'dd-mm-yyyy'), 7, 7159, to_date('02-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040611011532, to_date('11-06-2004', 'dd-mm-yyyy'), to_date('25-06-2004', 'dd-mm-yyyy'), 4, 5508, to_date('26-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000330011533, to_date('30-03-2000', 'dd-mm-yyyy'), to_date('13-04-2000', 'dd-mm-yyyy'), 8, 2620, to_date('07-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100319011534, to_date('19-03-2010', 'dd-mm-yyyy'), to_date('02-04-2010', 'dd-mm-yyyy'), 9, 6783, to_date('06-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022011535, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 11, 7504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100501011536, to_date('01-05-2010', 'dd-mm-yyyy'), to_date('15-05-2010', 'dd-mm-yyyy'), 10, 6284, to_date('11-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041114011537, to_date('14-11-2004', 'dd-mm-yyyy'), to_date('28-11-2004', 'dd-mm-yyyy'), 10, 4523, to_date('26-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070430011538, to_date('30-04-2007', 'dd-mm-yyyy'), to_date('14-05-2007', 'dd-mm-yyyy'), 7, 5728, to_date('17-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040419011539, to_date('19-04-2004', 'dd-mm-yyyy'), to_date('03-05-2004', 'dd-mm-yyyy'), 4, 3161, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130011540, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 3, 5369, to_date('11-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091212011541, to_date('12-12-2009', 'dd-mm-yyyy'), to_date('26-12-2009', 'dd-mm-yyyy'), 7, 5206, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030505011542, to_date('05-05-2003', 'dd-mm-yyyy'), to_date('19-05-2003', 'dd-mm-yyyy'), 9, 2826, to_date('11-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010403011543, to_date('03-04-2001', 'dd-mm-yyyy'), to_date('17-04-2001', 'dd-mm-yyyy'), 5, 1165, to_date('11-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001028011544, to_date('28-10-2000', 'dd-mm-yyyy'), to_date('11-11-2000', 'dd-mm-yyyy'), 9, 1302, to_date('14-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121011545, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 12, 1645, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040920011546, to_date('20-09-2004', 'dd-mm-yyyy'), to_date('04-10-2004', 'dd-mm-yyyy'), 11, 3267, to_date('29-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090928011547, to_date('28-09-2009', 'dd-mm-yyyy'), to_date('12-10-2009', 'dd-mm-yyyy'), 7, 8256, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115011548, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 3, 6866, to_date('16-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131225011549, to_date('25-12-2013', 'dd-mm-yyyy'), to_date('08-01-2014', 'dd-mm-yyyy'), 3, 9265, to_date('07-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090129011550, to_date('29-01-2009', 'dd-mm-yyyy'), to_date('12-02-2009', 'dd-mm-yyyy'), 1, 5895, to_date('01-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080816011551, to_date('16-08-2008', 'dd-mm-yyyy'), to_date('30-08-2008', 'dd-mm-yyyy'), 2, 6356, to_date('23-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080514011552, to_date('14-05-2008', 'dd-mm-yyyy'), to_date('28-05-2008', 'dd-mm-yyyy'), 8, 8596, to_date('02-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070224011553, to_date('24-02-2007', 'dd-mm-yyyy'), to_date('10-03-2007', 'dd-mm-yyyy'), 11, 7590, to_date('12-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070711011554, to_date('11-07-2007', 'dd-mm-yyyy'), to_date('25-07-2007', 'dd-mm-yyyy'), 8, 6381, to_date('17-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111201011555, to_date('01-12-2011', 'dd-mm-yyyy'), to_date('15-12-2011', 'dd-mm-yyyy'), 7, 8129, to_date('07-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111212011556, to_date('12-12-2011', 'dd-mm-yyyy'), to_date('26-12-2011', 'dd-mm-yyyy'), 2, 7609, to_date('16-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021124011557, to_date('24-11-2002', 'dd-mm-yyyy'), to_date('08-12-2002', 'dd-mm-yyyy'), 8, 4679, to_date('08-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000404011558, to_date('04-04-2000', 'dd-mm-yyyy'), to_date('18-04-2000', 'dd-mm-yyyy'), 10, 2158, to_date('13-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327011559, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 8, 6310, to_date('05-04-2008', 'dd-mm-yyyy'));
commit;
prompt 14000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081011011560, to_date('11-10-2008', 'dd-mm-yyyy'), to_date('25-10-2008', 'dd-mm-yyyy'), 2, 5833, to_date('23-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021216011561, to_date('16-12-2002', 'dd-mm-yyyy'), to_date('30-12-2002', 'dd-mm-yyyy'), 8, 2030, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207011562, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 2, 5647, to_date('26-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100901011563, to_date('01-09-2010', 'dd-mm-yyyy'), to_date('15-09-2010', 'dd-mm-yyyy'), 5, 10781, to_date('14-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070823011564, to_date('23-08-2007', 'dd-mm-yyyy'), to_date('06-09-2007', 'dd-mm-yyyy'), 8, 6264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080924011565, to_date('24-09-2008', 'dd-mm-yyyy'), to_date('08-10-2008', 'dd-mm-yyyy'), 12, 4826, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031201011566, to_date('01-12-2003', 'dd-mm-yyyy'), to_date('15-12-2003', 'dd-mm-yyyy'), 9, 4095, to_date('08-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930011567, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 7, 4335, to_date('10-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030818011568, to_date('18-08-2003', 'dd-mm-yyyy'), to_date('01-09-2003', 'dd-mm-yyyy'), 9, 1028, to_date('23-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140325011569, to_date('25-03-2014', 'dd-mm-yyyy'), to_date('08-04-2014', 'dd-mm-yyyy'), 9, 10964, to_date('10-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040125011570, to_date('25-01-2004', 'dd-mm-yyyy'), to_date('08-02-2004', 'dd-mm-yyyy'), 2, 2625, to_date('05-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021006011571, to_date('06-10-2002', 'dd-mm-yyyy'), to_date('20-10-2002', 'dd-mm-yyyy'), 3, 2772, to_date('22-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130227011572, to_date('27-02-2013', 'dd-mm-yyyy'), to_date('13-03-2013', 'dd-mm-yyyy'), 2, 10023, to_date('01-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010527011573, to_date('27-05-2001', 'dd-mm-yyyy'), to_date('10-06-2001', 'dd-mm-yyyy'), 2, 1056, to_date('02-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080503011574, to_date('03-05-2008', 'dd-mm-yyyy'), to_date('17-05-2008', 'dd-mm-yyyy'), 1, 4812, to_date('11-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030119011575, to_date('19-01-2003', 'dd-mm-yyyy'), to_date('02-02-2003', 'dd-mm-yyyy'), 5, 6216, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051222011576, to_date('22-12-2005', 'dd-mm-yyyy'), to_date('05-01-2006', 'dd-mm-yyyy'), 6, 4457, to_date('03-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090803011577, to_date('03-08-2009', 'dd-mm-yyyy'), to_date('17-08-2009', 'dd-mm-yyyy'), 6, 6054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111011578, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 2, 11531, to_date('22-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130908011579, to_date('08-09-2013', 'dd-mm-yyyy'), to_date('22-09-2013', 'dd-mm-yyyy'), 2, 7474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021218011580, to_date('18-12-2002', 'dd-mm-yyyy'), to_date('01-01-2003', 'dd-mm-yyyy'), 11, 2405, to_date('04-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101011581, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 10, 3697, to_date('04-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709011582, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 6, 8322, to_date('21-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090830011583, to_date('30-08-2009', 'dd-mm-yyyy'), to_date('13-09-2009', 'dd-mm-yyyy'), 4, 5174, to_date('07-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110111011584, to_date('11-01-2011', 'dd-mm-yyyy'), to_date('25-01-2011', 'dd-mm-yyyy'), 11, 7308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120115011585, to_date('15-01-2012', 'dd-mm-yyyy'), to_date('29-01-2012', 'dd-mm-yyyy'), 2, 9655, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041113011586, to_date('13-11-2004', 'dd-mm-yyyy'), to_date('27-11-2004', 'dd-mm-yyyy'), 9, 2795, to_date('22-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090310011587, to_date('10-03-2009', 'dd-mm-yyyy'), to_date('24-03-2009', 'dd-mm-yyyy'), 7, 9226, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041230011588, to_date('30-12-2004', 'dd-mm-yyyy'), to_date('13-01-2005', 'dd-mm-yyyy'), 9, 4121, to_date('13-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061021011589, to_date('21-10-2006', 'dd-mm-yyyy'), to_date('04-11-2006', 'dd-mm-yyyy'), 3, 6044, to_date('05-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020725011590, to_date('25-07-2002', 'dd-mm-yyyy'), to_date('08-08-2002', 'dd-mm-yyyy'), 9, 2483, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090218011591, to_date('18-02-2009', 'dd-mm-yyyy'), to_date('04-03-2009', 'dd-mm-yyyy'), 6, 7784, to_date('23-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051014011592, to_date('14-10-2005', 'dd-mm-yyyy'), to_date('28-10-2005', 'dd-mm-yyyy'), 10, 5418, to_date('21-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000825011593, to_date('25-08-2000', 'dd-mm-yyyy'), to_date('08-09-2000', 'dd-mm-yyyy'), 6, 1260, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020403011594, to_date('03-04-2002', 'dd-mm-yyyy'), to_date('17-04-2002', 'dd-mm-yyyy'), 2, 3462, to_date('18-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001011595, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 8, 3066, to_date('03-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000324011596, to_date('24-03-2000', 'dd-mm-yyyy'), to_date('07-04-2000', 'dd-mm-yyyy'), 3, 2470, to_date('03-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060203011597, to_date('03-02-2006', 'dd-mm-yyyy'), to_date('17-02-2006', 'dd-mm-yyyy'), 5, 5035, to_date('22-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011207011598, to_date('07-12-2001', 'dd-mm-yyyy'), to_date('21-12-2001', 'dd-mm-yyyy'), 4, 2012, to_date('12-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080528011599, to_date('28-05-2008', 'dd-mm-yyyy'), to_date('11-06-2008', 'dd-mm-yyyy'), 6, 7347, to_date('02-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110508011600, to_date('08-05-2011', 'dd-mm-yyyy'), to_date('22-05-2011', 'dd-mm-yyyy'), 8, 8670, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020513011601, to_date('13-05-2002', 'dd-mm-yyyy'), to_date('27-05-2002', 'dd-mm-yyyy'), 7, 2640, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090102011602, to_date('02-01-2009', 'dd-mm-yyyy'), to_date('16-01-2009', 'dd-mm-yyyy'), 8, 7820, to_date('16-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100111011603, to_date('11-01-2010', 'dd-mm-yyyy'), to_date('25-01-2010', 'dd-mm-yyyy'), 6, 4578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020630011604, to_date('30-06-2002', 'dd-mm-yyyy'), to_date('14-07-2002', 'dd-mm-yyyy'), 4, 3052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120424011605, to_date('24-04-2012', 'dd-mm-yyyy'), to_date('08-05-2012', 'dd-mm-yyyy'), 4, 6696, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020306011606, to_date('06-03-2002', 'dd-mm-yyyy'), to_date('20-03-2002', 'dd-mm-yyyy'), 2, 3112, to_date('17-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070820011607, to_date('20-08-2007', 'dd-mm-yyyy'), to_date('03-09-2007', 'dd-mm-yyyy'), 7, 2616, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218011608, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 10, 2799, to_date('05-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071129011609, to_date('29-11-2007', 'dd-mm-yyyy'), to_date('13-12-2007', 'dd-mm-yyyy'), 6, 6718, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100607011610, to_date('07-06-2010', 'dd-mm-yyyy'), to_date('21-06-2010', 'dd-mm-yyyy'), 5, 7904, to_date('10-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903011611, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 2, 1896, to_date('12-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090125011612, to_date('25-01-2009', 'dd-mm-yyyy'), to_date('08-02-2009', 'dd-mm-yyyy'), 7, 7059, to_date('03-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020301011613, to_date('01-03-2002', 'dd-mm-yyyy'), to_date('15-03-2002', 'dd-mm-yyyy'), 6, 1502, to_date('13-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010813011614, to_date('13-08-2001', 'dd-mm-yyyy'), to_date('27-08-2001', 'dd-mm-yyyy'), 6, 2397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061015011615, to_date('15-10-2006', 'dd-mm-yyyy'), to_date('29-10-2006', 'dd-mm-yyyy'), 3, 3782, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020616011616, to_date('16-06-2002', 'dd-mm-yyyy'), to_date('30-06-2002', 'dd-mm-yyyy'), 7, 4181, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130513011617, to_date('13-05-2013', 'dd-mm-yyyy'), to_date('27-05-2013', 'dd-mm-yyyy'), 10, 11148, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020530011618, to_date('30-05-2002', 'dd-mm-yyyy'), to_date('13-06-2002', 'dd-mm-yyyy'), 9, 4343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040513011619, to_date('13-05-2004', 'dd-mm-yyyy'), to_date('27-05-2004', 'dd-mm-yyyy'), 6, 3292, to_date('29-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070915011620, to_date('15-09-2007', 'dd-mm-yyyy'), to_date('29-09-2007', 'dd-mm-yyyy'), 8, 5544, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120527011621, to_date('27-05-2012', 'dd-mm-yyyy'), to_date('10-06-2012', 'dd-mm-yyyy'), 3, 9999, to_date('04-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030109011622, to_date('09-01-2003', 'dd-mm-yyyy'), to_date('23-01-2003', 'dd-mm-yyyy'), 6, 3520, to_date('24-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010402011623, to_date('02-04-2001', 'dd-mm-yyyy'), to_date('16-04-2001', 'dd-mm-yyyy'), 12, 1126, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110505011624, to_date('05-05-2011', 'dd-mm-yyyy'), to_date('19-05-2011', 'dd-mm-yyyy'), 9, 8731, to_date('24-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100528011625, to_date('28-05-2010', 'dd-mm-yyyy'), to_date('11-06-2010', 'dd-mm-yyyy'), 10, 4745, to_date('07-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100811011626, to_date('11-08-2010', 'dd-mm-yyyy'), to_date('25-08-2010', 'dd-mm-yyyy'), 9, 8224, to_date('21-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100112011627, to_date('12-01-2010', 'dd-mm-yyyy'), to_date('26-01-2010', 'dd-mm-yyyy'), 5, 9944, to_date('19-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051204011628, to_date('04-12-2005', 'dd-mm-yyyy'), to_date('18-12-2005', 'dd-mm-yyyy'), 10, 3991, to_date('09-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040915011629, to_date('15-09-2004', 'dd-mm-yyyy'), to_date('29-09-2004', 'dd-mm-yyyy'), 8, 2999, to_date('27-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070322011630, to_date('22-03-2007', 'dd-mm-yyyy'), to_date('05-04-2007', 'dd-mm-yyyy'), 5, 5944, to_date('25-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030220011631, to_date('20-02-2003', 'dd-mm-yyyy'), to_date('06-03-2003', 'dd-mm-yyyy'), 3, 3257, to_date('10-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020210011632, to_date('10-02-2002', 'dd-mm-yyyy'), to_date('24-02-2002', 'dd-mm-yyyy'), 9, 1719, to_date('20-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081216011633, to_date('16-12-2008', 'dd-mm-yyyy'), to_date('30-12-2008', 'dd-mm-yyyy'), 1, 6904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000930011634, to_date('30-09-2000', 'dd-mm-yyyy'), to_date('14-10-2000', 'dd-mm-yyyy'), 4, 1698, to_date('12-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023011635, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 3, 1429, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130818011636, to_date('18-08-2013', 'dd-mm-yyyy'), to_date('01-09-2013', 'dd-mm-yyyy'), 4, 9756, to_date('26-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090519011637, to_date('19-05-2009', 'dd-mm-yyyy'), to_date('02-06-2009', 'dd-mm-yyyy'), 9, 6237, to_date('23-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080729011638, to_date('29-07-2008', 'dd-mm-yyyy'), to_date('12-08-2008', 'dd-mm-yyyy'), 12, 4551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050607011639, to_date('07-06-2005', 'dd-mm-yyyy'), to_date('21-06-2005', 'dd-mm-yyyy'), 5, 3677, to_date('26-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620011640, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 2, 4074, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517011641, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 11, 6947, to_date('28-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071127011642, to_date('27-11-2007', 'dd-mm-yyyy'), to_date('11-12-2007', 'dd-mm-yyyy'), 1, 4821, to_date('07-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013011643, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 11, 2556, to_date('26-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110809011644, to_date('09-08-2011', 'dd-mm-yyyy'), to_date('23-08-2011', 'dd-mm-yyyy'), 11, 6032, to_date('29-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120816011645, to_date('16-08-2012', 'dd-mm-yyyy'), to_date('30-08-2012', 'dd-mm-yyyy'), 1, 9554, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051012011646, to_date('12-10-2005', 'dd-mm-yyyy'), to_date('26-10-2005', 'dd-mm-yyyy'), 8, 5317, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080731011647, to_date('31-07-2008', 'dd-mm-yyyy'), to_date('14-08-2008', 'dd-mm-yyyy'), 7, 6724, to_date('16-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030216011648, to_date('16-02-2003', 'dd-mm-yyyy'), to_date('02-03-2003', 'dd-mm-yyyy'), 10, 2501, to_date('28-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010802011649, to_date('02-08-2001', 'dd-mm-yyyy'), to_date('16-08-2001', 'dd-mm-yyyy'), 3, 2280, to_date('06-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000312011650, to_date('12-03-2000', 'dd-mm-yyyy'), to_date('26-03-2000', 'dd-mm-yyyy'), 10, 1980, to_date('27-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110502011651, to_date('02-05-2011', 'dd-mm-yyyy'), to_date('16-05-2011', 'dd-mm-yyyy'), 6, 9339, to_date('21-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000805011652, to_date('05-08-2000', 'dd-mm-yyyy'), to_date('19-08-2000', 'dd-mm-yyyy'), 5, 1133, to_date('06-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061222011653, to_date('22-12-2006', 'dd-mm-yyyy'), to_date('05-01-2007', 'dd-mm-yyyy'), 4, 3871, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010418011654, to_date('18-04-2001', 'dd-mm-yyyy'), to_date('02-05-2001', 'dd-mm-yyyy'), 9, 3040, to_date('29-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016011655, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 6, 7563, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061204011656, to_date('04-12-2006', 'dd-mm-yyyy'), to_date('18-12-2006', 'dd-mm-yyyy'), 9, 5504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120803011657, to_date('03-08-2012', 'dd-mm-yyyy'), to_date('17-08-2012', 'dd-mm-yyyy'), 6, 7661, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010202011658, to_date('02-02-2001', 'dd-mm-yyyy'), to_date('16-02-2001', 'dd-mm-yyyy'), 2, 1502, to_date('04-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070918011659, to_date('18-09-2007', 'dd-mm-yyyy'), to_date('02-10-2007', 'dd-mm-yyyy'), 7, 6871, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110205011660, to_date('05-02-2011', 'dd-mm-yyyy'), to_date('19-02-2011', 'dd-mm-yyyy'), 1, 8377, to_date('21-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020629011661, to_date('29-06-2002', 'dd-mm-yyyy'), to_date('13-07-2002', 'dd-mm-yyyy'), 11, 2607, to_date('13-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405011662, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 7, 2240, to_date('19-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130717011663, to_date('17-07-2013', 'dd-mm-yyyy'), to_date('31-07-2013', 'dd-mm-yyyy'), 10, 8189, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101209011664, to_date('09-12-2010', 'dd-mm-yyyy'), to_date('23-12-2010', 'dd-mm-yyyy'), 12, 9583, to_date('25-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050728011665, to_date('28-07-2005', 'dd-mm-yyyy'), to_date('11-08-2005', 'dd-mm-yyyy'), 5, 4503, to_date('15-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060827011666, to_date('27-08-2006', 'dd-mm-yyyy'), to_date('10-09-2006', 'dd-mm-yyyy'), 3, 5570, to_date('28-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101108011667, to_date('08-11-2010', 'dd-mm-yyyy'), to_date('22-11-2010', 'dd-mm-yyyy'), 1, 6067, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100918011668, to_date('18-09-2010', 'dd-mm-yyyy'), to_date('02-10-2010', 'dd-mm-yyyy'), 11, 5604, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130417011669, to_date('17-04-2013', 'dd-mm-yyyy'), to_date('01-05-2013', 'dd-mm-yyyy'), 2, 7187, to_date('02-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050522011670, to_date('22-05-2005', 'dd-mm-yyyy'), to_date('05-06-2005', 'dd-mm-yyyy'), 5, 3469, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000305011671, to_date('05-03-2000', 'dd-mm-yyyy'), to_date('19-03-2000', 'dd-mm-yyyy'), 2, 1729, to_date('19-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070823011672, to_date('23-08-2007', 'dd-mm-yyyy'), to_date('06-09-2007', 'dd-mm-yyyy'), 4, 7089, to_date('24-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020818011673, to_date('18-08-2002', 'dd-mm-yyyy'), to_date('01-09-2002', 'dd-mm-yyyy'), 11, 2952, to_date('02-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101211011674, to_date('11-12-2010', 'dd-mm-yyyy'), to_date('25-12-2010', 'dd-mm-yyyy'), 7, 8527, to_date('16-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090127011675, to_date('27-01-2009', 'dd-mm-yyyy'), to_date('10-02-2009', 'dd-mm-yyyy'), 7, 8850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060723011676, to_date('23-07-2006', 'dd-mm-yyyy'), to_date('06-08-2006', 'dd-mm-yyyy'), 9, 4828, to_date('02-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050720011677, to_date('20-07-2005', 'dd-mm-yyyy'), to_date('03-08-2005', 'dd-mm-yyyy'), 8, 4914, to_date('22-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110206011678, to_date('06-02-2011', 'dd-mm-yyyy'), to_date('20-02-2011', 'dd-mm-yyyy'), 10, 7841, to_date('08-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121129011679, to_date('29-11-2012', 'dd-mm-yyyy'), to_date('13-12-2012', 'dd-mm-yyyy'), 4, 6703, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130226011680, to_date('26-02-2013', 'dd-mm-yyyy'), to_date('12-03-2013', 'dd-mm-yyyy'), 4, 7790, to_date('11-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040423011681, to_date('23-04-2004', 'dd-mm-yyyy'), to_date('07-05-2004', 'dd-mm-yyyy'), 3, 1956, to_date('07-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090919011682, to_date('19-09-2009', 'dd-mm-yyyy'), to_date('03-10-2009', 'dd-mm-yyyy'), 10, 5301, to_date('04-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090331011683, to_date('31-03-2009', 'dd-mm-yyyy'), to_date('14-04-2009', 'dd-mm-yyyy'), 8, 6169, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131014011684, to_date('14-10-2013', 'dd-mm-yyyy'), to_date('28-10-2013', 'dd-mm-yyyy'), 7, 6656, to_date('26-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130014380, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 1, 4054, to_date('03-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050525014381, to_date('25-05-2005', 'dd-mm-yyyy'), to_date('08-06-2005', 'dd-mm-yyyy'), 3, 4344, to_date('12-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628014382, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 2, 3132, to_date('01-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080520014383, to_date('20-05-2008', 'dd-mm-yyyy'), to_date('03-06-2008', 'dd-mm-yyyy'), 3, 6499, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810014384, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 2, 5217, to_date('12-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110223014385, to_date('23-02-2011', 'dd-mm-yyyy'), to_date('09-03-2011', 'dd-mm-yyyy'), 2, 9619, to_date('03-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051129014386, to_date('29-11-2005', 'dd-mm-yyyy'), to_date('13-12-2005', 'dd-mm-yyyy'), 3, 4542, to_date('04-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050923014387, to_date('23-09-2005', 'dd-mm-yyyy'), to_date('07-10-2005', 'dd-mm-yyyy'), 3, 4369, to_date('05-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080722014388, to_date('22-07-2008', 'dd-mm-yyyy'), to_date('05-08-2008', 'dd-mm-yyyy'), 2, 6759, to_date('01-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322014389, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 1, 2998, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051010014390, to_date('10-10-2005', 'dd-mm-yyyy'), to_date('24-10-2005', 'dd-mm-yyyy'), 2, 3446, to_date('23-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071220014391, to_date('20-12-2007', 'dd-mm-yyyy'), to_date('03-01-2008', 'dd-mm-yyyy'), 1, 6737, to_date('27-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000819014392, to_date('19-08-2000', 'dd-mm-yyyy'), to_date('02-09-2000', 'dd-mm-yyyy'), 4, 1153, to_date('28-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000328014393, to_date('28-03-2000', 'dd-mm-yyyy'), to_date('11-04-2000', 'dd-mm-yyyy'), 1, 1546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140514014394, to_date('14-05-2014', 'dd-mm-yyyy'), to_date('28-05-2014', 'dd-mm-yyyy'), 1, 10120, to_date('25-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060416014395, to_date('16-04-2006', 'dd-mm-yyyy'), to_date('30-04-2006', 'dd-mm-yyyy'), 3, 3599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010701014396, to_date('01-07-2001', 'dd-mm-yyyy'), to_date('15-07-2001', 'dd-mm-yyyy'), 4, 2834, to_date('09-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081218014397, to_date('18-12-2008', 'dd-mm-yyyy'), to_date('01-01-2009', 'dd-mm-yyyy'), 2, 6108, to_date('27-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091027014398, to_date('27-10-2009', 'dd-mm-yyyy'), to_date('10-11-2009', 'dd-mm-yyyy'), 3, 6258, to_date('01-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061014014399, to_date('14-10-2006', 'dd-mm-yyyy'), to_date('28-10-2006', 'dd-mm-yyyy'), 2, 4637, to_date('31-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140114014400, to_date('14-01-2014', 'dd-mm-yyyy'), to_date('28-01-2014', 'dd-mm-yyyy'), 1, 8975, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060923014401, to_date('23-09-2006', 'dd-mm-yyyy'), to_date('07-10-2006', 'dd-mm-yyyy'), 1, 3681, to_date('06-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020923014402, to_date('23-09-2002', 'dd-mm-yyyy'), to_date('07-10-2002', 'dd-mm-yyyy'), 3, 3724, to_date('08-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110619014403, to_date('19-06-2011', 'dd-mm-yyyy'), to_date('03-07-2011', 'dd-mm-yyyy'), 2, 5986, to_date('03-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120409014404, to_date('09-04-2012', 'dd-mm-yyyy'), to_date('23-04-2012', 'dd-mm-yyyy'), 1, 7341, to_date('18-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516014405, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 3, 1807, to_date('30-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020813014406, to_date('13-08-2002', 'dd-mm-yyyy'), to_date('27-08-2002', 'dd-mm-yyyy'), 2, 923, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116014407, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 3, 8276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203014408, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 3, 3046, to_date('05-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040915014409, to_date('15-09-2004', 'dd-mm-yyyy'), to_date('29-09-2004', 'dd-mm-yyyy'), 4, 4302, to_date('02-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080418014410, to_date('18-04-2008', 'dd-mm-yyyy'), to_date('02-05-2008', 'dd-mm-yyyy'), 1, 3830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130705014411, to_date('05-07-2013', 'dd-mm-yyyy'), to_date('19-07-2013', 'dd-mm-yyyy'), 3, 8769, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020419014412, to_date('19-04-2002', 'dd-mm-yyyy'), to_date('03-05-2002', 'dd-mm-yyyy'), 3, 2657, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010604014413, to_date('04-06-2001', 'dd-mm-yyyy'), to_date('18-06-2001', 'dd-mm-yyyy'), 3, 3037, to_date('08-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040804014414, to_date('04-08-2004', 'dd-mm-yyyy'), to_date('18-08-2004', 'dd-mm-yyyy'), 4, 3654, to_date('13-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021010014415, to_date('10-10-2002', 'dd-mm-yyyy'), to_date('24-10-2002', 'dd-mm-yyyy'), 3, 2313, to_date('12-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030721014416, to_date('21-07-2003', 'dd-mm-yyyy'), to_date('04-08-2003', 'dd-mm-yyyy'), 1, 3831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000707014417, to_date('07-07-2000', 'dd-mm-yyyy'), to_date('21-07-2000', 'dd-mm-yyyy'), 4, 2338, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031210014418, to_date('10-12-2003', 'dd-mm-yyyy'), to_date('24-12-2003', 'dd-mm-yyyy'), 3, 5169, to_date('20-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090519014419, to_date('19-05-2009', 'dd-mm-yyyy'), to_date('02-06-2009', 'dd-mm-yyyy'), 3, 8130, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060211014420, to_date('11-02-2006', 'dd-mm-yyyy'), to_date('25-02-2006', 'dd-mm-yyyy'), 2, 3529, to_date('20-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021105014421, to_date('05-11-2002', 'dd-mm-yyyy'), to_date('19-11-2002', 'dd-mm-yyyy'), 2, 2444, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011214014422, to_date('14-12-2001', 'dd-mm-yyyy'), to_date('28-12-2001', 'dd-mm-yyyy'), 2, 2182, to_date('29-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070618014423, to_date('18-06-2007', 'dd-mm-yyyy'), to_date('02-07-2007', 'dd-mm-yyyy'), 2, 6034, to_date('30-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406014424, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 2, 6519, to_date('15-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140411014425, to_date('11-04-2014', 'dd-mm-yyyy'), to_date('25-04-2014', 'dd-mm-yyyy'), 2, 9135, to_date('14-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051123014426, to_date('23-11-2005', 'dd-mm-yyyy'), to_date('07-12-2005', 'dd-mm-yyyy'), 1, 4519, to_date('10-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030321014427, to_date('21-03-2003', 'dd-mm-yyyy'), to_date('04-04-2003', 'dd-mm-yyyy'), 3, 3965, to_date('29-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140508014428, to_date('08-05-2014', 'dd-mm-yyyy'), to_date('22-05-2014', 'dd-mm-yyyy'), 1, 10519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100708014429, to_date('08-07-2010', 'dd-mm-yyyy'), to_date('22-07-2010', 'dd-mm-yyyy'), 4, 7988, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091004014430, to_date('04-10-2009', 'dd-mm-yyyy'), to_date('18-10-2009', 'dd-mm-yyyy'), 1, 5206, to_date('06-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730014431, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 4, 7759, to_date('08-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106014432, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 3, 5365, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031022014433, to_date('22-10-2003', 'dd-mm-yyyy'), to_date('05-11-2003', 'dd-mm-yyyy'), 2, 3441, to_date('06-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101210014434, to_date('10-12-2010', 'dd-mm-yyyy'), to_date('24-12-2010', 'dd-mm-yyyy'), 4, 7986, to_date('20-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101018014435, to_date('18-10-2010', 'dd-mm-yyyy'), to_date('01-11-2010', 'dd-mm-yyyy'), 1, 6122, to_date('24-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050630014436, to_date('30-06-2005', 'dd-mm-yyyy'), to_date('14-07-2005', 'dd-mm-yyyy'), 4, 6320, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090918014437, to_date('18-09-2009', 'dd-mm-yyyy'), to_date('02-10-2009', 'dd-mm-yyyy'), 2, 6437, to_date('06-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140301014438, to_date('01-03-2014', 'dd-mm-yyyy'), to_date('15-03-2014', 'dd-mm-yyyy'), 1, 7291, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608014439, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 3, 5723, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040704014440, to_date('04-07-2004', 'dd-mm-yyyy'), to_date('18-07-2004', 'dd-mm-yyyy'), 4, 5394, to_date('22-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111211014441, to_date('11-12-2011', 'dd-mm-yyyy'), to_date('25-12-2011', 'dd-mm-yyyy'), 3, 4758, to_date('15-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090412014442, to_date('12-04-2009', 'dd-mm-yyyy'), to_date('26-04-2009', 'dd-mm-yyyy'), 1, 6991, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121205014443, to_date('05-12-2012', 'dd-mm-yyyy'), to_date('19-12-2012', 'dd-mm-yyyy'), 2, 8787, to_date('21-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000705014444, to_date('05-07-2000', 'dd-mm-yyyy'), to_date('19-07-2000', 'dd-mm-yyyy'), 2, 2951, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120501014445, to_date('01-05-2012', 'dd-mm-yyyy'), to_date('15-05-2012', 'dd-mm-yyyy'), 3, 6952, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010826014446, to_date('26-08-2001', 'dd-mm-yyyy'), to_date('09-09-2001', 'dd-mm-yyyy'), 3, 3251, to_date('05-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100413014447, to_date('13-04-2010', 'dd-mm-yyyy'), to_date('27-04-2010', 'dd-mm-yyyy'), 2, 7926, to_date('22-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050321014448, to_date('21-03-2005', 'dd-mm-yyyy'), to_date('04-04-2005', 'dd-mm-yyyy'), 2, 5252, to_date('25-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091008014449, to_date('08-10-2009', 'dd-mm-yyyy'), to_date('22-10-2009', 'dd-mm-yyyy'), 3, 8070, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110404014450, to_date('04-04-2011', 'dd-mm-yyyy'), to_date('18-04-2011', 'dd-mm-yyyy'), 4, 7735, to_date('20-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090226014451, to_date('26-02-2009', 'dd-mm-yyyy'), to_date('12-03-2009', 'dd-mm-yyyy'), 3, 6086, to_date('05-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130408014452, to_date('08-04-2013', 'dd-mm-yyyy'), to_date('22-04-2013', 'dd-mm-yyyy'), 3, 9973, to_date('14-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000510014453, to_date('10-05-2000', 'dd-mm-yyyy'), to_date('24-05-2000', 'dd-mm-yyyy'), 4, 2294, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080515014454, to_date('15-05-2008', 'dd-mm-yyyy'), to_date('29-05-2008', 'dd-mm-yyyy'), 2, 5998, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030617014455, to_date('17-06-2003', 'dd-mm-yyyy'), to_date('01-07-2003', 'dd-mm-yyyy'), 2, 3005, to_date('22-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070818014456, to_date('18-08-2007', 'dd-mm-yyyy'), to_date('01-09-2007', 'dd-mm-yyyy'), 2, 6642, to_date('05-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130308014457, to_date('08-03-2013', 'dd-mm-yyyy'), to_date('22-03-2013', 'dd-mm-yyyy'), 1, 10379, to_date('10-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090111014458, to_date('11-01-2009', 'dd-mm-yyyy'), to_date('25-01-2009', 'dd-mm-yyyy'), 2, 6098, to_date('23-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060325014459, to_date('25-03-2006', 'dd-mm-yyyy'), to_date('08-04-2006', 'dd-mm-yyyy'), 2, 5129, to_date('06-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080714014460, to_date('14-07-2008', 'dd-mm-yyyy'), to_date('28-07-2008', 'dd-mm-yyyy'), 2, 6219, to_date('31-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081212014461, to_date('12-12-2008', 'dd-mm-yyyy'), to_date('26-12-2008', 'dd-mm-yyyy'), 2, 7901, to_date('23-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060421014462, to_date('21-04-2006', 'dd-mm-yyyy'), to_date('05-05-2006', 'dd-mm-yyyy'), 3, 6600, to_date('02-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100326014463, to_date('26-03-2010', 'dd-mm-yyyy'), to_date('09-04-2010', 'dd-mm-yyyy'), 2, 7481, to_date('08-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021124014464, to_date('24-11-2002', 'dd-mm-yyyy'), to_date('08-12-2002', 'dd-mm-yyyy'), 1, 2717, to_date('10-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030927014465, to_date('27-09-2003', 'dd-mm-yyyy'), to_date('11-10-2003', 'dd-mm-yyyy'), 2, 3672, to_date('04-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120810014466, to_date('10-08-2012', 'dd-mm-yyyy'), to_date('24-08-2012', 'dd-mm-yyyy'), 3, 8410, to_date('27-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090616014467, to_date('16-06-2009', 'dd-mm-yyyy'), to_date('30-06-2009', 'dd-mm-yyyy'), 2, 7595, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040815014468, to_date('15-08-2004', 'dd-mm-yyyy'), to_date('29-08-2004', 'dd-mm-yyyy'), 3, 1652, to_date('29-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110514014469, to_date('14-05-2011', 'dd-mm-yyyy'), to_date('28-05-2011', 'dd-mm-yyyy'), 3, 9128, to_date('01-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031024014470, to_date('24-10-2003', 'dd-mm-yyyy'), to_date('07-11-2003', 'dd-mm-yyyy'), 1, 2452, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100525014471, to_date('25-05-2010', 'dd-mm-yyyy'), to_date('08-06-2010', 'dd-mm-yyyy'), 3, 9206, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121229014472, to_date('29-12-2012', 'dd-mm-yyyy'), to_date('12-01-2013', 'dd-mm-yyyy'), 3, 7834, to_date('07-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090827014473, to_date('27-08-2009', 'dd-mm-yyyy'), to_date('10-09-2009', 'dd-mm-yyyy'), 1, 4417, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110905014474, to_date('05-09-2011', 'dd-mm-yyyy'), to_date('19-09-2011', 'dd-mm-yyyy'), 3, 5782, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130122014475, to_date('22-01-2013', 'dd-mm-yyyy'), to_date('05-02-2013', 'dd-mm-yyyy'), 3, 10935, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110327014476, to_date('27-03-2011', 'dd-mm-yyyy'), to_date('10-04-2011', 'dd-mm-yyyy'), 2, 8433, to_date('14-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061219014477, to_date('19-12-2006', 'dd-mm-yyyy'), to_date('02-01-2007', 'dd-mm-yyyy'), 1, 3239, to_date('01-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110923014478, to_date('23-09-2011', 'dd-mm-yyyy'), to_date('07-10-2011', 'dd-mm-yyyy'), 4, 6302, to_date('11-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071126014479, to_date('26-11-2007', 'dd-mm-yyyy'), to_date('10-12-2007', 'dd-mm-yyyy'), 3, 6353, to_date('04-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130719014480, to_date('19-07-2013', 'dd-mm-yyyy'), to_date('02-08-2013', 'dd-mm-yyyy'), 3, 8254, to_date('27-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110107014481, to_date('07-01-2011', 'dd-mm-yyyy'), to_date('21-01-2011', 'dd-mm-yyyy'), 3, 6049, to_date('15-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020328014482, to_date('28-03-2002', 'dd-mm-yyyy'), to_date('11-04-2002', 'dd-mm-yyyy'), 4, 1180, to_date('30-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130811014483, to_date('11-08-2013', 'dd-mm-yyyy'), to_date('25-08-2013', 'dd-mm-yyyy'), 2, 10210, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101210014484, to_date('10-12-2010', 'dd-mm-yyyy'), to_date('24-12-2010', 'dd-mm-yyyy'), 4, 8343, to_date('12-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070808014485, to_date('08-08-2007', 'dd-mm-yyyy'), to_date('22-08-2007', 'dd-mm-yyyy'), 3, 5698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111215014486, to_date('15-12-2011', 'dd-mm-yyyy'), to_date('29-12-2011', 'dd-mm-yyyy'), 2, 9730, to_date('30-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140302014487, to_date('02-03-2014', 'dd-mm-yyyy'), to_date('16-03-2014', 'dd-mm-yyyy'), 4, 7070, to_date('14-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011202014488, to_date('02-12-2001', 'dd-mm-yyyy'), to_date('16-12-2001', 'dd-mm-yyyy'), 4, 2683, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225014489, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 1, 6675, to_date('07-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061204014490, to_date('04-12-2006', 'dd-mm-yyyy'), to_date('18-12-2006', 'dd-mm-yyyy'), 1, 5130, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060624014491, to_date('24-06-2006', 'dd-mm-yyyy'), to_date('08-07-2006', 'dd-mm-yyyy'), 3, 7262, to_date('07-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040109014492, to_date('09-01-2004', 'dd-mm-yyyy'), to_date('23-01-2004', 'dd-mm-yyyy'), 3, 4502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030828014493, to_date('28-08-2003', 'dd-mm-yyyy'), to_date('11-09-2003', 'dd-mm-yyyy'), 3, 3307, to_date('12-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050808014494, to_date('08-08-2005', 'dd-mm-yyyy'), to_date('22-08-2005', 'dd-mm-yyyy'), 2, 8596, to_date('11-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051026014495, to_date('26-10-2005', 'dd-mm-yyyy'), to_date('09-11-2005', 'dd-mm-yyyy'), 3, 3795, to_date('07-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808014496, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 4, 4059, to_date('21-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000411014497, to_date('11-04-2000', 'dd-mm-yyyy'), to_date('25-04-2000', 'dd-mm-yyyy'), 4, 2081, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090407014498, to_date('07-04-2009', 'dd-mm-yyyy'), to_date('21-04-2009', 'dd-mm-yyyy'), 1, 8272, to_date('20-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080905014499, to_date('05-09-2008', 'dd-mm-yyyy'), to_date('19-09-2008', 'dd-mm-yyyy'), 2, 7060, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011107014500, to_date('07-11-2001', 'dd-mm-yyyy'), to_date('21-11-2001', 'dd-mm-yyyy'), 2, 2666, to_date('17-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030222014501, to_date('22-02-2003', 'dd-mm-yyyy'), to_date('08-03-2003', 'dd-mm-yyyy'), 1, 2703, to_date('07-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040614014502, to_date('14-06-2004', 'dd-mm-yyyy'), to_date('28-06-2004', 'dd-mm-yyyy'), 4, 3370, to_date('20-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924014503, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 3, 3277, to_date('08-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050612014504, to_date('12-06-2005', 'dd-mm-yyyy'), to_date('26-06-2005', 'dd-mm-yyyy'), 2, 3837, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030906014505, to_date('06-09-2003', 'dd-mm-yyyy'), to_date('20-09-2003', 'dd-mm-yyyy'), 4, 4872, to_date('21-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000508014506, to_date('08-05-2000', 'dd-mm-yyyy'), to_date('22-05-2000', 'dd-mm-yyyy'), 3, 858, to_date('25-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060215014507, to_date('15-02-2006', 'dd-mm-yyyy'), to_date('01-03-2006', 'dd-mm-yyyy'), 3, 4404, to_date('01-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111014014508, to_date('14-10-2011', 'dd-mm-yyyy'), to_date('28-10-2011', 'dd-mm-yyyy'), 4, 7708, to_date('22-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070725014509, to_date('25-07-2007', 'dd-mm-yyyy'), to_date('08-08-2007', 'dd-mm-yyyy'), 2, 7400, to_date('07-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912014510, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 2, 4352, to_date('15-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322014511, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 1, 1698, to_date('06-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091205014512, to_date('05-12-2009', 'dd-mm-yyyy'), to_date('19-12-2009', 'dd-mm-yyyy'), 3, 6820, to_date('06-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041218014513, to_date('18-12-2004', 'dd-mm-yyyy'), to_date('01-01-2005', 'dd-mm-yyyy'), 2, 2834, to_date('22-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928014514, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 4, 7185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031003014515, to_date('03-10-2003', 'dd-mm-yyyy'), to_date('17-10-2003', 'dd-mm-yyyy'), 2, 4519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050909014516, to_date('09-09-2005', 'dd-mm-yyyy'), to_date('23-09-2005', 'dd-mm-yyyy'), 2, 4354, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515014517, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 4, 486, to_date('30-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129014518, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 2, 8469, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010607014519, to_date('07-06-2001', 'dd-mm-yyyy'), to_date('21-06-2001', 'dd-mm-yyyy'), 2, 3679, to_date('21-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010918014520, to_date('18-09-2001', 'dd-mm-yyyy'), to_date('02-10-2001', 'dd-mm-yyyy'), 3, 1728, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050108014521, to_date('08-01-2005', 'dd-mm-yyyy'), to_date('22-01-2005', 'dd-mm-yyyy'), 2, 4694, to_date('10-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020907014522, to_date('07-09-2002', 'dd-mm-yyyy'), to_date('21-09-2002', 'dd-mm-yyyy'), 2, 3604, to_date('17-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130501014523, to_date('01-05-2013', 'dd-mm-yyyy'), to_date('15-05-2013', 'dd-mm-yyyy'), 3, 10783, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110706014524, to_date('06-07-2011', 'dd-mm-yyyy'), to_date('20-07-2011', 'dd-mm-yyyy'), 2, 5872, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070823014525, to_date('23-08-2007', 'dd-mm-yyyy'), to_date('06-09-2007', 'dd-mm-yyyy'), 3, 5541, to_date('07-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021007014526, to_date('07-10-2002', 'dd-mm-yyyy'), to_date('21-10-2002', 'dd-mm-yyyy'), 3, 3230, to_date('16-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140316014527, to_date('16-03-2014', 'dd-mm-yyyy'), to_date('30-03-2014', 'dd-mm-yyyy'), 3, 11127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091202014528, to_date('02-12-2009', 'dd-mm-yyyy'), to_date('16-12-2009', 'dd-mm-yyyy'), 3, 8872, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060915014529, to_date('15-09-2006', 'dd-mm-yyyy'), to_date('29-09-2006', 'dd-mm-yyyy'), 3, 7038, to_date('03-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050422014530, to_date('22-04-2005', 'dd-mm-yyyy'), to_date('06-05-2005', 'dd-mm-yyyy'), 4, 4151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110218014531, to_date('18-02-2011', 'dd-mm-yyyy'), to_date('04-03-2011', 'dd-mm-yyyy'), 2, 7031, to_date('22-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915014532, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 3, 9025, to_date('26-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091007014533, to_date('07-10-2009', 'dd-mm-yyyy'), to_date('21-10-2009', 'dd-mm-yyyy'), 3, 6253, to_date('26-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020014534, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 3, 4167, to_date('01-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100622014535, to_date('22-06-2010', 'dd-mm-yyyy'), to_date('06-07-2010', 'dd-mm-yyyy'), 2, 5696, to_date('24-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215014536, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 2, 6333, to_date('02-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130103014537, to_date('03-01-2013', 'dd-mm-yyyy'), to_date('17-01-2013', 'dd-mm-yyyy'), 2, 10743, to_date('11-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000529014538, to_date('29-05-2000', 'dd-mm-yyyy'), to_date('12-06-2000', 'dd-mm-yyyy'), 3, 853, to_date('31-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723014539, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 1, 3380, to_date('27-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111214014540, to_date('14-12-2011', 'dd-mm-yyyy'), to_date('28-12-2011', 'dd-mm-yyyy'), 4, 7701, to_date('21-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000717014541, to_date('17-07-2000', 'dd-mm-yyyy'), to_date('31-07-2000', 'dd-mm-yyyy'), 3, 2167, to_date('06-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080204014542, to_date('04-02-2008', 'dd-mm-yyyy'), to_date('18-02-2008', 'dd-mm-yyyy'), 3, 4942, to_date('10-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000518014543, to_date('18-05-2000', 'dd-mm-yyyy'), to_date('01-06-2000', 'dd-mm-yyyy'), 3, 1910, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000701014544, to_date('01-07-2000', 'dd-mm-yyyy'), to_date('15-07-2000', 'dd-mm-yyyy'), 3, 1899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120421014545, to_date('21-04-2012', 'dd-mm-yyyy'), to_date('05-05-2012', 'dd-mm-yyyy'), 2, 7631, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902014546, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 3, 6266, to_date('08-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619014547, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 2, 2630, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030626014548, to_date('26-06-2003', 'dd-mm-yyyy'), to_date('10-07-2003', 'dd-mm-yyyy'), 3, 4217, to_date('30-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010017071, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 2, 6662, to_date('15-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050126017072, to_date('26-01-2005', 'dd-mm-yyyy'), to_date('09-02-2005', 'dd-mm-yyyy'), 1, 4769, to_date('04-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050921017073, to_date('21-09-2005', 'dd-mm-yyyy'), to_date('05-10-2005', 'dd-mm-yyyy'), 2, 3617, to_date('03-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127017074, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 2, 5831, to_date('11-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000826017075, to_date('26-08-2000', 'dd-mm-yyyy'), to_date('09-09-2000', 'dd-mm-yyyy'), 1, 780, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111005017076, to_date('05-10-2011', 'dd-mm-yyyy'), to_date('19-10-2011', 'dd-mm-yyyy'), 1, 6124, to_date('06-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120526017077, to_date('26-05-2012', 'dd-mm-yyyy'), to_date('09-06-2012', 'dd-mm-yyyy'), 1, 10081, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207017078, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 1, 2186, to_date('14-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000313017079, to_date('13-03-2000', 'dd-mm-yyyy'), to_date('27-03-2000', 'dd-mm-yyyy'), 2, 1424, to_date('20-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110918017080, to_date('18-09-2011', 'dd-mm-yyyy'), to_date('02-10-2011', 'dd-mm-yyyy'), 1, 6752, to_date('27-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090424017081, to_date('24-04-2009', 'dd-mm-yyyy'), to_date('08-05-2009', 'dd-mm-yyyy'), 2, 7009, to_date('02-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081029017082, to_date('29-10-2008', 'dd-mm-yyyy'), to_date('12-11-2008', 'dd-mm-yyyy'), 1, 5605, to_date('07-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010314017083, to_date('14-03-2001', 'dd-mm-yyyy'), to_date('28-03-2001', 'dd-mm-yyyy'), 2, 2661, to_date('19-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100927017084, to_date('27-09-2010', 'dd-mm-yyyy'), to_date('11-10-2010', 'dd-mm-yyyy'), 1, 7236, to_date('11-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121224017085, to_date('24-12-2012', 'dd-mm-yyyy'), to_date('07-01-2013', 'dd-mm-yyyy'), 1, 9125, to_date('27-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140214017086, to_date('14-02-2014', 'dd-mm-yyyy'), to_date('28-02-2014', 'dd-mm-yyyy'), 1, 8587, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060114017087, to_date('14-01-2006', 'dd-mm-yyyy'), to_date('28-01-2006', 'dd-mm-yyyy'), 2, 4441, to_date('25-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000913017088, to_date('13-09-2000', 'dd-mm-yyyy'), to_date('27-09-2000', 'dd-mm-yyyy'), 2, 2611, to_date('21-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080718017089, to_date('18-07-2008', 'dd-mm-yyyy'), to_date('01-08-2008', 'dd-mm-yyyy'), 2, 6239, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040216017090, to_date('16-02-2004', 'dd-mm-yyyy'), to_date('01-03-2004', 'dd-mm-yyyy'), 2, 3690, to_date('03-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120913017091, to_date('13-09-2012', 'dd-mm-yyyy'), to_date('27-09-2012', 'dd-mm-yyyy'), 1, 9783, to_date('20-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010514017092, to_date('14-05-2001', 'dd-mm-yyyy'), to_date('28-05-2001', 'dd-mm-yyyy'), 1, 4797, to_date('03-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011118017093, to_date('18-11-2001', 'dd-mm-yyyy'), to_date('02-12-2001', 'dd-mm-yyyy'), 1, 2410, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000210017094, to_date('10-02-2000', 'dd-mm-yyyy'), to_date('24-02-2000', 'dd-mm-yyyy'), 2, 1153, to_date('17-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131121017095, to_date('21-11-2013', 'dd-mm-yyyy'), to_date('05-12-2013', 'dd-mm-yyyy'), 1, 9687, to_date('02-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106017096, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 2, 3961, to_date('10-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040615017097, to_date('15-06-2004', 'dd-mm-yyyy'), to_date('29-06-2004', 'dd-mm-yyyy'), 2, 2862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000817017098, to_date('17-08-2000', 'dd-mm-yyyy'), to_date('31-08-2000', 'dd-mm-yyyy'), 1, 3360, to_date('24-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130428017099, to_date('28-04-2013', 'dd-mm-yyyy'), to_date('12-05-2013', 'dd-mm-yyyy'), 1, 8612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060711017100, to_date('11-07-2006', 'dd-mm-yyyy'), to_date('25-07-2006', 'dd-mm-yyyy'), 2, 4789, to_date('27-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131217017101, to_date('17-12-2013', 'dd-mm-yyyy'), to_date('31-12-2013', 'dd-mm-yyyy'), 1, 7352, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130318017102, to_date('18-03-2013', 'dd-mm-yyyy'), to_date('01-04-2013', 'dd-mm-yyyy'), 2, 7395, to_date('24-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050708017103, to_date('08-07-2005', 'dd-mm-yyyy'), to_date('22-07-2005', 'dd-mm-yyyy'), 2, 4443, to_date('27-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131124017104, to_date('24-11-2013', 'dd-mm-yyyy'), to_date('08-12-2013', 'dd-mm-yyyy'), 1, 7584, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090323017105, to_date('23-03-2009', 'dd-mm-yyyy'), to_date('06-04-2009', 'dd-mm-yyyy'), 2, 8181, to_date('10-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051031017106, to_date('31-10-2005', 'dd-mm-yyyy'), to_date('14-11-2005', 'dd-mm-yyyy'), 1, 2991, to_date('19-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041002017107, to_date('02-10-2004', 'dd-mm-yyyy'), to_date('16-10-2004', 'dd-mm-yyyy'), 1, 3950, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120420017108, to_date('20-04-2012', 'dd-mm-yyyy'), to_date('04-05-2012', 'dd-mm-yyyy'), 1, 8330, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110208017109, to_date('08-02-2011', 'dd-mm-yyyy'), to_date('22-02-2011', 'dd-mm-yyyy'), 2, 9180, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121210017110, to_date('10-12-2012', 'dd-mm-yyyy'), to_date('24-12-2012', 'dd-mm-yyyy'), 1, 8257, to_date('23-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081204017111, to_date('04-12-2008', 'dd-mm-yyyy'), to_date('18-12-2008', 'dd-mm-yyyy'), 2, 5899, to_date('19-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829017112, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 1, 3379, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030509017113, to_date('09-05-2003', 'dd-mm-yyyy'), to_date('23-05-2003', 'dd-mm-yyyy'), 2, 2821, to_date('14-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140211017114, to_date('11-02-2014', 'dd-mm-yyyy'), to_date('25-02-2014', 'dd-mm-yyyy'), 2, 11217, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426017115, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 2, 5482, to_date('09-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120122017116, to_date('22-01-2012', 'dd-mm-yyyy'), to_date('05-02-2012', 'dd-mm-yyyy'), 2, 5447, to_date('28-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120922017117, to_date('22-09-2012', 'dd-mm-yyyy'), to_date('06-10-2012', 'dd-mm-yyyy'), 2, 6723, to_date('09-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729017118, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 1, 7239, to_date('05-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020102017119, to_date('02-01-2002', 'dd-mm-yyyy'), to_date('16-01-2002', 'dd-mm-yyyy'), 1, 1420, to_date('04-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090524017120, to_date('24-05-2009', 'dd-mm-yyyy'), to_date('07-06-2009', 'dd-mm-yyyy'), 2, 4181, to_date('06-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140506017121, to_date('06-05-2014', 'dd-mm-yyyy'), to_date('20-05-2014', 'dd-mm-yyyy'), 2, 8654, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110929017122, to_date('29-09-2011', 'dd-mm-yyyy'), to_date('13-10-2011', 'dd-mm-yyyy'), 1, 10204, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100818017123, to_date('18-08-2010', 'dd-mm-yyyy'), to_date('01-09-2010', 'dd-mm-yyyy'), 1, 6771, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101121017124, to_date('21-11-2010', 'dd-mm-yyyy'), to_date('05-12-2010', 'dd-mm-yyyy'), 2, 9112, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605017125, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 1, 2250, to_date('08-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110818017126, to_date('18-08-2011', 'dd-mm-yyyy'), to_date('01-09-2011', 'dd-mm-yyyy'), 1, 9071, to_date('03-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040520017127, to_date('20-05-2004', 'dd-mm-yyyy'), to_date('03-06-2004', 'dd-mm-yyyy'), 2, 4970, to_date('24-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041219017128, to_date('19-12-2004', 'dd-mm-yyyy'), to_date('02-01-2005', 'dd-mm-yyyy'), 1, 1549, to_date('22-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817017129, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 2, 5638, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070728017130, to_date('28-07-2007', 'dd-mm-yyyy'), to_date('11-08-2007', 'dd-mm-yyyy'), 1, 2773, to_date('09-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429017131, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 2, 919, to_date('17-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081106017132, to_date('06-11-2008', 'dd-mm-yyyy'), to_date('20-11-2008', 'dd-mm-yyyy'), 1, 6899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100525017133, to_date('25-05-2010', 'dd-mm-yyyy'), to_date('08-06-2010', 'dd-mm-yyyy'), 2, 9710, to_date('07-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511017134, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 2, 2475, to_date('26-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050618017135, to_date('18-06-2005', 'dd-mm-yyyy'), to_date('02-07-2005', 'dd-mm-yyyy'), 2, 6679, to_date('25-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120527017136, to_date('27-05-2012', 'dd-mm-yyyy'), to_date('10-06-2012', 'dd-mm-yyyy'), 2, 7552, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030316017137, to_date('16-03-2003', 'dd-mm-yyyy'), to_date('30-03-2003', 'dd-mm-yyyy'), 1, 3611, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020607017138, to_date('07-06-2002', 'dd-mm-yyyy'), to_date('21-06-2002', 'dd-mm-yyyy'), 1, 1504, to_date('12-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101119017139, to_date('19-11-2010', 'dd-mm-yyyy'), to_date('03-12-2010', 'dd-mm-yyyy'), 2, 7292, to_date('08-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120823017140, to_date('23-08-2012', 'dd-mm-yyyy'), to_date('06-09-2012', 'dd-mm-yyyy'), 2, 9019, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080130017141, to_date('30-01-2008', 'dd-mm-yyyy'), to_date('13-02-2008', 'dd-mm-yyyy'), 1, 9746, to_date('06-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100307017142, to_date('07-03-2010', 'dd-mm-yyyy'), to_date('21-03-2010', 'dd-mm-yyyy'), 1, 8730, to_date('25-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425017143, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 2, 4311, to_date('04-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051227017144, to_date('27-12-2005', 'dd-mm-yyyy'), to_date('10-01-2006', 'dd-mm-yyyy'), 2, 2970, to_date('30-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204017145, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 2, 5945, to_date('21-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060105017146, to_date('05-01-2006', 'dd-mm-yyyy'), to_date('19-01-2006', 'dd-mm-yyyy'), 2, 5916, to_date('10-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070410017147, to_date('10-04-2007', 'dd-mm-yyyy'), to_date('24-04-2007', 'dd-mm-yyyy'), 2, 4279, to_date('17-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130316017148, to_date('16-03-2013', 'dd-mm-yyyy'), to_date('30-03-2013', 'dd-mm-yyyy'), 1, 8634, to_date('25-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101104017149, to_date('04-11-2010', 'dd-mm-yyyy'), to_date('18-11-2010', 'dd-mm-yyyy'), 2, 7447, to_date('17-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140123017150, to_date('23-01-2014', 'dd-mm-yyyy'), to_date('06-02-2014', 'dd-mm-yyyy'), 1, 9466, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120724017151, to_date('24-07-2012', 'dd-mm-yyyy'), to_date('07-08-2012', 'dd-mm-yyyy'), 2, 6445, to_date('02-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218017152, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 2, 9150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917017153, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 2, 8258, to_date('27-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120328017154, to_date('28-03-2012', 'dd-mm-yyyy'), to_date('11-04-2012', 'dd-mm-yyyy'), 2, 7597, to_date('08-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040429017155, to_date('29-04-2004', 'dd-mm-yyyy'), to_date('13-05-2004', 'dd-mm-yyyy'), 1, 5082, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421017156, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 2, 4991, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120628017157, to_date('28-06-2012', 'dd-mm-yyyy'), to_date('12-07-2012', 'dd-mm-yyyy'), 2, 4783, to_date('18-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090826017158, to_date('26-08-2009', 'dd-mm-yyyy'), to_date('09-09-2009', 'dd-mm-yyyy'), 1, 7423, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060331017159, to_date('31-03-2006', 'dd-mm-yyyy'), to_date('14-04-2006', 'dd-mm-yyyy'), 1, 4752, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120427017160, to_date('27-04-2012', 'dd-mm-yyyy'), to_date('11-05-2012', 'dd-mm-yyyy'), 2, 9761, to_date('15-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121101017161, to_date('01-11-2012', 'dd-mm-yyyy'), to_date('15-11-2012', 'dd-mm-yyyy'), 2, 11607, to_date('02-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090813017162, to_date('13-08-2009', 'dd-mm-yyyy'), to_date('27-08-2009', 'dd-mm-yyyy'), 1, 6422, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130425017163, to_date('25-04-2013', 'dd-mm-yyyy'), to_date('09-05-2013', 'dd-mm-yyyy'), 1, 8622, to_date('09-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011221017164, to_date('21-12-2001', 'dd-mm-yyyy'), to_date('04-01-2002', 'dd-mm-yyyy'), 2, 2538, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100515017165, to_date('15-05-2010', 'dd-mm-yyyy'), to_date('29-05-2010', 'dd-mm-yyyy'), 1, 6167, to_date('20-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318017166, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 2, 3848, to_date('27-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060922017167, to_date('22-09-2006', 'dd-mm-yyyy'), to_date('06-10-2006', 'dd-mm-yyyy'), 1, 5011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623017168, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 2, 2302, to_date('10-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060814017169, to_date('14-08-2006', 'dd-mm-yyyy'), to_date('28-08-2006', 'dd-mm-yyyy'), 2, 3764, to_date('26-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130629017170, to_date('29-06-2013', 'dd-mm-yyyy'), to_date('13-07-2013', 'dd-mm-yyyy'), 1, 9339, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530017171, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 1, 4896, to_date('14-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121102017172, to_date('02-11-2012', 'dd-mm-yyyy'), to_date('16-11-2012', 'dd-mm-yyyy'), 2, 7709, to_date('06-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100506017173, to_date('06-05-2010', 'dd-mm-yyyy'), to_date('20-05-2010', 'dd-mm-yyyy'), 2, 5863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709017174, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 1, 8359, to_date('20-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217017175, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 1, 2937, to_date('28-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110118017176, to_date('18-01-2011', 'dd-mm-yyyy'), to_date('01-02-2011', 'dd-mm-yyyy'), 1, 8548, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130508017177, to_date('08-05-2013', 'dd-mm-yyyy'), to_date('22-05-2013', 'dd-mm-yyyy'), 1, 8750, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070705017178, to_date('05-07-2007', 'dd-mm-yyyy'), to_date('19-07-2007', 'dd-mm-yyyy'), 2, 5336, to_date('14-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010914017179, to_date('14-09-2001', 'dd-mm-yyyy'), to_date('28-09-2001', 'dd-mm-yyyy'), 1, 2947, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120424017180, to_date('24-04-2012', 'dd-mm-yyyy'), to_date('08-05-2012', 'dd-mm-yyyy'), 2, 7068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140125017181, to_date('25-01-2014', 'dd-mm-yyyy'), to_date('08-02-2014', 'dd-mm-yyyy'), 1, 8490, to_date('08-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091126017182, to_date('26-11-2009', 'dd-mm-yyyy'), to_date('10-12-2009', 'dd-mm-yyyy'), 1, 6312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030806017183, to_date('06-08-2003', 'dd-mm-yyyy'), to_date('20-08-2003', 'dd-mm-yyyy'), 1, 2740, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120719017184, to_date('19-07-2012', 'dd-mm-yyyy'), to_date('02-08-2012', 'dd-mm-yyyy'), 1, 7954, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100410017185, to_date('10-04-2010', 'dd-mm-yyyy'), to_date('24-04-2010', 'dd-mm-yyyy'), 1, 8387, to_date('24-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070212017186, to_date('12-02-2007', 'dd-mm-yyyy'), to_date('26-02-2007', 'dd-mm-yyyy'), 1, 2971, to_date('23-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050703017187, to_date('03-07-2005', 'dd-mm-yyyy'), to_date('17-07-2005', 'dd-mm-yyyy'), 2, 5207, to_date('20-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030913017188, to_date('13-09-2003', 'dd-mm-yyyy'), to_date('27-09-2003', 'dd-mm-yyyy'), 2, 4455, to_date('23-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140325017189, to_date('25-03-2014', 'dd-mm-yyyy'), to_date('08-04-2014', 'dd-mm-yyyy'), 2, 9942, to_date('04-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040308017190, to_date('08-03-2004', 'dd-mm-yyyy'), to_date('22-03-2004', 'dd-mm-yyyy'), 1, 3315, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110017191, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 2, 1084, to_date('26-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326017192, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 1, 3488, to_date('08-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011030017193, to_date('30-10-2001', 'dd-mm-yyyy'), to_date('13-11-2001', 'dd-mm-yyyy'), 2, 2995, to_date('04-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050807017194, to_date('07-08-2005', 'dd-mm-yyyy'), to_date('21-08-2005', 'dd-mm-yyyy'), 2, 4565, to_date('12-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010608017195, to_date('08-06-2001', 'dd-mm-yyyy'), to_date('22-06-2001', 'dd-mm-yyyy'), 1, 720, to_date('20-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121209017196, to_date('09-12-2012', 'dd-mm-yyyy'), to_date('23-12-2012', 'dd-mm-yyyy'), 1, 8225, to_date('13-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091103017197, to_date('03-11-2009', 'dd-mm-yyyy'), to_date('17-11-2009', 'dd-mm-yyyy'), 2, 7061, to_date('08-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020329017198, to_date('29-03-2002', 'dd-mm-yyyy'), to_date('12-04-2002', 'dd-mm-yyyy'), 2, 4287, to_date('14-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103017199, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 2, 5836, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131005017200, to_date('05-10-2013', 'dd-mm-yyyy'), to_date('19-10-2013', 'dd-mm-yyyy'), 2, 8516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130118017201, to_date('18-01-2013', 'dd-mm-yyyy'), to_date('01-02-2013', 'dd-mm-yyyy'), 2, 6664, to_date('31-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110128017202, to_date('28-01-2011', 'dd-mm-yyyy'), to_date('11-02-2011', 'dd-mm-yyyy'), 1, 7068, to_date('13-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106017203, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 1, 5682, to_date('12-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000224017204, to_date('24-02-2000', 'dd-mm-yyyy'), to_date('09-03-2000', 'dd-mm-yyyy'), 1, 2012, to_date('09-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110509017205, to_date('09-05-2011', 'dd-mm-yyyy'), to_date('23-05-2011', 'dd-mm-yyyy'), 1, 5731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723017206, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 2, 2618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070820017207, to_date('20-08-2007', 'dd-mm-yyyy'), to_date('03-09-2007', 'dd-mm-yyyy'), 2, 6551, to_date('03-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330017208, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 1, 9867, to_date('04-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060413017209, to_date('13-04-2006', 'dd-mm-yyyy'), to_date('27-04-2006', 'dd-mm-yyyy'), 1, 4714, to_date('20-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090311017210, to_date('11-03-2009', 'dd-mm-yyyy'), to_date('25-03-2009', 'dd-mm-yyyy'), 1, 7128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000304017211, to_date('04-03-2000', 'dd-mm-yyyy'), to_date('18-03-2000', 'dd-mm-yyyy'), 1, 2415, to_date('10-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100730017212, to_date('30-07-2010', 'dd-mm-yyyy'), to_date('13-08-2010', 'dd-mm-yyyy'), 2, 8164, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010407017213, to_date('07-04-2001', 'dd-mm-yyyy'), to_date('21-04-2001', 'dd-mm-yyyy'), 2, 3727, to_date('21-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130831017214, to_date('31-08-2013', 'dd-mm-yyyy'), to_date('14-09-2013', 'dd-mm-yyyy'), 1, 8606, to_date('12-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130703017215, to_date('03-07-2013', 'dd-mm-yyyy'), to_date('17-07-2013', 'dd-mm-yyyy'), 1, 9668, to_date('16-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031020017216, to_date('20-10-2003', 'dd-mm-yyyy'), to_date('03-11-2003', 'dd-mm-yyyy'), 1, 3434, to_date('27-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725017217, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 1, 4756, to_date('07-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100329017218, to_date('29-03-2010', 'dd-mm-yyyy'), to_date('12-04-2010', 'dd-mm-yyyy'), 2, 7618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060909017219, to_date('09-09-2006', 'dd-mm-yyyy'), to_date('23-09-2006', 'dd-mm-yyyy'), 1, 4077, to_date('23-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071202017220, to_date('02-12-2007', 'dd-mm-yyyy'), to_date('16-12-2007', 'dd-mm-yyyy'), 1, 6678, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100312017221, to_date('12-03-2010', 'dd-mm-yyyy'), to_date('26-03-2010', 'dd-mm-yyyy'), 2, 6198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010412017222, to_date('12-04-2001', 'dd-mm-yyyy'), to_date('26-04-2001', 'dd-mm-yyyy'), 2, 1420, to_date('29-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603017223, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 1, 9317, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080314017224, to_date('14-03-2008', 'dd-mm-yyyy'), to_date('28-03-2008', 'dd-mm-yyyy'), 1, 7482, to_date('29-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000813017225, to_date('13-08-2000', 'dd-mm-yyyy'), to_date('27-08-2000', 'dd-mm-yyyy'), 1, 1456, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202017226, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 2, 3276, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040301017227, to_date('01-03-2004', 'dd-mm-yyyy'), to_date('15-03-2004', 'dd-mm-yyyy'), 1, 4305, to_date('05-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100131017228, to_date('31-01-2010', 'dd-mm-yyyy'), to_date('14-02-2010', 'dd-mm-yyyy'), 1, 7915, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100328017229, to_date('28-03-2010', 'dd-mm-yyyy'), to_date('11-04-2010', 'dd-mm-yyyy'), 2, 8264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091012017230, to_date('12-10-2009', 'dd-mm-yyyy'), to_date('26-10-2009', 'dd-mm-yyyy'), 2, 6013, to_date('19-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050904017231, to_date('04-09-2005', 'dd-mm-yyyy'), to_date('18-09-2005', 'dd-mm-yyyy'), 2, 4192, to_date('05-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090228017232, to_date('28-02-2009', 'dd-mm-yyyy'), to_date('14-03-2009', 'dd-mm-yyyy'), 2, 4586, to_date('12-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110727017233, to_date('27-07-2011', 'dd-mm-yyyy'), to_date('10-08-2011', 'dd-mm-yyyy'), 2, 6215, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060704017234, to_date('04-07-2006', 'dd-mm-yyyy'), to_date('18-07-2006', 'dd-mm-yyyy'), 1, 3566, to_date('09-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031026017235, to_date('26-10-2003', 'dd-mm-yyyy'), to_date('09-11-2003', 'dd-mm-yyyy'), 1, 4391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061229017236, to_date('29-12-2006', 'dd-mm-yyyy'), to_date('12-01-2007', 'dd-mm-yyyy'), 1, 4696, to_date('30-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010124017237, to_date('24-01-2001', 'dd-mm-yyyy'), to_date('07-02-2001', 'dd-mm-yyyy'), 1, 2060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080605017238, to_date('05-06-2008', 'dd-mm-yyyy'), to_date('19-06-2008', 'dd-mm-yyyy'), 2, 6937, to_date('11-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713017239, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 2, 2863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070612017240, to_date('12-06-2007', 'dd-mm-yyyy'), to_date('26-06-2007', 'dd-mm-yyyy'), 2, 8370, to_date('21-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100401009176, to_date('01-04-2010', 'dd-mm-yyyy'), to_date('15-04-2010', 'dd-mm-yyyy'), 8, 6035, to_date('03-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131109009177, to_date('09-11-2013', 'dd-mm-yyyy'), to_date('23-11-2013', 'dd-mm-yyyy'), 3, 9746, to_date('28-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061126009178, to_date('26-11-2006', 'dd-mm-yyyy'), to_date('10-12-2006', 'dd-mm-yyyy'), 7, 4912, to_date('01-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080506009179, to_date('06-05-2008', 'dd-mm-yyyy'), to_date('20-05-2008', 'dd-mm-yyyy'), 5, 4367, to_date('24-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130711009180, to_date('11-07-2013', 'dd-mm-yyyy'), to_date('25-07-2013', 'dd-mm-yyyy'), 5, 9781, to_date('25-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723009181, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 12, 6533, to_date('29-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091203009182, to_date('03-12-2009', 'dd-mm-yyyy'), to_date('17-12-2009', 'dd-mm-yyyy'), 4, 6696, to_date('11-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140428009183, to_date('28-04-2014', 'dd-mm-yyyy'), to_date('12-05-2014', 'dd-mm-yyyy'), 2, 9789, to_date('17-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051210009184, to_date('10-12-2005', 'dd-mm-yyyy'), to_date('24-12-2005', 'dd-mm-yyyy'), 11, 3100, to_date('25-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217009185, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 10, 2075, to_date('19-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070424009186, to_date('24-04-2007', 'dd-mm-yyyy'), to_date('08-05-2007', 'dd-mm-yyyy'), 10, 5878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031001009187, to_date('01-10-2003', 'dd-mm-yyyy'), to_date('15-10-2003', 'dd-mm-yyyy'), 6, 1889, to_date('06-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030219009188, to_date('19-02-2003', 'dd-mm-yyyy'), to_date('05-03-2003', 'dd-mm-yyyy'), 7, 5361, to_date('07-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050119009189, to_date('19-01-2005', 'dd-mm-yyyy'), to_date('02-02-2005', 'dd-mm-yyyy'), 8, 6130, to_date('30-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090527009190, to_date('27-05-2009', 'dd-mm-yyyy'), to_date('10-06-2009', 'dd-mm-yyyy'), 10, 8041, to_date('14-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401009191, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 4, 3710, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100117009192, to_date('17-01-2010', 'dd-mm-yyyy'), to_date('31-01-2010', 'dd-mm-yyyy'), 8, 7679, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130208009193, to_date('08-02-2013', 'dd-mm-yyyy'), to_date('22-02-2013', 'dd-mm-yyyy'), 5, 10470, to_date('09-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131219009194, to_date('19-12-2013', 'dd-mm-yyyy'), to_date('02-01-2014', 'dd-mm-yyyy'), 6, 7714, to_date('31-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111113009195, to_date('13-11-2011', 'dd-mm-yyyy'), to_date('27-11-2011', 'dd-mm-yyyy'), 8, 8879, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101221009196, to_date('21-12-2010', 'dd-mm-yyyy'), to_date('04-01-2011', 'dd-mm-yyyy'), 10, 9344, to_date('24-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021211009197, to_date('11-12-2002', 'dd-mm-yyyy'), to_date('25-12-2002', 'dd-mm-yyyy'), 11, 3284, to_date('26-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000219009198, to_date('19-02-2000', 'dd-mm-yyyy'), to_date('04-03-2000', 'dd-mm-yyyy'), 4, 1259, to_date('20-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050720009199, to_date('20-07-2005', 'dd-mm-yyyy'), to_date('03-08-2005', 'dd-mm-yyyy'), 3, 2504, to_date('09-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411009200, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 10, 5076, to_date('30-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011029009201, to_date('29-10-2001', 'dd-mm-yyyy'), to_date('12-11-2001', 'dd-mm-yyyy'), 5, 2120, to_date('13-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303009202, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 8, 5402, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212009203, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 9, 5779, to_date('21-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010913009204, to_date('13-09-2001', 'dd-mm-yyyy'), to_date('27-09-2001', 'dd-mm-yyyy'), 10, 2074, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203009205, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 9, 6983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327009206, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 7, 6454, to_date('13-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120505009207, to_date('05-05-2012', 'dd-mm-yyyy'), to_date('19-05-2012', 'dd-mm-yyyy'), 6, 8049, to_date('09-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004009208, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 11, 1891, to_date('19-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070508009209, to_date('08-05-2007', 'dd-mm-yyyy'), to_date('22-05-2007', 'dd-mm-yyyy'), 6, 3979, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140217009210, to_date('17-02-2014', 'dd-mm-yyyy'), to_date('03-03-2014', 'dd-mm-yyyy'), 2, 9994, to_date('24-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050216009211, to_date('16-02-2005', 'dd-mm-yyyy'), to_date('02-03-2005', 'dd-mm-yyyy'), 6, 6859, to_date('27-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120303009212, to_date('03-03-2012', 'dd-mm-yyyy'), to_date('17-03-2012', 'dd-mm-yyyy'), 4, 8142, to_date('13-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714009213, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 8, 6605, to_date('26-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030813009214, to_date('13-08-2003', 'dd-mm-yyyy'), to_date('27-08-2003', 'dd-mm-yyyy'), 11, 2558, to_date('17-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001117009215, to_date('17-11-2000', 'dd-mm-yyyy'), to_date('01-12-2000', 'dd-mm-yyyy'), 9, 3108, to_date('26-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120512009216, to_date('12-05-2012', 'dd-mm-yyyy'), to_date('26-05-2012', 'dd-mm-yyyy'), 7, 7435, to_date('31-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031020009217, to_date('20-10-2003', 'dd-mm-yyyy'), to_date('03-11-2003', 'dd-mm-yyyy'), 9, 5123, to_date('26-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050314009218, to_date('14-03-2005', 'dd-mm-yyyy'), to_date('28-03-2005', 'dd-mm-yyyy'), 5, 1810, to_date('24-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726009219, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 9, 2584, to_date('06-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090406009220, to_date('06-04-2009', 'dd-mm-yyyy'), to_date('20-04-2009', 'dd-mm-yyyy'), 10, 5362, to_date('10-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020303009221, to_date('03-03-2002', 'dd-mm-yyyy'), to_date('17-03-2002', 'dd-mm-yyyy'), 7, 4870, to_date('16-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070423009222, to_date('23-04-2007', 'dd-mm-yyyy'), to_date('07-05-2007', 'dd-mm-yyyy'), 9, 6117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010906009223, to_date('06-09-2001', 'dd-mm-yyyy'), to_date('20-09-2001', 'dd-mm-yyyy'), 7, 4263, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100215009224, to_date('15-02-2010', 'dd-mm-yyyy'), to_date('01-03-2010', 'dd-mm-yyyy'), 9, 5903, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020714009225, to_date('14-07-2002', 'dd-mm-yyyy'), to_date('28-07-2002', 'dd-mm-yyyy'), 10, 3386, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010213009226, to_date('13-02-2001', 'dd-mm-yyyy'), to_date('27-02-2001', 'dd-mm-yyyy'), 7, 1636, to_date('28-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713009227, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 9, 1654, to_date('20-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130518009228, to_date('18-05-2013', 'dd-mm-yyyy'), to_date('01-06-2013', 'dd-mm-yyyy'), 11, 6019, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140305009229, to_date('05-03-2014', 'dd-mm-yyyy'), to_date('19-03-2014', 'dd-mm-yyyy'), 10, 8572, to_date('15-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010429009230, to_date('29-04-2001', 'dd-mm-yyyy'), to_date('13-05-2001', 'dd-mm-yyyy'), 7, 2585, to_date('13-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091118009231, to_date('18-11-2009', 'dd-mm-yyyy'), to_date('02-12-2009', 'dd-mm-yyyy'), 1, 6884, to_date('23-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040422009232, to_date('22-04-2004', 'dd-mm-yyyy'), to_date('06-05-2004', 'dd-mm-yyyy'), 8, 3612, to_date('29-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100124009233, to_date('24-01-2010', 'dd-mm-yyyy'), to_date('07-02-2010', 'dd-mm-yyyy'), 8, 7504, to_date('06-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120125009234, to_date('25-01-2012', 'dd-mm-yyyy'), to_date('08-02-2012', 'dd-mm-yyyy'), 6, 6913, to_date('30-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081031009235, to_date('31-10-2008', 'dd-mm-yyyy'), to_date('14-11-2008', 'dd-mm-yyyy'), 9, 7090, to_date('12-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130823009236, to_date('23-08-2013', 'dd-mm-yyyy'), to_date('06-09-2013', 'dd-mm-yyyy'), 6, 13007, to_date('28-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030929009237, to_date('29-09-2003', 'dd-mm-yyyy'), to_date('13-10-2003', 'dd-mm-yyyy'), 11, 2506, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100722009238, to_date('22-07-2010', 'dd-mm-yyyy'), to_date('05-08-2010', 'dd-mm-yyyy'), 2, 5815, to_date('31-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040716009239, to_date('16-07-2004', 'dd-mm-yyyy'), to_date('30-07-2004', 'dd-mm-yyyy'), 11, 5123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011127009240, to_date('27-11-2001', 'dd-mm-yyyy'), to_date('11-12-2001', 'dd-mm-yyyy'), 7, 2218, to_date('15-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100411009241, to_date('11-04-2010', 'dd-mm-yyyy'), to_date('25-04-2010', 'dd-mm-yyyy'), 6, 8957, to_date('23-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040308009242, to_date('08-03-2004', 'dd-mm-yyyy'), to_date('22-03-2004', 'dd-mm-yyyy'), 10, 2785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060929009243, to_date('29-09-2006', 'dd-mm-yyyy'), to_date('13-10-2006', 'dd-mm-yyyy'), 1, 4663, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010818009244, to_date('18-08-2001', 'dd-mm-yyyy'), to_date('01-09-2001', 'dd-mm-yyyy'), 11, 1364, to_date('24-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060123009245, to_date('23-01-2006', 'dd-mm-yyyy'), to_date('06-02-2006', 'dd-mm-yyyy'), 3, 4955, to_date('06-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109009246, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 5, 6861, to_date('26-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111009247, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 8, 4058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110105009248, to_date('05-01-2011', 'dd-mm-yyyy'), to_date('19-01-2011', 'dd-mm-yyyy'), 5, 4983, to_date('16-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819009249, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 4, 5570, to_date('01-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050613009250, to_date('13-06-2005', 'dd-mm-yyyy'), to_date('27-06-2005', 'dd-mm-yyyy'), 7, 4912, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030302009251, to_date('02-03-2003', 'dd-mm-yyyy'), to_date('16-03-2003', 'dd-mm-yyyy'), 12, 3099, to_date('08-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030415009252, to_date('15-04-2003', 'dd-mm-yyyy'), to_date('29-04-2003', 'dd-mm-yyyy'), 9, 3215, to_date('18-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081007009253, to_date('07-10-2008', 'dd-mm-yyyy'), to_date('21-10-2008', 'dd-mm-yyyy'), 11, 4482, to_date('21-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131001009254, to_date('01-10-2013', 'dd-mm-yyyy'), to_date('15-10-2013', 'dd-mm-yyyy'), 11, 9021, to_date('14-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302009255, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 11, 4901, to_date('14-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010531009256, to_date('31-05-2001', 'dd-mm-yyyy'), to_date('14-06-2001', 'dd-mm-yyyy'), 5, 3016, to_date('12-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040917009257, to_date('17-09-2004', 'dd-mm-yyyy'), to_date('01-10-2004', 'dd-mm-yyyy'), 2, 3353, to_date('30-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120520009258, to_date('20-05-2012', 'dd-mm-yyyy'), to_date('03-06-2012', 'dd-mm-yyyy'), 4, 7093, to_date('05-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140104009259, to_date('04-01-2014', 'dd-mm-yyyy'), to_date('18-01-2014', 'dd-mm-yyyy'), 10, 7872, to_date('09-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081124009260, to_date('24-11-2008', 'dd-mm-yyyy'), to_date('08-12-2008', 'dd-mm-yyyy'), 12, 8119, to_date('03-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060720009261, to_date('20-07-2006', 'dd-mm-yyyy'), to_date('03-08-2006', 'dd-mm-yyyy'), 7, 5662, to_date('21-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040731009262, to_date('31-07-2004', 'dd-mm-yyyy'), to_date('14-08-2004', 'dd-mm-yyyy'), 5, 5896, to_date('09-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050403009263, to_date('03-04-2005', 'dd-mm-yyyy'), to_date('17-04-2005', 'dd-mm-yyyy'), 11, 6122, to_date('17-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031028009264, to_date('28-10-2003', 'dd-mm-yyyy'), to_date('11-11-2003', 'dd-mm-yyyy'), 1, 2142, to_date('07-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000913009265, to_date('13-09-2000', 'dd-mm-yyyy'), to_date('27-09-2000', 'dd-mm-yyyy'), 2, 2263, to_date('20-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131228009266, to_date('28-12-2013', 'dd-mm-yyyy'), to_date('11-01-2014', 'dd-mm-yyyy'), 3, 8967, to_date('10-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307009267, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 6, 4763, to_date('15-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000929009268, to_date('29-09-2000', 'dd-mm-yyyy'), to_date('13-10-2000', 'dd-mm-yyyy'), 4, 1980, to_date('07-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020413009269, to_date('13-04-2002', 'dd-mm-yyyy'), to_date('27-04-2002', 'dd-mm-yyyy'), 10, 3838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041224009270, to_date('24-12-2004', 'dd-mm-yyyy'), to_date('07-01-2005', 'dd-mm-yyyy'), 4, 5199, to_date('10-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101019009271, to_date('19-10-2010', 'dd-mm-yyyy'), to_date('02-11-2010', 'dd-mm-yyyy'), 6, 7567, to_date('28-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011115009272, to_date('15-11-2001', 'dd-mm-yyyy'), to_date('29-11-2001', 'dd-mm-yyyy'), 1, 1281, to_date('03-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020821009273, to_date('21-08-2002', 'dd-mm-yyyy'), to_date('04-09-2002', 'dd-mm-yyyy'), 8, 1890, to_date('09-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030827009274, to_date('27-08-2003', 'dd-mm-yyyy'), to_date('10-09-2003', 'dd-mm-yyyy'), 11, 2293, to_date('02-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010919009275, to_date('19-09-2001', 'dd-mm-yyyy'), to_date('03-10-2001', 'dd-mm-yyyy'), 5, 1855, to_date('25-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120226009276, to_date('26-02-2012', 'dd-mm-yyyy'), to_date('11-03-2012', 'dd-mm-yyyy'), 6, 9579, to_date('04-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080805009277, to_date('05-08-2008', 'dd-mm-yyyy'), to_date('19-08-2008', 'dd-mm-yyyy'), 3, 6081, to_date('09-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030421009278, to_date('21-04-2003', 'dd-mm-yyyy'), to_date('05-05-2003', 'dd-mm-yyyy'), 3, 2513, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040808009279, to_date('08-08-2004', 'dd-mm-yyyy'), to_date('22-08-2004', 'dd-mm-yyyy'), 11, 4481, to_date('16-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081217009280, to_date('17-12-2008', 'dd-mm-yyyy'), to_date('31-12-2008', 'dd-mm-yyyy'), 11, 5664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130111009281, to_date('11-01-2013', 'dd-mm-yyyy'), to_date('25-01-2013', 'dd-mm-yyyy'), 10, 8706, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040206009282, to_date('06-02-2004', 'dd-mm-yyyy'), to_date('20-02-2004', 'dd-mm-yyyy'), 2, 4812, to_date('08-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070925009283, to_date('25-09-2007', 'dd-mm-yyyy'), to_date('09-10-2007', 'dd-mm-yyyy'), 6, 7240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614009284, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 12, 5838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121203009285, to_date('03-12-2012', 'dd-mm-yyyy'), to_date('17-12-2012', 'dd-mm-yyyy'), 1, 7402, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000921009286, to_date('21-09-2000', 'dd-mm-yyyy'), to_date('05-10-2000', 'dd-mm-yyyy'), 3, 1786, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011120009287, to_date('20-11-2001', 'dd-mm-yyyy'), to_date('04-12-2001', 'dd-mm-yyyy'), 5, 2937, to_date('04-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131025009288, to_date('25-10-2013', 'dd-mm-yyyy'), to_date('08-11-2013', 'dd-mm-yyyy'), 9, 10517, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010807009289, to_date('07-08-2001', 'dd-mm-yyyy'), to_date('21-08-2001', 'dd-mm-yyyy'), 10, 1876, to_date('11-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060402009290, to_date('02-04-2006', 'dd-mm-yyyy'), to_date('16-04-2006', 'dd-mm-yyyy'), 8, 5534, to_date('07-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040124009291, to_date('24-01-2004', 'dd-mm-yyyy'), to_date('07-02-2004', 'dd-mm-yyyy'), 10, 7033, to_date('09-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120909009292, to_date('09-09-2012', 'dd-mm-yyyy'), to_date('23-09-2012', 'dd-mm-yyyy'), 5, 9261, to_date('18-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070131009293, to_date('31-01-2007', 'dd-mm-yyyy'), to_date('14-02-2007', 'dd-mm-yyyy'), 9, 5749, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016009294, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 7, 4562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110721009295, to_date('21-07-2011', 'dd-mm-yyyy'), to_date('04-08-2011', 'dd-mm-yyyy'), 3, 7465, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020318009296, to_date('18-03-2002', 'dd-mm-yyyy'), to_date('01-04-2002', 'dd-mm-yyyy'), 10, 2772, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011014009297, to_date('14-10-2001', 'dd-mm-yyyy'), to_date('28-10-2001', 'dd-mm-yyyy'), 6, 2534, to_date('02-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609009298, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 3, 6898, to_date('20-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711009299, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 10, 6945, to_date('18-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080716009300, to_date('16-07-2008', 'dd-mm-yyyy'), to_date('30-07-2008', 'dd-mm-yyyy'), 2, 7981, to_date('24-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421009301, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 6, 10093, to_date('25-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040826009302, to_date('26-08-2004', 'dd-mm-yyyy'), to_date('09-09-2004', 'dd-mm-yyyy'), 10, 4903, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000401009303, to_date('01-04-2000', 'dd-mm-yyyy'), to_date('15-04-2000', 'dd-mm-yyyy'), 10, 1533, to_date('15-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110502009304, to_date('02-05-2011', 'dd-mm-yyyy'), to_date('16-05-2011', 'dd-mm-yyyy'), 10, 7046, to_date('09-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040707009305, to_date('07-07-2004', 'dd-mm-yyyy'), to_date('21-07-2004', 'dd-mm-yyyy'), 5, 4623, to_date('15-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502009306, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 12, 7820, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021015009307, to_date('15-10-2002', 'dd-mm-yyyy'), to_date('29-10-2002', 'dd-mm-yyyy'), 6, 1547, to_date('30-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021213009308, to_date('13-12-2002', 'dd-mm-yyyy'), to_date('27-12-2002', 'dd-mm-yyyy'), 6, 2203, to_date('19-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130507009309, to_date('07-05-2013', 'dd-mm-yyyy'), to_date('21-05-2013', 'dd-mm-yyyy'), 9, 7262, to_date('24-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000628009310, to_date('28-06-2000', 'dd-mm-yyyy'), to_date('12-07-2000', 'dd-mm-yyyy'), 10, 1358, to_date('07-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101008009311, to_date('08-10-2010', 'dd-mm-yyyy'), to_date('22-10-2010', 'dd-mm-yyyy'), 8, 7729, to_date('09-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021024009312, to_date('24-10-2002', 'dd-mm-yyyy'), to_date('07-11-2002', 'dd-mm-yyyy'), 10, 3860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080819009313, to_date('19-08-2008', 'dd-mm-yyyy'), to_date('02-09-2008', 'dd-mm-yyyy'), 6, 5937, to_date('27-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081127009314, to_date('27-11-2008', 'dd-mm-yyyy'), to_date('11-12-2008', 'dd-mm-yyyy'), 5, 7651, to_date('11-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719009315, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 12, 2137, to_date('24-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060320009316, to_date('20-03-2006', 'dd-mm-yyyy'), to_date('03-04-2006', 'dd-mm-yyyy'), 2, 5539, to_date('22-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030916009317, to_date('16-09-2003', 'dd-mm-yyyy'), to_date('30-09-2003', 'dd-mm-yyyy'), 5, 1650, to_date('05-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324009318, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 6, 4154, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100706009319, to_date('06-07-2010', 'dd-mm-yyyy'), to_date('20-07-2010', 'dd-mm-yyyy'), 3, 8227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040605009320, to_date('05-06-2004', 'dd-mm-yyyy'), to_date('19-06-2004', 'dd-mm-yyyy'), 2, 4091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061201009321, to_date('01-12-2006', 'dd-mm-yyyy'), to_date('15-12-2006', 'dd-mm-yyyy'), 3, 3636, to_date('09-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040504009322, to_date('04-05-2004', 'dd-mm-yyyy'), to_date('18-05-2004', 'dd-mm-yyyy'), 12, 5823, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031224009323, to_date('24-12-2003', 'dd-mm-yyyy'), to_date('07-01-2004', 'dd-mm-yyyy'), 4, 4357, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070121009324, to_date('21-01-2007', 'dd-mm-yyyy'), to_date('04-02-2007', 'dd-mm-yyyy'), 10, 6698, to_date('28-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110715009325, to_date('15-07-2011', 'dd-mm-yyyy'), to_date('29-07-2011', 'dd-mm-yyyy'), 4, 10581, to_date('02-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100820009326, to_date('20-08-2010', 'dd-mm-yyyy'), to_date('03-09-2010', 'dd-mm-yyyy'), 5, 6135, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140118009327, to_date('18-01-2014', 'dd-mm-yyyy'), to_date('01-02-2014', 'dd-mm-yyyy'), 7, 7384, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051016009328, to_date('16-10-2005', 'dd-mm-yyyy'), to_date('30-10-2005', 'dd-mm-yyyy'), 5, 3114, to_date('29-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010809009329, to_date('09-08-2001', 'dd-mm-yyyy'), to_date('23-08-2001', 'dd-mm-yyyy'), 8, 1952, to_date('24-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409011685, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 7, 5044, to_date('12-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021108011686, to_date('08-11-2002', 'dd-mm-yyyy'), to_date('22-11-2002', 'dd-mm-yyyy'), 7, 1458, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040821011687, to_date('21-08-2004', 'dd-mm-yyyy'), to_date('04-09-2004', 'dd-mm-yyyy'), 6, 3063, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130705011688, to_date('05-07-2013', 'dd-mm-yyyy'), to_date('19-07-2013', 'dd-mm-yyyy'), 8, 8168, to_date('11-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130109011689, to_date('09-01-2013', 'dd-mm-yyyy'), to_date('23-01-2013', 'dd-mm-yyyy'), 8, 8555, to_date('25-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040920011690, to_date('20-09-2004', 'dd-mm-yyyy'), to_date('04-10-2004', 'dd-mm-yyyy'), 12, 4556, to_date('09-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070928011691, to_date('28-09-2007', 'dd-mm-yyyy'), to_date('12-10-2007', 'dd-mm-yyyy'), 9, 7754, to_date('09-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090609011692, to_date('09-06-2009', 'dd-mm-yyyy'), to_date('23-06-2009', 'dd-mm-yyyy'), 9, 6613, to_date('13-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011222011693, to_date('22-12-2001', 'dd-mm-yyyy'), to_date('05-01-2002', 'dd-mm-yyyy'), 10, 2641, to_date('03-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010608011694, to_date('08-06-2001', 'dd-mm-yyyy'), to_date('22-06-2001', 'dd-mm-yyyy'), 7, 2135, to_date('11-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011209011695, to_date('09-12-2001', 'dd-mm-yyyy'), to_date('23-12-2001', 'dd-mm-yyyy'), 9, 3572, to_date('12-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429011696, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 9, 3214, to_date('30-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051210011697, to_date('10-12-2005', 'dd-mm-yyyy'), to_date('24-12-2005', 'dd-mm-yyyy'), 9, 3796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010322011698, to_date('22-03-2001', 'dd-mm-yyyy'), to_date('05-04-2001', 'dd-mm-yyyy'), 10, 3594, to_date('24-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605011699, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 7, 5469, to_date('13-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140318011700, to_date('18-03-2014', 'dd-mm-yyyy'), to_date('01-04-2014', 'dd-mm-yyyy'), 10, 7121, to_date('23-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111128011701, to_date('28-11-2011', 'dd-mm-yyyy'), to_date('12-12-2011', 'dd-mm-yyyy'), 4, 9064, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100205011702, to_date('05-02-2010', 'dd-mm-yyyy'), to_date('19-02-2010', 'dd-mm-yyyy'), 10, 5517, to_date('23-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000207011703, to_date('07-02-2000', 'dd-mm-yyyy'), to_date('21-02-2000', 'dd-mm-yyyy'), 3, 882, to_date('12-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605011704, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 12, 1349, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041228011705, to_date('28-12-2004', 'dd-mm-yyyy'), to_date('11-01-2005', 'dd-mm-yyyy'), 10, 3074, to_date('14-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625011706, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 9, 3246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021018011707, to_date('18-10-2002', 'dd-mm-yyyy'), to_date('01-11-2002', 'dd-mm-yyyy'), 6, 4079, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010717011708, to_date('17-07-2001', 'dd-mm-yyyy'), to_date('31-07-2001', 'dd-mm-yyyy'), 8, 1379, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000525011709, to_date('25-05-2000', 'dd-mm-yyyy'), to_date('08-06-2000', 'dd-mm-yyyy'), 8, 2471, to_date('04-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100604011710, to_date('04-06-2010', 'dd-mm-yyyy'), to_date('18-06-2010', 'dd-mm-yyyy'), 2, 8902, to_date('05-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081226011711, to_date('26-12-2008', 'dd-mm-yyyy'), to_date('09-01-2009', 'dd-mm-yyyy'), 8, 4918, to_date('31-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010702011712, to_date('02-07-2001', 'dd-mm-yyyy'), to_date('16-07-2001', 'dd-mm-yyyy'), 2, 3013, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040830011713, to_date('30-08-2004', 'dd-mm-yyyy'), to_date('13-09-2004', 'dd-mm-yyyy'), 6, 3928, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070328011714, to_date('28-03-2007', 'dd-mm-yyyy'), to_date('11-04-2007', 'dd-mm-yyyy'), 1, 5038, to_date('05-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061223011715, to_date('23-12-2006', 'dd-mm-yyyy'), to_date('06-01-2007', 'dd-mm-yyyy'), 11, 4474, to_date('28-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120918011716, to_date('18-09-2012', 'dd-mm-yyyy'), to_date('02-10-2012', 'dd-mm-yyyy'), 3, 10094, to_date('21-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051109011717, to_date('09-11-2005', 'dd-mm-yyyy'), to_date('23-11-2005', 'dd-mm-yyyy'), 10, 3029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001029011718, to_date('29-10-2000', 'dd-mm-yyyy'), to_date('12-11-2000', 'dd-mm-yyyy'), 9, 1606, to_date('06-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519011719, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 3, 5391, to_date('07-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808011720, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 8, 5280, to_date('15-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131124011721, to_date('24-11-2013', 'dd-mm-yyyy'), to_date('08-12-2013', 'dd-mm-yyyy'), 5, 11114, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050607011722, to_date('07-06-2005', 'dd-mm-yyyy'), to_date('21-06-2005', 'dd-mm-yyyy'), 11, 5873, to_date('13-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000110011723, to_date('10-01-2000', 'dd-mm-yyyy'), to_date('24-01-2000', 'dd-mm-yyyy'), 6, 1550, to_date('18-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808011724, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 1, 6209, to_date('24-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040912011725, to_date('12-09-2004', 'dd-mm-yyyy'), to_date('26-09-2004', 'dd-mm-yyyy'), 4, 3316, to_date('18-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020822011726, to_date('22-08-2002', 'dd-mm-yyyy'), to_date('05-09-2002', 'dd-mm-yyyy'), 9, 2069, to_date('26-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928011727, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 10, 9168, to_date('16-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050519011728, to_date('19-05-2005', 'dd-mm-yyyy'), to_date('02-06-2005', 'dd-mm-yyyy'), 12, 5626, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061219011729, to_date('19-12-2006', 'dd-mm-yyyy'), to_date('02-01-2007', 'dd-mm-yyyy'), 3, 4577, to_date('08-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070309011730, to_date('09-03-2007', 'dd-mm-yyyy'), to_date('23-03-2007', 'dd-mm-yyyy'), 6, 5990, to_date('27-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917011731, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 6, 5834, to_date('03-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090223011732, to_date('23-02-2009', 'dd-mm-yyyy'), to_date('09-03-2009', 'dd-mm-yyyy'), 12, 5649, to_date('06-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000110011733, to_date('10-01-2000', 'dd-mm-yyyy'), to_date('24-01-2000', 'dd-mm-yyyy'), 1, 1249, to_date('27-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030311011734, to_date('11-03-2003', 'dd-mm-yyyy'), to_date('25-03-2003', 'dd-mm-yyyy'), 7, 2856, to_date('14-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010111011735, to_date('11-01-2001', 'dd-mm-yyyy'), to_date('25-01-2001', 'dd-mm-yyyy'), 11, 2457, to_date('22-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041118011736, to_date('18-11-2004', 'dd-mm-yyyy'), to_date('02-12-2004', 'dd-mm-yyyy'), 7, 3082, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131210011737, to_date('10-12-2013', 'dd-mm-yyyy'), to_date('24-12-2013', 'dd-mm-yyyy'), 7, 5470, to_date('12-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120806011738, to_date('06-08-2012', 'dd-mm-yyyy'), to_date('20-08-2012', 'dd-mm-yyyy'), 6, 9097, to_date('20-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031006011739, to_date('06-10-2003', 'dd-mm-yyyy'), to_date('20-10-2003', 'dd-mm-yyyy'), 2, 2924, to_date('15-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110430011740, to_date('30-04-2011', 'dd-mm-yyyy'), to_date('14-05-2011', 'dd-mm-yyyy'), 2, 8743, to_date('03-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100522011741, to_date('22-05-2010', 'dd-mm-yyyy'), to_date('05-06-2010', 'dd-mm-yyyy'), 6, 8117, to_date('23-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020810011742, to_date('10-08-2002', 'dd-mm-yyyy'), to_date('24-08-2002', 'dd-mm-yyyy'), 7, 2443, to_date('13-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000310011743, to_date('10-03-2000', 'dd-mm-yyyy'), to_date('24-03-2000', 'dd-mm-yyyy'), 11, 3205, to_date('28-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080421011744, to_date('21-04-2008', 'dd-mm-yyyy'), to_date('05-05-2008', 'dd-mm-yyyy'), 3, 6616, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130821011745, to_date('21-08-2013', 'dd-mm-yyyy'), to_date('04-09-2013', 'dd-mm-yyyy'), 4, 8856, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040819011746, to_date('19-08-2004', 'dd-mm-yyyy'), to_date('02-09-2004', 'dd-mm-yyyy'), 10, 3956, to_date('20-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050110011747, to_date('10-01-2005', 'dd-mm-yyyy'), to_date('24-01-2005', 'dd-mm-yyyy'), 8, 4338, to_date('18-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121211011748, to_date('11-12-2012', 'dd-mm-yyyy'), to_date('25-12-2012', 'dd-mm-yyyy'), 11, 8221, to_date('18-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070227011749, to_date('27-02-2007', 'dd-mm-yyyy'), to_date('13-03-2007', 'dd-mm-yyyy'), 3, 7362, to_date('06-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926011750, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 7, 4846, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021218011751, to_date('18-12-2002', 'dd-mm-yyyy'), to_date('01-01-2003', 'dd-mm-yyyy'), 1, 3174, to_date('26-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030625011752, to_date('25-06-2003', 'dd-mm-yyyy'), to_date('09-07-2003', 'dd-mm-yyyy'), 1, 2637, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000805011753, to_date('05-08-2000', 'dd-mm-yyyy'), to_date('19-08-2000', 'dd-mm-yyyy'), 7, 2804, to_date('11-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131021011754, to_date('21-10-2013', 'dd-mm-yyyy'), to_date('04-11-2013', 'dd-mm-yyyy'), 1, 5562, to_date('03-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120307011755, to_date('07-03-2012', 'dd-mm-yyyy'), to_date('21-03-2012', 'dd-mm-yyyy'), 10, 6472, to_date('18-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315011756, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 6, 3851, to_date('16-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130311011757, to_date('11-03-2013', 'dd-mm-yyyy'), to_date('25-03-2013', 'dd-mm-yyyy'), 6, 13179, to_date('21-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110828011758, to_date('28-08-2011', 'dd-mm-yyyy'), to_date('11-09-2011', 'dd-mm-yyyy'), 6, 8114, to_date('30-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130108011759, to_date('08-01-2013', 'dd-mm-yyyy'), to_date('22-01-2013', 'dd-mm-yyyy'), 10, 7866, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040118011760, to_date('18-01-2004', 'dd-mm-yyyy'), to_date('01-02-2004', 'dd-mm-yyyy'), 12, 3989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100226011761, to_date('26-02-2010', 'dd-mm-yyyy'), to_date('12-03-2010', 'dd-mm-yyyy'), 9, 7604, to_date('17-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020629011762, to_date('29-06-2002', 'dd-mm-yyyy'), to_date('13-07-2002', 'dd-mm-yyyy'), 12, 2632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130121011763, to_date('21-01-2013', 'dd-mm-yyyy'), to_date('04-02-2013', 'dd-mm-yyyy'), 4, 8271, to_date('31-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130122011764, to_date('22-01-2013', 'dd-mm-yyyy'), to_date('05-02-2013', 'dd-mm-yyyy'), 3, 8946, to_date('29-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101115011765, to_date('15-11-2010', 'dd-mm-yyyy'), to_date('29-11-2010', 'dd-mm-yyyy'), 11, 6867, to_date('16-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111226011766, to_date('26-12-2011', 'dd-mm-yyyy'), to_date('09-01-2012', 'dd-mm-yyyy'), 11, 6729, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001005011767, to_date('05-10-2000', 'dd-mm-yyyy'), to_date('19-10-2000', 'dd-mm-yyyy'), 8, 2596, to_date('24-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040705011768, to_date('05-07-2004', 'dd-mm-yyyy'), to_date('19-07-2004', 'dd-mm-yyyy'), 8, 3758, to_date('11-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000403011769, to_date('03-04-2000', 'dd-mm-yyyy'), to_date('17-04-2000', 'dd-mm-yyyy'), 1, 1804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021026011770, to_date('26-10-2002', 'dd-mm-yyyy'), to_date('09-11-2002', 'dd-mm-yyyy'), 3, 1937, to_date('13-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001222011771, to_date('22-12-2000', 'dd-mm-yyyy'), to_date('05-01-2001', 'dd-mm-yyyy'), 3, 1669, to_date('09-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101115011772, to_date('15-11-2010', 'dd-mm-yyyy'), to_date('29-11-2010', 'dd-mm-yyyy'), 10, 7073, to_date('16-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090811011773, to_date('11-08-2009', 'dd-mm-yyyy'), to_date('25-08-2009', 'dd-mm-yyyy'), 9, 7720, to_date('23-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100611011774, to_date('11-06-2010', 'dd-mm-yyyy'), to_date('25-06-2010', 'dd-mm-yyyy'), 7, 8487, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050228011775, to_date('28-02-2005', 'dd-mm-yyyy'), to_date('14-03-2005', 'dd-mm-yyyy'), 10, 5351, to_date('15-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000501011776, to_date('01-05-2000', 'dd-mm-yyyy'), to_date('15-05-2000', 'dd-mm-yyyy'), 8, 2682, to_date('11-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000117011777, to_date('17-01-2000', 'dd-mm-yyyy'), to_date('31-01-2000', 'dd-mm-yyyy'), 6, 3804, to_date('01-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229011778, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 10, 5934, to_date('18-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050925011779, to_date('25-09-2005', 'dd-mm-yyyy'), to_date('09-10-2005', 'dd-mm-yyyy'), 11, 2870, to_date('30-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030501011780, to_date('01-05-2003', 'dd-mm-yyyy'), to_date('15-05-2003', 'dd-mm-yyyy'), 8, 4352, to_date('18-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121011781, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 7, 5753, to_date('30-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923011782, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 2, 7507, to_date('02-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000920011783, to_date('20-09-2000', 'dd-mm-yyyy'), to_date('04-10-2000', 'dd-mm-yyyy'), 10, 1056, to_date('04-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040412011784, to_date('12-04-2004', 'dd-mm-yyyy'), to_date('26-04-2004', 'dd-mm-yyyy'), 1, 3456, to_date('21-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010901011785, to_date('01-09-2001', 'dd-mm-yyyy'), to_date('15-09-2001', 'dd-mm-yyyy'), 5, 3138, to_date('13-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110712011786, to_date('12-07-2011', 'dd-mm-yyyy'), to_date('26-07-2011', 'dd-mm-yyyy'), 9, 7570, to_date('26-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020101011787, to_date('01-01-2002', 'dd-mm-yyyy'), to_date('15-01-2002', 'dd-mm-yyyy'), 2, 1855, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323011788, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 8, 10595, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030305011789, to_date('05-03-2003', 'dd-mm-yyyy'), to_date('19-03-2003', 'dd-mm-yyyy'), 9, 3674, to_date('12-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130821011790, to_date('21-08-2013', 'dd-mm-yyyy'), to_date('04-09-2013', 'dd-mm-yyyy'), 8, 8730, to_date('04-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090608011791, to_date('08-06-2009', 'dd-mm-yyyy'), to_date('22-06-2009', 'dd-mm-yyyy'), 11, 5569, to_date('19-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111205011792, to_date('05-12-2011', 'dd-mm-yyyy'), to_date('19-12-2011', 'dd-mm-yyyy'), 1, 8299, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000131011793, to_date('31-01-2000', 'dd-mm-yyyy'), to_date('14-02-2000', 'dd-mm-yyyy'), 1, 383, to_date('17-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100512011794, to_date('12-05-2010', 'dd-mm-yyyy'), to_date('26-05-2010', 'dd-mm-yyyy'), 8, 7068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726011795, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 3, 5438, to_date('03-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070510011796, to_date('10-05-2007', 'dd-mm-yyyy'), to_date('24-05-2007', 'dd-mm-yyyy'), 12, 5063, to_date('27-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090315011797, to_date('15-03-2009', 'dd-mm-yyyy'), to_date('29-03-2009', 'dd-mm-yyyy'), 3, 5986, to_date('01-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120120011798, to_date('20-01-2012', 'dd-mm-yyyy'), to_date('03-02-2012', 'dd-mm-yyyy'), 4, 9351, to_date('09-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090327011799, to_date('27-03-2009', 'dd-mm-yyyy'), to_date('10-04-2009', 'dd-mm-yyyy'), 12, 6764, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000501011800, to_date('01-05-2000', 'dd-mm-yyyy'), to_date('15-05-2000', 'dd-mm-yyyy'), 12, 1888, to_date('05-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071110011801, to_date('10-11-2007', 'dd-mm-yyyy'), to_date('24-11-2007', 'dd-mm-yyyy'), 11, 6239, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110308011802, to_date('08-03-2011', 'dd-mm-yyyy'), to_date('22-03-2011', 'dd-mm-yyyy'), 3, 5170, to_date('25-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090618011803, to_date('18-06-2009', 'dd-mm-yyyy'), to_date('02-07-2009', 'dd-mm-yyyy'), 6, 5951, to_date('04-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040208011804, to_date('08-02-2004', 'dd-mm-yyyy'), to_date('22-02-2004', 'dd-mm-yyyy'), 5, 3346, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123011805, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 7, 6424, to_date('12-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501011806, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 9, 2670, to_date('14-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110205011807, to_date('05-02-2011', 'dd-mm-yyyy'), to_date('19-02-2011', 'dd-mm-yyyy'), 4, 8995, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229011808, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 11, 5790, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120926011809, to_date('26-09-2012', 'dd-mm-yyyy'), to_date('10-10-2012', 'dd-mm-yyyy'), 6, 9375, to_date('11-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060121011810, to_date('21-01-2006', 'dd-mm-yyyy'), to_date('04-02-2006', 'dd-mm-yyyy'), 11, 5256, to_date('29-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090113011811, to_date('13-01-2009', 'dd-mm-yyyy'), to_date('27-01-2009', 'dd-mm-yyyy'), 6, 7525, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110604011812, to_date('04-06-2011', 'dd-mm-yyyy'), to_date('18-06-2011', 'dd-mm-yyyy'), 11, 4220, to_date('17-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110328011813, to_date('28-03-2011', 'dd-mm-yyyy'), to_date('11-04-2011', 'dd-mm-yyyy'), 7, 9072, to_date('12-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110310011814, to_date('10-03-2011', 'dd-mm-yyyy'), to_date('24-03-2011', 'dd-mm-yyyy'), 7, 9180, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130525011815, to_date('25-05-2013', 'dd-mm-yyyy'), to_date('08-06-2013', 'dd-mm-yyyy'), 11, 11618, to_date('12-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111110011816, to_date('10-11-2011', 'dd-mm-yyyy'), to_date('24-11-2011', 'dd-mm-yyyy'), 5, 8608, to_date('29-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010307011817, to_date('07-03-2001', 'dd-mm-yyyy'), to_date('21-03-2001', 'dd-mm-yyyy'), 2, 2498, to_date('18-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090524011818, to_date('24-05-2009', 'dd-mm-yyyy'), to_date('07-06-2009', 'dd-mm-yyyy'), 1, 7659, to_date('07-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061213011819, to_date('13-12-2006', 'dd-mm-yyyy'), to_date('27-12-2006', 'dd-mm-yyyy'), 9, 4864, to_date('18-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120911011820, to_date('11-09-2012', 'dd-mm-yyyy'), to_date('25-09-2012', 'dd-mm-yyyy'), 9, 8755, to_date('24-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130914011821, to_date('14-09-2013', 'dd-mm-yyyy'), to_date('28-09-2013', 'dd-mm-yyyy'), 1, 10710, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040127011822, to_date('27-01-2004', 'dd-mm-yyyy'), to_date('10-02-2004', 'dd-mm-yyyy'), 4, 5391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100115011823, to_date('15-01-2010', 'dd-mm-yyyy'), to_date('29-01-2010', 'dd-mm-yyyy'), 10, 7589, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120804011824, to_date('04-08-2012', 'dd-mm-yyyy'), to_date('18-08-2012', 'dd-mm-yyyy'), 11, 8981, to_date('07-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011219011825, to_date('19-12-2001', 'dd-mm-yyyy'), to_date('02-01-2002', 'dd-mm-yyyy'), 9, 2477, to_date('01-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111209011826, to_date('09-12-2011', 'dd-mm-yyyy'), to_date('23-12-2011', 'dd-mm-yyyy'), 6, 7846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060311011827, to_date('11-03-2006', 'dd-mm-yyyy'), to_date('25-03-2006', 'dd-mm-yyyy'), 10, 4043, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111104011828, to_date('04-11-2011', 'dd-mm-yyyy'), to_date('18-11-2011', 'dd-mm-yyyy'), 8, 8597, to_date('19-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061106011829, to_date('06-11-2006', 'dd-mm-yyyy'), to_date('20-11-2006', 'dd-mm-yyyy'), 11, 4224, to_date('21-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021022011830, to_date('22-10-2002', 'dd-mm-yyyy'), to_date('05-11-2002', 'dd-mm-yyyy'), 7, 2641, to_date('08-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021112011831, to_date('12-11-2002', 'dd-mm-yyyy'), to_date('26-11-2002', 'dd-mm-yyyy'), 1, 3705, to_date('23-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120225011832, to_date('25-02-2012', 'dd-mm-yyyy'), to_date('10-03-2012', 'dd-mm-yyyy'), 3, 7614, to_date('02-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110102011833, to_date('02-01-2011', 'dd-mm-yyyy'), to_date('16-01-2011', 'dd-mm-yyyy'), 9, 6554, to_date('03-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001103011834, to_date('03-11-2000', 'dd-mm-yyyy'), to_date('17-11-2000', 'dd-mm-yyyy'), 8, 915, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051124011835, to_date('24-11-2005', 'dd-mm-yyyy'), to_date('08-12-2005', 'dd-mm-yyyy'), 5, 5088, to_date('10-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020919011836, to_date('19-09-2002', 'dd-mm-yyyy'), to_date('03-10-2002', 'dd-mm-yyyy'), 11, 1973, to_date('26-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070607011837, to_date('07-06-2007', 'dd-mm-yyyy'), to_date('21-06-2007', 'dd-mm-yyyy'), 5, 6103, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040410011838, to_date('10-04-2004', 'dd-mm-yyyy'), to_date('24-04-2004', 'dd-mm-yyyy'), 3, 5003, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060802011839, to_date('02-08-2006', 'dd-mm-yyyy'), to_date('16-08-2006', 'dd-mm-yyyy'), 10, 4834, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040711011840, to_date('11-07-2004', 'dd-mm-yyyy'), to_date('25-07-2004', 'dd-mm-yyyy'), 3, 3531, to_date('24-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081018011841, to_date('18-10-2008', 'dd-mm-yyyy'), to_date('01-11-2008', 'dd-mm-yyyy'), 2, 8038, to_date('07-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120412011842, to_date('12-04-2012', 'dd-mm-yyyy'), to_date('26-04-2012', 'dd-mm-yyyy'), 8, 7351, to_date('28-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121110011843, to_date('10-11-2012', 'dd-mm-yyyy'), to_date('24-11-2012', 'dd-mm-yyyy'), 12, 9381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129011844, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 5, 10053, to_date('31-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041023011845, to_date('23-10-2004', 'dd-mm-yyyy'), to_date('06-11-2004', 'dd-mm-yyyy'), 9, 3461, to_date('01-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050226011846, to_date('26-02-2005', 'dd-mm-yyyy'), to_date('12-03-2005', 'dd-mm-yyyy'), 11, 4146, to_date('10-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070327011847, to_date('27-03-2007', 'dd-mm-yyyy'), to_date('10-04-2007', 'dd-mm-yyyy'), 12, 2854, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105011848, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 9, 4499, to_date('08-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031016011849, to_date('16-10-2003', 'dd-mm-yyyy'), to_date('30-10-2003', 'dd-mm-yyyy'), 9, 2058, to_date('24-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101007011850, to_date('07-10-2010', 'dd-mm-yyyy'), to_date('21-10-2010', 'dd-mm-yyyy'), 12, 8228, to_date('21-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114011851, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 11, 3620, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010414011852, to_date('14-04-2001', 'dd-mm-yyyy'), to_date('28-04-2001', 'dd-mm-yyyy'), 5, 1500, to_date('28-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926014549, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 4, 3470, to_date('07-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010908014550, to_date('08-09-2001', 'dd-mm-yyyy'), to_date('22-09-2001', 'dd-mm-yyyy'), 1, 2700, to_date('26-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080926014551, to_date('26-09-2008', 'dd-mm-yyyy'), to_date('10-10-2008', 'dd-mm-yyyy'), 1, 3758, to_date('06-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030802014552, to_date('02-08-2003', 'dd-mm-yyyy'), to_date('16-08-2003', 'dd-mm-yyyy'), 2, 1873, to_date('14-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090427014553, to_date('27-04-2009', 'dd-mm-yyyy'), to_date('11-05-2009', 'dd-mm-yyyy'), 4, 7124, to_date('30-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327014554, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 2, 4252, to_date('12-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100410014555, to_date('10-04-2010', 'dd-mm-yyyy'), to_date('24-04-2010', 'dd-mm-yyyy'), 4, 6270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118014556, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 3, 2032, to_date('21-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201014557, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 4, 2370, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100315014558, to_date('15-03-2010', 'dd-mm-yyyy'), to_date('29-03-2010', 'dd-mm-yyyy'), 1, 7159, to_date('18-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090828014559, to_date('28-08-2009', 'dd-mm-yyyy'), to_date('11-09-2009', 'dd-mm-yyyy'), 2, 7839, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121118014560, to_date('18-11-2012', 'dd-mm-yyyy'), to_date('02-12-2012', 'dd-mm-yyyy'), 4, 9222, to_date('26-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060306014561, to_date('06-03-2006', 'dd-mm-yyyy'), to_date('20-03-2006', 'dd-mm-yyyy'), 1, 4009, to_date('14-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031005014562, to_date('05-10-2003', 'dd-mm-yyyy'), to_date('19-10-2003', 'dd-mm-yyyy'), 2, 3840, to_date('12-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060107014563, to_date('07-01-2006', 'dd-mm-yyyy'), to_date('21-01-2006', 'dd-mm-yyyy'), 1, 7509, to_date('14-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004014564, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 2, 567, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080108014565, to_date('08-01-2008', 'dd-mm-yyyy'), to_date('22-01-2008', 'dd-mm-yyyy'), 4, 6745, to_date('21-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100709014566, to_date('09-07-2010', 'dd-mm-yyyy'), to_date('23-07-2010', 'dd-mm-yyyy'), 1, 5844, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110510014567, to_date('10-05-2011', 'dd-mm-yyyy'), to_date('24-05-2011', 'dd-mm-yyyy'), 1, 4835, to_date('18-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101127014568, to_date('27-11-2010', 'dd-mm-yyyy'), to_date('11-12-2010', 'dd-mm-yyyy'), 2, 6915, to_date('04-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030905014569, to_date('05-09-2003', 'dd-mm-yyyy'), to_date('19-09-2003', 'dd-mm-yyyy'), 1, 2454, to_date('14-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090523014570, to_date('23-05-2009', 'dd-mm-yyyy'), to_date('06-06-2009', 'dd-mm-yyyy'), 3, 7566, to_date('28-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010917014571, to_date('17-09-2001', 'dd-mm-yyyy'), to_date('01-10-2001', 'dd-mm-yyyy'), 4, 1956, to_date('27-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130812014572, to_date('12-08-2013', 'dd-mm-yyyy'), to_date('26-08-2013', 'dd-mm-yyyy'), 2, 8125, to_date('31-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000518014573, to_date('18-05-2000', 'dd-mm-yyyy'), to_date('01-06-2000', 'dd-mm-yyyy'), 3, 1274, to_date('24-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130712014574, to_date('12-07-2013', 'dd-mm-yyyy'), to_date('26-07-2013', 'dd-mm-yyyy'), 3, 10044, to_date('28-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040515014575, to_date('15-05-2004', 'dd-mm-yyyy'), to_date('29-05-2004', 'dd-mm-yyyy'), 2, 5948, to_date('20-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130522014576, to_date('22-05-2013', 'dd-mm-yyyy'), to_date('05-06-2013', 'dd-mm-yyyy'), 1, 9366, to_date('07-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061115014577, to_date('15-11-2006', 'dd-mm-yyyy'), to_date('29-11-2006', 'dd-mm-yyyy'), 4, 4675, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131118014578, to_date('18-11-2013', 'dd-mm-yyyy'), to_date('02-12-2013', 'dd-mm-yyyy'), 3, 8831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100816014579, to_date('16-08-2010', 'dd-mm-yyyy'), to_date('30-08-2010', 'dd-mm-yyyy'), 4, 7497, to_date('23-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100726014580, to_date('26-07-2010', 'dd-mm-yyyy'), to_date('09-08-2010', 'dd-mm-yyyy'), 2, 5433, to_date('12-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080208014581, to_date('08-02-2008', 'dd-mm-yyyy'), to_date('22-02-2008', 'dd-mm-yyyy'), 1, 6203, to_date('20-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000511014582, to_date('11-05-2000', 'dd-mm-yyyy'), to_date('25-05-2000', 'dd-mm-yyyy'), 2, 2691, to_date('15-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101021014583, to_date('21-10-2010', 'dd-mm-yyyy'), to_date('04-11-2010', 'dd-mm-yyyy'), 2, 6765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090415014584, to_date('15-04-2009', 'dd-mm-yyyy'), to_date('29-04-2009', 'dd-mm-yyyy'), 3, 5492, to_date('05-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001014585, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 2, 3859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011231014586, to_date('31-12-2001', 'dd-mm-yyyy'), to_date('14-01-2002', 'dd-mm-yyyy'), 2, 2973, to_date('08-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020529014587, to_date('29-05-2002', 'dd-mm-yyyy'), to_date('12-06-2002', 'dd-mm-yyyy'), 3, 3206, to_date('16-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110913014588, to_date('13-09-2011', 'dd-mm-yyyy'), to_date('27-09-2011', 'dd-mm-yyyy'), 2, 6896, to_date('22-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090927014589, to_date('27-09-2009', 'dd-mm-yyyy'), to_date('11-10-2009', 'dd-mm-yyyy'), 3, 9021, to_date('13-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040529014590, to_date('29-05-2004', 'dd-mm-yyyy'), to_date('12-06-2004', 'dd-mm-yyyy'), 2, 5338, to_date('06-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090911014591, to_date('11-09-2009', 'dd-mm-yyyy'), to_date('25-09-2009', 'dd-mm-yyyy'), 2, 6322, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050322014592, to_date('22-03-2005', 'dd-mm-yyyy'), to_date('05-04-2005', 'dd-mm-yyyy'), 2, 4322, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815014593, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 2, 2695, to_date('22-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030123014594, to_date('23-01-2003', 'dd-mm-yyyy'), to_date('06-02-2003', 'dd-mm-yyyy'), 2, 3441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030316014595, to_date('16-03-2003', 'dd-mm-yyyy'), to_date('30-03-2003', 'dd-mm-yyyy'), 2, 3655, to_date('30-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080103014596, to_date('03-01-2008', 'dd-mm-yyyy'), to_date('17-01-2008', 'dd-mm-yyyy'), 2, 7874, to_date('09-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041012014597, to_date('12-10-2004', 'dd-mm-yyyy'), to_date('26-10-2004', 'dd-mm-yyyy'), 3, 4667, to_date('23-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130808014598, to_date('08-08-2013', 'dd-mm-yyyy'), to_date('22-08-2013', 'dd-mm-yyyy'), 2, 8540, to_date('22-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030612014599, to_date('12-06-2003', 'dd-mm-yyyy'), to_date('26-06-2003', 'dd-mm-yyyy'), 1, 3122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130829014600, to_date('29-08-2013', 'dd-mm-yyyy'), to_date('12-09-2013', 'dd-mm-yyyy'), 2, 12501, to_date('07-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110528014601, to_date('28-05-2011', 'dd-mm-yyyy'), to_date('11-06-2011', 'dd-mm-yyyy'), 3, 7451, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100105014602, to_date('05-01-2010', 'dd-mm-yyyy'), to_date('19-01-2010', 'dd-mm-yyyy'), 2, 6989, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090114014603, to_date('14-01-2009', 'dd-mm-yyyy'), to_date('28-01-2009', 'dd-mm-yyyy'), 3, 8487, to_date('02-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090907014604, to_date('07-09-2009', 'dd-mm-yyyy'), to_date('21-09-2009', 'dd-mm-yyyy'), 3, 9052, to_date('26-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010519014605, to_date('19-05-2001', 'dd-mm-yyyy'), to_date('02-06-2001', 'dd-mm-yyyy'), 2, 2992, to_date('04-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000807014606, to_date('07-08-2000', 'dd-mm-yyyy'), to_date('21-08-2000', 'dd-mm-yyyy'), 2, 2899, to_date('13-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020906014607, to_date('06-09-2002', 'dd-mm-yyyy'), to_date('20-09-2002', 'dd-mm-yyyy'), 2, 3288, to_date('25-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322014608, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 4, 1315, to_date('07-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419014609, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 2, 5488, to_date('05-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020413014610, to_date('13-04-2002', 'dd-mm-yyyy'), to_date('27-04-2002', 'dd-mm-yyyy'), 2, 1350, to_date('25-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110927014611, to_date('27-09-2011', 'dd-mm-yyyy'), to_date('11-10-2011', 'dd-mm-yyyy'), 3, 6985, to_date('30-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130126014612, to_date('26-01-2013', 'dd-mm-yyyy'), to_date('09-02-2013', 'dd-mm-yyyy'), 4, 10395, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050801014613, to_date('01-08-2005', 'dd-mm-yyyy'), to_date('15-08-2005', 'dd-mm-yyyy'), 4, 4533, to_date('10-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110708014614, to_date('08-07-2011', 'dd-mm-yyyy'), to_date('22-07-2011', 'dd-mm-yyyy'), 4, 6251, to_date('14-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206014615, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 4, 5578, to_date('13-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060209014616, to_date('09-02-2006', 'dd-mm-yyyy'), to_date('23-02-2006', 'dd-mm-yyyy'), 2, 6029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140321014617, to_date('21-03-2014', 'dd-mm-yyyy'), to_date('04-04-2014', 'dd-mm-yyyy'), 2, 10498, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090526014618, to_date('26-05-2009', 'dd-mm-yyyy'), to_date('09-06-2009', 'dd-mm-yyyy'), 1, 5677, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040428014619, to_date('28-04-2004', 'dd-mm-yyyy'), to_date('12-05-2004', 'dd-mm-yyyy'), 1, 3430, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111123014620, to_date('23-11-2011', 'dd-mm-yyyy'), to_date('07-12-2011', 'dd-mm-yyyy'), 4, 7095, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080819014621, to_date('19-08-2008', 'dd-mm-yyyy'), to_date('02-09-2008', 'dd-mm-yyyy'), 1, 4635, to_date('29-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060106014622, to_date('06-01-2006', 'dd-mm-yyyy'), to_date('20-01-2006', 'dd-mm-yyyy'), 2, 3650, to_date('22-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080226014623, to_date('26-02-2008', 'dd-mm-yyyy'), to_date('11-03-2008', 'dd-mm-yyyy'), 1, 7396, to_date('12-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050516014624, to_date('16-05-2005', 'dd-mm-yyyy'), to_date('30-05-2005', 'dd-mm-yyyy'), 1, 4136, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031227014625, to_date('27-12-2003', 'dd-mm-yyyy'), to_date('10-01-2004', 'dd-mm-yyyy'), 4, 3486, to_date('30-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111008014626, to_date('08-10-2011', 'dd-mm-yyyy'), to_date('22-10-2011', 'dd-mm-yyyy'), 4, 7608, to_date('16-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080326014627, to_date('26-03-2008', 'dd-mm-yyyy'), to_date('09-04-2008', 'dd-mm-yyyy'), 4, 6128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000831014628, to_date('31-08-2000', 'dd-mm-yyyy'), to_date('14-09-2000', 'dd-mm-yyyy'), 4, 1263, to_date('10-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215014629, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 2, 6907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030325014630, to_date('25-03-2003', 'dd-mm-yyyy'), to_date('08-04-2003', 'dd-mm-yyyy'), 2, 1674, to_date('26-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010226014631, to_date('26-02-2001', 'dd-mm-yyyy'), to_date('12-03-2001', 'dd-mm-yyyy'), 2, 3595, to_date('16-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021022014632, to_date('22-10-2002', 'dd-mm-yyyy'), to_date('05-11-2002', 'dd-mm-yyyy'), 2, 3160, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050522014633, to_date('22-05-2005', 'dd-mm-yyyy'), to_date('05-06-2005', 'dd-mm-yyyy'), 2, 5141, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011023014634, to_date('23-10-2001', 'dd-mm-yyyy'), to_date('06-11-2001', 'dd-mm-yyyy'), 3, 2700, to_date('09-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010411014635, to_date('11-04-2001', 'dd-mm-yyyy'), to_date('25-04-2001', 'dd-mm-yyyy'), 4, 1624, to_date('13-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091221014636, to_date('21-12-2009', 'dd-mm-yyyy'), to_date('04-01-2010', 'dd-mm-yyyy'), 4, 7424, to_date('22-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013014637, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 4, 8962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130129014638, to_date('29-01-2013', 'dd-mm-yyyy'), to_date('12-02-2013', 'dd-mm-yyyy'), 2, 10942, to_date('31-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040426014639, to_date('26-04-2004', 'dd-mm-yyyy'), to_date('10-05-2004', 'dd-mm-yyyy'), 3, 3461, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060115014640, to_date('15-01-2006', 'dd-mm-yyyy'), to_date('29-01-2006', 'dd-mm-yyyy'), 2, 4094, to_date('26-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120110014641, to_date('10-01-2012', 'dd-mm-yyyy'), to_date('24-01-2012', 'dd-mm-yyyy'), 3, 6949, to_date('24-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819014642, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 4, 7845, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110713014643, to_date('13-07-2011', 'dd-mm-yyyy'), to_date('27-07-2011', 'dd-mm-yyyy'), 2, 8349, to_date('17-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090615014644, to_date('15-06-2009', 'dd-mm-yyyy'), to_date('29-06-2009', 'dd-mm-yyyy'), 3, 6254, to_date('21-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121026014645, to_date('26-10-2012', 'dd-mm-yyyy'), to_date('09-11-2012', 'dd-mm-yyyy'), 2, 8585, to_date('27-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001030014646, to_date('30-10-2000', 'dd-mm-yyyy'), to_date('13-11-2000', 'dd-mm-yyyy'), 1, 1584, to_date('31-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130620014647, to_date('20-06-2013', 'dd-mm-yyyy'), to_date('04-07-2013', 'dd-mm-yyyy'), 2, 10957, to_date('26-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220014648, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 3, 9465, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081025014649, to_date('25-10-2008', 'dd-mm-yyyy'), to_date('08-11-2008', 'dd-mm-yyyy'), 2, 6467, to_date('08-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031216014650, to_date('16-12-2003', 'dd-mm-yyyy'), to_date('30-12-2003', 'dd-mm-yyyy'), 3, 3727, to_date('29-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081024014651, to_date('24-10-2008', 'dd-mm-yyyy'), to_date('07-11-2008', 'dd-mm-yyyy'), 3, 6327, to_date('07-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011209014652, to_date('09-12-2001', 'dd-mm-yyyy'), to_date('23-12-2001', 'dd-mm-yyyy'), 3, 2184, to_date('14-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020604014653, to_date('04-06-2002', 'dd-mm-yyyy'), to_date('18-06-2002', 'dd-mm-yyyy'), 1, 3733, to_date('07-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030227014654, to_date('27-02-2003', 'dd-mm-yyyy'), to_date('13-03-2003', 'dd-mm-yyyy'), 2, 2296, to_date('13-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625014655, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 4, 2921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090303014656, to_date('03-03-2009', 'dd-mm-yyyy'), to_date('17-03-2009', 'dd-mm-yyyy'), 2, 6346, to_date('18-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050116014657, to_date('16-01-2005', 'dd-mm-yyyy'), to_date('30-01-2005', 'dd-mm-yyyy'), 3, 6110, to_date('23-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526014658, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 3, 2049, to_date('10-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060925014659, to_date('25-09-2006', 'dd-mm-yyyy'), to_date('09-10-2006', 'dd-mm-yyyy'), 3, 5997, to_date('12-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100324014660, to_date('24-03-2010', 'dd-mm-yyyy'), to_date('07-04-2010', 'dd-mm-yyyy'), 3, 7032, to_date('28-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910014661, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 1, 7033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080809014662, to_date('09-08-2008', 'dd-mm-yyyy'), to_date('23-08-2008', 'dd-mm-yyyy'), 1, 5189, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121014663, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 2, 7124, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080822014664, to_date('22-08-2008', 'dd-mm-yyyy'), to_date('05-09-2008', 'dd-mm-yyyy'), 3, 5009, to_date('04-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080402014665, to_date('02-04-2008', 'dd-mm-yyyy'), to_date('16-04-2008', 'dd-mm-yyyy'), 2, 6153, to_date('09-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101029014666, to_date('29-10-2010', 'dd-mm-yyyy'), to_date('12-11-2010', 'dd-mm-yyyy'), 2, 6479, to_date('10-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140401014667, to_date('01-04-2014', 'dd-mm-yyyy'), to_date('15-04-2014', 'dd-mm-yyyy'), 3, 9394, to_date('06-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060526014668, to_date('26-05-2006', 'dd-mm-yyyy'), to_date('09-06-2006', 'dd-mm-yyyy'), 3, 4297, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000120014669, to_date('20-01-2000', 'dd-mm-yyyy'), to_date('03-02-2000', 'dd-mm-yyyy'), 1, 2285, to_date('31-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070309014670, to_date('09-03-2007', 'dd-mm-yyyy'), to_date('23-03-2007', 'dd-mm-yyyy'), 2, 4976, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130929014671, to_date('29-09-2013', 'dd-mm-yyyy'), to_date('13-10-2013', 'dd-mm-yyyy'), 2, 9197, to_date('14-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100620014672, to_date('20-06-2010', 'dd-mm-yyyy'), to_date('04-07-2010', 'dd-mm-yyyy'), 4, 8009, to_date('07-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040819014673, to_date('19-08-2004', 'dd-mm-yyyy'), to_date('02-09-2004', 'dd-mm-yyyy'), 1, 5716, to_date('27-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040822014674, to_date('22-08-2004', 'dd-mm-yyyy'), to_date('05-09-2004', 'dd-mm-yyyy'), 2, 3862, to_date('03-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130322014675, to_date('22-03-2013', 'dd-mm-yyyy'), to_date('05-04-2013', 'dd-mm-yyyy'), 3, 9219, to_date('04-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070924014676, to_date('24-09-2007', 'dd-mm-yyyy'), to_date('08-10-2007', 'dd-mm-yyyy'), 3, 7942, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813014677, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 1, 6936, to_date('19-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021014678, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 2, 1929, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728014679, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 1, 12937, to_date('07-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051111014680, to_date('11-11-2005', 'dd-mm-yyyy'), to_date('25-11-2005', 'dd-mm-yyyy'), 2, 6539, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021029014681, to_date('29-10-2002', 'dd-mm-yyyy'), to_date('12-11-2002', 'dd-mm-yyyy'), 3, 2323, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021014682, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 2, 4390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225014683, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 2, 5059, to_date('02-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040617014684, to_date('17-06-2004', 'dd-mm-yyyy'), to_date('01-07-2004', 'dd-mm-yyyy'), 4, 3694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615014685, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 3, 11804, to_date('03-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070321014686, to_date('21-03-2007', 'dd-mm-yyyy'), to_date('04-04-2007', 'dd-mm-yyyy'), 4, 6879, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812014687, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 3, 10123, to_date('15-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040615014688, to_date('15-06-2004', 'dd-mm-yyyy'), to_date('29-06-2004', 'dd-mm-yyyy'), 2, 4514, to_date('04-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010523014689, to_date('23-05-2001', 'dd-mm-yyyy'), to_date('06-06-2001', 'dd-mm-yyyy'), 4, 3093, to_date('01-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021101014690, to_date('01-11-2002', 'dd-mm-yyyy'), to_date('15-11-2002', 'dd-mm-yyyy'), 2, 3389, to_date('20-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050622014691, to_date('22-06-2005', 'dd-mm-yyyy'), to_date('06-07-2005', 'dd-mm-yyyy'), 2, 5738, to_date('07-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831014692, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 3, 6751, to_date('15-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070305014693, to_date('05-03-2007', 'dd-mm-yyyy'), to_date('19-03-2007', 'dd-mm-yyyy'), 2, 3576, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011007014694, to_date('07-10-2001', 'dd-mm-yyyy'), to_date('21-10-2001', 'dd-mm-yyyy'), 3, 2565, to_date('15-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222014695, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 1, 8260, to_date('11-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140129014696, to_date('29-01-2014', 'dd-mm-yyyy'), to_date('12-02-2014', 'dd-mm-yyyy'), 2, 8984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090905014697, to_date('05-09-2009', 'dd-mm-yyyy'), to_date('19-09-2009', 'dd-mm-yyyy'), 4, 5236, to_date('24-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031220014698, to_date('20-12-2003', 'dd-mm-yyyy'), to_date('03-01-2004', 'dd-mm-yyyy'), 4, 5186, to_date('29-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010413014699, to_date('13-04-2001', 'dd-mm-yyyy'), to_date('27-04-2001', 'dd-mm-yyyy'), 4, 2313, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040815014700, to_date('15-08-2004', 'dd-mm-yyyy'), to_date('29-08-2004', 'dd-mm-yyyy'), 2, 3270, to_date('01-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111026014701, to_date('26-10-2011', 'dd-mm-yyyy'), to_date('09-11-2011', 'dd-mm-yyyy'), 3, 7079, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120714014702, to_date('14-07-2012', 'dd-mm-yyyy'), to_date('28-07-2012', 'dd-mm-yyyy'), 3, 8692, to_date('21-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131205014703, to_date('05-12-2013', 'dd-mm-yyyy'), to_date('19-12-2013', 'dd-mm-yyyy'), 2, 8439, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140502014704, to_date('02-05-2014', 'dd-mm-yyyy'), to_date('16-05-2014', 'dd-mm-yyyy'), 1, 8774, to_date('08-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040415014705, to_date('15-04-2004', 'dd-mm-yyyy'), to_date('29-04-2004', 'dd-mm-yyyy'), 1, 4538, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100904014706, to_date('04-09-2010', 'dd-mm-yyyy'), to_date('18-09-2010', 'dd-mm-yyyy'), 4, 3524, to_date('11-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060711014707, to_date('11-07-2006', 'dd-mm-yyyy'), to_date('25-07-2006', 'dd-mm-yyyy'), 3, 8672, to_date('30-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130303014708, to_date('03-03-2013', 'dd-mm-yyyy'), to_date('17-03-2013', 'dd-mm-yyyy'), 3, 10990, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040216014709, to_date('16-02-2004', 'dd-mm-yyyy'), to_date('01-03-2004', 'dd-mm-yyyy'), 4, 6360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120217014710, to_date('17-02-2012', 'dd-mm-yyyy'), to_date('02-03-2012', 'dd-mm-yyyy'), 2, 7846, to_date('21-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030825014711, to_date('25-08-2003', 'dd-mm-yyyy'), to_date('08-09-2003', 'dd-mm-yyyy'), 4, 4751, to_date('14-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130330014712, to_date('30-03-2013', 'dd-mm-yyyy'), to_date('13-04-2013', 'dd-mm-yyyy'), 4, 8921, to_date('12-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325014713, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 2, 6876, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902014714, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 4, 5517, to_date('08-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090619014715, to_date('19-06-2009', 'dd-mm-yyyy'), to_date('03-07-2009', 'dd-mm-yyyy'), 2, 6435, to_date('22-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070427014716, to_date('27-04-2007', 'dd-mm-yyyy'), to_date('11-05-2007', 'dd-mm-yyyy'), 2, 5002, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061229017241, to_date('29-12-2006', 'dd-mm-yyyy'), to_date('12-01-2007', 'dd-mm-yyyy'), 1, 4335, to_date('15-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030705017242, to_date('05-07-2003', 'dd-mm-yyyy'), to_date('19-07-2003', 'dd-mm-yyyy'), 2, 3318, to_date('08-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216017243, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 1, 6858, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140225017244, to_date('25-02-2014', 'dd-mm-yyyy'), to_date('11-03-2014', 'dd-mm-yyyy'), 2, 9107, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040901017245, to_date('01-09-2004', 'dd-mm-yyyy'), to_date('15-09-2004', 'dd-mm-yyyy'), 2, 3123, to_date('20-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100829017246, to_date('29-08-2010', 'dd-mm-yyyy'), to_date('12-09-2010', 'dd-mm-yyyy'), 1, 6392, to_date('12-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080723017247, to_date('23-07-2008', 'dd-mm-yyyy'), to_date('06-08-2008', 'dd-mm-yyyy'), 2, 6034, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081025017248, to_date('25-10-2008', 'dd-mm-yyyy'), to_date('08-11-2008', 'dd-mm-yyyy'), 2, 8408, to_date('28-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050515017249, to_date('15-05-2005', 'dd-mm-yyyy'), to_date('29-05-2005', 'dd-mm-yyyy'), 2, 5417, to_date('27-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090425017250, to_date('25-04-2009', 'dd-mm-yyyy'), to_date('09-05-2009', 'dd-mm-yyyy'), 2, 7554, to_date('10-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100801017251, to_date('01-08-2010', 'dd-mm-yyyy'), to_date('15-08-2010', 'dd-mm-yyyy'), 2, 8396, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030901017252, to_date('01-09-2003', 'dd-mm-yyyy'), to_date('15-09-2003', 'dd-mm-yyyy'), 2, 3758, to_date('11-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507017253, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 2, 3032, to_date('27-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000419017254, to_date('19-04-2000', 'dd-mm-yyyy'), to_date('03-05-2000', 'dd-mm-yyyy'), 2, 2186, to_date('27-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140227017255, to_date('27-02-2014', 'dd-mm-yyyy'), to_date('13-03-2014', 'dd-mm-yyyy'), 2, 12790, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100920017256, to_date('20-09-2010', 'dd-mm-yyyy'), to_date('04-10-2010', 'dd-mm-yyyy'), 2, 4565, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011011017257, to_date('11-10-2001', 'dd-mm-yyyy'), to_date('25-10-2001', 'dd-mm-yyyy'), 1, 816, to_date('28-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011123017258, to_date('23-11-2001', 'dd-mm-yyyy'), to_date('07-12-2001', 'dd-mm-yyyy'), 1, 1998, to_date('01-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131128017259, to_date('28-11-2013', 'dd-mm-yyyy'), to_date('12-12-2013', 'dd-mm-yyyy'), 2, 7435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030727017260, to_date('27-07-2003', 'dd-mm-yyyy'), to_date('10-08-2003', 'dd-mm-yyyy'), 2, 2780, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000704017261, to_date('04-07-2000', 'dd-mm-yyyy'), to_date('18-07-2000', 'dd-mm-yyyy'), 2, 1810, to_date('08-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090222017262, to_date('22-02-2009', 'dd-mm-yyyy'), to_date('08-03-2009', 'dd-mm-yyyy'), 1, 6894, to_date('27-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041205017263, to_date('05-12-2004', 'dd-mm-yyyy'), to_date('19-12-2004', 'dd-mm-yyyy'), 1, 3342, to_date('12-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116017264, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 1, 6072, to_date('20-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130919017265, to_date('19-09-2013', 'dd-mm-yyyy'), to_date('03-10-2013', 'dd-mm-yyyy'), 2, 9417, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031218017266, to_date('18-12-2003', 'dd-mm-yyyy'), to_date('01-01-2004', 'dd-mm-yyyy'), 2, 3660, to_date('01-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010226017267, to_date('26-02-2001', 'dd-mm-yyyy'), to_date('12-03-2001', 'dd-mm-yyyy'), 1, 2955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030513017268, to_date('13-05-2003', 'dd-mm-yyyy'), to_date('27-05-2003', 'dd-mm-yyyy'), 2, 2844, to_date('24-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030524017269, to_date('24-05-2003', 'dd-mm-yyyy'), to_date('07-06-2003', 'dd-mm-yyyy'), 1, 3954, to_date('28-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607017270, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 2, 7006, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010720017271, to_date('20-07-2001', 'dd-mm-yyyy'), to_date('03-08-2001', 'dd-mm-yyyy'), 2, 3508, to_date('08-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522017272, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 1, 4894, to_date('07-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070326017273, to_date('26-03-2007', 'dd-mm-yyyy'), to_date('09-04-2007', 'dd-mm-yyyy'), 1, 5211, to_date('01-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091001017274, to_date('01-10-2009', 'dd-mm-yyyy'), to_date('15-10-2009', 'dd-mm-yyyy'), 1, 4328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071110017275, to_date('10-11-2007', 'dd-mm-yyyy'), to_date('24-11-2007', 'dd-mm-yyyy'), 2, 6566, to_date('20-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001009017276, to_date('09-10-2000', 'dd-mm-yyyy'), to_date('23-10-2000', 'dd-mm-yyyy'), 1, 2428, to_date('20-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120407017277, to_date('07-04-2012', 'dd-mm-yyyy'), to_date('21-04-2012', 'dd-mm-yyyy'), 1, 6132, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620017278, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 1, 9827, to_date('29-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050402017279, to_date('02-04-2005', 'dd-mm-yyyy'), to_date('16-04-2005', 'dd-mm-yyyy'), 2, 4321, to_date('05-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030108017280, to_date('08-01-2003', 'dd-mm-yyyy'), to_date('22-01-2003', 'dd-mm-yyyy'), 1, 3062, to_date('13-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010609017281, to_date('09-06-2001', 'dd-mm-yyyy'), to_date('23-06-2001', 'dd-mm-yyyy'), 2, 3019, to_date('14-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030703017282, to_date('03-07-2003', 'dd-mm-yyyy'), to_date('17-07-2003', 'dd-mm-yyyy'), 1, 3771, to_date('19-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111027017283, to_date('27-10-2011', 'dd-mm-yyyy'), to_date('10-11-2011', 'dd-mm-yyyy'), 2, 6031, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000125017284, to_date('25-01-2000', 'dd-mm-yyyy'), to_date('08-02-2000', 'dd-mm-yyyy'), 1, 2103, to_date('14-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140220017285, to_date('20-02-2014', 'dd-mm-yyyy'), to_date('06-03-2014', 'dd-mm-yyyy'), 1, 10255, to_date('25-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327017286, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 2, 10988, to_date('01-04-2014', 'dd-mm-yyyy'));
commit;
prompt 15000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120218017287, to_date('18-02-2012', 'dd-mm-yyyy'), to_date('03-03-2012', 'dd-mm-yyyy'), 1, 9457, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080327017288, to_date('27-03-2008', 'dd-mm-yyyy'), to_date('10-04-2008', 'dd-mm-yyyy'), 2, 5700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000417017289, to_date('17-04-2000', 'dd-mm-yyyy'), to_date('01-05-2000', 'dd-mm-yyyy'), 1, 2686, to_date('30-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817017290, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 1, 5781, to_date('02-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050209017291, to_date('09-02-2005', 'dd-mm-yyyy'), to_date('23-02-2005', 'dd-mm-yyyy'), 2, 4053, to_date('11-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419017292, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 2, 2724, to_date('22-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070923017293, to_date('23-09-2007', 'dd-mm-yyyy'), to_date('07-10-2007', 'dd-mm-yyyy'), 1, 5991, to_date('10-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070911017294, to_date('11-09-2007', 'dd-mm-yyyy'), to_date('25-09-2007', 'dd-mm-yyyy'), 1, 5709, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080607017295, to_date('07-06-2008', 'dd-mm-yyyy'), to_date('21-06-2008', 'dd-mm-yyyy'), 1, 6850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060101017296, to_date('01-01-2006', 'dd-mm-yyyy'), to_date('15-01-2006', 'dd-mm-yyyy'), 1, 4456, to_date('18-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050409017297, to_date('09-04-2005', 'dd-mm-yyyy'), to_date('23-04-2005', 'dd-mm-yyyy'), 1, 3347, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140115017298, to_date('15-01-2014', 'dd-mm-yyyy'), to_date('29-01-2014', 'dd-mm-yyyy'), 2, 8835, to_date('30-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051102017299, to_date('02-11-2005', 'dd-mm-yyyy'), to_date('16-11-2005', 'dd-mm-yyyy'), 1, 5298, to_date('11-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120802017300, to_date('02-08-2012', 'dd-mm-yyyy'), to_date('16-08-2012', 'dd-mm-yyyy'), 2, 8241, to_date('12-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011202017301, to_date('02-12-2001', 'dd-mm-yyyy'), to_date('16-12-2001', 'dd-mm-yyyy'), 2, 1227, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060303017302, to_date('03-03-2006', 'dd-mm-yyyy'), to_date('17-03-2006', 'dd-mm-yyyy'), 1, 4874, to_date('20-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070605017303, to_date('05-06-2007', 'dd-mm-yyyy'), to_date('19-06-2007', 'dd-mm-yyyy'), 2, 4329, to_date('20-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110903017304, to_date('03-09-2011', 'dd-mm-yyyy'), to_date('17-09-2011', 'dd-mm-yyyy'), 2, 8834, to_date('16-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020626017305, to_date('26-06-2002', 'dd-mm-yyyy'), to_date('10-07-2002', 'dd-mm-yyyy'), 2, 3567, to_date('05-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050907017306, to_date('07-09-2005', 'dd-mm-yyyy'), to_date('21-09-2005', 'dd-mm-yyyy'), 2, 7174, to_date('13-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090901017307, to_date('01-09-2009', 'dd-mm-yyyy'), to_date('15-09-2009', 'dd-mm-yyyy'), 1, 8222, to_date('08-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070903017308, to_date('03-09-2007', 'dd-mm-yyyy'), to_date('17-09-2007', 'dd-mm-yyyy'), 1, 2432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140317017309, to_date('17-03-2014', 'dd-mm-yyyy'), to_date('31-03-2014', 'dd-mm-yyyy'), 2, 7801, to_date('21-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213017310, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 1, 8273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091020017311, to_date('20-10-2009', 'dd-mm-yyyy'), to_date('03-11-2009', 'dd-mm-yyyy'), 2, 3998, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090310017312, to_date('10-03-2009', 'dd-mm-yyyy'), to_date('24-03-2009', 'dd-mm-yyyy'), 2, 6314, to_date('26-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021115017313, to_date('15-11-2002', 'dd-mm-yyyy'), to_date('29-11-2002', 'dd-mm-yyyy'), 1, 2923, to_date('17-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120017314, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 2, 3998, to_date('24-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020203017315, to_date('03-02-2002', 'dd-mm-yyyy'), to_date('17-02-2002', 'dd-mm-yyyy'), 2, 2740, to_date('14-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050318017316, to_date('18-03-2005', 'dd-mm-yyyy'), to_date('01-04-2005', 'dd-mm-yyyy'), 1, 6116, to_date('30-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080824017317, to_date('24-08-2008', 'dd-mm-yyyy'), to_date('07-09-2008', 'dd-mm-yyyy'), 2, 5588, to_date('09-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001227017318, to_date('27-12-2000', 'dd-mm-yyyy'), to_date('10-01-2001', 'dd-mm-yyyy'), 1, 2238, to_date('09-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110925017319, to_date('25-09-2011', 'dd-mm-yyyy'), to_date('09-10-2011', 'dd-mm-yyyy'), 1, 8253, to_date('09-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131007017320, to_date('07-10-2013', 'dd-mm-yyyy'), to_date('21-10-2013', 'dd-mm-yyyy'), 2, 5613, to_date('11-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110629017321, to_date('29-06-2011', 'dd-mm-yyyy'), to_date('13-07-2011', 'dd-mm-yyyy'), 1, 6717, to_date('03-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110602017322, to_date('02-06-2011', 'dd-mm-yyyy'), to_date('16-06-2011', 'dd-mm-yyyy'), 2, 8351, to_date('08-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120813017323, to_date('13-08-2012', 'dd-mm-yyyy'), to_date('27-08-2012', 'dd-mm-yyyy'), 2, 11217, to_date('21-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040714017324, to_date('14-07-2004', 'dd-mm-yyyy'), to_date('28-07-2004', 'dd-mm-yyyy'), 1, 4657, to_date('22-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060402017325, to_date('02-04-2006', 'dd-mm-yyyy'), to_date('16-04-2006', 'dd-mm-yyyy'), 2, 4896, to_date('12-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040615017326, to_date('15-06-2004', 'dd-mm-yyyy'), to_date('29-06-2004', 'dd-mm-yyyy'), 2, 3050, to_date('17-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090109017327, to_date('09-01-2009', 'dd-mm-yyyy'), to_date('23-01-2009', 'dd-mm-yyyy'), 1, 8496, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110825017328, to_date('25-08-2011', 'dd-mm-yyyy'), to_date('08-09-2011', 'dd-mm-yyyy'), 1, 7085, to_date('30-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090615017329, to_date('15-06-2009', 'dd-mm-yyyy'), to_date('29-06-2009', 'dd-mm-yyyy'), 1, 8324, to_date('23-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110424017330, to_date('24-04-2011', 'dd-mm-yyyy'), to_date('08-05-2011', 'dd-mm-yyyy'), 2, 6412, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421017331, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 2, 4409, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100508017332, to_date('08-05-2010', 'dd-mm-yyyy'), to_date('22-05-2010', 'dd-mm-yyyy'), 1, 7025, to_date('12-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119017333, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 1, 9926, to_date('21-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201017334, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 2, 6120, to_date('10-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000728017335, to_date('28-07-2000', 'dd-mm-yyyy'), to_date('11-08-2000', 'dd-mm-yyyy'), 2, 1088, to_date('10-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007017336, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 2, 3178, to_date('17-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051222017337, to_date('22-12-2005', 'dd-mm-yyyy'), to_date('05-01-2006', 'dd-mm-yyyy'), 1, 5676, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130425017338, to_date('25-04-2013', 'dd-mm-yyyy'), to_date('09-05-2013', 'dd-mm-yyyy'), 2, 9401, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061118017339, to_date('18-11-2006', 'dd-mm-yyyy'), to_date('02-12-2006', 'dd-mm-yyyy'), 2, 4412, to_date('04-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060203017340, to_date('03-02-2006', 'dd-mm-yyyy'), to_date('17-02-2006', 'dd-mm-yyyy'), 2, 5939, to_date('07-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100709017341, to_date('09-07-2010', 'dd-mm-yyyy'), to_date('23-07-2010', 'dd-mm-yyyy'), 1, 8689, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007017342, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 2, 3184, to_date('26-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060224017343, to_date('24-02-2006', 'dd-mm-yyyy'), to_date('10-03-2006', 'dd-mm-yyyy'), 2, 3890, to_date('16-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040518017344, to_date('18-05-2004', 'dd-mm-yyyy'), to_date('01-06-2004', 'dd-mm-yyyy'), 2, 3801, to_date('21-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010815017345, to_date('15-08-2001', 'dd-mm-yyyy'), to_date('29-08-2001', 'dd-mm-yyyy'), 2, 2129, to_date('22-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020610017346, to_date('10-06-2002', 'dd-mm-yyyy'), to_date('24-06-2002', 'dd-mm-yyyy'), 2, 1890, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061127017347, to_date('27-11-2006', 'dd-mm-yyyy'), to_date('11-12-2006', 'dd-mm-yyyy'), 2, 4459, to_date('06-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080626017348, to_date('26-06-2008', 'dd-mm-yyyy'), to_date('10-07-2008', 'dd-mm-yyyy'), 1, 5982, to_date('05-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125017349, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 2, 3679, to_date('06-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080514017350, to_date('14-05-2008', 'dd-mm-yyyy'), to_date('28-05-2008', 'dd-mm-yyyy'), 1, 3986, to_date('22-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130701017351, to_date('01-07-2013', 'dd-mm-yyyy'), to_date('15-07-2013', 'dd-mm-yyyy'), 1, 9028, to_date('10-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820017352, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 1, 2614, to_date('22-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101021017353, to_date('21-10-2010', 'dd-mm-yyyy'), to_date('04-11-2010', 'dd-mm-yyyy'), 1, 7795, to_date('04-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080811017354, to_date('11-08-2008', 'dd-mm-yyyy'), to_date('25-08-2008', 'dd-mm-yyyy'), 1, 6983, to_date('24-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030508017355, to_date('08-05-2003', 'dd-mm-yyyy'), to_date('22-05-2003', 'dd-mm-yyyy'), 2, 4884, to_date('24-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207017356, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 1, 10020, to_date('26-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130724017357, to_date('24-07-2013', 'dd-mm-yyyy'), to_date('07-08-2013', 'dd-mm-yyyy'), 2, 8643, to_date('07-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080329017358, to_date('29-03-2008', 'dd-mm-yyyy'), to_date('12-04-2008', 'dd-mm-yyyy'), 1, 5571, to_date('08-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130719017359, to_date('19-07-2013', 'dd-mm-yyyy'), to_date('02-08-2013', 'dd-mm-yyyy'), 2, 9882, to_date('28-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010105017360, to_date('05-01-2001', 'dd-mm-yyyy'), to_date('19-01-2001', 'dd-mm-yyyy'), 2, 2889, to_date('11-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121116017361, to_date('16-11-2012', 'dd-mm-yyyy'), to_date('30-11-2012', 'dd-mm-yyyy'), 2, 7202, to_date('20-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000914017362, to_date('14-09-2000', 'dd-mm-yyyy'), to_date('28-09-2000', 'dd-mm-yyyy'), 1, 1405, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031117017363, to_date('17-11-2003', 'dd-mm-yyyy'), to_date('01-12-2003', 'dd-mm-yyyy'), 1, 2753, to_date('05-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011122017364, to_date('22-11-2001', 'dd-mm-yyyy'), to_date('06-12-2001', 'dd-mm-yyyy'), 1, 3672, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010825017365, to_date('25-08-2001', 'dd-mm-yyyy'), to_date('08-09-2001', 'dd-mm-yyyy'), 2, 3110, to_date('11-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041108017366, to_date('08-11-2004', 'dd-mm-yyyy'), to_date('22-11-2004', 'dd-mm-yyyy'), 1, 3629, to_date('21-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090531017367, to_date('31-05-2009', 'dd-mm-yyyy'), to_date('14-06-2009', 'dd-mm-yyyy'), 1, 4332, to_date('19-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106017368, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 1, 8951, to_date('20-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411017369, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 1, 5440, to_date('29-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626017370, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 1, 6717, to_date('02-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050908017371, to_date('08-09-2005', 'dd-mm-yyyy'), to_date('22-09-2005', 'dd-mm-yyyy'), 2, 5083, to_date('16-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130507017372, to_date('07-05-2013', 'dd-mm-yyyy'), to_date('21-05-2013', 'dd-mm-yyyy'), 2, 9041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040424017373, to_date('24-04-2004', 'dd-mm-yyyy'), to_date('08-05-2004', 'dd-mm-yyyy'), 2, 3885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030120017374, to_date('20-01-2003', 'dd-mm-yyyy'), to_date('03-02-2003', 'dd-mm-yyyy'), 2, 3476, to_date('05-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071211017375, to_date('11-12-2007', 'dd-mm-yyyy'), to_date('25-12-2007', 'dd-mm-yyyy'), 2, 6091, to_date('31-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090818017376, to_date('18-08-2009', 'dd-mm-yyyy'), to_date('01-09-2009', 'dd-mm-yyyy'), 1, 8696, to_date('05-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140106017377, to_date('06-01-2014', 'dd-mm-yyyy'), to_date('20-01-2014', 'dd-mm-yyyy'), 2, 8991, to_date('16-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023017378, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 1, 1936, to_date('24-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110322017379, to_date('22-03-2011', 'dd-mm-yyyy'), to_date('05-04-2011', 'dd-mm-yyyy'), 2, 9666, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030813017380, to_date('13-08-2003', 'dd-mm-yyyy'), to_date('27-08-2003', 'dd-mm-yyyy'), 2, 2870, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116017381, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 2, 5210, to_date('22-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070720017382, to_date('20-07-2007', 'dd-mm-yyyy'), to_date('03-08-2007', 'dd-mm-yyyy'), 1, 3591, to_date('04-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120606017383, to_date('06-06-2012', 'dd-mm-yyyy'), to_date('20-06-2012', 'dd-mm-yyyy'), 1, 7197, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061010017384, to_date('10-10-2006', 'dd-mm-yyyy'), to_date('24-10-2006', 'dd-mm-yyyy'), 2, 6919, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011215017385, to_date('15-12-2001', 'dd-mm-yyyy'), to_date('29-12-2001', 'dd-mm-yyyy'), 1, 2871, to_date('04-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100311017386, to_date('11-03-2010', 'dd-mm-yyyy'), to_date('25-03-2010', 'dd-mm-yyyy'), 2, 7502, to_date('30-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140322017387, to_date('22-03-2014', 'dd-mm-yyyy'), to_date('05-04-2014', 'dd-mm-yyyy'), 2, 8830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031223017388, to_date('23-12-2003', 'dd-mm-yyyy'), to_date('06-01-2004', 'dd-mm-yyyy'), 1, 3332, to_date('04-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130820017389, to_date('20-08-2013', 'dd-mm-yyyy'), to_date('03-09-2013', 'dd-mm-yyyy'), 2, 7424, to_date('30-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100808017390, to_date('08-08-2010', 'dd-mm-yyyy'), to_date('22-08-2010', 'dd-mm-yyyy'), 1, 7884, to_date('21-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203017391, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 2, 3680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081108017392, to_date('08-11-2008', 'dd-mm-yyyy'), to_date('22-11-2008', 'dd-mm-yyyy'), 1, 4534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816017393, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 1, 8812, to_date('24-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101030017394, to_date('30-10-2010', 'dd-mm-yyyy'), to_date('13-11-2010', 'dd-mm-yyyy'), 1, 9270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050616017395, to_date('16-06-2005', 'dd-mm-yyyy'), to_date('30-06-2005', 'dd-mm-yyyy'), 2, 6455, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608017396, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 2, 8228, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404017397, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 1, 6684, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812017398, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 1, 10553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424017399, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 2, 7746, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906017400, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 1, 7440, to_date('10-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020122017401, to_date('22-01-2002', 'dd-mm-yyyy'), to_date('05-02-2002', 'dd-mm-yyyy'), 1, 2254, to_date('25-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120618017402, to_date('18-06-2012', 'dd-mm-yyyy'), to_date('02-07-2012', 'dd-mm-yyyy'), 1, 6913, to_date('22-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100222017403, to_date('22-02-2010', 'dd-mm-yyyy'), to_date('08-03-2010', 'dd-mm-yyyy'), 2, 6013, to_date('07-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001031017404, to_date('31-10-2000', 'dd-mm-yyyy'), to_date('14-11-2000', 'dd-mm-yyyy'), 1, 669, to_date('13-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010927017405, to_date('27-09-2001', 'dd-mm-yyyy'), to_date('11-10-2001', 'dd-mm-yyyy'), 1, 2285, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120121017406, to_date('21-01-2012', 'dd-mm-yyyy'), to_date('04-02-2012', 'dd-mm-yyyy'), 1, 5817, to_date('09-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120828017407, to_date('28-08-2012', 'dd-mm-yyyy'), to_date('11-09-2012', 'dd-mm-yyyy'), 2, 8951, to_date('07-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040216017408, to_date('16-02-2004', 'dd-mm-yyyy'), to_date('01-03-2004', 'dd-mm-yyyy'), 1, 4092, to_date('06-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031013017409, to_date('13-10-2003', 'dd-mm-yyyy'), to_date('27-10-2003', 'dd-mm-yyyy'), 2, 2708, to_date('18-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080814009330, to_date('14-08-2008', 'dd-mm-yyyy'), to_date('28-08-2008', 'dd-mm-yyyy'), 11, 4612, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121121009331, to_date('21-11-2012', 'dd-mm-yyyy'), to_date('05-12-2012', 'dd-mm-yyyy'), 8, 7959, to_date('26-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100521009332, to_date('21-05-2010', 'dd-mm-yyyy'), to_date('04-06-2010', 'dd-mm-yyyy'), 7, 7119, to_date('01-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001106009333, to_date('06-11-2000', 'dd-mm-yyyy'), to_date('20-11-2000', 'dd-mm-yyyy'), 8, 1028, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020509009334, to_date('09-05-2002', 'dd-mm-yyyy'), to_date('23-05-2002', 'dd-mm-yyyy'), 4, 3126, to_date('24-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120920009335, to_date('20-09-2012', 'dd-mm-yyyy'), to_date('04-10-2012', 'dd-mm-yyyy'), 3, 7765, to_date('08-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060529009336, to_date('29-05-2006', 'dd-mm-yyyy'), to_date('12-06-2006', 'dd-mm-yyyy'), 12, 5808, to_date('07-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060806009337, to_date('06-08-2006', 'dd-mm-yyyy'), to_date('20-08-2006', 'dd-mm-yyyy'), 1, 5685, to_date('21-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091112009338, to_date('12-11-2009', 'dd-mm-yyyy'), to_date('26-11-2009', 'dd-mm-yyyy'), 9, 6323, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071021009339, to_date('21-10-2007', 'dd-mm-yyyy'), to_date('04-11-2007', 'dd-mm-yyyy'), 4, 5402, to_date('22-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110709009340, to_date('09-07-2011', 'dd-mm-yyyy'), to_date('23-07-2011', 'dd-mm-yyyy'), 11, 8242, to_date('11-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110806009341, to_date('06-08-2011', 'dd-mm-yyyy'), to_date('20-08-2011', 'dd-mm-yyyy'), 8, 7408, to_date('15-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120305009342, to_date('05-03-2012', 'dd-mm-yyyy'), to_date('19-03-2012', 'dd-mm-yyyy'), 12, 7724, to_date('22-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081228009343, to_date('28-12-2008', 'dd-mm-yyyy'), to_date('11-01-2009', 'dd-mm-yyyy'), 11, 7001, to_date('05-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812009344, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 4, 9980, to_date('16-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030109009345, to_date('09-01-2003', 'dd-mm-yyyy'), to_date('23-01-2003', 'dd-mm-yyyy'), 2, 2115, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060603009346, to_date('03-06-2006', 'dd-mm-yyyy'), to_date('17-06-2006', 'dd-mm-yyyy'), 1, 4177, to_date('04-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608009347, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 9, 7119, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100721009348, to_date('21-07-2010', 'dd-mm-yyyy'), to_date('04-08-2010', 'dd-mm-yyyy'), 9, 6196, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111009349, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 12, 4587, to_date('16-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515009350, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 2, 1349, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110608009351, to_date('08-06-2011', 'dd-mm-yyyy'), to_date('22-06-2011', 'dd-mm-yyyy'), 10, 8860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130127009352, to_date('27-01-2013', 'dd-mm-yyyy'), to_date('10-02-2013', 'dd-mm-yyyy'), 4, 10279, to_date('10-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111127009353, to_date('27-11-2011', 'dd-mm-yyyy'), to_date('11-12-2011', 'dd-mm-yyyy'), 11, 6588, to_date('28-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060908009354, to_date('08-09-2006', 'dd-mm-yyyy'), to_date('22-09-2006', 'dd-mm-yyyy'), 4, 6868, to_date('10-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101204009355, to_date('04-12-2010', 'dd-mm-yyyy'), to_date('18-12-2010', 'dd-mm-yyyy'), 6, 9445, to_date('21-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917009356, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 1, 6701, to_date('29-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050821009357, to_date('21-08-2005', 'dd-mm-yyyy'), to_date('04-09-2005', 'dd-mm-yyyy'), 1, 3619, to_date('29-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120723009358, to_date('23-07-2012', 'dd-mm-yyyy'), to_date('06-08-2012', 'dd-mm-yyyy'), 7, 9374, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090112009359, to_date('12-01-2009', 'dd-mm-yyyy'), to_date('26-01-2009', 'dd-mm-yyyy'), 2, 8191, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090313009360, to_date('13-03-2009', 'dd-mm-yyyy'), to_date('27-03-2009', 'dd-mm-yyyy'), 2, 5868, to_date('15-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050904009361, to_date('04-09-2005', 'dd-mm-yyyy'), to_date('18-09-2005', 'dd-mm-yyyy'), 8, 3798, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140209009362, to_date('09-02-2014', 'dd-mm-yyyy'), to_date('23-02-2014', 'dd-mm-yyyy'), 8, 8819, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081215009363, to_date('15-12-2008', 'dd-mm-yyyy'), to_date('29-12-2008', 'dd-mm-yyyy'), 8, 6767, to_date('19-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020527009364, to_date('27-05-2002', 'dd-mm-yyyy'), to_date('10-06-2002', 'dd-mm-yyyy'), 7, 1871, to_date('30-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111015009365, to_date('15-10-2011', 'dd-mm-yyyy'), to_date('29-10-2011', 'dd-mm-yyyy'), 8, 7730, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040607009366, to_date('07-06-2004', 'dd-mm-yyyy'), to_date('21-06-2004', 'dd-mm-yyyy'), 8, 4633, to_date('08-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140421009367, to_date('21-04-2014', 'dd-mm-yyyy'), to_date('05-05-2014', 'dd-mm-yyyy'), 1, 6864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122009368, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 6, 3828, to_date('30-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031008009369, to_date('08-10-2003', 'dd-mm-yyyy'), to_date('22-10-2003', 'dd-mm-yyyy'), 3, 2797, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331009370, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 8, 1732, to_date('18-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101102009371, to_date('02-11-2010', 'dd-mm-yyyy'), to_date('16-11-2010', 'dd-mm-yyyy'), 8, 7180, to_date('14-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070913009372, to_date('13-09-2007', 'dd-mm-yyyy'), to_date('27-09-2007', 'dd-mm-yyyy'), 3, 5346, to_date('15-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071214009373, to_date('14-12-2007', 'dd-mm-yyyy'), to_date('28-12-2007', 'dd-mm-yyyy'), 5, 4879, to_date('30-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111015009374, to_date('15-10-2011', 'dd-mm-yyyy'), to_date('29-10-2011', 'dd-mm-yyyy'), 10, 5461, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090831009375, to_date('31-08-2009', 'dd-mm-yyyy'), to_date('14-09-2009', 'dd-mm-yyyy'), 3, 5148, to_date('07-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040614009376, to_date('14-06-2004', 'dd-mm-yyyy'), to_date('28-06-2004', 'dd-mm-yyyy'), 7, 2828, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040920009377, to_date('20-09-2004', 'dd-mm-yyyy'), to_date('04-10-2004', 'dd-mm-yyyy'), 2, 3390, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100422009378, to_date('22-04-2010', 'dd-mm-yyyy'), to_date('06-05-2010', 'dd-mm-yyyy'), 7, 4840, to_date('26-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091121009379, to_date('21-11-2009', 'dd-mm-yyyy'), to_date('05-12-2009', 'dd-mm-yyyy'), 11, 5887, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100919009380, to_date('19-09-2010', 'dd-mm-yyyy'), to_date('03-10-2010', 'dd-mm-yyyy'), 1, 5402, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111125009381, to_date('25-11-2011', 'dd-mm-yyyy'), to_date('09-12-2011', 'dd-mm-yyyy'), 2, 7152, to_date('01-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051119009382, to_date('19-11-2005', 'dd-mm-yyyy'), to_date('03-12-2005', 'dd-mm-yyyy'), 10, 5692, to_date('30-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331009383, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 9, 3472, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110413009384, to_date('13-04-2011', 'dd-mm-yyyy'), to_date('27-04-2011', 'dd-mm-yyyy'), 11, 6471, to_date('22-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002009385, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 7, 5148, to_date('19-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727009386, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 4, 1696, to_date('14-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225009387, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 3, 3278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130103009388, to_date('03-01-2013', 'dd-mm-yyyy'), to_date('17-01-2013', 'dd-mm-yyyy'), 8, 9314, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041117009389, to_date('17-11-2004', 'dd-mm-yyyy'), to_date('01-12-2004', 'dd-mm-yyyy'), 10, 4622, to_date('06-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040815009390, to_date('15-08-2004', 'dd-mm-yyyy'), to_date('29-08-2004', 'dd-mm-yyyy'), 12, 3637, to_date('20-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302009391, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 4, 6705, to_date('07-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070717009392, to_date('17-07-2007', 'dd-mm-yyyy'), to_date('31-07-2007', 'dd-mm-yyyy'), 11, 6218, to_date('30-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509009393, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 10, 6220, to_date('13-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021012009394, to_date('12-10-2002', 'dd-mm-yyyy'), to_date('26-10-2002', 'dd-mm-yyyy'), 6, 2154, to_date('24-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061004009395, to_date('04-10-2006', 'dd-mm-yyyy'), to_date('18-10-2006', 'dd-mm-yyyy'), 9, 5155, to_date('05-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010713009396, to_date('13-07-2001', 'dd-mm-yyyy'), to_date('27-07-2001', 'dd-mm-yyyy'), 7, 2618, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130610009397, to_date('10-06-2013', 'dd-mm-yyyy'), to_date('24-06-2013', 'dd-mm-yyyy'), 11, 8230, to_date('24-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050620009398, to_date('20-06-2005', 'dd-mm-yyyy'), to_date('04-07-2005', 'dd-mm-yyyy'), 5, 5039, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071121009399, to_date('21-11-2007', 'dd-mm-yyyy'), to_date('05-12-2007', 'dd-mm-yyyy'), 2, 4711, to_date('02-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040719009400, to_date('19-07-2004', 'dd-mm-yyyy'), to_date('02-08-2004', 'dd-mm-yyyy'), 7, 3659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041109009401, to_date('09-11-2004', 'dd-mm-yyyy'), to_date('23-11-2004', 'dd-mm-yyyy'), 2, 4107, to_date('11-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020613009402, to_date('13-06-2002', 'dd-mm-yyyy'), to_date('27-06-2002', 'dd-mm-yyyy'), 8, 2879, to_date('17-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120430009403, to_date('30-04-2012', 'dd-mm-yyyy'), to_date('14-05-2012', 'dd-mm-yyyy'), 9, 8391, to_date('18-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827009404, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 11, 4323, to_date('31-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000204009405, to_date('04-02-2000', 'dd-mm-yyyy'), to_date('18-02-2000', 'dd-mm-yyyy'), 9, 2599, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041111009406, to_date('11-11-2004', 'dd-mm-yyyy'), to_date('25-11-2004', 'dd-mm-yyyy'), 8, 3288, to_date('14-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140508009407, to_date('08-05-2014', 'dd-mm-yyyy'), to_date('22-05-2014', 'dd-mm-yyyy'), 7, 10044, to_date('20-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080117009408, to_date('17-01-2008', 'dd-mm-yyyy'), to_date('31-01-2008', 'dd-mm-yyyy'), 2, 8314, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703009409, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 6, 528, to_date('21-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060221009410, to_date('21-02-2006', 'dd-mm-yyyy'), to_date('07-03-2006', 'dd-mm-yyyy'), 7, 3910, to_date('01-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010110009411, to_date('10-01-2001', 'dd-mm-yyyy'), to_date('24-01-2001', 'dd-mm-yyyy'), 2, 2672, to_date('13-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429009412, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 5, 1878, to_date('15-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060521009413, to_date('21-05-2006', 'dd-mm-yyyy'), to_date('04-06-2006', 'dd-mm-yyyy'), 1, 5687, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140202009414, to_date('02-02-2014', 'dd-mm-yyyy'), to_date('16-02-2014', 'dd-mm-yyyy'), 2, 11039, to_date('07-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140418009415, to_date('18-04-2014', 'dd-mm-yyyy'), to_date('02-05-2014', 'dd-mm-yyyy'), 9, 8960, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121101009416, to_date('01-11-2012', 'dd-mm-yyyy'), to_date('15-11-2012', 'dd-mm-yyyy'), 8, 8159, to_date('19-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091129009417, to_date('29-11-2009', 'dd-mm-yyyy'), to_date('13-12-2009', 'dd-mm-yyyy'), 2, 6221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130404009418, to_date('04-04-2013', 'dd-mm-yyyy'), to_date('18-04-2013', 'dd-mm-yyyy'), 10, 7831, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000509009419, to_date('09-05-2000', 'dd-mm-yyyy'), to_date('23-05-2000', 'dd-mm-yyyy'), 12, 1351, to_date('18-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100102009420, to_date('02-01-2010', 'dd-mm-yyyy'), to_date('16-01-2010', 'dd-mm-yyyy'), 3, 7511, to_date('07-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090709009421, to_date('09-07-2009', 'dd-mm-yyyy'), to_date('23-07-2009', 'dd-mm-yyyy'), 12, 3376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100220009422, to_date('20-02-2010', 'dd-mm-yyyy'), to_date('06-03-2010', 'dd-mm-yyyy'), 4, 7478, to_date('25-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070311009423, to_date('11-03-2007', 'dd-mm-yyyy'), to_date('25-03-2007', 'dd-mm-yyyy'), 8, 6409, to_date('14-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100907009424, to_date('07-09-2010', 'dd-mm-yyyy'), to_date('21-09-2010', 'dd-mm-yyyy'), 4, 6033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220009425, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 3, 7425, to_date('11-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120218009426, to_date('18-02-2012', 'dd-mm-yyyy'), to_date('03-03-2012', 'dd-mm-yyyy'), 11, 7858, to_date('24-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130208009427, to_date('08-02-2013', 'dd-mm-yyyy'), to_date('22-02-2013', 'dd-mm-yyyy'), 9, 8908, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070729009428, to_date('29-07-2007', 'dd-mm-yyyy'), to_date('12-08-2007', 'dd-mm-yyyy'), 8, 6151, to_date('05-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020401009429, to_date('01-04-2002', 'dd-mm-yyyy'), to_date('15-04-2002', 'dd-mm-yyyy'), 7, 2459, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000821009430, to_date('21-08-2000', 'dd-mm-yyyy'), to_date('04-09-2000', 'dd-mm-yyyy'), 5, 1473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105009431, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 12, 3446, to_date('07-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061227009432, to_date('27-12-2006', 'dd-mm-yyyy'), to_date('10-01-2007', 'dd-mm-yyyy'), 11, 4840, to_date('13-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101117009433, to_date('17-11-2010', 'dd-mm-yyyy'), to_date('01-12-2010', 'dd-mm-yyyy'), 2, 6639, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923009434, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 12, 2266, to_date('05-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010724009435, to_date('24-07-2001', 'dd-mm-yyyy'), to_date('07-08-2001', 'dd-mm-yyyy'), 12, 2261, to_date('08-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050502009436, to_date('02-05-2005', 'dd-mm-yyyy'), to_date('16-05-2005', 'dd-mm-yyyy'), 7, 2815, to_date('14-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427009437, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 1, 2705, to_date('10-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070315009438, to_date('15-03-2007', 'dd-mm-yyyy'), to_date('29-03-2007', 'dd-mm-yyyy'), 8, 4529, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131108009439, to_date('08-11-2013', 'dd-mm-yyyy'), to_date('22-11-2013', 'dd-mm-yyyy'), 5, 7725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120516009440, to_date('16-05-2012', 'dd-mm-yyyy'), to_date('30-05-2012', 'dd-mm-yyyy'), 5, 6083, to_date('23-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607009441, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 3, 4317, to_date('14-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004009442, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 6, 9781, to_date('14-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071207009443, to_date('07-12-2007', 'dd-mm-yyyy'), to_date('21-12-2007', 'dd-mm-yyyy'), 10, 6079, to_date('27-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021008009444, to_date('08-10-2002', 'dd-mm-yyyy'), to_date('22-10-2002', 'dd-mm-yyyy'), 7, 3639, to_date('22-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060729009445, to_date('29-07-2006', 'dd-mm-yyyy'), to_date('12-08-2006', 'dd-mm-yyyy'), 8, 5785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090906009446, to_date('06-09-2009', 'dd-mm-yyyy'), to_date('20-09-2009', 'dd-mm-yyyy'), 2, 6210, to_date('19-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626009447, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 4, 6850, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040901009448, to_date('01-09-2004', 'dd-mm-yyyy'), to_date('15-09-2004', 'dd-mm-yyyy'), 12, 3801, to_date('06-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000611009449, to_date('11-06-2000', 'dd-mm-yyyy'), to_date('25-06-2000', 'dd-mm-yyyy'), 1, 1911, to_date('01-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111219009450, to_date('19-12-2011', 'dd-mm-yyyy'), to_date('02-01-2012', 'dd-mm-yyyy'), 5, 7872, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080221009451, to_date('21-02-2008', 'dd-mm-yyyy'), to_date('06-03-2008', 'dd-mm-yyyy'), 12, 6880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010104009452, to_date('04-01-2001', 'dd-mm-yyyy'), to_date('18-01-2001', 'dd-mm-yyyy'), 3, 1812, to_date('08-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303009453, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 7, 4817, to_date('20-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080205009454, to_date('05-02-2008', 'dd-mm-yyyy'), to_date('19-02-2008', 'dd-mm-yyyy'), 6, 6377, to_date('17-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120701009455, to_date('01-07-2012', 'dd-mm-yyyy'), to_date('15-07-2012', 'dd-mm-yyyy'), 11, 8248, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030603009456, to_date('03-06-2003', 'dd-mm-yyyy'), to_date('17-06-2003', 'dd-mm-yyyy'), 4, 3766, to_date('05-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000121009457, to_date('21-01-2000', 'dd-mm-yyyy'), to_date('04-02-2000', 'dd-mm-yyyy'), 4, 1534, to_date('24-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050604009458, to_date('04-06-2005', 'dd-mm-yyyy'), to_date('18-06-2005', 'dd-mm-yyyy'), 10, 3117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121202009459, to_date('02-12-2012', 'dd-mm-yyyy'), to_date('16-12-2012', 'dd-mm-yyyy'), 10, 7655, to_date('11-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319009460, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 5, 3735, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040127009461, to_date('27-01-2004', 'dd-mm-yyyy'), to_date('10-02-2004', 'dd-mm-yyyy'), 4, 2829, to_date('02-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130919009462, to_date('19-09-2013', 'dd-mm-yyyy'), to_date('03-10-2013', 'dd-mm-yyyy'), 6, 10012, to_date('30-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030218009463, to_date('18-02-2003', 'dd-mm-yyyy'), to_date('04-03-2003', 'dd-mm-yyyy'), 10, 4511, to_date('04-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070509009464, to_date('09-05-2007', 'dd-mm-yyyy'), to_date('23-05-2007', 'dd-mm-yyyy'), 5, 4400, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429009465, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 5, 1064, to_date('16-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000728009466, to_date('28-07-2000', 'dd-mm-yyyy'), to_date('11-08-2000', 'dd-mm-yyyy'), 7, 2323, to_date('16-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061227009467, to_date('27-12-2006', 'dd-mm-yyyy'), to_date('10-01-2007', 'dd-mm-yyyy'), 1, 4715, to_date('12-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080519009468, to_date('19-05-2008', 'dd-mm-yyyy'), to_date('02-06-2008', 'dd-mm-yyyy'), 9, 8576, to_date('07-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001106009469, to_date('06-11-2000', 'dd-mm-yyyy'), to_date('20-11-2000', 'dd-mm-yyyy'), 2, 1558, to_date('24-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226009470, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 5, 4490, to_date('13-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121009471, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 6, 4395, to_date('26-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430009472, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 7, 5450, to_date('03-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100420009473, to_date('20-04-2010', 'dd-mm-yyyy'), to_date('04-05-2010', 'dd-mm-yyyy'), 5, 3235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071018009474, to_date('18-10-2007', 'dd-mm-yyyy'), to_date('01-11-2007', 'dd-mm-yyyy'), 8, 5996, to_date('23-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040814009475, to_date('14-08-2004', 'dd-mm-yyyy'), to_date('28-08-2004', 'dd-mm-yyyy'), 4, 2492, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060419009476, to_date('19-04-2006', 'dd-mm-yyyy'), to_date('03-05-2006', 'dd-mm-yyyy'), 8, 6624, to_date('23-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121012009477, to_date('12-10-2012', 'dd-mm-yyyy'), to_date('26-10-2012', 'dd-mm-yyyy'), 9, 9217, to_date('22-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040627009478, to_date('27-06-2004', 'dd-mm-yyyy'), to_date('11-07-2004', 'dd-mm-yyyy'), 6, 3993, to_date('09-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071115009479, to_date('15-11-2007', 'dd-mm-yyyy'), to_date('29-11-2007', 'dd-mm-yyyy'), 10, 3811, to_date('19-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090407009480, to_date('07-04-2009', 'dd-mm-yyyy'), to_date('21-04-2009', 'dd-mm-yyyy'), 9, 6096, to_date('08-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307009481, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 11, 3944, to_date('11-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051118009482, to_date('18-11-2005', 'dd-mm-yyyy'), to_date('02-12-2005', 'dd-mm-yyyy'), 2, 4433, to_date('07-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222009483, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 7, 7099, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418011853, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 9, 1761, to_date('26-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040814011854, to_date('14-08-2004', 'dd-mm-yyyy'), to_date('28-08-2004', 'dd-mm-yyyy'), 6, 4105, to_date('31-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081220011855, to_date('20-12-2008', 'dd-mm-yyyy'), to_date('03-01-2009', 'dd-mm-yyyy'), 7, 5708, to_date('30-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090726011856, to_date('26-07-2009', 'dd-mm-yyyy'), to_date('09-08-2009', 'dd-mm-yyyy'), 5, 6538, to_date('31-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110131011857, to_date('31-01-2011', 'dd-mm-yyyy'), to_date('14-02-2011', 'dd-mm-yyyy'), 11, 4401, to_date('14-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070120011858, to_date('20-01-2007', 'dd-mm-yyyy'), to_date('03-02-2007', 'dd-mm-yyyy'), 4, 6662, to_date('06-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110310011859, to_date('10-03-2011', 'dd-mm-yyyy'), to_date('24-03-2011', 'dd-mm-yyyy'), 5, 9474, to_date('22-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006011860, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 6, 7420, to_date('22-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130519011861, to_date('19-05-2013', 'dd-mm-yyyy'), to_date('02-06-2013', 'dd-mm-yyyy'), 4, 10088, to_date('27-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060614011862, to_date('14-06-2006', 'dd-mm-yyyy'), to_date('28-06-2006', 'dd-mm-yyyy'), 8, 3777, to_date('03-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100126011863, to_date('26-01-2010', 'dd-mm-yyyy'), to_date('09-02-2010', 'dd-mm-yyyy'), 6, 6986, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131125011864, to_date('25-11-2013', 'dd-mm-yyyy'), to_date('09-12-2013', 'dd-mm-yyyy'), 11, 4962, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040728011865, to_date('28-07-2004', 'dd-mm-yyyy'), to_date('11-08-2004', 'dd-mm-yyyy'), 6, 5696, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000708011866, to_date('08-07-2000', 'dd-mm-yyyy'), to_date('22-07-2000', 'dd-mm-yyyy'), 9, 462, to_date('10-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110414011867, to_date('14-04-2011', 'dd-mm-yyyy'), to_date('28-04-2011', 'dd-mm-yyyy'), 6, 8007, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110823011868, to_date('23-08-2011', 'dd-mm-yyyy'), to_date('06-09-2011', 'dd-mm-yyyy'), 6, 8232, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090921011869, to_date('21-09-2009', 'dd-mm-yyyy'), to_date('05-10-2009', 'dd-mm-yyyy'), 2, 8091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081127011870, to_date('27-11-2008', 'dd-mm-yyyy'), to_date('11-12-2008', 'dd-mm-yyyy'), 2, 6877, to_date('05-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204011871, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 6, 2661, to_date('11-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110619011872, to_date('19-06-2011', 'dd-mm-yyyy'), to_date('03-07-2011', 'dd-mm-yyyy'), 5, 7707, to_date('26-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010626011873, to_date('26-06-2001', 'dd-mm-yyyy'), to_date('10-07-2001', 'dd-mm-yyyy'), 11, 3672, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100317011874, to_date('17-03-2010', 'dd-mm-yyyy'), to_date('31-03-2010', 'dd-mm-yyyy'), 7, 6194, to_date('29-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100513011875, to_date('13-05-2010', 'dd-mm-yyyy'), to_date('27-05-2010', 'dd-mm-yyyy'), 5, 5188, to_date('31-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070811011876, to_date('11-08-2007', 'dd-mm-yyyy'), to_date('25-08-2007', 'dd-mm-yyyy'), 6, 5010, to_date('23-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020728011877, to_date('28-07-2002', 'dd-mm-yyyy'), to_date('11-08-2002', 'dd-mm-yyyy'), 7, 2531, to_date('05-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061025011878, to_date('25-10-2006', 'dd-mm-yyyy'), to_date('08-11-2006', 'dd-mm-yyyy'), 3, 6403, to_date('01-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723011879, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 3, 10525, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130731011880, to_date('31-07-2013', 'dd-mm-yyyy'), to_date('14-08-2013', 'dd-mm-yyyy'), 9, 8904, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100323011881, to_date('23-03-2010', 'dd-mm-yyyy'), to_date('06-04-2010', 'dd-mm-yyyy'), 2, 6980, to_date('08-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050509011882, to_date('09-05-2005', 'dd-mm-yyyy'), to_date('23-05-2005', 'dd-mm-yyyy'), 3, 4665, to_date('16-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010723011883, to_date('23-07-2001', 'dd-mm-yyyy'), to_date('06-08-2001', 'dd-mm-yyyy'), 11, 2151, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000830011884, to_date('30-08-2000', 'dd-mm-yyyy'), to_date('13-09-2000', 'dd-mm-yyyy'), 8, 634, to_date('10-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010305011885, to_date('05-03-2001', 'dd-mm-yyyy'), to_date('19-03-2001', 'dd-mm-yyyy'), 8, 2263, to_date('16-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318011886, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 8, 5226, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000826011887, to_date('26-08-2000', 'dd-mm-yyyy'), to_date('09-09-2000', 'dd-mm-yyyy'), 6, 1651, to_date('29-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140102011888, to_date('02-01-2014', 'dd-mm-yyyy'), to_date('16-01-2014', 'dd-mm-yyyy'), 6, 7162, to_date('16-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130408011889, to_date('08-04-2013', 'dd-mm-yyyy'), to_date('22-04-2013', 'dd-mm-yyyy'), 3, 11590, to_date('18-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111217011890, to_date('17-12-2011', 'dd-mm-yyyy'), to_date('31-12-2011', 'dd-mm-yyyy'), 5, 8444, to_date('20-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080517011891, to_date('17-05-2008', 'dd-mm-yyyy'), to_date('31-05-2008', 'dd-mm-yyyy'), 12, 7662, to_date('28-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080218011892, to_date('18-02-2008', 'dd-mm-yyyy'), to_date('03-03-2008', 'dd-mm-yyyy'), 8, 6271, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217011893, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 11, 2552, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224011894, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 5, 7301, to_date('03-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816011895, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 1, 8315, to_date('04-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120609011896, to_date('09-06-2012', 'dd-mm-yyyy'), to_date('23-06-2012', 'dd-mm-yyyy'), 11, 9300, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021016011897, to_date('16-10-2002', 'dd-mm-yyyy'), to_date('30-10-2002', 'dd-mm-yyyy'), 6, 2417, to_date('01-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220011898, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 8, 9580, to_date('12-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110830011899, to_date('30-08-2011', 'dd-mm-yyyy'), to_date('13-09-2011', 'dd-mm-yyyy'), 9, 8977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090204011900, to_date('04-02-2009', 'dd-mm-yyyy'), to_date('18-02-2009', 'dd-mm-yyyy'), 12, 5893, to_date('17-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001203011901, to_date('03-12-2000', 'dd-mm-yyyy'), to_date('17-12-2000', 'dd-mm-yyyy'), 6, 2314, to_date('10-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817011902, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 6, 6598, to_date('01-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110723011903, to_date('23-07-2011', 'dd-mm-yyyy'), to_date('06-08-2011', 'dd-mm-yyyy'), 8, 7777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101225011904, to_date('25-12-2010', 'dd-mm-yyyy'), to_date('08-01-2011', 'dd-mm-yyyy'), 11, 5996, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001029011905, to_date('29-10-2000', 'dd-mm-yyyy'), to_date('12-11-2000', 'dd-mm-yyyy'), 8, 3573, to_date('03-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090626011906, to_date('26-06-2009', 'dd-mm-yyyy'), to_date('10-07-2009', 'dd-mm-yyyy'), 1, 7760, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050923011907, to_date('23-09-2005', 'dd-mm-yyyy'), to_date('07-10-2005', 'dd-mm-yyyy'), 7, 4980, to_date('29-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050905011908, to_date('05-09-2005', 'dd-mm-yyyy'), to_date('19-09-2005', 'dd-mm-yyyy'), 1, 4773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031204011909, to_date('04-12-2003', 'dd-mm-yyyy'), to_date('18-12-2003', 'dd-mm-yyyy'), 5, 2550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100721011910, to_date('21-07-2010', 'dd-mm-yyyy'), to_date('04-08-2010', 'dd-mm-yyyy'), 9, 4866, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000610011911, to_date('10-06-2000', 'dd-mm-yyyy'), to_date('24-06-2000', 'dd-mm-yyyy'), 11, 2173, to_date('25-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120316011912, to_date('16-03-2012', 'dd-mm-yyyy'), to_date('30-03-2012', 'dd-mm-yyyy'), 10, 8297, to_date('18-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041218011913, to_date('18-12-2004', 'dd-mm-yyyy'), to_date('01-01-2005', 'dd-mm-yyyy'), 7, 5336, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060815011914, to_date('15-08-2006', 'dd-mm-yyyy'), to_date('29-08-2006', 'dd-mm-yyyy'), 3, 6405, to_date('04-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808011915, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 1, 4204, to_date('14-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020605011916, to_date('05-06-2002', 'dd-mm-yyyy'), to_date('19-06-2002', 'dd-mm-yyyy'), 7, 1933, to_date('10-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130820011917, to_date('20-08-2013', 'dd-mm-yyyy'), to_date('03-09-2013', 'dd-mm-yyyy'), 4, 7630, to_date('31-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090808011918, to_date('08-08-2009', 'dd-mm-yyyy'), to_date('22-08-2009', 'dd-mm-yyyy'), 9, 6973, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090731011919, to_date('31-07-2009', 'dd-mm-yyyy'), to_date('14-08-2009', 'dd-mm-yyyy'), 8, 4005, to_date('01-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120201011920, to_date('01-02-2012', 'dd-mm-yyyy'), to_date('15-02-2012', 'dd-mm-yyyy'), 9, 7642, to_date('15-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070208011921, to_date('08-02-2007', 'dd-mm-yyyy'), to_date('22-02-2007', 'dd-mm-yyyy'), 2, 5659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010321011922, to_date('21-03-2001', 'dd-mm-yyyy'), to_date('04-04-2001', 'dd-mm-yyyy'), 1, 2898, to_date('07-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010125011923, to_date('25-01-2001', 'dd-mm-yyyy'), to_date('08-02-2001', 'dd-mm-yyyy'), 1, 866, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140305011924, to_date('05-03-2014', 'dd-mm-yyyy'), to_date('19-03-2014', 'dd-mm-yyyy'), 9, 6654, to_date('25-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007011925, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 5, 4674, to_date('20-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000608011926, to_date('08-06-2000', 'dd-mm-yyyy'), to_date('22-06-2000', 'dd-mm-yyyy'), 12, 1704, to_date('21-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070309011927, to_date('09-03-2007', 'dd-mm-yyyy'), to_date('23-03-2007', 'dd-mm-yyyy'), 9, 6960, to_date('20-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011020011928, to_date('20-10-2001', 'dd-mm-yyyy'), to_date('03-11-2001', 'dd-mm-yyyy'), 1, 3754, to_date('04-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010719011929, to_date('19-07-2001', 'dd-mm-yyyy'), to_date('02-08-2001', 'dd-mm-yyyy'), 8, 853, to_date('06-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031212011930, to_date('12-12-2003', 'dd-mm-yyyy'), to_date('26-12-2003', 'dd-mm-yyyy'), 3, 6347, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030619011931, to_date('19-06-2003', 'dd-mm-yyyy'), to_date('03-07-2003', 'dd-mm-yyyy'), 11, 2202, to_date('05-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117011932, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 1, 8044, to_date('26-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000225011933, to_date('25-02-2000', 'dd-mm-yyyy'), to_date('10-03-2000', 'dd-mm-yyyy'), 4, 1938, to_date('06-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061107011934, to_date('07-11-2006', 'dd-mm-yyyy'), to_date('21-11-2006', 'dd-mm-yyyy'), 2, 5290, to_date('17-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050912011935, to_date('12-09-2005', 'dd-mm-yyyy'), to_date('26-09-2005', 'dd-mm-yyyy'), 11, 5008, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031110011936, to_date('10-11-2003', 'dd-mm-yyyy'), to_date('24-11-2003', 'dd-mm-yyyy'), 2, 4187, to_date('17-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020907011937, to_date('07-09-2002', 'dd-mm-yyyy'), to_date('21-09-2002', 'dd-mm-yyyy'), 6, 3071, to_date('14-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090516011938, to_date('16-05-2009', 'dd-mm-yyyy'), to_date('30-05-2009', 'dd-mm-yyyy'), 9, 6691, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001015011939, to_date('15-10-2000', 'dd-mm-yyyy'), to_date('29-10-2000', 'dd-mm-yyyy'), 6, 432, to_date('20-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110322011940, to_date('22-03-2011', 'dd-mm-yyyy'), to_date('05-04-2011', 'dd-mm-yyyy'), 7, 8466, to_date('24-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010117011941, to_date('17-01-2001', 'dd-mm-yyyy'), to_date('31-01-2001', 'dd-mm-yyyy'), 1, 2491, to_date('06-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020514011942, to_date('14-05-2002', 'dd-mm-yyyy'), to_date('28-05-2002', 'dd-mm-yyyy'), 2, 3938, to_date('21-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917011943, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 10, 6531, to_date('26-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802011944, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 11, 8982, to_date('04-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140106011945, to_date('06-01-2014', 'dd-mm-yyyy'), to_date('20-01-2014', 'dd-mm-yyyy'), 12, 10320, to_date('17-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120306011946, to_date('06-03-2012', 'dd-mm-yyyy'), to_date('20-03-2012', 'dd-mm-yyyy'), 1, 8692, to_date('11-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061031011947, to_date('31-10-2006', 'dd-mm-yyyy'), to_date('14-11-2006', 'dd-mm-yyyy'), 1, 5541, to_date('09-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000414011948, to_date('14-04-2000', 'dd-mm-yyyy'), to_date('28-04-2000', 'dd-mm-yyyy'), 2, 2465, to_date('01-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070317011949, to_date('17-03-2007', 'dd-mm-yyyy'), to_date('31-03-2007', 'dd-mm-yyyy'), 8, 5082, to_date('05-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811011950, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 12, 1068, to_date('21-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080917011951, to_date('17-09-2008', 'dd-mm-yyyy'), to_date('01-10-2008', 'dd-mm-yyyy'), 3, 4648, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040121011952, to_date('21-01-2004', 'dd-mm-yyyy'), to_date('04-02-2004', 'dd-mm-yyyy'), 2, 3860, to_date('09-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030617011953, to_date('17-06-2003', 'dd-mm-yyyy'), to_date('01-07-2003', 'dd-mm-yyyy'), 3, 2986, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020614011954, to_date('14-06-2002', 'dd-mm-yyyy'), to_date('28-06-2002', 'dd-mm-yyyy'), 7, 3592, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010721011955, to_date('21-07-2001', 'dd-mm-yyyy'), to_date('04-08-2001', 'dd-mm-yyyy'), 5, 3702, to_date('24-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080823011956, to_date('23-08-2008', 'dd-mm-yyyy'), to_date('06-09-2008', 'dd-mm-yyyy'), 6, 8123, to_date('30-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214011957, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 8, 4741, to_date('15-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070609011958, to_date('09-06-2007', 'dd-mm-yyyy'), to_date('23-06-2007', 'dd-mm-yyyy'), 4, 4415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040702011959, to_date('02-07-2004', 'dd-mm-yyyy'), to_date('16-07-2004', 'dd-mm-yyyy'), 7, 5016, to_date('11-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100213011960, to_date('13-02-2010', 'dd-mm-yyyy'), to_date('27-02-2010', 'dd-mm-yyyy'), 8, 5813, to_date('02-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615011961, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 8, 7906, to_date('27-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050805011962, to_date('05-08-2005', 'dd-mm-yyyy'), to_date('19-08-2005', 'dd-mm-yyyy'), 8, 3534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130707011963, to_date('07-07-2013', 'dd-mm-yyyy'), to_date('21-07-2013', 'dd-mm-yyyy'), 1, 7916, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081003011964, to_date('03-10-2008', 'dd-mm-yyyy'), to_date('17-10-2008', 'dd-mm-yyyy'), 8, 2459, to_date('09-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070429011965, to_date('29-04-2007', 'dd-mm-yyyy'), to_date('13-05-2007', 'dd-mm-yyyy'), 10, 7488, to_date('18-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100906011966, to_date('06-09-2010', 'dd-mm-yyyy'), to_date('20-09-2010', 'dd-mm-yyyy'), 9, 8063, to_date('15-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100620011967, to_date('20-06-2010', 'dd-mm-yyyy'), to_date('04-07-2010', 'dd-mm-yyyy'), 3, 6645, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060217011968, to_date('17-02-2006', 'dd-mm-yyyy'), to_date('03-03-2006', 'dd-mm-yyyy'), 4, 4439, to_date('07-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080403011969, to_date('03-04-2008', 'dd-mm-yyyy'), to_date('17-04-2008', 'dd-mm-yyyy'), 5, 5552, to_date('18-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040924011970, to_date('24-09-2004', 'dd-mm-yyyy'), to_date('08-10-2004', 'dd-mm-yyyy'), 5, 2853, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001216011971, to_date('16-12-2000', 'dd-mm-yyyy'), to_date('30-12-2000', 'dd-mm-yyyy'), 11, 1931, to_date('25-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080104011972, to_date('04-01-2008', 'dd-mm-yyyy'), to_date('18-01-2008', 'dd-mm-yyyy'), 4, 6359, to_date('14-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011006011973, to_date('06-10-2001', 'dd-mm-yyyy'), to_date('20-10-2001', 'dd-mm-yyyy'), 6, 1108, to_date('24-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060525011974, to_date('25-05-2006', 'dd-mm-yyyy'), to_date('08-06-2006', 'dd-mm-yyyy'), 1, 5516, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040103011975, to_date('03-01-2004', 'dd-mm-yyyy'), to_date('17-01-2004', 'dd-mm-yyyy'), 9, 4185, to_date('20-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080819011976, to_date('19-08-2008', 'dd-mm-yyyy'), to_date('02-09-2008', 'dd-mm-yyyy'), 11, 6262, to_date('27-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000217011977, to_date('17-02-2000', 'dd-mm-yyyy'), to_date('02-03-2000', 'dd-mm-yyyy'), 10, 3162, to_date('04-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031110011978, to_date('10-11-2003', 'dd-mm-yyyy'), to_date('24-11-2003', 'dd-mm-yyyy'), 10, 4545, to_date('12-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050714011979, to_date('14-07-2005', 'dd-mm-yyyy'), to_date('28-07-2005', 'dd-mm-yyyy'), 5, 4210, to_date('20-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323011980, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 12, 7927, to_date('12-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000319011981, to_date('19-03-2000', 'dd-mm-yyyy'), to_date('02-04-2000', 'dd-mm-yyyy'), 10, 1611, to_date('05-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130324011982, to_date('24-03-2013', 'dd-mm-yyyy'), to_date('07-04-2013', 'dd-mm-yyyy'), 1, 8823, to_date('04-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070704011983, to_date('04-07-2007', 'dd-mm-yyyy'), to_date('18-07-2007', 'dd-mm-yyyy'), 5, 4488, to_date('24-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031108011984, to_date('08-11-2003', 'dd-mm-yyyy'), to_date('22-11-2003', 'dd-mm-yyyy'), 9, 3461, to_date('18-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131229011985, to_date('29-12-2013', 'dd-mm-yyyy'), to_date('12-01-2014', 'dd-mm-yyyy'), 5, 9958, to_date('05-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110725011986, to_date('25-07-2011', 'dd-mm-yyyy'), to_date('08-08-2011', 'dd-mm-yyyy'), 7, 10147, to_date('27-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010508011987, to_date('08-05-2001', 'dd-mm-yyyy'), to_date('22-05-2001', 'dd-mm-yyyy'), 7, 2480, to_date('23-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100207011988, to_date('07-02-2010', 'dd-mm-yyyy'), to_date('21-02-2010', 'dd-mm-yyyy'), 2, 6519, to_date('19-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050916011989, to_date('16-09-2005', 'dd-mm-yyyy'), to_date('30-09-2005', 'dd-mm-yyyy'), 3, 5140, to_date('19-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131218011990, to_date('18-12-2013', 'dd-mm-yyyy'), to_date('01-01-2014', 'dd-mm-yyyy'), 5, 7159, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130305011991, to_date('05-03-2013', 'dd-mm-yyyy'), to_date('19-03-2013', 'dd-mm-yyyy'), 7, 11061, to_date('19-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131017011992, to_date('17-10-2013', 'dd-mm-yyyy'), to_date('31-10-2013', 'dd-mm-yyyy'), 10, 11315, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130403011993, to_date('03-04-2013', 'dd-mm-yyyy'), to_date('17-04-2013', 'dd-mm-yyyy'), 12, 8457, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010429011994, to_date('29-04-2001', 'dd-mm-yyyy'), to_date('13-05-2001', 'dd-mm-yyyy'), 9, 1718, to_date('08-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100326011995, to_date('26-03-2010', 'dd-mm-yyyy'), to_date('09-04-2010', 'dd-mm-yyyy'), 10, 7621, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070705011996, to_date('05-07-2007', 'dd-mm-yyyy'), to_date('19-07-2007', 'dd-mm-yyyy'), 5, 5864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130612011997, to_date('12-06-2013', 'dd-mm-yyyy'), to_date('26-06-2013', 'dd-mm-yyyy'), 3, 6991, to_date('19-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010618011998, to_date('18-06-2001', 'dd-mm-yyyy'), to_date('02-07-2001', 'dd-mm-yyyy'), 3, 1525, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060426011999, to_date('26-04-2006', 'dd-mm-yyyy'), to_date('10-05-2006', 'dd-mm-yyyy'), 10, 8556, to_date('15-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130012000, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 6, 5234, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519012001, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 4, 4903, to_date('22-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070715012002, to_date('15-07-2007', 'dd-mm-yyyy'), to_date('29-07-2007', 'dd-mm-yyyy'), 2, 6090, to_date('01-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041101012003, to_date('01-11-2004', 'dd-mm-yyyy'), to_date('15-11-2004', 'dd-mm-yyyy'), 4, 3632, to_date('16-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020521012004, to_date('21-05-2002', 'dd-mm-yyyy'), to_date('04-06-2002', 'dd-mm-yyyy'), 3, 3543, to_date('30-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090412012005, to_date('12-04-2009', 'dd-mm-yyyy'), to_date('26-04-2009', 'dd-mm-yyyy'), 3, 8157, to_date('27-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020531012006, to_date('31-05-2002', 'dd-mm-yyyy'), to_date('14-06-2002', 'dd-mm-yyyy'), 1, 3767, to_date('03-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020928012007, to_date('28-09-2002', 'dd-mm-yyyy'), to_date('12-10-2002', 'dd-mm-yyyy'), 3, 2393, to_date('18-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812012008, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 2, 6167, to_date('23-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101110012009, to_date('10-11-2010', 'dd-mm-yyyy'), to_date('24-11-2010', 'dd-mm-yyyy'), 4, 5698, to_date('14-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101023012010, to_date('23-10-2010', 'dd-mm-yyyy'), to_date('06-11-2010', 'dd-mm-yyyy'), 3, 6184, to_date('07-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130812012011, to_date('12-08-2013', 'dd-mm-yyyy'), to_date('26-08-2013', 'dd-mm-yyyy'), 2, 7227, to_date('31-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041106012012, to_date('06-11-2004', 'dd-mm-yyyy'), to_date('20-11-2004', 'dd-mm-yyyy'), 2, 3219, to_date('14-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060313012013, to_date('13-03-2006', 'dd-mm-yyyy'), to_date('27-03-2006', 'dd-mm-yyyy'), 3, 6144, to_date('26-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121023012014, to_date('23-10-2012', 'dd-mm-yyyy'), to_date('06-11-2012', 'dd-mm-yyyy'), 4, 8165, to_date('01-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217012015, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 2, 2705, to_date('06-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020514012016, to_date('14-05-2002', 'dd-mm-yyyy'), to_date('28-05-2002', 'dd-mm-yyyy'), 3, 4283, to_date('27-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030717012017, to_date('17-07-2003', 'dd-mm-yyyy'), to_date('31-07-2003', 'dd-mm-yyyy'), 2, 1816, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050626012018, to_date('26-06-2005', 'dd-mm-yyyy'), to_date('10-07-2005', 'dd-mm-yyyy'), 3, 4627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021105012019, to_date('05-11-2002', 'dd-mm-yyyy'), to_date('19-11-2002', 'dd-mm-yyyy'), 3, 1710, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090716014717, to_date('16-07-2009', 'dd-mm-yyyy'), to_date('30-07-2009', 'dd-mm-yyyy'), 3, 7426, to_date('29-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070805014718, to_date('05-08-2007', 'dd-mm-yyyy'), to_date('19-08-2007', 'dd-mm-yyyy'), 2, 3738, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010314014719, to_date('14-03-2001', 'dd-mm-yyyy'), to_date('28-03-2001', 'dd-mm-yyyy'), 2, 3142, to_date('24-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001102014720, to_date('02-11-2000', 'dd-mm-yyyy'), to_date('16-11-2000', 'dd-mm-yyyy'), 4, 1522, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100224014721, to_date('24-02-2010', 'dd-mm-yyyy'), to_date('10-03-2010', 'dd-mm-yyyy'), 2, 8680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130419014722, to_date('19-04-2013', 'dd-mm-yyyy'), to_date('03-05-2013', 'dd-mm-yyyy'), 3, 11126, to_date('24-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060903014723, to_date('03-09-2006', 'dd-mm-yyyy'), to_date('17-09-2006', 'dd-mm-yyyy'), 4, 3656, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061111014724, to_date('11-11-2006', 'dd-mm-yyyy'), to_date('25-11-2006', 'dd-mm-yyyy'), 3, 5441, to_date('23-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090916014725, to_date('16-09-2009', 'dd-mm-yyyy'), to_date('30-09-2009', 'dd-mm-yyyy'), 1, 5783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030507014726, to_date('07-05-2003', 'dd-mm-yyyy'), to_date('21-05-2003', 'dd-mm-yyyy'), 1, 5033, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130430014727, to_date('30-04-2013', 'dd-mm-yyyy'), to_date('14-05-2013', 'dd-mm-yyyy'), 1, 8539, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060530014728, to_date('30-05-2006', 'dd-mm-yyyy'), to_date('13-06-2006', 'dd-mm-yyyy'), 2, 5263, to_date('14-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703014729, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 4, 6631, to_date('22-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080622014730, to_date('22-06-2008', 'dd-mm-yyyy'), to_date('06-07-2008', 'dd-mm-yyyy'), 2, 6094, to_date('09-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120104014731, to_date('04-01-2012', 'dd-mm-yyyy'), to_date('18-01-2012', 'dd-mm-yyyy'), 4, 6811, to_date('09-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120922014732, to_date('22-09-2012', 'dd-mm-yyyy'), to_date('06-10-2012', 'dd-mm-yyyy'), 3, 6723, to_date('08-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040407014733, to_date('07-04-2004', 'dd-mm-yyyy'), to_date('21-04-2004', 'dd-mm-yyyy'), 3, 4228, to_date('12-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130915014734, to_date('15-09-2013', 'dd-mm-yyyy'), to_date('29-09-2013', 'dd-mm-yyyy'), 2, 8722, to_date('20-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090403014735, to_date('03-04-2009', 'dd-mm-yyyy'), to_date('17-04-2009', 'dd-mm-yyyy'), 1, 7643, to_date('16-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140126014736, to_date('26-01-2014', 'dd-mm-yyyy'), to_date('09-02-2014', 'dd-mm-yyyy'), 1, 9014, to_date('11-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051107014737, to_date('07-11-2005', 'dd-mm-yyyy'), to_date('21-11-2005', 'dd-mm-yyyy'), 3, 5329, to_date('19-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091215014738, to_date('15-12-2009', 'dd-mm-yyyy'), to_date('29-12-2009', 'dd-mm-yyyy'), 4, 6335, to_date('04-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080315014739, to_date('15-03-2008', 'dd-mm-yyyy'), to_date('29-03-2008', 'dd-mm-yyyy'), 1, 5538, to_date('01-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101014014740, to_date('14-10-2010', 'dd-mm-yyyy'), to_date('28-10-2010', 'dd-mm-yyyy'), 2, 8341, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050306014741, to_date('06-03-2005', 'dd-mm-yyyy'), to_date('20-03-2005', 'dd-mm-yyyy'), 3, 3885, to_date('10-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130419014742, to_date('19-04-2013', 'dd-mm-yyyy'), to_date('03-05-2013', 'dd-mm-yyyy'), 2, 10933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120829014743, to_date('29-08-2012', 'dd-mm-yyyy'), to_date('12-09-2012', 'dd-mm-yyyy'), 3, 6313, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080822014744, to_date('22-08-2008', 'dd-mm-yyyy'), to_date('05-09-2008', 'dd-mm-yyyy'), 3, 7183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119014745, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 3, 8543, to_date('08-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013014746, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 3, 5492, to_date('29-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061226014747, to_date('26-12-2006', 'dd-mm-yyyy'), to_date('09-01-2007', 'dd-mm-yyyy'), 2, 5751, to_date('08-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090830014748, to_date('30-08-2009', 'dd-mm-yyyy'), to_date('13-09-2009', 'dd-mm-yyyy'), 3, 7157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100618014749, to_date('18-06-2010', 'dd-mm-yyyy'), to_date('02-07-2010', 'dd-mm-yyyy'), 3, 8878, to_date('20-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050315014750, to_date('15-03-2005', 'dd-mm-yyyy'), to_date('29-03-2005', 'dd-mm-yyyy'), 4, 5611, to_date('17-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100428014751, to_date('28-04-2010', 'dd-mm-yyyy'), to_date('12-05-2010', 'dd-mm-yyyy'), 2, 6850, to_date('15-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101002014752, to_date('02-10-2010', 'dd-mm-yyyy'), to_date('16-10-2010', 'dd-mm-yyyy'), 3, 7283, to_date('05-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030726014753, to_date('26-07-2003', 'dd-mm-yyyy'), to_date('09-08-2003', 'dd-mm-yyyy'), 3, 3118, to_date('13-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410014754, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 2, 4572, to_date('22-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111212014755, to_date('12-12-2011', 'dd-mm-yyyy'), to_date('26-12-2011', 'dd-mm-yyyy'), 1, 10268, to_date('26-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100303014756, to_date('03-03-2010', 'dd-mm-yyyy'), to_date('17-03-2010', 'dd-mm-yyyy'), 4, 7941, to_date('12-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627014757, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 2, 4880, to_date('03-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110101014758, to_date('01-01-2011', 'dd-mm-yyyy'), to_date('15-01-2011', 'dd-mm-yyyy'), 3, 7035, to_date('17-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121112014759, to_date('12-11-2012', 'dd-mm-yyyy'), to_date('26-11-2012', 'dd-mm-yyyy'), 2, 10070, to_date('13-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513014760, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 2, 3605, to_date('16-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030308014761, to_date('08-03-2003', 'dd-mm-yyyy'), to_date('22-03-2003', 'dd-mm-yyyy'), 2, 1795, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010228014762, to_date('28-02-2001', 'dd-mm-yyyy'), to_date('14-03-2001', 'dd-mm-yyyy'), 2, 2003, to_date('04-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081104014763, to_date('04-11-2008', 'dd-mm-yyyy'), to_date('18-11-2008', 'dd-mm-yyyy'), 2, 8032, to_date('11-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140124014764, to_date('24-01-2014', 'dd-mm-yyyy'), to_date('07-02-2014', 'dd-mm-yyyy'), 4, 12213, to_date('31-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040401014765, to_date('01-04-2004', 'dd-mm-yyyy'), to_date('15-04-2004', 'dd-mm-yyyy'), 2, 2054, to_date('20-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001108014766, to_date('08-11-2000', 'dd-mm-yyyy'), to_date('22-11-2000', 'dd-mm-yyyy'), 2, 1519, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080224014767, to_date('24-02-2008', 'dd-mm-yyyy'), to_date('09-03-2008', 'dd-mm-yyyy'), 1, 6435, to_date('25-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040315014768, to_date('15-03-2004', 'dd-mm-yyyy'), to_date('29-03-2004', 'dd-mm-yyyy'), 1, 5918, to_date('28-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071128014769, to_date('28-11-2007', 'dd-mm-yyyy'), to_date('12-12-2007', 'dd-mm-yyyy'), 4, 4506, to_date('11-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110719014770, to_date('19-07-2011', 'dd-mm-yyyy'), to_date('02-08-2011', 'dd-mm-yyyy'), 2, 6967, to_date('20-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030318014771, to_date('18-03-2003', 'dd-mm-yyyy'), to_date('01-04-2003', 'dd-mm-yyyy'), 4, 3818, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090422014772, to_date('22-04-2009', 'dd-mm-yyyy'), to_date('06-05-2009', 'dd-mm-yyyy'), 2, 8195, to_date('08-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060627014773, to_date('27-06-2006', 'dd-mm-yyyy'), to_date('11-07-2006', 'dd-mm-yyyy'), 2, 4131, to_date('09-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725014774, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 2, 7313, to_date('05-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000821014775, to_date('21-08-2000', 'dd-mm-yyyy'), to_date('04-09-2000', 'dd-mm-yyyy'), 3, 1796, to_date('28-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912014776, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 4, 4392, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040803014777, to_date('03-08-2004', 'dd-mm-yyyy'), to_date('17-08-2004', 'dd-mm-yyyy'), 1, 2915, to_date('05-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130616014778, to_date('16-06-2013', 'dd-mm-yyyy'), to_date('30-06-2013', 'dd-mm-yyyy'), 4, 6982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110519014779, to_date('19-05-2011', 'dd-mm-yyyy'), to_date('02-06-2011', 'dd-mm-yyyy'), 2, 7019, to_date('31-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011103014780, to_date('03-11-2001', 'dd-mm-yyyy'), to_date('17-11-2001', 'dd-mm-yyyy'), 2, 2272, to_date('14-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130922014781, to_date('22-09-2013', 'dd-mm-yyyy'), to_date('06-10-2013', 'dd-mm-yyyy'), 1, 7266, to_date('08-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070825014782, to_date('25-08-2007', 'dd-mm-yyyy'), to_date('08-09-2007', 'dd-mm-yyyy'), 2, 5139, to_date('12-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021010014783, to_date('10-10-2002', 'dd-mm-yyyy'), to_date('24-10-2002', 'dd-mm-yyyy'), 2, 2916, to_date('22-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080916014784, to_date('16-09-2008', 'dd-mm-yyyy'), to_date('30-09-2008', 'dd-mm-yyyy'), 3, 5357, to_date('25-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608014785, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 2, 6412, to_date('23-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100511014786, to_date('11-05-2010', 'dd-mm-yyyy'), to_date('25-05-2010', 'dd-mm-yyyy'), 2, 5591, to_date('16-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030304014787, to_date('04-03-2003', 'dd-mm-yyyy'), to_date('18-03-2003', 'dd-mm-yyyy'), 1, 4848, to_date('17-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011206014788, to_date('06-12-2001', 'dd-mm-yyyy'), to_date('20-12-2001', 'dd-mm-yyyy'), 3, 2072, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020129014789, to_date('29-01-2002', 'dd-mm-yyyy'), to_date('12-02-2002', 'dd-mm-yyyy'), 2, 3659, to_date('12-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140404014790, to_date('04-04-2014', 'dd-mm-yyyy'), to_date('18-04-2014', 'dd-mm-yyyy'), 1, 8255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051017014791, to_date('17-10-2005', 'dd-mm-yyyy'), to_date('31-10-2005', 'dd-mm-yyyy'), 2, 5230, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140402014792, to_date('02-04-2014', 'dd-mm-yyyy'), to_date('16-04-2014', 'dd-mm-yyyy'), 3, 8500, to_date('16-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020919014793, to_date('19-09-2002', 'dd-mm-yyyy'), to_date('03-10-2002', 'dd-mm-yyyy'), 3, 2038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020717014794, to_date('17-07-2002', 'dd-mm-yyyy'), to_date('31-07-2002', 'dd-mm-yyyy'), 3, 3609, to_date('29-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061229014795, to_date('29-12-2006', 'dd-mm-yyyy'), to_date('12-01-2007', 'dd-mm-yyyy'), 3, 4960, to_date('04-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090908014796, to_date('08-09-2009', 'dd-mm-yyyy'), to_date('22-09-2009', 'dd-mm-yyyy'), 4, 9058, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071228014797, to_date('28-12-2007', 'dd-mm-yyyy'), to_date('11-01-2008', 'dd-mm-yyyy'), 2, 4080, to_date('16-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041011014798, to_date('11-10-2004', 'dd-mm-yyyy'), to_date('25-10-2004', 'dd-mm-yyyy'), 4, 5035, to_date('29-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100622014799, to_date('22-06-2010', 'dd-mm-yyyy'), to_date('06-07-2010', 'dd-mm-yyyy'), 3, 8483, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609014800, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 2, 4072, to_date('25-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050928014801, to_date('28-09-2005', 'dd-mm-yyyy'), to_date('12-10-2005', 'dd-mm-yyyy'), 4, 5423, to_date('17-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080205014802, to_date('05-02-2008', 'dd-mm-yyyy'), to_date('19-02-2008', 'dd-mm-yyyy'), 3, 4164, to_date('22-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090704014803, to_date('04-07-2009', 'dd-mm-yyyy'), to_date('18-07-2009', 'dd-mm-yyyy'), 1, 5763, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225014804, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 2, 3142, to_date('07-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120613014805, to_date('13-06-2012', 'dd-mm-yyyy'), to_date('27-06-2012', 'dd-mm-yyyy'), 2, 8289, to_date('14-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010802014806, to_date('02-08-2001', 'dd-mm-yyyy'), to_date('16-08-2001', 'dd-mm-yyyy'), 3, 2183, to_date('06-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130126014807, to_date('26-01-2013', 'dd-mm-yyyy'), to_date('09-02-2013', 'dd-mm-yyyy'), 3, 7452, to_date('13-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010520014808, to_date('20-05-2001', 'dd-mm-yyyy'), to_date('03-06-2001', 'dd-mm-yyyy'), 2, 2261, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020419014809, to_date('19-04-2002', 'dd-mm-yyyy'), to_date('03-05-2002', 'dd-mm-yyyy'), 3, 2174, to_date('06-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140327014810, to_date('27-03-2014', 'dd-mm-yyyy'), to_date('10-04-2014', 'dd-mm-yyyy'), 3, 8979, to_date('31-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110329014811, to_date('29-03-2011', 'dd-mm-yyyy'), to_date('12-04-2011', 'dd-mm-yyyy'), 2, 7673, to_date('02-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101007014812, to_date('07-10-2010', 'dd-mm-yyyy'), to_date('21-10-2010', 'dd-mm-yyyy'), 4, 5467, to_date('17-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061211014813, to_date('11-12-2006', 'dd-mm-yyyy'), to_date('25-12-2006', 'dd-mm-yyyy'), 3, 7440, to_date('14-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030417014814, to_date('17-04-2003', 'dd-mm-yyyy'), to_date('01-05-2003', 'dd-mm-yyyy'), 3, 2655, to_date('28-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000212014815, to_date('12-02-2000', 'dd-mm-yyyy'), to_date('26-02-2000', 'dd-mm-yyyy'), 1, 1326, to_date('26-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071201014816, to_date('01-12-2007', 'dd-mm-yyyy'), to_date('15-12-2007', 'dd-mm-yyyy'), 2, 6594, to_date('05-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111021014817, to_date('21-10-2011', 'dd-mm-yyyy'), to_date('04-11-2011', 'dd-mm-yyyy'), 2, 8292, to_date('29-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131115014818, to_date('15-11-2013', 'dd-mm-yyyy'), to_date('29-11-2013', 'dd-mm-yyyy'), 4, 5842, to_date('28-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405014819, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 1, 6014, to_date('13-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100321014820, to_date('21-03-2010', 'dd-mm-yyyy'), to_date('04-04-2010', 'dd-mm-yyyy'), 2, 6268, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061107014821, to_date('07-11-2006', 'dd-mm-yyyy'), to_date('21-11-2006', 'dd-mm-yyyy'), 1, 6664, to_date('20-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050124014822, to_date('24-01-2005', 'dd-mm-yyyy'), to_date('07-02-2005', 'dd-mm-yyyy'), 3, 2553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100201014823, to_date('01-02-2010', 'dd-mm-yyyy'), to_date('15-02-2010', 'dd-mm-yyyy'), 1, 8389, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010506014824, to_date('06-05-2001', 'dd-mm-yyyy'), to_date('20-05-2001', 'dd-mm-yyyy'), 3, 1640, to_date('25-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130510014825, to_date('10-05-2013', 'dd-mm-yyyy'), to_date('24-05-2013', 'dd-mm-yyyy'), 3, 6300, to_date('28-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130425014826, to_date('25-04-2013', 'dd-mm-yyyy'), to_date('09-05-2013', 'dd-mm-yyyy'), 1, 11012, to_date('29-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051008014827, to_date('08-10-2005', 'dd-mm-yyyy'), to_date('22-10-2005', 'dd-mm-yyyy'), 3, 4376, to_date('20-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060203014828, to_date('03-02-2006', 'dd-mm-yyyy'), to_date('17-02-2006', 'dd-mm-yyyy'), 3, 6336, to_date('21-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121010014829, to_date('10-10-2012', 'dd-mm-yyyy'), to_date('24-10-2012', 'dd-mm-yyyy'), 2, 8716, to_date('24-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010608014830, to_date('08-06-2001', 'dd-mm-yyyy'), to_date('22-06-2001', 'dd-mm-yyyy'), 2, 2890, to_date('19-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207014831, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 2, 7403, to_date('10-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108014832, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 2, 2395, to_date('24-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130705014833, to_date('05-07-2013', 'dd-mm-yyyy'), to_date('19-07-2013', 'dd-mm-yyyy'), 3, 9553, to_date('08-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140505014834, to_date('05-05-2014', 'dd-mm-yyyy'), to_date('19-05-2014', 'dd-mm-yyyy'), 3, 11141, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130121014835, to_date('21-01-2013', 'dd-mm-yyyy'), to_date('04-02-2013', 'dd-mm-yyyy'), 3, 6339, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140513014836, to_date('13-05-2014', 'dd-mm-yyyy'), to_date('27-05-2014', 'dd-mm-yyyy'), 4, 7768, to_date('20-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120014837, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 3, 8230, to_date('03-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100628014838, to_date('28-06-2010', 'dd-mm-yyyy'), to_date('12-07-2010', 'dd-mm-yyyy'), 2, 8611, to_date('11-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100406014839, to_date('06-04-2010', 'dd-mm-yyyy'), to_date('20-04-2010', 'dd-mm-yyyy'), 3, 6734, to_date('08-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226014840, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 2, 2336, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090704014841, to_date('04-07-2009', 'dd-mm-yyyy'), to_date('18-07-2009', 'dd-mm-yyyy'), 2, 5418, to_date('17-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070220014842, to_date('20-02-2007', 'dd-mm-yyyy'), to_date('06-03-2007', 'dd-mm-yyyy'), 3, 3427, to_date('10-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020114014843, to_date('14-01-2002', 'dd-mm-yyyy'), to_date('28-01-2002', 'dd-mm-yyyy'), 2, 3523, to_date('25-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116014844, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 2, 6184, to_date('20-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000807014845, to_date('07-08-2000', 'dd-mm-yyyy'), to_date('21-08-2000', 'dd-mm-yyyy'), 2, 2322, to_date('18-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090528014846, to_date('28-05-2009', 'dd-mm-yyyy'), to_date('11-06-2009', 'dd-mm-yyyy'), 2, 5509, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525014847, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 1, 7874, to_date('13-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010223014848, to_date('23-02-2001', 'dd-mm-yyyy'), to_date('09-03-2001', 'dd-mm-yyyy'), 1, 1765, to_date('06-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120609014849, to_date('09-06-2012', 'dd-mm-yyyy'), to_date('23-06-2012', 'dd-mm-yyyy'), 3, 7159, to_date('27-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110804014850, to_date('04-08-2011', 'dd-mm-yyyy'), to_date('18-08-2011', 'dd-mm-yyyy'), 2, 9199, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010506014851, to_date('06-05-2001', 'dd-mm-yyyy'), to_date('20-05-2001', 'dd-mm-yyyy'), 1, 2594, to_date('07-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103014852, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 2, 9420, to_date('21-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070516014853, to_date('16-05-2007', 'dd-mm-yyyy'), to_date('30-05-2007', 'dd-mm-yyyy'), 3, 5407, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130111014854, to_date('11-01-2013', 'dd-mm-yyyy'), to_date('25-01-2013', 'dd-mm-yyyy'), 3, 10798, to_date('26-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081007014855, to_date('07-10-2008', 'dd-mm-yyyy'), to_date('21-10-2008', 'dd-mm-yyyy'), 2, 4463, to_date('15-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050617014856, to_date('17-06-2005', 'dd-mm-yyyy'), to_date('01-07-2005', 'dd-mm-yyyy'), 2, 4203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080116014857, to_date('16-01-2008', 'dd-mm-yyyy'), to_date('30-01-2008', 'dd-mm-yyyy'), 4, 6128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130825014858, to_date('25-08-2013', 'dd-mm-yyyy'), to_date('08-09-2013', 'dd-mm-yyyy'), 3, 8550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302014859, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 3, 4997, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130818014860, to_date('18-08-2013', 'dd-mm-yyyy'), to_date('01-09-2013', 'dd-mm-yyyy'), 3, 9576, to_date('19-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080106014861, to_date('06-01-2008', 'dd-mm-yyyy'), to_date('20-01-2008', 'dd-mm-yyyy'), 4, 6863, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040421014862, to_date('21-04-2004', 'dd-mm-yyyy'), to_date('05-05-2004', 'dd-mm-yyyy'), 3, 3003, to_date('26-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080502014863, to_date('02-05-2008', 'dd-mm-yyyy'), to_date('16-05-2008', 'dd-mm-yyyy'), 4, 4925, to_date('18-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080702014864, to_date('02-07-2008', 'dd-mm-yyyy'), to_date('16-07-2008', 'dd-mm-yyyy'), 1, 6545, to_date('19-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050903014865, to_date('03-09-2005', 'dd-mm-yyyy'), to_date('17-09-2005', 'dd-mm-yyyy'), 2, 3064, to_date('10-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000331014866, to_date('31-03-2000', 'dd-mm-yyyy'), to_date('14-04-2000', 'dd-mm-yyyy'), 4, 1316, to_date('12-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011124014867, to_date('24-11-2001', 'dd-mm-yyyy'), to_date('08-12-2001', 'dd-mm-yyyy'), 3, 1506, to_date('09-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000506014868, to_date('06-05-2000', 'dd-mm-yyyy'), to_date('20-05-2000', 'dd-mm-yyyy'), 2, 2164, to_date('15-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081130014869, to_date('30-11-2008', 'dd-mm-yyyy'), to_date('14-12-2008', 'dd-mm-yyyy'), 1, 5391, to_date('19-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110530014870, to_date('30-05-2011', 'dd-mm-yyyy'), to_date('13-06-2011', 'dd-mm-yyyy'), 4, 9688, to_date('18-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020820014871, to_date('20-08-2002', 'dd-mm-yyyy'), to_date('03-09-2002', 'dd-mm-yyyy'), 2, 2859, to_date('22-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121221014872, to_date('21-12-2012', 'dd-mm-yyyy'), to_date('04-01-2013', 'dd-mm-yyyy'), 4, 6252, to_date('06-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090607014873, to_date('07-06-2009', 'dd-mm-yyyy'), to_date('21-06-2009', 'dd-mm-yyyy'), 1, 5393, to_date('14-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071106014874, to_date('06-11-2007', 'dd-mm-yyyy'), to_date('20-11-2007', 'dd-mm-yyyy'), 1, 6551, to_date('12-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071116014875, to_date('16-11-2007', 'dd-mm-yyyy'), to_date('30-11-2007', 'dd-mm-yyyy'), 2, 7207, to_date('25-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070324014876, to_date('24-03-2007', 'dd-mm-yyyy'), to_date('07-04-2007', 'dd-mm-yyyy'), 3, 4568, to_date('01-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100402014877, to_date('02-04-2010', 'dd-mm-yyyy'), to_date('16-04-2010', 'dd-mm-yyyy'), 4, 7025, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131015014878, to_date('15-10-2013', 'dd-mm-yyyy'), to_date('29-10-2013', 'dd-mm-yyyy'), 2, 5988, to_date('18-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130719014879, to_date('19-07-2013', 'dd-mm-yyyy'), to_date('02-08-2013', 'dd-mm-yyyy'), 3, 6655, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070529014880, to_date('29-05-2007', 'dd-mm-yyyy'), to_date('12-06-2007', 'dd-mm-yyyy'), 4, 4504, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121202014881, to_date('02-12-2012', 'dd-mm-yyyy'), to_date('16-12-2012', 'dd-mm-yyyy'), 3, 7671, to_date('17-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916014882, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 2, 3595, to_date('19-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000109014883, to_date('09-01-2000', 'dd-mm-yyyy'), to_date('23-01-2000', 'dd-mm-yyyy'), 2, 2308, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131117014884, to_date('17-11-2013', 'dd-mm-yyyy'), to_date('01-12-2013', 'dd-mm-yyyy'), 2, 8916, to_date('27-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723017410, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 2, 7240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060209017411, to_date('09-02-2006', 'dd-mm-yyyy'), to_date('23-02-2006', 'dd-mm-yyyy'), 2, 4179, to_date('22-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130830017412, to_date('30-08-2013', 'dd-mm-yyyy'), to_date('13-09-2013', 'dd-mm-yyyy'), 2, 7290, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070223017413, to_date('23-02-2007', 'dd-mm-yyyy'), to_date('09-03-2007', 'dd-mm-yyyy'), 1, 5308, to_date('06-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000515017414, to_date('15-05-2000', 'dd-mm-yyyy'), to_date('29-05-2000', 'dd-mm-yyyy'), 1, 923, to_date('21-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090227017415, to_date('27-02-2009', 'dd-mm-yyyy'), to_date('13-03-2009', 'dd-mm-yyyy'), 2, 7934, to_date('03-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070114017416, to_date('14-01-2007', 'dd-mm-yyyy'), to_date('28-01-2007', 'dd-mm-yyyy'), 1, 6181, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021021017417, to_date('21-10-2002', 'dd-mm-yyyy'), to_date('04-11-2002', 'dd-mm-yyyy'), 1, 2027, to_date('27-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020522017418, to_date('22-05-2002', 'dd-mm-yyyy'), to_date('05-06-2002', 'dd-mm-yyyy'), 2, 2166, to_date('04-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408017419, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 2, 4871, to_date('22-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100224017420, to_date('24-02-2010', 'dd-mm-yyyy'), to_date('10-03-2010', 'dd-mm-yyyy'), 1, 4631, to_date('10-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140128017421, to_date('28-01-2014', 'dd-mm-yyyy'), to_date('11-02-2014', 'dd-mm-yyyy'), 2, 8938, to_date('29-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131129017422, to_date('29-11-2013', 'dd-mm-yyyy'), to_date('13-12-2013', 'dd-mm-yyyy'), 2, 10182, to_date('07-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110306017423, to_date('06-03-2011', 'dd-mm-yyyy'), to_date('20-03-2011', 'dd-mm-yyyy'), 1, 8183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020902017424, to_date('02-09-2002', 'dd-mm-yyyy'), to_date('16-09-2002', 'dd-mm-yyyy'), 2, 2984, to_date('07-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000707017425, to_date('07-07-2000', 'dd-mm-yyyy'), to_date('21-07-2000', 'dd-mm-yyyy'), 1, 1009, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010301017426, to_date('01-03-2001', 'dd-mm-yyyy'), to_date('15-03-2001', 'dd-mm-yyyy'), 2, 1570, to_date('14-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117017427, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 1, 8057, to_date('05-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515017428, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 2, 4896, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120905017429, to_date('05-09-2012', 'dd-mm-yyyy'), to_date('19-09-2012', 'dd-mm-yyyy'), 1, 9683, to_date('15-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000523017430, to_date('23-05-2000', 'dd-mm-yyyy'), to_date('06-06-2000', 'dd-mm-yyyy'), 2, 1259, to_date('07-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010812017431, to_date('12-08-2001', 'dd-mm-yyyy'), to_date('26-08-2001', 'dd-mm-yyyy'), 2, 1135, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131017432, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 2, 9309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030510017433, to_date('10-05-2003', 'dd-mm-yyyy'), to_date('24-05-2003', 'dd-mm-yyyy'), 1, 883, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080301017434, to_date('01-03-2008', 'dd-mm-yyyy'), to_date('15-03-2008', 'dd-mm-yyyy'), 1, 8027, to_date('08-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001102017435, to_date('02-11-2000', 'dd-mm-yyyy'), to_date('16-11-2000', 'dd-mm-yyyy'), 2, 1500, to_date('16-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130609017436, to_date('09-06-2013', 'dd-mm-yyyy'), to_date('23-06-2013', 'dd-mm-yyyy'), 2, 7444, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020603017437, to_date('03-06-2002', 'dd-mm-yyyy'), to_date('17-06-2002', 'dd-mm-yyyy'), 2, 1695, to_date('20-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021223017438, to_date('23-12-2002', 'dd-mm-yyyy'), to_date('06-01-2003', 'dd-mm-yyyy'), 2, 2198, to_date('31-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050312017439, to_date('12-03-2005', 'dd-mm-yyyy'), to_date('26-03-2005', 'dd-mm-yyyy'), 2, 5764, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060513017440, to_date('13-05-2006', 'dd-mm-yyyy'), to_date('27-05-2006', 'dd-mm-yyyy'), 2, 4839, to_date('23-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411017441, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 2, 6124, to_date('16-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050815017442, to_date('15-08-2005', 'dd-mm-yyyy'), to_date('29-08-2005', 'dd-mm-yyyy'), 1, 4258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081119017443, to_date('19-11-2008', 'dd-mm-yyyy'), to_date('03-12-2008', 'dd-mm-yyyy'), 2, 5734, to_date('27-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040313017444, to_date('13-03-2004', 'dd-mm-yyyy'), to_date('27-03-2004', 'dd-mm-yyyy'), 2, 4144, to_date('29-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811017445, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 1, 1764, to_date('17-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060211017446, to_date('11-02-2006', 'dd-mm-yyyy'), to_date('25-02-2006', 'dd-mm-yyyy'), 2, 3319, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060824017447, to_date('24-08-2006', 'dd-mm-yyyy'), to_date('07-09-2006', 'dd-mm-yyyy'), 2, 6242, to_date('04-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080908017448, to_date('08-09-2008', 'dd-mm-yyyy'), to_date('22-09-2008', 'dd-mm-yyyy'), 2, 5113, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050924017449, to_date('24-09-2005', 'dd-mm-yyyy'), to_date('08-10-2005', 'dd-mm-yyyy'), 2, 2641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323017450, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 1, 5631, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516017451, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 1, 6255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115017452, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 1, 1641, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080206017453, to_date('06-02-2008', 'dd-mm-yyyy'), to_date('20-02-2008', 'dd-mm-yyyy'), 2, 4336, to_date('18-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120727017454, to_date('27-07-2012', 'dd-mm-yyyy'), to_date('10-08-2012', 'dd-mm-yyyy'), 2, 8436, to_date('06-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090328017455, to_date('28-03-2009', 'dd-mm-yyyy'), to_date('11-04-2009', 'dd-mm-yyyy'), 2, 6431, to_date('09-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140219017456, to_date('19-02-2014', 'dd-mm-yyyy'), to_date('05-03-2014', 'dd-mm-yyyy'), 1, 8497, to_date('20-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130527017457, to_date('27-05-2013', 'dd-mm-yyyy'), to_date('10-06-2013', 'dd-mm-yyyy'), 2, 7673, to_date('31-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130216017458, to_date('16-02-2013', 'dd-mm-yyyy'), to_date('02-03-2013', 'dd-mm-yyyy'), 2, 7354, to_date('03-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080411017459, to_date('11-04-2008', 'dd-mm-yyyy'), to_date('25-04-2008', 'dd-mm-yyyy'), 1, 4872, to_date('28-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110213017460, to_date('13-02-2011', 'dd-mm-yyyy'), to_date('27-02-2011', 'dd-mm-yyyy'), 1, 8031, to_date('22-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110321017461, to_date('21-03-2011', 'dd-mm-yyyy'), to_date('04-04-2011', 'dd-mm-yyyy'), 2, 7896, to_date('26-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070316017462, to_date('16-03-2007', 'dd-mm-yyyy'), to_date('30-03-2007', 'dd-mm-yyyy'), 1, 6843, to_date('21-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060706017463, to_date('06-07-2006', 'dd-mm-yyyy'), to_date('20-07-2006', 'dd-mm-yyyy'), 2, 4188, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130529017464, to_date('29-05-2013', 'dd-mm-yyyy'), to_date('12-06-2013', 'dd-mm-yyyy'), 2, 10887, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929017465, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 1, 2254, to_date('10-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080524017466, to_date('24-05-2008', 'dd-mm-yyyy'), to_date('07-06-2008', 'dd-mm-yyyy'), 1, 3598, to_date('31-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020710017467, to_date('10-07-2002', 'dd-mm-yyyy'), to_date('24-07-2002', 'dd-mm-yyyy'), 2, 3778, to_date('11-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010629017468, to_date('29-06-2001', 'dd-mm-yyyy'), to_date('13-07-2001', 'dd-mm-yyyy'), 1, 1571, to_date('15-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090904017469, to_date('04-09-2009', 'dd-mm-yyyy'), to_date('18-09-2009', 'dd-mm-yyyy'), 1, 6832, to_date('17-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040522017470, to_date('22-05-2004', 'dd-mm-yyyy'), to_date('05-06-2004', 'dd-mm-yyyy'), 1, 4928, to_date('06-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041122017471, to_date('22-11-2004', 'dd-mm-yyyy'), to_date('06-12-2004', 'dd-mm-yyyy'), 1, 4272, to_date('04-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100708017472, to_date('08-07-2010', 'dd-mm-yyyy'), to_date('22-07-2010', 'dd-mm-yyyy'), 1, 7143, to_date('12-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010903017473, to_date('03-09-2001', 'dd-mm-yyyy'), to_date('17-09-2001', 'dd-mm-yyyy'), 1, 1992, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071130017474, to_date('30-11-2007', 'dd-mm-yyyy'), to_date('14-12-2007', 'dd-mm-yyyy'), 2, 5336, to_date('10-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226017475, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 1, 7986, to_date('28-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030112017476, to_date('12-01-2003', 'dd-mm-yyyy'), to_date('26-01-2003', 'dd-mm-yyyy'), 2, 2836, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130405017477, to_date('05-04-2013', 'dd-mm-yyyy'), to_date('19-04-2013', 'dd-mm-yyyy'), 2, 7264, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020121017478, to_date('21-01-2002', 'dd-mm-yyyy'), to_date('04-02-2002', 'dd-mm-yyyy'), 2, 2356, to_date('07-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103017479, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 1, 8225, to_date('13-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000203017480, to_date('03-02-2000', 'dd-mm-yyyy'), to_date('17-02-2000', 'dd-mm-yyyy'), 1, 1966, to_date('05-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101203017481, to_date('03-12-2010', 'dd-mm-yyyy'), to_date('17-12-2010', 'dd-mm-yyyy'), 1, 5683, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060521017482, to_date('21-05-2006', 'dd-mm-yyyy'), to_date('04-06-2006', 'dd-mm-yyyy'), 2, 5251, to_date('09-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120805017483, to_date('05-08-2012', 'dd-mm-yyyy'), to_date('19-08-2012', 'dd-mm-yyyy'), 1, 7647, to_date('25-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030712017484, to_date('12-07-2003', 'dd-mm-yyyy'), to_date('26-07-2003', 'dd-mm-yyyy'), 1, 2704, to_date('14-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010510017485, to_date('10-05-2001', 'dd-mm-yyyy'), to_date('24-05-2001', 'dd-mm-yyyy'), 1, 1316, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808017486, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 2, 6221, to_date('27-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100115017487, to_date('15-01-2010', 'dd-mm-yyyy'), to_date('29-01-2010', 'dd-mm-yyyy'), 1, 8146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021117017488, to_date('17-11-2002', 'dd-mm-yyyy'), to_date('01-12-2002', 'dd-mm-yyyy'), 1, 3780, to_date('26-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000906017489, to_date('06-09-2000', 'dd-mm-yyyy'), to_date('20-09-2000', 'dd-mm-yyyy'), 2, 795, to_date('11-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140206017490, to_date('06-02-2014', 'dd-mm-yyyy'), to_date('20-02-2014', 'dd-mm-yyyy'), 2, 9261, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100422017491, to_date('22-04-2010', 'dd-mm-yyyy'), to_date('06-05-2010', 'dd-mm-yyyy'), 1, 7668, to_date('03-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081019017492, to_date('19-10-2008', 'dd-mm-yyyy'), to_date('02-11-2008', 'dd-mm-yyyy'), 2, 8270, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011122017493, to_date('22-11-2001', 'dd-mm-yyyy'), to_date('06-12-2001', 'dd-mm-yyyy'), 1, 2443, to_date('25-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030301017494, to_date('01-03-2003', 'dd-mm-yyyy'), to_date('15-03-2003', 'dd-mm-yyyy'), 2, 4420, to_date('09-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000630017495, to_date('30-06-2000', 'dd-mm-yyyy'), to_date('14-07-2000', 'dd-mm-yyyy'), 1, 1547, to_date('16-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080615017496, to_date('15-06-2008', 'dd-mm-yyyy'), to_date('29-06-2008', 'dd-mm-yyyy'), 1, 5828, to_date('29-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010426017497, to_date('26-04-2001', 'dd-mm-yyyy'), to_date('10-05-2001', 'dd-mm-yyyy'), 1, 1505, to_date('15-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024017498, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 2, 6455, to_date('05-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110605017499, to_date('05-06-2011', 'dd-mm-yyyy'), to_date('19-06-2011', 'dd-mm-yyyy'), 2, 8420, to_date('23-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020703017500, to_date('03-07-2002', 'dd-mm-yyyy'), to_date('17-07-2002', 'dd-mm-yyyy'), 1, 3147, to_date('19-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110907017501, to_date('07-09-2011', 'dd-mm-yyyy'), to_date('21-09-2011', 'dd-mm-yyyy'), 2, 7110, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131027017502, to_date('27-10-2013', 'dd-mm-yyyy'), to_date('10-11-2013', 'dd-mm-yyyy'), 1, 9628, to_date('29-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070317017503, to_date('17-03-2007', 'dd-mm-yyyy'), to_date('31-03-2007', 'dd-mm-yyyy'), 1, 5623, to_date('21-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001115017504, to_date('15-11-2000', 'dd-mm-yyyy'), to_date('29-11-2000', 'dd-mm-yyyy'), 2, 1693, to_date('21-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606017505, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 2, 3883, to_date('16-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110824017506, to_date('24-08-2011', 'dd-mm-yyyy'), to_date('07-09-2011', 'dd-mm-yyyy'), 1, 7923, to_date('29-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201017507, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 1, 4110, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000526017508, to_date('26-05-2000', 'dd-mm-yyyy'), to_date('09-06-2000', 'dd-mm-yyyy'), 2, 2327, to_date('28-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100304017509, to_date('04-03-2010', 'dd-mm-yyyy'), to_date('18-03-2010', 'dd-mm-yyyy'), 1, 6531, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020105017510, to_date('05-01-2002', 'dd-mm-yyyy'), to_date('19-01-2002', 'dd-mm-yyyy'), 2, 4258, to_date('14-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802017511, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 1, 7439, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130211017512, to_date('11-02-2013', 'dd-mm-yyyy'), to_date('25-02-2013', 'dd-mm-yyyy'), 1, 7729, to_date('18-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100908017513, to_date('08-09-2010', 'dd-mm-yyyy'), to_date('22-09-2010', 'dd-mm-yyyy'), 2, 6494, to_date('13-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130603017514, to_date('03-06-2013', 'dd-mm-yyyy'), to_date('17-06-2013', 'dd-mm-yyyy'), 1, 8068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071209017515, to_date('09-12-2007', 'dd-mm-yyyy'), to_date('23-12-2007', 'dd-mm-yyyy'), 2, 5430, to_date('16-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080109017516, to_date('09-01-2008', 'dd-mm-yyyy'), to_date('23-01-2008', 'dd-mm-yyyy'), 1, 5930, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011224017517, to_date('24-12-2001', 'dd-mm-yyyy'), to_date('07-01-2002', 'dd-mm-yyyy'), 1, 3138, to_date('27-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010111017518, to_date('11-01-2001', 'dd-mm-yyyy'), to_date('25-01-2001', 'dd-mm-yyyy'), 1, 2859, to_date('20-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101217017519, to_date('17-12-2010', 'dd-mm-yyyy'), to_date('31-12-2010', 'dd-mm-yyyy'), 1, 7301, to_date('26-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101229017520, to_date('29-12-2010', 'dd-mm-yyyy'), to_date('12-01-2011', 'dd-mm-yyyy'), 1, 8160, to_date('12-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060916017521, to_date('16-09-2006', 'dd-mm-yyyy'), to_date('30-09-2006', 'dd-mm-yyyy'), 2, 2431, to_date('20-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080730017522, to_date('30-07-2008', 'dd-mm-yyyy'), to_date('13-08-2008', 'dd-mm-yyyy'), 2, 5781, to_date('05-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130421017523, to_date('21-04-2013', 'dd-mm-yyyy'), to_date('05-05-2013', 'dd-mm-yyyy'), 2, 10135, to_date('30-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050622017524, to_date('22-06-2005', 'dd-mm-yyyy'), to_date('06-07-2005', 'dd-mm-yyyy'), 2, 5003, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060901017525, to_date('01-09-2006', 'dd-mm-yyyy'), to_date('15-09-2006', 'dd-mm-yyyy'), 2, 2923, to_date('14-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225017526, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 1, 993, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000129017527, to_date('29-01-2000', 'dd-mm-yyyy'), to_date('12-02-2000', 'dd-mm-yyyy'), 2, 1020, to_date('09-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709017528, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 2, 6820, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090705017529, to_date('05-07-2009', 'dd-mm-yyyy'), to_date('19-07-2009', 'dd-mm-yyyy'), 2, 4820, to_date('21-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051130017530, to_date('30-11-2005', 'dd-mm-yyyy'), to_date('14-12-2005', 'dd-mm-yyyy'), 1, 2220, to_date('05-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020727017531, to_date('27-07-2002', 'dd-mm-yyyy'), to_date('10-08-2002', 'dd-mm-yyyy'), 1, 2402, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090119017532, to_date('19-01-2009', 'dd-mm-yyyy'), to_date('02-02-2009', 'dd-mm-yyyy'), 1, 6470, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000703017533, to_date('03-07-2000', 'dd-mm-yyyy'), to_date('17-07-2000', 'dd-mm-yyyy'), 2, 1546, to_date('19-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226017534, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 2, 4412, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703017535, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 1, 7457, to_date('11-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819017536, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 2, 4821, to_date('31-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090622017537, to_date('22-06-2009', 'dd-mm-yyyy'), to_date('06-07-2009', 'dd-mm-yyyy'), 1, 6210, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030213017538, to_date('13-02-2003', 'dd-mm-yyyy'), to_date('27-02-2003', 'dd-mm-yyyy'), 2, 4669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070728017539, to_date('28-07-2007', 'dd-mm-yyyy'), to_date('11-08-2007', 'dd-mm-yyyy'), 1, 7338, to_date('06-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100813017540, to_date('13-08-2010', 'dd-mm-yyyy'), to_date('27-08-2010', 'dd-mm-yyyy'), 1, 6049, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060201017541, to_date('01-02-2006', 'dd-mm-yyyy'), to_date('15-02-2006', 'dd-mm-yyyy'), 2, 5360, to_date('15-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010902017542, to_date('02-09-2001', 'dd-mm-yyyy'), to_date('16-09-2001', 'dd-mm-yyyy'), 1, 2198, to_date('05-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120522017543, to_date('22-05-2012', 'dd-mm-yyyy'), to_date('05-06-2012', 'dd-mm-yyyy'), 2, 7257, to_date('25-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060218017544, to_date('18-02-2006', 'dd-mm-yyyy'), to_date('04-03-2006', 'dd-mm-yyyy'), 1, 6078, to_date('01-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060605017545, to_date('05-06-2006', 'dd-mm-yyyy'), to_date('19-06-2006', 'dd-mm-yyyy'), 1, 6926, to_date('15-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051024017546, to_date('24-10-2005', 'dd-mm-yyyy'), to_date('07-11-2005', 'dd-mm-yyyy'), 2, 3409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110822017547, to_date('22-08-2011', 'dd-mm-yyyy'), to_date('05-09-2011', 'dd-mm-yyyy'), 2, 8773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323017548, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 2, 10168, to_date('29-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000120017549, to_date('20-01-2000', 'dd-mm-yyyy'), to_date('03-02-2000', 'dd-mm-yyyy'), 2, 716, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110520017550, to_date('20-05-2011', 'dd-mm-yyyy'), to_date('03-06-2011', 'dd-mm-yyyy'), 1, 8142, to_date('02-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111217017551, to_date('17-12-2011', 'dd-mm-yyyy'), to_date('31-12-2011', 'dd-mm-yyyy'), 2, 7747, to_date('02-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061015017552, to_date('15-10-2006', 'dd-mm-yyyy'), to_date('29-10-2006', 'dd-mm-yyyy'), 1, 4765, to_date('30-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021015017553, to_date('15-10-2002', 'dd-mm-yyyy'), to_date('29-10-2002', 'dd-mm-yyyy'), 2, 3230, to_date('17-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110607017554, to_date('07-06-2011', 'dd-mm-yyyy'), to_date('21-06-2011', 'dd-mm-yyyy'), 1, 7892, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080901017555, to_date('01-09-2008', 'dd-mm-yyyy'), to_date('15-09-2008', 'dd-mm-yyyy'), 2, 8472, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080722017556, to_date('22-07-2008', 'dd-mm-yyyy'), to_date('05-08-2008', 'dd-mm-yyyy'), 2, 5799, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080325017557, to_date('25-03-2008', 'dd-mm-yyyy'), to_date('08-04-2008', 'dd-mm-yyyy'), 1, 7372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120105017558, to_date('05-01-2012', 'dd-mm-yyyy'), to_date('19-01-2012', 'dd-mm-yyyy'), 2, 8178, to_date('21-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130526017559, to_date('26-05-2013', 'dd-mm-yyyy'), to_date('09-06-2013', 'dd-mm-yyyy'), 2, 7373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040203017560, to_date('03-02-2004', 'dd-mm-yyyy'), to_date('17-02-2004', 'dd-mm-yyyy'), 1, 2993, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070628017561, to_date('28-06-2007', 'dd-mm-yyyy'), to_date('12-07-2007', 'dd-mm-yyyy'), 1, 5374, to_date('05-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010202017562, to_date('02-02-2001', 'dd-mm-yyyy'), to_date('16-02-2001', 'dd-mm-yyyy'), 2, 1545, to_date('14-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110706017563, to_date('06-07-2011', 'dd-mm-yyyy'), to_date('20-07-2011', 'dd-mm-yyyy'), 2, 6370, to_date('25-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080902017564, to_date('02-09-2008', 'dd-mm-yyyy'), to_date('16-09-2008', 'dd-mm-yyyy'), 1, 5917, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060131017565, to_date('31-01-2006', 'dd-mm-yyyy'), to_date('14-02-2006', 'dd-mm-yyyy'), 2, 4058, to_date('04-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822017566, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 2, 11753, to_date('09-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040805017567, to_date('05-08-2004', 'dd-mm-yyyy'), to_date('19-08-2004', 'dd-mm-yyyy'), 1, 5773, to_date('21-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060212017568, to_date('12-02-2006', 'dd-mm-yyyy'), to_date('26-02-2006', 'dd-mm-yyyy'), 2, 4864, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130324017569, to_date('24-03-2013', 'dd-mm-yyyy'), to_date('07-04-2013', 'dd-mm-yyyy'), 1, 8145, to_date('09-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111016017570, to_date('16-10-2011', 'dd-mm-yyyy'), to_date('30-10-2011', 'dd-mm-yyyy'), 1, 7391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130304017571, to_date('04-03-2013', 'dd-mm-yyyy'), to_date('18-03-2013', 'dd-mm-yyyy'), 1, 9528, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110423017572, to_date('23-04-2011', 'dd-mm-yyyy'), to_date('07-05-2011', 'dd-mm-yyyy'), 1, 5906, to_date('30-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805017573, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 1, 6128, to_date('17-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061025017574, to_date('25-10-2006', 'dd-mm-yyyy'), to_date('08-11-2006', 'dd-mm-yyyy'), 2, 4068, to_date('14-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030315017575, to_date('15-03-2003', 'dd-mm-yyyy'), to_date('29-03-2003', 'dd-mm-yyyy'), 2, 1891, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010828017576, to_date('28-08-2001', 'dd-mm-yyyy'), to_date('11-09-2001', 'dd-mm-yyyy'), 2, 1946, to_date('07-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110817017577, to_date('17-08-2011', 'dd-mm-yyyy'), to_date('31-08-2011', 'dd-mm-yyyy'), 2, 8677, to_date('06-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090121017578, to_date('21-01-2009', 'dd-mm-yyyy'), to_date('04-02-2009', 'dd-mm-yyyy'), 2, 5563, to_date('28-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090320017579, to_date('20-03-2009', 'dd-mm-yyyy'), to_date('03-04-2009', 'dd-mm-yyyy'), 2, 6846, to_date('25-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140509009484, to_date('09-05-2014', 'dd-mm-yyyy'), to_date('23-05-2014', 'dd-mm-yyyy'), 11, 9627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020323009485, to_date('23-03-2002', 'dd-mm-yyyy'), to_date('06-04-2002', 'dd-mm-yyyy'), 3, 2381, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505009486, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 6, 5975, to_date('24-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110319009487, to_date('19-03-2011', 'dd-mm-yyyy'), to_date('02-04-2011', 'dd-mm-yyyy'), 3, 6123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090211009488, to_date('11-02-2009', 'dd-mm-yyyy'), to_date('25-02-2009', 'dd-mm-yyyy'), 5, 4807, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906009489, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 2, 3098, to_date('09-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131207009490, to_date('07-12-2013', 'dd-mm-yyyy'), to_date('21-12-2013', 'dd-mm-yyyy'), 9, 9548, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030205009491, to_date('05-02-2003', 'dd-mm-yyyy'), to_date('19-02-2003', 'dd-mm-yyyy'), 5, 5137, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050424009492, to_date('24-04-2005', 'dd-mm-yyyy'), to_date('08-05-2005', 'dd-mm-yyyy'), 6, 4635, to_date('10-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102009493, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 8, 3320, to_date('18-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020723009494, to_date('23-07-2002', 'dd-mm-yyyy'), to_date('06-08-2002', 'dd-mm-yyyy'), 5, 1288, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061201009495, to_date('01-12-2006', 'dd-mm-yyyy'), to_date('15-12-2006', 'dd-mm-yyyy'), 9, 3666, to_date('10-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130724009496, to_date('24-07-2013', 'dd-mm-yyyy'), to_date('07-08-2013', 'dd-mm-yyyy'), 11, 4917, to_date('29-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040909009497, to_date('09-09-2004', 'dd-mm-yyyy'), to_date('23-09-2004', 'dd-mm-yyyy'), 7, 4593, to_date('26-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120630009498, to_date('30-06-2012', 'dd-mm-yyyy'), to_date('14-07-2012', 'dd-mm-yyyy'), 4, 8177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080521009499, to_date('21-05-2008', 'dd-mm-yyyy'), to_date('04-06-2008', 'dd-mm-yyyy'), 8, 5403, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000409009500, to_date('09-04-2000', 'dd-mm-yyyy'), to_date('23-04-2000', 'dd-mm-yyyy'), 10, 1667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041231009501, to_date('31-12-2004', 'dd-mm-yyyy'), to_date('14-01-2005', 'dd-mm-yyyy'), 4, 4195, to_date('19-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040913009502, to_date('13-09-2004', 'dd-mm-yyyy'), to_date('27-09-2004', 'dd-mm-yyyy'), 11, 1243, to_date('29-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000209009503, to_date('09-02-2000', 'dd-mm-yyyy'), to_date('23-02-2000', 'dd-mm-yyyy'), 5, 1336, to_date('19-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910009504, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 8, 6346, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010615009505, to_date('15-06-2001', 'dd-mm-yyyy'), to_date('29-06-2001', 'dd-mm-yyyy'), 2, 3275, to_date('17-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040829009506, to_date('29-08-2004', 'dd-mm-yyyy'), to_date('12-09-2004', 'dd-mm-yyyy'), 10, 2869, to_date('12-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090707009507, to_date('07-07-2009', 'dd-mm-yyyy'), to_date('21-07-2009', 'dd-mm-yyyy'), 8, 5110, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110722009508, to_date('22-07-2011', 'dd-mm-yyyy'), to_date('05-08-2011', 'dd-mm-yyyy'), 5, 8202, to_date('29-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010119009509, to_date('19-01-2001', 'dd-mm-yyyy'), to_date('02-02-2001', 'dd-mm-yyyy'), 3, 2172, to_date('24-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010419009510, to_date('19-04-2001', 'dd-mm-yyyy'), to_date('03-05-2001', 'dd-mm-yyyy'), 9, 890, to_date('06-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100727009511, to_date('27-07-2010', 'dd-mm-yyyy'), to_date('10-08-2010', 'dd-mm-yyyy'), 9, 7198, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080309009512, to_date('09-03-2008', 'dd-mm-yyyy'), to_date('23-03-2008', 'dd-mm-yyyy'), 1, 7486, to_date('14-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100730009513, to_date('30-07-2010', 'dd-mm-yyyy'), to_date('13-08-2010', 'dd-mm-yyyy'), 12, 5970, to_date('11-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140326009514, to_date('26-03-2014', 'dd-mm-yyyy'), to_date('09-04-2014', 'dd-mm-yyyy'), 4, 8388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140313009515, to_date('13-03-2014', 'dd-mm-yyyy'), to_date('27-03-2014', 'dd-mm-yyyy'), 12, 7167, to_date('30-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020910009516, to_date('10-09-2002', 'dd-mm-yyyy'), to_date('24-09-2002', 'dd-mm-yyyy'), 8, 3596, to_date('17-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081006009517, to_date('06-10-2008', 'dd-mm-yyyy'), to_date('20-10-2008', 'dd-mm-yyyy'), 11, 5742, to_date('17-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060302009518, to_date('02-03-2006', 'dd-mm-yyyy'), to_date('16-03-2006', 'dd-mm-yyyy'), 2, 5599, to_date('14-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080119009519, to_date('19-01-2008', 'dd-mm-yyyy'), to_date('02-02-2008', 'dd-mm-yyyy'), 9, 6524, to_date('20-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030719009520, to_date('19-07-2003', 'dd-mm-yyyy'), to_date('02-08-2003', 'dd-mm-yyyy'), 8, 3415, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010225009521, to_date('25-02-2001', 'dd-mm-yyyy'), to_date('11-03-2001', 'dd-mm-yyyy'), 11, 2555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030115009522, to_date('15-01-2003', 'dd-mm-yyyy'), to_date('29-01-2003', 'dd-mm-yyyy'), 6, 2949, to_date('21-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140311009523, to_date('11-03-2014', 'dd-mm-yyyy'), to_date('25-03-2014', 'dd-mm-yyyy'), 6, 11462, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010113009524, to_date('13-01-2001', 'dd-mm-yyyy'), to_date('27-01-2001', 'dd-mm-yyyy'), 1, 2725, to_date('17-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031202009525, to_date('02-12-2003', 'dd-mm-yyyy'), to_date('16-12-2003', 'dd-mm-yyyy'), 2, 3853, to_date('11-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080806009526, to_date('06-08-2008', 'dd-mm-yyyy'), to_date('20-08-2008', 'dd-mm-yyyy'), 10, 6600, to_date('12-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115009527, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 8, 6172, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030822009528, to_date('22-08-2003', 'dd-mm-yyyy'), to_date('05-09-2003', 'dd-mm-yyyy'), 2, 2639, to_date('23-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051029009529, to_date('29-10-2005', 'dd-mm-yyyy'), to_date('12-11-2005', 'dd-mm-yyyy'), 1, 8152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000802009530, to_date('02-08-2000', 'dd-mm-yyyy'), to_date('16-08-2000', 'dd-mm-yyyy'), 8, 2281, to_date('08-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080424009531, to_date('24-04-2008', 'dd-mm-yyyy'), to_date('08-05-2008', 'dd-mm-yyyy'), 11, 6135, to_date('27-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030722009532, to_date('22-07-2003', 'dd-mm-yyyy'), to_date('05-08-2003', 'dd-mm-yyyy'), 12, 5413, to_date('01-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000513009533, to_date('13-05-2000', 'dd-mm-yyyy'), to_date('27-05-2000', 'dd-mm-yyyy'), 5, 2547, to_date('23-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060219009534, to_date('19-02-2006', 'dd-mm-yyyy'), to_date('05-03-2006', 'dd-mm-yyyy'), 9, 6094, to_date('02-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120216009535, to_date('16-02-2012', 'dd-mm-yyyy'), to_date('01-03-2012', 'dd-mm-yyyy'), 4, 10390, to_date('06-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050724009536, to_date('24-07-2005', 'dd-mm-yyyy'), to_date('07-08-2005', 'dd-mm-yyyy'), 7, 4328, to_date('04-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011119009537, to_date('19-11-2001', 'dd-mm-yyyy'), to_date('03-12-2001', 'dd-mm-yyyy'), 8, 1254, to_date('29-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070328009538, to_date('28-03-2007', 'dd-mm-yyyy'), to_date('11-04-2007', 'dd-mm-yyyy'), 8, 4915, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120305009539, to_date('05-03-2012', 'dd-mm-yyyy'), to_date('19-03-2012', 'dd-mm-yyyy'), 9, 7169, to_date('23-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623009540, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 4, 3880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020701009541, to_date('01-07-2002', 'dd-mm-yyyy'), to_date('15-07-2002', 'dd-mm-yyyy'), 10, 2527, to_date('10-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061130009542, to_date('30-11-2006', 'dd-mm-yyyy'), to_date('14-12-2006', 'dd-mm-yyyy'), 5, 4786, to_date('01-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100327009543, to_date('27-03-2010', 'dd-mm-yyyy'), to_date('10-04-2010', 'dd-mm-yyyy'), 4, 10056, to_date('04-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060731009544, to_date('31-07-2006', 'dd-mm-yyyy'), to_date('14-08-2006', 'dd-mm-yyyy'), 3, 4663, to_date('10-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100129009545, to_date('29-01-2010', 'dd-mm-yyyy'), to_date('12-02-2010', 'dd-mm-yyyy'), 3, 7530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090126009546, to_date('26-01-2009', 'dd-mm-yyyy'), to_date('09-02-2009', 'dd-mm-yyyy'), 4, 7152, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100801009547, to_date('01-08-2010', 'dd-mm-yyyy'), to_date('15-08-2010', 'dd-mm-yyyy'), 2, 8385, to_date('12-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021208009548, to_date('08-12-2002', 'dd-mm-yyyy'), to_date('22-12-2002', 'dd-mm-yyyy'), 5, 1033, to_date('22-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060501009549, to_date('01-05-2006', 'dd-mm-yyyy'), to_date('15-05-2006', 'dd-mm-yyyy'), 10, 5410, to_date('07-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080119009550, to_date('19-01-2008', 'dd-mm-yyyy'), to_date('02-02-2008', 'dd-mm-yyyy'), 2, 5809, to_date('22-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130116009551, to_date('16-01-2013', 'dd-mm-yyyy'), to_date('30-01-2013', 'dd-mm-yyyy'), 3, 9734, to_date('05-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010401009552, to_date('01-04-2001', 'dd-mm-yyyy'), to_date('15-04-2001', 'dd-mm-yyyy'), 7, 4015, to_date('16-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070906009553, to_date('06-09-2007', 'dd-mm-yyyy'), to_date('20-09-2007', 'dd-mm-yyyy'), 5, 4589, to_date('21-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060331009554, to_date('31-03-2006', 'dd-mm-yyyy'), to_date('14-04-2006', 'dd-mm-yyyy'), 3, 6059, to_date('04-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001210009555, to_date('10-12-2000', 'dd-mm-yyyy'), to_date('24-12-2000', 'dd-mm-yyyy'), 2, 1054, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070317009556, to_date('17-03-2007', 'dd-mm-yyyy'), to_date('31-03-2007', 'dd-mm-yyyy'), 5, 6454, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104009557, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 8, 2792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050830009558, to_date('30-08-2005', 'dd-mm-yyyy'), to_date('13-09-2005', 'dd-mm-yyyy'), 6, 5268, to_date('13-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071004009559, to_date('04-10-2007', 'dd-mm-yyyy'), to_date('18-10-2007', 'dd-mm-yyyy'), 8, 6077, to_date('20-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070920009560, to_date('20-09-2007', 'dd-mm-yyyy'), to_date('04-10-2007', 'dd-mm-yyyy'), 5, 5409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120921009561, to_date('21-09-2012', 'dd-mm-yyyy'), to_date('05-10-2012', 'dd-mm-yyyy'), 11, 9921, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100716009562, to_date('16-07-2010', 'dd-mm-yyyy'), to_date('30-07-2010', 'dd-mm-yyyy'), 3, 5861, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070209009563, to_date('09-02-2007', 'dd-mm-yyyy'), to_date('23-02-2007', 'dd-mm-yyyy'), 5, 6848, to_date('13-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222009564, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 1, 8318, to_date('08-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051219009565, to_date('19-12-2005', 'dd-mm-yyyy'), to_date('02-01-2006', 'dd-mm-yyyy'), 7, 4261, to_date('05-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070511009566, to_date('11-05-2007', 'dd-mm-yyyy'), to_date('25-05-2007', 'dd-mm-yyyy'), 11, 7369, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011016009567, to_date('16-10-2001', 'dd-mm-yyyy'), to_date('30-10-2001', 'dd-mm-yyyy'), 10, 1956, to_date('20-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131209009568, to_date('09-12-2013', 'dd-mm-yyyy'), to_date('23-12-2013', 'dd-mm-yyyy'), 5, 5907, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001027009569, to_date('27-10-2000', 'dd-mm-yyyy'), to_date('10-11-2000', 'dd-mm-yyyy'), 12, 1333, to_date('02-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060324009570, to_date('24-03-2006', 'dd-mm-yyyy'), to_date('07-04-2006', 'dd-mm-yyyy'), 10, 7014, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031130009571, to_date('30-11-2003', 'dd-mm-yyyy'), to_date('14-12-2003', 'dd-mm-yyyy'), 1, 4568, to_date('08-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080727009572, to_date('27-07-2008', 'dd-mm-yyyy'), to_date('10-08-2008', 'dd-mm-yyyy'), 11, 4429, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131007009573, to_date('07-10-2013', 'dd-mm-yyyy'), to_date('21-10-2013', 'dd-mm-yyyy'), 5, 7537, to_date('23-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070703009574, to_date('03-07-2007', 'dd-mm-yyyy'), to_date('17-07-2007', 'dd-mm-yyyy'), 3, 5503, to_date('18-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040606009575, to_date('06-06-2004', 'dd-mm-yyyy'), to_date('20-06-2004', 'dd-mm-yyyy'), 10, 4797, to_date('19-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001126009576, to_date('26-11-2000', 'dd-mm-yyyy'), to_date('10-12-2000', 'dd-mm-yyyy'), 8, 1270, to_date('29-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111029009577, to_date('29-10-2011', 'dd-mm-yyyy'), to_date('12-11-2011', 'dd-mm-yyyy'), 5, 7451, to_date('07-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000914009578, to_date('14-09-2000', 'dd-mm-yyyy'), to_date('28-09-2000', 'dd-mm-yyyy'), 7, 603, to_date('01-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111018009579, to_date('18-10-2011', 'dd-mm-yyyy'), to_date('01-11-2011', 'dd-mm-yyyy'), 10, 7555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091218009580, to_date('18-12-2009', 'dd-mm-yyyy'), to_date('01-01-2010', 'dd-mm-yyyy'), 10, 6128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001226009581, to_date('26-12-2000', 'dd-mm-yyyy'), to_date('09-01-2001', 'dd-mm-yyyy'), 4, 1449, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100904009582, to_date('04-09-2010', 'dd-mm-yyyy'), to_date('18-09-2010', 'dd-mm-yyyy'), 2, 6543, to_date('21-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061206009583, to_date('06-12-2006', 'dd-mm-yyyy'), to_date('20-12-2006', 'dd-mm-yyyy'), 9, 6016, to_date('11-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080214009584, to_date('14-02-2008', 'dd-mm-yyyy'), to_date('28-02-2008', 'dd-mm-yyyy'), 3, 6698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090606009585, to_date('06-06-2009', 'dd-mm-yyyy'), to_date('20-06-2009', 'dd-mm-yyyy'), 8, 6346, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060601009586, to_date('01-06-2006', 'dd-mm-yyyy'), to_date('15-06-2006', 'dd-mm-yyyy'), 6, 3207, to_date('03-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130316009587, to_date('16-03-2013', 'dd-mm-yyyy'), to_date('30-03-2013', 'dd-mm-yyyy'), 3, 6565, to_date('22-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302009588, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 3, 5766, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140104009589, to_date('04-01-2014', 'dd-mm-yyyy'), to_date('18-01-2014', 'dd-mm-yyyy'), 7, 10803, to_date('17-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001114009590, to_date('14-11-2000', 'dd-mm-yyyy'), to_date('28-11-2000', 'dd-mm-yyyy'), 7, 3153, to_date('02-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060723009591, to_date('23-07-2006', 'dd-mm-yyyy'), to_date('06-08-2006', 'dd-mm-yyyy'), 10, 5049, to_date('26-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050227009592, to_date('27-02-2005', 'dd-mm-yyyy'), to_date('13-03-2005', 'dd-mm-yyyy'), 3, 4700, to_date('06-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051201009593, to_date('01-12-2005', 'dd-mm-yyyy'), to_date('15-12-2005', 'dd-mm-yyyy'), 4, 5384, to_date('19-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223009594, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 11, 6372, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071004009595, to_date('04-10-2007', 'dd-mm-yyyy'), to_date('18-10-2007', 'dd-mm-yyyy'), 7, 5526, to_date('11-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070113009596, to_date('13-01-2007', 'dd-mm-yyyy'), to_date('27-01-2007', 'dd-mm-yyyy'), 12, 4743, to_date('23-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040316009597, to_date('16-03-2004', 'dd-mm-yyyy'), to_date('30-03-2004', 'dd-mm-yyyy'), 6, 4474, to_date('03-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070716009598, to_date('16-07-2007', 'dd-mm-yyyy'), to_date('30-07-2007', 'dd-mm-yyyy'), 10, 4642, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071114009599, to_date('14-11-2007', 'dd-mm-yyyy'), to_date('28-11-2007', 'dd-mm-yyyy'), 4, 5108, to_date('21-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121113009600, to_date('13-11-2012', 'dd-mm-yyyy'), to_date('27-11-2012', 'dd-mm-yyyy'), 2, 7766, to_date('02-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060327009601, to_date('27-03-2006', 'dd-mm-yyyy'), to_date('10-04-2006', 'dd-mm-yyyy'), 11, 4082, to_date('01-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060727009602, to_date('27-07-2006', 'dd-mm-yyyy'), to_date('10-08-2006', 'dd-mm-yyyy'), 6, 4512, to_date('16-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111130009603, to_date('30-11-2011', 'dd-mm-yyyy'), to_date('14-12-2011', 'dd-mm-yyyy'), 5, 6432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100618009604, to_date('18-06-2010', 'dd-mm-yyyy'), to_date('02-07-2010', 'dd-mm-yyyy'), 9, 7912, to_date('04-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081223009605, to_date('23-12-2008', 'dd-mm-yyyy'), to_date('06-01-2009', 'dd-mm-yyyy'), 4, 4727, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040703009606, to_date('03-07-2004', 'dd-mm-yyyy'), to_date('17-07-2004', 'dd-mm-yyyy'), 1, 4258, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110611009607, to_date('11-06-2011', 'dd-mm-yyyy'), to_date('25-06-2011', 'dd-mm-yyyy'), 3, 7850, to_date('18-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070725009608, to_date('25-07-2007', 'dd-mm-yyyy'), to_date('08-08-2007', 'dd-mm-yyyy'), 3, 6448, to_date('29-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060511009609, to_date('11-05-2006', 'dd-mm-yyyy'), to_date('25-05-2006', 'dd-mm-yyyy'), 4, 6220, to_date('21-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901009610, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 3, 3516, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020713009611, to_date('13-07-2002', 'dd-mm-yyyy'), to_date('27-07-2002', 'dd-mm-yyyy'), 3, 2685, to_date('16-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060711009612, to_date('11-07-2006', 'dd-mm-yyyy'), to_date('25-07-2006', 'dd-mm-yyyy'), 5, 8021, to_date('18-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100420009613, to_date('20-04-2010', 'dd-mm-yyyy'), to_date('04-05-2010', 'dd-mm-yyyy'), 11, 5872, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000625009614, to_date('25-06-2000', 'dd-mm-yyyy'), to_date('09-07-2000', 'dd-mm-yyyy'), 7, 2189, to_date('27-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120927009615, to_date('27-09-2012', 'dd-mm-yyyy'), to_date('11-10-2012', 'dd-mm-yyyy'), 1, 7479, to_date('12-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021102009616, to_date('02-11-2002', 'dd-mm-yyyy'), to_date('16-11-2002', 'dd-mm-yyyy'), 9, 1914, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020720009617, to_date('20-07-2002', 'dd-mm-yyyy'), to_date('03-08-2002', 'dd-mm-yyyy'), 6, 2916, to_date('24-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100415009618, to_date('15-04-2010', 'dd-mm-yyyy'), to_date('29-04-2010', 'dd-mm-yyyy'), 12, 6196, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100310009619, to_date('10-03-2010', 'dd-mm-yyyy'), to_date('24-03-2010', 'dd-mm-yyyy'), 9, 7295, to_date('26-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802009620, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 11, 6255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070401009621, to_date('01-04-2007', 'dd-mm-yyyy'), to_date('15-04-2007', 'dd-mm-yyyy'), 9, 4703, to_date('12-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030622009622, to_date('22-06-2003', 'dd-mm-yyyy'), to_date('06-07-2003', 'dd-mm-yyyy'), 11, 3000, to_date('25-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130117009623, to_date('17-01-2013', 'dd-mm-yyyy'), to_date('31-01-2013', 'dd-mm-yyyy'), 6, 8977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040827009624, to_date('27-08-2004', 'dd-mm-yyyy'), to_date('10-09-2004', 'dd-mm-yyyy'), 10, 5183, to_date('29-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080825009625, to_date('25-08-2008', 'dd-mm-yyyy'), to_date('08-09-2008', 'dd-mm-yyyy'), 6, 11343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130517009626, to_date('17-05-2013', 'dd-mm-yyyy'), to_date('31-05-2013', 'dd-mm-yyyy'), 5, 8376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101223009627, to_date('23-12-2010', 'dd-mm-yyyy'), to_date('06-01-2011', 'dd-mm-yyyy'), 9, 8487, to_date('05-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010922009628, to_date('22-09-2001', 'dd-mm-yyyy'), to_date('06-10-2001', 'dd-mm-yyyy'), 4, 1367, to_date('02-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030508009629, to_date('08-05-2003', 'dd-mm-yyyy'), to_date('22-05-2003', 'dd-mm-yyyy'), 9, 3687, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140221009630, to_date('21-02-2014', 'dd-mm-yyyy'), to_date('07-03-2014', 'dd-mm-yyyy'), 9, 6600, to_date('26-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090519009631, to_date('19-05-2009', 'dd-mm-yyyy'), to_date('02-06-2009', 'dd-mm-yyyy'), 10, 6650, to_date('24-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001103009632, to_date('03-11-2000', 'dd-mm-yyyy'), to_date('17-11-2000', 'dd-mm-yyyy'), 7, 2057, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090710009633, to_date('10-07-2009', 'dd-mm-yyyy'), to_date('24-07-2009', 'dd-mm-yyyy'), 11, 6294, to_date('29-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110303009634, to_date('03-03-2011', 'dd-mm-yyyy'), to_date('17-03-2011', 'dd-mm-yyyy'), 11, 7843, to_date('16-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131105009635, to_date('05-11-2013', 'dd-mm-yyyy'), to_date('19-11-2013', 'dd-mm-yyyy'), 6, 10238, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130928009636, to_date('28-09-2013', 'dd-mm-yyyy'), to_date('12-10-2013', 'dd-mm-yyyy'), 4, 5566, to_date('08-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030423009637, to_date('23-04-2003', 'dd-mm-yyyy'), to_date('07-05-2003', 'dd-mm-yyyy'), 11, 5972, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130119009638, to_date('19-01-2013', 'dd-mm-yyyy'), to_date('02-02-2013', 'dd-mm-yyyy'), 12, 11786, to_date('24-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040707012020, to_date('07-07-2004', 'dd-mm-yyyy'), to_date('21-07-2004', 'dd-mm-yyyy'), 1, 3739, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000126012021, to_date('26-01-2000', 'dd-mm-yyyy'), to_date('09-02-2000', 'dd-mm-yyyy'), 3, 1583, to_date('29-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060910012022, to_date('10-09-2006', 'dd-mm-yyyy'), to_date('24-09-2006', 'dd-mm-yyyy'), 3, 3697, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130706012023, to_date('06-07-2013', 'dd-mm-yyyy'), to_date('20-07-2013', 'dd-mm-yyyy'), 4, 9244, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000404012024, to_date('04-04-2000', 'dd-mm-yyyy'), to_date('18-04-2000', 'dd-mm-yyyy'), 3, 792, to_date('22-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304012025, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 1, 2414, to_date('09-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010718012026, to_date('18-07-2001', 'dd-mm-yyyy'), to_date('01-08-2001', 'dd-mm-yyyy'), 3, 2191, to_date('01-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202012027, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 2, 2123, to_date('08-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051212012028, to_date('12-12-2005', 'dd-mm-yyyy'), to_date('26-12-2005', 'dd-mm-yyyy'), 3, 5470, to_date('30-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110917012029, to_date('17-09-2011', 'dd-mm-yyyy'), to_date('01-10-2011', 'dd-mm-yyyy'), 4, 9137, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624012030, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 2, 10198, to_date('30-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110603012031, to_date('03-06-2011', 'dd-mm-yyyy'), to_date('17-06-2011', 'dd-mm-yyyy'), 3, 5184, to_date('04-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121106012032, to_date('06-11-2012', 'dd-mm-yyyy'), to_date('20-11-2012', 'dd-mm-yyyy'), 2, 8773, to_date('21-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020719012033, to_date('19-07-2002', 'dd-mm-yyyy'), to_date('02-08-2002', 'dd-mm-yyyy'), 3, 2435, to_date('04-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120711012034, to_date('11-07-2012', 'dd-mm-yyyy'), to_date('25-07-2012', 'dd-mm-yyyy'), 4, 8313, to_date('29-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031003012035, to_date('03-10-2003', 'dd-mm-yyyy'), to_date('17-10-2003', 'dd-mm-yyyy'), 2, 3204, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090817012036, to_date('17-08-2009', 'dd-mm-yyyy'), to_date('31-08-2009', 'dd-mm-yyyy'), 2, 8315, to_date('18-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040425012037, to_date('25-04-2004', 'dd-mm-yyyy'), to_date('09-05-2004', 'dd-mm-yyyy'), 4, 4035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111211012038, to_date('11-12-2011', 'dd-mm-yyyy'), to_date('25-12-2011', 'dd-mm-yyyy'), 3, 7643, to_date('30-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425012039, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 3, 2455, to_date('02-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071006012040, to_date('06-10-2007', 'dd-mm-yyyy'), to_date('20-10-2007', 'dd-mm-yyyy'), 4, 6394, to_date('09-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070211012041, to_date('11-02-2007', 'dd-mm-yyyy'), to_date('25-02-2007', 'dd-mm-yyyy'), 2, 6255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100715012042, to_date('15-07-2010', 'dd-mm-yyyy'), to_date('29-07-2010', 'dd-mm-yyyy'), 3, 7920, to_date('20-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717012043, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 3, 8578, to_date('21-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091210012044, to_date('10-12-2009', 'dd-mm-yyyy'), to_date('24-12-2009', 'dd-mm-yyyy'), 3, 9053, to_date('12-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120802012045, to_date('02-08-2012', 'dd-mm-yyyy'), to_date('16-08-2012', 'dd-mm-yyyy'), 3, 8516, to_date('20-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131006012046, to_date('06-10-2013', 'dd-mm-yyyy'), to_date('20-10-2013', 'dd-mm-yyyy'), 3, 11578, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020227012047, to_date('27-02-2002', 'dd-mm-yyyy'), to_date('13-03-2002', 'dd-mm-yyyy'), 1, 3469, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110805012048, to_date('05-08-2011', 'dd-mm-yyyy'), to_date('19-08-2011', 'dd-mm-yyyy'), 2, 10331, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030317012049, to_date('17-03-2003', 'dd-mm-yyyy'), to_date('31-03-2003', 'dd-mm-yyyy'), 2, 2791, to_date('20-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040916012050, to_date('16-09-2004', 'dd-mm-yyyy'), to_date('30-09-2004', 'dd-mm-yyyy'), 2, 2192, to_date('03-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100827012051, to_date('27-08-2010', 'dd-mm-yyyy'), to_date('10-09-2010', 'dd-mm-yyyy'), 4, 6295, to_date('08-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120101012052, to_date('01-01-2012', 'dd-mm-yyyy'), to_date('15-01-2012', 'dd-mm-yyyy'), 1, 10206, to_date('10-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723012053, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 4, 6543, to_date('10-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080930012054, to_date('30-09-2008', 'dd-mm-yyyy'), to_date('14-10-2008', 'dd-mm-yyyy'), 3, 5371, to_date('06-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020807012055, to_date('07-08-2002', 'dd-mm-yyyy'), to_date('21-08-2002', 'dd-mm-yyyy'), 4, 2217, to_date('08-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030822012056, to_date('22-08-2003', 'dd-mm-yyyy'), to_date('05-09-2003', 'dd-mm-yyyy'), 2, 3144, to_date('24-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130601012057, to_date('01-06-2013', 'dd-mm-yyyy'), to_date('15-06-2013', 'dd-mm-yyyy'), 3, 7931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131104012058, to_date('04-11-2013', 'dd-mm-yyyy'), to_date('18-11-2013', 'dd-mm-yyyy'), 2, 10236, to_date('13-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111101012059, to_date('01-11-2011', 'dd-mm-yyyy'), to_date('15-11-2011', 'dd-mm-yyyy'), 2, 7814, to_date('04-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029012060, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 2, 2981, to_date('12-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040603012061, to_date('03-06-2004', 'dd-mm-yyyy'), to_date('17-06-2004', 'dd-mm-yyyy'), 3, 3563, to_date('18-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120513012062, to_date('13-05-2012', 'dd-mm-yyyy'), to_date('27-05-2012', 'dd-mm-yyyy'), 3, 5885, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000615012063, to_date('15-06-2000', 'dd-mm-yyyy'), to_date('29-06-2000', 'dd-mm-yyyy'), 3, 1186, to_date('28-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090615012064, to_date('15-06-2009', 'dd-mm-yyyy'), to_date('29-06-2009', 'dd-mm-yyyy'), 1, 6740, to_date('30-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070610012065, to_date('10-06-2007', 'dd-mm-yyyy'), to_date('24-06-2007', 'dd-mm-yyyy'), 1, 5960, to_date('20-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090512012066, to_date('12-05-2009', 'dd-mm-yyyy'), to_date('26-05-2009', 'dd-mm-yyyy'), 1, 5086, to_date('17-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619012067, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 2, 1293, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050317012068, to_date('17-03-2005', 'dd-mm-yyyy'), to_date('31-03-2005', 'dd-mm-yyyy'), 3, 3836, to_date('30-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521012069, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 2, 5557, to_date('01-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110512012070, to_date('12-05-2011', 'dd-mm-yyyy'), to_date('26-05-2011', 'dd-mm-yyyy'), 2, 5980, to_date('30-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130731012071, to_date('31-07-2013', 'dd-mm-yyyy'), to_date('14-08-2013', 'dd-mm-yyyy'), 1, 9118, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090328012072, to_date('28-03-2009', 'dd-mm-yyyy'), to_date('11-04-2009', 'dd-mm-yyyy'), 2, 5739, to_date('31-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070213012073, to_date('13-02-2007', 'dd-mm-yyyy'), to_date('27-02-2007', 'dd-mm-yyyy'), 1, 5331, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061015012074, to_date('15-10-2006', 'dd-mm-yyyy'), to_date('29-10-2006', 'dd-mm-yyyy'), 3, 4542, to_date('24-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050203012075, to_date('03-02-2005', 'dd-mm-yyyy'), to_date('17-02-2005', 'dd-mm-yyyy'), 4, 5044, to_date('19-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080906012076, to_date('06-09-2008', 'dd-mm-yyyy'), to_date('20-09-2008', 'dd-mm-yyyy'), 4, 6716, to_date('13-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130722012077, to_date('22-07-2013', 'dd-mm-yyyy'), to_date('05-08-2013', 'dd-mm-yyyy'), 3, 8131, to_date('10-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001125012078, to_date('25-11-2000', 'dd-mm-yyyy'), to_date('09-12-2000', 'dd-mm-yyyy'), 2, 1008, to_date('12-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040522012079, to_date('22-05-2004', 'dd-mm-yyyy'), to_date('05-06-2004', 'dd-mm-yyyy'), 3, 2222, to_date('26-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020710012080, to_date('10-07-2002', 'dd-mm-yyyy'), to_date('24-07-2002', 'dd-mm-yyyy'), 3, 3522, to_date('27-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001011012081, to_date('11-10-2000', 'dd-mm-yyyy'), to_date('25-10-2000', 'dd-mm-yyyy'), 1, 1971, to_date('17-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511012082, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 1, 1524, to_date('15-05-2001', 'dd-mm-yyyy'));
commit;
prompt 16000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021206012083, to_date('06-12-2002', 'dd-mm-yyyy'), to_date('20-12-2002', 'dd-mm-yyyy'), 2, 2876, to_date('15-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140408012084, to_date('08-04-2014', 'dd-mm-yyyy'), to_date('22-04-2014', 'dd-mm-yyyy'), 1, 11127, to_date('09-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011206012085, to_date('06-12-2001', 'dd-mm-yyyy'), to_date('20-12-2001', 'dd-mm-yyyy'), 2, 2127, to_date('23-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000910012086, to_date('10-09-2000', 'dd-mm-yyyy'), to_date('24-09-2000', 'dd-mm-yyyy'), 4, 2805, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061029012087, to_date('29-10-2006', 'dd-mm-yyyy'), to_date('12-11-2006', 'dd-mm-yyyy'), 3, 3312, to_date('31-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051101012088, to_date('01-11-2005', 'dd-mm-yyyy'), to_date('15-11-2005', 'dd-mm-yyyy'), 3, 6822, to_date('16-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031116012089, to_date('16-11-2003', 'dd-mm-yyyy'), to_date('30-11-2003', 'dd-mm-yyyy'), 1, 2458, to_date('19-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104012090, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 2, 4491, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010711012091, to_date('11-07-2001', 'dd-mm-yyyy'), to_date('25-07-2001', 'dd-mm-yyyy'), 3, 996, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020427012092, to_date('27-04-2002', 'dd-mm-yyyy'), to_date('11-05-2002', 'dd-mm-yyyy'), 2, 2188, to_date('05-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001107012093, to_date('07-11-2000', 'dd-mm-yyyy'), to_date('21-11-2000', 'dd-mm-yyyy'), 4, 1592, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031223012094, to_date('23-12-2003', 'dd-mm-yyyy'), to_date('06-01-2004', 'dd-mm-yyyy'), 1, 3047, to_date('01-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010531012095, to_date('31-05-2001', 'dd-mm-yyyy'), to_date('14-06-2001', 'dd-mm-yyyy'), 3, 3440, to_date('04-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100803012096, to_date('03-08-2010', 'dd-mm-yyyy'), to_date('17-08-2010', 'dd-mm-yyyy'), 2, 8594, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010115012097, to_date('15-01-2001', 'dd-mm-yyyy'), to_date('29-01-2001', 'dd-mm-yyyy'), 3, 3081, to_date('22-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031119012098, to_date('19-11-2003', 'dd-mm-yyyy'), to_date('03-12-2003', 'dd-mm-yyyy'), 3, 4069, to_date('24-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130226012099, to_date('26-02-2013', 'dd-mm-yyyy'), to_date('12-03-2013', 'dd-mm-yyyy'), 4, 8042, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000612012100, to_date('12-06-2000', 'dd-mm-yyyy'), to_date('26-06-2000', 'dd-mm-yyyy'), 3, 2533, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620012101, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 2, 3459, to_date('21-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061116012102, to_date('16-11-2006', 'dd-mm-yyyy'), to_date('30-11-2006', 'dd-mm-yyyy'), 2, 3543, to_date('01-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040424012103, to_date('24-04-2004', 'dd-mm-yyyy'), to_date('08-05-2004', 'dd-mm-yyyy'), 2, 3462, to_date('30-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100815012104, to_date('15-08-2010', 'dd-mm-yyyy'), to_date('29-08-2010', 'dd-mm-yyyy'), 1, 6144, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070604012105, to_date('04-06-2007', 'dd-mm-yyyy'), to_date('18-06-2007', 'dd-mm-yyyy'), 4, 5575, to_date('09-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090821012106, to_date('21-08-2009', 'dd-mm-yyyy'), to_date('04-09-2009', 'dd-mm-yyyy'), 4, 7251, to_date('27-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040627012107, to_date('27-06-2004', 'dd-mm-yyyy'), to_date('11-07-2004', 'dd-mm-yyyy'), 3, 4717, to_date('29-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011205012108, to_date('05-12-2001', 'dd-mm-yyyy'), to_date('19-12-2001', 'dd-mm-yyyy'), 4, 3501, to_date('22-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070620012109, to_date('20-06-2007', 'dd-mm-yyyy'), to_date('04-07-2007', 'dd-mm-yyyy'), 3, 4380, to_date('21-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050901012110, to_date('01-09-2005', 'dd-mm-yyyy'), to_date('15-09-2005', 'dd-mm-yyyy'), 3, 3782, to_date('03-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061012012111, to_date('12-10-2006', 'dd-mm-yyyy'), to_date('26-10-2006', 'dd-mm-yyyy'), 2, 3612, to_date('25-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090826012112, to_date('26-08-2009', 'dd-mm-yyyy'), to_date('09-09-2009', 'dd-mm-yyyy'), 4, 5441, to_date('13-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021210012113, to_date('10-12-2002', 'dd-mm-yyyy'), to_date('24-12-2002', 'dd-mm-yyyy'), 1, 1545, to_date('17-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620012114, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 3, 7211, to_date('27-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040123012115, to_date('23-01-2004', 'dd-mm-yyyy'), to_date('06-02-2004', 'dd-mm-yyyy'), 2, 3659, to_date('06-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000309012116, to_date('09-03-2000', 'dd-mm-yyyy'), to_date('23-03-2000', 'dd-mm-yyyy'), 1, 702, to_date('24-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010707012117, to_date('07-07-2001', 'dd-mm-yyyy'), to_date('21-07-2001', 'dd-mm-yyyy'), 1, 2194, to_date('12-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905012118, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 2, 1204, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030826012119, to_date('26-08-2003', 'dd-mm-yyyy'), to_date('09-09-2003', 'dd-mm-yyyy'), 3, 4746, to_date('30-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070514012120, to_date('14-05-2007', 'dd-mm-yyyy'), to_date('28-05-2007', 'dd-mm-yyyy'), 3, 5613, to_date('16-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222012121, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 3, 7811, to_date('09-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004012122, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 3, 1657, to_date('15-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100612012123, to_date('12-06-2010', 'dd-mm-yyyy'), to_date('26-06-2010', 'dd-mm-yyyy'), 3, 7268, to_date('16-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100730012124, to_date('30-07-2010', 'dd-mm-yyyy'), to_date('13-08-2010', 'dd-mm-yyyy'), 3, 6970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130414012125, to_date('14-04-2013', 'dd-mm-yyyy'), to_date('28-04-2013', 'dd-mm-yyyy'), 4, 9590, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060625012126, to_date('25-06-2006', 'dd-mm-yyyy'), to_date('09-07-2006', 'dd-mm-yyyy'), 2, 5933, to_date('04-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011208012127, to_date('08-12-2001', 'dd-mm-yyyy'), to_date('22-12-2001', 'dd-mm-yyyy'), 2, 2417, to_date('27-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080504012128, to_date('04-05-2008', 'dd-mm-yyyy'), to_date('18-05-2008', 'dd-mm-yyyy'), 2, 5185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070110012129, to_date('10-01-2007', 'dd-mm-yyyy'), to_date('24-01-2007', 'dd-mm-yyyy'), 2, 4155, to_date('17-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902012130, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 3, 4636, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000506012131, to_date('06-05-2000', 'dd-mm-yyyy'), to_date('20-05-2000', 'dd-mm-yyyy'), 3, 2382, to_date('21-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100928012132, to_date('28-09-2010', 'dd-mm-yyyy'), to_date('12-10-2010', 'dd-mm-yyyy'), 2, 5251, to_date('10-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080504012133, to_date('04-05-2008', 'dd-mm-yyyy'), to_date('18-05-2008', 'dd-mm-yyyy'), 3, 4107, to_date('07-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040315012134, to_date('15-03-2004', 'dd-mm-yyyy'), to_date('29-03-2004', 'dd-mm-yyyy'), 2, 5839, to_date('29-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020531012135, to_date('31-05-2002', 'dd-mm-yyyy'), to_date('14-06-2002', 'dd-mm-yyyy'), 2, 2519, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030420012136, to_date('20-04-2003', 'dd-mm-yyyy'), to_date('04-05-2003', 'dd-mm-yyyy'), 2, 3834, to_date('23-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430012137, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 3, 6897, to_date('02-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021120012138, to_date('20-11-2002', 'dd-mm-yyyy'), to_date('04-12-2002', 'dd-mm-yyyy'), 2, 1828, to_date('05-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020520012139, to_date('20-05-2002', 'dd-mm-yyyy'), to_date('03-06-2002', 'dd-mm-yyyy'), 3, 1115, to_date('02-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130504012140, to_date('04-05-2013', 'dd-mm-yyyy'), to_date('18-05-2013', 'dd-mm-yyyy'), 2, 10909, to_date('08-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230012141, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 2, 2663, to_date('16-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050609012142, to_date('09-06-2005', 'dd-mm-yyyy'), to_date('23-06-2005', 'dd-mm-yyyy'), 2, 2888, to_date('27-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130910012143, to_date('10-09-2013', 'dd-mm-yyyy'), to_date('24-09-2013', 'dd-mm-yyyy'), 3, 7504, to_date('27-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060926012144, to_date('26-09-2006', 'dd-mm-yyyy'), to_date('10-10-2006', 'dd-mm-yyyy'), 2, 4138, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020607012145, to_date('07-06-2002', 'dd-mm-yyyy'), to_date('21-06-2002', 'dd-mm-yyyy'), 1, 1363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060218012146, to_date('18-02-2006', 'dd-mm-yyyy'), to_date('04-03-2006', 'dd-mm-yyyy'), 2, 2907, to_date('23-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071202012147, to_date('02-12-2007', 'dd-mm-yyyy'), to_date('16-12-2007', 'dd-mm-yyyy'), 2, 7146, to_date('14-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050727012148, to_date('27-07-2005', 'dd-mm-yyyy'), to_date('10-08-2005', 'dd-mm-yyyy'), 2, 3941, to_date('14-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131007012149, to_date('07-10-2013', 'dd-mm-yyyy'), to_date('21-10-2013', 'dd-mm-yyyy'), 1, 9882, to_date('11-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110209012150, to_date('09-02-2011', 'dd-mm-yyyy'), to_date('23-02-2011', 'dd-mm-yyyy'), 4, 9989, to_date('10-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110221012151, to_date('21-02-2011', 'dd-mm-yyyy'), to_date('07-03-2011', 'dd-mm-yyyy'), 2, 9074, to_date('12-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070922012152, to_date('22-09-2007', 'dd-mm-yyyy'), to_date('06-10-2007', 'dd-mm-yyyy'), 4, 6806, to_date('05-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090923012153, to_date('23-09-2009', 'dd-mm-yyyy'), to_date('07-10-2009', 'dd-mm-yyyy'), 3, 6972, to_date('03-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130509012154, to_date('09-05-2013', 'dd-mm-yyyy'), to_date('23-05-2013', 'dd-mm-yyyy'), 3, 10573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117012155, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 2, 6028, to_date('30-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091206012156, to_date('06-12-2009', 'dd-mm-yyyy'), to_date('20-12-2009', 'dd-mm-yyyy'), 2, 7128, to_date('24-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070403012157, to_date('03-04-2007', 'dd-mm-yyyy'), to_date('17-04-2007', 'dd-mm-yyyy'), 3, 5838, to_date('11-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010805012158, to_date('05-08-2001', 'dd-mm-yyyy'), to_date('19-08-2001', 'dd-mm-yyyy'), 3, 2285, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110808012159, to_date('08-08-2011', 'dd-mm-yyyy'), to_date('22-08-2011', 'dd-mm-yyyy'), 4, 7168, to_date('15-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070520012160, to_date('20-05-2007', 'dd-mm-yyyy'), to_date('03-06-2007', 'dd-mm-yyyy'), 2, 3477, to_date('25-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030115012161, to_date('15-01-2003', 'dd-mm-yyyy'), to_date('29-01-2003', 'dd-mm-yyyy'), 3, 3620, to_date('02-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080914012162, to_date('14-09-2008', 'dd-mm-yyyy'), to_date('28-09-2008', 'dd-mm-yyyy'), 1, 4910, to_date('18-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010629012163, to_date('29-06-2001', 'dd-mm-yyyy'), to_date('13-07-2001', 'dd-mm-yyyy'), 2, 3306, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080805012164, to_date('05-08-2008', 'dd-mm-yyyy'), to_date('19-08-2008', 'dd-mm-yyyy'), 4, 4536, to_date('07-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120214012165, to_date('14-02-2012', 'dd-mm-yyyy'), to_date('28-02-2012', 'dd-mm-yyyy'), 3, 11128, to_date('02-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020901012166, to_date('01-09-2002', 'dd-mm-yyyy'), to_date('15-09-2002', 'dd-mm-yyyy'), 2, 3750, to_date('06-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000722012167, to_date('22-07-2000', 'dd-mm-yyyy'), to_date('05-08-2000', 'dd-mm-yyyy'), 1, 696, to_date('07-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081211012168, to_date('11-12-2008', 'dd-mm-yyyy'), to_date('25-12-2008', 'dd-mm-yyyy'), 2, 4962, to_date('16-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040504012169, to_date('04-05-2004', 'dd-mm-yyyy'), to_date('18-05-2004', 'dd-mm-yyyy'), 2, 4124, to_date('16-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070424012170, to_date('24-04-2007', 'dd-mm-yyyy'), to_date('08-05-2007', 'dd-mm-yyyy'), 2, 4490, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040923012171, to_date('23-09-2004', 'dd-mm-yyyy'), to_date('07-10-2004', 'dd-mm-yyyy'), 3, 4871, to_date('27-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071129012172, to_date('29-11-2007', 'dd-mm-yyyy'), to_date('13-12-2007', 'dd-mm-yyyy'), 1, 3470, to_date('11-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061128012173, to_date('28-11-2006', 'dd-mm-yyyy'), to_date('12-12-2006', 'dd-mm-yyyy'), 2, 4295, to_date('01-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080202012174, to_date('02-02-2008', 'dd-mm-yyyy'), to_date('16-02-2008', 'dd-mm-yyyy'), 1, 3522, to_date('13-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030905012175, to_date('05-09-2003', 'dd-mm-yyyy'), to_date('19-09-2003', 'dd-mm-yyyy'), 2, 4114, to_date('19-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110628012176, to_date('28-06-2011', 'dd-mm-yyyy'), to_date('12-07-2011', 'dd-mm-yyyy'), 3, 10147, to_date('07-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040717012177, to_date('17-07-2004', 'dd-mm-yyyy'), to_date('31-07-2004', 'dd-mm-yyyy'), 4, 5704, to_date('01-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090207012178, to_date('07-02-2009', 'dd-mm-yyyy'), to_date('21-02-2009', 'dd-mm-yyyy'), 2, 3950, to_date('18-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070709012179, to_date('09-07-2007', 'dd-mm-yyyy'), to_date('23-07-2007', 'dd-mm-yyyy'), 2, 5586, to_date('17-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020629012180, to_date('29-06-2002', 'dd-mm-yyyy'), to_date('13-07-2002', 'dd-mm-yyyy'), 3, 5819, to_date('17-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130403012181, to_date('03-04-2013', 'dd-mm-yyyy'), to_date('17-04-2013', 'dd-mm-yyyy'), 2, 8915, to_date('12-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040524012182, to_date('24-05-2004', 'dd-mm-yyyy'), to_date('07-06-2004', 'dd-mm-yyyy'), 2, 3555, to_date('12-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050530012183, to_date('30-05-2005', 'dd-mm-yyyy'), to_date('13-06-2005', 'dd-mm-yyyy'), 4, 4694, to_date('16-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120530012184, to_date('30-05-2012', 'dd-mm-yyyy'), to_date('13-06-2012', 'dd-mm-yyyy'), 3, 7498, to_date('18-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080325012185, to_date('25-03-2008', 'dd-mm-yyyy'), to_date('08-04-2008', 'dd-mm-yyyy'), 2, 5826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040108012186, to_date('08-01-2004', 'dd-mm-yyyy'), to_date('22-01-2004', 'dd-mm-yyyy'), 2, 3347, to_date('13-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030728014885, to_date('28-07-2003', 'dd-mm-yyyy'), to_date('11-08-2003', 'dd-mm-yyyy'), 1, 5277, to_date('13-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140510014886, to_date('10-05-2014', 'dd-mm-yyyy'), to_date('24-05-2014', 'dd-mm-yyyy'), 4, 8288, to_date('16-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071003014887, to_date('03-10-2007', 'dd-mm-yyyy'), to_date('17-10-2007', 'dd-mm-yyyy'), 3, 5230, to_date('22-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120705014888, to_date('05-07-2012', 'dd-mm-yyyy'), to_date('19-07-2012', 'dd-mm-yyyy'), 1, 9432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130602014889, to_date('02-06-2013', 'dd-mm-yyyy'), to_date('16-06-2013', 'dd-mm-yyyy'), 2, 9057, to_date('06-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030910014890, to_date('10-09-2003', 'dd-mm-yyyy'), to_date('24-09-2003', 'dd-mm-yyyy'), 3, 5250, to_date('27-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131123014891, to_date('23-11-2013', 'dd-mm-yyyy'), to_date('07-12-2013', 'dd-mm-yyyy'), 1, 11716, to_date('11-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050307014892, to_date('07-03-2005', 'dd-mm-yyyy'), to_date('21-03-2005', 'dd-mm-yyyy'), 2, 4096, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000210014893, to_date('10-02-2000', 'dd-mm-yyyy'), to_date('24-02-2000', 'dd-mm-yyyy'), 3, 2264, to_date('28-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050123014894, to_date('23-01-2005', 'dd-mm-yyyy'), to_date('06-02-2005', 'dd-mm-yyyy'), 1, 4185, to_date('24-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050105014895, to_date('05-01-2005', 'dd-mm-yyyy'), to_date('19-01-2005', 'dd-mm-yyyy'), 1, 2891, to_date('13-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120707014896, to_date('07-07-2012', 'dd-mm-yyyy'), to_date('21-07-2012', 'dd-mm-yyyy'), 4, 8626, to_date('13-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040109014897, to_date('09-01-2004', 'dd-mm-yyyy'), to_date('23-01-2004', 'dd-mm-yyyy'), 2, 3842, to_date('19-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030315014898, to_date('15-03-2003', 'dd-mm-yyyy'), to_date('29-03-2003', 'dd-mm-yyyy'), 3, 4543, to_date('20-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011124014899, to_date('24-11-2001', 'dd-mm-yyyy'), to_date('08-12-2001', 'dd-mm-yyyy'), 3, 2815, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030510014900, to_date('10-05-2003', 'dd-mm-yyyy'), to_date('24-05-2003', 'dd-mm-yyyy'), 2, 5547, to_date('20-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090520014901, to_date('20-05-2009', 'dd-mm-yyyy'), to_date('03-06-2009', 'dd-mm-yyyy'), 1, 6107, to_date('31-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070520014902, to_date('20-05-2007', 'dd-mm-yyyy'), to_date('03-06-2007', 'dd-mm-yyyy'), 3, 6976, to_date('31-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121112014903, to_date('12-11-2012', 'dd-mm-yyyy'), to_date('26-11-2012', 'dd-mm-yyyy'), 4, 7506, to_date('14-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050730014904, to_date('30-07-2005', 'dd-mm-yyyy'), to_date('13-08-2005', 'dd-mm-yyyy'), 3, 6175, to_date('14-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051117014905, to_date('17-11-2005', 'dd-mm-yyyy'), to_date('01-12-2005', 'dd-mm-yyyy'), 3, 4886, to_date('03-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061021014906, to_date('21-10-2006', 'dd-mm-yyyy'), to_date('04-11-2006', 'dd-mm-yyyy'), 2, 3387, to_date('31-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070913014907, to_date('13-09-2007', 'dd-mm-yyyy'), to_date('27-09-2007', 'dd-mm-yyyy'), 2, 4129, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070127014908, to_date('27-01-2007', 'dd-mm-yyyy'), to_date('10-02-2007', 'dd-mm-yyyy'), 4, 7044, to_date('04-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101202014909, to_date('02-12-2010', 'dd-mm-yyyy'), to_date('16-12-2010', 'dd-mm-yyyy'), 3, 7650, to_date('10-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130302014910, to_date('02-03-2013', 'dd-mm-yyyy'), to_date('16-03-2013', 'dd-mm-yyyy'), 3, 8178, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010731014911, to_date('31-07-2001', 'dd-mm-yyyy'), to_date('14-08-2001', 'dd-mm-yyyy'), 3, 1619, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303014912, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 2, 5566, to_date('08-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060805014913, to_date('05-08-2006', 'dd-mm-yyyy'), to_date('19-08-2006', 'dd-mm-yyyy'), 2, 3157, to_date('11-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050627014914, to_date('27-06-2005', 'dd-mm-yyyy'), to_date('11-07-2005', 'dd-mm-yyyy'), 1, 5133, to_date('04-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040903014915, to_date('03-09-2004', 'dd-mm-yyyy'), to_date('17-09-2004', 'dd-mm-yyyy'), 2, 5019, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070504014916, to_date('04-05-2007', 'dd-mm-yyyy'), to_date('18-05-2007', 'dd-mm-yyyy'), 3, 7501, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090129014917, to_date('29-01-2009', 'dd-mm-yyyy'), to_date('12-02-2009', 'dd-mm-yyyy'), 2, 7216, to_date('03-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020116014918, to_date('16-01-2002', 'dd-mm-yyyy'), to_date('30-01-2002', 'dd-mm-yyyy'), 2, 3534, to_date('30-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130107014919, to_date('07-01-2013', 'dd-mm-yyyy'), to_date('21-01-2013', 'dd-mm-yyyy'), 3, 9083, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041105014920, to_date('05-11-2004', 'dd-mm-yyyy'), to_date('19-11-2004', 'dd-mm-yyyy'), 3, 5347, to_date('18-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100512014921, to_date('12-05-2010', 'dd-mm-yyyy'), to_date('26-05-2010', 'dd-mm-yyyy'), 2, 6436, to_date('29-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208014922, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 2, 10643, to_date('09-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020923014923, to_date('23-09-2002', 'dd-mm-yyyy'), to_date('07-10-2002', 'dd-mm-yyyy'), 3, 3687, to_date('04-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080413014924, to_date('13-04-2008', 'dd-mm-yyyy'), to_date('27-04-2008', 'dd-mm-yyyy'), 3, 5838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010710014925, to_date('10-07-2001', 'dd-mm-yyyy'), to_date('24-07-2001', 'dd-mm-yyyy'), 2, 1466, to_date('28-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414014926, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 3, 8803, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030721014927, to_date('21-07-2003', 'dd-mm-yyyy'), to_date('04-08-2003', 'dd-mm-yyyy'), 1, 2555, to_date('31-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130630014928, to_date('30-06-2013', 'dd-mm-yyyy'), to_date('14-07-2013', 'dd-mm-yyyy'), 4, 10793, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090216014929, to_date('16-02-2009', 'dd-mm-yyyy'), to_date('02-03-2009', 'dd-mm-yyyy'), 1, 5659, to_date('04-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010101014930, to_date('01-01-2001', 'dd-mm-yyyy'), to_date('15-01-2001', 'dd-mm-yyyy'), 2, 3950, to_date('16-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011028014931, to_date('28-10-2001', 'dd-mm-yyyy'), to_date('11-11-2001', 'dd-mm-yyyy'), 3, 2798, to_date('12-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080301014932, to_date('01-03-2008', 'dd-mm-yyyy'), to_date('15-03-2008', 'dd-mm-yyyy'), 2, 5845, to_date('04-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100913014933, to_date('13-09-2010', 'dd-mm-yyyy'), to_date('27-09-2010', 'dd-mm-yyyy'), 4, 8566, to_date('29-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208014934, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 3, 2715, to_date('16-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120216014935, to_date('16-02-2012', 'dd-mm-yyyy'), to_date('01-03-2012', 'dd-mm-yyyy'), 2, 9317, to_date('26-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110802014936, to_date('02-08-2011', 'dd-mm-yyyy'), to_date('16-08-2011', 'dd-mm-yyyy'), 3, 7750, to_date('17-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061202014937, to_date('02-12-2006', 'dd-mm-yyyy'), to_date('16-12-2006', 'dd-mm-yyyy'), 2, 6109, to_date('13-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417014938, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 3, 7567, to_date('07-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030207014939, to_date('07-02-2003', 'dd-mm-yyyy'), to_date('21-02-2003', 'dd-mm-yyyy'), 2, 5076, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609014940, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 3, 2009, to_date('22-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010408014941, to_date('08-04-2001', 'dd-mm-yyyy'), to_date('22-04-2001', 'dd-mm-yyyy'), 3, 1841, to_date('25-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050415014942, to_date('15-04-2005', 'dd-mm-yyyy'), to_date('29-04-2005', 'dd-mm-yyyy'), 2, 5620, to_date('17-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130222014943, to_date('22-02-2013', 'dd-mm-yyyy'), to_date('08-03-2013', 'dd-mm-yyyy'), 1, 6982, to_date('07-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020922014944, to_date('22-09-2002', 'dd-mm-yyyy'), to_date('06-10-2002', 'dd-mm-yyyy'), 1, 2134, to_date('06-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070124014945, to_date('24-01-2007', 'dd-mm-yyyy'), to_date('07-02-2007', 'dd-mm-yyyy'), 4, 7488, to_date('30-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120906014946, to_date('06-09-2012', 'dd-mm-yyyy'), to_date('20-09-2012', 'dd-mm-yyyy'), 4, 8623, to_date('13-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110525014947, to_date('25-05-2011', 'dd-mm-yyyy'), to_date('08-06-2011', 'dd-mm-yyyy'), 3, 8199, to_date('05-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080524014948, to_date('24-05-2008', 'dd-mm-yyyy'), to_date('07-06-2008', 'dd-mm-yyyy'), 1, 5750, to_date('31-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021111014949, to_date('11-11-2002', 'dd-mm-yyyy'), to_date('25-11-2002', 'dd-mm-yyyy'), 3, 2782, to_date('21-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071119014950, to_date('19-11-2007', 'dd-mm-yyyy'), to_date('03-12-2007', 'dd-mm-yyyy'), 4, 4972, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050209014951, to_date('09-02-2005', 'dd-mm-yyyy'), to_date('23-02-2005', 'dd-mm-yyyy'), 1, 4909, to_date('26-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041005014952, to_date('05-10-2004', 'dd-mm-yyyy'), to_date('19-10-2004', 'dd-mm-yyyy'), 3, 5616, to_date('23-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010401014953, to_date('01-04-2001', 'dd-mm-yyyy'), to_date('15-04-2001', 'dd-mm-yyyy'), 2, 1993, to_date('19-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080804014954, to_date('04-08-2008', 'dd-mm-yyyy'), to_date('18-08-2008', 'dd-mm-yyyy'), 2, 6075, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130627014955, to_date('27-06-2013', 'dd-mm-yyyy'), to_date('11-07-2013', 'dd-mm-yyyy'), 3, 5736, to_date('16-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020123014956, to_date('23-01-2002', 'dd-mm-yyyy'), to_date('06-02-2002', 'dd-mm-yyyy'), 1, 3173, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409014957, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 1, 5896, to_date('25-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010627014958, to_date('27-06-2001', 'dd-mm-yyyy'), to_date('11-07-2001', 'dd-mm-yyyy'), 1, 2131, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020111014959, to_date('11-01-2002', 'dd-mm-yyyy'), to_date('25-01-2002', 'dd-mm-yyyy'), 2, 1974, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021118014960, to_date('18-11-2002', 'dd-mm-yyyy'), to_date('02-12-2002', 'dd-mm-yyyy'), 3, 4615, to_date('02-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140427014961, to_date('27-04-2014', 'dd-mm-yyyy'), to_date('11-05-2014', 'dd-mm-yyyy'), 2, 14109, to_date('12-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104014962, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 2, 2292, to_date('19-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121218014963, to_date('18-12-2012', 'dd-mm-yyyy'), to_date('01-01-2013', 'dd-mm-yyyy'), 4, 9358, to_date('25-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071217014964, to_date('17-12-2007', 'dd-mm-yyyy'), to_date('31-12-2007', 'dd-mm-yyyy'), 1, 2682, to_date('02-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030826014965, to_date('26-08-2003', 'dd-mm-yyyy'), to_date('09-09-2003', 'dd-mm-yyyy'), 1, 3516, to_date('12-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030226014966, to_date('26-02-2003', 'dd-mm-yyyy'), to_date('12-03-2003', 'dd-mm-yyyy'), 4, 5323, to_date('16-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090503014967, to_date('03-05-2009', 'dd-mm-yyyy'), to_date('17-05-2009', 'dd-mm-yyyy'), 2, 5201, to_date('19-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070427014968, to_date('27-04-2007', 'dd-mm-yyyy'), to_date('11-05-2007', 'dd-mm-yyyy'), 1, 5601, to_date('02-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040527014969, to_date('27-05-2004', 'dd-mm-yyyy'), to_date('10-06-2004', 'dd-mm-yyyy'), 3, 6293, to_date('07-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031129014970, to_date('29-11-2003', 'dd-mm-yyyy'), to_date('13-12-2003', 'dd-mm-yyyy'), 3, 2349, to_date('12-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709014971, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 3, 8950, to_date('11-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100524014972, to_date('24-05-2010', 'dd-mm-yyyy'), to_date('07-06-2010', 'dd-mm-yyyy'), 3, 6561, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050921014973, to_date('21-09-2005', 'dd-mm-yyyy'), to_date('05-10-2005', 'dd-mm-yyyy'), 2, 3919, to_date('24-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130322014974, to_date('22-03-2013', 'dd-mm-yyyy'), to_date('05-04-2013', 'dd-mm-yyyy'), 4, 7916, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071215014975, to_date('15-12-2007', 'dd-mm-yyyy'), to_date('29-12-2007', 'dd-mm-yyyy'), 4, 6988, to_date('17-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051231014976, to_date('31-12-2005', 'dd-mm-yyyy'), to_date('14-01-2006', 'dd-mm-yyyy'), 2, 3298, to_date('12-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020607014977, to_date('07-06-2002', 'dd-mm-yyyy'), to_date('21-06-2002', 'dd-mm-yyyy'), 1, 1406, to_date('22-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110716014978, to_date('16-07-2011', 'dd-mm-yyyy'), to_date('30-07-2011', 'dd-mm-yyyy'), 1, 6988, to_date('05-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110116014979, to_date('16-01-2011', 'dd-mm-yyyy'), to_date('30-01-2011', 'dd-mm-yyyy'), 2, 6721, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130921014980, to_date('21-09-2013', 'dd-mm-yyyy'), to_date('05-10-2013', 'dd-mm-yyyy'), 2, 8602, to_date('04-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070126014981, to_date('26-01-2007', 'dd-mm-yyyy'), to_date('09-02-2007', 'dd-mm-yyyy'), 2, 7766, to_date('14-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000601014982, to_date('01-06-2000', 'dd-mm-yyyy'), to_date('15-06-2000', 'dd-mm-yyyy'), 4, 3271, to_date('20-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031010014983, to_date('10-10-2003', 'dd-mm-yyyy'), to_date('24-10-2003', 'dd-mm-yyyy'), 2, 4571, to_date('22-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011224014984, to_date('24-12-2001', 'dd-mm-yyyy'), to_date('07-01-2002', 'dd-mm-yyyy'), 3, 1359, to_date('02-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130717014985, to_date('17-07-2013', 'dd-mm-yyyy'), to_date('31-07-2013', 'dd-mm-yyyy'), 3, 6746, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020121014986, to_date('21-01-2002', 'dd-mm-yyyy'), to_date('04-02-2002', 'dd-mm-yyyy'), 2, 2787, to_date('08-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071011014987, to_date('11-10-2007', 'dd-mm-yyyy'), to_date('25-10-2007', 'dd-mm-yyyy'), 2, 7182, to_date('21-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060408014988, to_date('08-04-2006', 'dd-mm-yyyy'), to_date('22-04-2006', 'dd-mm-yyyy'), 2, 5420, to_date('12-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050403014989, to_date('03-04-2005', 'dd-mm-yyyy'), to_date('17-04-2005', 'dd-mm-yyyy'), 2, 6394, to_date('08-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140222014990, to_date('22-02-2014', 'dd-mm-yyyy'), to_date('08-03-2014', 'dd-mm-yyyy'), 3, 8695, to_date('06-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050518014991, to_date('18-05-2005', 'dd-mm-yyyy'), to_date('01-06-2005', 'dd-mm-yyyy'), 2, 3742, to_date('23-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130110014992, to_date('10-01-2013', 'dd-mm-yyyy'), to_date('24-01-2013', 'dd-mm-yyyy'), 1, 9494, to_date('27-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901014993, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 2, 2228, to_date('13-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140421014994, to_date('21-04-2014', 'dd-mm-yyyy'), to_date('05-05-2014', 'dd-mm-yyyy'), 4, 9749, to_date('10-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070202014995, to_date('02-02-2007', 'dd-mm-yyyy'), to_date('16-02-2007', 'dd-mm-yyyy'), 4, 5330, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010218014996, to_date('18-02-2001', 'dd-mm-yyyy'), to_date('04-03-2001', 'dd-mm-yyyy'), 2, 2902, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030828014997, to_date('28-08-2003', 'dd-mm-yyyy'), to_date('11-09-2003', 'dd-mm-yyyy'), 3, 4077, to_date('29-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010616014998, to_date('16-06-2001', 'dd-mm-yyyy'), to_date('30-06-2001', 'dd-mm-yyyy'), 2, 3773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020620014999, to_date('20-06-2002', 'dd-mm-yyyy'), to_date('04-07-2002', 'dd-mm-yyyy'), 3, 2180, to_date('07-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101116015000, to_date('16-11-2010', 'dd-mm-yyyy'), to_date('30-11-2010', 'dd-mm-yyyy'), 1, 8236, to_date('18-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090722015001, to_date('22-07-2009', 'dd-mm-yyyy'), to_date('05-08-2009', 'dd-mm-yyyy'), 3, 6778, to_date('23-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071028015002, to_date('28-10-2007', 'dd-mm-yyyy'), to_date('11-11-2007', 'dd-mm-yyyy'), 3, 7804, to_date('04-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040930015003, to_date('30-09-2004', 'dd-mm-yyyy'), to_date('14-10-2004', 'dd-mm-yyyy'), 2, 5442, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729015004, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 1, 7055, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111022015005, to_date('22-10-2011', 'dd-mm-yyyy'), to_date('05-11-2011', 'dd-mm-yyyy'), 4, 8876, to_date('31-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120729015006, to_date('29-07-2012', 'dd-mm-yyyy'), to_date('12-08-2012', 'dd-mm-yyyy'), 3, 9566, to_date('15-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040326015007, to_date('26-03-2004', 'dd-mm-yyyy'), to_date('09-04-2004', 'dd-mm-yyyy'), 3, 5003, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080519015008, to_date('19-05-2008', 'dd-mm-yyyy'), to_date('02-06-2008', 'dd-mm-yyyy'), 3, 6078, to_date('08-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090423015009, to_date('23-04-2009', 'dd-mm-yyyy'), to_date('07-05-2009', 'dd-mm-yyyy'), 2, 5275, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010619015010, to_date('19-06-2001', 'dd-mm-yyyy'), to_date('03-07-2001', 'dd-mm-yyyy'), 3, 2868, to_date('03-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020124015011, to_date('24-01-2002', 'dd-mm-yyyy'), to_date('07-02-2002', 'dd-mm-yyyy'), 3, 3858, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051027015012, to_date('27-10-2005', 'dd-mm-yyyy'), to_date('10-11-2005', 'dd-mm-yyyy'), 3, 4972, to_date('02-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081016015013, to_date('16-10-2008', 'dd-mm-yyyy'), to_date('30-10-2008', 'dd-mm-yyyy'), 2, 6366, to_date('02-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080407015014, to_date('07-04-2008', 'dd-mm-yyyy'), to_date('21-04-2008', 'dd-mm-yyyy'), 3, 6757, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000205015015, to_date('05-02-2000', 'dd-mm-yyyy'), to_date('19-02-2000', 'dd-mm-yyyy'), 3, 2965, to_date('14-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040302015016, to_date('02-03-2004', 'dd-mm-yyyy'), to_date('16-03-2004', 'dd-mm-yyyy'), 3, 5533, to_date('10-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100305015017, to_date('05-03-2010', 'dd-mm-yyyy'), to_date('19-03-2010', 'dd-mm-yyyy'), 1, 5744, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120715015018, to_date('15-07-2012', 'dd-mm-yyyy'), to_date('29-07-2012', 'dd-mm-yyyy'), 3, 8805, to_date('28-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140413015019, to_date('13-04-2014', 'dd-mm-yyyy'), to_date('27-04-2014', 'dd-mm-yyyy'), 3, 7564, to_date('23-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041231015020, to_date('31-12-2004', 'dd-mm-yyyy'), to_date('14-01-2005', 'dd-mm-yyyy'), 3, 4218, to_date('05-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021015021, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 3, 7833, to_date('09-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091108015022, to_date('08-11-2009', 'dd-mm-yyyy'), to_date('22-11-2009', 'dd-mm-yyyy'), 2, 5436, to_date('15-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061002015023, to_date('02-10-2006', 'dd-mm-yyyy'), to_date('16-10-2006', 'dd-mm-yyyy'), 2, 3975, to_date('04-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011217015024, to_date('17-12-2001', 'dd-mm-yyyy'), to_date('31-12-2001', 'dd-mm-yyyy'), 3, 4490, to_date('03-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010221015025, to_date('21-02-2001', 'dd-mm-yyyy'), to_date('07-03-2001', 'dd-mm-yyyy'), 3, 1512, to_date('02-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091210015026, to_date('10-12-2009', 'dd-mm-yyyy'), to_date('24-12-2009', 'dd-mm-yyyy'), 1, 4668, to_date('22-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060727015027, to_date('27-07-2006', 'dd-mm-yyyy'), to_date('10-08-2006', 'dd-mm-yyyy'), 3, 5862, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130806015028, to_date('06-08-2013', 'dd-mm-yyyy'), to_date('20-08-2013', 'dd-mm-yyyy'), 4, 8190, to_date('26-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121008015029, to_date('08-10-2012', 'dd-mm-yyyy'), to_date('22-10-2012', 'dd-mm-yyyy'), 3, 6898, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060911015030, to_date('11-09-2006', 'dd-mm-yyyy'), to_date('25-09-2006', 'dd-mm-yyyy'), 2, 5902, to_date('15-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010618015031, to_date('18-06-2001', 'dd-mm-yyyy'), to_date('02-07-2001', 'dd-mm-yyyy'), 3, 936, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404015032, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 2, 6918, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011028015033, to_date('28-10-2001', 'dd-mm-yyyy'), to_date('11-11-2001', 'dd-mm-yyyy'), 2, 2916, to_date('08-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080114015034, to_date('14-01-2008', 'dd-mm-yyyy'), to_date('28-01-2008', 'dd-mm-yyyy'), 1, 7344, to_date('16-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030814015035, to_date('14-08-2003', 'dd-mm-yyyy'), to_date('28-08-2003', 'dd-mm-yyyy'), 3, 3424, to_date('31-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070604015036, to_date('04-06-2007', 'dd-mm-yyyy'), to_date('18-06-2007', 'dd-mm-yyyy'), 3, 5826, to_date('07-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021011015037, to_date('11-10-2002', 'dd-mm-yyyy'), to_date('25-10-2002', 'dd-mm-yyyy'), 1, 4037, to_date('30-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011004015038, to_date('04-10-2001', 'dd-mm-yyyy'), to_date('18-10-2001', 'dd-mm-yyyy'), 1, 3530, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100315015039, to_date('15-03-2010', 'dd-mm-yyyy'), to_date('29-03-2010', 'dd-mm-yyyy'), 3, 5363, to_date('19-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130911015040, to_date('11-09-2013', 'dd-mm-yyyy'), to_date('25-09-2013', 'dd-mm-yyyy'), 2, 7830, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010304015041, to_date('04-03-2001', 'dd-mm-yyyy'), to_date('18-03-2001', 'dd-mm-yyyy'), 4, 2156, to_date('09-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000412015042, to_date('12-04-2000', 'dd-mm-yyyy'), to_date('26-04-2000', 'dd-mm-yyyy'), 3, 3448, to_date('16-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040904015043, to_date('04-09-2004', 'dd-mm-yyyy'), to_date('18-09-2004', 'dd-mm-yyyy'), 3, 4489, to_date('06-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110809015044, to_date('09-08-2011', 'dd-mm-yyyy'), to_date('23-08-2011', 'dd-mm-yyyy'), 2, 6995, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050625015045, to_date('25-06-2005', 'dd-mm-yyyy'), to_date('09-07-2005', 'dd-mm-yyyy'), 3, 3664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020310015046, to_date('10-03-2002', 'dd-mm-yyyy'), to_date('24-03-2002', 'dd-mm-yyyy'), 2, 3577, to_date('26-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430015047, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 4, 5145, to_date('13-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080220015048, to_date('20-02-2008', 'dd-mm-yyyy'), to_date('05-03-2008', 'dd-mm-yyyy'), 4, 5091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110330015049, to_date('30-03-2011', 'dd-mm-yyyy'), to_date('13-04-2011', 'dd-mm-yyyy'), 4, 5695, to_date('12-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030324015050, to_date('24-03-2003', 'dd-mm-yyyy'), to_date('07-04-2003', 'dd-mm-yyyy'), 3, 2440, to_date('11-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130329015051, to_date('29-03-2013', 'dd-mm-yyyy'), to_date('12-04-2013', 'dd-mm-yyyy'), 2, 9859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629017580, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 2, 3519, to_date('09-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212017581, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 2, 2481, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919017582, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 2, 4946, to_date('24-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091124017583, to_date('24-11-2009', 'dd-mm-yyyy'), to_date('08-12-2009', 'dd-mm-yyyy'), 1, 5230, to_date('02-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070514017584, to_date('14-05-2007', 'dd-mm-yyyy'), to_date('28-05-2007', 'dd-mm-yyyy'), 2, 5602, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021121017585, to_date('21-11-2002', 'dd-mm-yyyy'), to_date('05-12-2002', 'dd-mm-yyyy'), 2, 3241, to_date('30-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071226017586, to_date('26-12-2007', 'dd-mm-yyyy'), to_date('09-01-2008', 'dd-mm-yyyy'), 1, 5956, to_date('30-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041221017587, to_date('21-12-2004', 'dd-mm-yyyy'), to_date('04-01-2005', 'dd-mm-yyyy'), 1, 4336, to_date('09-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070909017588, to_date('09-09-2007', 'dd-mm-yyyy'), to_date('23-09-2007', 'dd-mm-yyyy'), 1, 6281, to_date('26-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070501017589, to_date('01-05-2007', 'dd-mm-yyyy'), to_date('15-05-2007', 'dd-mm-yyyy'), 2, 5377, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041107017590, to_date('07-11-2004', 'dd-mm-yyyy'), to_date('21-11-2004', 'dd-mm-yyyy'), 1, 4009, to_date('18-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022017591, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 2, 8346, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070129017592, to_date('29-01-2007', 'dd-mm-yyyy'), to_date('12-02-2007', 'dd-mm-yyyy'), 2, 5518, to_date('08-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104017593, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 2, 7301, to_date('16-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100223017594, to_date('23-02-2010', 'dd-mm-yyyy'), to_date('09-03-2010', 'dd-mm-yyyy'), 2, 7814, to_date('06-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225017595, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 2, 2979, to_date('02-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131028017596, to_date('28-10-2013', 'dd-mm-yyyy'), to_date('11-11-2013', 'dd-mm-yyyy'), 2, 8503, to_date('08-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051231017597, to_date('31-12-2005', 'dd-mm-yyyy'), to_date('14-01-2006', 'dd-mm-yyyy'), 1, 4054, to_date('10-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322017598, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 1, 3330, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223017599, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 2, 8694, to_date('08-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020304017600, to_date('04-03-2002', 'dd-mm-yyyy'), to_date('18-03-2002', 'dd-mm-yyyy'), 2, 528, to_date('11-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050614017601, to_date('14-06-2005', 'dd-mm-yyyy'), to_date('28-06-2005', 'dd-mm-yyyy'), 1, 2517, to_date('26-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808017602, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 1, 1352, to_date('11-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609017603, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 2, 2049, to_date('14-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130503017604, to_date('03-05-2013', 'dd-mm-yyyy'), to_date('17-05-2013', 'dd-mm-yyyy'), 2, 7297, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011214017605, to_date('14-12-2001', 'dd-mm-yyyy'), to_date('28-12-2001', 'dd-mm-yyyy'), 2, 1419, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000701017606, to_date('01-07-2000', 'dd-mm-yyyy'), to_date('15-07-2000', 'dd-mm-yyyy'), 2, 983, to_date('03-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050522017607, to_date('22-05-2005', 'dd-mm-yyyy'), to_date('05-06-2005', 'dd-mm-yyyy'), 1, 3858, to_date('05-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040420017608, to_date('20-04-2004', 'dd-mm-yyyy'), to_date('04-05-2004', 'dd-mm-yyyy'), 1, 2746, to_date('23-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071116017609, to_date('16-11-2007', 'dd-mm-yyyy'), to_date('30-11-2007', 'dd-mm-yyyy'), 2, 4586, to_date('02-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041009017610, to_date('09-10-2004', 'dd-mm-yyyy'), to_date('23-10-2004', 'dd-mm-yyyy'), 1, 4945, to_date('15-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130316017611, to_date('16-03-2013', 'dd-mm-yyyy'), to_date('30-03-2013', 'dd-mm-yyyy'), 2, 7300, to_date('25-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417017612, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 2, 5582, to_date('02-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000204017613, to_date('04-02-2000', 'dd-mm-yyyy'), to_date('18-02-2000', 'dd-mm-yyyy'), 2, 2100, to_date('23-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000408017614, to_date('08-04-2000', 'dd-mm-yyyy'), to_date('22-04-2000', 'dd-mm-yyyy'), 1, 534, to_date('10-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504017615, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 1, 2829, to_date('14-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723017616, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 1, 2150, to_date('04-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040110017617, to_date('10-01-2004', 'dd-mm-yyyy'), to_date('24-01-2004', 'dd-mm-yyyy'), 2, 4368, to_date('20-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080213017618, to_date('13-02-2008', 'dd-mm-yyyy'), to_date('27-02-2008', 'dd-mm-yyyy'), 2, 5118, to_date('02-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090326017619, to_date('26-03-2009', 'dd-mm-yyyy'), to_date('09-04-2009', 'dd-mm-yyyy'), 1, 7105, to_date('28-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071221017620, to_date('21-12-2007', 'dd-mm-yyyy'), to_date('04-01-2008', 'dd-mm-yyyy'), 1, 5438, to_date('27-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040915017621, to_date('15-09-2004', 'dd-mm-yyyy'), to_date('29-09-2004', 'dd-mm-yyyy'), 2, 1986, to_date('01-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100529017622, to_date('29-05-2010', 'dd-mm-yyyy'), to_date('12-06-2010', 'dd-mm-yyyy'), 1, 6807, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101111017623, to_date('11-11-2010', 'dd-mm-yyyy'), to_date('25-11-2010', 'dd-mm-yyyy'), 1, 6378, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050418017624, to_date('18-04-2005', 'dd-mm-yyyy'), to_date('02-05-2005', 'dd-mm-yyyy'), 1, 3682, to_date('30-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120229017625, to_date('29-02-2012', 'dd-mm-yyyy'), to_date('14-03-2012', 'dd-mm-yyyy'), 1, 8792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020320017626, to_date('20-03-2002', 'dd-mm-yyyy'), to_date('03-04-2002', 'dd-mm-yyyy'), 1, 3818, to_date('03-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050130017627, to_date('30-01-2005', 'dd-mm-yyyy'), to_date('13-02-2005', 'dd-mm-yyyy'), 1, 2441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140124017628, to_date('24-01-2014', 'dd-mm-yyyy'), to_date('07-02-2014', 'dd-mm-yyyy'), 1, 8395, to_date('29-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120627017629, to_date('27-06-2012', 'dd-mm-yyyy'), to_date('11-07-2012', 'dd-mm-yyyy'), 1, 6102, to_date('03-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030521017630, to_date('21-05-2003', 'dd-mm-yyyy'), to_date('04-06-2003', 'dd-mm-yyyy'), 1, 3449, to_date('31-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111012017631, to_date('12-10-2011', 'dd-mm-yyyy'), to_date('26-10-2011', 'dd-mm-yyyy'), 1, 8066, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090630017632, to_date('30-06-2009', 'dd-mm-yyyy'), to_date('14-07-2009', 'dd-mm-yyyy'), 1, 7561, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050111017633, to_date('11-01-2005', 'dd-mm-yyyy'), to_date('25-01-2005', 'dd-mm-yyyy'), 2, 4306, to_date('31-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031006017634, to_date('06-10-2003', 'dd-mm-yyyy'), to_date('20-10-2003', 'dd-mm-yyyy'), 1, 4711, to_date('19-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130406017635, to_date('06-04-2013', 'dd-mm-yyyy'), to_date('20-04-2013', 'dd-mm-yyyy'), 2, 9916, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826017636, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 2, 7005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090428017637, to_date('28-04-2009', 'dd-mm-yyyy'), to_date('12-05-2009', 'dd-mm-yyyy'), 1, 7081, to_date('13-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120109017638, to_date('09-01-2012', 'dd-mm-yyyy'), to_date('23-01-2012', 'dd-mm-yyyy'), 1, 9124, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031011017639, to_date('11-10-2003', 'dd-mm-yyyy'), to_date('25-10-2003', 'dd-mm-yyyy'), 2, 4694, to_date('20-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140201017640, to_date('01-02-2014', 'dd-mm-yyyy'), to_date('15-02-2014', 'dd-mm-yyyy'), 2, 10806, to_date('04-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227017641, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 2, 3171, to_date('14-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080702017642, to_date('02-07-2008', 'dd-mm-yyyy'), to_date('16-07-2008', 'dd-mm-yyyy'), 1, 5956, to_date('16-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131019017643, to_date('19-10-2013', 'dd-mm-yyyy'), to_date('02-11-2013', 'dd-mm-yyyy'), 2, 6872, to_date('06-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110603017644, to_date('03-06-2011', 'dd-mm-yyyy'), to_date('17-06-2011', 'dd-mm-yyyy'), 2, 8425, to_date('17-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020930017645, to_date('30-09-2002', 'dd-mm-yyyy'), to_date('14-10-2002', 'dd-mm-yyyy'), 1, 4202, to_date('13-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021129017646, to_date('29-11-2002', 'dd-mm-yyyy'), to_date('13-12-2002', 'dd-mm-yyyy'), 1, 5840, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020114017647, to_date('14-01-2002', 'dd-mm-yyyy'), to_date('28-01-2002', 'dd-mm-yyyy'), 2, 2686, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010410017648, to_date('10-04-2001', 'dd-mm-yyyy'), to_date('24-04-2001', 'dd-mm-yyyy'), 1, 2024, to_date('16-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531017649, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 2, 1662, to_date('13-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060714017650, to_date('14-07-2006', 'dd-mm-yyyy'), to_date('28-07-2006', 'dd-mm-yyyy'), 2, 5041, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040707017651, to_date('07-07-2004', 'dd-mm-yyyy'), to_date('21-07-2004', 'dd-mm-yyyy'), 2, 3511, to_date('17-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070125017652, to_date('25-01-2007', 'dd-mm-yyyy'), to_date('08-02-2007', 'dd-mm-yyyy'), 1, 4986, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050206017653, to_date('06-02-2005', 'dd-mm-yyyy'), to_date('20-02-2005', 'dd-mm-yyyy'), 1, 3207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100702017654, to_date('02-07-2010', 'dd-mm-yyyy'), to_date('16-07-2010', 'dd-mm-yyyy'), 2, 6143, to_date('14-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040227017655, to_date('27-02-2004', 'dd-mm-yyyy'), to_date('12-03-2004', 'dd-mm-yyyy'), 1, 4478, to_date('14-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070927017656, to_date('27-09-2007', 'dd-mm-yyyy'), to_date('11-10-2007', 'dd-mm-yyyy'), 1, 3425, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130904017657, to_date('04-09-2013', 'dd-mm-yyyy'), to_date('18-09-2013', 'dd-mm-yyyy'), 2, 9958, to_date('18-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000614017658, to_date('14-06-2000', 'dd-mm-yyyy'), to_date('28-06-2000', 'dd-mm-yyyy'), 2, 1343, to_date('16-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130302017659, to_date('02-03-2013', 'dd-mm-yyyy'), to_date('16-03-2013', 'dd-mm-yyyy'), 1, 8439, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808017660, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 2, 2855, to_date('20-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051025017661, to_date('25-10-2005', 'dd-mm-yyyy'), to_date('08-11-2005', 'dd-mm-yyyy'), 1, 3872, to_date('06-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011125017662, to_date('25-11-2001', 'dd-mm-yyyy'), to_date('09-12-2001', 'dd-mm-yyyy'), 1, 2399, to_date('05-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623017663, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 2, 3473, to_date('30-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120123017664, to_date('23-01-2012', 'dd-mm-yyyy'), to_date('06-02-2012', 'dd-mm-yyyy'), 2, 6190, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051205017665, to_date('05-12-2005', 'dd-mm-yyyy'), to_date('19-12-2005', 'dd-mm-yyyy'), 1, 5517, to_date('20-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070904017666, to_date('04-09-2007', 'dd-mm-yyyy'), to_date('18-09-2007', 'dd-mm-yyyy'), 2, 4136, to_date('23-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080626017667, to_date('26-06-2008', 'dd-mm-yyyy'), to_date('10-07-2008', 'dd-mm-yyyy'), 2, 7609, to_date('12-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000714017668, to_date('14-07-2000', 'dd-mm-yyyy'), to_date('28-07-2000', 'dd-mm-yyyy'), 1, 1485, to_date('16-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130110017669, to_date('10-01-2013', 'dd-mm-yyyy'), to_date('24-01-2013', 'dd-mm-yyyy'), 1, 9177, to_date('29-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010928017670, to_date('28-09-2001', 'dd-mm-yyyy'), to_date('12-10-2001', 'dd-mm-yyyy'), 2, 3503, to_date('09-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111117017671, to_date('17-11-2011', 'dd-mm-yyyy'), to_date('01-12-2011', 'dd-mm-yyyy'), 1, 6576, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130519017672, to_date('19-05-2013', 'dd-mm-yyyy'), to_date('02-06-2013', 'dd-mm-yyyy'), 1, 10039, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101223017673, to_date('23-12-2010', 'dd-mm-yyyy'), to_date('06-01-2011', 'dd-mm-yyyy'), 2, 8926, to_date('06-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030427017674, to_date('27-04-2003', 'dd-mm-yyyy'), to_date('11-05-2003', 'dd-mm-yyyy'), 2, 4906, to_date('12-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111025017675, to_date('25-10-2011', 'dd-mm-yyyy'), to_date('08-11-2011', 'dd-mm-yyyy'), 1, 9196, to_date('11-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020408017676, to_date('08-04-2002', 'dd-mm-yyyy'), to_date('22-04-2002', 'dd-mm-yyyy'), 1, 3207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090827017677, to_date('27-08-2009', 'dd-mm-yyyy'), to_date('10-09-2009', 'dd-mm-yyyy'), 1, 6475, to_date('10-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031106017678, to_date('06-11-2003', 'dd-mm-yyyy'), to_date('20-11-2003', 'dd-mm-yyyy'), 1, 4445, to_date('15-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010727017679, to_date('27-07-2001', 'dd-mm-yyyy'), to_date('10-08-2001', 'dd-mm-yyyy'), 2, 4661, to_date('08-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010313017680, to_date('13-03-2001', 'dd-mm-yyyy'), to_date('27-03-2001', 'dd-mm-yyyy'), 2, 1822, to_date('29-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131106017681, to_date('06-11-2013', 'dd-mm-yyyy'), to_date('20-11-2013', 'dd-mm-yyyy'), 1, 10376, to_date('22-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130428017682, to_date('28-04-2013', 'dd-mm-yyyy'), to_date('12-05-2013', 'dd-mm-yyyy'), 1, 8860, to_date('06-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060912017683, to_date('12-09-2006', 'dd-mm-yyyy'), to_date('26-09-2006', 'dd-mm-yyyy'), 2, 3762, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000519017684, to_date('19-05-2000', 'dd-mm-yyyy'), to_date('02-06-2000', 'dd-mm-yyyy'), 1, 2324, to_date('07-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019017685, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 2, 4018, to_date('07-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030814017686, to_date('14-08-2003', 'dd-mm-yyyy'), to_date('28-08-2003', 'dd-mm-yyyy'), 1, 2659, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061124017687, to_date('24-11-2006', 'dd-mm-yyyy'), to_date('08-12-2006', 'dd-mm-yyyy'), 1, 6863, to_date('06-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030821017688, to_date('21-08-2003', 'dd-mm-yyyy'), to_date('04-09-2003', 'dd-mm-yyyy'), 1, 5247, to_date('22-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051213017689, to_date('13-12-2005', 'dd-mm-yyyy'), to_date('27-12-2005', 'dd-mm-yyyy'), 2, 3612, to_date('20-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100831017690, to_date('31-08-2010', 'dd-mm-yyyy'), to_date('14-09-2010', 'dd-mm-yyyy'), 2, 6012, to_date('05-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070827017691, to_date('27-08-2007', 'dd-mm-yyyy'), to_date('10-09-2007', 'dd-mm-yyyy'), 1, 4744, to_date('30-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010609017692, to_date('09-06-2001', 'dd-mm-yyyy'), to_date('23-06-2001', 'dd-mm-yyyy'), 2, 2908, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030627017693, to_date('27-06-2003', 'dd-mm-yyyy'), to_date('11-07-2003', 'dd-mm-yyyy'), 2, 3012, to_date('05-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130410017694, to_date('10-04-2013', 'dd-mm-yyyy'), to_date('24-04-2013', 'dd-mm-yyyy'), 2, 11992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030406017695, to_date('06-04-2003', 'dd-mm-yyyy'), to_date('20-04-2003', 'dd-mm-yyyy'), 1, 3839, to_date('25-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060429017696, to_date('29-04-2006', 'dd-mm-yyyy'), to_date('13-05-2006', 'dd-mm-yyyy'), 2, 2269, to_date('17-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081005017697, to_date('05-10-2008', 'dd-mm-yyyy'), to_date('19-10-2008', 'dd-mm-yyyy'), 2, 4627, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010610017698, to_date('10-06-2001', 'dd-mm-yyyy'), to_date('24-06-2001', 'dd-mm-yyyy'), 2, 2784, to_date('21-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111017699, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 1, 1558, to_date('17-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051128017700, to_date('28-11-2005', 'dd-mm-yyyy'), to_date('12-12-2005', 'dd-mm-yyyy'), 2, 3879, to_date('07-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040505017701, to_date('05-05-2004', 'dd-mm-yyyy'), to_date('19-05-2004', 'dd-mm-yyyy'), 1, 6158, to_date('12-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140326017702, to_date('26-03-2014', 'dd-mm-yyyy'), to_date('09-04-2014', 'dd-mm-yyyy'), 2, 11307, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050221017703, to_date('21-02-2005', 'dd-mm-yyyy'), to_date('07-03-2005', 'dd-mm-yyyy'), 1, 2703, to_date('28-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060527017704, to_date('27-05-2006', 'dd-mm-yyyy'), to_date('10-06-2006', 'dd-mm-yyyy'), 2, 6176, to_date('05-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120518017705, to_date('18-05-2012', 'dd-mm-yyyy'), to_date('01-06-2012', 'dd-mm-yyyy'), 1, 10102, to_date('29-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120502017706, to_date('02-05-2012', 'dd-mm-yyyy'), to_date('16-05-2012', 'dd-mm-yyyy'), 1, 8951, to_date('14-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120615017707, to_date('15-06-2012', 'dd-mm-yyyy'), to_date('29-06-2012', 'dd-mm-yyyy'), 1, 11543, to_date('17-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624017708, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 1, 8818, to_date('02-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051023017709, to_date('23-10-2005', 'dd-mm-yyyy'), to_date('06-11-2005', 'dd-mm-yyyy'), 1, 3079, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060117017710, to_date('17-01-2006', 'dd-mm-yyyy'), to_date('31-01-2006', 'dd-mm-yyyy'), 1, 6987, to_date('04-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040224017711, to_date('24-02-2004', 'dd-mm-yyyy'), to_date('09-03-2004', 'dd-mm-yyyy'), 2, 2607, to_date('02-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100606017712, to_date('06-06-2010', 'dd-mm-yyyy'), to_date('20-06-2010', 'dd-mm-yyyy'), 1, 6298, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423017713, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 2, 7437, to_date('02-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051104017714, to_date('04-11-2005', 'dd-mm-yyyy'), to_date('18-11-2005', 'dd-mm-yyyy'), 2, 6074, to_date('20-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050831017715, to_date('31-08-2005', 'dd-mm-yyyy'), to_date('14-09-2005', 'dd-mm-yyyy'), 1, 3239, to_date('05-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031027017716, to_date('27-10-2003', 'dd-mm-yyyy'), to_date('10-11-2003', 'dd-mm-yyyy'), 2, 3177, to_date('10-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130124017717, to_date('24-01-2013', 'dd-mm-yyyy'), to_date('07-02-2013', 'dd-mm-yyyy'), 1, 7924, to_date('27-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020806017718, to_date('06-08-2002', 'dd-mm-yyyy'), to_date('20-08-2002', 'dd-mm-yyyy'), 1, 2134, to_date('09-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120505017719, to_date('05-05-2012', 'dd-mm-yyyy'), to_date('19-05-2012', 'dd-mm-yyyy'), 1, 6140, to_date('11-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000118017720, to_date('18-01-2000', 'dd-mm-yyyy'), to_date('01-02-2000', 'dd-mm-yyyy'), 1, 2325, to_date('22-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071202017721, to_date('02-12-2007', 'dd-mm-yyyy'), to_date('16-12-2007', 'dd-mm-yyyy'), 2, 5158, to_date('10-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011128017722, to_date('28-11-2001', 'dd-mm-yyyy'), to_date('12-12-2001', 'dd-mm-yyyy'), 2, 2132, to_date('16-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050410017723, to_date('10-04-2005', 'dd-mm-yyyy'), to_date('24-04-2005', 'dd-mm-yyyy'), 1, 3868, to_date('11-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090421017724, to_date('21-04-2009', 'dd-mm-yyyy'), to_date('05-05-2009', 'dd-mm-yyyy'), 2, 5815, to_date('09-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051211017725, to_date('11-12-2005', 'dd-mm-yyyy'), to_date('25-12-2005', 'dd-mm-yyyy'), 1, 5438, to_date('27-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030706017726, to_date('06-07-2003', 'dd-mm-yyyy'), to_date('20-07-2003', 'dd-mm-yyyy'), 1, 2998, to_date('15-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041202017727, to_date('02-12-2004', 'dd-mm-yyyy'), to_date('16-12-2004', 'dd-mm-yyyy'), 1, 4487, to_date('15-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070302017728, to_date('02-03-2007', 'dd-mm-yyyy'), to_date('16-03-2007', 'dd-mm-yyyy'), 2, 6776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140301017729, to_date('01-03-2014', 'dd-mm-yyyy'), to_date('15-03-2014', 'dd-mm-yyyy'), 2, 10651, to_date('18-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120422017730, to_date('22-04-2012', 'dd-mm-yyyy'), to_date('06-05-2012', 'dd-mm-yyyy'), 2, 8316, to_date('01-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030321017731, to_date('21-03-2003', 'dd-mm-yyyy'), to_date('04-04-2003', 'dd-mm-yyyy'), 2, 2554, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120425017732, to_date('25-04-2012', 'dd-mm-yyyy'), to_date('09-05-2012', 'dd-mm-yyyy'), 2, 8874, to_date('11-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050223017733, to_date('23-02-2005', 'dd-mm-yyyy'), to_date('09-03-2005', 'dd-mm-yyyy'), 2, 3521, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423017734, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 1, 8235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030217017735, to_date('17-02-2003', 'dd-mm-yyyy'), to_date('03-03-2003', 'dd-mm-yyyy'), 1, 3292, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140226017736, to_date('26-02-2014', 'dd-mm-yyyy'), to_date('12-03-2014', 'dd-mm-yyyy'), 2, 9397, to_date('02-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020316017737, to_date('16-03-2002', 'dd-mm-yyyy'), to_date('30-03-2002', 'dd-mm-yyyy'), 2, 2298, to_date('01-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020214017738, to_date('14-02-2002', 'dd-mm-yyyy'), to_date('28-02-2002', 'dd-mm-yyyy'), 2, 2117, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040812017739, to_date('12-08-2004', 'dd-mm-yyyy'), to_date('26-08-2004', 'dd-mm-yyyy'), 1, 3792, to_date('27-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041219017740, to_date('19-12-2004', 'dd-mm-yyyy'), to_date('02-01-2005', 'dd-mm-yyyy'), 1, 4834, to_date('28-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010901017741, to_date('01-09-2001', 'dd-mm-yyyy'), to_date('15-09-2001', 'dd-mm-yyyy'), 2, 2034, to_date('18-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040303017742, to_date('03-03-2004', 'dd-mm-yyyy'), to_date('17-03-2004', 'dd-mm-yyyy'), 1, 2740, to_date('19-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080301017743, to_date('01-03-2008', 'dd-mm-yyyy'), to_date('15-03-2008', 'dd-mm-yyyy'), 2, 4781, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131108017744, to_date('08-11-2013', 'dd-mm-yyyy'), to_date('22-11-2013', 'dd-mm-yyyy'), 1, 8846, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130718017745, to_date('18-07-2013', 'dd-mm-yyyy'), to_date('01-08-2013', 'dd-mm-yyyy'), 1, 7984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030421017746, to_date('21-04-2003', 'dd-mm-yyyy'), to_date('05-05-2003', 'dd-mm-yyyy'), 1, 1868, to_date('27-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101204017747, to_date('04-12-2010', 'dd-mm-yyyy'), to_date('18-12-2010', 'dd-mm-yyyy'), 2, 7908, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040825017748, to_date('25-08-2004', 'dd-mm-yyyy'), to_date('08-09-2004', 'dd-mm-yyyy'), 2, 5664, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120223009639, to_date('23-02-2012', 'dd-mm-yyyy'), to_date('08-03-2012', 'dd-mm-yyyy'), 7, 7015, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140301009640, to_date('01-03-2014', 'dd-mm-yyyy'), to_date('15-03-2014', 'dd-mm-yyyy'), 12, 11053, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110215009641, to_date('15-02-2011', 'dd-mm-yyyy'), to_date('01-03-2011', 'dd-mm-yyyy'), 9, 6223, to_date('16-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010414009642, to_date('14-04-2001', 'dd-mm-yyyy'), to_date('28-04-2001', 'dd-mm-yyyy'), 1, 2557, to_date('15-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819009643, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 1, 6423, to_date('07-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021003009644, to_date('03-10-2002', 'dd-mm-yyyy'), to_date('17-10-2002', 'dd-mm-yyyy'), 11, 2790, to_date('07-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091020009645, to_date('20-10-2009', 'dd-mm-yyyy'), to_date('03-11-2009', 'dd-mm-yyyy'), 10, 9024, to_date('05-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060502009646, to_date('02-05-2006', 'dd-mm-yyyy'), to_date('16-05-2006', 'dd-mm-yyyy'), 3, 5376, to_date('22-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000422009647, to_date('22-04-2000', 'dd-mm-yyyy'), to_date('06-05-2000', 'dd-mm-yyyy'), 2, 612, to_date('05-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041030009648, to_date('30-10-2004', 'dd-mm-yyyy'), to_date('13-11-2004', 'dd-mm-yyyy'), 11, 4741, to_date('17-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050927009649, to_date('27-09-2005', 'dd-mm-yyyy'), to_date('11-10-2005', 'dd-mm-yyyy'), 2, 7429, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140325009650, to_date('25-03-2014', 'dd-mm-yyyy'), to_date('08-04-2014', 'dd-mm-yyyy'), 10, 9523, to_date('10-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050825009651, to_date('25-08-2005', 'dd-mm-yyyy'), to_date('08-09-2005', 'dd-mm-yyyy'), 12, 3730, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051102009652, to_date('02-11-2005', 'dd-mm-yyyy'), to_date('16-11-2005', 'dd-mm-yyyy'), 12, 3727, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091021009653, to_date('21-10-2009', 'dd-mm-yyyy'), to_date('04-11-2009', 'dd-mm-yyyy'), 7, 7685, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000928009654, to_date('28-09-2000', 'dd-mm-yyyy'), to_date('12-10-2000', 'dd-mm-yyyy'), 9, 633, to_date('07-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021202009655, to_date('02-12-2002', 'dd-mm-yyyy'), to_date('16-12-2002', 'dd-mm-yyyy'), 6, 3609, to_date('04-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130605009656, to_date('05-06-2013', 'dd-mm-yyyy'), to_date('19-06-2013', 'dd-mm-yyyy'), 7, 8894, to_date('15-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040331009657, to_date('31-03-2004', 'dd-mm-yyyy'), to_date('14-04-2004', 'dd-mm-yyyy'), 3, 4189, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110705009658, to_date('05-07-2011', 'dd-mm-yyyy'), to_date('19-07-2011', 'dd-mm-yyyy'), 2, 5818, to_date('22-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080628009659, to_date('28-06-2008', 'dd-mm-yyyy'), to_date('12-07-2008', 'dd-mm-yyyy'), 5, 7352, to_date('11-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090416009660, to_date('16-04-2009', 'dd-mm-yyyy'), to_date('30-04-2009', 'dd-mm-yyyy'), 12, 4507, to_date('23-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130827009661, to_date('27-08-2013', 'dd-mm-yyyy'), to_date('10-09-2013', 'dd-mm-yyyy'), 4, 8395, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090422009662, to_date('22-04-2009', 'dd-mm-yyyy'), to_date('06-05-2009', 'dd-mm-yyyy'), 9, 5128, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209009663, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 2, 4007, to_date('29-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070906009664, to_date('06-09-2007', 'dd-mm-yyyy'), to_date('20-09-2007', 'dd-mm-yyyy'), 10, 5662, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051024009665, to_date('24-10-2005', 'dd-mm-yyyy'), to_date('07-11-2005', 'dd-mm-yyyy'), 10, 4718, to_date('04-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010826009666, to_date('26-08-2001', 'dd-mm-yyyy'), to_date('09-09-2001', 'dd-mm-yyyy'), 1, 3629, to_date('01-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060706009667, to_date('06-07-2006', 'dd-mm-yyyy'), to_date('20-07-2006', 'dd-mm-yyyy'), 8, 4421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050717009668, to_date('17-07-2005', 'dd-mm-yyyy'), to_date('31-07-2005', 'dd-mm-yyyy'), 12, 4844, to_date('03-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110701009669, to_date('01-07-2011', 'dd-mm-yyyy'), to_date('15-07-2011', 'dd-mm-yyyy'), 6, 7947, to_date('03-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031217009670, to_date('17-12-2003', 'dd-mm-yyyy'), to_date('31-12-2003', 'dd-mm-yyyy'), 10, 2744, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110530009671, to_date('30-05-2011', 'dd-mm-yyyy'), to_date('13-06-2011', 'dd-mm-yyyy'), 1, 5871, to_date('07-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060425009672, to_date('25-04-2006', 'dd-mm-yyyy'), to_date('09-05-2006', 'dd-mm-yyyy'), 8, 3808, to_date('08-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060923009673, to_date('23-09-2006', 'dd-mm-yyyy'), to_date('07-10-2006', 'dd-mm-yyyy'), 10, 5005, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051218009674, to_date('18-12-2005', 'dd-mm-yyyy'), to_date('01-01-2006', 'dd-mm-yyyy'), 9, 5873, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060123009675, to_date('23-01-2006', 'dd-mm-yyyy'), to_date('06-02-2006', 'dd-mm-yyyy'), 5, 5288, to_date('11-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121212009676, to_date('12-12-2012', 'dd-mm-yyyy'), to_date('26-12-2012', 'dd-mm-yyyy'), 6, 6701, to_date('24-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426009677, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 5, 1306, to_date('10-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120512009678, to_date('12-05-2012', 'dd-mm-yyyy'), to_date('26-05-2012', 'dd-mm-yyyy'), 3, 10244, to_date('29-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140113009679, to_date('13-01-2014', 'dd-mm-yyyy'), to_date('27-01-2014', 'dd-mm-yyyy'), 1, 8728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060329009680, to_date('29-03-2006', 'dd-mm-yyyy'), to_date('12-04-2006', 'dd-mm-yyyy'), 2, 4913, to_date('14-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416009681, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 12, 2951, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100210009682, to_date('10-02-2010', 'dd-mm-yyyy'), to_date('24-02-2010', 'dd-mm-yyyy'), 4, 6288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060323009683, to_date('23-03-2006', 'dd-mm-yyyy'), to_date('06-04-2006', 'dd-mm-yyyy'), 11, 5500, to_date('02-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130331009684, to_date('31-03-2013', 'dd-mm-yyyy'), to_date('14-04-2013', 'dd-mm-yyyy'), 10, 10481, to_date('11-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110812009685, to_date('12-08-2011', 'dd-mm-yyyy'), to_date('26-08-2011', 'dd-mm-yyyy'), 8, 8970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050102009686, to_date('02-01-2005', 'dd-mm-yyyy'), to_date('16-01-2005', 'dd-mm-yyyy'), 6, 6470, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040814009687, to_date('14-08-2004', 'dd-mm-yyyy'), to_date('28-08-2004', 'dd-mm-yyyy'), 7, 3182, to_date('27-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000426009688, to_date('26-04-2000', 'dd-mm-yyyy'), to_date('10-05-2000', 'dd-mm-yyyy'), 11, 358, to_date('02-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010708009689, to_date('08-07-2001', 'dd-mm-yyyy'), to_date('22-07-2001', 'dd-mm-yyyy'), 8, 969, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020311009690, to_date('11-03-2002', 'dd-mm-yyyy'), to_date('25-03-2002', 'dd-mm-yyyy'), 6, 3746, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711009691, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 11, 6341, to_date('24-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040928009692, to_date('28-09-2004', 'dd-mm-yyyy'), to_date('12-10-2004', 'dd-mm-yyyy'), 12, 5952, to_date('30-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030223009693, to_date('23-02-2003', 'dd-mm-yyyy'), to_date('09-03-2003', 'dd-mm-yyyy'), 2, 2311, to_date('03-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208009694, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 6, 2488, to_date('16-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110323009695, to_date('23-03-2011', 'dd-mm-yyyy'), to_date('06-04-2011', 'dd-mm-yyyy'), 4, 6008, to_date('24-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071230009696, to_date('30-12-2007', 'dd-mm-yyyy'), to_date('13-01-2008', 'dd-mm-yyyy'), 5, 3376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110409009697, to_date('09-04-2011', 'dd-mm-yyyy'), to_date('23-04-2011', 'dd-mm-yyyy'), 4, 9089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040427009698, to_date('27-04-2004', 'dd-mm-yyyy'), to_date('11-05-2004', 'dd-mm-yyyy'), 7, 4579, to_date('29-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000713009699, to_date('13-07-2000', 'dd-mm-yyyy'), to_date('27-07-2000', 'dd-mm-yyyy'), 7, 1331, to_date('23-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100128009700, to_date('28-01-2010', 'dd-mm-yyyy'), to_date('11-02-2010', 'dd-mm-yyyy'), 7, 11080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081119009701, to_date('19-11-2008', 'dd-mm-yyyy'), to_date('03-12-2008', 'dd-mm-yyyy'), 12, 5785, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628009702, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 9, 3732, to_date('02-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120503009703, to_date('03-05-2012', 'dd-mm-yyyy'), to_date('17-05-2012', 'dd-mm-yyyy'), 6, 9289, to_date('21-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090205009704, to_date('05-02-2009', 'dd-mm-yyyy'), to_date('19-02-2009', 'dd-mm-yyyy'), 11, 6998, to_date('18-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021123009705, to_date('23-11-2002', 'dd-mm-yyyy'), to_date('07-12-2002', 'dd-mm-yyyy'), 11, 1983, to_date('02-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131127009706, to_date('27-11-2013', 'dd-mm-yyyy'), to_date('11-12-2013', 'dd-mm-yyyy'), 4, 6409, to_date('29-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070114009707, to_date('14-01-2007', 'dd-mm-yyyy'), to_date('28-01-2007', 'dd-mm-yyyy'), 10, 5556, to_date('31-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060615009708, to_date('15-06-2006', 'dd-mm-yyyy'), to_date('29-06-2006', 'dd-mm-yyyy'), 5, 4521, to_date('23-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061026009709, to_date('26-10-2006', 'dd-mm-yyyy'), to_date('09-11-2006', 'dd-mm-yyyy'), 4, 6462, to_date('03-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060913009710, to_date('13-09-2006', 'dd-mm-yyyy'), to_date('27-09-2006', 'dd-mm-yyyy'), 2, 5464, to_date('18-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110425009711, to_date('25-04-2011', 'dd-mm-yyyy'), to_date('09-05-2011', 'dd-mm-yyyy'), 10, 8783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030511009712, to_date('11-05-2003', 'dd-mm-yyyy'), to_date('25-05-2003', 'dd-mm-yyyy'), 11, 2949, to_date('23-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091208009713, to_date('08-12-2009', 'dd-mm-yyyy'), to_date('22-12-2009', 'dd-mm-yyyy'), 2, 4875, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050220009714, to_date('20-02-2005', 'dd-mm-yyyy'), to_date('06-03-2005', 'dd-mm-yyyy'), 3, 4760, to_date('26-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120320009715, to_date('20-03-2012', 'dd-mm-yyyy'), to_date('03-04-2012', 'dd-mm-yyyy'), 6, 6990, to_date('05-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040212009716, to_date('12-02-2004', 'dd-mm-yyyy'), to_date('26-02-2004', 'dd-mm-yyyy'), 2, 3354, to_date('15-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090104009717, to_date('04-01-2009', 'dd-mm-yyyy'), to_date('18-01-2009', 'dd-mm-yyyy'), 10, 6001, to_date('19-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070207009718, to_date('07-02-2007', 'dd-mm-yyyy'), to_date('21-02-2007', 'dd-mm-yyyy'), 6, 3801, to_date('19-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050209009719, to_date('09-02-2005', 'dd-mm-yyyy'), to_date('23-02-2005', 'dd-mm-yyyy'), 6, 4732, to_date('27-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010528009720, to_date('28-05-2001', 'dd-mm-yyyy'), to_date('11-06-2001', 'dd-mm-yyyy'), 11, 3353, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111009721, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 4, 7391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050503009722, to_date('03-05-2005', 'dd-mm-yyyy'), to_date('17-05-2005', 'dd-mm-yyyy'), 12, 7147, to_date('21-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080526009723, to_date('26-05-2008', 'dd-mm-yyyy'), to_date('09-06-2008', 'dd-mm-yyyy'), 1, 4684, to_date('28-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070130009724, to_date('30-01-2007', 'dd-mm-yyyy'), to_date('13-02-2007', 'dd-mm-yyyy'), 10, 3806, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100221009725, to_date('21-02-2010', 'dd-mm-yyyy'), to_date('07-03-2010', 'dd-mm-yyyy'), 5, 5194, to_date('01-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021105009726, to_date('05-11-2002', 'dd-mm-yyyy'), to_date('19-11-2002', 'dd-mm-yyyy'), 1, 3153, to_date('09-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011224009727, to_date('24-12-2001', 'dd-mm-yyyy'), to_date('07-01-2002', 'dd-mm-yyyy'), 9, 3381, to_date('11-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030609009728, to_date('09-06-2003', 'dd-mm-yyyy'), to_date('23-06-2003', 'dd-mm-yyyy'), 8, 4970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010306009729, to_date('06-03-2001', 'dd-mm-yyyy'), to_date('20-03-2001', 'dd-mm-yyyy'), 7, 999, to_date('20-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121105009730, to_date('05-11-2012', 'dd-mm-yyyy'), to_date('19-11-2012', 'dd-mm-yyyy'), 5, 6874, to_date('10-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021107009731, to_date('07-11-2002', 'dd-mm-yyyy'), to_date('21-11-2002', 'dd-mm-yyyy'), 11, 3226, to_date('24-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209009732, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 10, 3341, to_date('19-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000421009733, to_date('21-04-2000', 'dd-mm-yyyy'), to_date('05-05-2000', 'dd-mm-yyyy'), 2, 2519, to_date('25-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121004009734, to_date('04-10-2012', 'dd-mm-yyyy'), to_date('18-10-2012', 'dd-mm-yyyy'), 9, 5657, to_date('06-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031214009735, to_date('14-12-2003', 'dd-mm-yyyy'), to_date('28-12-2003', 'dd-mm-yyyy'), 10, 3505, to_date('17-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091028009736, to_date('28-10-2009', 'dd-mm-yyyy'), to_date('11-11-2009', 'dd-mm-yyyy'), 4, 6347, to_date('04-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130816009737, to_date('16-08-2013', 'dd-mm-yyyy'), to_date('30-08-2013', 'dd-mm-yyyy'), 5, 9846, to_date('21-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010907009738, to_date('07-09-2001', 'dd-mm-yyyy'), to_date('21-09-2001', 'dd-mm-yyyy'), 8, 1834, to_date('14-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010108009739, to_date('08-01-2001', 'dd-mm-yyyy'), to_date('22-01-2001', 'dd-mm-yyyy'), 8, 1370, to_date('22-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021212009740, to_date('12-12-2002', 'dd-mm-yyyy'), to_date('26-12-2002', 'dd-mm-yyyy'), 2, 2516, to_date('18-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104009741, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 1, 2565, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131127009742, to_date('27-11-2013', 'dd-mm-yyyy'), to_date('11-12-2013', 'dd-mm-yyyy'), 6, 9451, to_date('07-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050702009743, to_date('02-07-2005', 'dd-mm-yyyy'), to_date('16-07-2005', 'dd-mm-yyyy'), 10, 2898, to_date('21-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090823009744, to_date('23-08-2009', 'dd-mm-yyyy'), to_date('06-09-2009', 'dd-mm-yyyy'), 9, 5695, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120418009745, to_date('18-04-2012', 'dd-mm-yyyy'), to_date('02-05-2012', 'dd-mm-yyyy'), 9, 10019, to_date('07-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004009746, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 6, 5136, to_date('19-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000303009747, to_date('03-03-2000', 'dd-mm-yyyy'), to_date('17-03-2000', 'dd-mm-yyyy'), 8, 570, to_date('12-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100805009748, to_date('05-08-2010', 'dd-mm-yyyy'), to_date('19-08-2010', 'dd-mm-yyyy'), 7, 8011, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060222009749, to_date('22-02-2006', 'dd-mm-yyyy'), to_date('08-03-2006', 'dd-mm-yyyy'), 2, 4926, to_date('02-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081130009750, to_date('30-11-2008', 'dd-mm-yyyy'), to_date('14-12-2008', 'dd-mm-yyyy'), 4, 5070, to_date('18-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101010009751, to_date('10-10-2010', 'dd-mm-yyyy'), to_date('24-10-2010', 'dd-mm-yyyy'), 1, 6737, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060124009752, to_date('24-01-2006', 'dd-mm-yyyy'), to_date('07-02-2006', 'dd-mm-yyyy'), 6, 5806, to_date('11-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110620009753, to_date('20-06-2011', 'dd-mm-yyyy'), to_date('04-07-2011', 'dd-mm-yyyy'), 1, 7311, to_date('08-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000708009754, to_date('08-07-2000', 'dd-mm-yyyy'), to_date('22-07-2000', 'dd-mm-yyyy'), 11, 2408, to_date('23-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131023009755, to_date('23-10-2013', 'dd-mm-yyyy'), to_date('06-11-2013', 'dd-mm-yyyy'), 3, 11199, to_date('25-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060401009756, to_date('01-04-2006', 'dd-mm-yyyy'), to_date('15-04-2006', 'dd-mm-yyyy'), 2, 4841, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131223009757, to_date('23-12-2013', 'dd-mm-yyyy'), to_date('06-01-2014', 'dd-mm-yyyy'), 3, 9963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140127009758, to_date('27-01-2014', 'dd-mm-yyyy'), to_date('10-02-2014', 'dd-mm-yyyy'), 2, 8725, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101005009759, to_date('05-10-2010', 'dd-mm-yyyy'), to_date('19-10-2010', 'dd-mm-yyyy'), 8, 10858, to_date('12-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080103009760, to_date('03-01-2008', 'dd-mm-yyyy'), to_date('17-01-2008', 'dd-mm-yyyy'), 6, 6090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020426009761, to_date('26-04-2002', 'dd-mm-yyyy'), to_date('10-05-2002', 'dd-mm-yyyy'), 1, 2823, to_date('05-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051020009762, to_date('20-10-2005', 'dd-mm-yyyy'), to_date('03-11-2005', 'dd-mm-yyyy'), 8, 4954, to_date('25-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081103009763, to_date('03-11-2008', 'dd-mm-yyyy'), to_date('17-11-2008', 'dd-mm-yyyy'), 5, 4915, to_date('16-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100312009764, to_date('12-03-2010', 'dd-mm-yyyy'), to_date('26-03-2010', 'dd-mm-yyyy'), 6, 6850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030702009765, to_date('02-07-2003', 'dd-mm-yyyy'), to_date('16-07-2003', 'dd-mm-yyyy'), 7, 3764, to_date('13-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050202009766, to_date('02-02-2005', 'dd-mm-yyyy'), to_date('16-02-2005', 'dd-mm-yyyy'), 4, 4333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805009767, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 11, 3815, to_date('14-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000520009768, to_date('20-05-2000', 'dd-mm-yyyy'), to_date('03-06-2000', 'dd-mm-yyyy'), 5, 2214, to_date('26-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060201009769, to_date('01-02-2006', 'dd-mm-yyyy'), to_date('15-02-2006', 'dd-mm-yyyy'), 10, 6970, to_date('19-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061228009770, to_date('28-12-2006', 'dd-mm-yyyy'), to_date('11-01-2007', 'dd-mm-yyyy'), 3, 4850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020715009771, to_date('15-07-2002', 'dd-mm-yyyy'), to_date('29-07-2002', 'dd-mm-yyyy'), 2, 1084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090110009772, to_date('10-01-2009', 'dd-mm-yyyy'), to_date('24-01-2009', 'dd-mm-yyyy'), 4, 5094, to_date('11-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090225009773, to_date('25-02-2009', 'dd-mm-yyyy'), to_date('11-03-2009', 'dd-mm-yyyy'), 11, 6905, to_date('01-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531009774, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 3, 3345, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101020009775, to_date('20-10-2010', 'dd-mm-yyyy'), to_date('03-11-2010', 'dd-mm-yyyy'), 2, 8094, to_date('04-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000609009776, to_date('09-06-2000', 'dd-mm-yyyy'), to_date('23-06-2000', 'dd-mm-yyyy'), 2, 663, to_date('29-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121208009777, to_date('08-12-2012', 'dd-mm-yyyy'), to_date('22-12-2012', 'dd-mm-yyyy'), 6, 8600, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090616009778, to_date('16-06-2009', 'dd-mm-yyyy'), to_date('30-06-2009', 'dd-mm-yyyy'), 12, 8176, to_date('03-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121018009779, to_date('18-10-2012', 'dd-mm-yyyy'), to_date('01-11-2012', 'dd-mm-yyyy'), 2, 9352, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715009780, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 8, 2403, to_date('29-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001218009781, to_date('18-12-2000', 'dd-mm-yyyy'), to_date('01-01-2001', 'dd-mm-yyyy'), 10, 1376, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030310009782, to_date('10-03-2003', 'dd-mm-yyyy'), to_date('24-03-2003', 'dd-mm-yyyy'), 10, 2770, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101218009783, to_date('18-12-2010', 'dd-mm-yyyy'), to_date('01-01-2011', 'dd-mm-yyyy'), 3, 6173, to_date('24-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090123009784, to_date('23-01-2009', 'dd-mm-yyyy'), to_date('06-02-2009', 'dd-mm-yyyy'), 2, 6335, to_date('25-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041231009785, to_date('31-12-2004', 'dd-mm-yyyy'), to_date('14-01-2005', 'dd-mm-yyyy'), 8, 3853, to_date('10-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060607009786, to_date('07-06-2006', 'dd-mm-yyyy'), to_date('21-06-2006', 'dd-mm-yyyy'), 6, 5130, to_date('10-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071017009787, to_date('17-10-2007', 'dd-mm-yyyy'), to_date('31-10-2007', 'dd-mm-yyyy'), 9, 5363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111013009788, to_date('13-10-2011', 'dd-mm-yyyy'), to_date('27-10-2011', 'dd-mm-yyyy'), 9, 6368, to_date('19-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080304009789, to_date('04-03-2008', 'dd-mm-yyyy'), to_date('18-03-2008', 'dd-mm-yyyy'), 9, 4136, to_date('05-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010318009790, to_date('18-03-2001', 'dd-mm-yyyy'), to_date('01-04-2001', 'dd-mm-yyyy'), 10, 2061, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100716009791, to_date('16-07-2010', 'dd-mm-yyyy'), to_date('30-07-2010', 'dd-mm-yyyy'), 3, 6949, to_date('27-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140430009792, to_date('30-04-2014', 'dd-mm-yyyy'), to_date('14-05-2014', 'dd-mm-yyyy'), 4, 11915, to_date('17-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121220009793, to_date('20-12-2012', 'dd-mm-yyyy'), to_date('03-01-2013', 'dd-mm-yyyy'), 10, 10956, to_date('29-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021025012187, to_date('25-10-2002', 'dd-mm-yyyy'), to_date('08-11-2002', 'dd-mm-yyyy'), 2, 2706, to_date('27-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030625012188, to_date('25-06-2003', 'dd-mm-yyyy'), to_date('09-07-2003', 'dd-mm-yyyy'), 1, 2623, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140417012189, to_date('17-04-2014', 'dd-mm-yyyy'), to_date('01-05-2014', 'dd-mm-yyyy'), 1, 9127, to_date('19-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060924012190, to_date('24-09-2006', 'dd-mm-yyyy'), to_date('08-10-2006', 'dd-mm-yyyy'), 2, 4132, to_date('11-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140411012191, to_date('11-04-2014', 'dd-mm-yyyy'), to_date('25-04-2014', 'dd-mm-yyyy'), 4, 7793, to_date('16-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130308012192, to_date('08-03-2013', 'dd-mm-yyyy'), to_date('22-03-2013', 'dd-mm-yyyy'), 2, 8181, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120130012193, to_date('30-01-2012', 'dd-mm-yyyy'), to_date('13-02-2012', 'dd-mm-yyyy'), 2, 8458, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051210012194, to_date('10-12-2005', 'dd-mm-yyyy'), to_date('24-12-2005', 'dd-mm-yyyy'), 4, 3975, to_date('15-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071020012195, to_date('20-10-2007', 'dd-mm-yyyy'), to_date('03-11-2007', 'dd-mm-yyyy'), 2, 5527, to_date('01-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100918012196, to_date('18-09-2010', 'dd-mm-yyyy'), to_date('02-10-2010', 'dd-mm-yyyy'), 1, 5741, to_date('29-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041007012197, to_date('07-10-2004', 'dd-mm-yyyy'), to_date('21-10-2004', 'dd-mm-yyyy'), 3, 4149, to_date('08-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040521012198, to_date('21-05-2004', 'dd-mm-yyyy'), to_date('04-06-2004', 'dd-mm-yyyy'), 4, 3905, to_date('01-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120930012199, to_date('30-09-2012', 'dd-mm-yyyy'), to_date('14-10-2012', 'dd-mm-yyyy'), 3, 7975, to_date('14-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090102012200, to_date('02-01-2009', 'dd-mm-yyyy'), to_date('16-01-2009', 'dd-mm-yyyy'), 2, 4050, to_date('17-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111009012201, to_date('09-10-2011', 'dd-mm-yyyy'), to_date('23-10-2011', 'dd-mm-yyyy'), 4, 7360, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070929012202, to_date('29-09-2007', 'dd-mm-yyyy'), to_date('13-10-2007', 'dd-mm-yyyy'), 2, 4064, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226012203, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 3, 3243, to_date('27-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081111012204, to_date('11-11-2008', 'dd-mm-yyyy'), to_date('25-11-2008', 'dd-mm-yyyy'), 1, 5709, to_date('13-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041115012205, to_date('15-11-2004', 'dd-mm-yyyy'), to_date('29-11-2004', 'dd-mm-yyyy'), 4, 3571, to_date('01-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000805012206, to_date('05-08-2000', 'dd-mm-yyyy'), to_date('19-08-2000', 'dd-mm-yyyy'), 2, 1536, to_date('19-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510012207, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 3, 4104, to_date('18-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110829012208, to_date('29-08-2011', 'dd-mm-yyyy'), to_date('12-09-2011', 'dd-mm-yyyy'), 3, 9646, to_date('11-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080307012209, to_date('07-03-2008', 'dd-mm-yyyy'), to_date('21-03-2008', 'dd-mm-yyyy'), 2, 5549, to_date('13-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504012210, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 4, 4881, to_date('07-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130307012211, to_date('07-03-2013', 'dd-mm-yyyy'), to_date('21-03-2013', 'dd-mm-yyyy'), 3, 9732, to_date('14-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050407012212, to_date('07-04-2005', 'dd-mm-yyyy'), to_date('21-04-2005', 'dd-mm-yyyy'), 2, 5231, to_date('23-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081030012213, to_date('30-10-2008', 'dd-mm-yyyy'), to_date('13-11-2008', 'dd-mm-yyyy'), 3, 3185, to_date('16-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020411012214, to_date('11-04-2002', 'dd-mm-yyyy'), to_date('25-04-2002', 'dd-mm-yyyy'), 2, 3509, to_date('30-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100313012215, to_date('13-03-2010', 'dd-mm-yyyy'), to_date('27-03-2010', 'dd-mm-yyyy'), 1, 6463, to_date('29-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140203012216, to_date('03-02-2014', 'dd-mm-yyyy'), to_date('17-02-2014', 'dd-mm-yyyy'), 2, 9455, to_date('14-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512012217, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 4, 4512, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051030012218, to_date('30-10-2005', 'dd-mm-yyyy'), to_date('13-11-2005', 'dd-mm-yyyy'), 4, 4741, to_date('15-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130729012219, to_date('29-07-2013', 'dd-mm-yyyy'), to_date('12-08-2013', 'dd-mm-yyyy'), 1, 10605, to_date('01-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110108012220, to_date('08-01-2011', 'dd-mm-yyyy'), to_date('22-01-2011', 'dd-mm-yyyy'), 3, 8092, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100505012221, to_date('05-05-2010', 'dd-mm-yyyy'), to_date('19-05-2010', 'dd-mm-yyyy'), 2, 7440, to_date('23-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070810012222, to_date('10-08-2007', 'dd-mm-yyyy'), to_date('24-08-2007', 'dd-mm-yyyy'), 1, 5188, to_date('21-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000629012223, to_date('29-06-2000', 'dd-mm-yyyy'), to_date('13-07-2000', 'dd-mm-yyyy'), 3, 1316, to_date('19-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080215012224, to_date('15-02-2008', 'dd-mm-yyyy'), to_date('29-02-2008', 'dd-mm-yyyy'), 1, 4743, to_date('27-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110223012225, to_date('23-02-2011', 'dd-mm-yyyy'), to_date('09-03-2011', 'dd-mm-yyyy'), 2, 9902, to_date('06-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817012226, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 2, 6662, to_date('26-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120413012227, to_date('13-04-2012', 'dd-mm-yyyy'), to_date('27-04-2012', 'dd-mm-yyyy'), 3, 9277, to_date('25-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091128012228, to_date('28-11-2009', 'dd-mm-yyyy'), to_date('12-12-2009', 'dd-mm-yyyy'), 1, 6089, to_date('30-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030924012229, to_date('24-09-2003', 'dd-mm-yyyy'), to_date('08-10-2003', 'dd-mm-yyyy'), 3, 3740, to_date('07-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050306012230, to_date('06-03-2005', 'dd-mm-yyyy'), to_date('20-03-2005', 'dd-mm-yyyy'), 3, 3419, to_date('16-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530012231, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 4, 8237, to_date('01-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090711012232, to_date('11-07-2009', 'dd-mm-yyyy'), to_date('25-07-2009', 'dd-mm-yyyy'), 1, 4923, to_date('23-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110402012233, to_date('02-04-2011', 'dd-mm-yyyy'), to_date('16-04-2011', 'dd-mm-yyyy'), 3, 7445, to_date('14-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020907012234, to_date('07-09-2002', 'dd-mm-yyyy'), to_date('21-09-2002', 'dd-mm-yyyy'), 3, 3594, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040111012235, to_date('11-01-2004', 'dd-mm-yyyy'), to_date('25-01-2004', 'dd-mm-yyyy'), 4, 2873, to_date('27-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121217012236, to_date('17-12-2012', 'dd-mm-yyyy'), to_date('31-12-2012', 'dd-mm-yyyy'), 4, 10806, to_date('29-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110613012237, to_date('13-06-2011', 'dd-mm-yyyy'), to_date('27-06-2011', 'dd-mm-yyyy'), 2, 5919, to_date('19-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050305012238, to_date('05-03-2005', 'dd-mm-yyyy'), to_date('19-03-2005', 'dd-mm-yyyy'), 2, 7098, to_date('18-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329012239, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 2, 1977, to_date('10-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031021012240, to_date('21-10-2003', 'dd-mm-yyyy'), to_date('04-11-2003', 'dd-mm-yyyy'), 2, 1742, to_date('08-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080317012241, to_date('17-03-2008', 'dd-mm-yyyy'), to_date('31-03-2008', 'dd-mm-yyyy'), 3, 7798, to_date('06-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050814012242, to_date('14-08-2005', 'dd-mm-yyyy'), to_date('28-08-2005', 'dd-mm-yyyy'), 3, 4424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071012012243, to_date('12-10-2007', 'dd-mm-yyyy'), to_date('26-10-2007', 'dd-mm-yyyy'), 3, 4978, to_date('18-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120801012244, to_date('01-08-2012', 'dd-mm-yyyy'), to_date('15-08-2012', 'dd-mm-yyyy'), 2, 9525, to_date('03-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090825012245, to_date('25-08-2009', 'dd-mm-yyyy'), to_date('08-09-2009', 'dd-mm-yyyy'), 3, 9971, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000516012246, to_date('16-05-2000', 'dd-mm-yyyy'), to_date('30-05-2000', 'dd-mm-yyyy'), 1, 677, to_date('19-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140130012247, to_date('30-01-2014', 'dd-mm-yyyy'), to_date('13-02-2014', 'dd-mm-yyyy'), 2, 7486, to_date('14-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000830012248, to_date('30-08-2000', 'dd-mm-yyyy'), to_date('13-09-2000', 'dd-mm-yyyy'), 4, 2848, to_date('08-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111004012249, to_date('04-10-2011', 'dd-mm-yyyy'), to_date('18-10-2011', 'dd-mm-yyyy'), 3, 7766, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110401012250, to_date('01-04-2011', 'dd-mm-yyyy'), to_date('15-04-2011', 'dd-mm-yyyy'), 3, 6958, to_date('07-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061007012251, to_date('07-10-2006', 'dd-mm-yyyy'), to_date('21-10-2006', 'dd-mm-yyyy'), 2, 6826, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030119012252, to_date('19-01-2003', 'dd-mm-yyyy'), to_date('02-02-2003', 'dd-mm-yyyy'), 2, 3263, to_date('01-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000228012253, to_date('28-02-2000', 'dd-mm-yyyy'), to_date('13-03-2000', 'dd-mm-yyyy'), 3, 1052, to_date('04-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050427012254, to_date('27-04-2005', 'dd-mm-yyyy'), to_date('11-05-2005', 'dd-mm-yyyy'), 2, 4361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061019012255, to_date('19-10-2006', 'dd-mm-yyyy'), to_date('02-11-2006', 'dd-mm-yyyy'), 2, 6265, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000222012256, to_date('22-02-2000', 'dd-mm-yyyy'), to_date('07-03-2000', 'dd-mm-yyyy'), 2, 1320, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070302012257, to_date('02-03-2007', 'dd-mm-yyyy'), to_date('16-03-2007', 'dd-mm-yyyy'), 3, 4424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111002012258, to_date('02-10-2011', 'dd-mm-yyyy'), to_date('16-10-2011', 'dd-mm-yyyy'), 3, 8815, to_date('20-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051022012259, to_date('22-10-2005', 'dd-mm-yyyy'), to_date('05-11-2005', 'dd-mm-yyyy'), 4, 5590, to_date('29-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020512012260, to_date('12-05-2002', 'dd-mm-yyyy'), to_date('26-05-2002', 'dd-mm-yyyy'), 2, 4201, to_date('20-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121011012261, to_date('11-10-2012', 'dd-mm-yyyy'), to_date('25-10-2012', 'dd-mm-yyyy'), 2, 9255, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090613012262, to_date('13-06-2009', 'dd-mm-yyyy'), to_date('27-06-2009', 'dd-mm-yyyy'), 2, 7919, to_date('25-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313012263, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 2, 6426, to_date('21-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090708012264, to_date('08-07-2009', 'dd-mm-yyyy'), to_date('22-07-2009', 'dd-mm-yyyy'), 1, 6641, to_date('11-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130822012265, to_date('22-08-2013', 'dd-mm-yyyy'), to_date('05-09-2013', 'dd-mm-yyyy'), 1, 9062, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020303012266, to_date('03-03-2002', 'dd-mm-yyyy'), to_date('17-03-2002', 'dd-mm-yyyy'), 3, 1832, to_date('18-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417012267, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 3, 5850, to_date('20-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050711012268, to_date('11-07-2005', 'dd-mm-yyyy'), to_date('25-07-2005', 'dd-mm-yyyy'), 3, 4181, to_date('30-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040414012269, to_date('14-04-2004', 'dd-mm-yyyy'), to_date('28-04-2004', 'dd-mm-yyyy'), 2, 3829, to_date('04-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040317012270, to_date('17-03-2004', 'dd-mm-yyyy'), to_date('31-03-2004', 'dd-mm-yyyy'), 1, 4086, to_date('31-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001108012271, to_date('08-11-2000', 'dd-mm-yyyy'), to_date('22-11-2000', 'dd-mm-yyyy'), 3, 2004, to_date('22-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140409012272, to_date('09-04-2014', 'dd-mm-yyyy'), to_date('23-04-2014', 'dd-mm-yyyy'), 4, 9335, to_date('22-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081102012273, to_date('02-11-2008', 'dd-mm-yyyy'), to_date('16-11-2008', 'dd-mm-yyyy'), 3, 5772, to_date('21-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070331012274, to_date('31-03-2007', 'dd-mm-yyyy'), to_date('14-04-2007', 'dd-mm-yyyy'), 2, 7107, to_date('04-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021001012275, to_date('01-10-2002', 'dd-mm-yyyy'), to_date('15-10-2002', 'dd-mm-yyyy'), 2, 2099, to_date('20-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120105012276, to_date('05-01-2012', 'dd-mm-yyyy'), to_date('19-01-2012', 'dd-mm-yyyy'), 2, 8595, to_date('17-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080530012277, to_date('30-05-2008', 'dd-mm-yyyy'), to_date('13-06-2008', 'dd-mm-yyyy'), 2, 5838, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081125012278, to_date('25-11-2008', 'dd-mm-yyyy'), to_date('09-12-2008', 'dd-mm-yyyy'), 3, 5968, to_date('02-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080107012279, to_date('07-01-2008', 'dd-mm-yyyy'), to_date('21-01-2008', 'dd-mm-yyyy'), 3, 8280, to_date('16-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031203012280, to_date('03-12-2003', 'dd-mm-yyyy'), to_date('17-12-2003', 'dd-mm-yyyy'), 2, 3872, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120723012281, to_date('23-07-2012', 'dd-mm-yyyy'), to_date('06-08-2012', 'dd-mm-yyyy'), 4, 7450, to_date('04-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041112012282, to_date('12-11-2004', 'dd-mm-yyyy'), to_date('26-11-2004', 'dd-mm-yyyy'), 2, 3099, to_date('22-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802012283, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 11159, to_date('17-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040913012284, to_date('13-09-2004', 'dd-mm-yyyy'), to_date('27-09-2004', 'dd-mm-yyyy'), 1, 5894, to_date('18-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131028012285, to_date('28-10-2013', 'dd-mm-yyyy'), to_date('11-11-2013', 'dd-mm-yyyy'), 4, 8713, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120507012286, to_date('07-05-2012', 'dd-mm-yyyy'), to_date('21-05-2012', 'dd-mm-yyyy'), 2, 9901, to_date('23-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030518012287, to_date('18-05-2003', 'dd-mm-yyyy'), to_date('01-06-2003', 'dd-mm-yyyy'), 3, 3573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100402012288, to_date('02-04-2010', 'dd-mm-yyyy'), to_date('16-04-2010', 'dd-mm-yyyy'), 4, 5180, to_date('21-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111105012289, to_date('05-11-2011', 'dd-mm-yyyy'), to_date('19-11-2011', 'dd-mm-yyyy'), 3, 9628, to_date('12-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080110012290, to_date('10-01-2008', 'dd-mm-yyyy'), to_date('24-01-2008', 'dd-mm-yyyy'), 3, 6722, to_date('20-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050820012291, to_date('20-08-2005', 'dd-mm-yyyy'), to_date('03-09-2005', 'dd-mm-yyyy'), 2, 3935, to_date('07-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090529012292, to_date('29-05-2009', 'dd-mm-yyyy'), to_date('12-06-2009', 'dd-mm-yyyy'), 2, 9792, to_date('17-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050313012293, to_date('13-03-2005', 'dd-mm-yyyy'), to_date('27-03-2005', 'dd-mm-yyyy'), 2, 3778, to_date('25-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061223012294, to_date('23-12-2006', 'dd-mm-yyyy'), to_date('06-01-2007', 'dd-mm-yyyy'), 2, 6765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000916012295, to_date('16-09-2000', 'dd-mm-yyyy'), to_date('30-09-2000', 'dd-mm-yyyy'), 1, 414, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000130012296, to_date('30-01-2000', 'dd-mm-yyyy'), to_date('13-02-2000', 'dd-mm-yyyy'), 3, 1527, to_date('10-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130611012297, to_date('11-06-2013', 'dd-mm-yyyy'), to_date('25-06-2013', 'dd-mm-yyyy'), 2, 8695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040426012298, to_date('26-04-2004', 'dd-mm-yyyy'), to_date('10-05-2004', 'dd-mm-yyyy'), 2, 4431, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011121012299, to_date('21-11-2001', 'dd-mm-yyyy'), to_date('05-12-2001', 'dd-mm-yyyy'), 2, 2272, to_date('28-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626012300, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 1, 7437, to_date('14-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100417012301, to_date('17-04-2010', 'dd-mm-yyyy'), to_date('01-05-2010', 'dd-mm-yyyy'), 4, 8781, to_date('20-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004012302, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 1, 1582, to_date('17-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091031012303, to_date('31-10-2009', 'dd-mm-yyyy'), to_date('14-11-2009', 'dd-mm-yyyy'), 2, 4881, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110722012304, to_date('22-07-2011', 'dd-mm-yyyy'), to_date('05-08-2011', 'dd-mm-yyyy'), 2, 6383, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001111012305, to_date('11-11-2000', 'dd-mm-yyyy'), to_date('25-11-2000', 'dd-mm-yyyy'), 1, 2190, to_date('21-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080226012306, to_date('26-02-2008', 'dd-mm-yyyy'), to_date('11-03-2008', 'dd-mm-yyyy'), 3, 7674, to_date('17-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140222012307, to_date('22-02-2014', 'dd-mm-yyyy'), to_date('08-03-2014', 'dd-mm-yyyy'), 3, 8507, to_date('27-02-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051229012308, to_date('29-12-2005', 'dd-mm-yyyy'), to_date('12-01-2006', 'dd-mm-yyyy'), 1, 4635, to_date('16-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130127012309, to_date('27-01-2013', 'dd-mm-yyyy'), to_date('10-02-2013', 'dd-mm-yyyy'), 4, 12032, to_date('02-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120224012310, to_date('24-02-2012', 'dd-mm-yyyy'), to_date('09-03-2012', 'dd-mm-yyyy'), 3, 8795, to_date('10-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130524012311, to_date('24-05-2013', 'dd-mm-yyyy'), to_date('07-06-2013', 'dd-mm-yyyy'), 3, 8089, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626012312, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 3, 5470, to_date('05-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070923012313, to_date('23-09-2007', 'dd-mm-yyyy'), to_date('07-10-2007', 'dd-mm-yyyy'), 3, 7961, to_date('10-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218012314, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 1, 7039, to_date('29-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110104012315, to_date('04-01-2011', 'dd-mm-yyyy'), to_date('18-01-2011', 'dd-mm-yyyy'), 2, 8312, to_date('15-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010927012316, to_date('27-09-2001', 'dd-mm-yyyy'), to_date('11-10-2001', 'dd-mm-yyyy'), 1, 1720, to_date('30-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050902012317, to_date('02-09-2005', 'dd-mm-yyyy'), to_date('16-09-2005', 'dd-mm-yyyy'), 2, 1875, to_date('12-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020420012318, to_date('20-04-2002', 'dd-mm-yyyy'), to_date('04-05-2002', 'dd-mm-yyyy'), 3, 2667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091211012319, to_date('11-12-2009', 'dd-mm-yyyy'), to_date('25-12-2009', 'dd-mm-yyyy'), 1, 6584, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030208012320, to_date('08-02-2003', 'dd-mm-yyyy'), to_date('22-02-2003', 'dd-mm-yyyy'), 3, 3381, to_date('13-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100715012321, to_date('15-07-2010', 'dd-mm-yyyy'), to_date('29-07-2010', 'dd-mm-yyyy'), 3, 5791, to_date('25-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081004012322, to_date('04-10-2008', 'dd-mm-yyyy'), to_date('18-10-2008', 'dd-mm-yyyy'), 2, 6551, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111111012323, to_date('11-11-2011', 'dd-mm-yyyy'), to_date('25-11-2011', 'dd-mm-yyyy'), 2, 7123, to_date('27-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120323012324, to_date('23-03-2012', 'dd-mm-yyyy'), to_date('06-04-2012', 'dd-mm-yyyy'), 2, 6954, to_date('26-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040725012325, to_date('25-07-2004', 'dd-mm-yyyy'), to_date('08-08-2004', 'dd-mm-yyyy'), 3, 3140, to_date('28-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090725012326, to_date('25-07-2009', 'dd-mm-yyyy'), to_date('08-08-2009', 'dd-mm-yyyy'), 4, 6346, to_date('09-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050613012327, to_date('13-06-2005', 'dd-mm-yyyy'), to_date('27-06-2005', 'dd-mm-yyyy'), 3, 6244, to_date('29-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100318012328, to_date('18-03-2010', 'dd-mm-yyyy'), to_date('01-04-2010', 'dd-mm-yyyy'), 1, 6229, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130908012329, to_date('08-09-2013', 'dd-mm-yyyy'), to_date('22-09-2013', 'dd-mm-yyyy'), 1, 9001, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120221012330, to_date('21-02-2012', 'dd-mm-yyyy'), to_date('06-03-2012', 'dd-mm-yyyy'), 4, 8294, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041226012331, to_date('26-12-2004', 'dd-mm-yyyy'), to_date('09-01-2005', 'dd-mm-yyyy'), 3, 3524, to_date('27-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090714012332, to_date('14-07-2009', 'dd-mm-yyyy'), to_date('28-07-2009', 'dd-mm-yyyy'), 2, 7565, to_date('16-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070610012333, to_date('10-06-2007', 'dd-mm-yyyy'), to_date('24-06-2007', 'dd-mm-yyyy'), 3, 6113, to_date('19-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060105012334, to_date('05-01-2006', 'dd-mm-yyyy'), to_date('19-01-2006', 'dd-mm-yyyy'), 1, 5203, to_date('09-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060722012335, to_date('22-07-2006', 'dd-mm-yyyy'), to_date('05-08-2006', 'dd-mm-yyyy'), 3, 5635, to_date('31-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121108012336, to_date('08-11-2012', 'dd-mm-yyyy'), to_date('22-11-2012', 'dd-mm-yyyy'), 3, 10065, to_date('19-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040129012337, to_date('29-01-2004', 'dd-mm-yyyy'), to_date('12-02-2004', 'dd-mm-yyyy'), 1, 2618, to_date('30-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131006012338, to_date('06-10-2013', 'dd-mm-yyyy'), to_date('20-10-2013', 'dd-mm-yyyy'), 2, 11323, to_date('11-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090408012339, to_date('08-04-2009', 'dd-mm-yyyy'), to_date('22-04-2009', 'dd-mm-yyyy'), 2, 7204, to_date('11-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080710012340, to_date('10-07-2008', 'dd-mm-yyyy'), to_date('24-07-2008', 'dd-mm-yyyy'), 2, 8812, to_date('23-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140331012341, to_date('31-03-2014', 'dd-mm-yyyy'), to_date('14-04-2014', 'dd-mm-yyyy'), 2, 9303, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070804012342, to_date('04-08-2007', 'dd-mm-yyyy'), to_date('18-08-2007', 'dd-mm-yyyy'), 1, 6557, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081201012343, to_date('01-12-2008', 'dd-mm-yyyy'), to_date('15-12-2008', 'dd-mm-yyyy'), 2, 6504, to_date('06-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000517012344, to_date('17-05-2000', 'dd-mm-yyyy'), to_date('31-05-2000', 'dd-mm-yyyy'), 3, 1886, to_date('24-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011211012345, to_date('11-12-2001', 'dd-mm-yyyy'), to_date('25-12-2001', 'dd-mm-yyyy'), 4, 4039, to_date('24-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131130012346, to_date('30-11-2013', 'dd-mm-yyyy'), to_date('14-12-2013', 'dd-mm-yyyy'), 2, 10169, to_date('01-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060113012347, to_date('13-01-2006', 'dd-mm-yyyy'), to_date('27-01-2006', 'dd-mm-yyyy'), 3, 4362, to_date('18-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000607012348, to_date('07-06-2000', 'dd-mm-yyyy'), to_date('21-06-2000', 'dd-mm-yyyy'), 2, 3087, to_date('17-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040527012349, to_date('27-05-2004', 'dd-mm-yyyy'), to_date('10-06-2004', 'dd-mm-yyyy'), 4, 1826, to_date('14-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120318012350, to_date('18-03-2012', 'dd-mm-yyyy'), to_date('01-04-2012', 'dd-mm-yyyy'), 4, 5050, to_date('29-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120213012351, to_date('13-02-2012', 'dd-mm-yyyy'), to_date('27-02-2012', 'dd-mm-yyyy'), 3, 7521, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081121012352, to_date('21-11-2008', 'dd-mm-yyyy'), to_date('05-12-2008', 'dd-mm-yyyy'), 3, 7990, to_date('11-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060126012353, to_date('26-01-2006', 'dd-mm-yyyy'), to_date('09-02-2006', 'dd-mm-yyyy'), 1, 3816, to_date('14-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010201015052, to_date('01-02-2001', 'dd-mm-yyyy'), to_date('15-02-2001', 'dd-mm-yyyy'), 3, 3620, to_date('19-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040715015053, to_date('15-07-2004', 'dd-mm-yyyy'), to_date('29-07-2004', 'dd-mm-yyyy'), 2, 3378, to_date('28-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080214015054, to_date('14-02-2008', 'dd-mm-yyyy'), to_date('28-02-2008', 'dd-mm-yyyy'), 4, 7082, to_date('18-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130702015055, to_date('02-07-2013', 'dd-mm-yyyy'), to_date('16-07-2013', 'dd-mm-yyyy'), 2, 8612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131026015056, to_date('26-10-2013', 'dd-mm-yyyy'), to_date('09-11-2013', 'dd-mm-yyyy'), 3, 7477, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121114015057, to_date('14-11-2012', 'dd-mm-yyyy'), to_date('28-11-2012', 'dd-mm-yyyy'), 3, 6207, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090830015058, to_date('30-08-2009', 'dd-mm-yyyy'), to_date('13-09-2009', 'dd-mm-yyyy'), 4, 8700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131111015059, to_date('11-11-2013', 'dd-mm-yyyy'), to_date('25-11-2013', 'dd-mm-yyyy'), 4, 9371, to_date('15-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203015060, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 3, 7269, to_date('16-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020112015061, to_date('12-01-2002', 'dd-mm-yyyy'), to_date('26-01-2002', 'dd-mm-yyyy'), 2, 3482, to_date('30-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000516015062, to_date('16-05-2000', 'dd-mm-yyyy'), to_date('30-05-2000', 'dd-mm-yyyy'), 2, 2063, to_date('18-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090513015063, to_date('13-05-2009', 'dd-mm-yyyy'), to_date('27-05-2009', 'dd-mm-yyyy'), 3, 7588, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100330015064, to_date('30-03-2010', 'dd-mm-yyyy'), to_date('13-04-2010', 'dd-mm-yyyy'), 2, 6299, to_date('01-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030722015065, to_date('22-07-2003', 'dd-mm-yyyy'), to_date('05-08-2003', 'dd-mm-yyyy'), 3, 3962, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110430015066, to_date('30-04-2011', 'dd-mm-yyyy'), to_date('14-05-2011', 'dd-mm-yyyy'), 3, 5243, to_date('07-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121102015067, to_date('02-11-2012', 'dd-mm-yyyy'), to_date('16-11-2012', 'dd-mm-yyyy'), 3, 7423, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080802015068, to_date('02-08-2008', 'dd-mm-yyyy'), to_date('16-08-2008', 'dd-mm-yyyy'), 4, 4983, to_date('07-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525015069, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 2, 6871, to_date('27-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715015070, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 3, 1017, to_date('23-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040227015071, to_date('27-02-2004', 'dd-mm-yyyy'), to_date('12-03-2004', 'dd-mm-yyyy'), 3, 3192, to_date('11-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081017015072, to_date('17-10-2008', 'dd-mm-yyyy'), to_date('31-10-2008', 'dd-mm-yyyy'), 3, 7798, to_date('28-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130102015073, to_date('02-01-2013', 'dd-mm-yyyy'), to_date('16-01-2013', 'dd-mm-yyyy'), 2, 8000, to_date('18-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080103015074, to_date('03-01-2008', 'dd-mm-yyyy'), to_date('17-01-2008', 'dd-mm-yyyy'), 1, 5803, to_date('14-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010322015075, to_date('22-03-2001', 'dd-mm-yyyy'), to_date('05-04-2001', 'dd-mm-yyyy'), 2, 1559, to_date('03-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030306015076, to_date('06-03-2003', 'dd-mm-yyyy'), to_date('20-03-2003', 'dd-mm-yyyy'), 2, 4205, to_date('09-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525015077, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 1, 1176, to_date('06-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120810015078, to_date('10-08-2012', 'dd-mm-yyyy'), to_date('24-08-2012', 'dd-mm-yyyy'), 4, 11212, to_date('22-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030707015079, to_date('07-07-2003', 'dd-mm-yyyy'), to_date('21-07-2003', 'dd-mm-yyyy'), 4, 3214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522015080, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 2, 2700, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120415015081, to_date('15-04-2012', 'dd-mm-yyyy'), to_date('29-04-2012', 'dd-mm-yyyy'), 2, 7226, to_date('05-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101015082, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 4, 3783, to_date('09-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120121015083, to_date('21-01-2012', 'dd-mm-yyyy'), to_date('04-02-2012', 'dd-mm-yyyy'), 3, 8346, to_date('27-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010417015084, to_date('17-04-2001', 'dd-mm-yyyy'), to_date('01-05-2001', 'dd-mm-yyyy'), 2, 2412, to_date('06-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030330015085, to_date('30-03-2003', 'dd-mm-yyyy'), to_date('13-04-2003', 'dd-mm-yyyy'), 4, 3878, to_date('03-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060825015086, to_date('25-08-2006', 'dd-mm-yyyy'), to_date('08-09-2006', 'dd-mm-yyyy'), 1, 9020, to_date('13-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060628015087, to_date('28-06-2006', 'dd-mm-yyyy'), to_date('12-07-2006', 'dd-mm-yyyy'), 1, 2546, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081022015088, to_date('22-10-2008', 'dd-mm-yyyy'), to_date('05-11-2008', 'dd-mm-yyyy'), 1, 4759, to_date('24-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120928015089, to_date('28-09-2012', 'dd-mm-yyyy'), to_date('12-10-2012', 'dd-mm-yyyy'), 3, 7632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030624015090, to_date('24-06-2003', 'dd-mm-yyyy'), to_date('08-07-2003', 'dd-mm-yyyy'), 2, 4000, to_date('02-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020323015091, to_date('23-03-2002', 'dd-mm-yyyy'), to_date('06-04-2002', 'dd-mm-yyyy'), 2, 3000, to_date('02-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061121015092, to_date('21-11-2006', 'dd-mm-yyyy'), to_date('05-12-2006', 'dd-mm-yyyy'), 2, 4247, to_date('06-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509015093, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 3, 3898, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403015094, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 3, 5038, to_date('05-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000116015095, to_date('16-01-2000', 'dd-mm-yyyy'), to_date('30-01-2000', 'dd-mm-yyyy'), 1, 1692, to_date('25-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000910015096, to_date('10-09-2000', 'dd-mm-yyyy'), to_date('24-09-2000', 'dd-mm-yyyy'), 2, 1496, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110623015097, to_date('23-06-2011', 'dd-mm-yyyy'), to_date('07-07-2011', 'dd-mm-yyyy'), 2, 4706, to_date('04-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112015098, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 1, 9829, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120622015099, to_date('22-06-2012', 'dd-mm-yyyy'), to_date('06-07-2012', 'dd-mm-yyyy'), 3, 10591, to_date('25-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100619015100, to_date('19-06-2010', 'dd-mm-yyyy'), to_date('03-07-2010', 'dd-mm-yyyy'), 3, 7880, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021130015101, to_date('30-11-2002', 'dd-mm-yyyy'), to_date('14-12-2002', 'dd-mm-yyyy'), 3, 2449, to_date('19-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091203015102, to_date('03-12-2009', 'dd-mm-yyyy'), to_date('17-12-2009', 'dd-mm-yyyy'), 3, 7790, to_date('22-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030101015103, to_date('01-01-2003', 'dd-mm-yyyy'), to_date('15-01-2003', 'dd-mm-yyyy'), 4, 4652, to_date('11-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111017015104, to_date('17-10-2011', 'dd-mm-yyyy'), to_date('31-10-2011', 'dd-mm-yyyy'), 4, 8074, to_date('29-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060403015105, to_date('03-04-2006', 'dd-mm-yyyy'), to_date('17-04-2006', 'dd-mm-yyyy'), 2, 5338, to_date('07-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131109015106, to_date('09-11-2013', 'dd-mm-yyyy'), to_date('23-11-2013', 'dd-mm-yyyy'), 4, 6675, to_date('24-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020509015107, to_date('09-05-2002', 'dd-mm-yyyy'), to_date('23-05-2002', 'dd-mm-yyyy'), 2, 1712, to_date('28-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021028015108, to_date('28-10-2002', 'dd-mm-yyyy'), to_date('11-11-2002', 'dd-mm-yyyy'), 3, 2867, to_date('17-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120131015109, to_date('31-01-2012', 'dd-mm-yyyy'), to_date('14-02-2012', 'dd-mm-yyyy'), 3, 6491, to_date('19-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030405015110, to_date('05-04-2003', 'dd-mm-yyyy'), to_date('19-04-2003', 'dd-mm-yyyy'), 1, 4068, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040906015111, to_date('06-09-2004', 'dd-mm-yyyy'), to_date('20-09-2004', 'dd-mm-yyyy'), 2, 2269, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120725015112, to_date('25-07-2012', 'dd-mm-yyyy'), to_date('08-08-2012', 'dd-mm-yyyy'), 3, 11212, to_date('28-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090812015113, to_date('12-08-2009', 'dd-mm-yyyy'), to_date('26-08-2009', 'dd-mm-yyyy'), 2, 5687, to_date('27-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010629015114, to_date('29-06-2001', 'dd-mm-yyyy'), to_date('13-07-2001', 'dd-mm-yyyy'), 1, 2269, to_date('14-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090211015115, to_date('11-02-2009', 'dd-mm-yyyy'), to_date('25-02-2009', 'dd-mm-yyyy'), 3, 6317, to_date('18-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130808015116, to_date('08-08-2013', 'dd-mm-yyyy'), to_date('22-08-2013', 'dd-mm-yyyy'), 3, 7416, to_date('24-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000901015117, to_date('01-09-2000', 'dd-mm-yyyy'), to_date('15-09-2000', 'dd-mm-yyyy'), 3, 1232, to_date('15-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040308015118, to_date('08-03-2004', 'dd-mm-yyyy'), to_date('22-03-2004', 'dd-mm-yyyy'), 2, 2728, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011208015119, to_date('08-12-2001', 'dd-mm-yyyy'), to_date('22-12-2001', 'dd-mm-yyyy'), 2, 3607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000503015120, to_date('03-05-2000', 'dd-mm-yyyy'), to_date('17-05-2000', 'dd-mm-yyyy'), 2, 1639, to_date('14-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100717015121, to_date('17-07-2010', 'dd-mm-yyyy'), to_date('31-07-2010', 'dd-mm-yyyy'), 3, 6840, to_date('23-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111218015122, to_date('18-12-2011', 'dd-mm-yyyy'), to_date('01-01-2012', 'dd-mm-yyyy'), 4, 9201, to_date('27-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110429015123, to_date('29-04-2011', 'dd-mm-yyyy'), to_date('13-05-2011', 'dd-mm-yyyy'), 4, 6382, to_date('08-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081231015124, to_date('31-12-2008', 'dd-mm-yyyy'), to_date('14-01-2009', 'dd-mm-yyyy'), 4, 4943, to_date('01-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120015125, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 3, 5414, to_date('01-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140415015126, to_date('15-04-2014', 'dd-mm-yyyy'), to_date('29-04-2014', 'dd-mm-yyyy'), 1, 9758, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061025015127, to_date('25-10-2006', 'dd-mm-yyyy'), to_date('08-11-2006', 'dd-mm-yyyy'), 1, 6256, to_date('05-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061119015128, to_date('19-11-2006', 'dd-mm-yyyy'), to_date('03-12-2006', 'dd-mm-yyyy'), 1, 5240, to_date('05-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110819015129, to_date('19-08-2011', 'dd-mm-yyyy'), to_date('02-09-2011', 'dd-mm-yyyy'), 2, 10680, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011130015130, to_date('30-11-2001', 'dd-mm-yyyy'), to_date('14-12-2001', 'dd-mm-yyyy'), 1, 2039, to_date('13-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130731015131, to_date('31-07-2013', 'dd-mm-yyyy'), to_date('14-08-2013', 'dd-mm-yyyy'), 3, 7479, to_date('16-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040926015132, to_date('26-09-2004', 'dd-mm-yyyy'), to_date('10-10-2004', 'dd-mm-yyyy'), 4, 4134, to_date('05-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121118015133, to_date('18-11-2012', 'dd-mm-yyyy'), to_date('02-12-2012', 'dd-mm-yyyy'), 1, 9349, to_date('01-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091014015134, to_date('14-10-2009', 'dd-mm-yyyy'), to_date('28-10-2009', 'dd-mm-yyyy'), 2, 8096, to_date('21-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040623015135, to_date('23-06-2004', 'dd-mm-yyyy'), to_date('07-07-2004', 'dd-mm-yyyy'), 4, 3452, to_date('06-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923015136, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 2, 6232, to_date('26-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050511015137, to_date('11-05-2005', 'dd-mm-yyyy'), to_date('25-05-2005', 'dd-mm-yyyy'), 1, 3468, to_date('21-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918015138, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 1, 3765, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010821015139, to_date('21-08-2001', 'dd-mm-yyyy'), to_date('04-09-2001', 'dd-mm-yyyy'), 4, 1412, to_date('27-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101002015140, to_date('02-10-2010', 'dd-mm-yyyy'), to_date('16-10-2010', 'dd-mm-yyyy'), 4, 5029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120810015141, to_date('10-08-2012', 'dd-mm-yyyy'), to_date('24-08-2012', 'dd-mm-yyyy'), 2, 6801, to_date('27-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060901015142, to_date('01-09-2006', 'dd-mm-yyyy'), to_date('15-09-2006', 'dd-mm-yyyy'), 3, 4263, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070105015143, to_date('05-01-2007', 'dd-mm-yyyy'), to_date('19-01-2007', 'dd-mm-yyyy'), 4, 6111, to_date('22-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100130015144, to_date('30-01-2010', 'dd-mm-yyyy'), to_date('13-02-2010', 'dd-mm-yyyy'), 1, 7449, to_date('14-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001216015145, to_date('16-12-2000', 'dd-mm-yyyy'), to_date('30-12-2000', 'dd-mm-yyyy'), 3, 1063, to_date('20-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111210015146, to_date('10-12-2011', 'dd-mm-yyyy'), to_date('24-12-2011', 'dd-mm-yyyy'), 2, 7080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080904015147, to_date('04-09-2008', 'dd-mm-yyyy'), to_date('18-09-2008', 'dd-mm-yyyy'), 2, 5411, to_date('21-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030531015148, to_date('31-05-2003', 'dd-mm-yyyy'), to_date('14-06-2003', 'dd-mm-yyyy'), 4, 1704, to_date('10-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905015149, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 2, 3226, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010412015150, to_date('12-04-2001', 'dd-mm-yyyy'), to_date('26-04-2001', 'dd-mm-yyyy'), 3, 1573, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130412015151, to_date('12-04-2013', 'dd-mm-yyyy'), to_date('26-04-2013', 'dd-mm-yyyy'), 1, 6619, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080828015152, to_date('28-08-2008', 'dd-mm-yyyy'), to_date('11-09-2008', 'dd-mm-yyyy'), 4, 8676, to_date('05-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000418015153, to_date('18-04-2000', 'dd-mm-yyyy'), to_date('02-05-2000', 'dd-mm-yyyy'), 3, 1837, to_date('27-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215015154, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 2, 9299, to_date('22-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130410015155, to_date('10-04-2013', 'dd-mm-yyyy'), to_date('24-04-2013', 'dd-mm-yyyy'), 3, 6957, to_date('23-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100916015156, to_date('16-09-2010', 'dd-mm-yyyy'), to_date('30-09-2010', 'dd-mm-yyyy'), 3, 8327, to_date('01-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071018015157, to_date('18-10-2007', 'dd-mm-yyyy'), to_date('01-11-2007', 'dd-mm-yyyy'), 4, 5261, to_date('30-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080601015158, to_date('01-06-2008', 'dd-mm-yyyy'), to_date('15-06-2008', 'dd-mm-yyyy'), 2, 5455, to_date('17-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020918015159, to_date('18-09-2002', 'dd-mm-yyyy'), to_date('02-10-2002', 'dd-mm-yyyy'), 2, 2111, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100709015160, to_date('09-07-2010', 'dd-mm-yyyy'), to_date('23-07-2010', 'dd-mm-yyyy'), 2, 6869, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100520015161, to_date('20-05-2010', 'dd-mm-yyyy'), to_date('03-06-2010', 'dd-mm-yyyy'), 3, 6812, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121022015162, to_date('22-10-2012', 'dd-mm-yyyy'), to_date('05-11-2012', 'dd-mm-yyyy'), 4, 8087, to_date('06-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020625015163, to_date('25-06-2002', 'dd-mm-yyyy'), to_date('09-07-2002', 'dd-mm-yyyy'), 2, 1938, to_date('04-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130905015164, to_date('05-09-2013', 'dd-mm-yyyy'), to_date('19-09-2013', 'dd-mm-yyyy'), 2, 6859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030520015165, to_date('20-05-2003', 'dd-mm-yyyy'), to_date('03-06-2003', 'dd-mm-yyyy'), 2, 3637, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080404015166, to_date('04-04-2008', 'dd-mm-yyyy'), to_date('18-04-2008', 'dd-mm-yyyy'), 2, 4601, to_date('24-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060424015167, to_date('24-04-2006', 'dd-mm-yyyy'), to_date('08-05-2006', 'dd-mm-yyyy'), 4, 5715, to_date('10-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061102015168, to_date('02-11-2006', 'dd-mm-yyyy'), to_date('16-11-2006', 'dd-mm-yyyy'), 1, 4753, to_date('15-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050504015169, to_date('04-05-2005', 'dd-mm-yyyy'), to_date('18-05-2005', 'dd-mm-yyyy'), 2, 3986, to_date('12-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515015170, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 2, 761, to_date('20-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130805015171, to_date('05-08-2013', 'dd-mm-yyyy'), to_date('19-08-2013', 'dd-mm-yyyy'), 2, 8956, to_date('22-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101124015172, to_date('24-11-2010', 'dd-mm-yyyy'), to_date('08-12-2010', 'dd-mm-yyyy'), 2, 7964, to_date('03-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070105015173, to_date('05-01-2007', 'dd-mm-yyyy'), to_date('19-01-2007', 'dd-mm-yyyy'), 4, 6870, to_date('24-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120218015174, to_date('18-02-2012', 'dd-mm-yyyy'), to_date('03-03-2012', 'dd-mm-yyyy'), 4, 10895, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629015175, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 2, 5605, to_date('14-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131031015176, to_date('31-10-2013', 'dd-mm-yyyy'), to_date('14-11-2013', 'dd-mm-yyyy'), 2, 7091, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010319015177, to_date('19-03-2001', 'dd-mm-yyyy'), to_date('02-04-2001', 'dd-mm-yyyy'), 2, 3030, to_date('25-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040917015178, to_date('17-09-2004', 'dd-mm-yyyy'), to_date('01-10-2004', 'dd-mm-yyyy'), 3, 4385, to_date('24-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051019015179, to_date('19-10-2005', 'dd-mm-yyyy'), to_date('02-11-2005', 'dd-mm-yyyy'), 2, 2351, to_date('22-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040410015180, to_date('10-04-2004', 'dd-mm-yyyy'), to_date('24-04-2004', 'dd-mm-yyyy'), 2, 3277, to_date('15-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110210015181, to_date('10-02-2011', 'dd-mm-yyyy'), to_date('24-02-2011', 'dd-mm-yyyy'), 4, 7982, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110421015182, to_date('21-04-2011', 'dd-mm-yyyy'), to_date('05-05-2011', 'dd-mm-yyyy'), 2, 6384, to_date('25-04-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120622015183, to_date('22-06-2012', 'dd-mm-yyyy'), to_date('06-07-2012', 'dd-mm-yyyy'), 2, 7049, to_date('08-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010210015184, to_date('10-02-2001', 'dd-mm-yyyy'), to_date('24-02-2001', 'dd-mm-yyyy'), 4, 1948, to_date('11-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070318015185, to_date('18-03-2007', 'dd-mm-yyyy'), to_date('01-04-2007', 'dd-mm-yyyy'), 2, 6086, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000416015186, to_date('16-04-2000', 'dd-mm-yyyy'), to_date('30-04-2000', 'dd-mm-yyyy'), 4, 750, to_date('24-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060415015187, to_date('15-04-2006', 'dd-mm-yyyy'), to_date('29-04-2006', 'dd-mm-yyyy'), 3, 3897, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091201015188, to_date('01-12-2009', 'dd-mm-yyyy'), to_date('15-12-2009', 'dd-mm-yyyy'), 3, 4771, to_date('08-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020212015189, to_date('12-02-2002', 'dd-mm-yyyy'), to_date('26-02-2002', 'dd-mm-yyyy'), 2, 2520, to_date('20-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061210015190, to_date('10-12-2006', 'dd-mm-yyyy'), to_date('24-12-2006', 'dd-mm-yyyy'), 3, 6015, to_date('26-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060412015191, to_date('12-04-2006', 'dd-mm-yyyy'), to_date('26-04-2006', 'dd-mm-yyyy'), 2, 4914, to_date('26-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020428015192, to_date('28-04-2002', 'dd-mm-yyyy'), to_date('12-05-2002', 'dd-mm-yyyy'), 2, 1954, to_date('06-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120826015193, to_date('26-08-2012', 'dd-mm-yyyy'), to_date('09-09-2012', 'dd-mm-yyyy'), 2, 9948, to_date('30-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120624015194, to_date('24-06-2012', 'dd-mm-yyyy'), to_date('08-07-2012', 'dd-mm-yyyy'), 4, 10220, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140227015195, to_date('27-02-2014', 'dd-mm-yyyy'), to_date('13-03-2014', 'dd-mm-yyyy'), 2, 8161, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030320015196, to_date('20-03-2003', 'dd-mm-yyyy'), to_date('03-04-2003', 'dd-mm-yyyy'), 4, 2727, to_date('27-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110626015197, to_date('26-06-2011', 'dd-mm-yyyy'), to_date('10-07-2011', 'dd-mm-yyyy'), 2, 10116, to_date('13-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070722015198, to_date('22-07-2007', 'dd-mm-yyyy'), to_date('05-08-2007', 'dd-mm-yyyy'), 2, 4603, to_date('27-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614015199, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 2, 5437, to_date('17-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100823015200, to_date('23-08-2010', 'dd-mm-yyyy'), to_date('06-09-2010', 'dd-mm-yyyy'), 3, 7381, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011108015201, to_date('08-11-2001', 'dd-mm-yyyy'), to_date('22-11-2001', 'dd-mm-yyyy'), 4, 2644, to_date('22-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040621015202, to_date('21-06-2004', 'dd-mm-yyyy'), to_date('05-07-2004', 'dd-mm-yyyy'), 3, 3632, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140409015203, to_date('09-04-2014', 'dd-mm-yyyy'), to_date('23-04-2014', 'dd-mm-yyyy'), 3, 8635, to_date('12-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050727015204, to_date('27-07-2005', 'dd-mm-yyyy'), to_date('10-08-2005', 'dd-mm-yyyy'), 1, 4655, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061207015205, to_date('07-12-2006', 'dd-mm-yyyy'), to_date('21-12-2006', 'dd-mm-yyyy'), 1, 6678, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060520015206, to_date('20-05-2006', 'dd-mm-yyyy'), to_date('03-06-2006', 'dd-mm-yyyy'), 2, 3164, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110527015207, to_date('27-05-2011', 'dd-mm-yyyy'), to_date('10-06-2011', 'dd-mm-yyyy'), 3, 5247, to_date('29-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001118015208, to_date('18-11-2000', 'dd-mm-yyyy'), to_date('02-12-2000', 'dd-mm-yyyy'), 4, 1104, to_date('20-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070117015209, to_date('17-01-2007', 'dd-mm-yyyy'), to_date('31-01-2007', 'dd-mm-yyyy'), 4, 5625, to_date('04-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080619015210, to_date('19-06-2008', 'dd-mm-yyyy'), to_date('03-07-2008', 'dd-mm-yyyy'), 2, 8071, to_date('04-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041103015211, to_date('03-11-2004', 'dd-mm-yyyy'), to_date('17-11-2004', 'dd-mm-yyyy'), 2, 4855, to_date('19-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706015212, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 2, 5818, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070329015213, to_date('29-03-2007', 'dd-mm-yyyy'), to_date('12-04-2007', 'dd-mm-yyyy'), 4, 3791, to_date('06-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100609015214, to_date('09-06-2010', 'dd-mm-yyyy'), to_date('23-06-2010', 'dd-mm-yyyy'), 3, 8275, to_date('24-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010216015215, to_date('16-02-2001', 'dd-mm-yyyy'), to_date('02-03-2001', 'dd-mm-yyyy'), 1, 2430, to_date('18-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091107015216, to_date('07-11-2009', 'dd-mm-yyyy'), to_date('21-11-2009', 'dd-mm-yyyy'), 2, 8445, to_date('21-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071116015217, to_date('16-11-2007', 'dd-mm-yyyy'), to_date('30-11-2007', 'dd-mm-yyyy'), 4, 2890, to_date('02-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040601015218, to_date('01-06-2004', 'dd-mm-yyyy'), to_date('15-06-2004', 'dd-mm-yyyy'), 3, 2292, to_date('19-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010329015219, to_date('29-03-2001', 'dd-mm-yyyy'), to_date('12-04-2001', 'dd-mm-yyyy'), 3, 1786, to_date('11-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040409017749, to_date('09-04-2004', 'dd-mm-yyyy'), to_date('23-04-2004', 'dd-mm-yyyy'), 2, 5173, to_date('10-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020408017750, to_date('08-04-2002', 'dd-mm-yyyy'), to_date('22-04-2002', 'dd-mm-yyyy'), 1, 2302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726017751, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 1, 2723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091115017752, to_date('15-11-2009', 'dd-mm-yyyy'), to_date('29-11-2009', 'dd-mm-yyyy'), 2, 5314, to_date('20-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140112017753, to_date('12-01-2014', 'dd-mm-yyyy'), to_date('26-01-2014', 'dd-mm-yyyy'), 2, 9984, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050706017754, to_date('06-07-2005', 'dd-mm-yyyy'), to_date('20-07-2005', 'dd-mm-yyyy'), 1, 3134, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100706017755, to_date('06-07-2010', 'dd-mm-yyyy'), to_date('20-07-2010', 'dd-mm-yyyy'), 1, 5697, to_date('07-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120302017756, to_date('02-03-2012', 'dd-mm-yyyy'), to_date('16-03-2012', 'dd-mm-yyyy'), 1, 9114, to_date('12-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000105017757, to_date('05-01-2000', 'dd-mm-yyyy'), to_date('19-01-2000', 'dd-mm-yyyy'), 1, 1139, to_date('20-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040318017758, to_date('18-03-2004', 'dd-mm-yyyy'), to_date('01-04-2004', 'dd-mm-yyyy'), 1, 4184, to_date('23-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120422017759, to_date('22-04-2012', 'dd-mm-yyyy'), to_date('06-05-2012', 'dd-mm-yyyy'), 2, 5813, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091009017760, to_date('09-10-2009', 'dd-mm-yyyy'), to_date('23-10-2009', 'dd-mm-yyyy'), 1, 7158, to_date('20-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100812017761, to_date('12-08-2010', 'dd-mm-yyyy'), to_date('26-08-2010', 'dd-mm-yyyy'), 2, 6852, to_date('30-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051115017762, to_date('15-11-2005', 'dd-mm-yyyy'), to_date('29-11-2005', 'dd-mm-yyyy'), 1, 4262, to_date('05-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030818017763, to_date('18-08-2003', 'dd-mm-yyyy'), to_date('01-09-2003', 'dd-mm-yyyy'), 1, 3722, to_date('05-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080428017764, to_date('28-04-2008', 'dd-mm-yyyy'), to_date('12-05-2008', 'dd-mm-yyyy'), 1, 6487, to_date('18-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000403017765, to_date('03-04-2000', 'dd-mm-yyyy'), to_date('17-04-2000', 'dd-mm-yyyy'), 2, 991, to_date('04-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031002017766, to_date('02-10-2003', 'dd-mm-yyyy'), to_date('16-10-2003', 'dd-mm-yyyy'), 1, 4552, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140218017767, to_date('18-02-2014', 'dd-mm-yyyy'), to_date('04-03-2014', 'dd-mm-yyyy'), 1, 9513, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225017768, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 2, 7205, to_date('14-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109017769, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 2, 6086, to_date('19-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001006017770, to_date('06-10-2000', 'dd-mm-yyyy'), to_date('20-10-2000', 'dd-mm-yyyy'), 2, 1214, to_date('07-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031107017771, to_date('07-11-2003', 'dd-mm-yyyy'), to_date('21-11-2003', 'dd-mm-yyyy'), 2, 2183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010912017772, to_date('12-09-2001', 'dd-mm-yyyy'), to_date('26-09-2001', 'dd-mm-yyyy'), 1, 1402, to_date('21-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110921017773, to_date('21-09-2011', 'dd-mm-yyyy'), to_date('05-10-2011', 'dd-mm-yyyy'), 1, 8804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000229017774, to_date('29-02-2000', 'dd-mm-yyyy'), to_date('14-03-2000', 'dd-mm-yyyy'), 2, 1730, to_date('01-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000830017775, to_date('30-08-2000', 'dd-mm-yyyy'), to_date('13-09-2000', 'dd-mm-yyyy'), 2, 1726, to_date('31-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071129017776, to_date('29-11-2007', 'dd-mm-yyyy'), to_date('13-12-2007', 'dd-mm-yyyy'), 2, 6568, to_date('09-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031004017777, to_date('04-10-2003', 'dd-mm-yyyy'), to_date('18-10-2003', 'dd-mm-yyyy'), 1, 3426, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041225017778, to_date('25-12-2004', 'dd-mm-yyyy'), to_date('08-01-2005', 'dd-mm-yyyy'), 1, 3919, to_date('30-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000218017779, to_date('18-02-2000', 'dd-mm-yyyy'), to_date('03-03-2000', 'dd-mm-yyyy'), 1, 2279, to_date('27-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051115017780, to_date('15-11-2005', 'dd-mm-yyyy'), to_date('29-11-2005', 'dd-mm-yyyy'), 1, 2647, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020813017781, to_date('13-08-2002', 'dd-mm-yyyy'), to_date('27-08-2002', 'dd-mm-yyyy'), 1, 3577, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070327017782, to_date('27-03-2007', 'dd-mm-yyyy'), to_date('10-04-2007', 'dd-mm-yyyy'), 2, 7084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101118017783, to_date('18-11-2010', 'dd-mm-yyyy'), to_date('02-12-2010', 'dd-mm-yyyy'), 1, 7311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131215017784, to_date('15-12-2013', 'dd-mm-yyyy'), to_date('29-12-2013', 'dd-mm-yyyy'), 1, 11295, to_date('17-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010130017785, to_date('30-01-2001', 'dd-mm-yyyy'), to_date('13-02-2001', 'dd-mm-yyyy'), 2, 2587, to_date('03-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130619017786, to_date('19-06-2013', 'dd-mm-yyyy'), to_date('03-07-2013', 'dd-mm-yyyy'), 2, 8772, to_date('22-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020508017787, to_date('08-05-2002', 'dd-mm-yyyy'), to_date('22-05-2002', 'dd-mm-yyyy'), 1, 1554, to_date('28-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110524017788, to_date('24-05-2011', 'dd-mm-yyyy'), to_date('07-06-2011', 'dd-mm-yyyy'), 1, 6765, to_date('27-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130331017789, to_date('31-03-2013', 'dd-mm-yyyy'), to_date('14-04-2013', 'dd-mm-yyyy'), 2, 9848, to_date('17-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020611017790, to_date('11-06-2002', 'dd-mm-yyyy'), to_date('25-06-2002', 'dd-mm-yyyy'), 2, 2776, to_date('16-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091105017791, to_date('05-11-2009', 'dd-mm-yyyy'), to_date('19-11-2009', 'dd-mm-yyyy'), 1, 6503, to_date('20-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110708017792, to_date('08-07-2011', 'dd-mm-yyyy'), to_date('22-07-2011', 'dd-mm-yyyy'), 2, 8894, to_date('11-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081213017793, to_date('13-12-2008', 'dd-mm-yyyy'), to_date('27-12-2008', 'dd-mm-yyyy'), 1, 7238, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130115017794, to_date('15-01-2013', 'dd-mm-yyyy'), to_date('29-01-2013', 'dd-mm-yyyy'), 2, 9343, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001021017795, to_date('21-10-2000', 'dd-mm-yyyy'), to_date('04-11-2000', 'dd-mm-yyyy'), 2, 855, to_date('06-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070324017796, to_date('24-03-2007', 'dd-mm-yyyy'), to_date('07-04-2007', 'dd-mm-yyyy'), 1, 3510, to_date('27-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000727017797, to_date('27-07-2000', 'dd-mm-yyyy'), to_date('10-08-2000', 'dd-mm-yyyy'), 1, 2793, to_date('31-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070315017798, to_date('15-03-2007', 'dd-mm-yyyy'), to_date('29-03-2007', 'dd-mm-yyyy'), 2, 3950, to_date('24-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000809017799, to_date('09-08-2000', 'dd-mm-yyyy'), to_date('23-08-2000', 'dd-mm-yyyy'), 2, 2599, to_date('14-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130402017800, to_date('02-04-2013', 'dd-mm-yyyy'), to_date('16-04-2013', 'dd-mm-yyyy'), 1, 9096, to_date('13-04-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020917017801, to_date('17-09-2002', 'dd-mm-yyyy'), to_date('01-10-2002', 'dd-mm-yyyy'), 1, 2101, to_date('04-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060721017802, to_date('21-07-2006', 'dd-mm-yyyy'), to_date('04-08-2006', 'dd-mm-yyyy'), 2, 3983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050218017803, to_date('18-02-2005', 'dd-mm-yyyy'), to_date('04-03-2005', 'dd-mm-yyyy'), 2, 5744, to_date('04-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050729017804, to_date('29-07-2005', 'dd-mm-yyyy'), to_date('12-08-2005', 'dd-mm-yyyy'), 1, 4437, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510017805, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 2, 6965, to_date('18-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000723017806, to_date('23-07-2000', 'dd-mm-yyyy'), to_date('06-08-2000', 'dd-mm-yyyy'), 2, 933, to_date('04-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090517017807, to_date('17-05-2009', 'dd-mm-yyyy'), to_date('31-05-2009', 'dd-mm-yyyy'), 1, 6092, to_date('20-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060519017808, to_date('19-05-2006', 'dd-mm-yyyy'), to_date('02-06-2006', 'dd-mm-yyyy'), 2, 4132, to_date('06-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051017017809, to_date('17-10-2005', 'dd-mm-yyyy'), to_date('31-10-2005', 'dd-mm-yyyy'), 2, 3501, to_date('05-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100930017810, to_date('30-09-2010', 'dd-mm-yyyy'), to_date('14-10-2010', 'dd-mm-yyyy'), 1, 4541, to_date('03-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021129017811, to_date('29-11-2002', 'dd-mm-yyyy'), to_date('13-12-2002', 'dd-mm-yyyy'), 1, 2876, to_date('17-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030919017812, to_date('19-09-2003', 'dd-mm-yyyy'), to_date('03-10-2003', 'dd-mm-yyyy'), 2, 2361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130817017813, to_date('17-08-2013', 'dd-mm-yyyy'), to_date('31-08-2013', 'dd-mm-yyyy'), 2, 8911, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827017814, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 2, 4301, to_date('13-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010205017815, to_date('05-02-2001', 'dd-mm-yyyy'), to_date('19-02-2001', 'dd-mm-yyyy'), 1, 3776, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130625017816, to_date('25-06-2013', 'dd-mm-yyyy'), to_date('09-07-2013', 'dd-mm-yyyy'), 1, 9127, to_date('27-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309017817, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 2, 8793, to_date('26-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100226017818, to_date('26-02-2010', 'dd-mm-yyyy'), to_date('12-03-2010', 'dd-mm-yyyy'), 2, 9323, null);
commit;
prompt 17000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080120017819, to_date('20-01-2008', 'dd-mm-yyyy'), to_date('03-02-2008', 'dd-mm-yyyy'), 1, 4894, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000412017820, to_date('12-04-2000', 'dd-mm-yyyy'), to_date('26-04-2000', 'dd-mm-yyyy'), 1, 1924, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130802017821, to_date('02-08-2013', 'dd-mm-yyyy'), to_date('16-08-2013', 'dd-mm-yyyy'), 2, 8510, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070221017822, to_date('21-02-2007', 'dd-mm-yyyy'), to_date('07-03-2007', 'dd-mm-yyyy'), 1, 4581, to_date('27-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010212017823, to_date('12-02-2001', 'dd-mm-yyyy'), to_date('26-02-2001', 'dd-mm-yyyy'), 2, 2154, to_date('25-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100312017824, to_date('12-03-2010', 'dd-mm-yyyy'), to_date('26-03-2010', 'dd-mm-yyyy'), 1, 5562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090814017825, to_date('14-08-2009', 'dd-mm-yyyy'), to_date('28-08-2009', 'dd-mm-yyyy'), 2, 7930, to_date('17-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010123017826, to_date('23-01-2001', 'dd-mm-yyyy'), to_date('06-02-2001', 'dd-mm-yyyy'), 2, 2146, to_date('04-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030906017827, to_date('06-09-2003', 'dd-mm-yyyy'), to_date('20-09-2003', 'dd-mm-yyyy'), 1, 4029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120217017828, to_date('17-02-2012', 'dd-mm-yyyy'), to_date('02-03-2012', 'dd-mm-yyyy'), 1, 6556, to_date('23-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040220017829, to_date('20-02-2004', 'dd-mm-yyyy'), to_date('05-03-2004', 'dd-mm-yyyy'), 2, 2225, to_date('29-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050405017830, to_date('05-04-2005', 'dd-mm-yyyy'), to_date('19-04-2005', 'dd-mm-yyyy'), 2, 6489, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060402017831, to_date('02-04-2006', 'dd-mm-yyyy'), to_date('16-04-2006', 'dd-mm-yyyy'), 2, 4800, to_date('14-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040928017832, to_date('28-09-2004', 'dd-mm-yyyy'), to_date('12-10-2004', 'dd-mm-yyyy'), 1, 3333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030130017833, to_date('30-01-2003', 'dd-mm-yyyy'), to_date('13-02-2003', 'dd-mm-yyyy'), 2, 4072, to_date('18-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070319017834, to_date('19-03-2007', 'dd-mm-yyyy'), to_date('02-04-2007', 'dd-mm-yyyy'), 1, 2991, to_date('28-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070809017835, to_date('09-08-2007', 'dd-mm-yyyy'), to_date('23-08-2007', 'dd-mm-yyyy'), 2, 5834, to_date('15-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110823017836, to_date('23-08-2011', 'dd-mm-yyyy'), to_date('06-09-2011', 'dd-mm-yyyy'), 1, 6208, to_date('26-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110820017837, to_date('20-08-2011', 'dd-mm-yyyy'), to_date('03-09-2011', 'dd-mm-yyyy'), 1, 6808, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309017838, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 1, 10245, to_date('13-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110829017839, to_date('29-08-2011', 'dd-mm-yyyy'), to_date('12-09-2011', 'dd-mm-yyyy'), 2, 7794, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011111017840, to_date('11-11-2001', 'dd-mm-yyyy'), to_date('25-11-2001', 'dd-mm-yyyy'), 1, 1572, to_date('13-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026017841, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 1, 6125, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001208017842, to_date('08-12-2000', 'dd-mm-yyyy'), to_date('22-12-2000', 'dd-mm-yyyy'), 2, 1938, to_date('27-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050705017843, to_date('05-07-2005', 'dd-mm-yyyy'), to_date('19-07-2005', 'dd-mm-yyyy'), 1, 6576, to_date('18-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040911017844, to_date('11-09-2004', 'dd-mm-yyyy'), to_date('25-09-2004', 'dd-mm-yyyy'), 2, 4158, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110809017845, to_date('09-08-2011', 'dd-mm-yyyy'), to_date('23-08-2011', 'dd-mm-yyyy'), 2, 9358, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050313017846, to_date('13-03-2005', 'dd-mm-yyyy'), to_date('27-03-2005', 'dd-mm-yyyy'), 1, 4483, to_date('15-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414017847, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 2, 8550, to_date('01-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050629017848, to_date('29-06-2005', 'dd-mm-yyyy'), to_date('13-07-2005', 'dd-mm-yyyy'), 2, 4645, to_date('15-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011013017849, to_date('13-10-2001', 'dd-mm-yyyy'), to_date('27-10-2001', 'dd-mm-yyyy'), 2, 2804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030519017850, to_date('19-05-2003', 'dd-mm-yyyy'), to_date('02-06-2003', 'dd-mm-yyyy'), 2, 3178, to_date('27-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110111017851, to_date('11-01-2011', 'dd-mm-yyyy'), to_date('25-01-2011', 'dd-mm-yyyy'), 2, 8181, to_date('20-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101020017852, to_date('20-10-2010', 'dd-mm-yyyy'), to_date('03-11-2010', 'dd-mm-yyyy'), 2, 7355, to_date('30-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011231017853, to_date('31-12-2001', 'dd-mm-yyyy'), to_date('14-01-2002', 'dd-mm-yyyy'), 2, 1722, to_date('09-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110529017854, to_date('29-05-2011', 'dd-mm-yyyy'), to_date('12-06-2011', 'dd-mm-yyyy'), 2, 9488, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000421017855, to_date('21-04-2000', 'dd-mm-yyyy'), to_date('05-05-2000', 'dd-mm-yyyy'), 2, 1668, to_date('30-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120414017856, to_date('14-04-2012', 'dd-mm-yyyy'), to_date('28-04-2012', 'dd-mm-yyyy'), 2, 7556, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130731017857, to_date('31-07-2013', 'dd-mm-yyyy'), to_date('14-08-2013', 'dd-mm-yyyy'), 2, 7777, to_date('12-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130325017858, to_date('25-03-2013', 'dd-mm-yyyy'), to_date('08-04-2013', 'dd-mm-yyyy'), 2, 6868, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140401017859, to_date('01-04-2014', 'dd-mm-yyyy'), to_date('15-04-2014', 'dd-mm-yyyy'), 2, 10723, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071123017860, to_date('23-11-2007', 'dd-mm-yyyy'), to_date('07-12-2007', 'dd-mm-yyyy'), 1, 5689, to_date('26-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080405017861, to_date('05-04-2008', 'dd-mm-yyyy'), to_date('19-04-2008', 'dd-mm-yyyy'), 2, 6069, to_date('25-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080818017862, to_date('18-08-2008', 'dd-mm-yyyy'), to_date('01-09-2008', 'dd-mm-yyyy'), 1, 7704, to_date('20-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080516017863, to_date('16-05-2008', 'dd-mm-yyyy'), to_date('30-05-2008', 'dd-mm-yyyy'), 2, 5935, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020217017864, to_date('17-02-2002', 'dd-mm-yyyy'), to_date('03-03-2002', 'dd-mm-yyyy'), 1, 2701, to_date('25-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020218017865, to_date('18-02-2002', 'dd-mm-yyyy'), to_date('04-03-2002', 'dd-mm-yyyy'), 1, 3051, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050315017866, to_date('15-03-2005', 'dd-mm-yyyy'), to_date('29-03-2005', 'dd-mm-yyyy'), 2, 3882, to_date('30-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040907017867, to_date('07-09-2004', 'dd-mm-yyyy'), to_date('21-09-2004', 'dd-mm-yyyy'), 2, 4245, to_date('11-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070818017868, to_date('18-08-2007', 'dd-mm-yyyy'), to_date('01-09-2007', 'dd-mm-yyyy'), 2, 3902, to_date('05-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130616017869, to_date('16-06-2013', 'dd-mm-yyyy'), to_date('30-06-2013', 'dd-mm-yyyy'), 2, 6608, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040725017870, to_date('25-07-2004', 'dd-mm-yyyy'), to_date('08-08-2004', 'dd-mm-yyyy'), 2, 5181, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020113017871, to_date('13-01-2002', 'dd-mm-yyyy'), to_date('27-01-2002', 'dd-mm-yyyy'), 2, 4083, to_date('16-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080325017872, to_date('25-03-2008', 'dd-mm-yyyy'), to_date('08-04-2008', 'dd-mm-yyyy'), 1, 6340, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130419017873, to_date('19-04-2013', 'dd-mm-yyyy'), to_date('03-05-2013', 'dd-mm-yyyy'), 1, 8559, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100711017874, to_date('11-07-2010', 'dd-mm-yyyy'), to_date('25-07-2010', 'dd-mm-yyyy'), 1, 6206, to_date('27-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030327017875, to_date('27-03-2003', 'dd-mm-yyyy'), to_date('10-04-2003', 'dd-mm-yyyy'), 1, 3175, to_date('02-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080201017876, to_date('01-02-2008', 'dd-mm-yyyy'), to_date('15-02-2008', 'dd-mm-yyyy'), 2, 6733, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050623017877, to_date('23-06-2005', 'dd-mm-yyyy'), to_date('07-07-2005', 'dd-mm-yyyy'), 2, 4437, to_date('28-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020114017878, to_date('14-01-2002', 'dd-mm-yyyy'), to_date('28-01-2002', 'dd-mm-yyyy'), 2, 3686, to_date('31-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010408017879, to_date('08-04-2001', 'dd-mm-yyyy'), to_date('22-04-2001', 'dd-mm-yyyy'), 2, 2764, to_date('10-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020525017880, to_date('25-05-2002', 'dd-mm-yyyy'), to_date('08-06-2002', 'dd-mm-yyyy'), 2, 2190, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020924017881, to_date('24-09-2002', 'dd-mm-yyyy'), to_date('08-10-2002', 'dd-mm-yyyy'), 1, 3923, to_date('27-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040609017882, to_date('09-06-2004', 'dd-mm-yyyy'), to_date('23-06-2004', 'dd-mm-yyyy'), 1, 3241, to_date('19-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040727017883, to_date('27-07-2004', 'dd-mm-yyyy'), to_date('10-08-2004', 'dd-mm-yyyy'), 2, 4180, to_date('16-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060713017884, to_date('13-07-2006', 'dd-mm-yyyy'), to_date('27-07-2006', 'dd-mm-yyyy'), 1, 1774, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309017885, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 1, 5774, to_date('25-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030318017886, to_date('18-03-2003', 'dd-mm-yyyy'), to_date('01-04-2003', 'dd-mm-yyyy'), 2, 3144, to_date('31-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090501017887, to_date('01-05-2009', 'dd-mm-yyyy'), to_date('15-05-2009', 'dd-mm-yyyy'), 1, 7687, to_date('10-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110315017888, to_date('15-03-2011', 'dd-mm-yyyy'), to_date('29-03-2011', 'dd-mm-yyyy'), 1, 8027, to_date('27-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070515017889, to_date('15-05-2007', 'dd-mm-yyyy'), to_date('29-05-2007', 'dd-mm-yyyy'), 2, 6468, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041114017890, to_date('14-11-2004', 'dd-mm-yyyy'), to_date('28-11-2004', 'dd-mm-yyyy'), 2, 2502, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110305017891, to_date('05-03-2011', 'dd-mm-yyyy'), to_date('19-03-2011', 'dd-mm-yyyy'), 2, 7877, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080826017892, to_date('26-08-2008', 'dd-mm-yyyy'), to_date('09-09-2008', 'dd-mm-yyyy'), 1, 6087, to_date('09-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030522017893, to_date('22-05-2003', 'dd-mm-yyyy'), to_date('05-06-2003', 'dd-mm-yyyy'), 2, 3176, to_date('30-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111019017894, to_date('19-10-2011', 'dd-mm-yyyy'), to_date('02-11-2011', 'dd-mm-yyyy'), 1, 6966, to_date('07-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110104017895, to_date('04-01-2011', 'dd-mm-yyyy'), to_date('18-01-2011', 'dd-mm-yyyy'), 2, 9153, to_date('18-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120307017896, to_date('07-03-2012', 'dd-mm-yyyy'), to_date('21-03-2012', 'dd-mm-yyyy'), 2, 9657, to_date('20-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070806017897, to_date('06-08-2007', 'dd-mm-yyyy'), to_date('20-08-2007', 'dd-mm-yyyy'), 1, 6493, to_date('26-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101125017898, to_date('25-11-2010', 'dd-mm-yyyy'), to_date('09-12-2010', 'dd-mm-yyyy'), 2, 7647, to_date('14-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060806017899, to_date('06-08-2006', 'dd-mm-yyyy'), to_date('20-08-2006', 'dd-mm-yyyy'), 2, 2963, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070207017900, to_date('07-02-2007', 'dd-mm-yyyy'), to_date('21-02-2007', 'dd-mm-yyyy'), 2, 4913, to_date('18-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060120017901, to_date('20-01-2006', 'dd-mm-yyyy'), to_date('03-02-2006', 'dd-mm-yyyy'), 2, 4152, to_date('01-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051219017902, to_date('19-12-2005', 'dd-mm-yyyy'), to_date('02-01-2006', 'dd-mm-yyyy'), 2, 4104, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041222017903, to_date('22-12-2004', 'dd-mm-yyyy'), to_date('05-01-2005', 'dd-mm-yyyy'), 1, 4796, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020804017904, to_date('04-08-2002', 'dd-mm-yyyy'), to_date('18-08-2002', 'dd-mm-yyyy'), 1, 2216, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060102017905, to_date('02-01-2006', 'dd-mm-yyyy'), to_date('16-01-2006', 'dd-mm-yyyy'), 2, 4929, to_date('10-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010921017906, to_date('21-09-2001', 'dd-mm-yyyy'), to_date('05-10-2001', 'dd-mm-yyyy'), 1, 2328, to_date('30-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050928017907, to_date('28-09-2005', 'dd-mm-yyyy'), to_date('12-10-2005', 'dd-mm-yyyy'), 2, 3009, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071130017908, to_date('30-11-2007', 'dd-mm-yyyy'), to_date('14-12-2007', 'dd-mm-yyyy'), 2, 4078, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050813017909, to_date('13-08-2005', 'dd-mm-yyyy'), to_date('27-08-2005', 'dd-mm-yyyy'), 1, 6924, to_date('23-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040710017910, to_date('10-07-2004', 'dd-mm-yyyy'), to_date('24-07-2004', 'dd-mm-yyyy'), 2, 6626, to_date('29-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000216017911, to_date('16-02-2000', 'dd-mm-yyyy'), to_date('01-03-2000', 'dd-mm-yyyy'), 2, 3101, to_date('01-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419017912, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 1, 2806, to_date('03-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080131017913, to_date('31-01-2008', 'dd-mm-yyyy'), to_date('14-02-2008', 'dd-mm-yyyy'), 2, 5618, to_date('11-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021129017914, to_date('29-11-2002', 'dd-mm-yyyy'), to_date('13-12-2002', 'dd-mm-yyyy'), 1, 4109, to_date('11-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110703017915, to_date('03-07-2011', 'dd-mm-yyyy'), to_date('17-07-2011', 'dd-mm-yyyy'), 2, 6974, to_date('15-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021023017916, to_date('23-10-2002', 'dd-mm-yyyy'), to_date('06-11-2002', 'dd-mm-yyyy'), 2, 3040, to_date('07-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020731017917, to_date('31-07-2002', 'dd-mm-yyyy'), to_date('14-08-2002', 'dd-mm-yyyy'), 1, 4594, to_date('06-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050515017918, to_date('15-05-2005', 'dd-mm-yyyy'), to_date('29-05-2005', 'dd-mm-yyyy'), 1, 2373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041210009794, to_date('10-12-2004', 'dd-mm-yyyy'), to_date('24-12-2004', 'dd-mm-yyyy'), 6, 2875, to_date('19-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030421009795, to_date('21-04-2003', 'dd-mm-yyyy'), to_date('05-05-2003', 'dd-mm-yyyy'), 3, 2255, to_date('01-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021114009796, to_date('14-11-2002', 'dd-mm-yyyy'), to_date('28-11-2002', 'dd-mm-yyyy'), 8, 378, to_date('03-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000502009797, to_date('02-05-2000', 'dd-mm-yyyy'), to_date('16-05-2000', 'dd-mm-yyyy'), 2, 1804, to_date('06-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070409009798, to_date('09-04-2007', 'dd-mm-yyyy'), to_date('23-04-2007', 'dd-mm-yyyy'), 7, 3159, to_date('16-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021221009799, to_date('21-12-2002', 'dd-mm-yyyy'), to_date('04-01-2003', 'dd-mm-yyyy'), 9, 2205, to_date('25-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060714009800, to_date('14-07-2006', 'dd-mm-yyyy'), to_date('28-07-2006', 'dd-mm-yyyy'), 4, 5037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130624009801, to_date('24-06-2013', 'dd-mm-yyyy'), to_date('08-07-2013', 'dd-mm-yyyy'), 5, 10771, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060630009802, to_date('30-06-2006', 'dd-mm-yyyy'), to_date('14-07-2006', 'dd-mm-yyyy'), 1, 4827, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051221009803, to_date('21-12-2005', 'dd-mm-yyyy'), to_date('04-01-2006', 'dd-mm-yyyy'), 7, 5833, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110426009804, to_date('26-04-2011', 'dd-mm-yyyy'), to_date('10-05-2011', 'dd-mm-yyyy'), 4, 4664, to_date('03-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011111009805, to_date('11-11-2001', 'dd-mm-yyyy'), to_date('25-11-2001', 'dd-mm-yyyy'), 1, 1046, to_date('16-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010724009806, to_date('24-07-2001', 'dd-mm-yyyy'), to_date('07-08-2001', 'dd-mm-yyyy'), 7, 2212, to_date('26-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010830009807, to_date('30-08-2001', 'dd-mm-yyyy'), to_date('13-09-2001', 'dd-mm-yyyy'), 6, 2753, to_date('19-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040811009808, to_date('11-08-2004', 'dd-mm-yyyy'), to_date('25-08-2004', 'dd-mm-yyyy'), 8, 5055, to_date('24-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130009809, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 3, 4254, to_date('16-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001026009810, to_date('26-10-2000', 'dd-mm-yyyy'), to_date('09-11-2000', 'dd-mm-yyyy'), 3, 1448, to_date('09-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100222009811, to_date('22-02-2010', 'dd-mm-yyyy'), to_date('08-03-2010', 'dd-mm-yyyy'), 10, 5555, to_date('28-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060604009812, to_date('04-06-2006', 'dd-mm-yyyy'), to_date('18-06-2006', 'dd-mm-yyyy'), 9, 3878, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120203009813, to_date('03-02-2012', 'dd-mm-yyyy'), to_date('17-02-2012', 'dd-mm-yyyy'), 9, 10146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080917009814, to_date('17-09-2008', 'dd-mm-yyyy'), to_date('01-10-2008', 'dd-mm-yyyy'), 8, 5283, to_date('27-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022009815, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 9, 4087, to_date('29-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050915009816, to_date('15-09-2005', 'dd-mm-yyyy'), to_date('29-09-2005', 'dd-mm-yyyy'), 7, 2837, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070313009817, to_date('13-03-2007', 'dd-mm-yyyy'), to_date('27-03-2007', 'dd-mm-yyyy'), 6, 7483, to_date('17-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110925009818, to_date('25-09-2011', 'dd-mm-yyyy'), to_date('09-10-2011', 'dd-mm-yyyy'), 2, 7249, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050720009819, to_date('20-07-2005', 'dd-mm-yyyy'), to_date('03-08-2005', 'dd-mm-yyyy'), 6, 6352, to_date('31-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010301009820, to_date('01-03-2001', 'dd-mm-yyyy'), to_date('15-03-2001', 'dd-mm-yyyy'), 5, 2020, to_date('09-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071104009821, to_date('04-11-2007', 'dd-mm-yyyy'), to_date('18-11-2007', 'dd-mm-yyyy'), 11, 4670, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130729009822, to_date('29-07-2013', 'dd-mm-yyyy'), to_date('12-08-2013', 'dd-mm-yyyy'), 3, 6936, to_date('09-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031120009823, to_date('20-11-2003', 'dd-mm-yyyy'), to_date('04-12-2003', 'dd-mm-yyyy'), 12, 5237, to_date('04-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000826009824, to_date('26-08-2000', 'dd-mm-yyyy'), to_date('09-09-2000', 'dd-mm-yyyy'), 6, 1222, to_date('10-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040131009825, to_date('31-01-2004', 'dd-mm-yyyy'), to_date('14-02-2004', 'dd-mm-yyyy'), 2, 4519, to_date('05-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071023009826, to_date('23-10-2007', 'dd-mm-yyyy'), to_date('06-11-2007', 'dd-mm-yyyy'), 1, 6204, to_date('31-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060808009827, to_date('08-08-2006', 'dd-mm-yyyy'), to_date('22-08-2006', 'dd-mm-yyyy'), 2, 5071, to_date('13-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110824009828, to_date('24-08-2011', 'dd-mm-yyyy'), to_date('07-09-2011', 'dd-mm-yyyy'), 9, 9765, to_date('28-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050418009829, to_date('18-04-2005', 'dd-mm-yyyy'), to_date('02-05-2005', 'dd-mm-yyyy'), 11, 4781, to_date('25-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071211009830, to_date('11-12-2007', 'dd-mm-yyyy'), to_date('25-12-2007', 'dd-mm-yyyy'), 8, 5290, to_date('24-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030411009831, to_date('11-04-2003', 'dd-mm-yyyy'), to_date('25-04-2003', 'dd-mm-yyyy'), 3, 4392, to_date('25-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060315009832, to_date('15-03-2006', 'dd-mm-yyyy'), to_date('29-03-2006', 'dd-mm-yyyy'), 10, 4219, to_date('22-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070107009833, to_date('07-01-2007', 'dd-mm-yyyy'), to_date('21-01-2007', 'dd-mm-yyyy'), 9, 8076, to_date('20-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090419009834, to_date('19-04-2009', 'dd-mm-yyyy'), to_date('03-05-2009', 'dd-mm-yyyy'), 8, 6731, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070324009835, to_date('24-03-2007', 'dd-mm-yyyy'), to_date('07-04-2007', 'dd-mm-yyyy'), 9, 6242, to_date('02-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505009836, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 11, 7011, to_date('11-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080202009837, to_date('02-02-2008', 'dd-mm-yyyy'), to_date('16-02-2008', 'dd-mm-yyyy'), 6, 9681, to_date('04-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110714009838, to_date('14-07-2011', 'dd-mm-yyyy'), to_date('28-07-2011', 'dd-mm-yyyy'), 7, 9537, to_date('24-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091228009839, to_date('28-12-2009', 'dd-mm-yyyy'), to_date('11-01-2010', 'dd-mm-yyyy'), 8, 6382, to_date('08-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080104009840, to_date('04-01-2008', 'dd-mm-yyyy'), to_date('18-01-2008', 'dd-mm-yyyy'), 8, 7122, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010804009841, to_date('04-08-2001', 'dd-mm-yyyy'), to_date('18-08-2001', 'dd-mm-yyyy'), 7, 2553, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130410009842, to_date('10-04-2013', 'dd-mm-yyyy'), to_date('24-04-2013', 'dd-mm-yyyy'), 6, 7333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090510009843, to_date('10-05-2009', 'dd-mm-yyyy'), to_date('24-05-2009', 'dd-mm-yyyy'), 8, 7038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070305009844, to_date('05-03-2007', 'dd-mm-yyyy'), to_date('19-03-2007', 'dd-mm-yyyy'), 5, 7992, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061111009845, to_date('11-11-2006', 'dd-mm-yyyy'), to_date('25-11-2006', 'dd-mm-yyyy'), 10, 5680, to_date('19-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100113009846, to_date('13-01-2010', 'dd-mm-yyyy'), to_date('27-01-2010', 'dd-mm-yyyy'), 8, 5365, to_date('23-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414009847, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 8, 10287, to_date('19-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070528009848, to_date('28-05-2007', 'dd-mm-yyyy'), to_date('11-06-2007', 'dd-mm-yyyy'), 3, 5344, to_date('11-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050224009849, to_date('24-02-2005', 'dd-mm-yyyy'), to_date('10-03-2005', 'dd-mm-yyyy'), 2, 4451, to_date('13-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021207009850, to_date('07-12-2002', 'dd-mm-yyyy'), to_date('21-12-2002', 'dd-mm-yyyy'), 6, 2036, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120525009851, to_date('25-05-2012', 'dd-mm-yyyy'), to_date('08-06-2012', 'dd-mm-yyyy'), 5, 9130, to_date('11-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080609009852, to_date('09-06-2008', 'dd-mm-yyyy'), to_date('23-06-2008', 'dd-mm-yyyy'), 5, 6995, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031205009853, to_date('05-12-2003', 'dd-mm-yyyy'), to_date('19-12-2003', 'dd-mm-yyyy'), 9, 5022, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000628009854, to_date('28-06-2000', 'dd-mm-yyyy'), to_date('12-07-2000', 'dd-mm-yyyy'), 9, 1202, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031031009855, to_date('31-10-2003', 'dd-mm-yyyy'), to_date('14-11-2003', 'dd-mm-yyyy'), 1, 2901, to_date('03-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513009856, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 5, 3817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020501009857, to_date('01-05-2002', 'dd-mm-yyyy'), to_date('15-05-2002', 'dd-mm-yyyy'), 4, 1792, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110202009858, to_date('02-02-2011', 'dd-mm-yyyy'), to_date('16-02-2011', 'dd-mm-yyyy'), 8, 6866, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100624009859, to_date('24-06-2010', 'dd-mm-yyyy'), to_date('08-07-2010', 'dd-mm-yyyy'), 9, 8405, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021230009860, to_date('30-12-2002', 'dd-mm-yyyy'), to_date('13-01-2003', 'dd-mm-yyyy'), 8, 2746, to_date('04-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060208009861, to_date('08-02-2006', 'dd-mm-yyyy'), to_date('22-02-2006', 'dd-mm-yyyy'), 2, 4810, to_date('11-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100118009862, to_date('18-01-2010', 'dd-mm-yyyy'), to_date('01-02-2010', 'dd-mm-yyyy'), 7, 6233, to_date('21-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000726009863, to_date('26-07-2000', 'dd-mm-yyyy'), to_date('09-08-2000', 'dd-mm-yyyy'), 2, 3179, to_date('31-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030730009864, to_date('30-07-2003', 'dd-mm-yyyy'), to_date('13-08-2003', 'dd-mm-yyyy'), 7, 2512, to_date('17-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020517009865, to_date('17-05-2002', 'dd-mm-yyyy'), to_date('31-05-2002', 'dd-mm-yyyy'), 5, 3609, to_date('31-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120928009866, to_date('28-09-2012', 'dd-mm-yyyy'), to_date('12-10-2012', 'dd-mm-yyyy'), 9, 9604, to_date('30-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070314009867, to_date('14-03-2007', 'dd-mm-yyyy'), to_date('28-03-2007', 'dd-mm-yyyy'), 3, 3087, to_date('19-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121121009868, to_date('21-11-2012', 'dd-mm-yyyy'), to_date('05-12-2012', 'dd-mm-yyyy'), 10, 9318, to_date('27-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010527009869, to_date('27-05-2001', 'dd-mm-yyyy'), to_date('10-06-2001', 'dd-mm-yyyy'), 2, 1925, to_date('29-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111129009870, to_date('29-11-2011', 'dd-mm-yyyy'), to_date('13-12-2011', 'dd-mm-yyyy'), 9, 8210, to_date('01-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040524009871, to_date('24-05-2004', 'dd-mm-yyyy'), to_date('07-06-2004', 'dd-mm-yyyy'), 9, 3388, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020213009872, to_date('13-02-2002', 'dd-mm-yyyy'), to_date('27-02-2002', 'dd-mm-yyyy'), 9, 3251, to_date('28-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081108009873, to_date('08-11-2008', 'dd-mm-yyyy'), to_date('22-11-2008', 'dd-mm-yyyy'), 7, 6416, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131106009874, to_date('06-11-2013', 'dd-mm-yyyy'), to_date('20-11-2013', 'dd-mm-yyyy'), 9, 9183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050517009875, to_date('17-05-2005', 'dd-mm-yyyy'), to_date('31-05-2005', 'dd-mm-yyyy'), 10, 3882, to_date('03-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605009876, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 9, 1928, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020426009877, to_date('26-04-2002', 'dd-mm-yyyy'), to_date('10-05-2002', 'dd-mm-yyyy'), 4, 2042, to_date('12-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051209009878, to_date('09-12-2005', 'dd-mm-yyyy'), to_date('23-12-2005', 'dd-mm-yyyy'), 9, 4836, to_date('28-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090825009879, to_date('25-08-2009', 'dd-mm-yyyy'), to_date('08-09-2009', 'dd-mm-yyyy'), 11, 7370, to_date('05-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020120009880, to_date('20-01-2002', 'dd-mm-yyyy'), to_date('03-02-2002', 'dd-mm-yyyy'), 11, 2506, to_date('05-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130120009881, to_date('20-01-2013', 'dd-mm-yyyy'), to_date('03-02-2013', 'dd-mm-yyyy'), 1, 5717, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031115009882, to_date('15-11-2003', 'dd-mm-yyyy'), to_date('29-11-2003', 'dd-mm-yyyy'), 5, 3462, to_date('03-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041217009883, to_date('17-12-2004', 'dd-mm-yyyy'), to_date('31-12-2004', 'dd-mm-yyyy'), 5, 3391, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050102009884, to_date('02-01-2005', 'dd-mm-yyyy'), to_date('16-01-2005', 'dd-mm-yyyy'), 9, 4348, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030516009885, to_date('16-05-2003', 'dd-mm-yyyy'), to_date('30-05-2003', 'dd-mm-yyyy'), 6, 4003, to_date('22-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815009886, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 11, 4440, to_date('21-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060318009887, to_date('18-03-2006', 'dd-mm-yyyy'), to_date('01-04-2006', 'dd-mm-yyyy'), 7, 5150, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021017009888, to_date('17-10-2002', 'dd-mm-yyyy'), to_date('31-10-2002', 'dd-mm-yyyy'), 9, 3538, to_date('29-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030922009889, to_date('22-09-2003', 'dd-mm-yyyy'), to_date('06-10-2003', 'dd-mm-yyyy'), 5, 4704, to_date('24-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100830009890, to_date('30-08-2010', 'dd-mm-yyyy'), to_date('13-09-2010', 'dd-mm-yyyy'), 5, 5329, to_date('17-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080521009891, to_date('21-05-2008', 'dd-mm-yyyy'), to_date('04-06-2008', 'dd-mm-yyyy'), 10, 4028, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070203009892, to_date('03-02-2007', 'dd-mm-yyyy'), to_date('17-02-2007', 'dd-mm-yyyy'), 6, 6403, to_date('16-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010515009893, to_date('15-05-2001', 'dd-mm-yyyy'), to_date('29-05-2001', 'dd-mm-yyyy'), 2, 1018, to_date('29-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010507009894, to_date('07-05-2001', 'dd-mm-yyyy'), to_date('21-05-2001', 'dd-mm-yyyy'), 8, 2036, to_date('15-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140304009895, to_date('04-03-2014', 'dd-mm-yyyy'), to_date('18-03-2014', 'dd-mm-yyyy'), 6, 7691, to_date('19-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071110009896, to_date('10-11-2007', 'dd-mm-yyyy'), to_date('24-11-2007', 'dd-mm-yyyy'), 3, 5327, to_date('13-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060927009897, to_date('27-09-2006', 'dd-mm-yyyy'), to_date('11-10-2006', 'dd-mm-yyyy'), 8, 4719, to_date('17-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071022009898, to_date('22-10-2007', 'dd-mm-yyyy'), to_date('05-11-2007', 'dd-mm-yyyy'), 7, 4852, to_date('30-10-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070915009899, to_date('15-09-2007', 'dd-mm-yyyy'), to_date('29-09-2007', 'dd-mm-yyyy'), 4, 3986, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131029009900, to_date('29-10-2013', 'dd-mm-yyyy'), to_date('12-11-2013', 'dd-mm-yyyy'), 9, 6607, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000110009901, to_date('10-01-2000', 'dd-mm-yyyy'), to_date('24-01-2000', 'dd-mm-yyyy'), 9, 2827, to_date('22-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120503009902, to_date('03-05-2012', 'dd-mm-yyyy'), to_date('17-05-2012', 'dd-mm-yyyy'), 3, 8284, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070324009903, to_date('24-03-2007', 'dd-mm-yyyy'), to_date('07-04-2007', 'dd-mm-yyyy'), 5, 5458, to_date('02-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040901009904, to_date('01-09-2004', 'dd-mm-yyyy'), to_date('15-09-2004', 'dd-mm-yyyy'), 7, 2283, to_date('12-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001220009905, to_date('20-12-2000', 'dd-mm-yyyy'), to_date('03-01-2001', 'dd-mm-yyyy'), 4, 1931, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121111009906, to_date('11-11-2012', 'dd-mm-yyyy'), to_date('25-11-2012', 'dd-mm-yyyy'), 7, 4833, to_date('26-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020323009907, to_date('23-03-2002', 'dd-mm-yyyy'), to_date('06-04-2002', 'dd-mm-yyyy'), 8, 2586, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090209009908, to_date('09-02-2009', 'dd-mm-yyyy'), to_date('23-02-2009', 'dd-mm-yyyy'), 12, 6580, to_date('11-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100109009909, to_date('09-01-2010', 'dd-mm-yyyy'), to_date('23-01-2010', 'dd-mm-yyyy'), 1, 8469, to_date('17-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060818009910, to_date('18-08-2006', 'dd-mm-yyyy'), to_date('01-09-2006', 'dd-mm-yyyy'), 10, 6203, to_date('28-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130309009911, to_date('09-03-2013', 'dd-mm-yyyy'), to_date('23-03-2013', 'dd-mm-yyyy'), 4, 8155, to_date('16-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010303009912, to_date('03-03-2001', 'dd-mm-yyyy'), to_date('17-03-2001', 'dd-mm-yyyy'), 4, 3801, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120321009913, to_date('21-03-2012', 'dd-mm-yyyy'), to_date('04-04-2012', 'dd-mm-yyyy'), 1, 8870, to_date('05-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050223009914, to_date('23-02-2005', 'dd-mm-yyyy'), to_date('09-03-2005', 'dd-mm-yyyy'), 2, 4592, to_date('09-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070717009915, to_date('17-07-2007', 'dd-mm-yyyy'), to_date('31-07-2007', 'dd-mm-yyyy'), 2, 10027, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220009916, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 5, 9099, to_date('03-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050408009917, to_date('08-04-2005', 'dd-mm-yyyy'), to_date('22-04-2005', 'dd-mm-yyyy'), 2, 5794, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111106009918, to_date('06-11-2011', 'dd-mm-yyyy'), to_date('20-11-2011', 'dd-mm-yyyy'), 11, 10565, to_date('16-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111208009919, to_date('08-12-2011', 'dd-mm-yyyy'), to_date('22-12-2011', 'dd-mm-yyyy'), 12, 10441, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100125009920, to_date('25-01-2010', 'dd-mm-yyyy'), to_date('08-02-2010', 'dd-mm-yyyy'), 11, 6619, to_date('05-02-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621009921, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 4, 5664, to_date('27-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040810009922, to_date('10-08-2004', 'dd-mm-yyyy'), to_date('24-08-2004', 'dd-mm-yyyy'), 6, 5594, to_date('15-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070802009923, to_date('02-08-2007', 'dd-mm-yyyy'), to_date('16-08-2007', 'dd-mm-yyyy'), 7, 9403, to_date('04-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130805009924, to_date('05-08-2013', 'dd-mm-yyyy'), to_date('19-08-2013', 'dd-mm-yyyy'), 7, 8860, to_date('18-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030505009925, to_date('05-05-2003', 'dd-mm-yyyy'), to_date('19-05-2003', 'dd-mm-yyyy'), 5, 3341, to_date('10-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100601009926, to_date('01-06-2010', 'dd-mm-yyyy'), to_date('15-06-2010', 'dd-mm-yyyy'), 9, 6947, to_date('02-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130901009927, to_date('01-09-2013', 'dd-mm-yyyy'), to_date('15-09-2013', 'dd-mm-yyyy'), 6, 6409, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060101009928, to_date('01-01-2006', 'dd-mm-yyyy'), to_date('15-01-2006', 'dd-mm-yyyy'), 7, 5423, to_date('06-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130625009929, to_date('25-06-2013', 'dd-mm-yyyy'), to_date('09-07-2013', 'dd-mm-yyyy'), 9, 10474, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040717009930, to_date('17-07-2004', 'dd-mm-yyyy'), to_date('31-07-2004', 'dd-mm-yyyy'), 10, 5288, to_date('24-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120307009931, to_date('07-03-2012', 'dd-mm-yyyy'), to_date('21-03-2012', 'dd-mm-yyyy'), 10, 9666, to_date('10-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060509009932, to_date('09-05-2006', 'dd-mm-yyyy'), to_date('23-05-2006', 'dd-mm-yyyy'), 10, 5165, to_date('26-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120510009933, to_date('10-05-2012', 'dd-mm-yyyy'), to_date('24-05-2012', 'dd-mm-yyyy'), 10, 6582, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120427009934, to_date('27-04-2012', 'dd-mm-yyyy'), to_date('11-05-2012', 'dd-mm-yyyy'), 4, 10264, to_date('07-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090825009935, to_date('25-08-2009', 'dd-mm-yyyy'), to_date('08-09-2009', 'dd-mm-yyyy'), 9, 6486, to_date('27-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030306009936, to_date('06-03-2003', 'dd-mm-yyyy'), to_date('20-03-2003', 'dd-mm-yyyy'), 10, 2826, to_date('22-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120421009937, to_date('21-04-2012', 'dd-mm-yyyy'), to_date('05-05-2012', 'dd-mm-yyyy'), 2, 8657, to_date('07-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110228009938, to_date('28-02-2011', 'dd-mm-yyyy'), to_date('14-03-2011', 'dd-mm-yyyy'), 10, 8699, to_date('11-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091211009939, to_date('11-12-2009', 'dd-mm-yyyy'), to_date('25-12-2009', 'dd-mm-yyyy'), 1, 6886, to_date('13-12-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081018009940, to_date('18-10-2008', 'dd-mm-yyyy'), to_date('01-11-2008', 'dd-mm-yyyy'), 9, 5873, to_date('03-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030106009941, to_date('06-01-2003', 'dd-mm-yyyy'), to_date('20-01-2003', 'dd-mm-yyyy'), 4, 4092, to_date('20-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040112009942, to_date('12-01-2004', 'dd-mm-yyyy'), to_date('26-01-2004', 'dd-mm-yyyy'), 2, 5684, to_date('20-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010211009943, to_date('11-02-2001', 'dd-mm-yyyy'), to_date('25-02-2001', 'dd-mm-yyyy'), 11, 1843, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120210009944, to_date('10-02-2012', 'dd-mm-yyyy'), to_date('24-02-2012', 'dd-mm-yyyy'), 7, 6532, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131028009945, to_date('28-10-2013', 'dd-mm-yyyy'), to_date('11-11-2013', 'dd-mm-yyyy'), 2, 8605, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061020009946, to_date('20-10-2006', 'dd-mm-yyyy'), to_date('03-11-2006', 'dd-mm-yyyy'), 7, 4408, to_date('27-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090830009947, to_date('30-08-2009', 'dd-mm-yyyy'), to_date('13-09-2009', 'dd-mm-yyyy'), 3, 8048, to_date('11-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030131009948, to_date('31-01-2003', 'dd-mm-yyyy'), to_date('14-02-2003', 'dd-mm-yyyy'), 6, 2646, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030408012354, to_date('08-04-2003', 'dd-mm-yyyy'), to_date('22-04-2003', 'dd-mm-yyyy'), 2, 3718, to_date('10-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050502012355, to_date('02-05-2005', 'dd-mm-yyyy'), to_date('16-05-2005', 'dd-mm-yyyy'), 4, 4288, to_date('08-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031010012356, to_date('10-10-2003', 'dd-mm-yyyy'), to_date('24-10-2003', 'dd-mm-yyyy'), 3, 3108, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010401012357, to_date('01-04-2001', 'dd-mm-yyyy'), to_date('15-04-2001', 'dd-mm-yyyy'), 1, 2127, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060517012358, to_date('17-05-2006', 'dd-mm-yyyy'), to_date('31-05-2006', 'dd-mm-yyyy'), 1, 4726, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110928012359, to_date('28-09-2011', 'dd-mm-yyyy'), to_date('12-10-2011', 'dd-mm-yyyy'), 4, 9445, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712012360, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 3, 1255, to_date('22-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227012361, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 2, 1114, to_date('19-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000712012362, to_date('12-07-2000', 'dd-mm-yyyy'), to_date('26-07-2000', 'dd-mm-yyyy'), 4, 205, to_date('27-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020204012363, to_date('04-02-2002', 'dd-mm-yyyy'), to_date('18-02-2002', 'dd-mm-yyyy'), 3, 3642, to_date('24-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091018012364, to_date('18-10-2009', 'dd-mm-yyyy'), to_date('01-11-2009', 'dd-mm-yyyy'), 4, 7401, to_date('30-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110729012365, to_date('29-07-2011', 'dd-mm-yyyy'), to_date('12-08-2011', 'dd-mm-yyyy'), 3, 6888, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071031012366, to_date('31-10-2007', 'dd-mm-yyyy'), to_date('14-11-2007', 'dd-mm-yyyy'), 1, 5992, to_date('13-11-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060124012367, to_date('24-01-2006', 'dd-mm-yyyy'), to_date('07-02-2006', 'dd-mm-yyyy'), 2, 5057, to_date('05-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080817012368, to_date('17-08-2008', 'dd-mm-yyyy'), to_date('31-08-2008', 'dd-mm-yyyy'), 4, 3704, to_date('27-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000121012369, to_date('21-01-2000', 'dd-mm-yyyy'), to_date('04-02-2000', 'dd-mm-yyyy'), 4, 686, to_date('25-01-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040820012370, to_date('20-08-2004', 'dd-mm-yyyy'), to_date('03-09-2004', 'dd-mm-yyyy'), 4, 3007, to_date('09-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100508012371, to_date('08-05-2010', 'dd-mm-yyyy'), to_date('22-05-2010', 'dd-mm-yyyy'), 2, 5633, to_date('09-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100716012372, to_date('16-07-2010', 'dd-mm-yyyy'), to_date('30-07-2010', 'dd-mm-yyyy'), 2, 6240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040613012373, to_date('13-06-2004', 'dd-mm-yyyy'), to_date('27-06-2004', 'dd-mm-yyyy'), 4, 4748, to_date('24-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070814012374, to_date('14-08-2007', 'dd-mm-yyyy'), to_date('28-08-2007', 'dd-mm-yyyy'), 2, 6976, to_date('18-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060515012375, to_date('15-05-2006', 'dd-mm-yyyy'), to_date('29-05-2006', 'dd-mm-yyyy'), 3, 5527, to_date('29-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050606012376, to_date('06-06-2005', 'dd-mm-yyyy'), to_date('20-06-2005', 'dd-mm-yyyy'), 1, 4296, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040406012377, to_date('06-04-2004', 'dd-mm-yyyy'), to_date('20-04-2004', 'dd-mm-yyyy'), 1, 3705, to_date('08-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080910012378, to_date('10-09-2008', 'dd-mm-yyyy'), to_date('24-09-2008', 'dd-mm-yyyy'), 3, 5610, to_date('14-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041014012379, to_date('14-10-2004', 'dd-mm-yyyy'), to_date('28-10-2004', 'dd-mm-yyyy'), 1, 4217, to_date('19-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000923012380, to_date('23-09-2000', 'dd-mm-yyyy'), to_date('07-10-2000', 'dd-mm-yyyy'), 3, 1654, to_date('30-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080508012381, to_date('08-05-2008', 'dd-mm-yyyy'), to_date('22-05-2008', 'dd-mm-yyyy'), 4, 5429, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010712012382, to_date('12-07-2001', 'dd-mm-yyyy'), to_date('26-07-2001', 'dd-mm-yyyy'), 3, 4279, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131230012383, to_date('30-12-2013', 'dd-mm-yyyy'), to_date('13-01-2014', 'dd-mm-yyyy'), 3, 9927, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061208012384, to_date('08-12-2006', 'dd-mm-yyyy'), to_date('22-12-2006', 'dd-mm-yyyy'), 3, 4211, to_date('22-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121023012385, to_date('23-10-2012', 'dd-mm-yyyy'), to_date('06-11-2012', 'dd-mm-yyyy'), 3, 8273, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130325012386, to_date('25-03-2013', 'dd-mm-yyyy'), to_date('08-04-2013', 'dd-mm-yyyy'), 1, 8899, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131009012387, to_date('09-10-2013', 'dd-mm-yyyy'), to_date('23-10-2013', 'dd-mm-yyyy'), 3, 12573, to_date('28-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080912012388, to_date('12-09-2008', 'dd-mm-yyyy'), to_date('26-09-2008', 'dd-mm-yyyy'), 4, 5503, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061205012389, to_date('05-12-2006', 'dd-mm-yyyy'), to_date('19-12-2006', 'dd-mm-yyyy'), 3, 6285, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101029012390, to_date('29-10-2010', 'dd-mm-yyyy'), to_date('12-11-2010', 'dd-mm-yyyy'), 2, 9694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060813012391, to_date('13-08-2006', 'dd-mm-yyyy'), to_date('27-08-2006', 'dd-mm-yyyy'), 3, 4695, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110313012392, to_date('13-03-2011', 'dd-mm-yyyy'), to_date('27-03-2011', 'dd-mm-yyyy'), 3, 5472, to_date('31-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030609012393, to_date('09-06-2003', 'dd-mm-yyyy'), to_date('23-06-2003', 'dd-mm-yyyy'), 2, 4338, to_date('19-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090309012394, to_date('09-03-2009', 'dd-mm-yyyy'), to_date('23-03-2009', 'dd-mm-yyyy'), 3, 9335, to_date('27-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010302012395, to_date('02-03-2001', 'dd-mm-yyyy'), to_date('16-03-2001', 'dd-mm-yyyy'), 2, 1983, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111212012396, to_date('12-12-2011', 'dd-mm-yyyy'), to_date('26-12-2011', 'dd-mm-yyyy'), 4, 6658, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070912012397, to_date('12-09-2007', 'dd-mm-yyyy'), to_date('26-09-2007', 'dd-mm-yyyy'), 2, 5807, to_date('30-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020806012398, to_date('06-08-2002', 'dd-mm-yyyy'), to_date('20-08-2002', 'dd-mm-yyyy'), 2, 3488, to_date('08-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101120012399, to_date('20-11-2010', 'dd-mm-yyyy'), to_date('04-12-2010', 'dd-mm-yyyy'), 2, 9499, to_date('24-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011014012400, to_date('14-10-2001', 'dd-mm-yyyy'), to_date('28-10-2001', 'dd-mm-yyyy'), 4, 2998, to_date('16-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040919012401, to_date('19-09-2004', 'dd-mm-yyyy'), to_date('03-10-2004', 'dd-mm-yyyy'), 3, 6601, to_date('03-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130310012402, to_date('10-03-2013', 'dd-mm-yyyy'), to_date('24-03-2013', 'dd-mm-yyyy'), 4, 10526, to_date('15-03-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030605012403, to_date('05-06-2003', 'dd-mm-yyyy'), to_date('19-06-2003', 'dd-mm-yyyy'), 1, 5415, to_date('19-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001109012404, to_date('09-11-2000', 'dd-mm-yyyy'), to_date('23-11-2000', 'dd-mm-yyyy'), 4, 3284, to_date('25-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060307012405, to_date('07-03-2006', 'dd-mm-yyyy'), to_date('21-03-2006', 'dd-mm-yyyy'), 2, 4490, to_date('09-03-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010501012406, to_date('01-05-2001', 'dd-mm-yyyy'), to_date('15-05-2001', 'dd-mm-yyyy'), 3, 2627, to_date('03-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090601012407, to_date('01-06-2009', 'dd-mm-yyyy'), to_date('15-06-2009', 'dd-mm-yyyy'), 3, 8617, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110427012408, to_date('27-04-2011', 'dd-mm-yyyy'), to_date('11-05-2011', 'dd-mm-yyyy'), 3, 11071, to_date('01-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070714012409, to_date('14-07-2007', 'dd-mm-yyyy'), to_date('28-07-2007', 'dd-mm-yyyy'), 3, 6257, to_date('28-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120607012410, to_date('07-06-2012', 'dd-mm-yyyy'), to_date('21-06-2012', 'dd-mm-yyyy'), 3, 9408, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070511012411, to_date('11-05-2007', 'dd-mm-yyyy'), to_date('25-05-2007', 'dd-mm-yyyy'), 4, 5990, to_date('18-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060612012412, to_date('12-06-2006', 'dd-mm-yyyy'), to_date('26-06-2006', 'dd-mm-yyyy'), 3, 3040, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111122012413, to_date('22-11-2011', 'dd-mm-yyyy'), to_date('06-12-2011', 'dd-mm-yyyy'), 1, 10293, to_date('11-12-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104012414, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 3, 6187, to_date('22-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910012415, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 2, 10315, to_date('12-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120720012416, to_date('20-07-2012', 'dd-mm-yyyy'), to_date('03-08-2012', 'dd-mm-yyyy'), 1, 8418, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031122012417, to_date('22-11-2003', 'dd-mm-yyyy'), to_date('06-12-2003', 'dd-mm-yyyy'), 1, 3803, to_date('10-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070523012418, to_date('23-05-2007', 'dd-mm-yyyy'), to_date('06-06-2007', 'dd-mm-yyyy'), 4, 5592, to_date('28-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131012012419, to_date('12-10-2013', 'dd-mm-yyyy'), to_date('26-10-2013', 'dd-mm-yyyy'), 2, 10307, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041218012420, to_date('18-12-2004', 'dd-mm-yyyy'), to_date('01-01-2005', 'dd-mm-yyyy'), 3, 3239, to_date('29-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131221012421, to_date('21-12-2013', 'dd-mm-yyyy'), to_date('04-01-2014', 'dd-mm-yyyy'), 3, 6645, to_date('04-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010406012422, to_date('06-04-2001', 'dd-mm-yyyy'), to_date('20-04-2001', 'dd-mm-yyyy'), 1, 2269, to_date('16-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121126012423, to_date('26-11-2012', 'dd-mm-yyyy'), to_date('10-12-2012', 'dd-mm-yyyy'), 3, 8311, to_date('03-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111113012424, to_date('13-11-2011', 'dd-mm-yyyy'), to_date('27-11-2011', 'dd-mm-yyyy'), 4, 10997, to_date('22-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020128012425, to_date('28-01-2002', 'dd-mm-yyyy'), to_date('11-02-2002', 'dd-mm-yyyy'), 2, 1177, to_date('01-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000715012426, to_date('15-07-2000', 'dd-mm-yyyy'), to_date('29-07-2000', 'dd-mm-yyyy'), 1, 984, to_date('28-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010118012427, to_date('18-01-2001', 'dd-mm-yyyy'), to_date('01-02-2001', 'dd-mm-yyyy'), 1, 2780, to_date('04-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100423012428, to_date('23-04-2010', 'dd-mm-yyyy'), to_date('07-05-2010', 'dd-mm-yyyy'), 3, 7438, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030412012429, to_date('12-04-2003', 'dd-mm-yyyy'), to_date('26-04-2003', 'dd-mm-yyyy'), 3, 3282, to_date('29-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120506012430, to_date('06-05-2012', 'dd-mm-yyyy'), to_date('20-05-2012', 'dd-mm-yyyy'), 1, 7722, to_date('20-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130317012431, to_date('17-03-2013', 'dd-mm-yyyy'), to_date('31-03-2013', 'dd-mm-yyyy'), 1, 6716, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140117012432, to_date('17-01-2014', 'dd-mm-yyyy'), to_date('31-01-2014', 'dd-mm-yyyy'), 2, 7310, to_date('27-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010628012433, to_date('28-06-2001', 'dd-mm-yyyy'), to_date('12-07-2001', 'dd-mm-yyyy'), 3, 2138, to_date('07-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090603012434, to_date('03-06-2009', 'dd-mm-yyyy'), to_date('17-06-2009', 'dd-mm-yyyy'), 2, 9108, to_date('05-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011103012435, to_date('03-11-2001', 'dd-mm-yyyy'), to_date('17-11-2001', 'dd-mm-yyyy'), 1, 1411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040507012436, to_date('07-05-2004', 'dd-mm-yyyy'), to_date('21-05-2004', 'dd-mm-yyyy'), 3, 3295, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120622012437, to_date('22-06-2012', 'dd-mm-yyyy'), to_date('06-07-2012', 'dd-mm-yyyy'), 1, 8424, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061011012438, to_date('11-10-2006', 'dd-mm-yyyy'), to_date('25-10-2006', 'dd-mm-yyyy'), 3, 5538, to_date('19-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001112012439, to_date('12-11-2000', 'dd-mm-yyyy'), to_date('26-11-2000', 'dd-mm-yyyy'), 4, 1462, to_date('19-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121129012440, to_date('29-11-2012', 'dd-mm-yyyy'), to_date('13-12-2012', 'dd-mm-yyyy'), 2, 7708, to_date('05-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060709012441, to_date('09-07-2006', 'dd-mm-yyyy'), to_date('23-07-2006', 'dd-mm-yyyy'), 1, 5305, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100917012442, to_date('17-09-2010', 'dd-mm-yyyy'), to_date('01-10-2010', 'dd-mm-yyyy'), 2, 7107, to_date('05-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130501012443, to_date('01-05-2013', 'dd-mm-yyyy'), to_date('15-05-2013', 'dd-mm-yyyy'), 3, 8848, to_date('12-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000911012444, to_date('11-09-2000', 'dd-mm-yyyy'), to_date('25-09-2000', 'dd-mm-yyyy'), 1, 2472, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040416012445, to_date('16-04-2004', 'dd-mm-yyyy'), to_date('30-04-2004', 'dd-mm-yyyy'), 3, 3741, to_date('19-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051010012446, to_date('10-10-2005', 'dd-mm-yyyy'), to_date('24-10-2005', 'dd-mm-yyyy'), 3, 4764, to_date('15-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429012447, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 2, 2321, to_date('13-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070505012448, to_date('05-05-2007', 'dd-mm-yyyy'), to_date('19-05-2007', 'dd-mm-yyyy'), 2, 5469, to_date('08-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000429012449, to_date('29-04-2000', 'dd-mm-yyyy'), to_date('13-05-2000', 'dd-mm-yyyy'), 3, 2006, to_date('10-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060406012450, to_date('06-04-2006', 'dd-mm-yyyy'), to_date('20-04-2006', 'dd-mm-yyyy'), 4, 4656, to_date('19-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090824012451, to_date('24-08-2009', 'dd-mm-yyyy'), to_date('07-09-2009', 'dd-mm-yyyy'), 3, 6433, to_date('08-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010116012452, to_date('16-01-2001', 'dd-mm-yyyy'), to_date('30-01-2001', 'dd-mm-yyyy'), 1, 1214, to_date('18-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130712012453, to_date('12-07-2013', 'dd-mm-yyyy'), to_date('26-07-2013', 'dd-mm-yyyy'), 4, 10007, to_date('16-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010322012454, to_date('22-03-2001', 'dd-mm-yyyy'), to_date('05-04-2001', 'dd-mm-yyyy'), 1, 2157, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100718012455, to_date('18-07-2010', 'dd-mm-yyyy'), to_date('01-08-2010', 'dd-mm-yyyy'), 3, 6959, to_date('24-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080430012456, to_date('30-04-2008', 'dd-mm-yyyy'), to_date('14-05-2008', 'dd-mm-yyyy'), 2, 5962, to_date('16-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030126012457, to_date('26-01-2003', 'dd-mm-yyyy'), to_date('09-02-2003', 'dd-mm-yyyy'), 1, 2801, to_date('27-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081205012458, to_date('05-12-2008', 'dd-mm-yyyy'), to_date('19-12-2008', 'dd-mm-yyyy'), 3, 4535, to_date('10-12-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020715012459, to_date('15-07-2002', 'dd-mm-yyyy'), to_date('29-07-2002', 'dd-mm-yyyy'), 2, 3779, to_date('30-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130609012460, to_date('09-06-2013', 'dd-mm-yyyy'), to_date('23-06-2013', 'dd-mm-yyyy'), 2, 6373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060114012461, to_date('14-01-2006', 'dd-mm-yyyy'), to_date('28-01-2006', 'dd-mm-yyyy'), 3, 4307, to_date('25-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816012462, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 2, 7800, to_date('25-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130910012463, to_date('10-09-2013', 'dd-mm-yyyy'), to_date('24-09-2013', 'dd-mm-yyyy'), 4, 10384, to_date('28-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030214012464, to_date('14-02-2003', 'dd-mm-yyyy'), to_date('28-02-2003', 'dd-mm-yyyy'), 3, 3994, to_date('05-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091011012465, to_date('11-10-2009', 'dd-mm-yyyy'), to_date('25-10-2009', 'dd-mm-yyyy'), 2, 6786, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101012466, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 2, 4140, to_date('14-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131011012467, to_date('11-10-2013', 'dd-mm-yyyy'), to_date('25-10-2013', 'dd-mm-yyyy'), 2, 9228, to_date('29-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071206012468, to_date('06-12-2007', 'dd-mm-yyyy'), to_date('20-12-2007', 'dd-mm-yyyy'), 1, 4045, to_date('21-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040730012469, to_date('30-07-2004', 'dd-mm-yyyy'), to_date('13-08-2004', 'dd-mm-yyyy'), 1, 5523, to_date('15-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001120012470, to_date('20-11-2000', 'dd-mm-yyyy'), to_date('04-12-2000', 'dd-mm-yyyy'), 3, 1671, to_date('05-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090710012471, to_date('10-07-2009', 'dd-mm-yyyy'), to_date('24-07-2009', 'dd-mm-yyyy'), 4, 6777, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111023012472, to_date('23-10-2011', 'dd-mm-yyyy'), to_date('06-11-2011', 'dd-mm-yyyy'), 3, 8309, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080615012473, to_date('15-06-2008', 'dd-mm-yyyy'), to_date('29-06-2008', 'dd-mm-yyyy'), 2, 6598, to_date('22-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020622012474, to_date('22-06-2002', 'dd-mm-yyyy'), to_date('06-07-2002', 'dd-mm-yyyy'), 3, 2328, to_date('08-07-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081018012475, to_date('18-10-2008', 'dd-mm-yyyy'), to_date('01-11-2008', 'dd-mm-yyyy'), 1, 6135, to_date('05-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101202012476, to_date('02-12-2010', 'dd-mm-yyyy'), to_date('16-12-2010', 'dd-mm-yyyy'), 3, 7850, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000411012477, to_date('11-04-2000', 'dd-mm-yyyy'), to_date('25-04-2000', 'dd-mm-yyyy'), 3, 2075, to_date('19-04-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111120012478, to_date('20-11-2011', 'dd-mm-yyyy'), to_date('04-12-2011', 'dd-mm-yyyy'), 4, 9756, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040821012479, to_date('21-08-2004', 'dd-mm-yyyy'), to_date('04-09-2004', 'dd-mm-yyyy'), 3, 5380, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050510012480, to_date('10-05-2005', 'dd-mm-yyyy'), to_date('24-05-2005', 'dd-mm-yyyy'), 3, 3216, to_date('14-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020126012481, to_date('26-01-2002', 'dd-mm-yyyy'), to_date('09-02-2002', 'dd-mm-yyyy'), 1, 2941, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030609012482, to_date('09-06-2003', 'dd-mm-yyyy'), to_date('23-06-2003', 'dd-mm-yyyy'), 4, 2620, to_date('24-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021226012483, to_date('26-12-2002', 'dd-mm-yyyy'), to_date('09-01-2003', 'dd-mm-yyyy'), 3, 2193, to_date('06-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111119012484, to_date('19-11-2011', 'dd-mm-yyyy'), to_date('03-12-2011', 'dd-mm-yyyy'), 1, 7669, to_date('20-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041227012485, to_date('27-12-2004', 'dd-mm-yyyy'), to_date('10-01-2005', 'dd-mm-yyyy'), 3, 5585, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090628012486, to_date('28-06-2009', 'dd-mm-yyyy'), to_date('12-07-2009', 'dd-mm-yyyy'), 2, 7174, to_date('17-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809012487, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 3, 4703, to_date('21-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120905012488, to_date('05-09-2012', 'dd-mm-yyyy'), to_date('19-09-2012', 'dd-mm-yyyy'), 4, 7198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100503012489, to_date('03-05-2010', 'dd-mm-yyyy'), to_date('17-05-2010', 'dd-mm-yyyy'), 1, 5666, to_date('17-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030512012490, to_date('12-05-2003', 'dd-mm-yyyy'), to_date('26-05-2003', 'dd-mm-yyyy'), 3, 3018, to_date('22-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070101012491, to_date('01-01-2007', 'dd-mm-yyyy'), to_date('15-01-2007', 'dd-mm-yyyy'), 4, 6071, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111122012492, to_date('22-11-2011', 'dd-mm-yyyy'), to_date('06-12-2011', 'dd-mm-yyyy'), 3, 6185, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120901012493, to_date('01-09-2012', 'dd-mm-yyyy'), to_date('15-09-2012', 'dd-mm-yyyy'), 1, 8134, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011214012494, to_date('14-12-2001', 'dd-mm-yyyy'), to_date('28-12-2001', 'dd-mm-yyyy'), 2, 2047, to_date('02-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030521012495, to_date('21-05-2003', 'dd-mm-yyyy'), to_date('04-06-2003', 'dd-mm-yyyy'), 2, 2346, to_date('09-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040305012496, to_date('05-03-2004', 'dd-mm-yyyy'), to_date('19-03-2004', 'dd-mm-yyyy'), 1, 5365, to_date('10-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081118012497, to_date('18-11-2008', 'dd-mm-yyyy'), to_date('02-12-2008', 'dd-mm-yyyy'), 2, 6241, to_date('22-11-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090617012498, to_date('17-06-2009', 'dd-mm-yyyy'), to_date('01-07-2009', 'dd-mm-yyyy'), 3, 5060, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100710012499, to_date('10-07-2010', 'dd-mm-yyyy'), to_date('24-07-2010', 'dd-mm-yyyy'), 2, 7248, to_date('25-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130716012500, to_date('16-07-2013', 'dd-mm-yyyy'), to_date('30-07-2013', 'dd-mm-yyyy'), 3, 9667, to_date('03-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010714012501, to_date('14-07-2001', 'dd-mm-yyyy'), to_date('28-07-2001', 'dd-mm-yyyy'), 1, 2950, to_date('30-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031226012502, to_date('26-12-2003', 'dd-mm-yyyy'), to_date('09-01-2004', 'dd-mm-yyyy'), 3, 2042, to_date('31-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820012503, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 3, 8027, to_date('28-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020812012504, to_date('12-08-2002', 'dd-mm-yyyy'), to_date('26-08-2002', 'dd-mm-yyyy'), 3, 2046, to_date('21-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805012505, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 3, 3397, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090620012506, to_date('20-06-2009', 'dd-mm-yyyy'), to_date('04-07-2009', 'dd-mm-yyyy'), 4, 8461, to_date('02-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030703012507, to_date('03-07-2003', 'dd-mm-yyyy'), to_date('17-07-2003', 'dd-mm-yyyy'), 4, 1971, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120329012508, to_date('29-03-2012', 'dd-mm-yyyy'), to_date('12-04-2012', 'dd-mm-yyyy'), 3, 6127, to_date('08-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100201012509, to_date('01-02-2010', 'dd-mm-yyyy'), to_date('15-02-2010', 'dd-mm-yyyy'), 3, 8782, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031015012510, to_date('15-10-2003', 'dd-mm-yyyy'), to_date('29-10-2003', 'dd-mm-yyyy'), 3, 3847, to_date('22-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040130012511, to_date('30-01-2004', 'dd-mm-yyyy'), to_date('13-02-2004', 'dd-mm-yyyy'), 2, 2286, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725012512, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 2, 8951, to_date('05-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091003012513, to_date('03-10-2009', 'dd-mm-yyyy'), to_date('17-10-2009', 'dd-mm-yyyy'), 3, 10017, to_date('19-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070922012514, to_date('22-09-2007', 'dd-mm-yyyy'), to_date('06-10-2007', 'dd-mm-yyyy'), 2, 5353, to_date('29-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129012515, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 3, 3414, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040807012516, to_date('07-08-2004', 'dd-mm-yyyy'), to_date('21-08-2004', 'dd-mm-yyyy'), 2, 2783, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121231012517, to_date('31-12-2012', 'dd-mm-yyyy'), to_date('14-01-2013', 'dd-mm-yyyy'), 3, 9097, to_date('04-01-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100808012518, to_date('08-08-2010', 'dd-mm-yyyy'), to_date('22-08-2010', 'dd-mm-yyyy'), 4, 9414, to_date('26-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080308012519, to_date('08-03-2008', 'dd-mm-yyyy'), to_date('22-03-2008', 'dd-mm-yyyy'), 2, 4137, to_date('20-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100104012520, to_date('04-01-2010', 'dd-mm-yyyy'), to_date('18-01-2010', 'dd-mm-yyyy'), 4, 8733, to_date('07-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131203012521, to_date('03-12-2013', 'dd-mm-yyyy'), to_date('17-12-2013', 'dd-mm-yyyy'), 2, 10219, to_date('06-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110110012522, to_date('10-01-2011', 'dd-mm-yyyy'), to_date('24-01-2011', 'dd-mm-yyyy'), 4, 6066, to_date('12-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031218012523, to_date('18-12-2003', 'dd-mm-yyyy'), to_date('01-01-2004', 'dd-mm-yyyy'), 4, 5167, to_date('23-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050522015220, to_date('22-05-2005', 'dd-mm-yyyy'), to_date('05-06-2005', 'dd-mm-yyyy'), 2, 7330, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070720015221, to_date('20-07-2007', 'dd-mm-yyyy'), to_date('03-08-2007', 'dd-mm-yyyy'), 3, 4932, to_date('04-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130428015222, to_date('28-04-2013', 'dd-mm-yyyy'), to_date('12-05-2013', 'dd-mm-yyyy'), 3, 10314, to_date('18-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041228015223, to_date('28-12-2004', 'dd-mm-yyyy'), to_date('11-01-2005', 'dd-mm-yyyy'), 2, 2619, to_date('30-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090710015224, to_date('10-07-2009', 'dd-mm-yyyy'), to_date('24-07-2009', 'dd-mm-yyyy'), 1, 9320, to_date('19-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061120015225, to_date('20-11-2006', 'dd-mm-yyyy'), to_date('04-12-2006', 'dd-mm-yyyy'), 2, 6005, to_date('06-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140425015226, to_date('25-04-2014', 'dd-mm-yyyy'), to_date('09-05-2014', 'dd-mm-yyyy'), 2, 10003, to_date('12-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111113015227, to_date('13-11-2011', 'dd-mm-yyyy'), to_date('27-11-2011', 'dd-mm-yyyy'), 2, 6290, to_date('15-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080229015228, to_date('29-02-2008', 'dd-mm-yyyy'), to_date('14-03-2008', 'dd-mm-yyyy'), 1, 9322, to_date('11-03-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071214015229, to_date('14-12-2007', 'dd-mm-yyyy'), to_date('28-12-2007', 'dd-mm-yyyy'), 3, 4989, to_date('30-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001214015230, to_date('14-12-2000', 'dd-mm-yyyy'), to_date('28-12-2000', 'dd-mm-yyyy'), 2, 1201, to_date('25-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070816015231, to_date('16-08-2007', 'dd-mm-yyyy'), to_date('30-08-2007', 'dd-mm-yyyy'), 3, 8258, to_date('21-08-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070819015232, to_date('19-08-2007', 'dd-mm-yyyy'), to_date('02-09-2007', 'dd-mm-yyyy'), 2, 4302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011020015233, to_date('20-10-2001', 'dd-mm-yyyy'), to_date('03-11-2001', 'dd-mm-yyyy'), 3, 2303, to_date('02-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110202015234, to_date('02-02-2011', 'dd-mm-yyyy'), to_date('16-02-2011', 'dd-mm-yyyy'), 3, 8776, to_date('07-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101027015235, to_date('27-10-2010', 'dd-mm-yyyy'), to_date('10-11-2010', 'dd-mm-yyyy'), 3, 6869, to_date('05-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070917015236, to_date('17-09-2007', 'dd-mm-yyyy'), to_date('01-10-2007', 'dd-mm-yyyy'), 4, 3354, to_date('21-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001225015237, to_date('25-12-2000', 'dd-mm-yyyy'), to_date('08-01-2001', 'dd-mm-yyyy'), 4, 1809, to_date('01-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130628015238, to_date('28-06-2013', 'dd-mm-yyyy'), to_date('12-07-2013', 'dd-mm-yyyy'), 4, 4972, to_date('05-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040629015239, to_date('29-06-2004', 'dd-mm-yyyy'), to_date('13-07-2004', 'dd-mm-yyyy'), 3, 4524, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010829015240, to_date('29-08-2001', 'dd-mm-yyyy'), to_date('12-09-2001', 'dd-mm-yyyy'), 1, 2092, to_date('11-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010722015241, to_date('22-07-2001', 'dd-mm-yyyy'), to_date('05-08-2001', 'dd-mm-yyyy'), 1, 1616, to_date('09-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061001015242, to_date('01-10-2006', 'dd-mm-yyyy'), to_date('15-10-2006', 'dd-mm-yyyy'), 3, 4042, to_date('08-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050129015243, to_date('29-01-2005', 'dd-mm-yyyy'), to_date('12-02-2005', 'dd-mm-yyyy'), 1, 5214, to_date('06-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030122015244, to_date('22-01-2003', 'dd-mm-yyyy'), to_date('05-02-2003', 'dd-mm-yyyy'), 3, 1837, to_date('28-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120921015245, to_date('21-09-2012', 'dd-mm-yyyy'), to_date('05-10-2012', 'dd-mm-yyyy'), 2, 9346, to_date('07-10-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101216015246, to_date('16-12-2010', 'dd-mm-yyyy'), to_date('30-12-2010', 'dd-mm-yyyy'), 3, 5599, to_date('22-12-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001214015247, to_date('14-12-2000', 'dd-mm-yyyy'), to_date('28-12-2000', 'dd-mm-yyyy'), 2, 1256, to_date('23-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040614015248, to_date('14-06-2004', 'dd-mm-yyyy'), to_date('28-06-2004', 'dd-mm-yyyy'), 1, 3117, to_date('21-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000702015249, to_date('02-07-2000', 'dd-mm-yyyy'), to_date('16-07-2000', 'dd-mm-yyyy'), 2, 1687, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070127015250, to_date('27-01-2007', 'dd-mm-yyyy'), to_date('10-02-2007', 'dd-mm-yyyy'), 3, 7527, to_date('14-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010816015251, to_date('16-08-2001', 'dd-mm-yyyy'), to_date('30-08-2001', 'dd-mm-yyyy'), 3, 2933, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040526015252, to_date('26-05-2004', 'dd-mm-yyyy'), to_date('09-06-2004', 'dd-mm-yyyy'), 3, 3411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040306015253, to_date('06-03-2004', 'dd-mm-yyyy'), to_date('20-03-2004', 'dd-mm-yyyy'), 3, 4755, to_date('10-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030608015254, to_date('08-06-2003', 'dd-mm-yyyy'), to_date('22-06-2003', 'dd-mm-yyyy'), 4, 4853, to_date('15-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020127015255, to_date('27-01-2002', 'dd-mm-yyyy'), to_date('10-02-2002', 'dd-mm-yyyy'), 4, 4618, to_date('07-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010308015256, to_date('08-03-2001', 'dd-mm-yyyy'), to_date('22-03-2001', 'dd-mm-yyyy'), 2, 1946, to_date('13-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070222015257, to_date('22-02-2007', 'dd-mm-yyyy'), to_date('08-03-2007', 'dd-mm-yyyy'), 2, 8464, to_date('02-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040508015258, to_date('08-05-2004', 'dd-mm-yyyy'), to_date('22-05-2004', 'dd-mm-yyyy'), 2, 3950, to_date('25-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110902015259, to_date('02-09-2011', 'dd-mm-yyyy'), to_date('16-09-2011', 'dd-mm-yyyy'), 2, 7362, to_date('13-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050608015260, to_date('08-06-2005', 'dd-mm-yyyy'), to_date('22-06-2005', 'dd-mm-yyyy'), 3, 4196, to_date('25-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020227015261, to_date('27-02-2002', 'dd-mm-yyyy'), to_date('13-03-2002', 'dd-mm-yyyy'), 1, 1410, to_date('03-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061230015262, to_date('30-12-2006', 'dd-mm-yyyy'), to_date('13-01-2007', 'dd-mm-yyyy'), 3, 7020, to_date('18-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100907015263, to_date('07-09-2010', 'dd-mm-yyyy'), to_date('21-09-2010', 'dd-mm-yyyy'), 1, 6735, to_date('26-09-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051008015264, to_date('08-10-2005', 'dd-mm-yyyy'), to_date('22-10-2005', 'dd-mm-yyyy'), 1, 5340, to_date('19-10-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030619015265, to_date('19-06-2003', 'dd-mm-yyyy'), to_date('03-07-2003', 'dd-mm-yyyy'), 3, 2325, to_date('23-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130701015266, to_date('01-07-2013', 'dd-mm-yyyy'), to_date('15-07-2013', 'dd-mm-yyyy'), 1, 8076, to_date('09-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021120015267, to_date('20-11-2002', 'dd-mm-yyyy'), to_date('04-12-2002', 'dd-mm-yyyy'), 3, 3784, to_date('25-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010307015268, to_date('07-03-2001', 'dd-mm-yyyy'), to_date('21-03-2001', 'dd-mm-yyyy'), 1, 3834, to_date('22-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225015269, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 2, 8021, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050301015270, to_date('01-03-2005', 'dd-mm-yyyy'), to_date('15-03-2005', 'dd-mm-yyyy'), 4, 5432, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061101015271, to_date('01-11-2006', 'dd-mm-yyyy'), to_date('15-11-2006', 'dd-mm-yyyy'), 4, 4484, to_date('11-11-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090327015272, to_date('27-03-2009', 'dd-mm-yyyy'), to_date('10-04-2009', 'dd-mm-yyyy'), 2, 8230, to_date('08-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071224015273, to_date('24-12-2007', 'dd-mm-yyyy'), to_date('07-01-2008', 'dd-mm-yyyy'), 3, 6181, to_date('12-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426015274, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 3, 5153, to_date('07-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010108015275, to_date('08-01-2001', 'dd-mm-yyyy'), to_date('22-01-2001', 'dd-mm-yyyy'), 4, 2772, to_date('16-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040120015276, to_date('20-01-2004', 'dd-mm-yyyy'), to_date('03-02-2004', 'dd-mm-yyyy'), 3, 3335, to_date('08-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021004015277, to_date('04-10-2002', 'dd-mm-yyyy'), to_date('18-10-2002', 'dd-mm-yyyy'), 3, 922, to_date('19-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628015278, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 4, 3036, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030311015279, to_date('11-03-2003', 'dd-mm-yyyy'), to_date('25-03-2003', 'dd-mm-yyyy'), 2, 3437, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090604015280, to_date('04-06-2009', 'dd-mm-yyyy'), to_date('18-06-2009', 'dd-mm-yyyy'), 2, 5020, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110910015281, to_date('10-09-2011', 'dd-mm-yyyy'), to_date('24-09-2011', 'dd-mm-yyyy'), 3, 7240, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041130015282, to_date('30-11-2004', 'dd-mm-yyyy'), to_date('14-12-2004', 'dd-mm-yyyy'), 2, 3306, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030717015283, to_date('17-07-2003', 'dd-mm-yyyy'), to_date('31-07-2003', 'dd-mm-yyyy'), 2, 3413, to_date('03-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011226015284, to_date('26-12-2001', 'dd-mm-yyyy'), to_date('09-01-2002', 'dd-mm-yyyy'), 3, 2631, to_date('06-01-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051126015285, to_date('26-11-2005', 'dd-mm-yyyy'), to_date('10-12-2005', 'dd-mm-yyyy'), 1, 3343, to_date('15-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030104015286, to_date('04-01-2003', 'dd-mm-yyyy'), to_date('18-01-2003', 'dd-mm-yyyy'), 3, 2756, to_date('08-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060108015287, to_date('08-01-2006', 'dd-mm-yyyy'), to_date('22-01-2006', 'dd-mm-yyyy'), 2, 5289, to_date('19-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060106015288, to_date('06-01-2006', 'dd-mm-yyyy'), to_date('20-01-2006', 'dd-mm-yyyy'), 2, 6311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621015289, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 2, 1930, to_date('02-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080614015290, to_date('14-06-2008', 'dd-mm-yyyy'), to_date('28-06-2008', 'dd-mm-yyyy'), 4, 9121, to_date('25-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090403015291, to_date('03-04-2009', 'dd-mm-yyyy'), to_date('17-04-2009', 'dd-mm-yyyy'), 3, 6177, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050125015292, to_date('25-01-2005', 'dd-mm-yyyy'), to_date('08-02-2005', 'dd-mm-yyyy'), 3, 4358, to_date('02-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121130015293, to_date('30-11-2012', 'dd-mm-yyyy'), to_date('14-12-2012', 'dd-mm-yyyy'), 4, 5545, to_date('16-12-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091108015294, to_date('08-11-2009', 'dd-mm-yyyy'), to_date('22-11-2009', 'dd-mm-yyyy'), 3, 5141, to_date('27-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120919015295, to_date('19-09-2012', 'dd-mm-yyyy'), to_date('03-10-2012', 'dd-mm-yyyy'), 4, 5694, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522015296, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 1, 9550, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010506015297, to_date('06-05-2001', 'dd-mm-yyyy'), to_date('20-05-2001', 'dd-mm-yyyy'), 2, 2258, to_date('21-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000903015298, to_date('03-09-2000', 'dd-mm-yyyy'), to_date('17-09-2000', 'dd-mm-yyyy'), 1, 2277, to_date('08-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725015299, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 3, 6753, to_date('12-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030526015300, to_date('26-05-2003', 'dd-mm-yyyy'), to_date('09-06-2003', 'dd-mm-yyyy'), 4, 4025, to_date('08-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110423015301, to_date('23-04-2011', 'dd-mm-yyyy'), to_date('07-05-2011', 'dd-mm-yyyy'), 4, 7604, to_date('10-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020808015302, to_date('08-08-2002', 'dd-mm-yyyy'), to_date('22-08-2002', 'dd-mm-yyyy'), 4, 2449, to_date('25-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041025015303, to_date('25-10-2004', 'dd-mm-yyyy'), to_date('08-11-2004', 'dd-mm-yyyy'), 1, 3580, to_date('27-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020322015304, to_date('22-03-2002', 'dd-mm-yyyy'), to_date('05-04-2002', 'dd-mm-yyyy'), 1, 2455, to_date('09-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100807015305, to_date('07-08-2010', 'dd-mm-yyyy'), to_date('21-08-2010', 'dd-mm-yyyy'), 1, 6734, to_date('10-08-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020330015306, to_date('30-03-2002', 'dd-mm-yyyy'), to_date('13-04-2002', 'dd-mm-yyyy'), 4, 3035, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090716015307, to_date('16-07-2009', 'dd-mm-yyyy'), to_date('30-07-2009', 'dd-mm-yyyy'), 4, 4549, to_date('04-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010106015308, to_date('06-01-2001', 'dd-mm-yyyy'), to_date('20-01-2001', 'dd-mm-yyyy'), 1, 3709, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010216015309, to_date('16-02-2001', 'dd-mm-yyyy'), to_date('02-03-2001', 'dd-mm-yyyy'), 2, 2708, to_date('26-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060606015310, to_date('06-06-2006', 'dd-mm-yyyy'), to_date('20-06-2006', 'dd-mm-yyyy'), 3, 2915, to_date('16-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040929015311, to_date('29-09-2004', 'dd-mm-yyyy'), to_date('13-10-2004', 'dd-mm-yyyy'), 4, 3670, to_date('17-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040430015312, to_date('30-04-2004', 'dd-mm-yyyy'), to_date('14-05-2004', 'dd-mm-yyyy'), 2, 2281, to_date('19-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226015313, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 3, 6853, to_date('01-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010216015314, to_date('16-02-2001', 'dd-mm-yyyy'), to_date('02-03-2001', 'dd-mm-yyyy'), 2, 2352, to_date('27-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081017015315, to_date('17-10-2008', 'dd-mm-yyyy'), to_date('31-10-2008', 'dd-mm-yyyy'), 3, 7347, to_date('29-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021127015316, to_date('27-11-2002', 'dd-mm-yyyy'), to_date('11-12-2002', 'dd-mm-yyyy'), 2, 1182, to_date('14-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060911015317, to_date('11-09-2006', 'dd-mm-yyyy'), to_date('25-09-2006', 'dd-mm-yyyy'), 2, 5473, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021206015318, to_date('06-12-2002', 'dd-mm-yyyy'), to_date('20-12-2002', 'dd-mm-yyyy'), 2, 1914, to_date('20-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000831015319, to_date('31-08-2000', 'dd-mm-yyyy'), to_date('14-09-2000', 'dd-mm-yyyy'), 3, 2046, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614015320, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 3, 8754, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080401015321, to_date('01-04-2008', 'dd-mm-yyyy'), to_date('15-04-2008', 'dd-mm-yyyy'), 2, 5630, to_date('21-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110112015322, to_date('12-01-2011', 'dd-mm-yyyy'), to_date('26-01-2011', 'dd-mm-yyyy'), 2, 9647, to_date('19-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031122015323, to_date('22-11-2003', 'dd-mm-yyyy'), to_date('06-12-2003', 'dd-mm-yyyy'), 3, 2699, to_date('05-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100310015324, to_date('10-03-2010', 'dd-mm-yyyy'), to_date('24-03-2010', 'dd-mm-yyyy'), 3, 9415, to_date('29-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060621015325, to_date('21-06-2006', 'dd-mm-yyyy'), to_date('05-07-2006', 'dd-mm-yyyy'), 2, 3363, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050101015326, to_date('01-01-2005', 'dd-mm-yyyy'), to_date('15-01-2005', 'dd-mm-yyyy'), 1, 4465, to_date('14-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070519015327, to_date('19-05-2007', 'dd-mm-yyyy'), to_date('02-06-2007', 'dd-mm-yyyy'), 3, 5601, to_date('05-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041206015328, to_date('06-12-2004', 'dd-mm-yyyy'), to_date('20-12-2004', 'dd-mm-yyyy'), 3, 3183, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000814015329, to_date('14-08-2000', 'dd-mm-yyyy'), to_date('28-08-2000', 'dd-mm-yyyy'), 2, 970, to_date('20-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041006015330, to_date('06-10-2004', 'dd-mm-yyyy'), to_date('20-10-2004', 'dd-mm-yyyy'), 2, 3890, to_date('13-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120112015331, to_date('12-01-2012', 'dd-mm-yyyy'), to_date('26-01-2012', 'dd-mm-yyyy'), 3, 8877, to_date('31-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050213015332, to_date('13-02-2005', 'dd-mm-yyyy'), to_date('27-02-2005', 'dd-mm-yyyy'), 2, 3865, to_date('24-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130323015333, to_date('23-03-2013', 'dd-mm-yyyy'), to_date('06-04-2013', 'dd-mm-yyyy'), 3, 8773, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061227015334, to_date('27-12-2006', 'dd-mm-yyyy'), to_date('10-01-2007', 'dd-mm-yyyy'), 2, 4905, to_date('15-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000501015335, to_date('01-05-2000', 'dd-mm-yyyy'), to_date('15-05-2000', 'dd-mm-yyyy'), 4, 2810, to_date('02-05-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031016015336, to_date('16-10-2003', 'dd-mm-yyyy'), to_date('30-10-2003', 'dd-mm-yyyy'), 2, 2708, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030308015337, to_date('08-03-2003', 'dd-mm-yyyy'), to_date('22-03-2003', 'dd-mm-yyyy'), 4, 2949, to_date('28-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000223015338, to_date('23-02-2000', 'dd-mm-yyyy'), to_date('08-03-2000', 'dd-mm-yyyy'), 2, 1333, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130419015339, to_date('19-04-2013', 'dd-mm-yyyy'), to_date('03-05-2013', 'dd-mm-yyyy'), 3, 7108, to_date('07-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020816015340, to_date('16-08-2002', 'dd-mm-yyyy'), to_date('30-08-2002', 'dd-mm-yyyy'), 3, 2481, to_date('31-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080126015341, to_date('26-01-2008', 'dd-mm-yyyy'), to_date('09-02-2008', 'dd-mm-yyyy'), 2, 8038, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110120015342, to_date('20-01-2011', 'dd-mm-yyyy'), to_date('03-02-2011', 'dd-mm-yyyy'), 2, 7251, to_date('01-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030815015343, to_date('15-08-2003', 'dd-mm-yyyy'), to_date('29-08-2003', 'dd-mm-yyyy'), 2, 2223, to_date('27-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130321015344, to_date('21-03-2013', 'dd-mm-yyyy'), to_date('04-04-2013', 'dd-mm-yyyy'), 2, 6893, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000702015345, to_date('02-07-2000', 'dd-mm-yyyy'), to_date('16-07-2000', 'dd-mm-yyyy'), 3, 1763, to_date('13-07-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070831015346, to_date('31-08-2007', 'dd-mm-yyyy'), to_date('14-09-2007', 'dd-mm-yyyy'), 3, 4277, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000122015347, to_date('22-01-2000', 'dd-mm-yyyy'), to_date('05-02-2000', 'dd-mm-yyyy'), 1, 2988, to_date('01-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070919015348, to_date('19-09-2007', 'dd-mm-yyyy'), to_date('03-10-2007', 'dd-mm-yyyy'), 1, 5001, to_date('21-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101010015349, to_date('10-10-2010', 'dd-mm-yyyy'), to_date('24-10-2010', 'dd-mm-yyyy'), 3, 4436, to_date('27-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080513015350, to_date('13-05-2008', 'dd-mm-yyyy'), to_date('27-05-2008', 'dd-mm-yyyy'), 3, 6970, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130514015351, to_date('14-05-2013', 'dd-mm-yyyy'), to_date('28-05-2013', 'dd-mm-yyyy'), 2, 7573, to_date('20-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040416015352, to_date('16-04-2004', 'dd-mm-yyyy'), to_date('30-04-2004', 'dd-mm-yyyy'), 1, 3542, to_date('01-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100228015353, to_date('28-02-2010', 'dd-mm-yyyy'), to_date('14-03-2010', 'dd-mm-yyyy'), 2, 9103, to_date('16-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040412015354, to_date('12-04-2004', 'dd-mm-yyyy'), to_date('26-04-2004', 'dd-mm-yyyy'), 3, 3870, to_date('01-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051211015355, to_date('11-12-2005', 'dd-mm-yyyy'), to_date('25-12-2005', 'dd-mm-yyyy'), 2, 5755, to_date('20-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111109015356, to_date('09-11-2011', 'dd-mm-yyyy'), to_date('23-11-2011', 'dd-mm-yyyy'), 2, 8008, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816015357, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 2, 7621, to_date('28-08-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120818015358, to_date('18-08-2012', 'dd-mm-yyyy'), to_date('01-09-2012', 'dd-mm-yyyy'), 1, 8241, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070604015359, to_date('04-06-2007', 'dd-mm-yyyy'), to_date('18-06-2007', 'dd-mm-yyyy'), 2, 6084, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000324015360, to_date('24-03-2000', 'dd-mm-yyyy'), to_date('07-04-2000', 'dd-mm-yyyy'), 1, 2115, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081113015361, to_date('13-11-2008', 'dd-mm-yyyy'), to_date('27-11-2008', 'dd-mm-yyyy'), 3, 4354, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050207015362, to_date('07-02-2005', 'dd-mm-yyyy'), to_date('21-02-2005', 'dd-mm-yyyy'), 2, 4888, to_date('22-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101016015363, to_date('16-10-2010', 'dd-mm-yyyy'), to_date('30-10-2010', 'dd-mm-yyyy'), 1, 9450, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120602015364, to_date('02-06-2012', 'dd-mm-yyyy'), to_date('16-06-2012', 'dd-mm-yyyy'), 4, 8904, to_date('08-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021127015365, to_date('27-11-2002', 'dd-mm-yyyy'), to_date('11-12-2002', 'dd-mm-yyyy'), 3, 2246, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091026015366, to_date('26-10-2009', 'dd-mm-yyyy'), to_date('09-11-2009', 'dd-mm-yyyy'), 2, 6964, to_date('03-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041221015367, to_date('21-12-2004', 'dd-mm-yyyy'), to_date('04-01-2005', 'dd-mm-yyyy'), 2, 2190, to_date('01-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030426015368, to_date('26-04-2003', 'dd-mm-yyyy'), to_date('10-05-2003', 'dd-mm-yyyy'), 3, 2664, to_date('03-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040504015369, to_date('04-05-2004', 'dd-mm-yyyy'), to_date('18-05-2004', 'dd-mm-yyyy'), 2, 3943, to_date('14-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120703015370, to_date('03-07-2012', 'dd-mm-yyyy'), to_date('17-07-2012', 'dd-mm-yyyy'), 2, 7539, to_date('07-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070129015371, to_date('29-01-2007', 'dd-mm-yyyy'), to_date('12-02-2007', 'dd-mm-yyyy'), 4, 4306, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010324015372, to_date('24-03-2001', 'dd-mm-yyyy'), to_date('07-04-2001', 'dd-mm-yyyy'), 3, 3057, to_date('06-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000505015373, to_date('05-05-2000', 'dd-mm-yyyy'), to_date('19-05-2000', 'dd-mm-yyyy'), 3, 1328, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040116015374, to_date('16-01-2004', 'dd-mm-yyyy'), to_date('30-01-2004', 'dd-mm-yyyy'), 3, 4370, to_date('19-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040726015375, to_date('26-07-2004', 'dd-mm-yyyy'), to_date('09-08-2004', 'dd-mm-yyyy'), 2, 5244, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021024015376, to_date('24-10-2002', 'dd-mm-yyyy'), to_date('07-11-2002', 'dd-mm-yyyy'), 2, 2077, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010221015377, to_date('21-02-2001', 'dd-mm-yyyy'), to_date('07-03-2001', 'dd-mm-yyyy'), 2, 1642, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051216015378, to_date('16-12-2005', 'dd-mm-yyyy'), to_date('30-12-2005', 'dd-mm-yyyy'), 3, 6944, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130306015379, to_date('06-03-2013', 'dd-mm-yyyy'), to_date('20-03-2013', 'dd-mm-yyyy'), 3, 8820, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050513015380, to_date('13-05-2005', 'dd-mm-yyyy'), to_date('27-05-2005', 'dd-mm-yyyy'), 3, 4806, to_date('21-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120129015381, to_date('29-01-2012', 'dd-mm-yyyy'), to_date('12-02-2012', 'dd-mm-yyyy'), 2, 7572, to_date('14-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060130015382, to_date('30-01-2006', 'dd-mm-yyyy'), to_date('13-02-2006', 'dd-mm-yyyy'), 1, 3600, to_date('15-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041126015383, to_date('26-11-2004', 'dd-mm-yyyy'), to_date('10-12-2004', 'dd-mm-yyyy'), 1, 3785, to_date('08-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010529015384, to_date('29-05-2001', 'dd-mm-yyyy'), to_date('12-06-2001', 'dd-mm-yyyy'), 3, 2649, to_date('31-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050402015385, to_date('02-04-2005', 'dd-mm-yyyy'), to_date('16-04-2005', 'dd-mm-yyyy'), 1, 4162, to_date('10-04-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130712015386, to_date('12-07-2013', 'dd-mm-yyyy'), to_date('26-07-2013', 'dd-mm-yyyy'), 2, 8972, to_date('17-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100921015387, to_date('21-09-2010', 'dd-mm-yyyy'), to_date('05-10-2010', 'dd-mm-yyyy'), 3, 8517, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060710015388, to_date('10-07-2006', 'dd-mm-yyyy'), to_date('24-07-2006', 'dd-mm-yyyy'), 2, 5026, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131119017919, to_date('19-11-2013', 'dd-mm-yyyy'), to_date('03-12-2013', 'dd-mm-yyyy'), 1, 9834, to_date('02-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120126017920, to_date('26-01-2012', 'dd-mm-yyyy'), to_date('09-02-2012', 'dd-mm-yyyy'), 1, 9312, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040726017921, to_date('26-07-2004', 'dd-mm-yyyy'), to_date('09-08-2004', 'dd-mm-yyyy'), 1, 3326, to_date('27-07-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070614017922, to_date('14-06-2007', 'dd-mm-yyyy'), to_date('28-06-2007', 'dd-mm-yyyy'), 2, 4493, to_date('28-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001025017923, to_date('25-10-2000', 'dd-mm-yyyy'), to_date('08-11-2000', 'dd-mm-yyyy'), 1, 1752, to_date('08-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000811017924, to_date('11-08-2000', 'dd-mm-yyyy'), to_date('25-08-2000', 'dd-mm-yyyy'), 1, 1734, to_date('27-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110509017925, to_date('09-05-2011', 'dd-mm-yyyy'), to_date('23-05-2011', 'dd-mm-yyyy'), 2, 6721, to_date('10-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100103017926, to_date('03-01-2010', 'dd-mm-yyyy'), to_date('17-01-2010', 'dd-mm-yyyy'), 1, 8505, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090909017927, to_date('09-09-2009', 'dd-mm-yyyy'), to_date('23-09-2009', 'dd-mm-yyyy'), 2, 8014, to_date('28-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131112017928, to_date('12-11-2013', 'dd-mm-yyyy'), to_date('26-11-2013', 'dd-mm-yyyy'), 1, 7358, to_date('28-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080912017929, to_date('12-09-2008', 'dd-mm-yyyy'), to_date('26-09-2008', 'dd-mm-yyyy'), 1, 5482, to_date('21-09-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131222017930, to_date('22-12-2013', 'dd-mm-yyyy'), to_date('05-01-2014', 'dd-mm-yyyy'), 2, 10042, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130203017931, to_date('03-02-2013', 'dd-mm-yyyy'), to_date('17-02-2013', 'dd-mm-yyyy'), 1, 7275, to_date('18-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130901017932, to_date('01-09-2013', 'dd-mm-yyyy'), to_date('15-09-2013', 'dd-mm-yyyy'), 1, 9126, to_date('21-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060826017933, to_date('26-08-2006', 'dd-mm-yyyy'), to_date('09-09-2006', 'dd-mm-yyyy'), 1, 4998, to_date('06-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091213017934, to_date('13-12-2009', 'dd-mm-yyyy'), to_date('27-12-2009', 'dd-mm-yyyy'), 2, 7698, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131108017935, to_date('08-11-2013', 'dd-mm-yyyy'), to_date('22-11-2013', 'dd-mm-yyyy'), 1, 10053, to_date('28-11-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080410017936, to_date('10-04-2008', 'dd-mm-yyyy'), to_date('24-04-2008', 'dd-mm-yyyy'), 1, 6070, to_date('24-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060417017937, to_date('17-04-2006', 'dd-mm-yyyy'), to_date('01-05-2006', 'dd-mm-yyyy'), 1, 5555, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140414017938, to_date('14-04-2014', 'dd-mm-yyyy'), to_date('28-04-2014', 'dd-mm-yyyy'), 1, 8171, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030724017939, to_date('24-07-2003', 'dd-mm-yyyy'), to_date('07-08-2003', 'dd-mm-yyyy'), 2, 4222, to_date('07-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020904017940, to_date('04-09-2002', 'dd-mm-yyyy'), to_date('18-09-2002', 'dd-mm-yyyy'), 1, 2694, to_date('16-09-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051208017941, to_date('08-12-2005', 'dd-mm-yyyy'), to_date('22-12-2005', 'dd-mm-yyyy'), 2, 3571, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010620017942, to_date('20-06-2001', 'dd-mm-yyyy'), to_date('04-07-2001', 'dd-mm-yyyy'), 1, 1062, to_date('23-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110617017943, to_date('17-06-2011', 'dd-mm-yyyy'), to_date('01-07-2011', 'dd-mm-yyyy'), 1, 5774, to_date('29-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000107017944, to_date('07-01-2000', 'dd-mm-yyyy'), to_date('21-01-2000', 'dd-mm-yyyy'), 2, 1203, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000820017945, to_date('20-08-2000', 'dd-mm-yyyy'), to_date('03-09-2000', 'dd-mm-yyyy'), 2, 1908, to_date('27-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130410017946, to_date('10-04-2013', 'dd-mm-yyyy'), to_date('24-04-2013', 'dd-mm-yyyy'), 2, 10303, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140308017947, to_date('08-03-2014', 'dd-mm-yyyy'), to_date('22-03-2014', 'dd-mm-yyyy'), 2, 10025, to_date('21-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130521017948, to_date('21-05-2013', 'dd-mm-yyyy'), to_date('04-06-2013', 'dd-mm-yyyy'), 2, 8800, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140102017949, to_date('02-01-2014', 'dd-mm-yyyy'), to_date('16-01-2014', 'dd-mm-yyyy'), 2, 9963, to_date('11-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011207017950, to_date('07-12-2001', 'dd-mm-yyyy'), to_date('21-12-2001', 'dd-mm-yyyy'), 1, 1243, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070212017951, to_date('12-02-2007', 'dd-mm-yyyy'), to_date('26-02-2007', 'dd-mm-yyyy'), 1, 7194, to_date('18-02-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031109017952, to_date('09-11-2003', 'dd-mm-yyyy'), to_date('23-11-2003', 'dd-mm-yyyy'), 1, 3009, to_date('16-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100923017953, to_date('23-09-2010', 'dd-mm-yyyy'), to_date('07-10-2010', 'dd-mm-yyyy'), 1, 6772, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120724017954, to_date('24-07-2012', 'dd-mm-yyyy'), to_date('07-08-2012', 'dd-mm-yyyy'), 1, 9887, to_date('03-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000822017955, to_date('22-08-2000', 'dd-mm-yyyy'), to_date('05-09-2000', 'dd-mm-yyyy'), 1, 3837, to_date('26-08-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051109017956, to_date('09-11-2005', 'dd-mm-yyyy'), to_date('23-11-2005', 'dd-mm-yyyy'), 1, 4448, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091226017957, to_date('26-12-2009', 'dd-mm-yyyy'), to_date('09-01-2010', 'dd-mm-yyyy'), 2, 6243, to_date('13-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110906017958, to_date('06-09-2011', 'dd-mm-yyyy'), to_date('20-09-2011', 'dd-mm-yyyy'), 1, 9198, to_date('26-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060407017959, to_date('07-04-2006', 'dd-mm-yyyy'), to_date('21-04-2006', 'dd-mm-yyyy'), 1, 3393, to_date('11-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050712017960, to_date('12-07-2005', 'dd-mm-yyyy'), to_date('26-07-2005', 'dd-mm-yyyy'), 2, 2069, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020324017961, to_date('24-03-2002', 'dd-mm-yyyy'), to_date('07-04-2002', 'dd-mm-yyyy'), 1, 5067, to_date('05-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030805017962, to_date('05-08-2003', 'dd-mm-yyyy'), to_date('19-08-2003', 'dd-mm-yyyy'), 1, 1827, to_date('15-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080330017963, to_date('30-03-2008', 'dd-mm-yyyy'), to_date('13-04-2008', 'dd-mm-yyyy'), 2, 6572, to_date('17-04-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120312017964, to_date('12-03-2012', 'dd-mm-yyyy'), to_date('26-03-2012', 'dd-mm-yyyy'), 2, 8039, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081123017965, to_date('23-11-2008', 'dd-mm-yyyy'), to_date('07-12-2008', 'dd-mm-yyyy'), 1, 5201, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130613017966, to_date('13-06-2013', 'dd-mm-yyyy'), to_date('27-06-2013', 'dd-mm-yyyy'), 2, 10903, to_date('29-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091101017967, to_date('01-11-2009', 'dd-mm-yyyy'), to_date('15-11-2009', 'dd-mm-yyyy'), 2, 6678, to_date('06-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030108017968, to_date('08-01-2003', 'dd-mm-yyyy'), to_date('22-01-2003', 'dd-mm-yyyy'), 2, 2072, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091217017969, to_date('17-12-2009', 'dd-mm-yyyy'), to_date('31-12-2009', 'dd-mm-yyyy'), 2, 4976, to_date('02-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090429017970, to_date('29-04-2009', 'dd-mm-yyyy'), to_date('13-05-2009', 'dd-mm-yyyy'), 1, 5538, to_date('02-05-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050916017971, to_date('16-09-2005', 'dd-mm-yyyy'), to_date('30-09-2005', 'dd-mm-yyyy'), 2, 3623, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070402017972, to_date('02-04-2007', 'dd-mm-yyyy'), to_date('16-04-2007', 'dd-mm-yyyy'), 1, 6562, to_date('07-04-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010504017973, to_date('04-05-2001', 'dd-mm-yyyy'), to_date('18-05-2001', 'dd-mm-yyyy'), 1, 2722, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010301017974, to_date('01-03-2001', 'dd-mm-yyyy'), to_date('15-03-2001', 'dd-mm-yyyy'), 1, 2893, to_date('19-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020621017975, to_date('21-06-2002', 'dd-mm-yyyy'), to_date('05-07-2002', 'dd-mm-yyyy'), 1, 1647, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100717017976, to_date('17-07-2010', 'dd-mm-yyyy'), to_date('31-07-2010', 'dd-mm-yyyy'), 1, 9133, to_date('28-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001028017977, to_date('28-10-2000', 'dd-mm-yyyy'), to_date('11-11-2000', 'dd-mm-yyyy'), 1, 1297, to_date('09-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050520017978, to_date('20-05-2005', 'dd-mm-yyyy'), to_date('03-06-2005', 'dd-mm-yyyy'), 2, 4205, to_date('01-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130424017979, to_date('24-04-2013', 'dd-mm-yyyy'), to_date('08-05-2013', 'dd-mm-yyyy'), 1, 9908, to_date('05-05-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130220017980, to_date('20-02-2013', 'dd-mm-yyyy'), to_date('06-03-2013', 'dd-mm-yyyy'), 2, 6605, to_date('26-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110516017981, to_date('16-05-2011', 'dd-mm-yyyy'), to_date('30-05-2011', 'dd-mm-yyyy'), 1, 5849, to_date('18-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120607017982, to_date('07-06-2012', 'dd-mm-yyyy'), to_date('21-06-2012', 'dd-mm-yyyy'), 2, 7353, to_date('23-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120823017983, to_date('23-08-2012', 'dd-mm-yyyy'), to_date('06-09-2012', 'dd-mm-yyyy'), 1, 8362, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820017984, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 1, 5217, to_date('07-09-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071127017985, to_date('27-11-2007', 'dd-mm-yyyy'), to_date('11-12-2007', 'dd-mm-yyyy'), 1, 4146, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010222017986, to_date('22-02-2001', 'dd-mm-yyyy'), to_date('08-03-2001', 'dd-mm-yyyy'), 2, 1370, to_date('05-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090102017987, to_date('02-01-2009', 'dd-mm-yyyy'), to_date('16-01-2009', 'dd-mm-yyyy'), 1, 6628, to_date('14-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090727017988, to_date('27-07-2009', 'dd-mm-yyyy'), to_date('10-08-2009', 'dd-mm-yyyy'), 1, 6938, to_date('05-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110225017989, to_date('25-02-2011', 'dd-mm-yyyy'), to_date('11-03-2011', 'dd-mm-yyyy'), 1, 5316, to_date('04-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101030017990, to_date('30-10-2010', 'dd-mm-yyyy'), to_date('13-11-2010', 'dd-mm-yyyy'), 1, 8378, to_date('16-11-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110821017991, to_date('21-08-2011', 'dd-mm-yyyy'), to_date('04-09-2011', 'dd-mm-yyyy'), 1, 7296, to_date('01-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031106017992, to_date('06-11-2003', 'dd-mm-yyyy'), to_date('20-11-2003', 'dd-mm-yyyy'), 1, 3034, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130724017993, to_date('24-07-2013', 'dd-mm-yyyy'), to_date('07-08-2013', 'dd-mm-yyyy'), 2, 7005, to_date('31-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030127017994, to_date('27-01-2003', 'dd-mm-yyyy'), to_date('10-02-2003', 'dd-mm-yyyy'), 1, 3038, to_date('15-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021027017995, to_date('27-10-2002', 'dd-mm-yyyy'), to_date('10-11-2002', 'dd-mm-yyyy'), 2, 1799, to_date('04-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020430017996, to_date('30-04-2002', 'dd-mm-yyyy'), to_date('14-05-2002', 'dd-mm-yyyy'), 1, 2971, to_date('03-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020810017997, to_date('10-08-2002', 'dd-mm-yyyy'), to_date('24-08-2002', 'dd-mm-yyyy'), 1, 3768, to_date('14-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140111017998, to_date('11-01-2014', 'dd-mm-yyyy'), to_date('25-01-2014', 'dd-mm-yyyy'), 2, 9564, to_date('17-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110816017999, to_date('16-08-2011', 'dd-mm-yyyy'), to_date('30-08-2011', 'dd-mm-yyyy'), 1, 8182, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001011018000, to_date('11-10-2000', 'dd-mm-yyyy'), to_date('25-10-2000', 'dd-mm-yyyy'), 2, 1097, to_date('29-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020402018001, to_date('02-04-2002', 'dd-mm-yyyy'), to_date('16-04-2002', 'dd-mm-yyyy'), 1, 3635, to_date('15-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070707018002, to_date('07-07-2007', 'dd-mm-yyyy'), to_date('21-07-2007', 'dd-mm-yyyy'), 2, 6489, to_date('09-07-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080725009949, to_date('25-07-2008', 'dd-mm-yyyy'), to_date('08-08-2008', 'dd-mm-yyyy'), 3, 7309, to_date('29-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111030009950, to_date('30-10-2011', 'dd-mm-yyyy'), to_date('13-11-2011', 'dd-mm-yyyy'), 3, 6787, to_date('05-11-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050314009951, to_date('14-03-2005', 'dd-mm-yyyy'), to_date('28-03-2005', 'dd-mm-yyyy'), 3, 2955, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010920009952, to_date('20-09-2001', 'dd-mm-yyyy'), to_date('04-10-2001', 'dd-mm-yyyy'), 2, 787, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120305009953, to_date('05-03-2012', 'dd-mm-yyyy'), to_date('19-03-2012', 'dd-mm-yyyy'), 9, 7423, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100615009954, to_date('15-06-2010', 'dd-mm-yyyy'), to_date('29-06-2010', 'dd-mm-yyyy'), 10, 7658, to_date('19-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090215009955, to_date('15-02-2009', 'dd-mm-yyyy'), to_date('01-03-2009', 'dd-mm-yyyy'), 8, 5366, to_date('06-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090301009956, to_date('01-03-2009', 'dd-mm-yyyy'), to_date('15-03-2009', 'dd-mm-yyyy'), 8, 9563, to_date('08-03-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080501009957, to_date('01-05-2008', 'dd-mm-yyyy'), to_date('15-05-2008', 'dd-mm-yyyy'), 4, 7957, to_date('08-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031219009958, to_date('19-12-2003', 'dd-mm-yyyy'), to_date('02-01-2004', 'dd-mm-yyyy'), 11, 3575, to_date('26-12-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060129009959, to_date('29-01-2006', 'dd-mm-yyyy'), to_date('12-02-2006', 'dd-mm-yyyy'), 11, 5037, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419009960, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 11, 3217, to_date('30-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111022009961, to_date('22-10-2011', 'dd-mm-yyyy'), to_date('05-11-2011', 'dd-mm-yyyy'), 12, 6289, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080919009962, to_date('19-09-2008', 'dd-mm-yyyy'), to_date('03-10-2008', 'dd-mm-yyyy'), 10, 7288, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100621009963, to_date('21-06-2010', 'dd-mm-yyyy'), to_date('05-07-2010', 'dd-mm-yyyy'), 3, 7238, to_date('09-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041025009964, to_date('25-10-2004', 'dd-mm-yyyy'), to_date('08-11-2004', 'dd-mm-yyyy'), 9, 2557, to_date('09-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041214009965, to_date('14-12-2004', 'dd-mm-yyyy'), to_date('28-12-2004', 'dd-mm-yyyy'), 11, 3756, to_date('21-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041107009966, to_date('07-11-2004', 'dd-mm-yyyy'), to_date('21-11-2004', 'dd-mm-yyyy'), 8, 4123, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100910009967, to_date('10-09-2010', 'dd-mm-yyyy'), to_date('24-09-2010', 'dd-mm-yyyy'), 4, 7148, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110915009968, to_date('15-09-2011', 'dd-mm-yyyy'), to_date('29-09-2011', 'dd-mm-yyyy'), 11, 7396, to_date('01-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120714009969, to_date('14-07-2012', 'dd-mm-yyyy'), to_date('28-07-2012', 'dd-mm-yyyy'), 7, 8997, to_date('26-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070222009970, to_date('22-02-2007', 'dd-mm-yyyy'), to_date('08-03-2007', 'dd-mm-yyyy'), 8, 5029, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100929009971, to_date('29-09-2010', 'dd-mm-yyyy'), to_date('13-10-2010', 'dd-mm-yyyy'), 4, 8444, to_date('10-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021204009972, to_date('04-12-2002', 'dd-mm-yyyy'), to_date('18-12-2002', 'dd-mm-yyyy'), 4, 2344, to_date('23-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100106009973, to_date('06-01-2010', 'dd-mm-yyyy'), to_date('20-01-2010', 'dd-mm-yyyy'), 8, 4776, to_date('22-01-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010911009974, to_date('11-09-2001', 'dd-mm-yyyy'), to_date('25-09-2001', 'dd-mm-yyyy'), 10, 3324, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131127009975, to_date('27-11-2013', 'dd-mm-yyyy'), to_date('11-12-2013', 'dd-mm-yyyy'), 3, 10060, to_date('13-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070907009976, to_date('07-09-2007', 'dd-mm-yyyy'), to_date('21-09-2007', 'dd-mm-yyyy'), 6, 4947, to_date('21-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110307009977, to_date('07-03-2011', 'dd-mm-yyyy'), to_date('21-03-2011', 'dd-mm-yyyy'), 3, 7921, to_date('16-03-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071128009978, to_date('28-11-2007', 'dd-mm-yyyy'), to_date('12-12-2007', 'dd-mm-yyyy'), 10, 4422, to_date('14-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111223009979, to_date('23-12-2011', 'dd-mm-yyyy'), to_date('06-01-2012', 'dd-mm-yyyy'), 6, 8965, to_date('10-01-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111211009980, to_date('11-12-2011', 'dd-mm-yyyy'), to_date('25-12-2011', 'dd-mm-yyyy'), 9, 7159, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020827009981, to_date('27-08-2002', 'dd-mm-yyyy'), to_date('10-09-2002', 'dd-mm-yyyy'), 3, 1669, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001001009982, to_date('01-10-2000', 'dd-mm-yyyy'), to_date('15-10-2000', 'dd-mm-yyyy'), 6, 755, to_date('11-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101228009983, to_date('28-12-2010', 'dd-mm-yyyy'), to_date('11-01-2011', 'dd-mm-yyyy'), 10, 7558, to_date('05-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090209009984, to_date('09-02-2009', 'dd-mm-yyyy'), to_date('23-02-2009', 'dd-mm-yyyy'), 2, 8228, to_date('15-02-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100228009985, to_date('28-02-2010', 'dd-mm-yyyy'), to_date('14-03-2010', 'dd-mm-yyyy'), 5, 9471, to_date('19-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131201009986, to_date('01-12-2013', 'dd-mm-yyyy'), to_date('15-12-2013', 'dd-mm-yyyy'), 5, 7584, to_date('18-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131016009987, to_date('16-10-2013', 'dd-mm-yyyy'), to_date('30-10-2013', 'dd-mm-yyyy'), 3, 7682, to_date('27-10-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060709009988, to_date('09-07-2006', 'dd-mm-yyyy'), to_date('23-07-2006', 'dd-mm-yyyy'), 4, 6214, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100623009989, to_date('23-06-2010', 'dd-mm-yyyy'), to_date('07-07-2010', 'dd-mm-yyyy'), 8, 7505, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030221009990, to_date('21-02-2003', 'dd-mm-yyyy'), to_date('07-03-2003', 'dd-mm-yyyy'), 4, 2562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061215009991, to_date('15-12-2006', 'dd-mm-yyyy'), to_date('29-12-2006', 'dd-mm-yyyy'), 1, 5661, to_date('01-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080316009992, to_date('16-03-2008', 'dd-mm-yyyy'), to_date('30-03-2008', 'dd-mm-yyyy'), 11, 5175, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041221009993, to_date('21-12-2004', 'dd-mm-yyyy'), to_date('04-01-2005', 'dd-mm-yyyy'), 9, 4739, to_date('08-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621009994, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 3, 6379, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111014009995, to_date('14-10-2011', 'dd-mm-yyyy'), to_date('28-10-2011', 'dd-mm-yyyy'), 7, 9944, to_date('26-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020925009996, to_date('25-09-2002', 'dd-mm-yyyy'), to_date('09-10-2002', 'dd-mm-yyyy'), 1, 1407, to_date('04-10-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070919009997, to_date('19-09-2007', 'dd-mm-yyyy'), to_date('03-10-2007', 'dd-mm-yyyy'), 6, 6942, to_date('26-09-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130101009998, to_date('01-01-2013', 'dd-mm-yyyy'), to_date('15-01-2013', 'dd-mm-yyyy'), 4, 9583, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030121009999, to_date('21-01-2003', 'dd-mm-yyyy'), to_date('04-02-2003', 'dd-mm-yyyy'), 2, 2591, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120620010000, to_date('20-06-2012', 'dd-mm-yyyy'), to_date('04-07-2012', 'dd-mm-yyyy'), 10, 11817, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140120010001, to_date('20-01-2014', 'dd-mm-yyyy'), to_date('03-02-2014', 'dd-mm-yyyy'), 1, 8118, to_date('31-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040325010002, to_date('25-03-2004', 'dd-mm-yyyy'), to_date('08-04-2004', 'dd-mm-yyyy'), 1, 4376, to_date('04-04-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120513010003, to_date('13-05-2012', 'dd-mm-yyyy'), to_date('27-05-2012', 'dd-mm-yyyy'), 2, 8186, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120222010004, to_date('22-02-2012', 'dd-mm-yyyy'), to_date('07-03-2012', 'dd-mm-yyyy'), 2, 7335, to_date('03-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010605010005, to_date('05-06-2001', 'dd-mm-yyyy'), to_date('19-06-2001', 'dd-mm-yyyy'), 3, 1274, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131218010006, to_date('18-12-2013', 'dd-mm-yyyy'), to_date('01-01-2014', 'dd-mm-yyyy'), 10, 9621, to_date('01-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001206010007, to_date('06-12-2000', 'dd-mm-yyyy'), to_date('20-12-2000', 'dd-mm-yyyy'), 11, 2086, to_date('24-12-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050126010008, to_date('26-01-2005', 'dd-mm-yyyy'), to_date('09-02-2005', 'dd-mm-yyyy'), 3, 4422, to_date('03-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091010010009, to_date('10-10-2009', 'dd-mm-yyyy'), to_date('24-10-2009', 'dd-mm-yyyy'), 7, 6023, to_date('26-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020317010010, to_date('17-03-2002', 'dd-mm-yyyy'), to_date('31-03-2002', 'dd-mm-yyyy'), 11, 3259, to_date('21-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060917010011, to_date('17-09-2006', 'dd-mm-yyyy'), to_date('01-10-2006', 'dd-mm-yyyy'), 10, 5959, to_date('24-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140312010012, to_date('12-03-2014', 'dd-mm-yyyy'), to_date('26-03-2014', 'dd-mm-yyyy'), 6, 11072, to_date('21-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090522010013, to_date('22-05-2009', 'dd-mm-yyyy'), to_date('05-06-2009', 'dd-mm-yyyy'), 10, 6952, to_date('04-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061103010014, to_date('03-11-2006', 'dd-mm-yyyy'), to_date('17-11-2006', 'dd-mm-yyyy'), 2, 3520, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071122010015, to_date('22-11-2007', 'dd-mm-yyyy'), to_date('06-12-2007', 'dd-mm-yyyy'), 7, 4426, to_date('09-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041215010016, to_date('15-12-2004', 'dd-mm-yyyy'), to_date('29-12-2004', 'dd-mm-yyyy'), 10, 2736, to_date('20-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070515010017, to_date('15-05-2007', 'dd-mm-yyyy'), to_date('29-05-2007', 'dd-mm-yyyy'), 3, 6051, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110221010018, to_date('21-02-2011', 'dd-mm-yyyy'), to_date('07-03-2011', 'dd-mm-yyyy'), 10, 6643, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060819010019, to_date('19-08-2006', 'dd-mm-yyyy'), to_date('02-09-2006', 'dd-mm-yyyy'), 10, 4792, to_date('08-09-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020529010020, to_date('29-05-2002', 'dd-mm-yyyy'), to_date('12-06-2002', 'dd-mm-yyyy'), 6, 1982, to_date('18-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000920010021, to_date('20-09-2000', 'dd-mm-yyyy'), to_date('04-10-2000', 'dd-mm-yyyy'), 9, 2317, to_date('23-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011113010022, to_date('13-11-2001', 'dd-mm-yyyy'), to_date('27-11-2001', 'dd-mm-yyyy'), 12, 2065, to_date('15-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010912010023, to_date('12-09-2001', 'dd-mm-yyyy'), to_date('26-09-2001', 'dd-mm-yyyy'), 3, 1808, to_date('02-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070426010024, to_date('26-04-2007', 'dd-mm-yyyy'), to_date('10-05-2007', 'dd-mm-yyyy'), 7, 6497, to_date('11-05-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050803010025, to_date('03-08-2005', 'dd-mm-yyyy'), to_date('17-08-2005', 'dd-mm-yyyy'), 11, 4278, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140507010026, to_date('07-05-2014', 'dd-mm-yyyy'), to_date('21-05-2014', 'dd-mm-yyyy'), 2, 7206, to_date('15-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070223010027, to_date('23-02-2007', 'dd-mm-yyyy'), to_date('09-03-2007', 'dd-mm-yyyy'), 4, 4991, to_date('01-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20111004010028, to_date('04-10-2011', 'dd-mm-yyyy'), to_date('18-10-2011', 'dd-mm-yyyy'), 5, 7223, to_date('17-10-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010621010029, to_date('21-06-2001', 'dd-mm-yyyy'), to_date('05-07-2001', 'dd-mm-yyyy'), 11, 2080, to_date('01-07-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041208010030, to_date('08-12-2004', 'dd-mm-yyyy'), to_date('22-12-2004', 'dd-mm-yyyy'), 10, 4827, to_date('24-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100524010031, to_date('24-05-2010', 'dd-mm-yyyy'), to_date('07-06-2010', 'dd-mm-yyyy'), 7, 8425, to_date('08-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110110010032, to_date('10-01-2011', 'dd-mm-yyyy'), to_date('24-01-2011', 'dd-mm-yyyy'), 7, 6494, to_date('13-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060828010033, to_date('28-08-2006', 'dd-mm-yyyy'), to_date('11-09-2006', 'dd-mm-yyyy'), 3, 4214, to_date('31-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000603010034, to_date('03-06-2000', 'dd-mm-yyyy'), to_date('17-06-2000', 'dd-mm-yyyy'), 12, 1956, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000228010035, to_date('28-02-2000', 'dd-mm-yyyy'), to_date('13-03-2000', 'dd-mm-yyyy'), 4, 2861, to_date('14-03-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050218010036, to_date('18-02-2005', 'dd-mm-yyyy'), to_date('04-03-2005', 'dd-mm-yyyy'), 6, 4960, to_date('22-02-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130123010037, to_date('23-01-2013', 'dd-mm-yyyy'), to_date('06-02-2013', 'dd-mm-yyyy'), 9, 9848, to_date('08-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030418010038, to_date('18-04-2003', 'dd-mm-yyyy'), to_date('02-05-2003', 'dd-mm-yyyy'), 10, 2825, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120215010039, to_date('15-02-2012', 'dd-mm-yyyy'), to_date('29-02-2012', 'dd-mm-yyyy'), 8, 6164, to_date('26-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081230010040, to_date('30-12-2008', 'dd-mm-yyyy'), to_date('13-01-2009', 'dd-mm-yyyy'), 3, 5302, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090925010041, to_date('25-09-2009', 'dd-mm-yyyy'), to_date('09-10-2009', 'dd-mm-yyyy'), 5, 7814, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071224010042, to_date('24-12-2007', 'dd-mm-yyyy'), to_date('07-01-2008', 'dd-mm-yyyy'), 8, 5183, to_date('05-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061009010043, to_date('09-10-2006', 'dd-mm-yyyy'), to_date('23-10-2006', 'dd-mm-yyyy'), 9, 4630, to_date('29-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000919010044, to_date('19-09-2000', 'dd-mm-yyyy'), to_date('03-10-2000', 'dd-mm-yyyy'), 7, 2979, to_date('25-09-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000601010045, to_date('01-06-2000', 'dd-mm-yyyy'), to_date('15-06-2000', 'dd-mm-yyyy'), 4, 3110, to_date('15-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001002010046, to_date('02-10-2000', 'dd-mm-yyyy'), to_date('16-10-2000', 'dd-mm-yyyy'), 11, 3078, to_date('10-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130702010047, to_date('02-07-2013', 'dd-mm-yyyy'), to_date('16-07-2013', 'dd-mm-yyyy'), 2, 7371, to_date('06-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140404010048, to_date('04-04-2014', 'dd-mm-yyyy'), to_date('18-04-2014', 'dd-mm-yyyy'), 7, 7706, to_date('17-04-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100915010049, to_date('15-09-2010', 'dd-mm-yyyy'), to_date('29-09-2010', 'dd-mm-yyyy'), 9, 10188, to_date('02-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020404010050, to_date('04-04-2002', 'dd-mm-yyyy'), to_date('18-04-2002', 'dd-mm-yyyy'), 5, 2837, to_date('06-04-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010731010051, to_date('31-07-2001', 'dd-mm-yyyy'), to_date('14-08-2001', 'dd-mm-yyyy'), 11, 2528, to_date('15-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051205010052, to_date('05-12-2005', 'dd-mm-yyyy'), to_date('19-12-2005', 'dd-mm-yyyy'), 5, 6054, to_date('08-12-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070730010053, to_date('30-07-2007', 'dd-mm-yyyy'), to_date('13-08-2007', 'dd-mm-yyyy'), 7, 5548, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060608010054, to_date('08-06-2006', 'dd-mm-yyyy'), to_date('22-06-2006', 'dd-mm-yyyy'), 2, 6441, to_date('11-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020506010055, to_date('06-05-2002', 'dd-mm-yyyy'), to_date('20-05-2002', 'dd-mm-yyyy'), 12, 2380, to_date('08-05-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110417010056, to_date('17-04-2011', 'dd-mm-yyyy'), to_date('01-05-2011', 'dd-mm-yyyy'), 10, 8700, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120726010057, to_date('26-07-2012', 'dd-mm-yyyy'), to_date('09-08-2012', 'dd-mm-yyyy'), 5, 10087, to_date('04-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030320010058, to_date('20-03-2003', 'dd-mm-yyyy'), to_date('03-04-2003', 'dd-mm-yyyy'), 8, 3615, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070904010059, to_date('04-09-2007', 'dd-mm-yyyy'), to_date('18-09-2007', 'dd-mm-yyyy'), 5, 4495, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050918010060, to_date('18-09-2005', 'dd-mm-yyyy'), to_date('02-10-2005', 'dd-mm-yyyy'), 6, 4032, to_date('21-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101205010061, to_date('05-12-2010', 'dd-mm-yyyy'), to_date('19-12-2010', 'dd-mm-yyyy'), 12, 5080, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120904010062, to_date('04-09-2012', 'dd-mm-yyyy'), to_date('18-09-2012', 'dd-mm-yyyy'), 5, 6711, to_date('21-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000922010063, to_date('22-09-2000', 'dd-mm-yyyy'), to_date('06-10-2000', 'dd-mm-yyyy'), 5, 2596, to_date('02-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030416010064, to_date('16-04-2003', 'dd-mm-yyyy'), to_date('30-04-2003', 'dd-mm-yyyy'), 7, 4520, to_date('21-04-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101020010065, to_date('20-10-2010', 'dd-mm-yyyy'), to_date('03-11-2010', 'dd-mm-yyyy'), 7, 3799, to_date('24-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021119010066, to_date('19-11-2002', 'dd-mm-yyyy'), to_date('03-12-2002', 'dd-mm-yyyy'), 11, 3438, to_date('25-11-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140204010067, to_date('04-02-2014', 'dd-mm-yyyy'), to_date('18-02-2014', 'dd-mm-yyyy'), 10, 11233, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140506010068, to_date('06-05-2014', 'dd-mm-yyyy'), to_date('20-05-2014', 'dd-mm-yyyy'), 9, 12090, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130720010069, to_date('20-07-2013', 'dd-mm-yyyy'), to_date('03-08-2013', 'dd-mm-yyyy'), 7, 8544, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060708010070, to_date('08-07-2006', 'dd-mm-yyyy'), to_date('22-07-2006', 'dd-mm-yyyy'), 5, 3929, to_date('19-07-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140106010071, to_date('06-01-2014', 'dd-mm-yyyy'), to_date('20-01-2014', 'dd-mm-yyyy'), 11, 6240, to_date('09-01-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040418010072, to_date('18-04-2004', 'dd-mm-yyyy'), to_date('02-05-2004', 'dd-mm-yyyy'), 3, 3382, to_date('04-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100407010073, to_date('07-04-2010', 'dd-mm-yyyy'), to_date('21-04-2010', 'dd-mm-yyyy'), 11, 7311, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090917010074, to_date('17-09-2009', 'dd-mm-yyyy'), to_date('01-10-2009', 'dd-mm-yyyy'), 4, 6592, to_date('02-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010905010075, to_date('05-09-2001', 'dd-mm-yyyy'), to_date('19-09-2001', 'dd-mm-yyyy'), 6, 1898, to_date('09-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090823010076, to_date('23-08-2009', 'dd-mm-yyyy'), to_date('06-09-2009', 'dd-mm-yyyy'), 11, 5126, to_date('30-08-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060818010077, to_date('18-08-2006', 'dd-mm-yyyy'), to_date('01-09-2006', 'dd-mm-yyyy'), 6, 3499, to_date('31-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060424010078, to_date('24-04-2006', 'dd-mm-yyyy'), to_date('08-05-2006', 'dd-mm-yyyy'), 2, 5056, to_date('02-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001018010079, to_date('18-10-2000', 'dd-mm-yyyy'), to_date('01-11-2000', 'dd-mm-yyyy'), 12, 1330, to_date('25-10-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000201010080, to_date('01-02-2000', 'dd-mm-yyyy'), to_date('15-02-2000', 'dd-mm-yyyy'), 5, 1931, to_date('09-02-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130805010081, to_date('05-08-2013', 'dd-mm-yyyy'), to_date('19-08-2013', 'dd-mm-yyyy'), 5, 8845, to_date('24-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080702010082, to_date('02-07-2008', 'dd-mm-yyyy'), to_date('16-07-2008', 'dd-mm-yyyy'), 11, 8163, to_date('06-07-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120310010083, to_date('10-03-2012', 'dd-mm-yyyy'), to_date('24-03-2012', 'dd-mm-yyyy'), 9, 10831, to_date('12-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010817010084, to_date('17-08-2001', 'dd-mm-yyyy'), to_date('31-08-2001', 'dd-mm-yyyy'), 7, 2229, to_date('26-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131220010085, to_date('20-12-2013', 'dd-mm-yyyy'), to_date('03-01-2014', 'dd-mm-yyyy'), 10, 9178, to_date('25-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001004010086, to_date('04-10-2000', 'dd-mm-yyyy'), to_date('18-10-2000', 'dd-mm-yyyy'), 11, 1784, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021224010087, to_date('24-12-2002', 'dd-mm-yyyy'), to_date('07-01-2003', 'dd-mm-yyyy'), 1, 1054, to_date('28-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010407010088, to_date('07-04-2001', 'dd-mm-yyyy'), to_date('21-04-2001', 'dd-mm-yyyy'), 7, 3540, to_date('20-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120822010089, to_date('22-08-2012', 'dd-mm-yyyy'), to_date('05-09-2012', 'dd-mm-yyyy'), 1, 11085, to_date('24-08-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090820010090, to_date('20-08-2009', 'dd-mm-yyyy'), to_date('03-09-2009', 'dd-mm-yyyy'), 4, 8465, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010725010091, to_date('25-07-2001', 'dd-mm-yyyy'), to_date('08-08-2001', 'dd-mm-yyyy'), 9, 3103, to_date('03-08-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030628010092, to_date('28-06-2003', 'dd-mm-yyyy'), to_date('12-07-2003', 'dd-mm-yyyy'), 12, 3205, to_date('04-07-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120717010093, to_date('17-07-2012', 'dd-mm-yyyy'), to_date('31-07-2012', 'dd-mm-yyyy'), 4, 6630, to_date('24-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140508010094, to_date('08-05-2014', 'dd-mm-yyyy'), to_date('22-05-2014', 'dd-mm-yyyy'), 7, 9890, to_date('23-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050826010095, to_date('26-08-2005', 'dd-mm-yyyy'), to_date('09-09-2005', 'dd-mm-yyyy'), 2, 6252, to_date('30-08-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120914010096, to_date('14-09-2012', 'dd-mm-yyyy'), to_date('28-09-2012', 'dd-mm-yyyy'), 10, 9452, to_date('29-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010313010097, to_date('13-03-2001', 'dd-mm-yyyy'), to_date('27-03-2001', 'dd-mm-yyyy'), 5, 1731, to_date('01-04-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060321010098, to_date('21-03-2006', 'dd-mm-yyyy'), to_date('04-04-2006', 'dd-mm-yyyy'), 5, 6361, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010210010099, to_date('10-02-2001', 'dd-mm-yyyy'), to_date('24-02-2001', 'dd-mm-yyyy'), 2, 1756, to_date('13-02-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090605010100, to_date('05-06-2009', 'dd-mm-yyyy'), to_date('19-06-2009', 'dd-mm-yyyy'), 5, 6368, to_date('09-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041230010101, to_date('30-12-2004', 'dd-mm-yyyy'), to_date('13-01-2005', 'dd-mm-yyyy'), 3, 4647, to_date('02-01-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030314010102, to_date('14-03-2003', 'dd-mm-yyyy'), to_date('28-03-2003', 'dd-mm-yyyy'), 11, 2302, to_date('17-03-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100702012524, to_date('02-07-2010', 'dd-mm-yyyy'), to_date('16-07-2010', 'dd-mm-yyyy'), 2, 6710, to_date('19-07-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020610012525, to_date('10-06-2002', 'dd-mm-yyyy'), to_date('24-06-2002', 'dd-mm-yyyy'), 3, 2262, to_date('23-06-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040218012526, to_date('18-02-2004', 'dd-mm-yyyy'), to_date('03-03-2004', 'dd-mm-yyyy'), 1, 5562, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040729012527, to_date('29-07-2004', 'dd-mm-yyyy'), to_date('12-08-2004', 'dd-mm-yyyy'), 4, 3023, to_date('08-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050317012528, to_date('17-03-2005', 'dd-mm-yyyy'), to_date('31-03-2005', 'dd-mm-yyyy'), 2, 4457, to_date('26-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011006012529, to_date('06-10-2001', 'dd-mm-yyyy'), to_date('20-10-2001', 'dd-mm-yyyy'), 2, 1574, to_date('11-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120625012530, to_date('25-06-2012', 'dd-mm-yyyy'), to_date('09-07-2012', 'dd-mm-yyyy'), 2, 9275, to_date('15-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031101012531, to_date('01-11-2003', 'dd-mm-yyyy'), to_date('15-11-2003', 'dd-mm-yyyy'), 2, 3946, to_date('09-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041118012532, to_date('18-11-2004', 'dd-mm-yyyy'), to_date('02-12-2004', 'dd-mm-yyyy'), 3, 5371, to_date('22-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090302012533, to_date('02-03-2009', 'dd-mm-yyyy'), to_date('16-03-2009', 'dd-mm-yyyy'), 1, 6421, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020704012534, to_date('04-07-2002', 'dd-mm-yyyy'), to_date('18-07-2002', 'dd-mm-yyyy'), 4, 4061, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040831012535, to_date('31-08-2004', 'dd-mm-yyyy'), to_date('14-09-2004', 'dd-mm-yyyy'), 2, 4430, to_date('08-09-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010227012536, to_date('27-02-2001', 'dd-mm-yyyy'), to_date('13-03-2001', 'dd-mm-yyyy'), 3, 4740, to_date('10-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120514012537, to_date('14-05-2012', 'dd-mm-yyyy'), to_date('28-05-2012', 'dd-mm-yyyy'), 4, 9961, to_date('30-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080731012538, to_date('31-07-2008', 'dd-mm-yyyy'), to_date('14-08-2008', 'dd-mm-yyyy'), 4, 7942, to_date('19-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070310012539, to_date('10-03-2007', 'dd-mm-yyyy'), to_date('24-03-2007', 'dd-mm-yyyy'), 3, 7791, to_date('29-03-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110530012540, to_date('30-05-2011', 'dd-mm-yyyy'), to_date('13-06-2011', 'dd-mm-yyyy'), 3, 6346, to_date('11-06-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120205012541, to_date('05-02-2012', 'dd-mm-yyyy'), to_date('19-02-2012', 'dd-mm-yyyy'), 3, 5999, to_date('23-02-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041008012542, to_date('08-10-2004', 'dd-mm-yyyy'), to_date('22-10-2004', 'dd-mm-yyyy'), 2, 4311, to_date('27-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121007012543, to_date('07-10-2012', 'dd-mm-yyyy'), to_date('21-10-2012', 'dd-mm-yyyy'), 1, 7540, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051109012544, to_date('09-11-2005', 'dd-mm-yyyy'), to_date('23-11-2005', 'dd-mm-yyyy'), 1, 4505, to_date('17-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120723012545, to_date('23-07-2012', 'dd-mm-yyyy'), to_date('06-08-2012', 'dd-mm-yyyy'), 1, 7097, to_date('24-07-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070706012546, to_date('06-07-2007', 'dd-mm-yyyy'), to_date('20-07-2007', 'dd-mm-yyyy'), 2, 6095, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061212012547, to_date('12-12-2006', 'dd-mm-yyyy'), to_date('26-12-2006', 'dd-mm-yyyy'), 4, 3804, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051228012548, to_date('28-12-2005', 'dd-mm-yyyy'), to_date('11-01-2006', 'dd-mm-yyyy'), 2, 3387, to_date('08-01-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120728012549, to_date('28-07-2012', 'dd-mm-yyyy'), to_date('11-08-2012', 'dd-mm-yyyy'), 3, 8235, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090404012550, to_date('04-04-2009', 'dd-mm-yyyy'), to_date('18-04-2009', 'dd-mm-yyyy'), 3, 5819, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040310012551, to_date('10-03-2004', 'dd-mm-yyyy'), to_date('24-03-2004', 'dd-mm-yyyy'), 2, 3237, to_date('13-03-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091031012552, to_date('31-10-2009', 'dd-mm-yyyy'), to_date('14-11-2009', 'dd-mm-yyyy'), 2, 6737, to_date('13-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030623012553, to_date('23-06-2003', 'dd-mm-yyyy'), to_date('07-07-2003', 'dd-mm-yyyy'), 2, 2200, to_date('29-06-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010525012554, to_date('25-05-2001', 'dd-mm-yyyy'), to_date('08-06-2001', 'dd-mm-yyyy'), 2, 2801, to_date('13-06-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031027012555, to_date('27-10-2003', 'dd-mm-yyyy'), to_date('10-11-2003', 'dd-mm-yyyy'), 3, 3759, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011227012556, to_date('27-12-2001', 'dd-mm-yyyy'), to_date('10-01-2002', 'dd-mm-yyyy'), 4, 2277, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101018012557, to_date('18-10-2010', 'dd-mm-yyyy'), to_date('01-11-2010', 'dd-mm-yyyy'), 2, 10198, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031022012558, to_date('22-10-2003', 'dd-mm-yyyy'), to_date('05-11-2003', 'dd-mm-yyyy'), 4, 3684, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120610012559, to_date('10-06-2012', 'dd-mm-yyyy'), to_date('24-06-2012', 'dd-mm-yyyy'), 2, 7666, to_date('18-06-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050909012560, to_date('09-09-2005', 'dd-mm-yyyy'), to_date('23-09-2005', 'dd-mm-yyyy'), 4, 4599, to_date('16-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120817012561, to_date('17-08-2012', 'dd-mm-yyyy'), to_date('31-08-2012', 'dd-mm-yyyy'), 3, 9544, to_date('04-09-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101222012562, to_date('22-12-2010', 'dd-mm-yyyy'), to_date('05-01-2011', 'dd-mm-yyyy'), 3, 7648, to_date('07-01-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050112012563, to_date('12-01-2005', 'dd-mm-yyyy'), to_date('26-01-2005', 'dd-mm-yyyy'), 3, 2373, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010929012564, to_date('29-09-2001', 'dd-mm-yyyy'), to_date('13-10-2001', 'dd-mm-yyyy'), 3, 2368, to_date('06-10-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080130012565, to_date('30-01-2008', 'dd-mm-yyyy'), to_date('13-02-2008', 'dd-mm-yyyy'), 2, 7293, to_date('14-02-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110904012566, to_date('04-09-2011', 'dd-mm-yyyy'), to_date('18-09-2011', 'dd-mm-yyyy'), 2, 11098, to_date('08-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130206012567, to_date('06-02-2013', 'dd-mm-yyyy'), to_date('20-02-2013', 'dd-mm-yyyy'), 4, 8771, to_date('13-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130902012568, to_date('02-09-2013', 'dd-mm-yyyy'), to_date('16-09-2013', 'dd-mm-yyyy'), 4, 6358, to_date('13-09-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001228012569, to_date('28-12-2000', 'dd-mm-yyyy'), to_date('11-01-2001', 'dd-mm-yyyy'), 2, 1563, to_date('05-01-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080922012570, to_date('22-09-2008', 'dd-mm-yyyy'), to_date('06-10-2008', 'dd-mm-yyyy'), 3, 5972, to_date('06-10-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090524012571, to_date('24-05-2009', 'dd-mm-yyyy'), to_date('07-06-2009', 'dd-mm-yyyy'), 4, 5959, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20001017012572, to_date('17-10-2000', 'dd-mm-yyyy'), to_date('31-10-2000', 'dd-mm-yyyy'), 2, 2234, to_date('02-11-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070526012573, to_date('26-05-2007', 'dd-mm-yyyy'), to_date('09-06-2007', 'dd-mm-yyyy'), 4, 5372, to_date('06-06-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030214012574, to_date('14-02-2003', 'dd-mm-yyyy'), to_date('28-02-2003', 'dd-mm-yyyy'), 1, 3603, to_date('20-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090624012575, to_date('24-06-2009', 'dd-mm-yyyy'), to_date('08-07-2009', 'dd-mm-yyyy'), 4, 7861, to_date('25-06-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070406012576, to_date('06-04-2007', 'dd-mm-yyyy'), to_date('20-04-2007', 'dd-mm-yyyy'), 2, 5282, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100626012577, to_date('26-06-2010', 'dd-mm-yyyy'), to_date('10-07-2010', 'dd-mm-yyyy'), 3, 8860, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040825012578, to_date('25-08-2004', 'dd-mm-yyyy'), to_date('08-09-2004', 'dd-mm-yyyy'), 2, 3810, to_date('30-08-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031017012579, to_date('17-10-2003', 'dd-mm-yyyy'), to_date('31-10-2003', 'dd-mm-yyyy'), 2, 1412, to_date('01-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090103012580, to_date('03-01-2009', 'dd-mm-yyyy'), to_date('17-01-2009', 'dd-mm-yyyy'), 3, 5904, to_date('14-01-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050810012581, to_date('10-08-2005', 'dd-mm-yyyy'), to_date('24-08-2005', 'dd-mm-yyyy'), 4, 4212, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000605012582, to_date('05-06-2000', 'dd-mm-yyyy'), to_date('19-06-2000', 'dd-mm-yyyy'), 1, 1583, to_date('08-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130801012583, to_date('01-08-2013', 'dd-mm-yyyy'), to_date('15-08-2013', 'dd-mm-yyyy'), 3, 7780, to_date('12-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000602012584, to_date('02-06-2000', 'dd-mm-yyyy'), to_date('16-06-2000', 'dd-mm-yyyy'), 3, 1269, to_date('06-06-2000', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140222012585, to_date('22-02-2014', 'dd-mm-yyyy'), to_date('08-03-2014', 'dd-mm-yyyy'), 4, 9526, to_date('04-03-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060725012586, to_date('25-07-2006', 'dd-mm-yyyy'), to_date('08-08-2006', 'dd-mm-yyyy'), 2, 4390, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030419012587, to_date('19-04-2003', 'dd-mm-yyyy'), to_date('03-05-2003', 'dd-mm-yyyy'), 3, 2667, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20021127012588, to_date('27-11-2002', 'dd-mm-yyyy'), to_date('11-12-2002', 'dd-mm-yyyy'), 1, 3591, to_date('01-12-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080929012589, to_date('29-09-2008', 'dd-mm-yyyy'), to_date('13-10-2008', 'dd-mm-yyyy'), 3, 6614, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070114012590, to_date('14-01-2007', 'dd-mm-yyyy'), to_date('28-01-2007', 'dd-mm-yyyy'), 2, 6928, to_date('25-01-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020614012591, to_date('14-06-2002', 'dd-mm-yyyy'), to_date('28-06-2002', 'dd-mm-yyyy'), 3, 1496, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051111012592, to_date('11-11-2005', 'dd-mm-yyyy'), to_date('25-11-2005', 'dd-mm-yyyy'), 2, 5400, to_date('22-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101017012593, to_date('17-10-2010', 'dd-mm-yyyy'), to_date('31-10-2010', 'dd-mm-yyyy'), 1, 7973, to_date('21-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020812012594, to_date('12-08-2002', 'dd-mm-yyyy'), to_date('26-08-2002', 'dd-mm-yyyy'), 2, 3452, to_date('13-08-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130318012595, to_date('18-03-2013', 'dd-mm-yyyy'), to_date('01-04-2013', 'dd-mm-yyyy'), 3, 8739, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080126012596, to_date('26-01-2008', 'dd-mm-yyyy'), to_date('09-02-2008', 'dd-mm-yyyy'), 2, 6455, to_date('29-01-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130723012597, to_date('23-07-2013', 'dd-mm-yyyy'), to_date('06-08-2013', 'dd-mm-yyyy'), 1, 9710, to_date('02-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20031122012598, to_date('22-11-2003', 'dd-mm-yyyy'), to_date('06-12-2003', 'dd-mm-yyyy'), 1, 3968, to_date('29-11-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040417012599, to_date('17-04-2004', 'dd-mm-yyyy'), to_date('01-05-2004', 'dd-mm-yyyy'), 2, 2615, to_date('02-05-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090407012600, to_date('07-04-2009', 'dd-mm-yyyy'), to_date('21-04-2009', 'dd-mm-yyyy'), 4, 6727, to_date('16-04-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030919012601, to_date('19-09-2003', 'dd-mm-yyyy'), to_date('03-10-2003', 'dd-mm-yyyy'), 2, 4110, to_date('09-10-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030212012602, to_date('12-02-2003', 'dd-mm-yyyy'), to_date('26-02-2003', 'dd-mm-yyyy'), 3, 2651, to_date('23-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120430012603, to_date('30-04-2012', 'dd-mm-yyyy'), to_date('14-05-2012', 'dd-mm-yyyy'), 3, 9434, to_date('10-05-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070408012604, to_date('08-04-2007', 'dd-mm-yyyy'), to_date('22-04-2007', 'dd-mm-yyyy'), 2, 6016, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011212012605, to_date('12-12-2001', 'dd-mm-yyyy'), to_date('26-12-2001', 'dd-mm-yyyy'), 2, 1048, to_date('19-12-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030118012606, to_date('18-01-2003', 'dd-mm-yyyy'), to_date('01-02-2003', 'dd-mm-yyyy'), 3, 4155, to_date('21-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010511012607, to_date('11-05-2001', 'dd-mm-yyyy'), to_date('25-05-2001', 'dd-mm-yyyy'), 1, 726, to_date('18-05-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060802012608, to_date('02-08-2006', 'dd-mm-yyyy'), to_date('16-08-2006', 'dd-mm-yyyy'), 4, 5612, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030123012609, to_date('23-01-2003', 'dd-mm-yyyy'), to_date('06-02-2003', 'dd-mm-yyyy'), 1, 2983, to_date('27-01-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110830012610, to_date('30-08-2011', 'dd-mm-yyyy'), to_date('13-09-2011', 'dd-mm-yyyy'), 3, 6414, to_date('18-09-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050713012611, to_date('13-07-2005', 'dd-mm-yyyy'), to_date('27-07-2005', 'dd-mm-yyyy'), 2, 5887, to_date('26-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060420012612, to_date('20-04-2006', 'dd-mm-yyyy'), to_date('04-05-2006', 'dd-mm-yyyy'), 3, 3824, to_date('04-05-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20000120012613, to_date('20-01-2000', 'dd-mm-yyyy'), to_date('03-02-2000', 'dd-mm-yyyy'), 2, 802, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020730012614, to_date('30-07-2002', 'dd-mm-yyyy'), to_date('13-08-2002', 'dd-mm-yyyy'), 2, 3977, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060518012615, to_date('18-05-2006', 'dd-mm-yyyy'), to_date('01-06-2006', 'dd-mm-yyyy'), 2, 4237, to_date('02-06-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080803012616, to_date('03-08-2008', 'dd-mm-yyyy'), to_date('17-08-2008', 'dd-mm-yyyy'), 4, 5473, to_date('06-08-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110220012617, to_date('20-02-2011', 'dd-mm-yyyy'), to_date('06-03-2011', 'dd-mm-yyyy'), 3, 9672, to_date('25-02-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20070325012618, to_date('25-03-2007', 'dd-mm-yyyy'), to_date('08-04-2007', 'dd-mm-yyyy'), 4, 4761, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090405012619, to_date('05-04-2009', 'dd-mm-yyyy'), to_date('19-04-2009', 'dd-mm-yyyy'), 3, 7859, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080613012620, to_date('13-06-2008', 'dd-mm-yyyy'), to_date('27-06-2008', 'dd-mm-yyyy'), 1, 9565, to_date('18-06-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110511012621, to_date('11-05-2011', 'dd-mm-yyyy'), to_date('25-05-2011', 'dd-mm-yyyy'), 3, 7096, to_date('23-05-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030422012622, to_date('22-04-2003', 'dd-mm-yyyy'), to_date('06-05-2003', 'dd-mm-yyyy'), 2, 2236, to_date('05-05-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071111012623, to_date('11-11-2007', 'dd-mm-yyyy'), to_date('25-11-2007', 'dd-mm-yyyy'), 4, 4938, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090713012624, to_date('13-07-2009', 'dd-mm-yyyy'), to_date('27-07-2009', 'dd-mm-yyyy'), 2, 7128, to_date('21-07-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120314012625, to_date('14-03-2012', 'dd-mm-yyyy'), to_date('28-03-2012', 'dd-mm-yyyy'), 2, 8510, to_date('24-03-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110813012626, to_date('13-08-2011', 'dd-mm-yyyy'), to_date('27-08-2011', 'dd-mm-yyyy'), 4, 8254, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110621012627, to_date('21-06-2011', 'dd-mm-yyyy'), to_date('05-07-2011', 'dd-mm-yyyy'), 4, 8630, to_date('01-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110312012628, to_date('12-03-2011', 'dd-mm-yyyy'), to_date('26-03-2011', 'dd-mm-yyyy'), 4, 8789, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120428012629, to_date('28-04-2012', 'dd-mm-yyyy'), to_date('12-05-2012', 'dd-mm-yyyy'), 1, 9617, to_date('30-04-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100608012630, to_date('08-06-2010', 'dd-mm-yyyy'), to_date('22-06-2010', 'dd-mm-yyyy'), 2, 6926, to_date('21-06-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051103012631, to_date('03-11-2005', 'dd-mm-yyyy'), to_date('17-11-2005', 'dd-mm-yyyy'), 2, 5534, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041006012632, to_date('06-10-2004', 'dd-mm-yyyy'), to_date('20-10-2004', 'dd-mm-yyyy'), 2, 4116, to_date('12-10-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080423012633, to_date('23-04-2008', 'dd-mm-yyyy'), to_date('07-05-2008', 'dd-mm-yyyy'), 1, 6156, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040126012634, to_date('26-01-2004', 'dd-mm-yyyy'), to_date('09-02-2004', 'dd-mm-yyyy'), 3, 4386, to_date('14-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20101025012635, to_date('25-10-2010', 'dd-mm-yyyy'), to_date('08-11-2010', 'dd-mm-yyyy'), 2, 5173, to_date('30-10-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061207012636, to_date('07-12-2006', 'dd-mm-yyyy'), to_date('21-12-2006', 'dd-mm-yyyy'), 3, 5601, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110705012637, to_date('05-07-2011', 'dd-mm-yyyy'), to_date('19-07-2011', 'dd-mm-yyyy'), 2, 9837, to_date('10-07-2011', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20121024012638, to_date('24-10-2012', 'dd-mm-yyyy'), to_date('07-11-2012', 'dd-mm-yyyy'), 2, 7376, to_date('01-11-2012', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030924012639, to_date('24-09-2003', 'dd-mm-yyyy'), to_date('08-10-2003', 'dd-mm-yyyy'), 3, 4371, to_date('25-09-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130106012640, to_date('06-01-2013', 'dd-mm-yyyy'), to_date('20-01-2013', 'dd-mm-yyyy'), 2, 7835, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040618012641, to_date('18-06-2004', 'dd-mm-yyyy'), to_date('02-07-2004', 'dd-mm-yyyy'), 4, 3271, to_date('29-06-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130518012642, to_date('18-05-2013', 'dd-mm-yyyy'), to_date('01-06-2013', 'dd-mm-yyyy'), 3, 9626, to_date('03-06-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060414012643, to_date('14-04-2006', 'dd-mm-yyyy'), to_date('28-04-2006', 'dd-mm-yyyy'), 4, 7435, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130129012644, to_date('29-01-2013', 'dd-mm-yyyy'), to_date('12-02-2013', 'dd-mm-yyyy'), 2, 7101, to_date('14-02-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040506012645, to_date('06-05-2004', 'dd-mm-yyyy'), to_date('20-05-2004', 'dd-mm-yyyy'), 3, 3221, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100309012646, to_date('09-03-2010', 'dd-mm-yyyy'), to_date('23-03-2010', 'dd-mm-yyyy'), 4, 7981, to_date('23-03-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20091110012647, to_date('10-11-2009', 'dd-mm-yyyy'), to_date('24-11-2009', 'dd-mm-yyyy'), 2, 6236, to_date('29-11-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051109012648, to_date('09-11-2005', 'dd-mm-yyyy'), to_date('23-11-2005', 'dd-mm-yyyy'), 1, 3147, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041210012649, to_date('10-12-2004', 'dd-mm-yyyy'), to_date('24-12-2004', 'dd-mm-yyyy'), 2, 4111, to_date('22-12-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050304012650, to_date('04-03-2005', 'dd-mm-yyyy'), to_date('18-03-2005', 'dd-mm-yyyy'), 3, 4644, to_date('20-03-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050706012651, to_date('06-07-2005', 'dd-mm-yyyy'), to_date('20-07-2005', 'dd-mm-yyyy'), 3, 4667, to_date('14-07-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20140516012652, to_date('16-05-2014', 'dd-mm-yyyy'), to_date('30-05-2014', 'dd-mm-yyyy'), 3, 9913, to_date('22-05-2014', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040123012653, to_date('23-01-2004', 'dd-mm-yyyy'), to_date('06-02-2004', 'dd-mm-yyyy'), 2, 4110, to_date('03-02-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060922012654, to_date('22-09-2006', 'dd-mm-yyyy'), to_date('06-10-2006', 'dd-mm-yyyy'), 4, 6114, to_date('04-10-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010830012655, to_date('30-08-2001', 'dd-mm-yyyy'), to_date('13-09-2001', 'dd-mm-yyyy'), 2, 1936, to_date('16-09-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20061119012656, to_date('19-11-2006', 'dd-mm-yyyy'), to_date('03-12-2006', 'dd-mm-yyyy'), 4, 5254, to_date('07-12-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130530012657, to_date('30-05-2013', 'dd-mm-yyyy'), to_date('13-06-2013', 'dd-mm-yyyy'), 3, 7478, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090614012658, to_date('14-06-2009', 'dd-mm-yyyy'), to_date('28-06-2009', 'dd-mm-yyyy'), 2, 8500, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060812012659, to_date('12-08-2006', 'dd-mm-yyyy'), to_date('26-08-2006', 'dd-mm-yyyy'), 2, 5969, to_date('16-08-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130729012660, to_date('29-07-2013', 'dd-mm-yyyy'), to_date('12-08-2013', 'dd-mm-yyyy'), 2, 7804, to_date('09-08-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040209012661, to_date('09-02-2004', 'dd-mm-yyyy'), to_date('23-02-2004', 'dd-mm-yyyy'), 3, 5167, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051115012662, to_date('15-11-2005', 'dd-mm-yyyy'), to_date('29-11-2005', 'dd-mm-yyyy'), 2, 3760, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030614012663, to_date('14-06-2003', 'dd-mm-yyyy'), to_date('28-06-2003', 'dd-mm-yyyy'), 2, 4509, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100414012664, to_date('14-04-2010', 'dd-mm-yyyy'), to_date('28-04-2010', 'dd-mm-yyyy'), 3, 7328, to_date('25-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060410012665, to_date('10-04-2006', 'dd-mm-yyyy'), to_date('24-04-2006', 'dd-mm-yyyy'), 1, 5424, to_date('14-04-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050503012666, to_date('03-05-2005', 'dd-mm-yyyy'), to_date('17-05-2005', 'dd-mm-yyyy'), 4, 4180, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030809012667, to_date('09-08-2003', 'dd-mm-yyyy'), to_date('23-08-2003', 'dd-mm-yyyy'), 2, 2014, to_date('13-08-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080422012668, to_date('22-04-2008', 'dd-mm-yyyy'), to_date('06-05-2008', 'dd-mm-yyyy'), 1, 4677, to_date('12-05-2008', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20051120012669, to_date('20-11-2005', 'dd-mm-yyyy'), to_date('04-12-2005', 'dd-mm-yyyy'), 2, 6004, to_date('28-11-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20090922012670, to_date('22-09-2009', 'dd-mm-yyyy'), to_date('06-10-2009', 'dd-mm-yyyy'), 2, 7713, to_date('07-10-2009', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20040126012671, to_date('26-01-2004', 'dd-mm-yyyy'), to_date('09-02-2004', 'dd-mm-yyyy'), 3, 2335, to_date('30-01-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010306012672, to_date('06-03-2001', 'dd-mm-yyyy'), to_date('20-03-2001', 'dd-mm-yyyy'), 3, 2649, to_date('23-03-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020127012673, to_date('27-01-2002', 'dd-mm-yyyy'), to_date('10-02-2002', 'dd-mm-yyyy'), 2, 5970, to_date('06-02-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20010317012674, to_date('17-03-2001', 'dd-mm-yyyy'), to_date('31-03-2001', 'dd-mm-yyyy'), 4, 3579, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20130709012675, to_date('09-07-2013', 'dd-mm-yyyy'), to_date('23-07-2013', 'dd-mm-yyyy'), 4, 8653, to_date('14-07-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20060214012676, to_date('14-02-2006', 'dd-mm-yyyy'), to_date('28-02-2006', 'dd-mm-yyyy'), 4, 5808, to_date('20-02-2006', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100509012677, to_date('09-05-2010', 'dd-mm-yyyy'), to_date('23-05-2010', 'dd-mm-yyyy'), 2, 8639, to_date('29-05-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20020226012678, to_date('26-02-2002', 'dd-mm-yyyy'), to_date('12-03-2002', 'dd-mm-yyyy'), 2, 2376, to_date('12-03-2002', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030220012679, to_date('20-02-2003', 'dd-mm-yyyy'), to_date('06-03-2003', 'dd-mm-yyyy'), 1, 5891, to_date('28-02-2003', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20131128012680, to_date('28-11-2013', 'dd-mm-yyyy'), to_date('12-12-2013', 'dd-mm-yyyy'), 2, 7929, to_date('04-12-2013', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050414012681, to_date('14-04-2005', 'dd-mm-yyyy'), to_date('28-04-2005', 'dd-mm-yyyy'), 3, 4382, to_date('01-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20110722012682, to_date('22-07-2011', 'dd-mm-yyyy'), to_date('05-08-2011', 'dd-mm-yyyy'), 1, 8052, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20011031012683, to_date('31-10-2001', 'dd-mm-yyyy'), to_date('14-11-2001', 'dd-mm-yyyy'), 2, 2631, to_date('02-11-2001', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050827012684, to_date('27-08-2005', 'dd-mm-yyyy'), to_date('10-09-2005', 'dd-mm-yyyy'), 2, 2672, to_date('11-09-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050602012685, to_date('02-06-2005', 'dd-mm-yyyy'), to_date('16-06-2005', 'dd-mm-yyyy'), 3, 7002, to_date('11-06-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20120730012686, to_date('30-07-2012', 'dd-mm-yyyy'), to_date('13-08-2012', 'dd-mm-yyyy'), 4, 10748, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20071202012687, to_date('02-12-2007', 'dd-mm-yyyy'), to_date('16-12-2007', 'dd-mm-yyyy'), 1, 7955, to_date('10-12-2007', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20100329012688, to_date('29-03-2010', 'dd-mm-yyyy'), to_date('12-04-2010', 'dd-mm-yyyy'), 1, 7399, to_date('13-04-2010', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20081021012689, to_date('21-10-2008', 'dd-mm-yyyy'), to_date('04-11-2008', 'dd-mm-yyyy'), 4, 6411, null);
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20041104012690, to_date('04-11-2004', 'dd-mm-yyyy'), to_date('18-11-2004', 'dd-mm-yyyy'), 1, 3140, to_date('24-11-2004', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20080515012691, to_date('15-05-2008', 'dd-mm-yyyy'), to_date('29-05-2008', 'dd-mm-yyyy'), 2, 4992, to_date('23-05-2008', 'dd-mm-yyyy'));
commit;
prompt 18000 records committed...
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20050512012692, to_date('12-05-2005', 'dd-mm-yyyy'), to_date('26-05-2005', 'dd-mm-yyyy'), 3, 4186, to_date('28-05-2005', 'dd-mm-yyyy'));
insert into INVOICES (invno, invdate, duedate, customerid, invamount, paydate)
values (20030802012693, to_date('02-08-2003', 'dd-mm-yyyy'), to_date('16-08-2003', 'dd-mm-yyyy'), 3, 3716, null);
commit;
prompt 18002 records loaded
prompt Loading PRODCOLOURS...
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (1, 'Schwarz');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (2, 'Rot');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (3, 'Gold');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (4, 'Blau');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (5, 'Weiss');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (6, 'Grn');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (7, 'Gelb');
insert into PRODCOLOURS (prodcolourid, prodcolourname)
values (8, 'Silber');
commit;
prompt 8 records loaded
prompt Loading PRODFORMS...
insert into PRODFORMS (prodformid, prodformname)
values (6, 'Wrfel');
insert into PRODFORMS (prodformid, prodformname)
values (5, 'Kegel');
insert into PRODFORMS (prodformid, prodformname)
values (1, 'Quader');
insert into PRODFORMS (prodformid, prodformname)
values (2, 'Zylinder');
insert into PRODFORMS (prodformid, prodformname)
values (3, 'Kugel');
insert into PRODFORMS (prodformid, prodformname)
values (4, 'Pyramide');
commit;
prompt 6 records loaded
prompt Loading PRODMATERIAL...
insert into PRODMATERIAL (prodmaterialid, prodmaterialname)
values (1, 'Holz');
insert into PRODMATERIAL (prodmaterialid, prodmaterialname)
values (2, 'Metall');
insert into PRODMATERIAL (prodmaterialid, prodmaterialname)
values (3, 'Kunststoff');
insert into PRODMATERIAL (prodmaterialid, prodmaterialname)
values (4, 'Glas');
commit;
prompt 4 records loaded
prompt Loading PRODUCTS...
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (1, 'Holz_Quader_Schwarz', 1, 1, 1, 3);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (2, 'Holz_Quader_Rot', 2, 1, 1, 4);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (3, 'Holz_Quader_Gold', 3, 1, 1, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (4, 'Holz_Quader_Blau', 4, 1, 1, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (5, 'Holz_Quader_Weiss', 5, 1, 1, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (6, 'Holz_Quader_Grn', 6, 1, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (7, 'Holz_Quader_Gelb', 7, 1, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (8, 'Holz_Quader_Silber', 8, 1, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (9, 'Metall_Quader_Schwarz', 1, 1, 2, 4);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (10, 'Metall_Quader_Rot', 2, 1, 2, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (11, 'Metall_Quader_Gold', 3, 1, 2, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (12, 'Metall_Quader_Blau', 4, 1, 2, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (13, 'Metall_Quader_Weiss', 5, 1, 2, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (14, 'Metall_Quader_Grn', 6, 1, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (15, 'Metall_Quader_Gelb', 7, 1, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (16, 'Metall_Quader_Silber', 8, 1, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (17, 'Kunststoff_Quader_Schwarz', 1, 1, 3, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (18, 'Kunststoff_Quader_Rot', 2, 1, 3, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (19, 'Kunststoff_Quader_Gold', 3, 1, 3, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (20, 'Kunststoff_Quader_Blau', 4, 1, 3, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (21, 'Kunststoff_Quader_Weiss', 5, 1, 3, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (22, 'Kunststoff_Quader_Grn', 6, 1, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (23, 'Kunststoff_Quader_Gelb', 7, 1, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (24, 'Kunststoff_Quader_Silber', 8, 1, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (25, 'Glas_Quader_Schwarz', 1, 1, 4, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (26, 'Glas_Quader_Rot', 2, 1, 4, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (27, 'Glas_Quader_Gold', 3, 1, 4, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (28, 'Glas_Quader_Blau', 4, 1, 4, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (29, 'Glas_Quader_Weiss', 5, 1, 4, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (30, 'Glas_Quader_Grn', 6, 1, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (31, 'Glas_Quader_Gelb', 7, 1, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (32, 'Glas_Quader_Silber', 8, 1, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (33, 'Holz_Zylinder_Schwarz', 1, 2, 1, 4);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (34, 'Holz_Zylinder_Rot', 2, 2, 1, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (35, 'Holz_Zylinder_Gold', 3, 2, 1, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (36, 'Holz_Zylinder_Blau', 4, 2, 1, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (37, 'Holz_Zylinder_Weiss', 5, 2, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (38, 'Holz_Zylinder_Grn', 6, 2, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (39, 'Holz_Zylinder_Gelb', 7, 2, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (40, 'Holz_Zylinder_Silber', 8, 2, 1, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (41, 'Metall_Zylinder_Schwarz', 1, 2, 2, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (42, 'Metall_Zylinder_Rot', 2, 2, 2, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (43, 'Metall_Zylinder_Gold', 3, 2, 2, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (44, 'Metall_Zylinder_Blau', 4, 2, 2, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (45, 'Metall_Zylinder_Weiss', 5, 2, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (46, 'Metall_Zylinder_Grn', 6, 2, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (47, 'Metall_Zylinder_Gelb', 7, 2, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (48, 'Metall_Zylinder_Silber', 8, 2, 2, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (49, 'Kunststoff_Zylinder_Schwarz', 1, 2, 3, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (50, 'Kunststoff_Zylinder_Rot', 2, 2, 3, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (51, 'Kunststoff_Zylinder_Gold', 3, 2, 3, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (52, 'Kunststoff_Zylinder_Blau', 4, 2, 3, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (53, 'Kunststoff_Zylinder_Weiss', 5, 2, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (54, 'Kunststoff_Zylinder_Grn', 6, 2, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (55, 'Kunststoff_Zylinder_Gelb', 7, 2, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (56, 'Kunststoff_Zylinder_Silber', 8, 2, 3, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (57, 'Glas_Zylinder_Schwarz', 1, 2, 4, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (58, 'Glas_Zylinder_Rot', 2, 2, 4, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (59, 'Glas_Zylinder_Gold', 3, 2, 4, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (60, 'Glas_Zylinder_Blau', 4, 2, 4, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (61, 'Glas_Zylinder_Weiss', 5, 2, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (62, 'Glas_Zylinder_Grn', 6, 2, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (63, 'Glas_Zylinder_Gelb', 7, 2, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (64, 'Glas_Zylinder_Silber', 8, 2, 4, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (65, 'Holz_Kugel_Schwarz', 1, 3, 1, 5);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (66, 'Holz_Kugel_Rot', 2, 3, 1, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (67, 'Holz_Kugel_Gold', 3, 3, 1, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (68, 'Holz_Kugel_Blau', 4, 3, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (69, 'Holz_Kugel_Weiss', 5, 3, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (70, 'Holz_Kugel_Grn', 6, 3, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (71, 'Holz_Kugel_Gelb', 7, 3, 1, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (72, 'Holz_Kugel_Silber', 8, 3, 1, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (73, 'Metall_Kugel_Schwarz', 1, 3, 2, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (74, 'Metall_Kugel_Rot', 2, 3, 2, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (75, 'Metall_Kugel_Gold', 3, 3, 2, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (76, 'Metall_Kugel_Blau', 4, 3, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (77, 'Metall_Kugel_Weiss', 5, 3, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (78, 'Metall_Kugel_Grn', 6, 3, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (79, 'Metall_Kugel_Gelb', 7, 3, 2, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (80, 'Metall_Kugel_Silber', 8, 3, 2, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (81, 'Kunststoff_Kugel_Schwarz', 1, 3, 3, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (82, 'Kunststoff_Kugel_Rot', 2, 3, 3, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (83, 'Kunststoff_Kugel_Gold', 3, 3, 3, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (84, 'Kunststoff_Kugel_Blau', 4, 3, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (85, 'Kunststoff_Kugel_Weiss', 5, 3, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (86, 'Kunststoff_Kugel_Grn', 6, 3, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (87, 'Kunststoff_Kugel_Gelb', 7, 3, 3, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (88, 'Kunststoff_Kugel_Silber', 8, 3, 3, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (89, 'Glas_Kugel_Schwarz', 1, 3, 4, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (90, 'Glas_Kugel_Rot', 2, 3, 4, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (91, 'Glas_Kugel_Gold', 3, 3, 4, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (92, 'Glas_Kugel_Blau', 4, 3, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (93, 'Glas_Kugel_Weiss', 5, 3, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (94, 'Glas_Kugel_Grn', 6, 3, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (95, 'Glas_Kugel_Gelb', 7, 3, 4, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (96, 'Glas_Kugel_Silber', 8, 3, 4, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (97, 'Holz_Pyramide_Schwarz', 1, 4, 1, 6);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (98, 'Holz_Pyramide_Rot', 2, 4, 1, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (99, 'Holz_Pyramide_Gold', 3, 4, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (100, 'Holz_Pyramide_Blau', 4, 4, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (101, 'Holz_Pyramide_Weiss', 5, 4, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (102, 'Holz_Pyramide_Grn', 6, 4, 1, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (103, 'Holz_Pyramide_Gelb', 7, 4, 1, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (104, 'Holz_Pyramide_Silber', 8, 4, 1, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (105, 'Metall_Pyramide_Schwarz', 1, 4, 2, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (106, 'Metall_Pyramide_Rot', 2, 4, 2, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (107, 'Metall_Pyramide_Gold', 3, 4, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (108, 'Metall_Pyramide_Blau', 4, 4, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (109, 'Metall_Pyramide_Weiss', 5, 4, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (110, 'Metall_Pyramide_Grn', 6, 4, 2, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (111, 'Metall_Pyramide_Gelb', 7, 4, 2, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (112, 'Metall_Pyramide_Silber', 8, 4, 2, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (113, 'Kunststoff_Pyramide_Schwarz', 1, 4, 3, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (114, 'Kunststoff_Pyramide_Rot', 2, 4, 3, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (115, 'Kunststoff_Pyramide_Gold', 3, 4, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (116, 'Kunststoff_Pyramide_Blau', 4, 4, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (117, 'Kunststoff_Pyramide_Weiss', 5, 4, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (118, 'Kunststoff_Pyramide_Grn', 6, 4, 3, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (119, 'Kunststoff_Pyramide_Gelb', 7, 4, 3, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (120, 'Kunststoff_Pyramide_Silber', 8, 4, 3, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (121, 'Glas_Pyramide_Schwarz', 1, 4, 4, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (122, 'Glas_Pyramide_Rot', 2, 4, 4, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (123, 'Glas_Pyramide_Gold', 3, 4, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (124, 'Glas_Pyramide_Blau', 4, 4, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (125, 'Glas_Pyramide_Weiss', 5, 4, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (126, 'Glas_Pyramide_Grn', 6, 4, 4, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (127, 'Glas_Pyramide_Gelb', 7, 4, 4, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (128, 'Glas_Pyramide_Silber', 8, 4, 4, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (129, 'Holz_Kegel_Schwarz', 1, 5, 1, 7);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (130, 'Holz_Kegel_Rot', 2, 5, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (131, 'Holz_Kegel_Gold', 3, 5, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (132, 'Holz_Kegel_Blau', 4, 5, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (133, 'Holz_Kegel_Weiss', 5, 5, 1, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (134, 'Holz_Kegel_Grn', 6, 5, 1, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (135, 'Holz_Kegel_Gelb', 7, 5, 1, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (136, 'Holz_Kegel_Silber', 8, 5, 1, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (137, 'Metall_Kegel_Schwarz', 1, 5, 2, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (138, 'Metall_Kegel_Rot', 2, 5, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (139, 'Metall_Kegel_Gold', 3, 5, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (140, 'Metall_Kegel_Blau', 4, 5, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (141, 'Metall_Kegel_Weiss', 5, 5, 2, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (142, 'Metall_Kegel_Grn', 6, 5, 2, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (143, 'Metall_Kegel_Gelb', 7, 5, 2, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (144, 'Metall_Kegel_Silber', 8, 5, 2, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (145, 'Kunststoff_Kegel_Schwarz', 1, 5, 3, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (146, 'Kunststoff_Kegel_Rot', 2, 5, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (147, 'Kunststoff_Kegel_Gold', 3, 5, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (148, 'Kunststoff_Kegel_Blau', 4, 5, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (149, 'Kunststoff_Kegel_Weiss', 5, 5, 3, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (150, 'Kunststoff_Kegel_Grn', 6, 5, 3, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (151, 'Kunststoff_Kegel_Gelb', 7, 5, 3, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (152, 'Kunststoff_Kegel_Silber', 8, 5, 3, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (153, 'Glas_Kegel_Schwarz', 1, 5, 4, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (154, 'Glas_Kegel_Rot', 2, 5, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (155, 'Glas_Kegel_Gold', 3, 5, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (156, 'Glas_Kegel_Blau', 4, 5, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (157, 'Glas_Kegel_Weiss', 5, 5, 4, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (158, 'Glas_Kegel_Grn', 6, 5, 4, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (159, 'Glas_Kegel_Gelb', 7, 5, 4, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (160, 'Glas_Kegel_Silber', 8, 5, 4, 17);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (161, 'Holz_Wrfel_Schwarz', 1, 6, 1, 8);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (162, 'Holz_Wrfel_Rot', 2, 6, 1, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (163, 'Holz_Wrfel_Gold', 3, 6, 1, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (164, 'Holz_Wrfel_Blau', 4, 6, 1, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (165, 'Holz_Wrfel_Weiss', 5, 6, 1, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (166, 'Holz_Wrfel_Grn', 6, 6, 1, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (167, 'Holz_Wrfel_Gelb', 7, 6, 1, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (168, 'Holz_Wrfel_Silber', 8, 6, 1, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (169, 'Metall_Wrfel_Schwarz', 1, 6, 2, 9);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (170, 'Metall_Wrfel_Rot', 2, 6, 2, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (171, 'Metall_Wrfel_Gold', 3, 6, 2, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (172, 'Metall_Wrfel_Blau', 4, 6, 2, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (173, 'Metall_Wrfel_Weiss', 5, 6, 2, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (174, 'Metall_Wrfel_Grn', 6, 6, 2, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (175, 'Metall_Wrfel_Gelb', 7, 6, 2, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (176, 'Metall_Wrfel_Silber', 8, 6, 2, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (177, 'Kunststoff_Wrfel_Schwarz', 1, 6, 3, 10);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (178, 'Kunststoff_Wrfel_Rot', 2, 6, 3, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (179, 'Kunststoff_Wrfel_Gold', 3, 6, 3, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (180, 'Kunststoff_Wrfel_Blau', 4, 6, 3, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (181, 'Kunststoff_Wrfel_Weiss', 5, 6, 3, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (182, 'Kunststoff_Wrfel_Grn', 6, 6, 3, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (183, 'Kunststoff_Wrfel_Gelb', 7, 6, 3, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (184, 'Kunststoff_Wrfel_Silber', 8, 6, 3, 17);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (185, 'Glas_Wrfel_Schwarz', 1, 6, 4, 11);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (186, 'Glas_Wrfel_Rot', 2, 6, 4, 12);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (187, 'Glas_Wrfel_Gold', 3, 6, 4, 13);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (188, 'Glas_Wrfel_Blau', 4, 6, 4, 14);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (189, 'Glas_Wrfel_Weiss', 5, 6, 4, 15);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (190, 'Glas_Wrfel_Grn', 6, 6, 4, 16);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (191, 'Glas_Wrfel_Gelb', 7, 6, 4, 17);
insert into PRODUCTS (productid, productname, prodcolourid, prodformid, prodmaterialid, productprice)
values (192, 'Glas_Wrfel_Silber', 8, 6, 4, 18);
commit;
prompt 192 records loaded
prompt Loading INVLINES...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 9, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 10, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 11, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 12, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 13, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 14, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 15, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604000769, 1, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604000769, 2, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604000769, 3, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604000769, 4, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 1, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 2, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 3, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 4, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 5, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000770, 6, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310000771, 1, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310000771, 2, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310000771, 3, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000772, 1, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000772, 2, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000772, 3, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000772, 4, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803000773, 1, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803000773, 2, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803000773, 3, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803000773, 4, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803000773, 5, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 1, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 2, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 3, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 4, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 5, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 6, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 7, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 8, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 9, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 10, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 11, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 12, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 13, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123000774, 14, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 1, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 2, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 3, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 4, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 5, 81, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 6, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 7, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 8, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 9, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 10, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 11, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 12, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 13, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 14, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000775, 15, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127000776, 1, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127000776, 2, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127000776, 3, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127000776, 4, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 1, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 2, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 3, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 4, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 5, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 6, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 7, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 8, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 9, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 10, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 11, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 12, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 13, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 14, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 15, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 16, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 17, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117000777, 18, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223000778, 1, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223000778, 2, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223000778, 3, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 1, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 2, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 3, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 4, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 5, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 6, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 7, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 8, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 9, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000779, 10, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 1, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 2, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 3, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 4, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 5, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303000780, 6, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 1, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 2, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 3, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 4, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 5, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 6, 119, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 7, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 8, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 9, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 10, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 11, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 12, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 13, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 14, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211000781, 15, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 1, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 2, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 3, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 4, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 5, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 6, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 7, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 8, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 9, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 10, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 11, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 12, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 13, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000782, 14, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 1, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 2, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 3, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 4, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 5, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 6, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 7, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 8, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217000783, 9, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 1, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 2, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 4, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 5, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 6, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 7, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 8, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 9, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703000784, 10, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 1, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 2, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 3, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 4, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 5, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 6, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 7, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 8, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 9, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 10, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 11, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 12, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 13, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301000785, 14, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108000786, 1, 38, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108000786, 2, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108000786, 3, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108000786, 4, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108000786, 5, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 1, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 2, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 3, 100, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 4, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 5, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924000787, 6, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 1, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 2, 131, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 3, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 4, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 5, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 6, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 7, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 8, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 9, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 10, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 11, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 12, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 13, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 14, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627000788, 15, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 1, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 2, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 3, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 4, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 5, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 6, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109000789, 7, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 1, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 2, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 3, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 4, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 5, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 6, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 7, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 8, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 9, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000790, 10, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525000791, 1, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525000791, 2, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525000791, 3, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 1, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 2, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 3, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 4, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 5, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 6, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 7, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 8, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 9, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 10, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 11, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 12, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 13, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 14, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 15, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 16, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321000792, 17, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 1, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 2, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 3, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 4, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 5, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 6, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 7, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407000793, 8, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217000794, 1, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217000794, 2, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 1, 70, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 2, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 3, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 4, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527000053, 3, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527000053, 4, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527000053, 5, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 1, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 2, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 3, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 4, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 5, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 6, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 7, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 8, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 9, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 10, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 11, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 12, 68, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 13, 79, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 14, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 15, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408000054, 16, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 1, 183, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 2, 117, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 3, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 4, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 5, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025000055, 6, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 1, 44, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 2, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 3, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 4, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 5, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 6, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 7, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 8, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 9, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 10, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 11, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 12, 147, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 13, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 14, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000056, 15, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 1, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 2, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 3, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 4, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 5, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528000057, 6, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 1, 121, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 2, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 3, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 4, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 5, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816000058, 6, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218000059, 1, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218000059, 2, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 1, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 2, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 3, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 4, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 5, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 6, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 7, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 8, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 9, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 10, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 11, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081027000060, 12, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230000061, 1, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230000061, 2, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230000061, 3, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230000061, 4, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230000061, 5, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 1, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 2, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 3, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 4, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 5, 27, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 6, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 7, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 8, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 9, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000062, 10, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 1, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 2, 104, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 3, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 4, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 5, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 6, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 7, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 8, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 9, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 10, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 11, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 12, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 13, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 14, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000063, 15, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219000064, 1, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219000064, 2, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219000064, 3, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219000064, 4, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219000064, 5, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000065, 1, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000065, 2, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000065, 3, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000065, 4, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000065, 5, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 1, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 2, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 3, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 4, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 5, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 6, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 7, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 8, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 9, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 10, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 11, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 12, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000066, 13, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 1, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 2, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 3, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 4, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 5, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 6, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 7, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 8, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327000067, 9, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 1, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 2, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 3, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 4, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 5, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 6, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 7, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 8, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 9, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 10, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 11, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 12, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 13, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 14, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 15, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 16, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308000068, 17, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 1, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 2, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 3, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 4, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 5, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 6, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 7, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 8, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 9, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 10, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 11, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 12, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421000069, 13, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513000070, 1, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513000070, 2, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513000070, 3, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513000070, 4, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 1, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 2, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 3, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 4, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 5, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325000071, 6, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 1, 107, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 2, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 3, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 4, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 5, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 6, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 7, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 8, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 9, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 10, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 11, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 12, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 13, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 14, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 15, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801000072, 16, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 1, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 2, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 3, 155, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 4, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 5, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 6, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 7, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 8, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 9, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128000073, 10, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 1, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 2, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 3, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 4, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 5, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 6, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 7, 58, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 8, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 9, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 10, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 11, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 12, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710000074, 13, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 1, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 2, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 3, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 4, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 5, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000075, 6, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 1, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 2, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 3, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 4, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 5, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 6, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 7, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 8, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 9, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 10, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 11, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 12, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 13, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 14, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421000076, 15, 149, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 1, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 2, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 3, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 4, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 5, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 6, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 7, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 8, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 9, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 10, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 11, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 1, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 2, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 3, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 4, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 5, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 6, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 7, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 8, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 9, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 10, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 11, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000417, 12, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 1, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 2, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 3, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 4, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 5, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 6, 67, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 7, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 8, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 9, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 10, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 11, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 12, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 13, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215000418, 14, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 1, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 2, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 3, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 4, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 5, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 6, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 7, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 8, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 9, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 10, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 11, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 12, 164, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 13, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 14, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 15, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727000419, 16, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 1, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 2, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 3, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 4, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 5, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 6, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 7, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 8, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 9, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 10, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 11, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 12, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 13, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713000420, 14, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 1, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 2, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 3, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 4, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 5, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 6, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 7, 128, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024000421, 8, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 1, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 2, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 3, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 4, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 5, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 6, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 7, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 8, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 9, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 10, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 11, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 12, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 13, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 14, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230000422, 15, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 1, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 2, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 3, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 4, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 5, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 6, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 7, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 8, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 9, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 10, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 11, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 12, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 13, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 14, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212000423, 15, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 1, 35, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 2, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 3, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 4, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 5, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 6, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 7, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 8, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 9, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 10, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 11, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 12, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004000424, 13, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000425, 1, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000425, 2, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000425, 3, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000425, 4, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 1, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 2, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 3, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 4, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 5, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 6, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 7, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 8, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 9, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 10, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 11, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 12, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 13, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116000426, 14, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 1, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 2, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 3, 184, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 4, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 5, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 6, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229000427, 7, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 1, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 2, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 3, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 4, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 5, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119000428, 6, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 1, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 2, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 3, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 4, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 5, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 6, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 7, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 8, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 9, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 10, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 11, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 12, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 13, 40, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 14, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 15, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702000429, 16, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 1, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 2, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 3, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 4, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 5, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604000430, 6, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 1, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 2, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 3, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 4, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 5, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 6, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 7, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 8, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121000431, 9, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 1, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 2, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 3, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 4, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 5, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 6, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 7, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721000432, 8, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 1, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 2, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 3, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 4, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 5, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 6, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 7, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 8, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 9, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 10, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 11, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 12, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 13, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 14, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719000433, 15, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 1, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 2, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 3, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 4, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 5, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 6, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 7, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 8, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 9, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 10, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 11, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 12, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 13, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000434, 14, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 1, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 2, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 3, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 4, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 5, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 6, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 7, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000435, 8, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 1, 90, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 2, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 3, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 4, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 5, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 6, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 7, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905000436, 8, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 1, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 2, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 3, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 4, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 5, 134, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 6, 159, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 7, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 8, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114000437, 9, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 1, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 2, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 3, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 4, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 5, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 6, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 7, 182, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 8, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 5, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222000795, 6, 65, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 1, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 2, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 3, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 4, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 5, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 6, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 7, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 8, 140, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 9, 33, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 10, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 11, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818000796, 12, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 1, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 2, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 3, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 4, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 5, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 6, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 7, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 8, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930000797, 9, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 1, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 2, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 3, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 4, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 5, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329000798, 6, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127000799, 1, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127000799, 2, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127000799, 3, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127000799, 4, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 1, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 2, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 3, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 4, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 5, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 6, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 7, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 8, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111000800, 9, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 1, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 2, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 3, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 4, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 5, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921000801, 6, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 1, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 2, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 3, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 4, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 5, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 6, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 7, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 8, 59, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 9, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 10, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 11, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 12, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 13, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 14, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 15, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301000802, 16, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 1, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 2, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 3, 27, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 4, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 5, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 6, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 7, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 8, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 9, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013000803, 10, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 1, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 2, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 3, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 4, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 5, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 6, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 7, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 8, 176, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 9, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 10, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 11, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116000804, 12, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111000805, 1, 138, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111000805, 2, 148, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111000805, 3, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111000805, 4, 124, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111000805, 5, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 1, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 2, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 3, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 4, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 5, 129, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 6, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 7, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 8, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 9, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 10, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 11, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 12, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 13, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 14, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 15, 161, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913000806, 16, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 1, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 2, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 3, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 4, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 5, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 6, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 7, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 8, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 9, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 10, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 11, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 12, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 13, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 14, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926000807, 15, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 1, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 2, 169, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 3, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 4, 73, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 5, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 6, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 7, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 8, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 9, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 10, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 11, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 12, 10, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 13, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503000808, 14, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000809, 1, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000809, 2, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000809, 3, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000809, 4, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 1, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 2, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 3, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 4, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 5, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 6, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 7, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 8, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417000810, 9, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 1, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 2, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 3, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 4, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 5, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 6, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 7, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908000811, 8, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 1, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 2, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 3, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 4, 132, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 5, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 6, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 7, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 8, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 9, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 10, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 11, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100526000812, 12, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127000813, 1, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127000813, 2, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127000813, 3, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127000813, 4, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 1, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 2, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 3, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 4, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 5, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 6, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 7, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000814, 8, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 1, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 2, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 3, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 4, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 5, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 6, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 7, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 8, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 9, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015000815, 10, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 1, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 2, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 3, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 4, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 5, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 6, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313000816, 7, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 1, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 2, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 3, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 4, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 5, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 6, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 7, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 8, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221000817, 9, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711000818, 1, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711000818, 2, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711000818, 3, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711000818, 4, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 1, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 2, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 3, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 4, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 5, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 6, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 7, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 8, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 9, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 10, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 11, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 12, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 13, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 14, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 15, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 16, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422000819, 17, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 1, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 2, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 3, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 4, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 5, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 6, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 7, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 8, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 9, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315000820, 10, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020406000821, 1, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 12, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 13, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 14, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 15, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 16, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126000077, 17, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 1, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 2, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 3, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 4, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 5, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 6, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 7, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 8, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 9, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 10, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 11, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903000078, 12, 76, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 1, 131, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 2, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 3, 129, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 4, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 5, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 6, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 7, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701000079, 8, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 1, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 2, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 3, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 4, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 5, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 6, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 7, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 8, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 9, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 10, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 11, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 12, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 13, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000080, 14, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 1, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 2, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 3, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 4, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 5, 10, 81, 5, 405);
commit;
prompt 1000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 6, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026000081, 7, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 1, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 2, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 3, 88, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 4, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 5, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221000082, 6, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 1, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 2, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 3, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 4, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 5, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 6, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 7, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 8, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823000083, 9, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 1, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 2, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 3, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 4, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 5, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 6, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 7, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 8, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 9, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730000084, 10, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 1, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 2, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 3, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 4, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 5, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 6, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 7, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826000085, 8, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 1, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 2, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 3, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 4, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 5, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 6, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 7, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000086, 8, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616000087, 1, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616000087, 2, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 1, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 2, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 3, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 4, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 5, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 6, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 7, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 8, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 9, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 10, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 11, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 12, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000088, 13, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 1, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 2, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 3, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 4, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 5, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 6, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 7, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 8, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 9, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 10, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 11, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 12, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 13, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 14, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 15, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 16, 52, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507000089, 17, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 1, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 2, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 3, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 4, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 5, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 6, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 7, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 8, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 9, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 10, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 11, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 12, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 13, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126000090, 14, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 1, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 2, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 3, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 4, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 5, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 6, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 7, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 8, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 9, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 10, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 11, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 12, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 13, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 14, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 15, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 16, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 17, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103000091, 18, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 1, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 2, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 3, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 4, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 5, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 6, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029000092, 7, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 1, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 2, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 3, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 4, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 5, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 6, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 7, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 8, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 9, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 10, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510000093, 11, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 1, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 2, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 3, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 4, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 5, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 6, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 7, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 8, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 9, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 10, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 11, 12, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 12, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204000094, 13, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 1, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 2, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 3, 141, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 4, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 5, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 6, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 7, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 8, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 9, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 10, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 11, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 12, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422000095, 13, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 1, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 2, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 3, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 4, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 5, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 6, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 7, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 8, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 9, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 10, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 11, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302000096, 12, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 1, 122, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 2, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 3, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 4, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 5, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 6, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 7, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 8, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 9, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 10, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 11, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216000097, 12, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102000098, 1, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102000098, 2, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102000098, 3, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 1, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 2, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 3, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 4, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 5, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 6, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 7, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214000099, 8, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 1, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 2, 33, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 3, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 4, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 5, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 6, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 7, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 8, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 9, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 10, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 11, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 12, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 13, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226000438, 14, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 1, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 2, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 3, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 4, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 5, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626000439, 6, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 1, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 2, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 3, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 4, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 5, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 6, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227000440, 7, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 1, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 2, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 3, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 4, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 5, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000441, 6, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 1, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 2, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 3, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 4, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 5, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 6, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 7, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 8, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 9, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 10, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 11, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 12, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816000442, 13, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 1, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 2, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 3, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 4, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 5, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 6, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 7, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 8, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 9, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 10, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 11, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 12, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 13, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317000443, 14, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 1, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 2, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 3, 127, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 4, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 5, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130000444, 6, 99, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 1, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 2, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 3, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 4, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 5, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 6, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 7, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 8, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 9, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 10, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 11, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828000445, 12, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 1, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 2, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 3, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 4, 108, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 5, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 6, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114000446, 7, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 1, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 2, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 3, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 4, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 5, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 6, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 7, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215000447, 8, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011024000448, 1, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011024000448, 2, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011024000448, 3, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011024000448, 4, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011024000448, 5, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 1, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 2, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 3, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 4, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 5, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 6, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 7, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 8, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 9, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 10, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 11, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 12, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 13, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 14, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909000449, 15, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000450, 1, 145, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000450, 2, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000450, 3, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000450, 4, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000450, 5, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 1, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 2, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 3, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 4, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 5, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 6, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 7, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 8, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000451, 9, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 1, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 2, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 3, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 4, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 5, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 6, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 7, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 8, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 9, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 10, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 11, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 12, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 13, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 14, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728000452, 15, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 1, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 2, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 3, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 4, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 5, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 6, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 7, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 8, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909000453, 9, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 1, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 2, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 3, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 4, 35, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 5, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 6, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 7, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 8, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 9, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 10, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 11, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 12, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512000454, 13, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 1, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 2, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 3, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 4, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 5, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 6, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 7, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 8, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 9, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 10, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 11, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 12, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 13, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220000455, 14, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625000456, 1, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625000456, 2, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625000456, 3, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625000456, 4, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622000457, 1, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622000457, 2, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622000457, 3, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622000457, 4, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622000457, 5, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 1, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 2, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 3, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 4, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 5, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 6, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 7, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 8, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 9, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 10, 109, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 11, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 12, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603000458, 13, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 1, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 2, 33, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 3, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 4, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 5, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 6, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 7, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 8, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 9, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 10, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 11, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 12, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 13, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 14, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 15, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000459, 16, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 1, 186, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 2, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 3, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 4, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 5, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 6, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 7, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 8, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 9, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 10, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 11, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 12, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522000460, 13, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 1, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 2, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 3, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 4, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 5, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 6, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 7, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 8, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 9, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 10, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 11, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 12, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 13, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919000461, 14, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 1, 171, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 2, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 3, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 4, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020406000821, 2, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020406000821, 3, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020406000821, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020406000821, 5, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 1, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 2, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 3, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 4, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 5, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 6, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112000822, 7, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403000823, 1, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403000823, 2, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403000823, 3, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403000823, 4, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403000823, 5, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 1, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 2, 190, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 3, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 4, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 5, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 6, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 7, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 8, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 9, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 10, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 11, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 12, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 13, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 14, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 15, 148, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823000824, 16, 137, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 1, 109, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 2, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 3, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 4, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 5, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 6, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 7, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 8, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 9, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 10, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 11, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 12, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 13, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 14, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028000825, 15, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 1, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 2, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 3, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 4, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 5, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010000826, 6, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 1, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 2, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 3, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 4, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 5, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501000827, 6, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 1, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 2, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 3, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 4, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 5, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 6, 44, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 7, 84, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529000828, 8, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 1, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 2, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 3, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 4, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 5, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 6, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000829, 7, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 1, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 2, 118, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 3, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 4, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 5, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 6, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 7, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 8, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927000830, 9, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 1, 92, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 2, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 3, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 4, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 5, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125000831, 6, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 1, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 2, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 3, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 4, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 5, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 6, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 7, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 8, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 9, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 10, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 11, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 12, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 13, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 14, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 15, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112000832, 16, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 1, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 2, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 3, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 4, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 5, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 6, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 7, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 8, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220000833, 9, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 1, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 2, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 3, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 4, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 5, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 6, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 7, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 8, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 9, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 10, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 11, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 12, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 13, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 14, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 15, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 16, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119000834, 17, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 1, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 2, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 3, 61, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 4, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 5, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 6, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101000835, 7, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 1, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 2, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 3, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 4, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 5, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 6, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 7, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 8, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806000836, 9, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 1, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 2, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 3, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 4, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 5, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 6, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 7, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 8, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 9, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 10, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 11, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 12, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 13, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222000837, 14, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 1, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 2, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 3, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 4, 146, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 5, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 6, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 7, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 8, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 9, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 10, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411000838, 11, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 1, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 2, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 3, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 4, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 5, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 6, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 7, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 8, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 9, 31, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403000839, 10, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 1, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 2, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 3, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 4, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 5, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 6, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 7, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 8, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 9, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 10, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 11, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 12, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119000840, 13, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 1, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 2, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 3, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 4, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 5, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 6, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 7, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 8, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 9, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 10, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 11, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 12, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 13, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 14, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625000841, 15, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910000842, 1, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910000842, 2, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910000842, 3, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910000842, 4, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 1, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 2, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 3, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 4, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 5, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 6, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 7, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 8, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 9, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130000843, 10, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 1, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 2, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 3, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 4, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 5, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000844, 6, 176, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 1, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 2, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 4, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 5, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 6, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 7, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 8, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 9, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 9, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 10, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214000100, 11, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 1, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 2, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 3, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 4, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 5, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 6, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 7, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 8, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 9, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 10, 155, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 11, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 12, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 13, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213000101, 14, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 1, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 2, 35, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 3, 192, 5, 18, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 4, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 5, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 6, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 7, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 8, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 9, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 10, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 11, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 12, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 13, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 14, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011000102, 15, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 1, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 2, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 3, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 4, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 5, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 6, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 7, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 8, 35, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 9, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 10, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 11, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 12, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008000103, 13, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231000104, 1, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231000104, 2, 31, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231000104, 3, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231000104, 4, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231000104, 5, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 1, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 2, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 3, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 4, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 5, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 6, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 7, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 8, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 9, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 10, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 11, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 12, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311000105, 13, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 1, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 2, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 3, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 4, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 5, 138, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 6, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 7, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509000106, 8, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725000107, 1, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725000107, 2, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725000107, 3, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725000107, 4, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 1, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 2, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 3, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 4, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 5, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 6, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 7, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 8, 141, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 9, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 10, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 11, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 12, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000108, 13, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 1, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 2, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 3, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 4, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 5, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 6, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 7, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 8, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 9, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 10, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 11, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 12, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 13, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 14, 123, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 15, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 16, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825000109, 17, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 1, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 2, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 3, 191, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 4, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 5, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 6, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 7, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 8, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 9, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000110, 10, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 1, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 2, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 3, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 4, 61, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 5, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601000111, 6, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613000112, 1, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613000112, 2, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613000112, 3, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601000113, 1, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601000113, 2, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601000113, 3, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601000113, 4, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601000113, 5, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 1, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 2, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 3, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 4, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 5, 155, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 6, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 7, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 8, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 9, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 10, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 11, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 12, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 13, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 14, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702000114, 15, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 1, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 2, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 3, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 4, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 5, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 6, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000115, 7, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 1, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 2, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 3, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 4, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 5, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 6, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 7, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 8, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 9, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 10, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 11, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629000116, 12, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 1, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 2, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 3, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 4, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 5, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 6, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 7, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 8, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 9, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 10, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118000117, 11, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 1, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 2, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 3, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 4, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 5, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 6, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 7, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 8, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 9, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 10, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 11, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 12, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 13, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000118, 14, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 1, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 2, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 3, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 4, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 5, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 6, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000119, 7, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 1, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 2, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 3, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 5, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221000120, 6, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 1, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 2, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 3, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 4, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 5, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407000121, 6, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 1, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 2, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 3, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 4, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 5, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 6, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 7, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 8, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 9, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215000122, 10, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 1, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 2, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 3, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 4, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 5, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000123, 6, 115, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 1, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 2, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 3, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 4, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 5, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 6, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000124, 7, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 1, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 2, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 3, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 4, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 5, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 6, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 7, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 8, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 9, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 5, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 6, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 7, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 8, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 9, 179, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 10, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 11, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618000462, 12, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 1, 84, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 2, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 3, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 4, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 5, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705000463, 6, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 1, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 2, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 3, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 4, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 5, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 6, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727000464, 7, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 1, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 2, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 3, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 4, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 5, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203000465, 6, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 1, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 2, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 3, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 4, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 5, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317000466, 6, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 1, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 2, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 3, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 4, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 5, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 6, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 7, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831000467, 8, 72, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 1, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 2, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 3, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 4, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 5, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 6, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 7, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 8, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 9, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 10, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 11, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 12, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 13, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 14, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 15, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120820000468, 16, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 1, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 2, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 3, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 4, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 5, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 6, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705000469, 7, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 1, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 2, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 3, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 4, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 5, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529000470, 6, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 1, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 2, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 3, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 4, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 5, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722000471, 6, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 1, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 2, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 3, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 4, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 5, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 6, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 7, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 8, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 9, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 10, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 11, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 12, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605000472, 13, 102, 2, 11, 22);
commit;
prompt 2000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 1, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 2, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 3, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 4, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 5, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 6, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000473, 7, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000474, 1, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000474, 2, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000474, 3, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000474, 4, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000474, 5, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 1, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 2, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 3, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 4, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 5, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 6, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 7, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 8, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 9, 93, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 10, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 11, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 12, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501000475, 13, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 1, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 2, 12, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 3, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 4, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 5, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 6, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106000476, 7, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122000477, 1, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122000477, 2, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122000477, 3, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122000477, 4, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 1, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 2, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 3, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 4, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 5, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 6, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 7, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 8, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 9, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 10, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 11, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000478, 12, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 1, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 2, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 3, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 4, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 5, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 6, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 7, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 8, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 9, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 10, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 11, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 12, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 13, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623000479, 14, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 1, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 2, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 3, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 4, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 5, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211000480, 6, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 1, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 2, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 3, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 4, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 5, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 6, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 7, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 8, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 9, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 10, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 11, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 12, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 13, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 14, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 15, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311000481, 16, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 1, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 2, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 3, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 4, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 5, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 6, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 7, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 8, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 9, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 10, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 11, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 12, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 13, 69, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 14, 41, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101208000482, 15, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103000483, 1, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103000483, 2, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022000484, 1, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022000484, 2, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022000484, 3, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022000484, 4, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022000484, 5, 3, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 1, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 2, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 3, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 4, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 5, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 6, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 7, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 8, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029000485, 9, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 1, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 2, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 3, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 4, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 5, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 6, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 7, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 8, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 9, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 10, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000486, 11, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 1, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 2, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 3, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 4, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 5, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 6, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 7, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 8, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 9, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 10, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 11, 153, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210000487, 12, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 1, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 2, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 3, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 4, 181, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 5, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 6, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 7, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 8, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 9, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 10, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 11, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 12, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 10, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 11, 95, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 12, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 13, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414000845, 14, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 1, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 2, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 3, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 4, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 5, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909000846, 6, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 1, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 2, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 3, 11, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 4, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 5, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 6, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 7, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 8, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 9, 36, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 10, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 11, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 12, 78, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 13, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101103000847, 14, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 1, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 2, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 3, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 4, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 5, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 6, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 7, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 8, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 9, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 10, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 11, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 12, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 13, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 14, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207000848, 15, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723000849, 1, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723000849, 2, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723000849, 3, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723000849, 4, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 1, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 2, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 3, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 4, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 5, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 6, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 7, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 8, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 9, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 10, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 11, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 12, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 13, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 14, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324000850, 15, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 1, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 2, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 3, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 4, 104, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 5, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 6, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 7, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 8, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 9, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 10, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 11, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 12, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029000851, 13, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 1, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 2, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 3, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 4, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 5, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 6, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 7, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 8, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 9, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 10, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000852, 11, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228000853, 1, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228000853, 2, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228000853, 3, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 1, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 2, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 3, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 4, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 5, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 6, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 7, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 8, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 9, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 10, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 11, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 12, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 13, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603000854, 14, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000428000855, 1, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000428000855, 2, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000428000855, 3, 138, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000428000855, 4, 38, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 1, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 2, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 3, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 4, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 5, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 6, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 7, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 8, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 9, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 10, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 11, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 12, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 13, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124000856, 14, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 1, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 2, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 3, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 4, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 5, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 6, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 7, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 8, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 9, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 10, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 11, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831000857, 12, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 1, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 2, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 3, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 4, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 5, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 6, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 7, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 8, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 9, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 10, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316000858, 11, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 1, 162, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 2, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 3, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 4, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 5, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 6, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 7, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 8, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 9, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 10, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 11, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 12, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531000859, 13, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009000860, 1, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009000860, 2, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009000860, 3, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009000860, 4, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009000860, 5, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 1, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 2, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 3, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 4, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 5, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 6, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 7, 47, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 8, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 9, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 10, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 11, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 12, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 13, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 14, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 15, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 16, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 17, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 18, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311000861, 19, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 1, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 2, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 3, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 4, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 5, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 6, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 7, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 8, 76, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 9, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 10, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 11, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 12, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529000862, 13, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 1, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 2, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 3, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 4, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 5, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 6, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 7, 192, 6, 18, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 8, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 9, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 10, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 11, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 12, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000863, 13, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 1, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 2, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 3, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 4, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 5, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 6, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 7, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 8, 27, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 9, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 10, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 11, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 12, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127000864, 13, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 1, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 2, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 3, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 4, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 5, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 6, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 7, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021000865, 8, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 1, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 2, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 3, 138, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 4, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 5, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 6, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 7, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 8, 19, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 9, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 10, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 11, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 12, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 13, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 14, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 10, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 11, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 12, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 13, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718000125, 14, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809000126, 1, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809000126, 2, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809000126, 3, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809000126, 4, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809000126, 5, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 1, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 2, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 3, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 4, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 5, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 6, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 7, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 8, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 9, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 10, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 11, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 12, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 13, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 14, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 15, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307000127, 16, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 1, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 2, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 3, 182, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 4, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 5, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 6, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 7, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 8, 114, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 9, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 10, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080527000128, 11, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 1, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 2, 181, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 3, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 4, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 5, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 6, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 7, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 8, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914000129, 9, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 1, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 2, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 3, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 4, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 5, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 6, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 7, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 8, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 9, 10, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 10, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 11, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104000130, 12, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 1, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 2, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 3, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 4, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 5, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 6, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 7, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 8, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 9, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 10, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 11, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 12, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 13, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416000131, 14, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 1, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 2, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 3, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 4, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 5, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 6, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 7, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 8, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 9, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 10, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 11, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 12, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101000132, 13, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 1, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 2, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 3, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 4, 165, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 5, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208000133, 6, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 1, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 2, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 3, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 4, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 5, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 6, 71, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 7, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 8, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 9, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 10, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023000134, 11, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 1, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 2, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 3, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 4, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 5, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 6, 132, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 7, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 8, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 9, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 10, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 11, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321000135, 12, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 1, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 2, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 3, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 4, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 5, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 6, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 7, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 8, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 9, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 10, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 11, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 12, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 13, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 14, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 15, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000136, 16, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 1, 88, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 2, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 3, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 4, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 5, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 6, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 7, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429000137, 8, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 1, 35, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 2, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 3, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 4, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 5, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 6, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 7, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 8, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 9, 90, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 10, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 11, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 12, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 13, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 14, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 15, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103000138, 16, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 1, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 2, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 3, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 4, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 5, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 6, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 7, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 8, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 9, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 10, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000139, 11, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 1, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 2, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 3, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 4, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 5, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 6, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 7, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 8, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 9, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 10, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 11, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 12, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 13, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 14, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 15, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 16, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 17, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804000140, 18, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 1, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 2, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 3, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 4, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 5, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 6, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 7, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 8, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 9, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 10, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 11, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 12, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 13, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 14, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 15, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 16, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 17, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 18, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407000141, 19, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 1, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 2, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 3, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 4, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 5, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 6, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 7, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 8, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 9, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 10, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 11, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 12, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 13, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514000142, 14, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 1, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 2, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 3, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 4, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 5, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 6, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 7, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 8, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 9, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 10, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 11, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 12, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326000143, 13, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000144, 1, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000144, 2, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 1, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 2, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 3, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 4, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 5, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025000145, 6, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 1, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 13, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 14, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914000488, 15, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 1, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 2, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 3, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 4, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 5, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 6, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 7, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 8, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 9, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518000489, 10, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 1, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 2, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 3, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 4, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 5, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000490, 6, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 1, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 2, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 3, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 4, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 5, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 6, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 7, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 8, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 9, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 10, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101000491, 11, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 1, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 2, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 3, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 4, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 5, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 6, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 7, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 8, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 9, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 10, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 11, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 12, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000492, 13, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 1, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 2, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 3, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 4, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 5, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 6, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 7, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 8, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 9, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423000493, 10, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 1, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 2, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 3, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 4, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 5, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 6, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 7, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 8, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 9, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 10, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 11, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 12, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 13, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 14, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916000494, 15, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 1, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 2, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 3, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 4, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 5, 8, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 6, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 7, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 8, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 9, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 10, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316000495, 11, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110000496, 1, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110000496, 2, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110000496, 3, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110000496, 4, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110000496, 5, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000497, 1, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000497, 2, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000497, 3, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000497, 4, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 1, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 2, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 3, 33, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 4, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 5, 127, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 6, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 7, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 8, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 9, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 10, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 11, 32, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 12, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 13, 180, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 14, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129000498, 15, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217000499, 1, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217000499, 2, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217000499, 3, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217000499, 4, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217000499, 5, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 1, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 2, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 3, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 4, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 5, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 6, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 7, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720000500, 8, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621000501, 1, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621000501, 2, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621000501, 3, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 1, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 2, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 3, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 4, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 5, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 6, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 7, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 8, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 9, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 10, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 11, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 12, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 13, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202000502, 14, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 1, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 2, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 3, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 4, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 5, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 6, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 7, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 8, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 9, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 10, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 11, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 12, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 13, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 14, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311000503, 15, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 1, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 2, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 3, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 4, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 5, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000504, 6, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 1, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 2, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 3, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 4, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 5, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 6, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 7, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 8, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 9, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 10, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 11, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 12, 166, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 13, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 14, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022000505, 15, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 1, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 2, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 3, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 4, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 5, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 6, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 7, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728000506, 8, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 1, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 2, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 3, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 4, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 5, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 6, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 7, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 8, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 9, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 10, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 11, 140, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 12, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 13, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 14, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 15, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523000507, 16, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 1, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 2, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 3, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 4, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 5, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 6, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 7, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 8, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 9, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 10, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117000508, 11, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000509, 1, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000509, 2, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000509, 3, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 1, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 2, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 3, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 4, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 5, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 6, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 7, 135, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 8, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 9, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 10, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 11, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 12, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 13, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 14, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 15, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524000510, 16, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 1, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 2, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 3, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 4, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 5, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 6, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 7, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 8, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 9, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000511, 10, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 1, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 2, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 3, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 4, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 5, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 6, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526000866, 15, 56, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906000867, 1, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906000867, 2, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906000867, 3, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906000867, 4, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000868, 1, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000868, 2, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000868, 3, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000868, 4, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000868, 5, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 1, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 2, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 3, 1, 85, 3, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 4, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 5, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 6, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 7, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 8, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 9, 166, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313000869, 10, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 1, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 2, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 3, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 4, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 5, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000870, 6, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 1, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 2, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 3, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 4, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 5, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 6, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 7, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 8, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724000871, 9, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 1, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 2, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 3, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 4, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 5, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 6, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 7, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 8, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 9, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 10, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 11, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 12, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926000872, 13, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 1, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 2, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 3, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 4, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 5, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 6, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 7, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 8, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 9, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 10, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 11, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 12, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 13, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 14, 85, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 15, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 16, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 17, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310000873, 18, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 1, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 2, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 3, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 4, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 5, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 6, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 7, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 8, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 9, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 10, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 11, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 12, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 13, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 14, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 15, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604000874, 16, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 1, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 2, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 3, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 4, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 5, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 6, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 7, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 8, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 9, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610000875, 10, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618000876, 1, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618000876, 2, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618000876, 3, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618000876, 4, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618000876, 5, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606000877, 1, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606000877, 2, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606000877, 3, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606000877, 4, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 1, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 2, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 3, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 4, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 5, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 6, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 7, 68, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 8, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 9, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 10, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 11, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 12, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 13, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 14, 134, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219000878, 15, 94, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 1, 74, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 2, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 3, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 4, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 5, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 6, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 7, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 8, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 9, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 10, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 11, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 12, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 13, 111, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 14, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528000879, 15, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 1, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 2, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 3, 166, 21, 13, 273);
commit;
prompt 3000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 4, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 5, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 6, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 7, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525000880, 8, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512000881, 1, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512000881, 2, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512000881, 3, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512000881, 4, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512000881, 5, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 1, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 2, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 3, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 4, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 5, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210000882, 6, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 1, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 2, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 3, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 4, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 5, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 6, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 7, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 8, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 9, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 10, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 11, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 12, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 13, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315000883, 14, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 1, 134, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 2, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 3, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 4, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 5, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 6, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624000884, 7, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 1, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 2, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 3, 156, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 4, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 5, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 6, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 7, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 8, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 9, 3, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 10, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000885, 11, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 1, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 2, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 3, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 4, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 5, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 6, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 7, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 8, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 9, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 10, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 11, 2, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 12, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 13, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 14, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 15, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 16, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 17, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214000886, 18, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 1, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 2, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 3, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 4, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 5, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 6, 69, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719000887, 7, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 1, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 2, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 3, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 4, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 5, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 6, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 7, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 8, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 9, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 10, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412000888, 11, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 1, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 2, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 3, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 5, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 6, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 7, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 8, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 9, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 10, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 11, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 12, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 13, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021000889, 14, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 1, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 2, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 3, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 4, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 5, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 6, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 7, 185, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 2, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 3, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 4, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 5, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 6, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 7, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 8, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211000146, 9, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 1, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 2, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 3, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 4, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 5, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000147, 6, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 1, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 2, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 3, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 4, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 5, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 6, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 7, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 8, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 9, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 10, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 11, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 12, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 13, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502000148, 14, 106, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 1, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 2, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 3, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 4, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 5, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 6, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 7, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 8, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 9, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 10, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 11, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000149, 12, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 1, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 2, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 3, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 4, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 5, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 6, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 7, 192, 41, 18, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 8, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810000150, 9, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 1, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 2, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 3, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 4, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 5, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 6, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030413000151, 7, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 1, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 2, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 3, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 4, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 5, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 6, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 7, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 8, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 9, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 10, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 11, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 12, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 13, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 14, 162, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 15, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000152, 16, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 1, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 2, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 3, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 4, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 5, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 6, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 7, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 8, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 9, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 10, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 11, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 12, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 13, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 14, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 15, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215000153, 16, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 1, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 2, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 3, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 4, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 5, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 6, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 7, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 8, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 9, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 10, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 11, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 12, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 13, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 14, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906000154, 15, 31, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 1, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 2, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 3, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 4, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 5, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 6, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 7, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 8, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 9, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 10, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 11, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329000155, 12, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 1, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 2, 63, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 3, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 4, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 5, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619000156, 6, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 1, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 2, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 3, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 4, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 5, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 6, 157, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 7, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 8, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 9, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 10, 78, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 11, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204000157, 12, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909000158, 1, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909000158, 2, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909000158, 3, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909000158, 4, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 1, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 2, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 3, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 4, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 5, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 6, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 7, 22, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 8, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105000159, 9, 47, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 1, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 2, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 3, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 4, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 5, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014000160, 6, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222000161, 1, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222000161, 2, 188, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222000161, 3, 137, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222000161, 4, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 1, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 2, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 3, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 4, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 5, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913000162, 6, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 1, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 2, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 3, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 4, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 5, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 6, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 7, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 8, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 9, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 10, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 11, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122000163, 12, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000719000164, 1, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000719000164, 2, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 1, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 2, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 3, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 4, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 5, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 6, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227000165, 7, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 1, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 2, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 3, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 4, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 5, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 6, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 7, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 8, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725000166, 9, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 1, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 2, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 3, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 4, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 5, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 6, 2, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 7, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 8, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 9, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 10, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 11, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 12, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 13, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 14, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 15, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 16, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224000167, 17, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 1, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 2, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 3, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 4, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 5, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 6, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 7, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 8, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222000168, 9, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 1, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 2, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 3, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 4, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 5, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 6, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113000169, 7, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 1, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 2, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 3, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 4, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 5, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 6, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 7, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 8, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 9, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 10, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 11, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 12, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 13, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405000170, 14, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 7, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 8, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 9, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 10, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 11, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 12, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727000512, 13, 145, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802000513, 1, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802000513, 2, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802000513, 3, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802000513, 4, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 1, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 2, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 3, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 4, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 5, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 6, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 7, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 8, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 9, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 10, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 11, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000514, 12, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 1, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 2, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 3, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 4, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 5, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 6, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 7, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 8, 22, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 9, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 10, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 11, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 12, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 13, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 14, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106000515, 15, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 1, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 2, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 3, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 4, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 5, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 6, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 7, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 8, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 9, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925000516, 10, 139, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 1, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 2, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 3, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 4, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 5, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 6, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 7, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 8, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 9, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 10, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 11, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 12, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 13, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830000517, 14, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 1, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 2, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 3, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 4, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 5, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 6, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 7, 107, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 8, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126000518, 9, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 1, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 2, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 3, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 4, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 5, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725000519, 6, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 1, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 2, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 3, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 4, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 5, 114, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 6, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 7, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204000520, 8, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925000521, 1, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925000521, 2, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925000521, 3, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925000521, 4, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405000522, 1, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405000522, 2, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405000522, 3, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405000522, 4, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405000522, 5, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 1, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 2, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 3, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 4, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 5, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 6, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117000523, 7, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 1, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 2, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 3, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 4, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 5, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 6, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 7, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 8, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 9, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 10, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 11, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 12, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 13, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 14, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118000524, 15, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 1, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 2, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 3, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 4, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 5, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 6, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 7, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 8, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 9, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 10, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 11, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 12, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917000525, 13, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 1, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 2, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 3, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 4, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 5, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 6, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 7, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 8, 57, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 9, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206000526, 10, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 1, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 2, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 3, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 4, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 5, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 6, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 7, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 8, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 9, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000527, 10, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 1, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 2, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 3, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 4, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 5, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 6, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 7, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 8, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 9, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 10, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 11, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 12, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 13, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 14, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 15, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 16, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221000528, 17, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 2, 12, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 3, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 4, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 5, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 6, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 7, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713000529, 8, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 1, 26, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 2, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 3, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 4, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 5, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 6, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040718000530, 7, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926000531, 1, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926000531, 2, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926000531, 3, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926000531, 4, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 1, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 2, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 3, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 4, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 5, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 6, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 7, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 8, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 9, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 10, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 11, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 12, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 13, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 14, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231000532, 15, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 1, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 2, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 3, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 4, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 5, 41, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 6, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 7, 96, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 8, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506000533, 9, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 1, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 2, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 3, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 4, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 5, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 6, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 7, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 8, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 9, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 10, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 11, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 12, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 13, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 14, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 15, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918000534, 16, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 1, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 2, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 3, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 4, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 5, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 6, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 7, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 8, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 9, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128000535, 10, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020526000536, 1, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020526000536, 2, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020526000536, 3, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 9, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 10, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 1, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 2, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 3, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 4, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 5, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 6, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 7, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 8, 168, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 9, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 10, 101, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 11, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115000941, 12, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 1, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 2, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 3, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 4, 121, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 5, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 6, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 7, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 8, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 9, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 10, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120000942, 11, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 1, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 2, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 3, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 4, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 5, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000943, 6, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 1, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 2, 10, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 3, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 4, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 5, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 6, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 7, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129000944, 8, 120, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 1, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 2, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 3, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 4, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 5, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 6, 42, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 7, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 8, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 9, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 10, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213000945, 11, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 1, 109, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 2, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 3, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 4, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 5, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 6, 24, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 7, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 8, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 9, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 10, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000946, 11, 128, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 1, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 2, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 3, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 4, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 5, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 6, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 7, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702000947, 8, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000948, 1, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000948, 2, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000948, 3, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000948, 4, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 1, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 2, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 3, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 4, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 5, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 6, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 7, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 8, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 9, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 10, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 11, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000949, 12, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 1, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 2, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 3, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 4, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 5, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 6, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 7, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 8, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 9, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 10, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 11, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 12, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 13, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 14, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 15, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 16, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140429000950, 17, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 1, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 2, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 3, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 4, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 5, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 6, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 7, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 8, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 9, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 10, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 11, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905000951, 12, 107, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 1, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 2, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 3, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 4, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 5, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 6, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 7, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 8, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 9, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 10, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212000952, 11, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 1, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 2, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 3, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 4, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 5, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 6, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 7, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 8, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 9, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 10, 192, 71, 18, 1278);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 11, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225000953, 12, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 1, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 2, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 3, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 4, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 5, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 6, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 7, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 8, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 9, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 10, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 11, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 12, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 13, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 14, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 15, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403000954, 16, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 1, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 2, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 3, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 4, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 5, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 6, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 7, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 8, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 9, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204000955, 10, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212000956, 1, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212000956, 2, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212000956, 3, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212000956, 4, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212000956, 5, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 1, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 2, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 3, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 4, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 5, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 6, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 7, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008000957, 8, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 1, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 2, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 3, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 4, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 5, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628000958, 6, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 1, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 2, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 3, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 4, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 5, 1, 75, 3, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 6, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 7, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125000959, 8, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 1, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 3, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 4, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 5, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 6, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 7, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 8, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 9, 189, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 10, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216000960, 11, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518000961, 1, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518000961, 2, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518000961, 3, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 1, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 2, 184, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 3, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 4, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 5, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 6, 38, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 7, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303000962, 8, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 1, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 2, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 3, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 4, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 5, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 6, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 7, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 8, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 9, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 10, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 11, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 12, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 13, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 14, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901000963, 15, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530000964, 1, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530000964, 2, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530000964, 3, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530000964, 4, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 1, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 2, 174, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 3, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 4, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 5, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 6, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 7, 94, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 8, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 1, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 2, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 3, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 4, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 5, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 6, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 7, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 8, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 9, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 10, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 11, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 12, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 13, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 14, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013000171, 15, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 1, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 2, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 3, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 4, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 5, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 6, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 7, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 8, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 9, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 10, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 11, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 12, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000172, 13, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 1, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 2, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 3, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 4, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 5, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 6, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 7, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 8, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 9, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 10, 173, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809000173, 11, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000174, 1, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000174, 2, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000174, 3, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327000174, 4, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 1, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 2, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 3, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 4, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 5, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023000175, 6, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 1, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 2, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 3, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 4, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 5, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 6, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 7, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 8, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 9, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 10, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 11, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 12, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 13, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 14, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 15, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000176, 16, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 1, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 2, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 3, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 4, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 5, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 6, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 7, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 8, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 9, 180, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 10, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019000177, 11, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 1, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 2, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 3, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 4, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 5, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 6, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 7, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 8, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 9, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 10, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 11, 96, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 12, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 13, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124000178, 14, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 1, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 2, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 3, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 4, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 5, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 6, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 7, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 8, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 9, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 10, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 11, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 12, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423000179, 13, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 1, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 2, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 3, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 4, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 5, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 6, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 7, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 8, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 9, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 10, 68, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 11, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 12, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401000180, 13, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000181, 1, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000181, 2, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000181, 3, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000181, 4, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 1, 188, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 2, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 3, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 4, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 5, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 6, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 7, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 8, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 9, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 10, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 11, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 12, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215000182, 13, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116000183, 1, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116000183, 2, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116000183, 3, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116000183, 4, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116000183, 5, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 1, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 2, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 3, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 4, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 5, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 6, 1, 40, 3, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507000184, 7, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514000185, 1, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514000185, 2, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514000185, 3, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514000185, 4, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514000185, 5, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 1, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 2, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 3, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 4, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 5, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 6, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 7, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 8, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 9, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 10, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000186, 11, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405000187, 1, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405000187, 2, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405000187, 3, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405000187, 4, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405000187, 5, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 1, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 2, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 3, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 4, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 5, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 6, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 7, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 8, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 9, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 10, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127000188, 11, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 1, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 2, 54, 96, 11, 1056);
commit;
prompt 4000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 3, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 4, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 5, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 6, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 7, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 8, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 9, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 10, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 11, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 12, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 13, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 14, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 15, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 16, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 17, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122000189, 18, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 1, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 2, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 3, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 4, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 5, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808000190, 6, 10, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 1, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 2, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 3, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 4, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 5, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119000191, 6, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 1, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 2, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 3, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 4, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 5, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 6, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 7, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 8, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 9, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 10, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 11, 115, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 12, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 13, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 14, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819000192, 15, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 1, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 2, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 3, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 4, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 5, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 6, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 7, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 8, 136, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 9, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 10, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 11, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 12, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 13, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630000193, 14, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 1, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 2, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 3, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020526000536, 4, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020526000536, 5, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121000537, 1, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121000537, 2, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121000537, 3, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121000537, 4, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121000537, 5, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 1, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 2, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 3, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 4, 99, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 5, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 6, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 7, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 8, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 9, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 10, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 11, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 12, 1, 7, 3, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 13, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 14, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 15, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 16, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505000538, 17, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 1, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 2, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 3, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 4, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 5, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 6, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331000539, 7, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 1, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 2, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 3, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 4, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 5, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 6, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 7, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 8, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 9, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217000540, 10, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 1, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 2, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 3, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 4, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 5, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 6, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 7, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 8, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 9, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 10, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 11, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 12, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518000541, 13, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 1, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 2, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 3, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 4, 18, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 5, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 6, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 7, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 8, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605000542, 9, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 1, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 2, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 3, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 4, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 5, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 6, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 7, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 8, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 9, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 10, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 11, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 12, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 13, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 14, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 15, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 16, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315000543, 17, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317000544, 1, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317000544, 2, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317000544, 3, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 1, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 2, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 3, 17, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 4, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 5, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 6, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 7, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 8, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 9, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 10, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916000545, 11, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 1, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 2, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 3, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 4, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 5, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 6, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 7, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 8, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 9, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 10, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 11, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 12, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 13, 116, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 14, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 15, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201000546, 16, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 1, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 2, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 3, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 4, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 6, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 7, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 8, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 9, 111, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 10, 39, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 11, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 12, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 13, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 14, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 15, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914000547, 16, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407000548, 1, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407000548, 2, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407000548, 3, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407000548, 4, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 1, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 2, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 3, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 4, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 5, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 6, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 7, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904000549, 8, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329000550, 1, 89, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329000550, 2, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 1, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 2, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 3, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 4, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 5, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 6, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 7, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 8, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 9, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 10, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 11, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 12, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006000551, 13, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 1, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 2, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 3, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 4, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 5, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 6, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 7, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 8, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 9, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 10, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213000552, 11, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 1, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 2, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 3, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 4, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 5, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 6, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 7, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 8, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 9, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120000553, 10, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000554, 1, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000554, 2, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000554, 3, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000554, 4, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000554, 5, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 1, 191, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 2, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 3, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 4, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 5, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 6, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228000555, 7, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 1, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 3, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 4, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 5, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 6, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 7, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 8, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 9, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 10, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 11, 22, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 12, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 13, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 14, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 15, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629000556, 16, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210000557, 1, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210000557, 2, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210000557, 3, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210000557, 4, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210000557, 5, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 1, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 2, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 3, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 4, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 5, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 6, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 7, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 8, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 9, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 10, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 11, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 12, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 13, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 14, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 15, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 16, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 17, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328000558, 18, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 1, 63, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 2, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 3, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 4, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 5, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 6, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507000559, 7, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 1, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 2, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 3, 148, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 4, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 5, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 6, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 7, 79, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 6, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 7, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 8, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 9, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 10, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 11, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 12, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 13, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 1, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 2, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 3, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 4, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 5, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 6, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 7, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 8, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 9, 109, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 10, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 11, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 12, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 13, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105001059, 14, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110001060, 1, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110001060, 2, 61, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110001060, 3, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110001060, 4, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 1, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 2, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 3, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 4, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 5, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 6, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 7, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 8, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001061, 9, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 1, 79, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 2, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 3, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 4, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 5, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 6, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 7, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 8, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 9, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 10, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620001062, 11, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 1, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 2, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 3, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 4, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 5, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 6, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 7, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 8, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 9, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624001063, 10, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 1, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 2, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 3, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 4, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 5, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 6, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 7, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 8, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 9, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 10, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 11, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 12, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 13, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231001064, 14, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 1, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 2, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 3, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 4, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 5, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 6, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 7, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 8, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 9, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117001065, 10, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 1, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 2, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 3, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 4, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 5, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 6, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 7, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 8, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 9, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 10, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 11, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203001066, 12, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 1, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 2, 81, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 3, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 4, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 5, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 6, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 7, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 8, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 9, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 10, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 11, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 12, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 13, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206001067, 14, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 1, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 2, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 3, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 4, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 5, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 6, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 7, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 8, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 9, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 10, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 11, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 12, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 13, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 14, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 15, 37, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413001068, 16, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 1, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 2, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 3, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 4, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 5, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 6, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 7, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 8, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 9, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 10, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 11, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 12, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 13, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 14, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 15, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001069, 16, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701001070, 1, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701001070, 2, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701001070, 3, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701001070, 4, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701001070, 5, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818001071, 1, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818001071, 2, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818001071, 3, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818001071, 4, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 1, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 2, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 3, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 4, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 5, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 6, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 7, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 8, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 9, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001072, 10, 187, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 1, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 2, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 3, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 4, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 5, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 6, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 7, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 8, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 9, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419001073, 10, 186, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 1, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 2, 70, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 3, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 4, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 5, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 6, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 7, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 8, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 9, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 10, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818001074, 11, 58, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 1, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 2, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 3, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 4, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 5, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 6, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 7, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 8, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104001075, 9, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 1, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 2, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 3, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 4, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 5, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 6, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 7, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 8, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 9, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 10, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 11, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 12, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 13, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411001076, 14, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 1, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 2, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 3, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 4, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 5, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 6, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 7, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 8, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 9, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209001077, 10, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 1, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 2, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 3, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 4, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 5, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 6, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 7, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 8, 122, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718001078, 9, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 1, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 2, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 3, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 4, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 5, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 6, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 7, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 8, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 9, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 10, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 11, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 12, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 13, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 14, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106001079, 15, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 1, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 2, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 3, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 4, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 4, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 5, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 6, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730000194, 7, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 1, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 2, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 3, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 4, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 5, 148, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 6, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 7, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414000195, 8, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 1, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 2, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 3, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 4, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 5, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 6, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 7, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 8, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 9, 109, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910000196, 10, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000197, 1, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000197, 2, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000197, 3, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000197, 4, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 1, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 2, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 3, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 4, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 5, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 6, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 7, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 8, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 9, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 10, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 11, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 12, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000198, 13, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 1, 192, 5, 18, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 2, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 3, 124, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 4, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 5, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118000199, 6, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000200, 1, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000200, 2, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000200, 3, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000200, 4, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011000200, 5, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001022000201, 1, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001022000201, 2, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001022000201, 3, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 1, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 2, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 3, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 4, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 5, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 6, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107000202, 7, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 1, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 2, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 3, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 4, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 5, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 6, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 7, 32, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 8, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 9, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812000203, 10, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 1, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 2, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 3, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 4, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 5, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810000204, 6, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919000205, 1, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919000205, 2, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919000205, 3, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919000205, 4, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919000205, 5, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 1, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 2, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 3, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 4, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 5, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 6, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 7, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 8, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 9, 191, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 10, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403000206, 11, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 1, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 2, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 3, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 4, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 5, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 6, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 7, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 8, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 9, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000207, 10, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709000208, 1, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709000208, 2, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709000208, 3, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709000208, 4, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 1, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 2, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 3, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 4, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 5, 178, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 6, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 7, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 8, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919000209, 9, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 1, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 2, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 3, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 4, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 5, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 6, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 7, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 8, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 9, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 10, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 11, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 12, 131, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 13, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 14, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 15, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 16, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 17, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420000210, 18, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 1, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 2, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 3, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 4, 133, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 5, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 6, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 7, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 8, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 9, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 10, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 11, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 12, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225000211, 13, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 1, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 2, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 3, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 4, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 5, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 6, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 7, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 8, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 9, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603000212, 10, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 1, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 2, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 3, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 4, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 5, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 6, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 7, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 8, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 9, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 10, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 11, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 12, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131000213, 13, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 1, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 2, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 3, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 4, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 5, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 6, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 7, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707000214, 8, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 1, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 2, 179, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 3, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 4, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 5, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 6, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 7, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 8, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 9, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212000215, 10, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 1, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 2, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 3, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 4, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 5, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617000216, 6, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 1, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 2, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 3, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 4, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 5, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 6, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 7, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 8, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 9, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 10, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 11, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 12, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 13, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 14, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 15, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716000217, 16, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 1, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 2, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 3, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 4, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 5, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 6, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 7, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 8, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 9, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 10, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 11, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 12, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630000218, 13, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 1, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 2, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 3, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 4, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 5, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 6, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 7, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 8, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 9, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 10, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903000219, 11, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 1, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 2, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 3, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 4, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 5, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820000220, 6, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 8, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 9, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 10, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 11, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813000560, 12, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000561, 1, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000561, 2, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000561, 3, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517000561, 4, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 1, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 2, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 3, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 4, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 5, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 6, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 7, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 8, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 9, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 10, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 11, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 12, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 13, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 14, 48, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 15, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 16, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 17, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 18, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124000562, 19, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 1, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 2, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 3, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 4, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 5, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 6, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 7, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 8, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 9, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 10, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 11, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121000563, 12, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 1, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 2, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 3, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 4, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 5, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 6, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 7, 187, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 8, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 9, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 10, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 11, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 12, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 13, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 14, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 15, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 16, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303000564, 17, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 1, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 2, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 3, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 4, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 5, 18, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 6, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 7, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 8, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 9, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 10, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 11, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 12, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512000565, 13, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000566, 1, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000566, 2, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000566, 3, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418000566, 4, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 1, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 2, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 3, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 4, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 5, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 6, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 7, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 8, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706000567, 9, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 1, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 2, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 3, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 4, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 5, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 6, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 7, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 8, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000568, 9, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 1, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 2, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 3, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 4, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 5, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 6, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 7, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 8, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 9, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914000569, 10, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 1, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 2, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 3, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 4, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 5, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 6, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 7, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 8, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 9, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 10, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005000570, 11, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219000571, 1, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219000571, 2, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219000571, 3, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 1, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 2, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 3, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 4, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 5, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923000572, 6, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212000573, 1, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212000573, 2, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212000573, 3, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212000573, 4, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212000573, 5, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 1, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 2, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 3, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 4, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 5, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 6, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 7, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 8, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 9, 146, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 10, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 11, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 12, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 13, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 14, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302000574, 15, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000575, 1, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000575, 2, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000575, 3, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000575, 4, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429000575, 5, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826000576, 1, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826000576, 2, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826000576, 3, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 1, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 2, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 3, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 4, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 5, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 6, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 7, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 8, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 9, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 10, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 11, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324000577, 12, 127, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 1, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 2, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 3, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 4, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 5, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 6, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 7, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 8, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 9, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 10, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 11, 85, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 12, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 13, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730000578, 14, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 1, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 2, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 3, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 4, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 5, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 6, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 7, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 8, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 9, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 10, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126000579, 11, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 1, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 2, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 3, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 4, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 5, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 6, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 7, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 8, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 9, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 10, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 11, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 12, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 13, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 14, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 15, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809000580, 16, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 1, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 2, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 3, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 4, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 5, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 6, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 7, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 8, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 9, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 10, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409000581, 11, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 1, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 2, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 3, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 4, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 5, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 6, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 7, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 8, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 9, 62, 72, 12, 864);
commit;
prompt 5000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 10, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 11, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 12, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 13, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712000582, 14, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 1, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 2, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 3, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 4, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 5, 96, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 6, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 7, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307000583, 8, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 1, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 2, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 3, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 9, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 10, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826000965, 11, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 1, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 2, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 3, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 4, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 5, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 6, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 7, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 8, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 9, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 10, 156, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 11, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 12, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 13, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121213000966, 14, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 1, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 2, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 3, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 4, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 5, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 6, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 7, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 8, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 9, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 10, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 11, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 12, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023000967, 13, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 1, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 2, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 3, 30, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 4, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 5, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 6, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 7, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 8, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 9, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 10, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 11, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 12, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 13, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 14, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117000968, 15, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104000969, 1, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104000969, 2, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104000969, 3, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104000969, 4, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104000969, 5, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207000970, 1, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207000970, 2, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207000970, 3, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207000970, 4, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207000970, 5, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 1, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 2, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 3, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 4, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 5, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 6, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 7, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 8, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014000971, 9, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 1, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 2, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 3, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 4, 134, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 5, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 6, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 7, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 8, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 9, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318000972, 10, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 1, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 2, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 3, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 4, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 5, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 6, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 7, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 8, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 9, 147, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106000973, 10, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603000974, 1, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603000974, 2, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603000974, 3, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603000974, 4, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603000974, 5, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 1, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 2, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 3, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 4, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 5, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 6, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 7, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 8, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 9, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611000975, 10, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 1, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 2, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 3, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 4, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 5, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 6, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 7, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 8, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 9, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 10, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 11, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730000976, 12, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 1, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 2, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 3, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 4, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 5, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 6, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 7, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 8, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 9, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 10, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 11, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 12, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201000977, 13, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 1, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 2, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 3, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 4, 6, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 5, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 6, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 7, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201000978, 8, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 1, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 2, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 3, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 4, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 5, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 6, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 7, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 8, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 9, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 10, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 11, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 12, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 13, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 14, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120410000979, 15, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 1, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 2, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 3, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 4, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 5, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 6, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027000980, 7, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222000981, 1, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222000981, 2, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222000981, 3, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222000981, 4, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 1, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 2, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 3, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 4, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 5, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916000982, 6, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 1, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 2, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 3, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 4, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 5, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 6, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 7, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 8, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 9, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 10, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 11, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 12, 192, 12, 18, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211000983, 13, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 1, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 2, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 3, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 4, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 5, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 6, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 7, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 8, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 9, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 10, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 11, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 12, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119000984, 13, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 1, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 2, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 3, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 4, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 5, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 6, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 7, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111000985, 8, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 1, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 2, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 3, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 4, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 5, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 6, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018000986, 7, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 1, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 2, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 3, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 4, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 5, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 6, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 7, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 8, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 9, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 10, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 11, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 12, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 13, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 14, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911000987, 15, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 1, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 2, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 3, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 4, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 5, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 6, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207000988, 7, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000989, 1, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000989, 2, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000989, 3, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518000989, 4, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 1, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 2, 180, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 3, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 4, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 5, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 6, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 7, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 8, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 1, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 2, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 3, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 4, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 5, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 6, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 7, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 8, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 9, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 10, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127000221, 11, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 1, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 2, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 3, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 4, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 5, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 6, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000222, 7, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 1, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 2, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 3, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 4, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 5, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 6, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018000223, 7, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 1, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 2, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 3, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 4, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 5, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 6, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 7, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 8, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 9, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 10, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 11, 192, 23, 18, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 12, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331000224, 13, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 1, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 2, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 3, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 4, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 5, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 6, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 7, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 8, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 9, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 10, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 11, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 12, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 13, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 14, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 15, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425000225, 16, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120000226, 1, 59, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120000226, 2, 150, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120000226, 3, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120000226, 4, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120000226, 5, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 1, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 2, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 3, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 4, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 5, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 6, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 7, 19, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 8, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 9, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 10, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 11, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 12, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 13, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 14, 192, 45, 18, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 15, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 16, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022000227, 17, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102000228, 1, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102000228, 2, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102000228, 3, 167, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102000228, 4, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102000228, 5, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 1, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 2, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 3, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 4, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 5, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 6, 165, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 7, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 8, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 9, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 10, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 11, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 12, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 13, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 14, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 15, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105000229, 16, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 1, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 2, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 3, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 4, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 5, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 6, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 7, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 8, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 9, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 10, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922000230, 11, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010814000231, 1, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010814000231, 2, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010814000231, 3, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010814000231, 4, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 1, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 2, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 3, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 4, 22, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 5, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 6, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 7, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 8, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 9, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 10, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 11, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 12, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 13, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 14, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000232, 15, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 1, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 2, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 3, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 4, 87, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 5, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 6, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 7, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 8, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 9, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051002000233, 10, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211000234, 1, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211000234, 2, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211000234, 3, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211000234, 4, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426000235, 1, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426000235, 2, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 1, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 2, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 3, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 4, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 5, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 6, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 7, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 8, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110000236, 9, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 1, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 2, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 3, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 4, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 5, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 6, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 7, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 8, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 9, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060409000237, 10, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 1, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 2, 51, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 3, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 4, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 5, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 6, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 7, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 8, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 9, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 10, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 11, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 12, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 13, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004000238, 14, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020823000239, 1, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020823000239, 2, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020823000239, 3, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020823000239, 4, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020823000239, 5, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 1, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 2, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 3, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 4, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 5, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 6, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408000240, 7, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625000241, 1, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625000241, 2, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625000241, 3, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625000241, 4, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703000242, 1, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703000242, 2, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703000242, 3, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703000242, 4, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 1, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 2, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 3, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 4, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 5, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 6, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123000243, 7, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 1, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 2, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 3, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 4, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 5, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628000244, 6, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220000245, 1, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220000245, 2, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 1, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 2, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 3, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 4, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 5, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 6, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 7, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 8, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 9, 10, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 10, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 11, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 12, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 13, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 14, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 15, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624000246, 16, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105000247, 1, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105000247, 2, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 1, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 2, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 3, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 4, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 5, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 6, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 7, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 8, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 9, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 10, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 4, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 5, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 6, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 7, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 8, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212000584, 9, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 1, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 2, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 3, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 4, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 5, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 6, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207000585, 7, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011204000586, 1, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011204000586, 2, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011204000586, 3, 132, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011204000586, 4, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011204000586, 5, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308000587, 1, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308000587, 2, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308000587, 3, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308000587, 4, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 1, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 2, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 3, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 4, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 5, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 6, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 7, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 8, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 9, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 10, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000588, 11, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128000589, 1, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128000589, 2, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128000589, 3, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128000589, 4, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128000589, 5, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209000590, 1, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209000590, 2, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209000590, 3, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209000590, 4, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209000590, 5, 94, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 1, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 2, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 3, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 4, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 5, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 6, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402000591, 7, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 1, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 2, 154, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 3, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 4, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 5, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 6, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502000592, 7, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 1, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 2, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 3, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 4, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 5, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526000593, 6, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 1, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 2, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 3, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 4, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 5, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 6, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 7, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 8, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 9, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 10, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 11, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080123000594, 12, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 1, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 2, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 3, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 4, 58, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 5, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 6, 52, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 7, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 8, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 9, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 10, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 11, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 12, 10, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 13, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 14, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 15, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 16, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227000595, 17, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 1, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 2, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 3, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 4, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 5, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 6, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 7, 164, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 8, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 9, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 10, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 11, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 12, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421000596, 13, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 1, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 2, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 3, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 4, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 5, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 6, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 7, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 8, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 9, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 10, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 11, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 12, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 13, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 14, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 15, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 16, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210000597, 17, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 1, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 2, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 3, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 4, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 5, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 6, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518000598, 7, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 1, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 2, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 3, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 4, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 5, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 6, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 7, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 8, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 9, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 10, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 11, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 12, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 13, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 14, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 15, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 16, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411000599, 17, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 1, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 2, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 3, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 4, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 5, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 6, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 7, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202000600, 8, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 1, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 2, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 3, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 4, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 5, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 6, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 7, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 8, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000601, 9, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 1, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 2, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 3, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 4, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 5, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 6, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 7, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 8, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 9, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 10, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309000602, 11, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719000603, 1, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719000603, 2, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719000603, 3, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719000603, 4, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719000603, 5, 63, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 1, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 2, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 3, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 4, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 5, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 6, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 7, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 8, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 9, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 10, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 11, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 12, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 13, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518000604, 14, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 1, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 2, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 3, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 4, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 5, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 6, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 7, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 8, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 9, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 10, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 11, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113000605, 12, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 1, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 2, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 3, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 4, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 5, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 6, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 7, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 8, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 9, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 10, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 11, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104000606, 12, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 1, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 2, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 3, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 4, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 5, 8, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 6, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 7, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116000607, 8, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 1, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 2, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 3, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 4, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 5, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 6, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 7, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 8, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 9, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 10, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 11, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111000608, 12, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 1, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 2, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 5, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001080, 6, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 1, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 2, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 3, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 4, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 5, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 6, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 7, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 8, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 9, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 10, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 11, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909001081, 12, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 1, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 2, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 3, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 4, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 5, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 6, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 7, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001082, 8, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 1, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 2, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 3, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 4, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 5, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419001083, 6, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 1, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 2, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 3, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 4, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 5, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 6, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 7, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 8, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 9, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 10, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 11, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 12, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 13, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118001084, 14, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927001085, 1, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927001085, 2, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927001085, 3, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927001085, 4, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927001085, 5, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 1, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 2, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 3, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 4, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 5, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 6, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 7, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 8, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 9, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 10, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 11, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 12, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 13, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 14, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603001086, 15, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 1, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 2, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 3, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 4, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 5, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 6, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 7, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 8, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 9, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 10, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 11, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 12, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 13, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 14, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 15, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214001087, 16, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 1, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 2, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 3, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 4, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 5, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 6, 153, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 7, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 8, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 9, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 10, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 11, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001088, 12, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 1, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 2, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 3, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 4, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 5, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 6, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 7, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 8, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 9, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 10, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 11, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 12, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 13, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 14, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128001089, 15, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 1, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 2, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 3, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 4, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 5, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 6, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 7, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 8, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 9, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 10, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 11, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 12, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 13, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 14, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 15, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222001090, 16, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 1, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 2, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 3, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 4, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 5, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 6, 71, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 7, 42, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 8, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427001091, 9, 9, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 1, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 2, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 3, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 4, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 5, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 6, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 7, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 8, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 9, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 10, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229001092, 11, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 1, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 2, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 3, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 4, 100, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 5, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 6, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 7, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 8, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 9, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 10, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 11, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 12, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 13, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615001093, 14, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 1, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 2, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 3, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 4, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 5, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 6, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 7, 69, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001094, 8, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 1, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 2, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 3, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 4, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 5, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 6, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 7, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 8, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 9, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 10, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 11, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 12, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 13, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 14, 49, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429001095, 15, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 1, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 2, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 3, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 4, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 5, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 6, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 7, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 8, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 9, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 10, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 11, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 12, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 13, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 14, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201001096, 15, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 1, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 2, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 3, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 4, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 5, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 6, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 7, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 8, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 9, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 10, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 11, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 12, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 13, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514001097, 14, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 1, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 2, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 3, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 4, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 5, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 6, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 7, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 8, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 9, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 10, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 11, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 12, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 13, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318001098, 14, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 1, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 2, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 3, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 4, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 5, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 6, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 7, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729001099, 8, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 1, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 2, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 3, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 4, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 5, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 6, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 7, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001100, 8, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 1, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 2, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 11, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 12, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531000248, 13, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 1, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 2, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 3, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 4, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 5, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 6, 55, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 7, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 8, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 9, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000249, 10, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 1, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 2, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 3, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 4, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 5, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 6, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 7, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 8, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 9, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610000250, 10, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 1, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 2, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 3, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 4, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 5, 140, 69, 11, 759);
commit;
prompt 6000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 6, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 7, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 8, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708000251, 9, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 1, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 2, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 3, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 4, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 5, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 6, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 7, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 8, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 9, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 10, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 11, 192, 14, 18, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 12, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 13, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 14, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 15, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811000252, 16, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525000253, 1, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525000253, 2, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525000253, 3, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525000253, 4, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525000253, 5, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 1, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 2, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 3, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 4, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 5, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 6, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 7, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 8, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310000254, 9, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 1, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 2, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 3, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 4, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 5, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 6, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 7, 151, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 8, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000255, 9, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 1, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 2, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 3, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 4, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 5, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 6, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 7, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 8, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 9, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 10, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 11, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 12, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 13, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 14, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213000256, 15, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 1, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 2, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 3, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 4, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 5, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 6, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 7, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818000257, 8, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 1, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 2, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 3, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 4, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 5, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 6, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 7, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 8, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 9, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 10, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 11, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 12, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 13, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 14, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 15, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 16, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612000258, 17, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 1, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 2, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 3, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 4, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 5, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624000259, 6, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629000260, 1, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629000260, 2, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629000260, 3, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629000260, 4, 45, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629000260, 5, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 1, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 2, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 3, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 4, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 5, 19, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 6, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 7, 131, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214000261, 8, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 1, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 2, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 3, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 4, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 5, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 6, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 7, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 8, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 9, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 10, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 11, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 12, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 13, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 14, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215000262, 15, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 1, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 2, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 3, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 4, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 5, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 6, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 7, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 8, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 9, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 10, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 11, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 12, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 13, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 14, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 15, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 16, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 17, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217000263, 18, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 1, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 2, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 3, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 4, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 5, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 6, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 7, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 8, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 9, 129, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 10, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 11, 116, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 12, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 13, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514000264, 14, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 1, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 2, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 3, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 4, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 5, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824000265, 6, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 1, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 2, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 3, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 4, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 5, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 6, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710000266, 7, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 1, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 2, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 3, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 4, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 5, 169, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 6, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 7, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 8, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 9, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 10, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 11, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 12, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215000267, 13, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 1, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 2, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 3, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 4, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 5, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 6, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 7, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 8, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 9, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 10, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 11, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 12, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 13, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 14, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501000268, 15, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 1, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 2, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 3, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 4, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 5, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 6, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 7, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 8, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 9, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 10, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 11, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 12, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918000269, 13, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402000270, 1, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402000270, 2, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402000270, 3, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402000270, 4, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402000270, 5, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 1, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 2, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 3, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 3, 58, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 4, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 5, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 6, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 7, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 8, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124000609, 9, 88, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007000610, 1, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007000610, 2, 51, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007000610, 3, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007000610, 4, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007000610, 5, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 1, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 2, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 3, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 4, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 5, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 6, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 7, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 8, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 9, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 10, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217000611, 11, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 1, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 2, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 3, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 4, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 5, 157, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 6, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 7, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 8, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 9, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 10, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 11, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 12, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 13, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 14, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 15, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727000612, 16, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 1, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 2, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 3, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 4, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 5, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 6, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424000613, 7, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 1, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 2, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 3, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 4, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 5, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 6, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 7, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 8, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 9, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 10, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 11, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 12, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526000614, 13, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101000615, 1, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101000615, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101000615, 3, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101000615, 4, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101000615, 5, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 1, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 2, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 3, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 4, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 5, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 6, 48, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 7, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 8, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 9, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 10, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829000616, 11, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 1, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 2, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 3, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 4, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 5, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 6, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 7, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 8, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 9, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 10, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 11, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 12, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 13, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 14, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 15, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 16, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822000617, 17, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 1, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 2, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 3, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 4, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 5, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 6, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 7, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 8, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509000618, 9, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 1, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 2, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 3, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 4, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 5, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 6, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 7, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 8, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 9, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 10, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 11, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 12, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 13, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 14, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409000619, 15, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916000620, 1, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916000620, 2, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916000620, 3, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916000620, 4, 187, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916000620, 5, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 1, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 2, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 3, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 4, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 5, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 6, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 7, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 8, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000621, 9, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 1, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 2, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 3, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 4, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 5, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 6, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 7, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 8, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 9, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 10, 51, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717000622, 11, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918000623, 1, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918000623, 2, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 1, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 2, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 3, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 4, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 5, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 6, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 7, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 8, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 9, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 10, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 11, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428000624, 12, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120000625, 1, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120000625, 2, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120000625, 3, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 1, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 2, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 3, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 4, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 5, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715000626, 6, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 1, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 2, 183, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 3, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 4, 108, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 5, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 6, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 7, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 8, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 9, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 10, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 11, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 12, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 13, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828000627, 14, 164, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 1, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 2, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 3, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 4, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 5, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 6, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 7, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 8, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 9, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 10, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502000628, 11, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 1, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 2, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 3, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 4, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 5, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 6, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 7, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 8, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 9, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 10, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 11, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 12, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 13, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 14, 96, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504000629, 15, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 1, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 2, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 3, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 4, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 5, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 6, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 7, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 8, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 9, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 10, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 11, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 12, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 13, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 14, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 15, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509000630, 16, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 1, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 2, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 3, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 4, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 5, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 6, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 7, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 8, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 9, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 10, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 11, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 12, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 13, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628000631, 14, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 1, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 2, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 3, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 4, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 5, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 9, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 10, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 11, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 12, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602000990, 13, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 1, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 2, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 3, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 4, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 5, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 6, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 7, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 8, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 9, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 10, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 11, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 12, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 13, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 14, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806000991, 15, 150, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 1, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 2, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 3, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 4, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 5, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 6, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 7, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 8, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 9, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 10, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 11, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 12, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 13, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 14, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 15, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 16, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 17, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214000992, 18, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 1, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 2, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 3, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 4, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 5, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 6, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 7, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 8, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 9, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 10, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 11, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 12, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 13, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 14, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000993, 15, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201000994, 1, 1, 91, 3, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201000994, 2, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201000994, 3, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201000994, 4, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201000994, 5, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 1, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 2, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 3, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 4, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 5, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 6, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 7, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 8, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 9, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 10, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 11, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518000995, 12, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 1, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 2, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 3, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 4, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 5, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 6, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 7, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 8, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 9, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 10, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 11, 191, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503000996, 12, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 1, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 2, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 3, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 4, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 5, 69, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 6, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 7, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 8, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 9, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 10, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921000997, 11, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 1, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 2, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 3, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 4, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 5, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 6, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 7, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 8, 36, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 9, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 10, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 11, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 12, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 13, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 14, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 15, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522000998, 16, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 1, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 2, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 3, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 4, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 5, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 6, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 7, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 8, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 9, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 10, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 11, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 12, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 13, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 14, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618000999, 15, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 1, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 2, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 3, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 4, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 5, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 6, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 7, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 8, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 9, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 10, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929001000, 11, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 1, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 2, 80, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 3, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 4, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 5, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 6, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 7, 114, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 8, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 9, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131001001, 10, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 1, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 2, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 3, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 4, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 5, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 6, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 7, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608001002, 8, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 1, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 2, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 3, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 4, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 5, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 6, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 7, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 8, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 9, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 10, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 11, 27, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 12, 62, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 13, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 14, 45, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212001003, 15, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 1, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 2, 134, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 3, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 4, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 5, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717001004, 6, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 1, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 2, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 3, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 4, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 5, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 6, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 7, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 8, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 9, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 10, 188, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108001005, 11, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 1, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 2, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 3, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 4, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 5, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 6, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 7, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 8, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 9, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 10, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 11, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331001006, 12, 4, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 1, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 2, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 3, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 4, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 5, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 6, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 7, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 8, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 9, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 10, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 11, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 12, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 13, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 14, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 15, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218001007, 16, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324001008, 1, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324001008, 2, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324001008, 3, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324001008, 4, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324001008, 5, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418001009, 1, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418001009, 2, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418001009, 3, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418001009, 4, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418001009, 5, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 1, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 2, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 3, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 4, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 5, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 6, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 7, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 8, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 9, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 10, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 11, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 12, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 13, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 14, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001010, 15, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 1, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 4, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 5, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 6, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 7, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 8, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 9, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 10, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 11, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 12, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 13, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 14, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 15, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115000271, 16, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 1, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 2, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 3, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 4, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 5, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 6, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 7, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 8, 125, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 9, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 10, 123, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 11, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930000272, 12, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015000273, 1, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015000273, 2, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015000273, 3, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015000273, 4, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015000273, 5, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924000274, 1, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924000274, 2, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924000274, 3, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 1, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 2, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 3, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 4, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 5, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411000275, 6, 6, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623000276, 1, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623000276, 2, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623000276, 3, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623000276, 4, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 1, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 2, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 3, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 5, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 6, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725000277, 7, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 1, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 2, 103, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 3, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 4, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 5, 4, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 6, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 7, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 8, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 9, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 10, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 11, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 12, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 13, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604000278, 14, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304000279, 1, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304000279, 2, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225000280, 1, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225000280, 2, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 1, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 2, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 3, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 4, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 5, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 6, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 7, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 8, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 9, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 10, 74, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 11, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 12, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000281, 13, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 1, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 2, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 3, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 4, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 5, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 6, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 7, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 8, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 9, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 10, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 11, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 12, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 13, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 14, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626000282, 15, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517000283, 1, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517000283, 2, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 1, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 2, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 3, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 4, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 5, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 6, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 7, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 8, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 9, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 10, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 11, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 12, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 13, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 14, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530000284, 15, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 1, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 2, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 3, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 4, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 5, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 6, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 7, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 8, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 9, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012000285, 10, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 1, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 2, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 3, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 4, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 5, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 6, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017000286, 7, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 1, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 2, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 3, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 4, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 5, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 6, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 7, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209000287, 8, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 1, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 2, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 3, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 4, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 5, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 6, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 7, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 8, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 9, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 10, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025000288, 11, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 1, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 2, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 3, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 4, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 5, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 6, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 7, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 8, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 9, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 10, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129000289, 11, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012000290, 1, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012000290, 2, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012000290, 3, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012000290, 4, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012000290, 5, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 1, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 2, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 3, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 4, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 5, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 6, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 7, 145, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223000291, 8, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612000292, 1, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612000292, 2, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612000292, 3, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612000292, 4, 188, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 1, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 2, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 3, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 4, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 5, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 6, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 7, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 8, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 9, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 10, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 11, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 12, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725000293, 13, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712000294, 1, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712000294, 2, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712000294, 3, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712000294, 4, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712000294, 5, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 1, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 2, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 3, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 4, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 5, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130000295, 6, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 1, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 2, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 3, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 4, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 5, 122, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 6, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 7, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 8, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 9, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 10, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202000296, 11, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127000297, 1, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127000297, 2, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127000297, 3, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127000297, 4, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 1, 25, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 2, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 3, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 4, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 5, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 6, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 7, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 8, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 9, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 10, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 11, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 12, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 13, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 14, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 15, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 16, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012000298, 17, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 1, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 2, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 3, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 4, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 5, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 6, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 6, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 7, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 8, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 9, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 10, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 11, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 12, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080728000632, 13, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 1, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 2, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 3, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 4, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 5, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 6, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 7, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 8, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 9, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 10, 192, 78, 18, 1404);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 11, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 12, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 13, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321000633, 14, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 1, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 2, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 3, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 4, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 5, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002000634, 6, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 1, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 2, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 3, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 4, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 5, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 6, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 7, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514000635, 8, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 1, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 2, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 3, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 4, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 5, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 6, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 7, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 8, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 9, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 10, 65, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 11, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513000636, 12, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 1, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 2, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 3, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 4, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 5, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 6, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 7, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 8, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 9, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 10, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 11, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 12, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 13, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 14, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 15, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 16, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 17, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128000637, 18, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 1, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 2, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 3, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 4, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 5, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 6, 44, 37, 8, 296);
commit;
prompt 7000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 7, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 8, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 9, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 10, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 11, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 12, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 13, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 14, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 15, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 16, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216000638, 17, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 1, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 2, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 3, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 4, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 5, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 6, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 7, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610000639, 8, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 1, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 2, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 3, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 4, 155, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 5, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 6, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 7, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 8, 135, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 9, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 10, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228000640, 11, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 1, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 2, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 3, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 4, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 5, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 6, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 7, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 8, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 9, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 10, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 11, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 12, 48, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 13, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103000641, 14, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 1, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 2, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 3, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 4, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 5, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 6, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 7, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 8, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 9, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 10, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 11, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 12, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 13, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 14, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 15, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 16, 167, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 17, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512000642, 18, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 1, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 2, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 3, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 4, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 5, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 6, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 7, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 8, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 9, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 10, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 11, 158, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 12, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 13, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 14, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 15, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 16, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902000643, 17, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 1, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 2, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 3, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 4, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 5, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 6, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 7, 109, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 8, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 9, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 10, 101, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 11, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 12, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 13, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 14, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 15, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 16, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005000644, 17, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 1, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 2, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 3, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 4, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 5, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 6, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 7, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 8, 30, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 9, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 10, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 11, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 12, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 13, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 14, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122000645, 15, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 1, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 2, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 3, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 4, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 5, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 6, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 7, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 8, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 9, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 10, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 11, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831000646, 12, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 1, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 2, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 3, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 4, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 5, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 6, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 7, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 8, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 9, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 10, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 11, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 12, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 13, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 14, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 15, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 16, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000647, 17, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 1, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 2, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 3, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 4, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 5, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 6, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 7, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 8, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 9, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720000648, 10, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 1, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 2, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 3, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 4, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 5, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 6, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 7, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 8, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 9, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 10, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 11, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208000649, 12, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809000650, 1, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809000650, 2, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809000650, 3, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809000650, 4, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106000890, 8, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 1, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 2, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 3, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 4, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 5, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 6, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 7, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 8, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 9, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 10, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513000891, 11, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 1, 62, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 2, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 3, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 4, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 5, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 6, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 7, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 8, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 9, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 10, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 11, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213000892, 12, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 1, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 2, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 3, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 4, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 5, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 6, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 7, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 8, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 9, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 10, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 11, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414000893, 12, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 1, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 2, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 3, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 4, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 5, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 6, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 7, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 8, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 9, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 10, 99, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 11, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 12, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 13, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 14, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 15, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 16, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630000894, 17, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 1, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 2, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 3, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 4, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 5, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 6, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 7, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126000895, 8, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409000896, 1, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409000896, 2, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409000896, 3, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409000896, 4, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912000897, 1, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912000897, 2, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912000897, 3, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912000897, 4, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 1, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 2, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 3, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 4, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 5, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 6, 120, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 7, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 8, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 9, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910000898, 10, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 1, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 2, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 3, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 4, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 5, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 6, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 7, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 8, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 9, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 10, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 11, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 12, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 13, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026000899, 14, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 1, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 2, 88, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 3, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 4, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 5, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 6, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 7, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 8, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320000900, 9, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 1, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 2, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 3, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 4, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 5, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 6, 59, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 7, 7, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 8, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 9, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 10, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102000901, 11, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416000902, 1, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416000902, 2, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416000902, 3, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000903, 1, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000903, 2, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112000903, 3, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 1, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 2, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 3, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 4, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 5, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 6, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213000904, 7, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 1, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 2, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 3, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 4, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 5, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 6, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 7, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 8, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 9, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 10, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 11, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 12, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 13, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 14, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 15, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 16, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 17, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 18, 143, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130000905, 19, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 1, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 2, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 3, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 4, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 5, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 6, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 7, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 8, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 9, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 10, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 11, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 12, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 13, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 14, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 15, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924000906, 16, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 1, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 2, 77, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 3, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 4, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 5, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 6, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825000907, 7, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 1, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 2, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 3, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 4, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 5, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 6, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 7, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 8, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127000908, 9, 78, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 1, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 2, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 3, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 4, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 5, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 6, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 7, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 8, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 9, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 10, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 11, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 12, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 13, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 14, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327000909, 15, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 1, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 2, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 3, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 4, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 5, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 6, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 7, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 8, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 9, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 10, 31, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 11, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916000910, 12, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 1, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 2, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 3, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 4, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 5, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 6, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 7, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 8, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 9, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 10, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 11, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 12, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 13, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 14, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521000911, 15, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 1, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 2, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 3, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 4, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 5, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 6, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220000912, 7, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 1, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 2, 155, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 3, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 4, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 5, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 6, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 7, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 8, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 9, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 10, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 11, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 12, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112000913, 13, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 7, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128000299, 8, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 1, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 2, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 3, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 4, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 5, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 6, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 7, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 8, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 9, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 10, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 11, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 12, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 13, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 14, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304000300, 15, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 1, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 2, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 3, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 4, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 5, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 6, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 7, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 8, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 9, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 10, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118000301, 11, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711000302, 1, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711000302, 2, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526000303, 1, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526000303, 2, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526000303, 3, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813000304, 1, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813000304, 2, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813000304, 3, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 1, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 2, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 3, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 4, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 5, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 6, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 7, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 8, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 9, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 10, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714000305, 11, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 1, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 2, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 3, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 4, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 5, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 6, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112000306, 7, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 1, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 2, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 3, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 4, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 5, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 6, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 7, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 8, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 9, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 10, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070910000307, 11, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 1, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 2, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 3, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 4, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 5, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 6, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 7, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 8, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 9, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 10, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 11, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 12, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 13, 159, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 14, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618000308, 15, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 1, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 2, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 3, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 4, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 5, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 6, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201000309, 7, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 1, 30, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 2, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 3, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 4, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 5, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223000310, 6, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 1, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 2, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 3, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 4, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 5, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102000311, 6, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 1, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 2, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 3, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 4, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 5, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 6, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 7, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 8, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803000312, 9, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 1, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 2, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 3, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 4, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 5, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 6, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 7, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 8, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 9, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 10, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 11, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 12, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 13, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 14, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 15, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 16, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000313, 17, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 1, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 2, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 3, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 4, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 5, 25, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 6, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 7, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 8, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 9, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 10, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 11, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 12, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 13, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 14, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720000314, 15, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 1, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 2, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 3, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 4, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 5, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 6, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 7, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 8, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 9, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 10, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 11, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100814000315, 12, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 1, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 2, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 3, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 4, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 5, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 6, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 7, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118000316, 8, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 1, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 2, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 3, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 4, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 5, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 6, 175, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 7, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 8, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 9, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 10, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 11, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 12, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 13, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 14, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 15, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 16, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528000317, 17, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 1, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 2, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 3, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 4, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 5, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 6, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 7, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130000318, 8, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 1, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 2, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 3, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 4, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 5, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 6, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 7, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 8, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 9, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 10, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 11, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 12, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 13, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010000319, 14, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 1, 107, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 2, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 3, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 4, 152, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 5, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 6, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 7, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 8, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 9, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 10, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320000320, 11, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 1, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 2, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 3, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 4, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 5, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 6, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 7, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 8, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 9, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 10, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 11, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 12, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 13, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201000321, 14, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 1, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 2, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 3, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 4, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 5, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 6, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 7, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 8, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721000322, 9, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 1, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 2, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 3, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 4, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 5, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 6, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 1, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 2, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 3, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 4, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 5, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 6, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 7, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 8, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 9, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 10, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 11, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813000651, 12, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000652, 1, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000652, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000652, 3, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000652, 4, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000410000652, 5, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 1, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 2, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 3, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 4, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 5, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 6, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 7, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 8, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 9, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225000653, 10, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 1, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 2, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 3, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 4, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 5, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 6, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 7, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 8, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 9, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 10, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601000654, 11, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 1, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 2, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 3, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 4, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 5, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 6, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 7, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 8, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 9, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 10, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 11, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 12, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 13, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 14, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304000655, 15, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 1, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 2, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 3, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 4, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 5, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 6, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 7, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 8, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 9, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 10, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 11, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 12, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 13, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 14, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 15, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406000656, 16, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 1, 109, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 2, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 3, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 4, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 5, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 6, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 7, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726000657, 8, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 1, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 2, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 3, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 4, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 5, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 6, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 7, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 8, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219000658, 9, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 1, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 2, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 3, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 4, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 5, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 6, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 7, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 8, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 9, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 10, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 11, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 12, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 13, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105000659, 14, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 1, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 2, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 3, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 4, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 5, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 6, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 7, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 8, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 9, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 10, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407000660, 11, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000661, 1, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000661, 2, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000661, 3, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617000661, 4, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422000662, 1, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422000662, 2, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422000662, 3, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422000662, 4, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422000662, 5, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 1, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 2, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 3, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 4, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 5, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 6, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 7, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 8, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 9, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 10, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 11, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 12, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 13, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 14, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 15, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 16, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312000663, 17, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422000664, 1, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422000664, 2, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422000664, 3, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422000664, 4, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422000664, 5, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721000665, 1, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721000665, 2, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721000665, 3, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 1, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 2, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 3, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 4, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 5, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 6, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109000666, 7, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 1, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 2, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 3, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 4, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 5, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 6, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 7, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 8, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 9, 176, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 10, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 11, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226000667, 12, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 1, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 2, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 3, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 4, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 5, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 6, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118000668, 7, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 1, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 2, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 3, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 4, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 5, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 6, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 7, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 8, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 9, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 10, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 11, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526000669, 12, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 1, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 2, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 3, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 4, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 5, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 6, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 7, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 8, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 9, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 10, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 11, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 12, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 13, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 14, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 15, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000670, 16, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 1, 92, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 2, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 3, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 4, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 5, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 6, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 7, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 8, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 9, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000671, 10, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 1, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 2, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 3, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 4, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 5, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 6, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 7, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 8, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 9, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031000672, 10, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 1, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 2, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 3, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 4, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 5, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 6, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 7, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 8, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 9, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 10, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 11, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106000673, 12, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 1, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 2, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 3, 126, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 4, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 5, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 6, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 7, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 8, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 2, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 3, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 4, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 5, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 6, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 7, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 8, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 9, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 10, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 11, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001011, 12, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 1, 3, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 2, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 3, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 4, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 5, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 6, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 7, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 8, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 9, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 10, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 11, 103, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 12, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 13, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208001012, 14, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 1, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 2, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 3, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 4, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 5, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 6, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 7, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001013, 8, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 1, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 2, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 3, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 4, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 5, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 6, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 7, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 8, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 9, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 10, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 11, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418001014, 12, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 1, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 2, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 3, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 4, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 5, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 6, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 7, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 8, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001015, 9, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 1, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 2, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 3, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 4, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 5, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 6, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 8, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 9, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 10, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 11, 166, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 12, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 13, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 14, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 15, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 16, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408001016, 17, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206001017, 1, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206001017, 2, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206001017, 3, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206001017, 4, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131001018, 1, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131001018, 2, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131001018, 3, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 1, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 2, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 3, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 4, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 5, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 6, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020709001019, 7, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 1, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 2, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 3, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 4, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 5, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 6, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 7, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 8, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 9, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 10, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 11, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 12, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 13, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 14, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 15, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222001020, 16, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 1, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 2, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 3, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 4, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 5, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 6, 1, 75, 3, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 7, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216001021, 8, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 1, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 2, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 3, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 4, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 5, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 6, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 7, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 8, 29, 74, 10, 740);
commit;
prompt 8000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 9, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 10, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 11, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 12, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 13, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 14, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 15, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101001022, 16, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 1, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 2, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 3, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 4, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 5, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 6, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 7, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 8, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 9, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 10, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 11, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001023, 12, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 1, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 2, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 3, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 4, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 5, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 6, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 7, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 8, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 9, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 10, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031001024, 11, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 1, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 2, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 3, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 4, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 5, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 6, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 7, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 8, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 9, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 10, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 11, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 12, 103, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 13, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412001025, 14, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 1, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 2, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 3, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 4, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 5, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 6, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 7, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122001026, 8, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 1, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 2, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 3, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 4, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 5, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 6, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 7, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 8, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 9, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 10, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 11, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 12, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401001027, 13, 109, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 1, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 2, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 3, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 4, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 5, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 6, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 7, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 8, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 9, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 10, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 11, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 12, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 13, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420001028, 14, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203001029, 1, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203001029, 2, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203001029, 3, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 1, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 2, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 3, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 4, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 5, 154, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 6, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 7, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 8, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 9, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207001030, 10, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 1, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 2, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 3, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 4, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 5, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 6, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 7, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 8, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 9, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 10, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 11, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225001031, 12, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 1, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 2, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 3, 14, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 4, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 5, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 6, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 7, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 8, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060716001032, 9, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001001033, 1, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001001033, 2, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001001033, 3, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 1, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 2, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 3, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 4, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 5, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 7, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 8, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 9, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 10, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 11, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 12, 119, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 13, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 14, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 15, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000323, 16, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116000324, 1, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116000324, 2, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116000324, 3, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116000324, 4, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 1, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 2, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 3, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 4, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 5, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316000325, 6, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908000326, 1, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908000326, 2, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908000326, 3, 174, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908000326, 4, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908000326, 5, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 1, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 2, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 3, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 4, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 5, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 6, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 7, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 8, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 9, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 10, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 11, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 12, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 13, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 14, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 15, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 16, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321000327, 17, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922000328, 1, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922000328, 2, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922000328, 3, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922000328, 4, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922000328, 5, 66, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 1, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 2, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 3, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 4, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 5, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 6, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 7, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 8, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 9, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 10, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823000329, 11, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 1, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 2, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 3, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 4, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 5, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 6, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020912000330, 7, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 1, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 2, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 3, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 4, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 5, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 6, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 7, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 8, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 9, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 10, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 11, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 12, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 13, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923000331, 14, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428000332, 1, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428000332, 2, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428000332, 3, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428000332, 4, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 1, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 2, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 3, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 4, 44, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 5, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 6, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 7, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 8, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 9, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 10, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 11, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 12, 37, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 13, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006000333, 14, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 1, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 2, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 3, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 4, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 5, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 6, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 7, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 8, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103000334, 9, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 1, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 2, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 3, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 4, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 5, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 6, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 7, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 8, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 9, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 10, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 11, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 12, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 13, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209000335, 14, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230000336, 1, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230000336, 2, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230000336, 3, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230000336, 4, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123000337, 1, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123000337, 2, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123000337, 3, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123000337, 4, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123000337, 5, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 1, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 2, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 3, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 4, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 5, 156, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 6, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 7, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806000338, 8, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 1, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 2, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 3, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 4, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 5, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 6, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 7, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 8, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 9, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 10, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 11, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 12, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 13, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 14, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 15, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 16, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 17, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930000339, 18, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 1, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 2, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 3, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 4, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 5, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 6, 192, 80, 18, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 7, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 8, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 9, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 10, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226000340, 11, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 1, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 2, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 3, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 4, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 5, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 6, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 7, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 8, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 9, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 10, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902000341, 11, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 1, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 2, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 3, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 4, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 5, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 6, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 7, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 8, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905000342, 9, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 1, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 2, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 3, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 4, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 5, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 6, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 7, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 8, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 9, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 10, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 11, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 12, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 13, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 14, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507000343, 15, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 1, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 2, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 3, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 4, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 5, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 6, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 7, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 8, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 9, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 10, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 11, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303000344, 12, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 1, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 2, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 3, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 4, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 5, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 6, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 7, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 8, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 9, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802000345, 10, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 1, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 2, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 3, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 4, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 5, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 6, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 7, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 8, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523000346, 9, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 1, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 2, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 3, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 4, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 5, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 6, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051105000347, 7, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 9, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 10, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 11, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 12, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 13, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 14, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 15, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 16, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 17, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314000674, 18, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 1, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 2, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 3, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 4, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 5, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107000675, 6, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 1, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 2, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 3, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 4, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 5, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 6, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 7, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 8, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108000676, 9, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 1, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 2, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 3, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 4, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 5, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 6, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 7, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 8, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 9, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 10, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 11, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 12, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 13, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628000677, 14, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 1, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 2, 34, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 3, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 4, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 5, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102000678, 6, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 1, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 2, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 3, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 4, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 5, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 6, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 7, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 8, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 9, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 10, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 11, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 12, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 13, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 14, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828000679, 15, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 1, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 2, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 3, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 4, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 5, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 6, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 7, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215000680, 8, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 1, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 2, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 3, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 4, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 5, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 6, 119, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 7, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 8, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 9, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 10, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 11, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 12, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 13, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 14, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202000681, 15, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 1, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 2, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 3, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 4, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 5, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 6, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 7, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 8, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 9, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 10, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809000682, 11, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 1, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 2, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 3, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 4, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 5, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 6, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 7, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 8, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 9, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 10, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 11, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 12, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725000683, 13, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 1, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 2, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 3, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 4, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 5, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 6, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 7, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 8, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050811000684, 9, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 1, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 2, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 3, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 4, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 5, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 6, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 7, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 8, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 9, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 10, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 11, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 12, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 13, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 14, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 15, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 16, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120000685, 17, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 1, 141, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 2, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 3, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 4, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 5, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 6, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 7, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 8, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 9, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 10, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 11, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 12, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 13, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 14, 192, 47, 18, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822000686, 15, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 1, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 2, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 3, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 4, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 5, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 6, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 7, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 8, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 9, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 10, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326000687, 11, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 1, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 2, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 3, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 4, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 5, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 6, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 7, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 8, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301000688, 9, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 1, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 2, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 3, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 4, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 5, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 6, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911000689, 7, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814000690, 1, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814000690, 2, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814000690, 3, 33, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814000690, 4, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 1, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 2, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 3, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 4, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 5, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 6, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 7, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 8, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 9, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 10, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 11, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 12, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 13, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 14, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223000691, 15, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 1, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 2, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 3, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 4, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 5, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 6, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215000692, 7, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 1, 88, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 2, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 3, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 4, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 5, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 6, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 7, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 8, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 9, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 10, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 11, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 12, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 13, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 14, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 15, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222000693, 16, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 1, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 2, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 3, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 4, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 5, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 6, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 7, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524000694, 8, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 1, 104, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 2, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 3, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 4, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 5, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 6, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 7, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 8, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 9, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 10, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 11, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 12, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 13, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 14, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 1, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 2, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 3, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 4, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 5, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 6, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 7, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 8, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 9, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 10, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000914, 11, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 1, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 2, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 3, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 4, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 5, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 6, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 7, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 8, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129000915, 9, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 1, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 2, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 3, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 4, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 5, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 6, 59, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 7, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 8, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 9, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 10, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 11, 17, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 12, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000916, 13, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 1, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 2, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 3, 134, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 4, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 5, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 6, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 7, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 8, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000917, 9, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 1, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 2, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 3, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 4, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 5, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729000918, 6, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 1, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 2, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 3, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 4, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 5, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 6, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306000919, 7, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 1, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 2, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 3, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 4, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 5, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 6, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 7, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000920, 8, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516000921, 1, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516000921, 2, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516000921, 3, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516000921, 4, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 1, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 2, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 3, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 4, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 5, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 6, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 7, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 8, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 9, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 10, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 11, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707000922, 12, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 1, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 2, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 3, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 4, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 5, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 6, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 7, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 8, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903000923, 9, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 1, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 2, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 3, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 4, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 5, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 6, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702000924, 7, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 1, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 2, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 3, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 4, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 5, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 6, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 7, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527000925, 8, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219000926, 1, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219000926, 2, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523000927, 1, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523000927, 2, 101, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523000927, 3, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 1, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 2, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 3, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 4, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 5, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 6, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 7, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 8, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 9, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 10, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 11, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622000928, 12, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111000929, 1, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111000929, 2, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111000929, 3, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111000929, 4, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111000929, 5, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 1, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 2, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 3, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 4, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 5, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 6, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129000930, 7, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 1, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 2, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 3, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 4, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 5, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827000931, 6, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 1, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 2, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 3, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 4, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 5, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 6, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 7, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730000932, 8, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 1, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 2, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 3, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 4, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 5, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 6, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 7, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 8, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 9, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 10, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 11, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 12, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 13, 135, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 14, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 15, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 16, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818000933, 17, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 1, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 2, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 3, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 4, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 5, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 6, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 7, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 8, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 9, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 10, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 11, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 12, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 13, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119000934, 14, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628000935, 1, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628000935, 2, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628000935, 3, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628000935, 4, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628000935, 5, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 1, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 2, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 3, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 4, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 5, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 6, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 7, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 8, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 9, 48, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 10, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 11, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222000936, 12, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 1, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 2, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 3, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 4, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 5, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 6, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 7, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 8, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 9, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 10, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 11, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 12, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 13, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825000937, 14, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 1, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 2, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 3, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 4, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 5, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004000938, 6, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 1, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 2, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 3, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 4, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 5, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 6, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 7, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 8, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 9, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 10, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 11, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 12, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 13, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 14, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 15, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 16, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131000939, 17, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 1, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 2, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 3, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 4, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 5, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 6, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 7, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061216000940, 8, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 1, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 2, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 3, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 4, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 5, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 6, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 7, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 8, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620000348, 9, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 1, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 2, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 3, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 4, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 5, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 6, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204000349, 7, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 1, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 2, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 3, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 4, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 5, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 6, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 7, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 8, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 9, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 10, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 11, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 12, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 13, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 14, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 15, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 16, 131, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006000350, 17, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 1, 35, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 2, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 3, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 4, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 5, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 6, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 7, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 8, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 9, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 10, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 11, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 12, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 13, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 14, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 15, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720000351, 16, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 1, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 2, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 3, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 4, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 5, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 6, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 7, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 8, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 9, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 10, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 11, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 12, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 13, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 14, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 15, 124, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928000352, 16, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 1, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 2, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 4, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 5, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 6, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 7, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 8, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 9, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 10, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 11, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 12, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 13, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 14, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 15, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 16, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 17, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108000353, 18, 93, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206000354, 1, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206000354, 2, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206000354, 3, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206000354, 4, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 1, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 2, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 3, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 4, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 5, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 6, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 7, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 8, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 9, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 10, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 11, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018000355, 12, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 1, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 2, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 3, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 4, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 5, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 6, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 7, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 8, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 9, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 10, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 11, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 12, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 13, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 14, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 15, 149, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729000356, 16, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 1, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 2, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 3, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 4, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 5, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 6, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 7, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 8, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 9, 79, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 10, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027000357, 11, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 1, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 2, 24, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 3, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 4, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 5, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 6, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 7, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 8, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 9, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 10, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 11, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 12, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 13, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 14, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100123000358, 15, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 1, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 2, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 3, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 4, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 5, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 6, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 7, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 8, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 9, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 10, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 11, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 12, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 13, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906000359, 14, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 1, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 2, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 3, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 4, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 5, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 6, 117, 24, 12, 288);
commit;
prompt 9000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 7, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 8, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203000360, 9, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 1, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 2, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 3, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 4, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 5, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 6, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 7, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618000361, 8, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 1, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 2, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 3, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 4, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 5, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 6, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 7, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 8, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 9, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722000362, 10, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 1, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 2, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 3, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 4, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 5, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 6, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 7, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 8, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 9, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 10, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216000363, 11, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 1, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 2, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 3, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 4, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 5, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 6, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 7, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 8, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 9, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717000364, 10, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 1, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 2, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 3, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 4, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 5, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 6, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 7, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 8, 13, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221000365, 9, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 1, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 2, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 3, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 4, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 5, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 6, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912000366, 7, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121000367, 1, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121000367, 2, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121000367, 3, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 1, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 2, 108, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 3, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 4, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 5, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 6, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 7, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 8, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 9, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 10, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303000368, 11, 54, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018000369, 1, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018000369, 2, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018000369, 3, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018000369, 4, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018000369, 5, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 1, 69, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 15, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 16, 1, 95, 3, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014000695, 17, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 1, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 2, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 3, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 4, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 5, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716000696, 6, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 1, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 2, 134, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 3, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 4, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 5, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 6, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 7, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 8, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915000697, 9, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 1, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 2, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 3, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 4, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 5, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 6, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 7, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 8, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 9, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 10, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 11, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 12, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 13, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 14, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 15, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226000698, 16, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 1, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 2, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 3, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 4, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 5, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 6, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 7, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 8, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 9, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 10, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 11, 136, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122000699, 12, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 1, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 2, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 3, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 4, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 5, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621000700, 6, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202000701, 1, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202000701, 2, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202000701, 3, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202000701, 4, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212000702, 1, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212000702, 2, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212000702, 3, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212000702, 4, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212000702, 5, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 1, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 2, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 3, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 4, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 5, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 6, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008000703, 7, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000704, 1, 121, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000704, 2, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000704, 3, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000704, 4, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000704, 5, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216000705, 1, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216000705, 2, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216000705, 3, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216000705, 4, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216000705, 5, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 1, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 2, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 3, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 4, 80, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 5, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 6, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 7, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 8, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 9, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220000706, 10, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 1, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 2, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 3, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 4, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 5, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 6, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 7, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 8, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 9, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 10, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 11, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 12, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 13, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331000707, 14, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 1, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 2, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 3, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 4, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 5, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 6, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 7, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 8, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 9, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 10, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 11, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 12, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 13, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 14, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 15, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 16, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102000708, 17, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 1, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 2, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 3, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 4, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 5, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 6, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 7, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 8, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 9, 76, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 10, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 11, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 12, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 13, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 14, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 15, 101, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123000709, 16, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 1, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 2, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 3, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 4, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 5, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 6, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 7, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 8, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 9, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 10, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 11, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 12, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 13, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116000710, 14, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 1, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 2, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 3, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 4, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 5, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 6, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 7, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 8, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 9, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707000711, 10, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 1, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 2, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 3, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 4, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 5, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 6, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 7, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 8, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 9, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 10, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 11, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 12, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 13, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 14, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517000712, 15, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 1, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 2, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 3, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 4, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 5, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 6, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 7, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 8, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 9, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 10, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701000713, 11, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 1, 26, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 2, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 3, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 4, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 5, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 6, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 7, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 8, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224000714, 9, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 1, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 2, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 3, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 4, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 5, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 6, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 7, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 8, 71, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 9, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 10, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 11, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 12, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 13, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000715, 14, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 1, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 2, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 3, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 4, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 5, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 6, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614000716, 7, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 1, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 2, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 3, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 4, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 5, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 6, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 7, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 8, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 9, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618000717, 10, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 1, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 2, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 3, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 4, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 5, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 6, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 7, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 8, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 9, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 10, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 11, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125000718, 12, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 1, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 2, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 6, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 7, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 8, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 9, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617001034, 10, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 1, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 2, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 3, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 4, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 5, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 6, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 7, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 8, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 9, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001035, 10, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 1, 103, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 2, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 3, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 4, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 5, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 6, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 7, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 8, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 9, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 10, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 11, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 12, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 13, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711001036, 14, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 1, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 2, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 3, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 4, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 5, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 6, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 7, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 8, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 9, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 10, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 11, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 12, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014001037, 13, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 1, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 2, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 3, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 4, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 5, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 6, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 7, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 8, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 9, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 10, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 11, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 12, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 13, 40, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628001038, 14, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001123001039, 1, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001123001039, 2, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001123001039, 3, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 1, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 2, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 3, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 4, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 5, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 6, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 7, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 8, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 9, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 10, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 11, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 12, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 13, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622001040, 14, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 1, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 2, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 3, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 4, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 5, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 6, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 7, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 8, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 9, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 10, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215001041, 11, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 1, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 2, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 3, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 4, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 5, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 6, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302001042, 7, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 1, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 2, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 3, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 4, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 5, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 6, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 7, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 8, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029001043, 9, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 1, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 2, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 3, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 4, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 5, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 6, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 7, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 8, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001044, 9, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 1, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 2, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 3, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 4, 123, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 5, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 6, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 7, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 8, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 9, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 10, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324001045, 11, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 1, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 2, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 3, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 4, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 5, 71, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 6, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 7, 95, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 8, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 9, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 10, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 11, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 12, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 13, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720001046, 14, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 1, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 2, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 3, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 4, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 5, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 6, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 7, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 8, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 9, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 10, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 11, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 12, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202001047, 13, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 1, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 2, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 3, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 4, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 5, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 6, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 7, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 8, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 9, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 10, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205001048, 11, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722001049, 1, 192, 1, 18, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722001049, 2, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722001049, 3, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722001049, 4, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722001049, 5, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 1, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 2, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 3, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 4, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 5, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130001050, 6, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 1, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 2, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 3, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 4, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 5, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 6, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 7, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 8, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 9, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 10, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 11, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 12, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 13, 162, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101231001051, 14, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 1, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 2, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 3, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 4, 75, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 5, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 6, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 7, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609001052, 8, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 1, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 2, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 3, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 4, 143, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 5, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 6, 32, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 7, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 8, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 9, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 10, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 11, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001053, 12, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119001054, 1, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119001054, 2, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119001054, 3, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417001055, 1, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417001055, 2, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417001055, 3, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 1, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 2, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 3, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 4, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 5, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 6, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 7, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 8, 25, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 9, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 10, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109001056, 11, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 1, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 2, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 3, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 4, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 5, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 6, 104, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 7, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 8, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 9, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 10, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 11, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 12, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 13, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409001057, 14, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 1, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 2, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 3, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 4, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090219001058, 5, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 2, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 3, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 4, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 5, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 6, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 7, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040322000370, 8, 180, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 1, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 2, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 3, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 4, 100, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 5, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 6, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 7, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 8, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 9, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 10, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 11, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827000371, 12, 29, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 1, 85, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 2, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 3, 27, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 4, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 5, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 6, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 7, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 8, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617000372, 9, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319000373, 1, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319000373, 2, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319000373, 3, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319000373, 4, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319000373, 5, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522000374, 1, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522000374, 2, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522000374, 3, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522000374, 4, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522000374, 5, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 1, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 2, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 3, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 4, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 5, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821000375, 6, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 1, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 2, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 3, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 4, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 5, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 6, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 7, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 8, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 9, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 10, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 11, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911000376, 12, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 1, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 2, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 3, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 4, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 5, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 6, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 7, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 8, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410000377, 9, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 1, 18, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 2, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 3, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 4, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 5, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 6, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 7, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723000378, 8, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 1, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 2, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 3, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 4, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 5, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 6, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 7, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 8, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 9, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421000379, 10, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 1, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 2, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 3, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 4, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 5, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 6, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 7, 135, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 8, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 9, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 10, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129000380, 11, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 1, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 2, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 3, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 4, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 5, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 6, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 7, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 8, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112000381, 9, 61, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 1, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 2, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 3, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 4, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 5, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 6, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 7, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 8, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216000382, 9, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 1, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 2, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 3, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 4, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 5, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221000383, 6, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 1, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 2, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 3, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 4, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 5, 94, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 6, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 7, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 8, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 9, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 10, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 11, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 12, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 13, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 14, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817000384, 15, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 1, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 2, 66, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 3, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 4, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 5, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 6, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 7, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 8, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 9, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 10, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 11, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 12, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030000385, 13, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 1, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 2, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 3, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 4, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 5, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 6, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 7, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 8, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 9, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 10, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 11, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 12, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 13, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 14, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 15, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307000386, 16, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 1, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 2, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 3, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 4, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 5, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 6, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 7, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 8, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 9, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 10, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 11, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 12, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 13, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 14, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 15, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214000387, 16, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 1, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 2, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 3, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 4, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 5, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 6, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 7, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 8, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 9, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 10, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802000388, 11, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 1, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 2, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 3, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 4, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 5, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 6, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 7, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 8, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 9, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 10, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 11, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 12, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 13, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913000389, 14, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 1, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 2, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 3, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 4, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 5, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 6, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 7, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 8, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 9, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 10, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 11, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 12, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 13, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 14, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827000390, 15, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 1, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 2, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 3, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 4, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 5, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 6, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 7, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 8, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 9, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 10, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 11, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 12, 57, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 13, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 14, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 15, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430000391, 16, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 1, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 2, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 3, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 4, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 5, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 3, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 4, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 5, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 6, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 7, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 8, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 9, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 10, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 11, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 12, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 13, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 14, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831000719, 15, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 1, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 2, 25, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 3, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 4, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 5, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 6, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724000720, 7, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324000721, 1, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324000721, 2, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324000721, 3, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324000721, 4, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324000721, 5, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 1, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 2, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 3, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 4, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 5, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 6, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 7, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 8, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 9, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 10, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 11, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513000722, 12, 56, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 1, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 2, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 3, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 4, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 5, 113, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 6, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 7, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 8, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 9, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 10, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 11, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106000723, 12, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013000724, 1, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013000724, 2, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013000724, 3, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000725, 1, 129, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000725, 2, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000725, 3, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225000725, 4, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 1, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 3, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 4, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 5, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105000726, 6, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 1, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 2, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 3, 20, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 4, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 5, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 6, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 7, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806000727, 8, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 1, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 2, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 3, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 4, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 5, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 6, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 7, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 8, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 9, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 10, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 11, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523000728, 12, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 1, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 2, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 3, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 4, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 5, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 6, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 7, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 8, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 9, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 10, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 11, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 12, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 13, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 14, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 15, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605000729, 16, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 1, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 2, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 3, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 4, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 5, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 6, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 7, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 8, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 9, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 10, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 11, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 12, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407000730, 13, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 1, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 2, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 3, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 4, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 5, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 6, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 7, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 8, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 9, 19, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 10, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508000731, 11, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 1, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 2, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 3, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 4, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 5, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 6, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 7, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 8, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 9, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 10, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 11, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 12, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 13, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 14, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 15, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 16, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405000732, 17, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 1, 78, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 2, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 3, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 4, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 5, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 6, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 7, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405000733, 8, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 1, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 2, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 3, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 4, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 5, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 6, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 7, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 8, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 9, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 10, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 11, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 12, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 13, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718000734, 14, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 1, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 2, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 3, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 4, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 5, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 6, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 7, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 8, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 9, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 10, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 11, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828000735, 12, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 1, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 2, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 3, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 4, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 5, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 6, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 7, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 8, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005000736, 9, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 1, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 2, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 3, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 4, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 5, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 6, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 7, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 8, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 9, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 10, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130000737, 11, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 1, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 2, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 3, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 4, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 5, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 6, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 7, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 8, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328000738, 9, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 1, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 2, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 3, 165, 66, 12, 792);
commit;
prompt 10000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 4, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 5, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 6, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 7, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 8, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 9, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 10, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426000739, 11, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 1, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 2, 8, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 3, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 4, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 5, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 6, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 7, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 8, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 9, 160, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 10, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 11, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 12, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908000740, 13, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 1, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 2, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 3, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 4, 57, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 5, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 6, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 7, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 8, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 9, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 10, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 11, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 12, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 13, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117000001, 1, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117000001, 2, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117000001, 3, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117000001, 4, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117000001, 5, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014000002, 1, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014000002, 2, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014000002, 3, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014000002, 4, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014000002, 5, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 1, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 2, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 3, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 4, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 5, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 6, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 7, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 8, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 9, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 10, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 11, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 12, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 13, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 14, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 15, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 16, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530000003, 17, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 1, 21, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 2, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 3, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 4, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 5, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 6, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 7, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 8, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061027000004, 9, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 1, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 2, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 3, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 4, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 5, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 6, 130, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 7, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 8, 115, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 9, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 10, 14, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 11, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 12, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 13, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204000005, 14, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 1, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 2, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 3, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 4, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 5, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 6, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 7, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 8, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 9, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 10, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 11, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 12, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 13, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103000006, 14, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 1, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 2, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 3, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 4, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 5, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 6, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 7, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 8, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 9, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 10, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725000007, 11, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 1, 60, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 2, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 3, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 4, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 5, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 6, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 7, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 8, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 9, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 10, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 11, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622000008, 12, 129, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 1, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 2, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 3, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 4, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 5, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 6, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 7, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 8, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060522000009, 9, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 1, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 2, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 3, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 4, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 5, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 6, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113000010, 7, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 1, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 2, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 3, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 4, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 5, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606000011, 6, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208000012, 1, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208000012, 2, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208000012, 3, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208000012, 4, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208000012, 5, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 1, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 2, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 3, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 4, 62, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 5, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 6, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 7, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912000013, 8, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 1, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 2, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 3, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 4, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 5, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 6, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 7, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 8, 1, 75, 3, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 9, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731000014, 10, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828000015, 1, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828000015, 2, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828000015, 3, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828000015, 4, 4, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 1, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 2, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 3, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 4, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 5, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 6, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 7, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 8, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000016, 9, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 1, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 2, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 3, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 4, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 5, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 6, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 7, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 8, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 9, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 10, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 11, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 12, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 13, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 14, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025000017, 15, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 1, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 2, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 3, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 4, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 5, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 6, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 7, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 8, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802000018, 9, 9, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 1, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 2, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 3, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 4, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 5, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 6, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 7, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 8, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 9, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022000019, 10, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 1, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 2, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 3, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 4, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 5, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 6, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 7, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 8, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 9, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 10, 192, 16, 18, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 11, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 12, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 13, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416000020, 14, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 1, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 2, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 3, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 4, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 5, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 6, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 7, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114000021, 8, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901000022, 1, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901000022, 2, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901000022, 3, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901000022, 4, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806000023, 1, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806000023, 2, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806000023, 3, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806000023, 4, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806000023, 5, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820000024, 1, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820000024, 2, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820000024, 3, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014000025, 1, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014000025, 2, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014000025, 3, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 1, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 2, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 3, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 4, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 5, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 6, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 7, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 8, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 9, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 10, 182, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 11, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 12, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 13, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 14, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 15, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 16, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 17, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107000026, 18, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 1, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 2, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 3, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 4, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 5, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 6, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 7, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 8, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 9, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 10, 89, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 11, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 12, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 13, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 14, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317000392, 15, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 1, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 2, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 3, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 4, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 5, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 6, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 7, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 8, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 9, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 10, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 11, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 12, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 13, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 14, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 15, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 16, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220000393, 17, 54, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 1, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 2, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 3, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 4, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 5, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 6, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213000394, 7, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 1, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 2, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 3, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 4, 1, 92, 3, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 5, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 6, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 7, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 8, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812000395, 9, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 1, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 2, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 3, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 4, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 5, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 6, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 7, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 8, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 9, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205000396, 10, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000397, 1, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000397, 2, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415000397, 3, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 1, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 2, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 3, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 5, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 6, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 7, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 8, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 9, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 10, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 11, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000398, 12, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 1, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 2, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 3, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 4, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 5, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 6, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 7, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 8, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 9, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 10, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001000399, 11, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 1, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 2, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 3, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 4, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 5, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 6, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 7, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 8, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 9, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 10, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 11, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 12, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 13, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 14, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121027000400, 15, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 1, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 2, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 3, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 4, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 5, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 6, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 7, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 8, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 9, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 10, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 11, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 12, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 13, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 14, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812000401, 15, 57, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000402, 1, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000402, 2, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000402, 3, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 1, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 2, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 3, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 4, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 5, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 6, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 7, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 8, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 9, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 10, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321000403, 11, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 1, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 2, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 3, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 4, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 5, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 6, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 7, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 8, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 9, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 10, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 11, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 12, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315000404, 13, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 1, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 2, 116, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 3, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 4, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 5, 88, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 6, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 7, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 8, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 9, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 10, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 11, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708000405, 12, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 1, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 2, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 3, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 4, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 5, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204000406, 6, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 1, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 2, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 3, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 4, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 5, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 6, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 7, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 8, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 9, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 10, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903000407, 11, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724000408, 1, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724000408, 2, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724000408, 3, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724000408, 4, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 1, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 2, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 3, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 4, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 5, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 6, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 7, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730000409, 8, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 1, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 2, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 3, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 4, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 5, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 6, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021109000410, 7, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 1, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 2, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 3, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 4, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 5, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 6, 85, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 7, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 8, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 9, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228000411, 10, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 1, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 2, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 3, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 4, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 5, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 6, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 7, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627000412, 8, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 1, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 2, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 3, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 4, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 5, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 6, 128, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 7, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 8, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 9, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 10, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 11, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505000413, 12, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 1, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 2, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 3, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 4, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 5, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 6, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 7, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 8, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 9, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307000414, 10, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 1, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 2, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 3, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 4, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 5, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717000415, 6, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 1, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 2, 69, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 3, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 4, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 5, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 6, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 7, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 8, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 9, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612000416, 10, 180, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228000741, 14, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507000742, 1, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507000742, 2, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507000742, 3, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507000742, 4, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507000742, 5, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309000743, 1, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309000743, 2, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309000743, 3, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309000743, 4, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 1, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 2, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 3, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 4, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 5, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 6, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 7, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 8, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 9, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 10, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 11, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 12, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714000744, 13, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 1, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 2, 182, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 3, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 4, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 5, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 6, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 7, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 8, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 9, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 10, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 11, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 12, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 13, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 14, 9, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 15, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 16, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 17, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303000745, 18, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 1, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 2, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 3, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 4, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 5, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 6, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018000746, 7, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 1, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 2, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 3, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 4, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 5, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 6, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 7, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 8, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303000747, 9, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107000748, 1, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107000748, 2, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107000748, 3, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107000748, 4, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107000748, 5, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 1, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 2, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 3, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 4, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 5, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 6, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 7, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 8, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 9, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 10, 17, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 11, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505000749, 12, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 1, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 2, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 3, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 4, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 5, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 6, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 7, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 8, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 9, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 10, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 11, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228000750, 12, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420000751, 1, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420000751, 2, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420000751, 3, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420000751, 4, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420000751, 5, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 1, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 2, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 3, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 4, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 5, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419000752, 6, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 1, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 2, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 3, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 4, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 5, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 6, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 7, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 8, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529000753, 9, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 1, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 2, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 3, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 4, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 5, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 6, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 7, 109, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 8, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 9, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 10, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 11, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 12, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504000754, 13, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 1, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 2, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 3, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 4, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 5, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 6, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 7, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 8, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 9, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 10, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 11, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 12, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 13, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 14, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 15, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715000755, 16, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702000756, 1, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702000756, 2, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702000756, 3, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702000756, 4, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702000756, 5, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702000757, 1, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702000757, 2, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702000757, 3, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702000757, 4, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702000757, 5, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 1, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 2, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 3, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 4, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 5, 132, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 6, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 7, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 8, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 9, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 10, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 11, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 12, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 13, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 14, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701000758, 15, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027000759, 1, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027000759, 2, 25, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027000759, 3, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027000759, 4, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027000759, 5, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 1, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 2, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 3, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 4, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 5, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 6, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020000760, 7, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 1, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 2, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 3, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 4, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 5, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 6, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 7, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 8, 69, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 9, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 10, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015000761, 11, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000762, 1, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000762, 2, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000762, 3, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000762, 4, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104000762, 5, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605000763, 1, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605000763, 2, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605000763, 3, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605000763, 4, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605000763, 5, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 1, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 2, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 3, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 4, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 5, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 6, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 7, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 8, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 9, 44, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 10, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 11, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 12, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 13, 12, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 14, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130000764, 15, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 1, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 2, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 3, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 4, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 5, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 6, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 7, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 8, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 9, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 10, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 11, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 12, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116000765, 13, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515000766, 1, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515000766, 2, 167, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515000766, 3, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515000766, 4, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 1, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 2, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 3, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 4, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 5, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101000767, 6, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 1, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 2, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 3, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 4, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 5, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 6, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 7, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020000768, 8, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 6, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 7, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 8, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 9, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 10, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 11, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 12, 91, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231000027, 13, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 1, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 2, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 3, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 4, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 5, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 6, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 7, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 8, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 9, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 10, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 11, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117000028, 12, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 1, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 2, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 3, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 4, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 5, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016000029, 6, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 1, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 2, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 3, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 4, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 5, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 6, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 7, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 8, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 9, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811000030, 10, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124000031, 1, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124000031, 2, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124000031, 3, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124000031, 4, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124000031, 5, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 1, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 2, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 3, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 4, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 5, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 6, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 7, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 8, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410000032, 9, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 1, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 2, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 3, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 4, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 5, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 6, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 7, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 8, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 9, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 10, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 11, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 12, 114, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 13, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 14, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010000033, 15, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718000034, 1, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718000034, 2, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718000034, 3, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718000034, 4, 16, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 1, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 2, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 3, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 4, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 5, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 6, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116000035, 7, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 1, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 2, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 3, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 4, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 5, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 6, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 7, 119, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 8, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 9, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 10, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 11, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 12, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 13, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611000036, 14, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 1, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 2, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 3, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 4, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 5, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 6, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 7, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 8, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 9, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 10, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 11, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929000037, 12, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 1, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 2, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 3, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 4, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 5, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 6, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825000038, 7, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 1, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 2, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 3, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 4, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 5, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 6, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 7, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 8, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 9, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 10, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 11, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 12, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 13, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908000039, 14, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 1, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 2, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 3, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 4, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 5, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 6, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 7, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428000040, 8, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 1, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 2, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 3, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 4, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 5, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630000041, 6, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727000042, 1, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727000042, 2, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727000042, 3, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727000042, 4, 154, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727000042, 5, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 1, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 2, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 3, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 4, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 5, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 6, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 7, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 8, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611000043, 9, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 1, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 2, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 3, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 4, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 5, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 6, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028000044, 7, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330000045, 1, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330000045, 2, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330000045, 3, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 1, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 2, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 3, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 4, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 5, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 6, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 7, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222000046, 8, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 1, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 2, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 3, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 4, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 5, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 6, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 7, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 8, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 9, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608000047, 10, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 1, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 2, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 3, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 4, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 5, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 6, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 7, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 8, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 9, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 10, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 11, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 12, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215000048, 13, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 1, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 2, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 3, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 4, 134, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 5, 162, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 6, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 7, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 8, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 9, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 10, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 11, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 12, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 13, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 14, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 15, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 16, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 17, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224000049, 18, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 1, 24, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 2, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 3, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 4, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 5, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 6, 29, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 7, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 8, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 9, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 10, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527000050, 11, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822000051, 1, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822000051, 2, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822000051, 3, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822000051, 4, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 1, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 2, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 3, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 4, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 5, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 6, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 7, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 8, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 9, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 10, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 11, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080324000052, 12, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527000053, 1, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527000053, 2, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 7, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 8, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 9, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 10, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 1, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 2, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 3, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 4, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 5, 24, 68, 12, 816);
commit;
prompt 11000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 6, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 7, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 8, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 9, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 10, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805001617, 11, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 1, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 2, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 3, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 4, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 5, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 6, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 7, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 8, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 9, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 10, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 11, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 12, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 13, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 14, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112001618, 15, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 1, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 2, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 3, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 4, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 5, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 6, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 7, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 8, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 9, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 10, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128001619, 11, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 1, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 2, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 3, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 4, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 5, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 6, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 7, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 8, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328001620, 9, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 1, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 2, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 3, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 4, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 5, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824001621, 6, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 1, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 2, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 3, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 4, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 5, 55, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 6, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 7, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 8, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 9, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 10, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 11, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 12, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 13, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029001622, 14, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 1, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 2, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 3, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 4, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 5, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 6, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 7, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 8, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 9, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 10, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 11, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 12, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 13, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304001623, 14, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 1, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 2, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 3, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 4, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 5, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 6, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 7, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209001624, 8, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 1, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 2, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 3, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 4, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 5, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 6, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 7, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 8, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 9, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 10, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 11, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 12, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 13, 4, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 14, 188, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526001625, 15, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 1, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 2, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 3, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 4, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 5, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 6, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 7, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 8, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 9, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 10, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 11, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107001626, 12, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 1, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 2, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 3, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 4, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 5, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 6, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 7, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 8, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 9, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 10, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 11, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430001627, 12, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 1, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 2, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 3, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 4, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 5, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 6, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 7, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 8, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 9, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 10, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 11, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 12, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 13, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 14, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 15, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426001628, 16, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 1, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 2, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 3, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 4, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 5, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 6, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 7, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 8, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 9, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 10, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 11, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 12, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 13, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 14, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408001629, 15, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001630, 1, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001630, 2, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001630, 3, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001630, 4, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001630, 5, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 1, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 2, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 3, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 4, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 5, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 6, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 7, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 8, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 9, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 10, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909001631, 11, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 1, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 2, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 3, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 4, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 5, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 6, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 7, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109001632, 8, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 1, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 2, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 3, 108, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 4, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 5, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 6, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 7, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 8, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 9, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 10, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403001633, 11, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 1, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 2, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 3, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 4, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 5, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 6, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 7, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 8, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 9, 86, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 10, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 11, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 12, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 13, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122001634, 14, 16, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 1, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 2, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 3, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 4, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 5, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 6, 171, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 7, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 8, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 9, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 10, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 11, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 12, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 13, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 14, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 15, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 16, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823001635, 17, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 1, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 2, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 3, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 4, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 5, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 6, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 7, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219001636, 8, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 1, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 2, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 5, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 6, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 1, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 2, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 3, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 4, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 5, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 6, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 7, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 8, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 9, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 10, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709001995, 11, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 1, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 2, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 3, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 4, 100, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 5, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126001996, 6, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 1, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 2, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 3, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 4, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 5, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 6, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806001997, 7, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 1, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 2, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 3, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 4, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 5, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 6, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 7, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 8, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 9, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 10, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218001998, 11, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 1, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 2, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 3, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 4, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 5, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 6, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827001999, 7, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 1, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 2, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 3, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 4, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 5, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 6, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 7, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 8, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 9, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 10, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 11, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 12, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 13, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 14, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621002000, 15, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 1, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 2, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 3, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 4, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 5, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 6, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 7, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 8, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 9, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 10, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 11, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 12, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 13, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 14, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 15, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 16, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 17, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002001, 18, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 1, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 2, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 3, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 4, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 5, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 6, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 7, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 8, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 9, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 10, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 11, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 12, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112002002, 13, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822002003, 1, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822002003, 2, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822002003, 3, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305002004, 1, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305002004, 2, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305002004, 3, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 1, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 2, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 3, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 4, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 5, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 6, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 7, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 8, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 9, 35, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 10, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 11, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 12, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909002005, 13, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 1, 30, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 2, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 3, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 4, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 5, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412002006, 6, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 1, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 2, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 3, 148, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 4, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 5, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 6, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 7, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 8, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 9, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 10, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 11, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 12, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 13, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002007, 14, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 1, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 2, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 3, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 4, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 5, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 6, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530002008, 7, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 1, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 2, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 3, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 4, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 5, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 6, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 7, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 8, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 9, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 10, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 11, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 12, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 13, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002009, 14, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 1, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 2, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 3, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 4, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 5, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 6, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 7, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 8, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 9, 186, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 10, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 11, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080712002010, 12, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 1, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 2, 70, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 3, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 4, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 5, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 6, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 7, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 8, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 9, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 10, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 11, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030002011, 12, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 1, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 2, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 3, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 4, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 5, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 6, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 7, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 8, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 9, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 10, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 11, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106002012, 12, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 1, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 2, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 3, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 4, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 5, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 6, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 7, 90, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 8, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 9, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 10, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022002013, 11, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 1, 17, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 2, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 3, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 4, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 5, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 6, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 7, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 8, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 9, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 10, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 11, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 12, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 13, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327002014, 14, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 1, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 2, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 3, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 4, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 5, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 6, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 7, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 8, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 9, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 10, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 11, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 12, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 13, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218002015, 14, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 1, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 2, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 3, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 4, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 5, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 6, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 7, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 8, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 9, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 10, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 11, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602002016, 12, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 1, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 2, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 3, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 6, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 7, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 8, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 9, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 10, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 1, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 2, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 3, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 4, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 5, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 6, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 7, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 8, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 9, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 10, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 11, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 12, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 13, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002377, 14, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 1, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 2, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 3, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 4, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 5, 179, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 6, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 7, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 8, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 9, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 10, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 11, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 12, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725002378, 13, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 1, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 2, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 3, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 4, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 5, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 6, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 7, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 8, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 9, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 10, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 11, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602002379, 12, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 1, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 2, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 3, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 4, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 5, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 6, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 7, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 8, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 9, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 10, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 11, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 12, 34, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 13, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 14, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 15, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 16, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604002380, 17, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 1, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 2, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 3, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 4, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 5, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 6, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 7, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 8, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 9, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 10, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 11, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 12, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827002381, 13, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 1, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 2, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 3, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 4, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 5, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 6, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 7, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 8, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 9, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 10, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 11, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080429002382, 12, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 1, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 2, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 3, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 4, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 5, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 6, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 7, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 8, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 9, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 10, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 11, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 12, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 13, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 14, 19, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002383, 15, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 1, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 2, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 3, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 4, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 5, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 6, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 7, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 8, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 9, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 10, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 11, 131, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 12, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 13, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 14, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 15, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 16, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 17, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523002384, 18, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 1, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 2, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 3, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 4, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 5, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 6, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 7, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 8, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 9, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823002385, 10, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 1, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 2, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 3, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 4, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 5, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 6, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 7, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 8, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008002386, 9, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 1, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 2, 58, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 3, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 4, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 5, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 6, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 7, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007002387, 8, 36, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 1, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 2, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 3, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 4, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 5, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 6, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 7, 112, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 8, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 9, 69, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 10, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228002388, 11, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 1, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 2, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 3, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 4, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 5, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 6, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 7, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 8, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 9, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 10, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 11, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 12, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 13, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 14, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306002389, 15, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 1, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 2, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 3, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 4, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 5, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 6, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 7, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 8, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 9, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 10, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 11, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 12, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 13, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 14, 176, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 15, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 16, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306002390, 17, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 1, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 2, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 3, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 4, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 5, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 6, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 7, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 8, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 9, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 10, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 11, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 12, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 13, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 14, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 15, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515002391, 16, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 1, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 2, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 3, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 4, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 5, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 6, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 7, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 8, 36, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 9, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 10, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 11, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 12, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 13, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 14, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 15, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 16, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608002392, 17, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002393, 1, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002393, 2, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002393, 3, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002393, 4, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 1, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 2, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 3, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 4, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 5, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325002394, 6, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828002395, 1, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828002395, 2, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828002395, 3, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828002395, 4, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828002395, 5, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 1, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 2, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 9, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 10, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 11, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 12, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 13, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 1, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 2, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 3, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 4, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 5, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 6, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 7, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 8, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 9, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 10, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318001240, 11, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 1, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 2, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 3, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 4, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 5, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 6, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 7, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 8, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 9, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001241, 10, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 1, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 2, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 3, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 4, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 5, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 6, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031001242, 7, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 1, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 2, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 3, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 4, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 5, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 6, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 7, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 8, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018001243, 9, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429001244, 1, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429001244, 2, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429001244, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429001244, 4, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429001244, 5, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412001245, 1, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412001245, 2, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412001245, 3, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 1, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 2, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 3, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 4, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 5, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 6, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 7, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 8, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 9, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001246, 10, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 1, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 2, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 3, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 4, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 5, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 6, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 7, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 8, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 9, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 10, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 11, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 12, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019001247, 13, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 1, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 2, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 3, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 4, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 5, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 6, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 7, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 8, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 9, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 10, 56, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 11, 92, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710001248, 12, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 1, 24, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 2, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 3, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 4, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 5, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 6, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 7, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 8, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071024001249, 9, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 1, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 2, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 3, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 4, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 5, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 6, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 7, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 8, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 9, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 10, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 11, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 12, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 13, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 14, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 15, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509001250, 16, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 1, 27, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 2, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 3, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 4, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 5, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 6, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 7, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 8, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222001251, 9, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 1, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 3, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 4, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 5, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 6, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 7, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219001252, 8, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 1, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 2, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 3, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 4, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 5, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 6, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 7, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 8, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 9, 135, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 10, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 11, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 12, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 13, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 14, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 15, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 16, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908001253, 17, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519001254, 1, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519001254, 2, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519001254, 3, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 1, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 2, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 3, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 4, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 5, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 6, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 7, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314001255, 8, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124001256, 1, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124001256, 2, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124001256, 3, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 1, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 2, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 3, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 4, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 5, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 6, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 7, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 8, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 9, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 10, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 11, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 12, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 13, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 14, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 15, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213001257, 16, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205001258, 1, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205001258, 2, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205001258, 3, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 1, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 2, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 3, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 4, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 5, 57, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 6, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 7, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 8, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 9, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 10, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 11, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016001259, 12, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 1, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 2, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 3, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 4, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 5, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 6, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 7, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 8, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 9, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 10, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 11, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 12, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 13, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 14, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 15, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001260, 16, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 1, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 2, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 3, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 4, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 5, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 6, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 7, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 8, 120, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 9, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720001261, 10, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 1, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 2, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 3, 33, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 4, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 5, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723001262, 6, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 1, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 2, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 3, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 4, 53, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 5, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 6, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 7, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 8, 171, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 9, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 10, 101, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016001263, 11, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 1, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 2, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 3, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 4, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 5, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 6, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 7, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 3, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 4, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 5, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 6, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 7, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 8, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 9, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211001637, 10, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 1, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 2, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 3, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 4, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 5, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 6, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 7, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 8, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 9, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 10, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 11, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 12, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 13, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 14, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610001638, 15, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 1, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 2, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 3, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 4, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 5, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 6, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014001639, 7, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 1, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 2, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 3, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 4, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 5, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 6, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 7, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 8, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 9, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 10, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028001640, 11, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 1, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 2, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 3, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 4, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 5, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 6, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 7, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127001641, 8, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 1, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 2, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 3, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 4, 127, 21, 15, 315);
commit;
prompt 12000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 5, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 6, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 7, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 8, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 9, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 10, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 11, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 12, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 13, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110114001642, 14, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 1, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 2, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 3, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 4, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 5, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 6, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 7, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 8, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 9, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 10, 98, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 11, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 12, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 13, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 14, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001643, 15, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 1, 143, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 2, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 3, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 4, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 5, 152, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 6, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 7, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 8, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 9, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 10, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 11, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 12, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 13, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 14, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422001644, 15, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930001645, 1, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930001645, 2, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930001645, 3, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930001645, 4, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930001645, 5, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 1, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 2, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 3, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 4, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 5, 192, 82, 18, 1476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 6, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 7, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926001646, 8, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 1, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 2, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 3, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 4, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 5, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 6, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 7, 130, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 8, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 9, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 10, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 11, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 12, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001647, 13, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 1, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 2, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 3, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 4, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 5, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 6, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 7, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 8, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 9, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 10, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 11, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 12, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 13, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 14, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 15, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 16, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 17, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001648, 18, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424001649, 1, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424001649, 2, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424001649, 3, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 1, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 2, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 3, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 4, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 5, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 6, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 7, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825001650, 8, 126, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 1, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 2, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 3, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 4, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 5, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 6, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 7, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 8, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 9, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101001651, 10, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 1, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 2, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 3, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 4, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 5, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 6, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 7, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003001652, 8, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 1, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 2, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 3, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 4, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 5, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 6, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 7, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 8, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 9, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 10, 158, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 11, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421001653, 12, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 1, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 2, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 3, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 4, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 5, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 6, 189, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 7, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001654, 8, 167, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 1, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 2, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 3, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 4, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 5, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 6, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 7, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 8, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 9, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 10, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109001655, 11, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 1, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 2, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 3, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 4, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 5, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 6, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 7, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 8, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050117001656, 9, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 1, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 2, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 3, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 4, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 5, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 6, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 7, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 8, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 9, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622001657, 10, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 1, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 2, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 3, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 4, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 5, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 6, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 7, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 8, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 9, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 10, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509001658, 11, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 1, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 2, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 3, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 4, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 5, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 6, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 7, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 8, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 9, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 10, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 11, 151, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 12, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 4, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 5, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 6, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 7, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 8, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 9, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 10, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 11, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 12, 192, 94, 18, 1692);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002017, 13, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 1, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 2, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 3, 150, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 4, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 5, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 6, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 7, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 8, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 9, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002018, 10, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 1, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 2, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 3, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 4, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 5, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 6, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 7, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 8, 100, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 9, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 10, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515002019, 11, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 1, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 2, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 3, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 4, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 5, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 6, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 7, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 8, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 9, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002020, 10, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413002021, 1, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413002021, 2, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413002021, 3, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 1, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 2, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 3, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 4, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 5, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 6, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 7, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 8, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 9, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 10, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 11, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208002022, 12, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 1, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 2, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 3, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 4, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 5, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 6, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 7, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 8, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 9, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 10, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 11, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 12, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 13, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 14, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728002023, 15, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 1, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 2, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 3, 137, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 4, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 5, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 6, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 7, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 8, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 9, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 10, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 11, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 12, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 13, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 14, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 15, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 16, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002024, 17, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 1, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 2, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 3, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 4, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 5, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 6, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 7, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 8, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 9, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 10, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 11, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502002025, 12, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 1, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 2, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 3, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 4, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 5, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 6, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 7, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 8, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 9, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 10, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 11, 49, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 12, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010002026, 13, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 1, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 2, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 3, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 4, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 5, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 6, 41, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 7, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 8, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 9, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 10, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 11, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329002027, 12, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 1, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 2, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 3, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 4, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 5, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 6, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 7, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 8, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 9, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 10, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 11, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 12, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 13, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 14, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 15, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 16, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 17, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514002028, 18, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 1, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 2, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 3, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 4, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 5, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 6, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603002029, 7, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618002030, 1, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618002030, 2, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618002030, 3, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618002030, 4, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 1, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 2, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 3, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 4, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 5, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 6, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 7, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 8, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 9, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 10, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218002031, 11, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 1, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 2, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 3, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 4, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 5, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 6, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 7, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 8, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 9, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 10, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 11, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 12, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 13, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 14, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002032, 15, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 1, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 2, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 3, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 4, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 5, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106002033, 6, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002034, 1, 144, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002034, 2, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002034, 3, 96, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002034, 4, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 1, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 2, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 3, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 4, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 5, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 6, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 7, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 8, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 9, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 10, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 11, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916002035, 12, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 1, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 2, 79, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 3, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 4, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 5, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107002036, 6, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 1, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 2, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 3, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 4, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 5, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 6, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 7, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 8, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 9, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 10, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 11, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224002037, 12, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 1, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 2, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 3, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 4, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 5, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 6, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 7, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 8, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 9, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 10, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 11, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 12, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322002038, 13, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 1, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 2, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 3, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 4, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 5, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 3, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 4, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 5, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 6, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 7, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 8, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 9, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 10, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 11, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 12, 81, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 13, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002396, 14, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 1, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 2, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 3, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 4, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 5, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 6, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 7, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 8, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 9, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 10, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 11, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 12, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 13, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 14, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 15, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 16, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305002397, 17, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 1, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 2, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 3, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 4, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 5, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 6, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 7, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 8, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 9, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 10, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 11, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 12, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720002398, 13, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 1, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 2, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 3, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 4, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 5, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 6, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 7, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 8, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 9, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002399, 10, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 1, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 2, 97, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 3, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 4, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 5, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 6, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 7, 187, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 8, 111, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 9, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 10, 49, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 11, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627002400, 12, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 1, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 2, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 3, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 4, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 5, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 6, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 7, 88, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 8, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 9, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 10, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 11, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 12, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 13, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 14, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 15, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 16, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223002401, 17, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 1, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 2, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 3, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 4, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 5, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 6, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 7, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 8, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 9, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 10, 74, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 11, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 12, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701002402, 13, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 1, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 2, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 3, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 4, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 5, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 6, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 7, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 8, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 9, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 10, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 11, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 12, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 13, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002403, 14, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 1, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 2, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 3, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 4, 35, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 5, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 6, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119002404, 7, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 1, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 2, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 3, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 4, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 5, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 6, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 7, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 8, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 9, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 10, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 11, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 12, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 13, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 14, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 15, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524002405, 16, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 1, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 2, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 3, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 4, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 5, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 6, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 7, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 8, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 9, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 10, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217002406, 11, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012002407, 1, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012002407, 2, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012002407, 3, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012002407, 4, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 1, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 2, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 3, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 4, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 5, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002408, 6, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 1, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 2, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 3, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 4, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 5, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 6, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 7, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 8, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 9, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 10, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 11, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722002409, 12, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 1, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 2, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 3, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 4, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 5, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 6, 50, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 7, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 8, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 9, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 10, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 11, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 12, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 13, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090730002410, 14, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 1, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 2, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 3, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 4, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 5, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 6, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 7, 104, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 8, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 9, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 10, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 11, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 12, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924002411, 13, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 1, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 2, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 3, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 4, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 5, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 6, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 7, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 8, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 9, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 10, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 11, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 12, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 13, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 14, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 15, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 16, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206002412, 17, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603002413, 1, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603002413, 2, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603002413, 3, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603002413, 4, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819002414, 1, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819002414, 2, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819002414, 3, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819002414, 4, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 1, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 2, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 3, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 4, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 5, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 6, 97, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 7, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 8, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 9, 118, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 10, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321002415, 11, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611002416, 1, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611002416, 2, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611002416, 3, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 1, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 2, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 3, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 4, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 5, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 6, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720002417, 7, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 1, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 2, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 8, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 9, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416001264, 10, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001265, 1, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001265, 2, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001265, 3, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001265, 4, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 1, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 2, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 3, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 4, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 5, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 6, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 7, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 8, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126001266, 9, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809001267, 1, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809001267, 2, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809001267, 3, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809001267, 4, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 1, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 2, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 3, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 4, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 5, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 6, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103001268, 7, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 1, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 2, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 3, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 4, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 5, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 6, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 7, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223001269, 8, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621001270, 1, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621001270, 2, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621001270, 3, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621001270, 4, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621001270, 5, 158, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 1, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 2, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 3, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 4, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 5, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 6, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 7, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 8, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 9, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 10, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 11, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 12, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 13, 166, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 14, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 15, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 16, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327001271, 17, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 1, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 2, 1, 79, 3, 237);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 3, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 4, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 5, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319001272, 6, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 1, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 2, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 3, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 4, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 5, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 6, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 7, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 8, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 9, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 10, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 11, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 12, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 13, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 14, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 15, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 16, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 17, 78, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605001273, 18, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 1, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 2, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 3, 137, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 4, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 5, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604001274, 6, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 1, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 2, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 3, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 4, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 5, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 6, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 7, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612001275, 8, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 1, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 2, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 3, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 4, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 5, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 6, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 7, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 8, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 9, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 10, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 11, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507001276, 12, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 1, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 2, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 3, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 4, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 5, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 6, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 7, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 8, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815001277, 9, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 1, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 2, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 3, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 4, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 5, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 6, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 7, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 8, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 9, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 10, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 11, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 12, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001278, 13, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926001279, 1, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926001279, 2, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926001279, 3, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926001279, 4, 64, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 1, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 2, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 3, 100, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 4, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 5, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 6, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 7, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 8, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 9, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 10, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 11, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 12, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523001280, 13, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 1, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 2, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 3, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 4, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 5, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 6, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 7, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 8, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 9, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 10, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 11, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 12, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 13, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210001281, 14, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 1, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 2, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 3, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 4, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 5, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 6, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721001282, 7, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 1, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 2, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 3, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 4, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 5, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 6, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 7, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001283, 8, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 1, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 2, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 3, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 4, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 5, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 6, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 7, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 8, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 9, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 10, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 11, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226001284, 12, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 1, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 2, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 3, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 4, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 5, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 6, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 7, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 8, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 9, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 10, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 11, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 12, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 13, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 14, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522001285, 15, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 1, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 2, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 3, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 4, 16, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 5, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 6, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 7, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 8, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 9, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514001286, 10, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 1, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 2, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 3, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 4, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 5, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 6, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 7, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918001287, 8, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 1, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 2, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 3, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 4, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 5, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 6, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 7, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518001288, 8, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 1, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 2, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 3, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 4, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 5, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 6, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809001289, 7, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 1, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 2, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 3, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 4, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 13, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 14, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210001659, 15, 167, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 1, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 2, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 3, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 4, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 5, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 6, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 7, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 8, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 9, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 10, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 11, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112001660, 12, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 1, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 2, 98, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 3, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 4, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 5, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113001661, 6, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 1, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 2, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 3, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 4, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 5, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 6, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 7, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 8, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 9, 9, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 10, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 11, 1, 58, 3, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 12, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 13, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 14, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910001662, 15, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 1, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 2, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 3, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 4, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 5, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 6, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 7, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 8, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 9, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061017001663, 10, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 1, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 2, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 3, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 4, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 5, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 6, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 7, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 8, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 9, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 10, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 11, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 12, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 13, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 14, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126001664, 15, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209001665, 1, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209001665, 2, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209001665, 3, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 1, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 2, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 4, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 5, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 6, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 7, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 8, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 9, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 10, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 11, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 12, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 13, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623001666, 14, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 1, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 2, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 3, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 4, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 5, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 6, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 7, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 8, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 9, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 10, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 11, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706001667, 12, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 2, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 3, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 4, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 5, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 6, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 7, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 8, 22, 4, 10, 40);
commit;
prompt 13000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 9, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 10, 74, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 11, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 12, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 13, 80, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225001668, 14, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 1, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 2, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 3, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 4, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 5, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 6, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 7, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 8, 78, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 9, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 10, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528001669, 11, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 1, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 2, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 3, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 4, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 5, 192, 58, 18, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 6, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 7, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115001670, 8, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 1, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 2, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 3, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 4, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 5, 158, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 6, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 7, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 8, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001671, 9, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 1, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 2, 58, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 3, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 4, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 5, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 6, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 7, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 8, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 9, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 10, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 11, 81, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 12, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001672, 13, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 1, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 2, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 3, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 4, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 5, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 6, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504001673, 7, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 1, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 2, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 3, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 4, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 5, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 6, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 7, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001674, 8, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813001675, 1, 126, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813001675, 2, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813001675, 3, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813001675, 4, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 1, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 2, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 3, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 4, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 5, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 6, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 7, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 8, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 9, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 10, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 11, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 12, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 13, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 14, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 15, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 16, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118001676, 17, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702001677, 1, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702001677, 2, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702001677, 3, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702001677, 4, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020702001677, 5, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 1, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 2, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 3, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 4, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 5, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 6, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 7, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 8, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 9, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 10, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 11, 79, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815001678, 12, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 1, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 2, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 3, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 4, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 5, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 6, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 7, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 8, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 9, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 10, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 11, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 12, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117001679, 13, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 1, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 2, 44, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 3, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 4, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 5, 152, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 6, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 7, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 8, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 9, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001680, 10, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 1, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 2, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 3, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 4, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 5, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 6, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 7, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 8, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 9, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 10, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 11, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 12, 44, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 13, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 14, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 15, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 16, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 17, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 6, 185, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 7, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 8, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 9, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 10, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 11, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 12, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 13, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 14, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 15, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002039, 16, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 1, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 2, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 3, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 4, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 5, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 6, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 7, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 8, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 9, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 10, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 11, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 12, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222002040, 13, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 1, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 2, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 3, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 4, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 5, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 6, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 7, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002041, 8, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 1, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 2, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 3, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 4, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 5, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317002042, 6, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 1, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 2, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 3, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 4, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 5, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 6, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 7, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 8, 130, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 9, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 10, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 11, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 12, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 13, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 14, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 15, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 16, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331002043, 17, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520002044, 1, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520002044, 2, 28, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520002044, 3, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 1, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 2, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 3, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 4, 157, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 5, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 6, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 7, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 8, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 9, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 10, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 11, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 12, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 13, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 14, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 15, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423002045, 16, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 1, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 2, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 3, 13, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 4, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 5, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 6, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 7, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 8, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 9, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 10, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 11, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 12, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 13, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 14, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019002046, 15, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 1, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 2, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 3, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 4, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 5, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 6, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 7, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002047, 8, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 1, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 2, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 3, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 4, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 5, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 6, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 7, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029002048, 8, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 1, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 2, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 3, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 4, 45, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 5, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 6, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 7, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 8, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 9, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 10, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 11, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 12, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 13, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 14, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 15, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113002049, 16, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 1, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 2, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 3, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 4, 184, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 5, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 6, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002050, 7, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 1, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 2, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 3, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 4, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 5, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 6, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 7, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316002051, 8, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 1, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 2, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 3, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 4, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 5, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 6, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 7, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 8, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 9, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 10, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 11, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 12, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926002052, 13, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 1, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 2, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 3, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 4, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 5, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 6, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 7, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 8, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 9, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 10, 9, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 11, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 12, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002053, 13, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 1, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 2, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 3, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 4, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 5, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 6, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 7, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 8, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 9, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 10, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 11, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410002054, 12, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 1, 125, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 2, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 3, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 4, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 5, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 6, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 7, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 8, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 9, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 10, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 11, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 12, 106, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208002055, 13, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 1, 38, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 2, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 3, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 4, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 5, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 6, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 7, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 8, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 9, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 10, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 11, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 12, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 13, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002056, 14, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 1, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 2, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 3, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 4, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 5, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 6, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 7, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 8, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 9, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 10, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 11, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 12, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 13, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 14, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 15, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 16, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706002057, 17, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 1, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 2, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 3, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 4, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 5, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 6, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417002058, 7, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 1, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 2, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 3, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 4, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 5, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 6, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 7, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 8, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 9, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 10, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 11, 114, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 12, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021002059, 13, 51, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002060, 1, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 3, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 4, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 5, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 6, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 7, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 8, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408002418, 9, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716002419, 1, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716002419, 2, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716002419, 3, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716002419, 4, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716002419, 5, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 1, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 2, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 3, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 4, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 5, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 6, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 7, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 8, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 9, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 10, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 11, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 12, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 13, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 14, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 15, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 16, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 17, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318002420, 18, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 1, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 2, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 3, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 4, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 5, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 6, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 7, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 8, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 9, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 10, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801002421, 11, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827002422, 1, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827002422, 2, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827002422, 3, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827002422, 4, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809002423, 1, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809002423, 2, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809002423, 3, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002424, 1, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002424, 2, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002424, 3, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002424, 4, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002424, 5, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 1, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 2, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 3, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 4, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 5, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 6, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 7, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 8, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822002425, 9, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 1, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 2, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 3, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 4, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 5, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 6, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908002426, 7, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 1, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 2, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 3, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 4, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 5, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 6, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 7, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 8, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 9, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614002427, 10, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 1, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 2, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 3, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 4, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 5, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 6, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 7, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 8, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 9, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 10, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911002428, 11, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401002429, 1, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401002429, 2, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401002429, 3, 59, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401002429, 4, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 1, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 2, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 3, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 4, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 5, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 6, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 7, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 8, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 9, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 10, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 11, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 12, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 13, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 14, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907002430, 15, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 1, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 2, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 3, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 4, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 5, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 6, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 7, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002431, 8, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 1, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 2, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 3, 90, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 4, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 5, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 6, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 7, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 8, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 9, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 10, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 11, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 12, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 13, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829002432, 14, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 1, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 2, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 3, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 4, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 5, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 6, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 7, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 8, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 9, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002433, 10, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 1, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 2, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 3, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 4, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 5, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 6, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 7, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 8, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 9, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 10, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 11, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 12, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 13, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212002434, 14, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 1, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 2, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 3, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 4, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 5, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 6, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 7, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 8, 72, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 9, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 10, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 11, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812002435, 12, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 1, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 2, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 3, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 4, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 5, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 6, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 7, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 8, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 9, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 10, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 11, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 12, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 13, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731002436, 14, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 1, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 2, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 3, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 4, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 5, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 6, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 7, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 8, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 9, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 10, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 11, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 12, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 13, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 14, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002437, 15, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 1, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 2, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 3, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 4, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 5, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 6, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 7, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 8, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620002438, 9, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 1, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 2, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 3, 187, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 4, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 5, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 6, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 7, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 8, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022002439, 9, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 1, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 2, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 3, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 4, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 5, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 6, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 7, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 8, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 9, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 10, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 11, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 12, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423002440, 13, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 1, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 2, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 3, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 4, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 5, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 6, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 7, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 8, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 9, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 10, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 11, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 5, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227001290, 6, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 1, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 2, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 3, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 4, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 5, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 6, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 7, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 8, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821001291, 9, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 1, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 2, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 3, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 4, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 5, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 6, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 7, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 8, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 9, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 10, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 11, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 12, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 13, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326001292, 14, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 1, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 2, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 3, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 4, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 5, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 6, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 7, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 8, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 9, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 10, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 11, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 12, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001293, 13, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 1, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 2, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 3, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 4, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 5, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 6, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 7, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 8, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 9, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001294, 10, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 1, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 2, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 3, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 4, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 5, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 6, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 7, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 8, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 9, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 10, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110001295, 11, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000328001296, 1, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000328001296, 2, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000328001296, 3, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 1, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 2, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 3, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 4, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 5, 15, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 6, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 7, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826001297, 8, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 1, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 2, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 3, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 4, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 5, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 6, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 7, 163, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 8, 3, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 9, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 10, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 11, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 12, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 13, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 14, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 15, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722001298, 16, 152, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324001299, 1, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324001299, 2, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324001299, 3, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324001299, 4, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324001299, 5, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 1, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 2, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 3, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 5, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 6, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 7, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 8, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 9, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 10, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 11, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 12, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105001300, 13, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 1, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 2, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 3, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 4, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 5, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 6, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 7, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 8, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 9, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 10, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 11, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 12, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 13, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 14, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720001301, 15, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000731001302, 1, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000731001302, 2, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000731001302, 3, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000731001302, 4, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000731001302, 5, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 1, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 2, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 3, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 4, 184, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 5, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 6, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128001303, 7, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 1, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 2, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 3, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 4, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 5, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010925001304, 6, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 1, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 2, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 3, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 4, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 5, 70, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 6, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 7, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 8, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 9, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 10, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008001305, 11, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 1, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 2, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 3, 89, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 4, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 5, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 6, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 7, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 8, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 9, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 10, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 11, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 12, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 13, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 14, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 15, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620001306, 16, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518001307, 1, 156, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518001307, 2, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518001307, 3, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518001307, 4, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518001307, 5, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 1, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 2, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 3, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 4, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 5, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 6, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 7, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 8, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 9, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 10, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 11, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 12, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 13, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 14, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 15, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 16, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 17, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219001308, 18, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 1, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 2, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 3, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 4, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 5, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 6, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 7, 14, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 8, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 9, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 10, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 11, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 12, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 13, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 14, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 15, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 16, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221001309, 17, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 1, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 2, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 4, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 5, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420001310, 6, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001311, 1, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001311, 2, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001311, 3, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001311, 4, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001311, 5, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 1, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 2, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 3, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 4, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 5, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 6, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 7, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 8, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223001312, 9, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 1, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 2, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 3, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 4, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 5, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 6, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415001313, 7, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 1, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 2, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 3, 143, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 4, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 5, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 6, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 7, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 8, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001681, 18, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 1, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 2, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 3, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 4, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 5, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 6, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325001682, 7, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 1, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 2, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 3, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 4, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 5, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 6, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 7, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 8, 102, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 9, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 10, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 11, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 12, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 13, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108001683, 14, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 1, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 2, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 3, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 4, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 5, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 6, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 7, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 8, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 9, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001684, 10, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222001685, 1, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222001685, 2, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222001685, 3, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222001685, 4, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 1, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 2, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 3, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 4, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 5, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 6, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 7, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 8, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 9, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202001686, 10, 56, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 1, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 2, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 3, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 4, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 5, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 6, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 7, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 8, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 9, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 10, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725001687, 11, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 1, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 2, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 3, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 4, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 5, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 6, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 7, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 8, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 9, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 10, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504001688, 11, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 1, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 2, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 3, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 4, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 5, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 6, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 7, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 8, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 9, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 10, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 11, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 12, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 13, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 14, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 15, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 16, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 17, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119001689, 18, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 1, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 2, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 3, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 4, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 5, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 6, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 7, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 8, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 9, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 10, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 11, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 12, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 13, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 14, 155, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 15, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 16, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001690, 17, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 1, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 2, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 3, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 4, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 5, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 6, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 7, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 8, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 9, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 10, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 11, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 12, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 13, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905001691, 14, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 1, 148, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 2, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 3, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 4, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 5, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 6, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 7, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 8, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107001692, 9, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 1, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 2, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 3, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 4, 2, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 5, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 6, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 7, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028001693, 8, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 1, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 2, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 3, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 4, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 5, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 6, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 7, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 8, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 9, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 10, 175, 42, 15, 630);
commit;
prompt 14000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 11, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 12, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 13, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 14, 67, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 15, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 16, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128001694, 17, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 1, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 2, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 3, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 4, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 5, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 6, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 7, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 8, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 9, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 10, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 11, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215001695, 12, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 1, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 2, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 3, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 4, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 5, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 6, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001696, 7, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 1, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 2, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 3, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 4, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 5, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 6, 190, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 7, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 8, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 9, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 10, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 11, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 12, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 13, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 14, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 15, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507001697, 16, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 1, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 2, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 3, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 4, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 5, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 6, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 7, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 8, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723001698, 9, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113001699, 1, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113001699, 2, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113001699, 3, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113001699, 4, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113001699, 5, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 1, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 2, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 3, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 4, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 5, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 6, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 7, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 8, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 9, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 10, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 11, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 12, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001700, 13, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624001701, 1, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624001701, 2, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624001701, 3, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 1, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 2, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 3, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 4, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 5, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 6, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 7, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 8, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 9, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 10, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424001702, 11, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 1, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 2, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 3, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 4, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 5, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 6, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730001703, 7, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 1, 19, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 2, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 3, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 4, 126, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 5, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002060, 2, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002060, 3, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511002061, 1, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511002061, 2, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511002061, 3, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704002062, 1, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704002062, 2, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704002062, 3, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704002062, 4, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704002062, 5, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 1, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 2, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 3, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 4, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 5, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 6, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 7, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 8, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 9, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 10, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 11, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218002063, 12, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 1, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 2, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 3, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 4, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 5, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501002064, 6, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 1, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 2, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 3, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 4, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 5, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 6, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 7, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 8, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 9, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 10, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 11, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 12, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 13, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 14, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 15, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 16, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 17, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 18, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104002065, 19, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607002066, 1, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607002066, 2, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607002066, 3, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607002066, 4, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607002066, 5, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 1, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 2, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 3, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 4, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 5, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 6, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403002067, 7, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 1, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 2, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 3, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 4, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 5, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 6, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 7, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 8, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 9, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 10, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226002068, 11, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 1, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 2, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 3, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 4, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 5, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615002069, 6, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 1, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 2, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 3, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 4, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 5, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 6, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 7, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 8, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504002070, 9, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 1, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 2, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 3, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 4, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 5, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 6, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 7, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 8, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816002071, 9, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 1, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 2, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 3, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 4, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 5, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030902002072, 6, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 1, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 2, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 3, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 4, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 5, 39, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 6, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 7, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216002073, 8, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 1, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 2, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 3, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 4, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 5, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 6, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051004002074, 7, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105002075, 1, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105002075, 2, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105002075, 3, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105002075, 4, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105002075, 5, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 1, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 2, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 3, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 4, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 5, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 6, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 7, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 8, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 9, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 10, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 11, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 12, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100804002076, 13, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 1, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 2, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 3, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 4, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 5, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103002077, 6, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 1, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 2, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 3, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 4, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 5, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 6, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 7, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 8, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 9, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210002078, 10, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 1, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 2, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 3, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 4, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 5, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 6, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 7, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 8, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 9, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 10, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 11, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 12, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 13, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 14, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514002079, 15, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 1, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 2, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 3, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 4, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 5, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 6, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 7, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 8, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 9, 12, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420002080, 10, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 1, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 2, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 3, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 4, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 5, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 6, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 7, 117, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 8, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 9, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 10, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 11, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510002081, 12, 185, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 1, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 2, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 3, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 4, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 5, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 6, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 7, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121002082, 8, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 1, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 2, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 3, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 4, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 5, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002083, 6, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 1, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 2, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 3, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 4, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 5, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 6, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 7, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 8, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 9, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 10, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016002084, 11, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209002085, 1, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209002085, 2, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209002085, 3, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209002085, 4, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 1, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 2, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 3, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 4, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 5, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 6, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 7, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 8, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424002086, 9, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 1, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 2, 35, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 3, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 4, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 5, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 6, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 7, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 8, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 9, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 10, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 11, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 12, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215002087, 13, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 1, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 2, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928002441, 12, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 1, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 2, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 3, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 4, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 5, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 6, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 7, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 8, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 9, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610002442, 10, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 1, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 2, 157, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 3, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 4, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 5, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102002443, 6, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 1, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 2, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 3, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 4, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 5, 107, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 6, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 7, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 8, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 9, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227002444, 10, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 1, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 2, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 3, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 4, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 5, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 6, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 7, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 8, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 9, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 10, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 11, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002445, 12, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 1, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 2, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 3, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 4, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 5, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 6, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 7, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 8, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 9, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 10, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 11, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112002446, 12, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 1, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 2, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 3, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 4, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 5, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 6, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 7, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 8, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 9, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 10, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 11, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 12, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 13, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 14, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103002447, 15, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 1, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 2, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 3, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 4, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 5, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702002448, 6, 10, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 1, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 2, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 3, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 4, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 5, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 6, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 7, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209002449, 8, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 1, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 2, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 3, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 4, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 5, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 6, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 7, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 8, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 9, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 10, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 11, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 12, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 13, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 14, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 15, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 16, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501002450, 17, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 1, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 2, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 3, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 4, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 5, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 6, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 7, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 8, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 9, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225002451, 10, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 1, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 2, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 3, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 4, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 5, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 6, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 7, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 8, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 9, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 10, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 11, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 12, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 13, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 14, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 15, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 16, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115002452, 17, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 1, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 2, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 3, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 4, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 5, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 6, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 7, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 8, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 9, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 10, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 11, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 12, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 13, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 14, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 15, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010002453, 16, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 1, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 2, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 3, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 4, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 5, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 6, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 7, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 8, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 9, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 10, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 11, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 12, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 13, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219002454, 14, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207002455, 1, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207002455, 2, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207002455, 3, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 1, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 2, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 3, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 4, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 5, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 6, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 7, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 8, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702002456, 9, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 1, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 2, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 3, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 4, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 5, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 6, 29, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 7, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 8, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 9, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 10, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618002457, 11, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825002458, 1, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825002458, 2, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825002458, 3, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825002458, 4, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 1, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 2, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 3, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 4, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 5, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 6, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 7, 153, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 8, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 9, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 10, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 11, 168, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 12, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 13, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 14, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 15, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 16, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 17, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 18, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302002459, 19, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002460, 1, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002460, 2, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002460, 3, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002460, 4, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 1, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 2, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 3, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 4, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 5, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303002461, 6, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 1, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 2, 41, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 3, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 4, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 5, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 6, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 7, 161, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 8, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 9, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 10, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 11, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 12, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307002462, 13, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 1, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 2, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 3, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 4, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 5, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 6, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 7, 129, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 8, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 9, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 10, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 11, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 12, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 13, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 14, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 15, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 16, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 9, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 10, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 11, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001314, 12, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 1, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 2, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 3, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 4, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 5, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 6, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 7, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 8, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 9, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 10, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719001315, 11, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 1, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 2, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 3, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 4, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 5, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 6, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305001316, 7, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 1, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 2, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 3, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 4, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 5, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 6, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 7, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 8, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 9, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 10, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 11, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 12, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 13, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 14, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 15, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 16, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130215001317, 17, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000812001318, 1, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000812001318, 2, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000812001318, 3, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 1, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 2, 112, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 3, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 4, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 5, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 6, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 7, 190, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 8, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 9, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 10, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001319, 11, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 1, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 2, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 3, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 4, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 5, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 6, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 7, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 8, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 9, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 10, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 11, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215001320, 12, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 1, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 2, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 3, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 4, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 5, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829001321, 6, 32, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 1, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 2, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 3, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 4, 127, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 5, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 6, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 7, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 8, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 9, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 10, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 11, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 12, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 13, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 14, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 15, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 16, 46, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515001322, 17, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922001323, 1, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922001323, 2, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922001323, 3, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922001323, 4, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 1, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 2, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 3, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 4, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 5, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 6, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 7, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 8, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 9, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 10, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 11, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 12, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091123001324, 13, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 1, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 2, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 3, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 4, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 5, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 6, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 7, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 8, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 9, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 10, 134, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 11, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 12, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 13, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014001325, 14, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707001326, 1, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707001326, 2, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707001326, 3, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707001326, 4, 79, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 1, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 2, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 3, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 4, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 5, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 6, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 7, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 8, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 9, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 10, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 11, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 12, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106001327, 13, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 1, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 2, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 3, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 4, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 5, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 6, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 7, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 8, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 9, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 10, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915001328, 11, 48, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 1, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 2, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 3, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 4, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 5, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 6, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 7, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 8, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 9, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 10, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 11, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001329, 12, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 1, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 2, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 3, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 4, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 5, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 6, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 7, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 8, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 9, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 10, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 11, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 12, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 13, 67, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926001330, 14, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 1, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 2, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 3, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 4, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 5, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 6, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 7, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 8, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 9, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 10, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 11, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 12, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912001331, 13, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126001332, 1, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126001332, 2, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126001332, 3, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126001332, 4, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126001332, 5, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009001333, 1, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009001333, 2, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 1, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 2, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 3, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 4, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 5, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 6, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506001334, 7, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 1, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 2, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 3, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 4, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 5, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 6, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 7, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 8, 21, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 9, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110001335, 10, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 1, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 2, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 3, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 4, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 5, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 6, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 7, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 8, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 9, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 10, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 11, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230001336, 12, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 1, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 2, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 3, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 4, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 5, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 6, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 7, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 8, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 9, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 10, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 11, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001337, 12, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 1, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 2, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 3, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 4, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 5, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 6, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 7, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 8, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 9, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 10, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 11, 131, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827001704, 12, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 1, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 2, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 3, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 4, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 5, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606001705, 6, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 1, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 2, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 3, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 4, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 5, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 6, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 7, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304001706, 8, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210001707, 1, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210001707, 2, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210001707, 3, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210001707, 4, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 1, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 2, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 3, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 4, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 5, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 6, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 7, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 8, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 9, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 10, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 11, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 12, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 13, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 14, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 15, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226001708, 16, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 1, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 2, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 3, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 4, 191, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 5, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828001709, 6, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 1, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 2, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 3, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 4, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 5, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 6, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001710, 7, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 1, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 2, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 3, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 4, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 5, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 6, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 7, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 8, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 9, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 10, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 11, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 12, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303001711, 13, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 1, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 2, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 3, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 4, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 5, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 6, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 7, 157, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 8, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 9, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 10, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090120001712, 11, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 1, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 2, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 3, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 4, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 5, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001713, 6, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 1, 44, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 2, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 3, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 4, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 5, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 6, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 7, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 8, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 9, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 10, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608001714, 11, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 1, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 2, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 3, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 4, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 5, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 6, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 7, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 8, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 9, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 10, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 11, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 12, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 13, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 14, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 15, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921001715, 16, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 1, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 2, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 3, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 4, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 5, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 6, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 7, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 8, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 9, 39, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 10, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 11, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 12, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001716, 13, 173, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 1, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 2, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 3, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 4, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 5, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 6, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 7, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001717, 8, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412001718, 1, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412001718, 2, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412001718, 3, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412001718, 4, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412001718, 5, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 1, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 2, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 3, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 4, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 5, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 6, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 7, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001719, 8, 175, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 1, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 2, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 3, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 4, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 5, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 6, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 7, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 8, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 9, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818001720, 10, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 1, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 2, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 3, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 4, 62, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 5, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 6, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 7, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 8, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 9, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 10, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 11, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 12, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201001721, 13, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 1, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 2, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 3, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 4, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 5, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 6, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 7, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303001722, 8, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 1, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 2, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 3, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 4, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 5, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 6, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 7, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 8, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 9, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 10, 124, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 11, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619001723, 12, 153, 74, 10, 740);
commit;
prompt 15000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 1, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 2, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 3, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 4, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 5, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 6, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 7, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 8, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 9, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 10, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 11, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 12, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128001724, 13, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 1, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 2, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 3, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 4, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 5, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 6, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 7, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 8, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 9, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 10, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 11, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 12, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 13, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 14, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 15, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 16, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331001725, 17, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 1, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 2, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 3, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 4, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 5, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216001726, 6, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 1, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 2, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 3, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 4, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 5, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 6, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 7, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 8, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 9, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 10, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 11, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 12, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 13, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 14, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 15, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 3, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 4, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 5, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 6, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 7, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 8, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 9, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821002088, 10, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 1, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 2, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 3, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 4, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 5, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 6, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 7, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603002089, 8, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 1, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 2, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 3, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 4, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 5, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 6, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 7, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 8, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 9, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 10, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 11, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 12, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 13, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622002090, 14, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922002091, 1, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922002091, 2, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922002091, 3, 61, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922002091, 4, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 1, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 2, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 3, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 4, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 5, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 6, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 7, 65, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910002092, 8, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504002093, 1, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504002093, 2, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504002093, 3, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 1, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 2, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 3, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 4, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 5, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 6, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 7, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 8, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 9, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 10, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215002094, 11, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 1, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 2, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 3, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 4, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 5, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 6, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 7, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 8, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 9, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 10, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 11, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130002095, 12, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 1, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 2, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 3, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 4, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 5, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 6, 3, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 7, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 8, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002096, 9, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 1, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 2, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 3, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 4, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 5, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 6, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 7, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002097, 8, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 1, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 2, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 3, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 4, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 5, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 6, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 7, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 8, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 9, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 10, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 11, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 12, 41, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407002098, 13, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 1, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 2, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 3, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 4, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 5, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 6, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 7, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 8, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 9, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 10, 14, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 11, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 12, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 13, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 14, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 15, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409002099, 16, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 1, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 2, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 3, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 4, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 5, 39, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625002100, 6, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 1, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 2, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 3, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 4, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 5, 121, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 6, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 7, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 8, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 9, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 10, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114002101, 11, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 1, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 2, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 3, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 4, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 5, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 6, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 7, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 8, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 9, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 10, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 11, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 12, 64, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 13, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 14, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 15, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417002102, 16, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 1, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 2, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 3, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 4, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 5, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002103, 6, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 1, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 2, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 3, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 4, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 5, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 6, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 7, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306002104, 8, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 1, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 2, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 3, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 4, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 5, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 6, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 7, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 8, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 9, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 10, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 11, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 12, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214002105, 13, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 1, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 2, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 3, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 4, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 5, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 6, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 7, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 8, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 9, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 10, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 11, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 12, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 13, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 14, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121002106, 15, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 1, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 2, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 3, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 4, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 5, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 6, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 7, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 8, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 9, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611002107, 10, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 1, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 2, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 3, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 4, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 5, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 6, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 7, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 8, 37, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 9, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 10, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320002108, 11, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717002109, 1, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717002109, 2, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717002109, 3, 166, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 1, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 2, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 3, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 4, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 5, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 6, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 7, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 8, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 9, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915002110, 10, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 1, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 2, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 3, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 4, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 5, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 6, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 7, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 8, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 9, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 10, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 11, 125, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 12, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 13, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 14, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 15, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814002111, 16, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 2, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 3, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 4, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 5, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 6, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 7, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 8, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 9, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 10, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 1, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 2, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 3, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 4, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 5, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 6, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 7, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 8, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 9, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 10, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613002555, 11, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928002556, 1, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928002556, 2, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928002556, 3, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928002556, 4, 191, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005002557, 1, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005002557, 2, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005002557, 3, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218002558, 1, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218002558, 2, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218002558, 3, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218002558, 4, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 1, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 2, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 3, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 4, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 5, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 6, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 7, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 8, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 9, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 10, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 11, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 12, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002559, 13, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 1, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 2, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 3, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 4, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 5, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 6, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 7, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 8, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 9, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 10, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 11, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 12, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 13, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 14, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 15, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415002560, 16, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 1, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 2, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 3, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 4, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 5, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 6, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 7, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 8, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 9, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 10, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 11, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 12, 84, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821002561, 13, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 1, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 2, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 3, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 4, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 5, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 6, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 7, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 8, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 9, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 10, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327002562, 11, 69, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 1, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 2, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 3, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 4, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 5, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 6, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 7, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 8, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 9, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 10, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 11, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 12, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101028002563, 13, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 1, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 2, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 3, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 4, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 5, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 6, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 7, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 8, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 9, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 10, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 11, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 12, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210002564, 13, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 1, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 2, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 3, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 4, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 5, 145, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 6, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 7, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 8, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 9, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 10, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 11, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 12, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 13, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 14, 130, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 15, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 16, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 17, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306002565, 18, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 1, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 2, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 3, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 4, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 5, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 6, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 7, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 8, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 9, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 10, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 11, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 12, 84, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 13, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118002566, 14, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 1, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 2, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 3, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 4, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 5, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 6, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 7, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 8, 153, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 9, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 10, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 11, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 12, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 13, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 14, 105, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 15, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 16, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124002567, 17, 33, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 1, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 2, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 3, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 4, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 5, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 6, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 7, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 8, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 9, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 10, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 11, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 12, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 13, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 14, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 15, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018002568, 16, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 1, 1, 58, 3, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 2, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 3, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 4, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 5, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 6, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 7, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 8, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 9, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 10, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 11, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 12, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 13, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 14, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 15, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415002569, 16, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707002570, 1, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707002570, 2, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707002570, 3, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 1, 49, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 2, 59, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 3, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 4, 47, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 5, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 6, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 7, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 8, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 9, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 10, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 11, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 12, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 13, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 14, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 15, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 16, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002571, 17, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913002572, 1, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913002572, 2, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913002572, 3, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 1, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 2, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 3, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 4, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 5, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 6, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 7, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 8, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 9, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 10, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 11, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 12, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 13, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413002573, 14, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901002574, 1, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901002574, 2, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425002575, 1, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425002575, 2, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425002575, 3, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425002575, 4, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425002575, 5, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 1, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 2, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 3, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 4, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 6, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 7, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 8, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 9, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 10, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 11, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208001338, 12, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 1, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 2, 36, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 3, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 4, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 5, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 6, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 7, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508001339, 8, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 1, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 2, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 3, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 4, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 5, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 6, 96, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212001340, 7, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 1, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 2, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 3, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 4, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 5, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 6, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 7, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 8, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 9, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 10, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 11, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 12, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 13, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001341, 14, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 1, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 2, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 3, 189, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 4, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 5, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001342, 6, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 1, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 2, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 3, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 4, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 5, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 6, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 7, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127001343, 8, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 1, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 2, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 3, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 4, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 5, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 6, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 7, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 8, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 9, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 10, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203001344, 11, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 1, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 2, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 3, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 4, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 5, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121001345, 6, 177, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 1, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 2, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 3, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 4, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 5, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312001346, 6, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129001347, 1, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129001347, 2, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129001347, 3, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129001347, 4, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129001347, 5, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403001348, 1, 43, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403001348, 2, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403001348, 3, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403001348, 4, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 1, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 2, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 3, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 4, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 5, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 6, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 7, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 8, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 9, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 10, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 11, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 12, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 13, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 14, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124001349, 15, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 1, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 2, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 3, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 4, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 5, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 6, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422001350, 7, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 1, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 2, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 3, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 4, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 5, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 6, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 7, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 8, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 9, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 10, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 11, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 12, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 13, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619001351, 14, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 1, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 2, 141, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 3, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 4, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 5, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 6, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405001352, 7, 1, 14, 3, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 1, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 2, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 3, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 4, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 5, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 6, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 7, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 8, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 9, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 10, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 11, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 12, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 13, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903001353, 14, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 1, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 2, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 3, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 4, 4, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 5, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 6, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 7, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 8, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 9, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 10, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 11, 7, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102001354, 12, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 1, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 2, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 3, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 4, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 5, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 6, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 7, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 8, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 9, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 10, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 11, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 12, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 13, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 14, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 15, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 16, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 17, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 18, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305001355, 19, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 1, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 2, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 3, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 4, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 5, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227001356, 6, 172, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 1, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 2, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 3, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 4, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 5, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 6, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 7, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 8, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 9, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 10, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 11, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110001357, 12, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 1, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 2, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 3, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 4, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 5, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 6, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 7, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 8, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 9, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 10, 165, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 11, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 12, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 13, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 14, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102001358, 15, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 1, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 2, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 3, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 4, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 5, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 6, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 7, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 8, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 9, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 10, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 11, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 12, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 13, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 14, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912001359, 15, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 1, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 2, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 3, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 4, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 5, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 6, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 7, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 8, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 9, 169, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 10, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 11, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 12, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 13, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 14, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 15, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 16, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907001360, 17, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 1, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 2, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 3, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 4, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 16, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107001727, 17, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 1, 105, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 2, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 3, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 4, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 5, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 6, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 7, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 8, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 9, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 10, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 11, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 12, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 13, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 14, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 15, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 16, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611001728, 17, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 1, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 2, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 3, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 4, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 5, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 6, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808001729, 7, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 1, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 2, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 3, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 4, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 5, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 6, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 7, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 8, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203001730, 9, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122001731, 1, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122001731, 2, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122001731, 3, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122001731, 4, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 1, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 2, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 3, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 4, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 5, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 6, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 7, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 8, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 9, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 10, 68, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 11, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 12, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 13, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 14, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 15, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 16, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 17, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326001732, 18, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 1, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 2, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 3, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 4, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 5, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 6, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 7, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324001733, 8, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516001734, 1, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516001734, 2, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516001734, 3, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516001734, 4, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 1, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 2, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 3, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 4, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 5, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 6, 136, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001735, 7, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 1, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 2, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 3, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 4, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 5, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 6, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 7, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 8, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 9, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 10, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 11, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 12, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 13, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 14, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 15, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610001736, 16, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919001737, 1, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919001737, 2, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919001737, 3, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919001737, 4, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919001737, 5, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 1, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 2, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 3, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 4, 55, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 5, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 6, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 7, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 8, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 9, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 10, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 11, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028001738, 12, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 1, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 2, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 3, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 4, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 5, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 6, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001739, 7, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715001740, 1, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715001740, 2, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715001740, 3, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715001740, 4, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731001741, 1, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731001741, 2, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731001741, 3, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 1, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 2, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 3, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 4, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 5, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 6, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 7, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 8, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 9, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 10, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 11, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 12, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213001742, 13, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 1, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 2, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 3, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 4, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 5, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 6, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 7, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 8, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 9, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 10, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 11, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 12, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 13, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626001743, 14, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 1, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 2, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 3, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 4, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 5, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 6, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026001744, 7, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 1, 21, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 2, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 3, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 4, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 5, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 6, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001745, 7, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 1, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 2, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 3, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 4, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 5, 192, 47, 18, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 6, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 7, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703001746, 8, 85, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 1, 78, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 2, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 3, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 4, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 5, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 6, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 7, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 8, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620001747, 9, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 1, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 2, 162, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 3, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 4, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 5, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 6, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 7, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 8, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 9, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 10, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 11, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130001748, 12, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 1, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 2, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 3, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 4, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 5, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 6, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 7, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 8, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 9, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 10, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 11, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001749, 12, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 1, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 2, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 3, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 4, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 5, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 6, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 7, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 8, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 9, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 10, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 11, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 12, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 13, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 14, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 15, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 16, 1, 56, 3, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025001750, 17, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 1, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 2, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 3, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 4, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 5, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 6, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 7, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 8, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 9, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 10, 3, 71, 5, 355);
commit;
prompt 16000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 11, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729001751, 12, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 1, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 2, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 3, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 4, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 5, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 1, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 2, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 3, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 4, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 5, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 6, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 7, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 8, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320002112, 9, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112002113, 1, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112002113, 2, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112002113, 3, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112002113, 4, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 1, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 2, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 3, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 4, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 5, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021220002114, 6, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 1, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 2, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 3, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 4, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 5, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 6, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 7, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 8, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 9, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 10, 27, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 11, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 12, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 13, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 14, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 15, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727002115, 16, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 1, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 2, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 3, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 4, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 5, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 6, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 7, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 8, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012002116, 9, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 1, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 2, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 3, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 4, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 5, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 6, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 7, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 8, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 9, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 10, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 11, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 12, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708002117, 13, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 1, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 2, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 3, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 4, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 5, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109002118, 6, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 1, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 2, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 3, 30, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 4, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 5, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 6, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 7, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 8, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 9, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 10, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 11, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 12, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 13, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229002119, 14, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919002120, 1, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919002120, 2, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919002120, 3, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919002120, 4, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919002120, 5, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 1, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 2, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 3, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 4, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 5, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417002121, 6, 147, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 1, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 2, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 3, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 4, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 5, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 6, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 7, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 8, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 9, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 10, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002122, 11, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 1, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 2, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 3, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 4, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 5, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 6, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 7, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 8, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 9, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201002123, 10, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 1, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 2, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 3, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 4, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 5, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 6, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 7, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 8, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 9, 192, 6, 18, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 10, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 11, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 12, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706002124, 13, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322002125, 1, 128, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322002125, 2, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322002125, 3, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322002125, 4, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 1, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 2, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 3, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 4, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 5, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 6, 110, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 7, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 8, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 9, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 10, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 11, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 12, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312002126, 13, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 1, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 2, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 3, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 4, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 5, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 6, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 7, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 8, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071102002127, 9, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 1, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 2, 147, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 3, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 4, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 5, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403002128, 6, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815002129, 1, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815002129, 2, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815002129, 3, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815002129, 4, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 1, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 2, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 3, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 4, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 6, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 7, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 8, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120002130, 9, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 1, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 2, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 3, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 4, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 5, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 6, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 7, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 8, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 9, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 10, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 11, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604002131, 12, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 1, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 2, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 3, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 4, 179, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 5, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 6, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301002132, 7, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 1, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 2, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 3, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 4, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 5, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 6, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 7, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 8, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 9, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 10, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 11, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 12, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 13, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113002133, 14, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002134, 1, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002134, 2, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002134, 3, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002134, 4, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002134, 5, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 1, 44, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 2, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 3, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 4, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 5, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 6, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002135, 7, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 1, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 2, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 3, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 4, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 5, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925002136, 6, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 1, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 2, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 3, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 4, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 5, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 6, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 7, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 8, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 9, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 10, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 11, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 12, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 13, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 14, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206002137, 15, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 1, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 2, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 3, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 4, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 5, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 6, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002463, 17, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 1, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 2, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 3, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 4, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 5, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 6, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 7, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 8, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 9, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 10, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 11, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 12, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 13, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 14, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 15, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 16, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002464, 17, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 1, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 2, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 3, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 4, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 5, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 6, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 7, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 8, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 9, 8, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 10, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 11, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417002465, 12, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 1, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 2, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 3, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 4, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 5, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 6, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 7, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 8, 38, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 9, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 10, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 11, 129, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 12, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 13, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 14, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418002466, 15, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 1, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 2, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 3, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 4, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 5, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924002467, 6, 54, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021229002468, 1, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021229002468, 2, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021229002468, 3, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021229002468, 4, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021229002468, 5, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 1, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 2, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 3, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 4, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 5, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 6, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 7, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 8, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 9, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 10, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 11, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 12, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 13, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 14, 24, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 15, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 16, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502002469, 17, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307002470, 1, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307002470, 2, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307002470, 3, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307002470, 4, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307002470, 5, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 1, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 2, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 3, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 4, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 5, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 6, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 7, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 8, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401002471, 9, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 1, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 2, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 3, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 4, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 5, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 6, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 7, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 8, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 9, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 10, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 11, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 12, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 13, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100911002472, 14, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002473, 1, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002473, 2, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002473, 3, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002473, 4, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002473, 5, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 1, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 2, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 3, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 4, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 5, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 6, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 7, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 8, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 9, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 10, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 11, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 12, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 13, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 14, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 15, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129002474, 16, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 1, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 2, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 3, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 4, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 5, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 6, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 7, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 8, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 9, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 10, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 11, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 12, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 13, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 14, 1, 85, 3, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 15, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119002475, 16, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125002476, 1, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125002476, 2, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125002476, 3, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125002476, 4, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125002476, 5, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402002477, 1, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402002477, 2, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402002477, 3, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402002477, 4, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 1, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 2, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 3, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 4, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 5, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 6, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 7, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 8, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 9, 185, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 10, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 11, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 12, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002478, 13, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 1, 78, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 2, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 3, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 4, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 5, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 6, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 7, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 8, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721002479, 9, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 1, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 2, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 3, 1, 2, 3, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 4, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 5, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 6, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 7, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 8, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 9, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 10, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323002480, 11, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 1, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 2, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 3, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 4, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 5, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 6, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 7, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 8, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 9, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 10, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 11, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 12, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 13, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 14, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002481, 15, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 1, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 2, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 3, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 4, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 5, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 6, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 7, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 8, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 9, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 10, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 11, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 12, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 13, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 14, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 15, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 16, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128002482, 17, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 1, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 2, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 3, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 4, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 5, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 6, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 7, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 8, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 9, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 10, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 11, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 12, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 13, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222002483, 14, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 1, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 2, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 3, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 4, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 5, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 6, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 7, 69, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002484, 8, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 1, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 2, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 3, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 4, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 5, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 5, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 6, 182, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 7, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 8, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 9, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 10, 150, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 11, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 12, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 13, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 14, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 15, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509001361, 16, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 1, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 2, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 3, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 4, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 5, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 6, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 7, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 8, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 9, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 10, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 11, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 12, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 13, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 14, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 15, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 16, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 17, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217001362, 18, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 1, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 2, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 3, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 4, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 5, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 6, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 7, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 8, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 9, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050104001363, 10, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 1, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 2, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 3, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 4, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 5, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 6, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228001364, 7, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 1, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 2, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 3, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 4, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 5, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 6, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 7, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 8, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 9, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 10, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 11, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 12, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 13, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 14, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 15, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609001365, 16, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 1, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 2, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 3, 109, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 4, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 5, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 6, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 7, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 8, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 9, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 10, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829001366, 11, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 1, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 2, 187, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 3, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 4, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 5, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 6, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 7, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 8, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 9, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 10, 108, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 11, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 12, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001367, 13, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 1, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 2, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 3, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 4, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 5, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 6, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 7, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 8, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 9, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 10, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 11, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 12, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117001368, 13, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 1, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 2, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 3, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 4, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 5, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 6, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 7, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 8, 68, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 9, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 10, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 11, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 12, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 13, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909001369, 14, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 1, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 2, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 3, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 4, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 5, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 6, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 7, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 8, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 9, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219001370, 10, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723001371, 1, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723001371, 2, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723001371, 3, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 1, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 2, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 3, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 4, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 5, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 6, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 7, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 8, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 9, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 10, 39, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 11, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410001372, 12, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 1, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 2, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 3, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 4, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 5, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 6, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 7, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 8, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 9, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 10, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 11, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 12, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 13, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622001373, 14, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 1, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 2, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 4, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 5, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 6, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 7, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 8, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 9, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 10, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 11, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 12, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 13, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028001374, 14, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 1, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 3, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 4, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 5, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121001375, 6, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 1, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 2, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 3, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 4, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 5, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 6, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 7, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 8, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 9, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 10, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514001376, 11, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 1, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 2, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 3, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 4, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 5, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 6, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 7, 1, 95, 3, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 8, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 9, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 10, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801001377, 11, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 1, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 2, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 3, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 4, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 5, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 6, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 7, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 8, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 9, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 10, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 11, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 12, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 13, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615001378, 14, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 1, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 2, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 3, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 4, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 5, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 6, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 7, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112001379, 8, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 1, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 2, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 3, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 4, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 5, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 6, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 7, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 8, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 9, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 10, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 11, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 12, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 13, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001380, 14, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 1, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 2, 122, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 3, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 4, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 5, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 6, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 7, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111001381, 8, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 6, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 7, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406001752, 8, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 1, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 2, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 3, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 4, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 5, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 6, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 7, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 8, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 9, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 10, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001753, 11, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 1, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 2, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 3, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 4, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 5, 47, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 6, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 7, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 8, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 9, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 10, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001754, 11, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 1, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 2, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 3, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 4, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 5, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 6, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 7, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 8, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 9, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 10, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 11, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511001755, 12, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 1, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 2, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 3, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 4, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 5, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 6, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 7, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040119001756, 8, 57, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 1, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 2, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 3, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 4, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 5, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 6, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 7, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 8, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 9, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 10, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 11, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 12, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009001757, 13, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 1, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 2, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 3, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 4, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 5, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 6, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 7, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 8, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 9, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 10, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 11, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 12, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 13, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 14, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 15, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628001758, 16, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 1, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 2, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 3, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 4, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 5, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 6, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 7, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 8, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 9, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 10, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 11, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 12, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 13, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 14, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 15, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210001759, 16, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212001760, 1, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212001760, 2, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212001760, 3, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212001760, 4, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 1, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 2, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 3, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 4, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 5, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 6, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 7, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 8, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 9, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 10, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 11, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 12, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107001761, 13, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000812001762, 1, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000812001762, 2, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001763, 1, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001763, 2, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001763, 3, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007001763, 4, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 1, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 2, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 3, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 4, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 5, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 6, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 7, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 8, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001764, 9, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 1, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 2, 11, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 3, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 4, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 5, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 6, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 7, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 8, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705001765, 9, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 1, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 2, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 3, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 4, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 5, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 6, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 7, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 8, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 9, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 10, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 11, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 12, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 13, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 14, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 15, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 16, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 17, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 18, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311001766, 19, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 1, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 2, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 4, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 5, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 6, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 7, 2, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 8, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 9, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 10, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 11, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009001767, 12, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302001768, 1, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302001768, 2, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302001768, 3, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302001768, 4, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302001768, 5, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 1, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 2, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 3, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 4, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 5, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 6, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 7, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001769, 8, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 1, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 2, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 3, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 4, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 5, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 6, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 7, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 8, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 9, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 10, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220001770, 11, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 1, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 2, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 3, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 4, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 5, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 6, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 7, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001771, 8, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 1, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 2, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 3, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 4, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 5, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 6, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 7, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 8, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 9, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 10, 95, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 11, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103001772, 12, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 1, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 2, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 3, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 4, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 5, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 6, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 7, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 8, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 9, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 10, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 11, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524001773, 12, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001010001774, 1, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001010001774, 2, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001010001774, 3, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001010001774, 4, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 1, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 2, 110, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 3, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 4, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 5, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 6, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 7, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 8, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 9, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 10, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 11, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 12, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724001775, 13, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 1, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 2, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 3, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 4, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 7, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 8, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 9, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 10, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116002138, 11, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511002139, 1, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511002139, 2, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511002139, 3, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511002139, 4, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 1, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 2, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 3, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 4, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 5, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 6, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525002140, 7, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 1, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 2, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 3, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 4, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 5, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 6, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 7, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 8, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 9, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127002141, 10, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 1, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 2, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 3, 99, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 4, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 5, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 6, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 7, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 8, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 9, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 10, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 11, 154, 36, 11, 396);
commit;
prompt 17000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 12, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 13, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 14, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002142, 15, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 1, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 2, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 3, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 4, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 5, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 6, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 7, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 8, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 9, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 10, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002143, 11, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 1, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 2, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 3, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 4, 157, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 5, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 6, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 7, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 8, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 9, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 10, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 11, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906002144, 12, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 1, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 2, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 3, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 4, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 5, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 6, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 7, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 8, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118002145, 9, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117002146, 1, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117002146, 2, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117002146, 3, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117002146, 4, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117002146, 5, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018002147, 1, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018002147, 2, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018002147, 3, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 1, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 2, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 3, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 4, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 5, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 6, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 7, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 8, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 9, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 10, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624002148, 11, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 1, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 2, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 3, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 4, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 5, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 6, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 7, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 8, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 9, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 10, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070503002149, 11, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 1, 16, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 2, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 3, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 4, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 5, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 6, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 7, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 8, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 9, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 10, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 11, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 12, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 13, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 14, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 15, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 16, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 17, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 18, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116002150, 19, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 1, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 2, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 3, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 4, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 5, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 6, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 7, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 8, 1, 50, 3, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 9, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 10, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 11, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002151, 12, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 1, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 2, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 3, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 4, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 5, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 6, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 7, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 8, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 9, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 10, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 11, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220002152, 12, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 1, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 2, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 3, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 4, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 5, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 6, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 7, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 8, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 9, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 10, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 11, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 12, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 13, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 14, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 15, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 16, 147, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029002153, 17, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 1, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 2, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 3, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 4, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 5, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 6, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 7, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 8, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 9, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 10, 138, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 11, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 12, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111002154, 13, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 1, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 2, 63, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 3, 173, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 4, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 5, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 6, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 7, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 8, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 9, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 10, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 11, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 12, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 13, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101015002155, 14, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 1, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 2, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 3, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 4, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 5, 148, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 6, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 7, 32, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 8, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 9, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 10, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 11, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 12, 33, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 13, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412002156, 14, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104002157, 1, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104002157, 2, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104002157, 3, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104002157, 4, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 1, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 2, 188, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 3, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 4, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 5, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 6, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 7, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 8, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 9, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 10, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 11, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 12, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 13, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 14, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 15, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816002158, 16, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 1, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 2, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 3, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 4, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 5, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 6, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 7, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 8, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 9, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113002159, 10, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 1, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 2, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 3, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 4, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 5, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 6, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 7, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 8, 29, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 9, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 10, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 11, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 12, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 13, 14, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 14, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 15, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 16, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328002513, 1, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328002513, 2, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328002513, 3, 101, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328002513, 4, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328002513, 5, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 1, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 2, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 3, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 5, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 6, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 7, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 8, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 9, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 10, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 11, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 12, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 13, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706002514, 14, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527002515, 1, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527002515, 2, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527002515, 3, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527002515, 4, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527002515, 5, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 1, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 2, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 3, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 4, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 5, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 6, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 7, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 8, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 9, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 10, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 11, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 12, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718002516, 13, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 1, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 2, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 3, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 4, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 5, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 6, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 7, 33, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 8, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 9, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002517, 10, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517002518, 1, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517002518, 2, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517002518, 3, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517002518, 4, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 1, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 2, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 3, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 4, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 5, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 6, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 7, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 8, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 9, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 10, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 11, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 12, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 13, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 14, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110216002519, 15, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 1, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 2, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 3, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 4, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 5, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 6, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 7, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 8, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 9, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 10, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 11, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 12, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 13, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 14, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 15, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811002520, 16, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 1, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 2, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 3, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 4, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 5, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827002521, 6, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 1, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 2, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 3, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 4, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 5, 62, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 6, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 7, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 8, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 9, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315002522, 10, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321002523, 1, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321002523, 2, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321002523, 3, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 1, 94, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 2, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 3, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 4, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 5, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 6, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 7, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 8, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 9, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 10, 171, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 11, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 12, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 13, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 14, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 15, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820002524, 16, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 1, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 2, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 3, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 4, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 5, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 6, 186, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 7, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 8, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 9, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 10, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 11, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 12, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 13, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223002525, 14, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 1, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 2, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 3, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 4, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 5, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 6, 19, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 7, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 8, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 9, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 10, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 11, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 12, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 13, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516002526, 14, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 1, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 2, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 3, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 4, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 5, 90, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 6, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 7, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 8, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 9, 91, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 10, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 11, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 12, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 13, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 14, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 15, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 16, 3, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002527, 17, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 1, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 2, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 3, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 4, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 5, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 6, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 7, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 8, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 9, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 10, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012002528, 11, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 1, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 2, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 3, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 4, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 5, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 6, 168, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 7, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 8, 18, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 9, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 10, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 11, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 12, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 13, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518002529, 14, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 1, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 2, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 3, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 4, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 5, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 6, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 7, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 8, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 9, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528002530, 10, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 1, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 2, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 3, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 4, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 5, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 6, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 7, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 8, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 9, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 10, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 11, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 12, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 13, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 14, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615002531, 15, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 1, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 2, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 3, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 4, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 5, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 6, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 7, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 8, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 9, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 10, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 11, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 12, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 13, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 14, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 15, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 16, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 1, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 2, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 3, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 4, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 5, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 6, 156, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928001382, 7, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 1, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 2, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 3, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 4, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 5, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 6, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 7, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 8, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 9, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 10, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 11, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206001383, 12, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001384, 1, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001384, 2, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912001385, 1, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912001385, 2, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912001385, 3, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303001386, 1, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303001386, 2, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303001386, 3, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303001386, 4, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 1, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 2, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 3, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 4, 151, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 5, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 6, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 7, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 8, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 9, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 10, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428001387, 11, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 1, 10, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 2, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 3, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 4, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 5, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 6, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 7, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 8, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 9, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 10, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609001388, 11, 149, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 1, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 2, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 3, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 4, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 5, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 6, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 7, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 8, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 9, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 10, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 11, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 12, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 13, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 14, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126001389, 15, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 1, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 2, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 3, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 4, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 5, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 6, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 7, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 8, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 9, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 10, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204001390, 11, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 1, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 2, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 3, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 4, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 5, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 6, 30, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 7, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 8, 138, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 9, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 10, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 11, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509001391, 12, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 1, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 2, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 3, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 4, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 5, 105, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 6, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 7, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 8, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517001392, 9, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 1, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 2, 160, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 3, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 4, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 5, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 6, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 7, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101001393, 8, 162, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 1, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 2, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 3, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 4, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 5, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 6, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 7, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 8, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715001394, 9, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928001395, 1, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928001395, 2, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928001395, 3, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 1, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 2, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 3, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 4, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 5, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803001396, 6, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 1, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 2, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 3, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 4, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 5, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 6, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 7, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510001397, 8, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 1, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 2, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 3, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 4, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 5, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 6, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 7, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 8, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119001398, 9, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 1, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 2, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 3, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 4, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 5, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 6, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 7, 167, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 8, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 9, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 10, 101, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 11, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 12, 144, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 13, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 14, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 15, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623001399, 16, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021001400, 1, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021001400, 2, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021001400, 3, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 1, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 2, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 3, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 4, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 5, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 6, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 7, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 8, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 9, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 10, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 11, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 12, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 13, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306001401, 14, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 1, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 2, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 3, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 4, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 5, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 6, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 7, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 8, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 9, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 10, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 11, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 12, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 13, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 14, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027001402, 15, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 1, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 2, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 3, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 4, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 5, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 6, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030102001403, 7, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105001404, 1, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105001404, 2, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105001404, 3, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105001404, 4, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105001404, 5, 132, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 1, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 2, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 3, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 4, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 5, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 6, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 7, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 8, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 9, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 10, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004001405, 11, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 1, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 2, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 3, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 4, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 5, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 6, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 7, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 8, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 9, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 10, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 11, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 12, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 13, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 14, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601001406, 15, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 1, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 2, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 3, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 4, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 5, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 6, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 7, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 8, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 9, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 10, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 11, 133, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 12, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 13, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 5, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 6, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 7, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 8, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 9, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 10, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 11, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 12, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 13, 1, 8, 3, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908001776, 14, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 1, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 2, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 3, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 4, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 5, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109001777, 6, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010103001778, 1, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010103001778, 2, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010103001778, 3, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010103001778, 4, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010103001778, 5, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824001779, 1, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824001779, 2, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824001779, 3, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 1, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 2, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 3, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 4, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 5, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 6, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 7, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 8, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 9, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 10, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 11, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 12, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 13, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310001780, 14, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 1, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 2, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 3, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 4, 23, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 5, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 6, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 7, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101001781, 8, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 1, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 2, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 3, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 4, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 5, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 6, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 7, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 8, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 9, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 10, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001782, 11, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 1, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 2, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 3, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 4, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 5, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 6, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 7, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 8, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 9, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 10, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928001783, 11, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 1, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 2, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 3, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 4, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 5, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 6, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 7, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 8, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 9, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 10, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 11, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 12, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218001784, 13, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005001785, 1, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005001785, 2, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005001785, 3, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005001785, 4, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 1, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 2, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 3, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 4, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 5, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 6, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 7, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 8, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 9, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 10, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 11, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 12, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 13, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 14, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 15, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 16, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913001786, 17, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319001787, 1, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319001787, 2, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319001787, 3, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319001787, 4, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020814001788, 1, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020814001788, 2, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020814001788, 3, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020814001788, 4, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020814001788, 5, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 1, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 2, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 3, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 4, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 5, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 6, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 7, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 8, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 9, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 10, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607001789, 11, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 1, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 2, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 3, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 4, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 5, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040626001790, 6, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 1, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 2, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 3, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 4, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 5, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 6, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 7, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 8, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 9, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 10, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 11, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 12, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613001791, 13, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 1, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 2, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 3, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 4, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 5, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 6, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 7, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 8, 16, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 9, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 10, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 11, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 12, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 13, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 14, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 15, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625001792, 16, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 1, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 2, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 3, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 4, 1, 74, 3, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 5, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 6, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 7, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 8, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 9, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 10, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 11, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 12, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 13, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228001793, 14, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226001794, 1, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226001794, 2, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226001794, 3, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226001794, 4, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 1, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 2, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 3, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 4, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 5, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612001795, 6, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 1, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 2, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 3, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 4, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 5, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 6, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 7, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 8, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 9, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 10, 128, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 11, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 12, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 13, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525001796, 14, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502001797, 1, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502001797, 2, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502001797, 3, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 1, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 2, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 3, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 4, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 5, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 6, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 7, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 8, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 9, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 10, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 11, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 12, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 13, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 14, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 15, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 16, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520001798, 17, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 1, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 2, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 3, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 4, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 5, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 6, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 7, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 8, 147, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 9, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 10, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 11, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 12, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 13, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721001799, 14, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628001800, 1, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628001800, 2, 43, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628001800, 3, 189, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628001800, 4, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 1, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 2, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 3, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 4, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 5, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 6, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 6, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 7, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 8, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 9, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 10, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420002160, 11, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 1, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 2, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 3, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 4, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 5, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 6, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 7, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 8, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 9, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 10, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 11, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 12, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 13, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 14, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 15, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110521002161, 16, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 1, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 2, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 3, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 4, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 5, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 6, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 7, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002162, 8, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 1, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 2, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 3, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 4, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 5, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 6, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519002163, 7, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 1, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 2, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 3, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 4, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 5, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 6, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 7, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 8, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 9, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 10, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 11, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930002164, 12, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 1, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 2, 188, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 3, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 4, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 5, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 6, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520002165, 7, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 1, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 2, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 3, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 4, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 5, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 6, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 7, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 8, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 9, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 10, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 11, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 12, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 13, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 14, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002166, 15, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 1, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 2, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 3, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 4, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 5, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 6, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 7, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 8, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 9, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 10, 167, 1, 14, 14);
commit;
prompt 18000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 11, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 12, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626002167, 13, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806002168, 1, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806002168, 2, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806002168, 3, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 1, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 2, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 3, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 4, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 5, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 6, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 7, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 8, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 9, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428002169, 10, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 1, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 2, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 3, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 4, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 5, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423002170, 6, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 1, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 2, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 3, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 4, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 5, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 6, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 7, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 8, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 9, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 10, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219002171, 11, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 1, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 2, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 3, 99, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 4, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 5, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 6, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 7, 71, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 8, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 9, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 10, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 11, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 12, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 13, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 14, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 15, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 16, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028002172, 17, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 1, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 2, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 3, 167, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 4, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 5, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 6, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 7, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609002173, 8, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 1, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 2, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 3, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 4, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 5, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 6, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 7, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 8, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 9, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 10, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 11, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 12, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107002174, 13, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 1, 160, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 2, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 3, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 4, 85, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 5, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 6, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040616002175, 7, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 1, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 2, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 3, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 4, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 5, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 6, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 7, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002176, 8, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002177, 1, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002177, 2, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002177, 3, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002177, 4, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002177, 5, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 1, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 2, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 3, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 4, 157, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 5, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421002178, 6, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 1, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 2, 6, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 3, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 4, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 5, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 6, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 7, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 8, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 9, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206002179, 10, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 1, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 2, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 3, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 4, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 5, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 6, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 7, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 8, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 9, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 10, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728002180, 11, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926002181, 1, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926002181, 2, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926002181, 3, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926002181, 4, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 1, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 2, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 3, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 4, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 5, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223002182, 6, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 1, 180, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 2, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 3, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 4, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 5, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 6, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 7, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 8, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 9, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 10, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 11, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 12, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 13, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 14, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 15, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 16, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513002183, 17, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602002184, 1, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602002184, 2, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602002184, 3, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602002184, 4, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628002185, 1, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628002185, 2, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628002185, 3, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628002185, 4, 119, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 1, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 2, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 3, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 4, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 5, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 5, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 6, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 7, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 8, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 9, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 10, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 11, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 12, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 13, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202002576, 14, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 1, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 2, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 3, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 4, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 5, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 6, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430002577, 7, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 1, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 2, 59, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 3, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 4, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 5, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 6, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 7, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 8, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 9, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061109002578, 10, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 1, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 2, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 3, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 4, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 5, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030903002579, 6, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002580, 1, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002580, 2, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002580, 3, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002580, 4, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 1, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 2, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 3, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 4, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 5, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 6, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 7, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 8, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 9, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 10, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 11, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 12, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 13, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 14, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217002581, 15, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 1, 185, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 2, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 3, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 4, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 5, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 6, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 7, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 8, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 9, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002582, 10, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 1, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 2, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 3, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 4, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 5, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 6, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 7, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 8, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 9, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 10, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 11, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 12, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523002583, 13, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 1, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 2, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 3, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 4, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 5, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 6, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223002584, 7, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 1, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 2, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 3, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 4, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 5, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 6, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 7, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 8, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 9, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 10, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 11, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 12, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523002585, 13, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826002586, 1, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826002586, 2, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826002586, 3, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826002586, 4, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826002586, 5, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 1, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 2, 131, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 3, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 4, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 5, 185, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030429002587, 6, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 1, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 2, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 3, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 4, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 5, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 6, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 7, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 8, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 9, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 10, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 11, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002588, 12, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 1, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 2, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 3, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 4, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 5, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 6, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 7, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 8, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 9, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 10, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 11, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 12, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 13, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 14, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 15, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002589, 16, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 1, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 2, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 3, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 4, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 5, 24, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 6, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 7, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 8, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 9, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 10, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 11, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 12, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 13, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 14, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806002590, 15, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 1, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 2, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 3, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 4, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 5, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 6, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130002591, 7, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002592, 1, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002592, 2, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002592, 3, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002592, 4, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815002592, 5, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 1, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 2, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 3, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 4, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 5, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 6, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 7, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 8, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213002593, 9, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 1, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 2, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 3, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 4, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 5, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705002594, 6, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 1, 122, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 2, 188, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 3, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 4, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 5, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 6, 177, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 7, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 8, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 9, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 10, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 11, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 12, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 13, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 14, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 15, 112, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 16, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 17, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503002595, 18, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 1, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 2, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 3, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 4, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 5, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 6, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 7, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 8, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821002596, 9, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 1, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 2, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 3, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 4, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 5, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 6, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 7, 88, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 8, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 9, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 10, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 11, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229002597, 12, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 1, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 2, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 3, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 4, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 5, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 6, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616002598, 7, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 1, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 2, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 3, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 4, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 5, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 6, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 7, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 8, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 9, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 10, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 11, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405002599, 12, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 1, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 2, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 3, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 4, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 5, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 14, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 15, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105001407, 16, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 1, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 2, 179, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 3, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 4, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 5, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 6, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 7, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 8, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810001408, 9, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 1, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 2, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 3, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 4, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 5, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 6, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 7, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 8, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 9, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 10, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 11, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 12, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 13, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 14, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915001409, 15, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 1, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 2, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 3, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 4, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 5, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 6, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 7, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 8, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 9, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 10, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 11, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 12, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 13, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512001410, 14, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 1, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 2, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 3, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 4, 187, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 5, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418001411, 6, 33, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 1, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 2, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 3, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 4, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 5, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 6, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 7, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 8, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 9, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 10, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 11, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 12, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 13, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 14, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 15, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 16, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601001412, 17, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 1, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 2, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 3, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 4, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 5, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 6, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 7, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 8, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001413, 9, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 1, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 2, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 3, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 4, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 5, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 6, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 7, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907001414, 8, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 1, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 2, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 3, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 4, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 5, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 6, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214001415, 7, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 1, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 2, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 3, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 4, 167, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 5, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 6, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 7, 66, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 8, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 9, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 10, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 11, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 12, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 13, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 14, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 15, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 16, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206001416, 17, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 1, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 2, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 3, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 4, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 5, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 6, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 7, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 8, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208001417, 9, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 1, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 2, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 3, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 4, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 5, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 6, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107001418, 7, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 1, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 2, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 3, 123, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 4, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 5, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 6, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 7, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 8, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 9, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 10, 114, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 11, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 12, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 13, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 14, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712001419, 15, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 1, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 2, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 3, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 4, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 5, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 6, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605001420, 7, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 1, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 2, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 3, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 4, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 5, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 6, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 7, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 8, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 9, 68, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 10, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 11, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 12, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 13, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 14, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 15, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 16, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 17, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331001421, 18, 41, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125001422, 1, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125001422, 2, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125001422, 3, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125001422, 4, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125001422, 5, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218001423, 1, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218001423, 2, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 1, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 2, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 3, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 4, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 5, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 6, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 7, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 8, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 9, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 10, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 11, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 12, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 13, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 14, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516001424, 15, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 1, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 2, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 3, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 4, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 5, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 6, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 7, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 8, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 9, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 10, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 11, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 12, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 13, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 14, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 15, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330001425, 16, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 1, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 2, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 3, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 4, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 5, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 6, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 7, 154, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514001426, 8, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 1, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 2, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 3, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 4, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 5, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 6, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 7, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 8, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 9, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 10, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 11, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 12, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 13, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 14, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 15, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525001427, 16, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 1, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 2, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 3, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 4, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 5, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 6, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 7, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 8, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 9, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 10, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 11, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 12, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 13, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 14, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 15, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 16, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502001801, 7, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 1, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 2, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 3, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 4, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 5, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 6, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630001802, 7, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 1, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 2, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 3, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 4, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 5, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 6, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 7, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 8, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 9, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 10, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 11, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 12, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 13, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128001803, 14, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 1, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 2, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 3, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 4, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 5, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 6, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 7, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 8, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 9, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 10, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 11, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 12, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 13, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929001804, 14, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 1, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 2, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 3, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 4, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 5, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 6, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 7, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 8, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 9, 182, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 10, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 11, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 12, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 13, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 14, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927001805, 15, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 1, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 2, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 3, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 4, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 5, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 6, 135, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 7, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 8, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 9, 12, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 10, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 11, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 12, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 13, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 14, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 15, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216001806, 16, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 1, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 2, 69, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 3, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 4, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 5, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 6, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109001807, 7, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 1, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 2, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 3, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 4, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 5, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 6, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 7, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 8, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 9, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 10, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 11, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 12, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 13, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904001808, 14, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 1, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 2, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 3, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 4, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 5, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 6, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 7, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 8, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050506001809, 9, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 1, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 2, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 3, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 4, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 5, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 6, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 7, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 8, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 9, 138, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 10, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 11, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 12, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429001810, 13, 128, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 1, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 2, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 3, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 4, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 5, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 6, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 7, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 8, 62, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 9, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 10, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 11, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 12, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 13, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 14, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610001811, 15, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 1, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 2, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 3, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 4, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 5, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 6, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 7, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 8, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 9, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 10, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 11, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 12, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 13, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 14, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414001812, 15, 55, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 1, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 2, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 3, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 4, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 5, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 6, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 7, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 8, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 9, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 10, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 11, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 12, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613001813, 13, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 1, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 2, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 3, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 4, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 5, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 6, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 7, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 8, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 9, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529001814, 10, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 1, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 2, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 3, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 4, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 5, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 6, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 7, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 8, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 9, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 10, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 11, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 12, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 13, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 14, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 15, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902001815, 16, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 1, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 2, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 3, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 4, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 5, 104, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026001816, 6, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 1, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 2, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 3, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 4, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 5, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 6, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 7, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 8, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 9, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 10, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 11, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025001817, 12, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 1, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 2, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 3, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 4, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 5, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509001818, 6, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 1, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 2, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 3, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 4, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 5, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 6, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 7, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 8, 82, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 9, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 10, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 11, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103001819, 12, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 1, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 2, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 3, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 4, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 5, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 6, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 7, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225001820, 8, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 1, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 2, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 3, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 4, 158, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 5, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 6, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 7, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 8, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608001821, 9, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 1, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 2, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 3, 131, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 4, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 5, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 6, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 7, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 6, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105002186, 7, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 1, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 2, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 3, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 4, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 5, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 6, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 7, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323002187, 8, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 1, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 2, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 3, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 4, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 5, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 6, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 7, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 8, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 9, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 10, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 11, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 12, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 13, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002188, 14, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002189, 1, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002189, 2, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002189, 3, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002189, 4, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002189, 5, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 1, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 2, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 3, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 4, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 5, 139, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 6, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 7, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 8, 1, 18, 3, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 9, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 10, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 11, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 12, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 13, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 14, 190, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417002190, 15, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 1, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 2, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 3, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 4, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 5, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 6, 180, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215002191, 7, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 1, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 2, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 3, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 4, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 5, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 6, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 7, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 8, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 9, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 10, 1, 8, 3, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 11, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 12, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 13, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 14, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 15, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 16, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 17, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515002192, 18, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 1, 148, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 2, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 3, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 4, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 5, 168, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 6, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 7, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 8, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 9, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 10, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 11, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116002193, 12, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 1, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 2, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 3, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 4, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 5, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 6, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 7, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 8, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 9, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 10, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 11, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006002194, 12, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 1, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 2, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 3, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 4, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 5, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024002195, 6, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 1, 93, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 2, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 3, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 4, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 5, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 6, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 7, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 8, 137, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 9, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 10, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 11, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 12, 169, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 13, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 14, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220002196, 15, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 1, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 2, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 3, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 4, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 5, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 6, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 7, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 8, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 9, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 10, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 11, 58, 62, 8, 496);
commit;
prompt 19000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 12, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 13, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 14, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 15, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 16, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002197, 17, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 1, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 2, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 3, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 4, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 5, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 6, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 7, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 8, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 9, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 10, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 11, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 12, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 13, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 14, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 15, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 16, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 17, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002198, 18, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002199, 1, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002199, 2, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002199, 3, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002199, 4, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002199, 5, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002200, 1, 132, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002200, 2, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002200, 3, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 1, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 2, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 3, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 4, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 5, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 6, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 7, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 8, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 9, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 10, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 11, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 12, 100, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 13, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120411002201, 14, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 1, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 2, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 3, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 4, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 5, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 6, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 7, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405002202, 8, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 1, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 2, 70, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 3, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 4, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 5, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020510002203, 6, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 1, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 2, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 3, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 4, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 5, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 6, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 7, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 8, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108002204, 9, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 1, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 2, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 3, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 4, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 5, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 6, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 7, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027002205, 8, 87, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803002206, 1, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803002206, 2, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803002206, 3, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803002206, 4, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 1, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 2, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 3, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 4, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 5, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 6, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 7, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 8, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506002207, 9, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 1, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 2, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 3, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 4, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 5, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 6, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 7, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414002208, 8, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 1, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 2, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 3, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 4, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 5, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 6, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 7, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 8, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 9, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 10, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 11, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 12, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 13, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 14, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 15, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924002485, 6, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 1, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 2, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 3, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 4, 170, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 5, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 6, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 7, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 8, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 9, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 10, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 11, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 12, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 13, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204002486, 14, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 1, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 2, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 3, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 4, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 5, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 6, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 7, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112002487, 8, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 1, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 2, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 3, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 4, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 5, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 6, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 7, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 8, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 9, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 10, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 11, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 12, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606002488, 13, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 1, 4, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 2, 89, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 3, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 4, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 5, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623002489, 6, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613002490, 1, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613002490, 2, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 1, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 2, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 3, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 4, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 5, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 6, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 7, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 8, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 9, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104002491, 10, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 1, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 2, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 3, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 4, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 5, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 6, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 7, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 8, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 9, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214002492, 10, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 1, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 2, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 3, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 4, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 5, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 6, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 7, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 8, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 9, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 10, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015002493, 11, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420002494, 1, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420002494, 2, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420002494, 3, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420002494, 4, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 1, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 2, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 3, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 4, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 5, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 6, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 7, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 8, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 9, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 10, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302002495, 11, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 1, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 2, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 3, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 4, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 5, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 6, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 7, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 8, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 9, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 10, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 11, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 12, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 13, 137, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910002496, 14, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810002497, 1, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810002497, 2, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810002497, 3, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 1, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 2, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 3, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 4, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 5, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119002498, 6, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 1, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 2, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 3, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 4, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 5, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 6, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804002499, 7, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 1, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 2, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 3, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 4, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 5, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 6, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 7, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 8, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 9, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 10, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 11, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 12, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723002500, 13, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106002501, 1, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106002501, 2, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106002501, 3, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 1, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 2, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 3, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 4, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 5, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 6, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002502, 7, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 1, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 2, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 3, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 4, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 5, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 6, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 7, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 8, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 9, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 10, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716002503, 11, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 1, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 2, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 3, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 4, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 5, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517002504, 6, 57, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 1, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 2, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 3, 144, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 4, 153, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 5, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 6, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 7, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 8, 4, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104002505, 9, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 1, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 2, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 3, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 4, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 5, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 6, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 7, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 8, 99, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 9, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 10, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 11, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 12, 47, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106002506, 13, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 1, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 2, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 3, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 4, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 5, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 6, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 7, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 8, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 9, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 10, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 11, 23, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 12, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 13, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 14, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225002507, 15, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 1, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 2, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 3, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 4, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 5, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 6, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 7, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 8, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 9, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 10, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 11, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225002508, 12, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 1, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 2, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 3, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 4, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 5, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 6, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 7, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 8, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 9, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 10, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316002509, 11, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 1, 147, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 2, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 3, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 4, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 6, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 7, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407002510, 8, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 1, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 2, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 3, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 4, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 5, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222002511, 6, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 1, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 2, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 3, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 4, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506002512, 5, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416001428, 17, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 1, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 2, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 3, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 4, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 5, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 6, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 7, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 8, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 9, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 10, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 11, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 12, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 13, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 14, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 15, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118001429, 16, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 1, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 2, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 3, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 4, 169, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 5, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 6, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 7, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 8, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 9, 100, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 10, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 11, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020001430, 12, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 1, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 2, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 3, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 4, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 5, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 6, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 7, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 8, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 9, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 10, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 11, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226001431, 12, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 1, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 2, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 3, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 4, 48, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 5, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 6, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001432, 7, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 1, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 2, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 3, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 4, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 5, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 6, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 7, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208001433, 8, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 1, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 2, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 3, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 4, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 5, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 6, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 7, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 8, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 9, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 10, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 11, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124001434, 12, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 1, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 2, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 3, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 4, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 5, 79, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328001435, 6, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 1, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 2, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 3, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 4, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 5, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 6, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 7, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 8, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 9, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 10, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 11, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320001436, 12, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 1, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 2, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 3, 110, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 4, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 5, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 6, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 7, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 8, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 9, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 10, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 11, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 12, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211001437, 13, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 1, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 2, 136, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 3, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 4, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 5, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 6, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 7, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 8, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 9, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 10, 180, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 11, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 12, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 13, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106001438, 14, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626001439, 1, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626001439, 2, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626001439, 3, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626001439, 4, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626001439, 5, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 1, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 2, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 3, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 4, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 5, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 6, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 7, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 8, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 9, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 10, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601001440, 11, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 1, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 2, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 3, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 4, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 5, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 6, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 7, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 8, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 9, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 10, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 11, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 12, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 13, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 14, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 15, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122001441, 16, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 1, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 2, 173, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 3, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 4, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 5, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 6, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 7, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710001442, 8, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 1, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 2, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 3, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 4, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 5, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007001443, 6, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 1, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 2, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 3, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 4, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 5, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 6, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 7, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 8, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 9, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 10, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 11, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 12, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 13, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 14, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 15, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 16, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207001444, 17, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 1, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 2, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 3, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 4, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 5, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 6, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 7, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 8, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 9, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 10, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 11, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 12, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 13, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 14, 185, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401001445, 15, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 1, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 2, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 3, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 4, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 5, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 6, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 7, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 8, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 9, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 10, 155, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624001446, 11, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 1, 48, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 2, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 3, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 4, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 5, 147, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 6, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 7, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 8, 191, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 9, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 10, 80, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 11, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 12, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 13, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 14, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816001447, 15, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 1, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 2, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 3, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 4, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 5, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 6, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 7, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 8, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 9, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 10, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506001448, 11, 152, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 1, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 2, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 3, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 4, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 5, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 6, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 7, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 8, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070109001449, 9, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730001450, 1, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730001450, 2, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 8, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 9, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 10, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 11, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 12, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 13, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 14, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 15, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002001822, 16, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 1, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 2, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 3, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 4, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 5, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 6, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 7, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 8, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707001823, 9, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 1, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 2, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 3, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 4, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 5, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 6, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 7, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 8, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 9, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 10, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 11, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 12, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 13, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 14, 48, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 15, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 16, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214001824, 17, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 1, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 2, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 3, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 4, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 5, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 6, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501001825, 7, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 1, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 2, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 3, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 4, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 5, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 6, 79, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 7, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 8, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 9, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 10, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403001826, 11, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 1, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 2, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 3, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 4, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 5, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204001827, 6, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 1, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 2, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 3, 159, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 4, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 5, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 6, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 7, 122, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 8, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 9, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 10, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 11, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 12, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 13, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911001828, 14, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 1, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 2, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 3, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 4, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 5, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 6, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113001829, 7, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 1, 99, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 2, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 3, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 4, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 5, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 6, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 7, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 8, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 9, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 10, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 11, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 12, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 13, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 14, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504001830, 15, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 1, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 2, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 3, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 4, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 5, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 6, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 7, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 8, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 9, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 10, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 11, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 12, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 13, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 14, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 15, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 16, 86, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508001831, 17, 22, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 1, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 2, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 3, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 4, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 5, 101, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 6, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901001832, 7, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 1, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 2, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 3, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 4, 191, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 5, 76, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 6, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 7, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 8, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 9, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 10, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 11, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 12, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 13, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128001833, 14, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 1, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 2, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 3, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 4, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 5, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 6, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108001834, 7, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 1, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 2, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 3, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 4, 123, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 5, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 6, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 7, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 8, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204001835, 9, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 1, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 2, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 3, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 4, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 5, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 6, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 7, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 8, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 9, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 10, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722001836, 11, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 1, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 2, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 3, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 4, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 5, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011001837, 6, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 1, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 2, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 3, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 4, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 5, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 6, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 7, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220001838, 8, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 1, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 2, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 3, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 4, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 5, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222001839, 6, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 1, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 2, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 3, 142, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 4, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 5, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 6, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 7, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 8, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 9, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513001840, 10, 27, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 1, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 2, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 3, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 4, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 5, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 6, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 7, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 8, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 9, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 10, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 11, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 12, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080705001841, 13, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022001842, 1, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022001842, 2, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022001842, 3, 50, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022001842, 4, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022001842, 5, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 1, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 2, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 3, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 4, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 5, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 6, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 7, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403001843, 8, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 1, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 2, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 3, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 4, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 5, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 6, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 7, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 8, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 9, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 10, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 11, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 12, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001844, 13, 154, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222001845, 1, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222001845, 2, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222001845, 3, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222001845, 4, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 1, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 2, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 3, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 4, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 5, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 6, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 16, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203002209, 17, 130, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023002210, 1, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023002210, 2, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023002210, 3, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023002210, 4, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023002210, 5, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 1, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 2, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 3, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 4, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 5, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522002211, 6, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 1, 115, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 2, 172, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 3, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 4, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 5, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 6, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002212, 7, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801002213, 1, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801002213, 2, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801002213, 3, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801002213, 4, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 1, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 2, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 3, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 4, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 5, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 6, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 7, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512002214, 8, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 1, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 2, 21, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 3, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 4, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 5, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 6, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 7, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 8, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 9, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 10, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 11, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 12, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117002215, 13, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 1, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 2, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 3, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 4, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 5, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 6, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 7, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 8, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002216, 9, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 1, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 3, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 4, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 5, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 6, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 7, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 8, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 9, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 10, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 11, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 12, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 13, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 14, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002217, 15, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002218, 1, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002218, 2, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002218, 3, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002218, 4, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 1, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 2, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 3, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 4, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 5, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 6, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 7, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 8, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 9, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 10, 59, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 11, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 12, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 13, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 14, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426002219, 15, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 1, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 2, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 3, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 4, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 5, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 6, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 7, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 8, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523002220, 9, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 1, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 2, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 3, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 4, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 5, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 6, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 7, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 8, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 9, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 10, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 11, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 12, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 13, 156, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 14, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100429002221, 15, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 1, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 2, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 3, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 4, 92, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 5, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 6, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 7, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 8, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 9, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 10, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 11, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 12, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825002222, 13, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 1, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 2, 152, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 3, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 4, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 5, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 6, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 7, 107, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 8, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 9, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 10, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 11, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 12, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 13, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 14, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 15, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 16, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213002223, 17, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 1, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 2, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 3, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 4, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 5, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 6, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 7, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 8, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 9, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 10, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 11, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 12, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 13, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921002224, 14, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002225, 1, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002225, 2, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002225, 3, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807002225, 4, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 1, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 2, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 3, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 4, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 5, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 6, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516002226, 7, 71, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 1, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 2, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 3, 149, 85, 13, 1105);
commit;
prompt 20000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 4, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 5, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 6, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 7, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 8, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619002227, 9, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 1, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 2, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 3, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 4, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 5, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 6, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 7, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 8, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 9, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 10, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 11, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 12, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 13, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 14, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124002228, 15, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 1, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 2, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 3, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 4, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 5, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 6, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 7, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 8, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 9, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 10, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 11, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 12, 159, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 13, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123002229, 14, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 1, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 2, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 3, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 4, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 5, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720002230, 6, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 1, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 2, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 3, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 4, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 5, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 6, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 7, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 8, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 9, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 10, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 11, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 12, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002231, 13, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 1, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 2, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 3, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 4, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 5, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 6, 2, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 7, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 8, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 9, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 10, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 11, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125002232, 12, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 1, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 2, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 3, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 17, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011002532, 18, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 1, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 2, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 3, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 4, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 5, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 6, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 7, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 8, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 9, 185, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 10, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 11, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 12, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620002533, 13, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002534, 1, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417002534, 2, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 1, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 2, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 3, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 4, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 5, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 6, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 7, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 8, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 9, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915002535, 10, 104, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 1, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 2, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 3, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 4, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 5, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 6, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 7, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 8, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 9, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 10, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913002536, 11, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 1, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 2, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 3, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 4, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 5, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 6, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 7, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 8, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 9, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 10, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 11, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 12, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 13, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725002537, 14, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 1, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 2, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 3, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 4, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 5, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 6, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 7, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 8, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 9, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 10, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 11, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113002538, 12, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111002539, 1, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111002539, 2, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111002539, 3, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 1, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 2, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 3, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 4, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 5, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 6, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 7, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 8, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 9, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 10, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 11, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 12, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 13, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 14, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 15, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 16, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 17, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 18, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327002540, 19, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 1, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 2, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 3, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 4, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 5, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 6, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 7, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408002541, 8, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 1, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 2, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 3, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 4, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 5, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 6, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 7, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 8, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 9, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 10, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 11, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 12, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 13, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506002542, 14, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 1, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 2, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 3, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 4, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 5, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 6, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227002543, 7, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 1, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 2, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 3, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 4, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 5, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 6, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 7, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 8, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 9, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 10, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 11, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 12, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 13, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021002544, 14, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 1, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 2, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 3, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 4, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 5, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 6, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 7, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 8, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 9, 64, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 10, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 11, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 12, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 13, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 14, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 15, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002545, 16, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 1, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 2, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 3, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 4, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 5, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 6, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 7, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 8, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 9, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 10, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 11, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 12, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 13, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 14, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927002546, 15, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 1, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 2, 1, 27, 3, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 3, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 4, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 5, 40, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 6, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 7, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 8, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 9, 84, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 10, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 11, 20, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 12, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 13, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 14, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 15, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 16, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614002547, 17, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 1, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 2, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 3, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 4, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 5, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 6, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 7, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 8, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116002548, 9, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 1, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 2, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 3, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 4, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 5, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 6, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 7, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113002549, 8, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020619002550, 1, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020619002550, 2, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020619002550, 3, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020619002550, 4, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020619002550, 5, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 1, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 2, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 3, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 4, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 5, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 6, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228002551, 7, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 1, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 2, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 3, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 4, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 5, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 6, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 7, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 8, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 9, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 10, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 11, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 12, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 13, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 14, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 15, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 16, 156, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 17, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926002552, 18, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 1, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 2, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 3, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 4, 50, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 5, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 6, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 7, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 8, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 9, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 10, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 11, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 12, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 13, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119002553, 14, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616002554, 1, 31, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730001450, 3, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118001451, 1, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118001451, 2, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 1, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 2, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 3, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 4, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 5, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 6, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 7, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 8, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 9, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 10, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 11, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 12, 133, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910001452, 13, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 1, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 2, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 3, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 4, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 5, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 6, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 7, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 8, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 9, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 10, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 11, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 12, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 13, 132, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 14, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 15, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 16, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130205001453, 17, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 1, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 2, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 3, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 4, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 5, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 6, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 7, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 8, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 9, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 10, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 11, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 12, 73, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 13, 8, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 14, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 15, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220001454, 16, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 1, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 2, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 3, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 4, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 5, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 6, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604001455, 7, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 1, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 2, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 3, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 4, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 5, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 6, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 7, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 8, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 9, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 10, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 11, 27, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 12, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 13, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 14, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 15, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217001456, 16, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 1, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 2, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 3, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 4, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 5, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901001457, 6, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 1, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 2, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 3, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 4, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 5, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 6, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 7, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 8, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 9, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 10, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 11, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 12, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 13, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628001458, 14, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 1, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 2, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 3, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 4, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 5, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 6, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001459, 7, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125001460, 1, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125001460, 2, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125001460, 3, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125001460, 4, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125001460, 5, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 1, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 2, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 3, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 4, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 5, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 6, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 7, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 8, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 9, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 10, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 11, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 12, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331001461, 13, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 1, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 2, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 3, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 4, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 5, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 6, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 7, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 8, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 9, 9, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 10, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524001462, 11, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 1, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 2, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 3, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 4, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 5, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 6, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 7, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104001463, 8, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 1, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 2, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 3, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 4, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 5, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 6, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 7, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103001464, 8, 110, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 1, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 2, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 3, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 4, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 5, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 6, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 7, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 8, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 9, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 10, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 11, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 12, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 13, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 14, 138, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130001465, 15, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 1, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 2, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 3, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 4, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 5, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 6, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 7, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 8, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 9, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 10, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211001466, 11, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 1, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 2, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 3, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 4, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 5, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 6, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 7, 81, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 8, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 9, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 10, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 11, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609001467, 12, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221001468, 1, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221001468, 2, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221001468, 3, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221001468, 4, 191, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221001468, 5, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 1, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 2, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 3, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 4, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 5, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 6, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 7, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302001469, 8, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 1, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 2, 97, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 3, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 4, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 5, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 6, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 7, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 8, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208001470, 9, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 1, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 2, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 3, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 4, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 5, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 6, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 7, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629001471, 8, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 1, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 2, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 3, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 4, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 5, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 6, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 7, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 8, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 9, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 10, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125001472, 11, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 1, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 2, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 3, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 4, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 5, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 6, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 7, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 8, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 9, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 10, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 11, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 12, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 13, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 14, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 15, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 16, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 7, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 8, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 9, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001846, 10, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207001847, 1, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207001847, 2, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 1, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 2, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 3, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 4, 40, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 5, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 6, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 7, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 8, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312001848, 9, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 1, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 2, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 3, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 4, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 5, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 6, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 7, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 8, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 9, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 10, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 11, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070405001849, 12, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 1, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 2, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 3, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 4, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 5, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 6, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406001850, 7, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706001851, 1, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706001851, 2, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 1, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 2, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 3, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 4, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 5, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 6, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 7, 188, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 8, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 9, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530001852, 10, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001853, 1, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001853, 2, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001853, 3, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515001853, 4, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 1, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 2, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 3, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 4, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 5, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 6, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213001854, 7, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 1, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 2, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 3, 154, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 4, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 5, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 6, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 7, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 8, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 9, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 10, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 11, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 12, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 13, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 14, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 15, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 16, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 17, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507001855, 18, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 1, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 2, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 3, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 4, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 5, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 6, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 7, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414001856, 8, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 1, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 2, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 3, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 4, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 5, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 6, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 7, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 8, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 9, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 10, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 11, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 12, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 13, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 14, 106, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 15, 95, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131001857, 16, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 1, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 2, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 3, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 4, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 5, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 6, 71, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 7, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 8, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 9, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 10, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 11, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 12, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 13, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 14, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 15, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709001858, 16, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 1, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 2, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 3, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 4, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 5, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 6, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 7, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 8, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 9, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001859, 10, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 1, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 2, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 3, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 4, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 5, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 6, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 7, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 8, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 9, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 10, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126001860, 11, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 1, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 2, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 3, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 4, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 5, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 6, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 7, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 8, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 9, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 10, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 11, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413001861, 12, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 1, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 2, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 3, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 4, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 5, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 6, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 7, 5, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 8, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 9, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 10, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 11, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 12, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 13, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 14, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 15, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227001862, 16, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 1, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 2, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 3, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 4, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 5, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 6, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 7, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 8, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 9, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 10, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 11, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831001863, 12, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 1, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 2, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 3, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 4, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 5, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 6, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 7, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 8, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125001864, 9, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 1, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 2, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 3, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 4, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 5, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203001865, 6, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 1, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 2, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 3, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 4, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 5, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 6, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 7, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 8, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 9, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 10, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 11, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 12, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 13, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 14, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 15, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 16, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001866, 17, 182, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 1, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 2, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 3, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 4, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 5, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010611001867, 6, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 1, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 2, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 3, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 4, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 5, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 6, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 7, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 8, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 9, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 10, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 11, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 12, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818001868, 13, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 1, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 2, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 3, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 4, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 5, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 6, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 7, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 8, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 9, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111001869, 10, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 1, 99, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 2, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 4, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 5, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 6, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 7, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 8, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 9, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 10, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924002233, 11, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 1, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 2, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 3, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 4, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 5, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 6, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 7, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 8, 19, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 9, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 10, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 11, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 12, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 13, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 14, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 15, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811002234, 16, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 1, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 2, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 3, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 4, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 5, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 6, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 7, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 8, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 9, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524002235, 10, 20, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 1, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 2, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 3, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 4, 166, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 5, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 6, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 7, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 8, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 9, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 10, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 11, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526002236, 12, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 1, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 2, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 3, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 4, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 5, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 6, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 7, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 8, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 9, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080121002237, 10, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 1, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 2, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 3, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 4, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 5, 130, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 6, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 7, 20, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 8, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 9, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 10, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 11, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 12, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 13, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 14, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 15, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604002238, 16, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 1, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 2, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 3, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 4, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 5, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 6, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 7, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 8, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 9, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 10, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 11, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 12, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 13, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 14, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 15, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 16, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129002239, 17, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 1, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 2, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 3, 45, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 4, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 5, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 6, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 7, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 8, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 9, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825002240, 10, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 1, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 2, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 3, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 4, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 5, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 6, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 7, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 8, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 9, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 10, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 11, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912002241, 12, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 1, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 2, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 3, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 4, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 5, 55, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 6, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 7, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 8, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 9, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226002242, 10, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 1, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 2, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 3, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 4, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 5, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 6, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 7, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 8, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 9, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 10, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 11, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 12, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 13, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116002243, 14, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 1, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 2, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 3, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 4, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 5, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 6, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 7, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 8, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 9, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 10, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 11, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 12, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 13, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825002244, 14, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712002245, 1, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712002245, 2, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712002245, 3, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712002245, 4, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023002246, 1, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023002246, 2, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023002246, 3, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023002246, 4, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 1, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 2, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 3, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 4, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 5, 183, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 6, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 7, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 8, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 9, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 10, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 11, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 12, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 13, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002247, 14, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 1, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 2, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 3, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 4, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 5, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 6, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 7, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 8, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 9, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 10, 1, 13, 3, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 11, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 12, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108002248, 13, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 1, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 2, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 3, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 4, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 5, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 6, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 7, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 8, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 9, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 10, 41, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 11, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 12, 30, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723002249, 13, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 1, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 2, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 3, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 4, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 5, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225002250, 6, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 1, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 2, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 3, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 4, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 5, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 6, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 7, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 8, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 9, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 10, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 11, 114, 13, 9, 117);
commit;
prompt 21000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 12, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225002251, 13, 27, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 1, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 2, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 3, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 4, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 5, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 6, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106002252, 7, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 1, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 2, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 3, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 4, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 5, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 6, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 7, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 8, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 9, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 10, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 11, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 12, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 13, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 14, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104002253, 15, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002254, 1, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 3, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 4, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 5, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 6, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318001101, 7, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 1, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 2, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 3, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 4, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 5, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 6, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 7, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 8, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 9, 22, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 10, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 11, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 12, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 13, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903001102, 14, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 1, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 2, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 3, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 4, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 5, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 6, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 7, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 8, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 9, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 10, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 11, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 12, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 13, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 14, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 15, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131001103, 16, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 1, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 2, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 3, 10, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 4, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 5, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 6, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 7, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 8, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 9, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 10, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 11, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 12, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 13, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 14, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 15, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 16, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108001104, 17, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 1, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 2, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 3, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 4, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 5, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 6, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 7, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 8, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 9, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 10, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 11, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 12, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 13, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 14, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322001105, 15, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 1, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 2, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 3, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 4, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 5, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230001106, 6, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 1, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 2, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 3, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 4, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 5, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 6, 25, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 7, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 8, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623001107, 9, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 1, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 2, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 3, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 4, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 5, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 6, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 7, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 8, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 9, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 10, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 11, 90, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120001108, 12, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 1, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 2, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 3, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 4, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 5, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 6, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 7, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607001109, 8, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 1, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 2, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 3, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 4, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 5, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 6, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 7, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226001110, 8, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 1, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 2, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 3, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 4, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 5, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719001111, 6, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809001112, 1, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809001112, 2, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809001112, 3, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809001112, 4, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 1, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 2, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 3, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 4, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 5, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 6, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 7, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 8, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 9, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 10, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 11, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 12, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112001113, 13, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 1, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 2, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 3, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 4, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 5, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 6, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 7, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 8, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 9, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 10, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 11, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 12, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 13, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 14, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 15, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 16, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114001114, 17, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000803001115, 1, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000803001115, 2, 121, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000803001115, 3, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 1, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 2, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 3, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 4, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 5, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 6, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 7, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 8, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001116, 9, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 1, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 2, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 3, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 4, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 5, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830001117, 6, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 1, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 2, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 3, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 4, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 5, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 6, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 7, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 8, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 9, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131001118, 10, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 1, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 2, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 3, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 4, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 5, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 6, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 7, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 8, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 9, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 10, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 11, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 12, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 13, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 14, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426001119, 15, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 1, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 2, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 3, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 4, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 5, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 6, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 7, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 8, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 9, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 10, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 11, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 12, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 13, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 14, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404001120, 15, 159, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 1, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 2, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 3, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 4, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 5, 106, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 6, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102001121, 7, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 1, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 2, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 3, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 4, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 5, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 6, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 7, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 8, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 9, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 10, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 11, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 12, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 13, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513001122, 14, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 1, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 2, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 3, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 4, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 5, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 6, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 7, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 8, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 9, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 10, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 17, 179, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104001473, 18, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 1, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 2, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 3, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 4, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 5, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 6, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 7, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 8, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 9, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 10, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 11, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 12, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 13, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014001474, 14, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716001475, 1, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716001475, 2, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716001475, 3, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716001475, 4, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716001475, 5, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 1, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 2, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 3, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 4, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 5, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 6, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 7, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 8, 115, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 9, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 10, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 11, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620001476, 12, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 1, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 2, 126, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 3, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 4, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 5, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 6, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120001477, 7, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 1, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 2, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 3, 20, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 4, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 5, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 6, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 7, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 8, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 9, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 10, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 11, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 12, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 13, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 14, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 15, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 16, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 17, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128001478, 18, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 1, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 2, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 3, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 4, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 5, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 6, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 7, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 8, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 9, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 10, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 11, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 12, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508001479, 13, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 1, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 2, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 3, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 4, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 5, 191, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 6, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 7, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 8, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 9, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 10, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 11, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 12, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 13, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 14, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 15, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210001480, 16, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 1, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 2, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 3, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 4, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 5, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 6, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903001481, 7, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406001482, 1, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406001482, 2, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406001482, 3, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406001482, 4, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406001482, 5, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 1, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 2, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 3, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 4, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 5, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 6, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 7, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 8, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 9, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 10, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 11, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715001483, 12, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 1, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 2, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 3, 192, 62, 18, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 4, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 5, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 6, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 7, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 8, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 9, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 10, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713001484, 11, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 1, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 2, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 3, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 4, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 5, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 6, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 7, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 8, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124001485, 9, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 1, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 2, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 3, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 4, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 5, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 6, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 7, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 8, 43, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 9, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 10, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113001486, 11, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 1, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 2, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 3, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 4, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 5, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 6, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 7, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 8, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 9, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 10, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 11, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 12, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 13, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611001487, 14, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 1, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 2, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 3, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 4, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 5, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 6, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 7, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 8, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 9, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 10, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822001488, 11, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 1, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 2, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 3, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 4, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 5, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 6, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 7, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 8, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 9, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 10, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002001489, 11, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001490, 1, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001490, 2, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001490, 3, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823001490, 4, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 1, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 2, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 3, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 4, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 5, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 6, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 7, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218001491, 8, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620001492, 1, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620001492, 2, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620001492, 3, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620001492, 4, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620001492, 5, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 1, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 2, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 3, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 4, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 5, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 6, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 7, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402001493, 8, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 1, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 2, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 3, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 4, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 5, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 6, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 7, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 8, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 9, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 10, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 11, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 12, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 13, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 14, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 15, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231001494, 16, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 1, 22, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 2, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 3, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 4, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 5, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 6, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 7, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 8, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 9, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 10, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 11, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 12, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 13, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 14, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 15, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929001495, 16, 141, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 1, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 2, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 3, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 4, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 3, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 4, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 5, 112, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 6, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 7, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306001870, 8, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 1, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 2, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 3, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 4, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 5, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 6, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 7, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 8, 76, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 9, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 10, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 11, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827001871, 12, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 1, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 2, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 3, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 4, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 5, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905001872, 6, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 1, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 2, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 3, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 4, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 5, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 6, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 7, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 8, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 9, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 10, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 11, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 12, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 13, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 14, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 15, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803001873, 16, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 1, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 2, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 3, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 4, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 5, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 6, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 7, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 8, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 9, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 10, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 11, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 12, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204001874, 13, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815001875, 1, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815001875, 2, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815001875, 3, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815001875, 4, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113001876, 1, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113001876, 2, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113001876, 3, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031001877, 1, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031001877, 2, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031001877, 3, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031001877, 4, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 1, 66, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 2, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 3, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 4, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 5, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717001878, 6, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201001879, 1, 149, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201001879, 2, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 1, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 2, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 3, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 4, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 5, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 6, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 7, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 8, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 9, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021001880, 10, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 1, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 2, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 3, 91, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 4, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 5, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 6, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 7, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 8, 34, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 9, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713001881, 10, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 1, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 2, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 3, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 4, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 5, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 6, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021001882, 7, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116001883, 1, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116001883, 2, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116001883, 3, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116001883, 4, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116001883, 5, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 1, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 2, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 3, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 4, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 5, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 6, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 7, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 8, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 9, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 10, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 11, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 12, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 13, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 14, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 15, 104, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711001884, 16, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925001885, 1, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925001885, 2, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925001885, 3, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925001885, 4, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 1, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 2, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 3, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 4, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 5, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 6, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 7, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 8, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 9, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 10, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 11, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 12, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001886, 13, 188, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 1, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 2, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 3, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 4, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 5, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 6, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 7, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 8, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050816001887, 9, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 1, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 2, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 3, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 4, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 5, 189, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129001888, 6, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325001889, 1, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325001889, 2, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325001889, 3, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 1, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 2, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 3, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 4, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 5, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123001890, 6, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 1, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 2, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 3, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 4, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 5, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 6, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 7, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 8, 121, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 9, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 10, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 11, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 12, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 13, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 14, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 15, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217001891, 16, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 1, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 2, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 3, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 4, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 5, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 6, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 7, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130001892, 8, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 1, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 2, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 3, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 4, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 5, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022001893, 6, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909001894, 1, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909001894, 2, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909001894, 3, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909001894, 4, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909001894, 5, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806001895, 1, 37, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806001895, 2, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806001895, 3, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806001895, 4, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806001895, 5, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 1, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 2, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 3, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 4, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 5, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 6, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 7, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 8, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 9, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 10, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 11, 142, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 12, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 13, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 14, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002001896, 15, 99, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 1, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 2, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 3, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 4, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 5, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 6, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 7, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 8, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 9, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 10, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 11, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226001897, 12, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 1, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 2, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 3, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 4, 36, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 5, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 6, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 7, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525001898, 8, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 1, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 2, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 3, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002254, 2, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002254, 3, 81, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530002255, 1, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530002255, 2, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 1, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 2, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 3, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 4, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 5, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 6, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 7, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 8, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 9, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 10, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 11, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 12, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 13, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 14, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 15, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513002256, 16, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302002257, 1, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302002257, 2, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302002257, 3, 135, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302002257, 4, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629002258, 1, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629002258, 2, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629002258, 3, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 1, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 2, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 3, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 4, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 5, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 6, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 7, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 8, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 9, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 10, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 11, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 12, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 13, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 14, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 15, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819002259, 16, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 1, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 2, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 3, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 4, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 5, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 6, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 7, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 8, 157, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 9, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 10, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805002260, 11, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 1, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 2, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 3, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 4, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 5, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 6, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 7, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 8, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 9, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 10, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 11, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 12, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016002261, 13, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609002262, 1, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609002262, 2, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609002262, 3, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609002262, 4, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 1, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 2, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 3, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 4, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 5, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 6, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 7, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 8, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 9, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 10, 20, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 11, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 12, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 13, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 14, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 15, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201002263, 16, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 1, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 2, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 3, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 4, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 5, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002264, 6, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 1, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 2, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 3, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 4, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 5, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 6, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 7, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 8, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 9, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 10, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404002265, 11, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002266, 1, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002266, 2, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226002266, 3, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 1, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 2, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 3, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 4, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 5, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 6, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 7, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 8, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 9, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 10, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 11, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 12, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 13, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 14, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 15, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606002267, 16, 148, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 1, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 2, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 3, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 4, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 5, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 6, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 7, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 8, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 9, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 10, 70, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 11, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 12, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 13, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 14, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 15, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 16, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626002268, 17, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 1, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 2, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 3, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 4, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 5, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 6, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 7, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 8, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 9, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 10, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 11, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 12, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824002269, 13, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 1, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 2, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 3, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 4, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 5, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 6, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 7, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 8, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 9, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015002270, 10, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626002271, 1, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626002271, 2, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626002271, 3, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626002271, 4, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626002271, 5, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 1, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 2, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 3, 1, 64, 3, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 4, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 5, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 6, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 7, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 8, 64, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 9, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 10, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 11, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 12, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 13, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 14, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 15, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 16, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 17, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304002272, 18, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 2, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 3, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 4, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 5, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 6, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 7, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 8, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429002273, 9, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 1, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 2, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 3, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 4, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 5, 54, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 6, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 7, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 8, 192, 47, 18, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 9, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 10, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708002274, 11, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 1, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 2, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 3, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 4, 128, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 5, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002275, 6, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 1, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 2, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 3, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 4, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 5, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 6, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 7, 154, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 8, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 9, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 10, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 11, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 12, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 13, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 14, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 15, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 16, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 17, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307002276, 18, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 1, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 2, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 3, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 4, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 5, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 6, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 7, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 8, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 9, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 11, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 12, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 13, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 14, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209001123, 15, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 1, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 2, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 3, 191, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 4, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 5, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 6, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 7, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117001124, 8, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 1, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 2, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 3, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 4, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 5, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 6, 4, 18, 6, 108);
commit;
prompt 22000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 7, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 8, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 9, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 10, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 11, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 12, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 13, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026001125, 14, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 1, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 2, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 3, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 4, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 5, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 6, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 7, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 8, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 9, 83, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 10, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 11, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 12, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 13, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 14, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120327001126, 15, 51, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 1, 140, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 2, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 3, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 4, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 5, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 6, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 7, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215001127, 8, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 1, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 2, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 3, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 4, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 5, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 6, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 7, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 8, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 9, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 10, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 11, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 12, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 13, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 14, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 15, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615001128, 16, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 1, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 2, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 3, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 4, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 5, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 6, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 7, 55, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 8, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103001129, 9, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 1, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 2, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 3, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 4, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 5, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 6, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 7, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 8, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 9, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 10, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 11, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 12, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 13, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314001130, 14, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 1, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 2, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 3, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 4, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 5, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 6, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 7, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 8, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 9, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 10, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 11, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 12, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 13, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 14, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 15, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 16, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225001131, 17, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 1, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 2, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 3, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 4, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 5, 40, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 6, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128001132, 7, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 1, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 2, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 3, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 4, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 5, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023001133, 6, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 1, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 2, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 3, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 4, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 5, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 6, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 7, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 8, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 9, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 10, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 11, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 12, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 13, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 14, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 15, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 16, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 17, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730001134, 18, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 1, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 2, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 3, 56, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 4, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 5, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 6, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 7, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 8, 174, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 9, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 10, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 11, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 12, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 13, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 14, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804001135, 15, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 1, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 2, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 3, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 4, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 5, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 6, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 7, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 8, 86, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 9, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 10, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022001136, 11, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 1, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 2, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 3, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 4, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 5, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 6, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 7, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 8, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 9, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127001137, 10, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001138, 1, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001138, 2, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001138, 3, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001138, 4, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001138, 5, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113001139, 1, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113001139, 2, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113001139, 3, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113001139, 4, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113001139, 5, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 1, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 2, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 3, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 4, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 5, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 6, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 7, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 8, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926001140, 9, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 1, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 2, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 3, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 4, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 5, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 6, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 7, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 8, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 9, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 10, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 11, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517001141, 12, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 1, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 2, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 3, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 4, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 5, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 6, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 7, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 8, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 9, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 10, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 11, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 12, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 13, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 14, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 15, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226001142, 16, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 1, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 2, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 3, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 4, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 5, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 6, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 7, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 8, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 9, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 10, 135, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 11, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081105001143, 12, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 1, 60, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 2, 143, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 3, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 4, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 5, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 6, 125, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 7, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 5, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 6, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 7, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 8, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 9, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 10, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 11, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 12, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524001496, 13, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 1, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 2, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 3, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 4, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 5, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 6, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 7, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 8, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 9, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 10, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 11, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 12, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 13, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 14, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915001497, 15, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 1, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 2, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 3, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 4, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 5, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 6, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 7, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 8, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727001498, 9, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 1, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 2, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 3, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 4, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 5, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 6, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 7, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 8, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 9, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 10, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 11, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 12, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 13, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 14, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 15, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006001499, 16, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 1, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 2, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 3, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 4, 48, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 5, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 6, 152, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 7, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 8, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 9, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 10, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 11, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 12, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 13, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 14, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222001500, 15, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 1, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 2, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 3, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 4, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 5, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 6, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 7, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 8, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 9, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 10, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 11, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 12, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 13, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 14, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107001501, 15, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 1, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 2, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 3, 192, 18, 18, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 4, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 5, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001502, 6, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 1, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 2, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 3, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 4, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 5, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 6, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829001503, 7, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 1, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 2, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 3, 11, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 4, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 5, 93, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 6, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 7, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101001504, 8, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 1, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 2, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 3, 189, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 4, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 5, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 6, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 7, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 8, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226001505, 9, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 1, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 2, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 3, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 4, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 5, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 6, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 7, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 8, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 9, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 10, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221001506, 11, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 1, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 2, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 3, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 4, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 5, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004001507, 6, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 1, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 2, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 3, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 4, 98, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 5, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 6, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117001508, 7, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 1, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 2, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 3, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 4, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 5, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 6, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 7, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117001509, 8, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127001510, 1, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127001510, 2, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127001510, 3, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127001510, 4, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 1, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 2, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 3, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 4, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 5, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 6, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 7, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 8, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516001511, 9, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 1, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 2, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 3, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 4, 18, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 5, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 6, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 7, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 8, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 9, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 10, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 11, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 12, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726001512, 13, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 1, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 2, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 3, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 4, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 5, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 6, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 7, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 8, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 9, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 10, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 11, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 12, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 13, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204001513, 14, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 1, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 2, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 3, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 4, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 5, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031206001514, 6, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 1, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 2, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 3, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 4, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 5, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 6, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 7, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 8, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 9, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 10, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 11, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 12, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 13, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014001515, 14, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511001516, 1, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511001516, 2, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511001516, 3, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511001516, 4, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 1, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 2, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 3, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 4, 144, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 5, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415001517, 6, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 1, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 2, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 3, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 5, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 6, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 7, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819001518, 8, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 1, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 2, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 3, 178, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 4, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 5, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 6, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 7, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 8, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 9, 147, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 10, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 11, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 12, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519001519, 13, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 1, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 2, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 3, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 4, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 5, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 6, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 7, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 4, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 5, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 6, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 7, 95, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517001899, 8, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 1, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 2, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 3, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 4, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 5, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814001900, 6, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 1, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 2, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 3, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 4, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 5, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 6, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 7, 32, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 8, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 9, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 10, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 11, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 12, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 13, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 14, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911001901, 15, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517001902, 1, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517001902, 2, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517001902, 3, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517001902, 4, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 1, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 2, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 3, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 4, 147, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 5, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 6, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 7, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 8, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 9, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 10, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 11, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 12, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 13, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 14, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 15, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125001903, 16, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811001904, 1, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811001904, 2, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811001904, 3, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811001904, 4, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 1, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 2, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 3, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 4, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 5, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 6, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 7, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 8, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 9, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602001905, 10, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 1, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 2, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 3, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 4, 156, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 5, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 6, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 7, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 8, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 9, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 10, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 11, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 12, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627001906, 13, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 1, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 2, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 3, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 4, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 5, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 6, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 7, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 8, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 9, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 10, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 11, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 12, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 13, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402001907, 14, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907001908, 1, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907001908, 2, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907001908, 3, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907001908, 4, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907001908, 5, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 1, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 2, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 3, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 4, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 5, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 6, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 7, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112001909, 8, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 1, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 2, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 3, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 4, 89, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 5, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 6, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 7, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 8, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 9, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 10, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 11, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 12, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 13, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 14, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 15, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 16, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208001910, 17, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 1, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 2, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 3, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 4, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 5, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 6, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 7, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 8, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 9, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 10, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 11, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 12, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 13, 191, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 14, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 15, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916001911, 16, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 1, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 2, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 3, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 4, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 5, 121, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 6, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530001912, 7, 56, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 1, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 2, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 3, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 4, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 5, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 6, 108, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 7, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 8, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 9, 68, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 10, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413001913, 11, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 1, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 2, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 3, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 4, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 5, 30, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 6, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 7, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 8, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 9, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 10, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327001914, 11, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 1, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 2, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 3, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 4, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 5, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 6, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 7, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 8, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 9, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 10, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 11, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 12, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 13, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 14, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904001915, 15, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 1, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 2, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 3, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 4, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 5, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 6, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 7, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 8, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 9, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 10, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 11, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 12, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 13, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 14, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703001916, 15, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 1, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 2, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 3, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 4, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 5, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 6, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 7, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 8, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 9, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 10, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 11, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314001917, 12, 154, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 1, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 2, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 3, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 4, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 5, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 6, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 7, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 8, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 9, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 10, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 11, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 12, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 13, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222001918, 14, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 1, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 2, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 3, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 4, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 5, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 6, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623001919, 7, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 1, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 2, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 3, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 4, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 5, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823001920, 6, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001921, 1, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001921, 2, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001921, 3, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 1, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 2, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 3, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 4, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 5, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 10, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 11, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 12, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 13, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 14, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 15, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204002277, 16, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 1, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 2, 71, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 3, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 4, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 5, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119002278, 6, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 1, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 2, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 3, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 4, 107, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 5, 24, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 6, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002279, 7, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002280, 1, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002280, 2, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002280, 3, 81, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002280, 4, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517002280, 5, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 1, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 2, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 3, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 4, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 5, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 6, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 7, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 9, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 10, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 11, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 12, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 13, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 14, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 15, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 16, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414002281, 17, 62, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 1, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 2, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 3, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 4, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 5, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 6, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303002282, 7, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 1, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 2, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 3, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 4, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 5, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 6, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 7, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 8, 37, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010002283, 9, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 1, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 2, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 3, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 4, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 5, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 6, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 7, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 8, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 9, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 10, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 11, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 12, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 13, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125002284, 14, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 1, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 2, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 3, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 4, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 5, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 6, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 7, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 8, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 9, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 10, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 11, 7, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 12, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007002285, 13, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 1, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 2, 146, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 3, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 4, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 5, 134, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 6, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 7, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 8, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 9, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 10, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 11, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 12, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428002286, 13, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002287, 1, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002287, 2, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002287, 3, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002287, 4, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002287, 5, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 1, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 2, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 3, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 4, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 5, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 6, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 7, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 8, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 9, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 10, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 11, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 12, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115002288, 13, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323002289, 1, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323002289, 2, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323002289, 3, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323002289, 4, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323002289, 5, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001008002290, 1, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001008002290, 2, 21, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001008002290, 3, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 1, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 2, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 3, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 4, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 5, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 6, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 7, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 8, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 9, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 10, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 11, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 12, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 13, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 14, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905002291, 15, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 1, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 2, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 3, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 4, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 5, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 6, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 7, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 8, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 9, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127002292, 10, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011002293, 1, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011002293, 2, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011002293, 3, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 1, 85, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 2, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 3, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 4, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 5, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 6, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714002294, 7, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 1, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 2, 111, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 3, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 4, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 5, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 6, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 7, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 8, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404002295, 9, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 1, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 2, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 3, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 4, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 5, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 6, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 7, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 8, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 9, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 10, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 11, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410002296, 12, 113, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 1, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 2, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 3, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 4, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 5, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 6, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 7, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 8, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123002297, 9, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 1, 59, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 2, 14, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 3, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 4, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 5, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 6, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 7, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 8, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 9, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 10, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 11, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 12, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304002298, 13, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 1, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 2, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 3, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 4, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 5, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 6, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 7, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 8, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 9, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326002299, 10, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 1, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 2, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 3, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 4, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 5, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 6, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 7, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 8, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 9, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 10, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616002300, 11, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619002301, 1, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619002301, 2, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619002301, 3, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619002301, 4, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619002301, 5, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 1, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 2, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 3, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 4, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 5, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502002302, 6, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 1, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 2, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 3, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 4, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 5, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 6, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 8, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 9, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 10, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 11, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 12, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 13, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 14, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611001144, 15, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 1, 90, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 2, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 3, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 4, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 5, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 6, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 7, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 8, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071113001145, 9, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 1, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 2, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 3, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 4, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 5, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 6, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 7, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 8, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 9, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 10, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 11, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 12, 103, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 13, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822001146, 14, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001147, 1, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001147, 2, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727001147, 3, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 1, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 2, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 3, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 4, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 5, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 6, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 7, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 8, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 9, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 10, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 11, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113001148, 12, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 1, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 2, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 3, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 4, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 5, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 6, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001149, 7, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703001150, 1, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703001150, 2, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703001150, 3, 69, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 1, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 2, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 3, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 4, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 5, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 6, 76, 60, 9, 540);
commit;
prompt 23000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 7, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 8, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 9, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 10, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 11, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 12, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 13, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 14, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 15, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321001151, 16, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 1, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 2, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 3, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 4, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 5, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 6, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 7, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520001152, 8, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325001153, 1, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325001153, 2, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325001153, 3, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325001153, 4, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325001153, 5, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 1, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 2, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 3, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 4, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 5, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121001154, 6, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227001155, 1, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227001155, 2, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227001155, 3, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227001155, 4, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 1, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 2, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 3, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 4, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 5, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 6, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 7, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 8, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 9, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 10, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 11, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 12, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001156, 13, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224001157, 1, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224001157, 2, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224001157, 3, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224001157, 4, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224001157, 5, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 1, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 2, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 3, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 4, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 5, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 6, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 7, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 8, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 9, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 10, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 11, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905001158, 12, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 1, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 2, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 3, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 4, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 5, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 6, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 7, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726001159, 8, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 1, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 2, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 3, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 4, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 5, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 6, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 7, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 8, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 9, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 10, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 11, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 12, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 13, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 14, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 15, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019001160, 16, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 1, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 2, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 3, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 4, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 5, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 6, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 7, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 8, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 9, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 10, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 11, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 12, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 13, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 14, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 15, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 16, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716001161, 17, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215001162, 1, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215001162, 2, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215001162, 3, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 1, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 2, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 3, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 4, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 5, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 6, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203001163, 7, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 1, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 2, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 3, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 4, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 5, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 6, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 7, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 8, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 9, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 10, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 11, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 12, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 13, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 14, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 15, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 16, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516001164, 17, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520001165, 1, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520001165, 2, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520001165, 3, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520001165, 4, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520001165, 5, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 1, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 2, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 3, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 4, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 5, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 6, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 7, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 8, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 9, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 10, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 11, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 12, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030001166, 13, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 1, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 2, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 3, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 4, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 5, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 6, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 7, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 8, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 9, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 10, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 11, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 12, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 13, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 14, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001167, 15, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 1, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 2, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 3, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 4, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 5, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204001168, 6, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 1, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 2, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 3, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 4, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 5, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 6, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 8, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 9, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050526001520, 10, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 1, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 2, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 3, 24, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 4, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 5, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 6, 129, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 7, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 8, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 9, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 10, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 11, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 12, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 13, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 14, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 15, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 16, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112001521, 17, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 1, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 2, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 3, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 4, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 5, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 6, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 7, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108001522, 8, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 1, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 2, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 3, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 4, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 5, 41, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 6, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217001523, 7, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 1, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 2, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 3, 142, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 4, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 5, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 6, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 7, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 8, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 9, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 10, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 11, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 12, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001524, 13, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 1, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 2, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 3, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 4, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 5, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 6, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 7, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 8, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 9, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 10, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 11, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 12, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 13, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302001525, 14, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 1, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 2, 122, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 3, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 4, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 5, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 6, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 7, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 8, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 9, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 10, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 11, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 12, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 13, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917001526, 14, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123001527, 1, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123001527, 2, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123001527, 3, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123001527, 4, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123001527, 5, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 1, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 2, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 3, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 5, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913001528, 6, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207001529, 1, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207001529, 2, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207001529, 3, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207001529, 4, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207001529, 5, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 1, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 2, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 3, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 4, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 5, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 6, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 7, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429001530, 8, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 1, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 2, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 3, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 4, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 5, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 6, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 7, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 8, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 9, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 10, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 11, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 12, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814001531, 13, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 1, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 2, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 3, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 4, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 5, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 6, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 7, 138, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 8, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 9, 192, 11, 18, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 10, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912001532, 11, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 1, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 2, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 3, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 4, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 5, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221001533, 6, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 1, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 2, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 3, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 4, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 5, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 6, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 7, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 8, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 9, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 10, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001534, 11, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108001535, 1, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108001535, 2, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108001535, 3, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 1, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 2, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 3, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 4, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 5, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 6, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 7, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 8, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804001536, 9, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 1, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 2, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 3, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 4, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 5, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 6, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 7, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 8, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329001537, 9, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 1, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 2, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 3, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 4, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 5, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 6, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 7, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129001538, 8, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 1, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 2, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 3, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 4, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 5, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917001539, 6, 59, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 1, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 2, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 3, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 4, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 5, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 6, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 7, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 8, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 9, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 10, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 11, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 12, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023001540, 13, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 1, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 2, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 3, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 4, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 5, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 6, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 7, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 8, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 9, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 10, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 11, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415001541, 12, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 1, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 2, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 3, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 4, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 5, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 6, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 7, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 8, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 9, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 10, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 11, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 12, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 13, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125001542, 14, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 1, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 2, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 3, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 4, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 5, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 6, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 7, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 8, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 9, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 10, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 11, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917001543, 12, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 1, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 2, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 3, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 4, 38, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 5, 83, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 6, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 7, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 8, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 9, 90, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 10, 127, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 11, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328001544, 12, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 6, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 7, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008001922, 8, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 1, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 2, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 3, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 4, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 5, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711001923, 6, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 1, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 2, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 3, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 4, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 5, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 6, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 7, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 8, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 9, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 10, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 11, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 12, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 13, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 14, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 15, 180, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102001924, 16, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 1, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 2, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 3, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 4, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 5, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 6, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 7, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706001925, 8, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 1, 38, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 2, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 3, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 4, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 5, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 6, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 7, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 8, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 9, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001926, 10, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 1, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 2, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 3, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 4, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 5, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 6, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 7, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 8, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 9, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712001927, 10, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 1, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 2, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 3, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 4, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 5, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030620001928, 6, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 1, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 2, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 3, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 4, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 5, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 6, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 7, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 8, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 9, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 10, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 11, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829001929, 12, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211001930, 1, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211001930, 2, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211001930, 3, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 1, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 2, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 3, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 4, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 5, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102001931, 6, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 1, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 2, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 3, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 4, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 5, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 6, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 7, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 8, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 9, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715001932, 10, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 1, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 2, 117, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 3, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 4, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 5, 56, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 6, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 7, 168, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 8, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306001933, 9, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 1, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 2, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 3, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 4, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 5, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 6, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 7, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 8, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 9, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 10, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 11, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 12, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 13, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 14, 192, 34, 18, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907001934, 15, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 1, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 2, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 3, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 4, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 5, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 6, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 7, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 8, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 9, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 10, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 11, 108, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 12, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 13, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 14, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016001935, 15, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 1, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 2, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 3, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 4, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 5, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 6, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 7, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604001936, 8, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 1, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 2, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 3, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 4, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 5, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 6, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213001937, 7, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 1, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 2, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 3, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 4, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 5, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 6, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 7, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127001938, 8, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 1, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 2, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 3, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 4, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 5, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 6, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 7, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 8, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 9, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 10, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613001939, 11, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802001940, 1, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802001940, 2, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802001940, 3, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802001940, 4, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802001940, 5, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 1, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 2, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 3, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 4, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 5, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 6, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 7, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 8, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214001941, 9, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 1, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 2, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 3, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 4, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 5, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 6, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 7, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 8, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 9, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311001942, 10, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 1, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 2, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 3, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 4, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 5, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 6, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050309001943, 7, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 1, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 2, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 3, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 4, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 5, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 6, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 7, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 8, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 9, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 10, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 11, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 12, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 13, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612001944, 14, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 1, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 2, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 3, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 4, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 5, 128, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001945, 6, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 1, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 2, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 3, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 4, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 5, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 6, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 7, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 8, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 9, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 10, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 11, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 12, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 13, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405001946, 14, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 1, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 2, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 3, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 4, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 5, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 6, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 7, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 8, 166, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 9, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 10, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 11, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 7, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 8, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 9, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 10, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 11, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 12, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 13, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 14, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 15, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703002303, 16, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 1, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 2, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 3, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 4, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 5, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 6, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 7, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 8, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 9, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 10, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 11, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 12, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513002304, 13, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128002305, 1, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128002305, 2, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128002305, 3, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 1, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 2, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 3, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 4, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 5, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 6, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 7, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 8, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 9, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312002306, 10, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 1, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 2, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 3, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 4, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 5, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 6, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 7, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 8, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 9, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 10, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 11, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 12, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727002307, 13, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 1, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 2, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 3, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 4, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 5, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 6, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521002308, 7, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 1, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 2, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 3, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 4, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 6, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725002309, 7, 78, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 1, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 2, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 3, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 4, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 5, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 6, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 7, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 8, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 9, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 10, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621002310, 11, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 1, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 2, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 3, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 4, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 5, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 6, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 7, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 8, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 9, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 10, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 11, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 12, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 13, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714002311, 14, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 1, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 2, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 3, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 4, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 5, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109002312, 6, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301002313, 1, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301002313, 2, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301002313, 3, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301002313, 4, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301002313, 5, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 1, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 2, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 3, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 4, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 5, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 6, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 7, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 8, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 9, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 10, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 11, 156, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 12, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729002314, 13, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 1, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 2, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 3, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 4, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 5, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 6, 179, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 7, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 8, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 9, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 10, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 11, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 12, 109, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515002315, 13, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 1, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 2, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 3, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 4, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 5, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 6, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 7, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 8, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 9, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 10, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 11, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 12, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 13, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 14, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303002316, 15, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 1, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 2, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 3, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 4, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 5, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 6, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 7, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830002317, 8, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 1, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 2, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 3, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 4, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 5, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 6, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 7, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 8, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824002318, 9, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 1, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 2, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 3, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 4, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 5, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 6, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 7, 192, 75, 18, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617002319, 8, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917002320, 1, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917002320, 2, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917002320, 3, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917002320, 4, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312002321, 1, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312002321, 2, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312002321, 3, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312002321, 4, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312002321, 5, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 1, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 2, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 3, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 4, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 5, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 6, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 7, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 8, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 9, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 10, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 11, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 12, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 13, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 14, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 15, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 16, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006002322, 17, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 1, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 2, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 3, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 4, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 5, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 6, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 7, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 8, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725002323, 9, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319002324, 1, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319002324, 2, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319002324, 3, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319002324, 4, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 1, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 2, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 3, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 4, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 5, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 6, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 7, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 8, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 9, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818002325, 10, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127002326, 1, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127002326, 2, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127002326, 3, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 1, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 2, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 3, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 4, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 5, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 6, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 7, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 8, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 9, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 10, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 11, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 12, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 13, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213002327, 14, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000829002328, 1, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000829002328, 2, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000829002328, 3, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000829002328, 4, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 1, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 2, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 3, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 7, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 8, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 9, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 10, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 11, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 12, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001169, 13, 1, 71, 3, 213);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 1, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 2, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 3, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 4, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 5, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 6, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921001170, 7, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 1, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 2, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 3, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 4, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 5, 47, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 6, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323001171, 7, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306001172, 1, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306001172, 2, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306001172, 3, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 1, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 2, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 3, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 4, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 5, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 6, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 7, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 8, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 9, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 10, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 11, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 12, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 13, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 14, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003001173, 15, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209001174, 1, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209001174, 2, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209001174, 3, 94, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209001174, 4, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704001175, 1, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704001175, 2, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704001175, 3, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704001175, 4, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 1, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 2, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 3, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 4, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 5, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 6, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 7, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 8, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 9, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 10, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 11, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 12, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 13, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628001176, 14, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 1, 39, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 2, 145, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 3, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 4, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 5, 159, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 6, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 7, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 8, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 9, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020001177, 10, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 1, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 2, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 3, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 4, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 5, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 6, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 7, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 8, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 9, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 10, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 11, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 12, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 13, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 14, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808001178, 15, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 1, 82, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 2, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 3, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 4, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 5, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 6, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 7, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 8, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 9, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801001179, 10, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 1, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 2, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 3, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 4, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 5, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 6, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 7, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 8, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 9, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 10, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 11, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 12, 73, 28, 6, 168);
commit;
prompt 24000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 13, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 14, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 15, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 16, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224001180, 17, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 1, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 2, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 3, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 4, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 5, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 6, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708001181, 7, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 1, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 2, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 3, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 4, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 5, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 6, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 7, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 8, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 9, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 10, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 11, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 12, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 13, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 14, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 15, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 16, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 17, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221001182, 18, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 1, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 2, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 3, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 4, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 5, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 6, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 7, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 8, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 9, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 10, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 11, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 12, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124001183, 13, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 1, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 2, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 3, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 4, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 5, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 6, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 7, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 8, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 9, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 10, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 11, 62, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 12, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122001184, 13, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 1, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 2, 65, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 3, 177, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 4, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 5, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 6, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 7, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 8, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 9, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 10, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 11, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105001185, 12, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 1, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 2, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 3, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 4, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 5, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 6, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 7, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 8, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 9, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404001186, 10, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001187, 1, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001187, 2, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001187, 3, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225001187, 4, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 1, 94, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 2, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 3, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 4, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 5, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 6, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 7, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 8, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 9, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 10, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 11, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 12, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 13, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 14, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 15, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801001188, 16, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 1, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 2, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 3, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 4, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 5, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 6, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031225001189, 7, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 1, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 2, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 3, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 4, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 5, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 6, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 7, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 8, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 9, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 10, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 11, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 12, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206001190, 13, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404001191, 1, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404001191, 2, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404001191, 3, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 1, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 2, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 3, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 4, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 5, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 6, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511001192, 7, 43, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 1, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 2, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 3, 151, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 1, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 2, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 3, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 4, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 5, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 6, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 7, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 8, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 9, 143, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 10, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 11, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 12, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 13, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 14, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223001545, 15, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806001546, 1, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806001546, 2, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806001546, 3, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806001546, 4, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 1, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 2, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 3, 57, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 4, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 5, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912001547, 6, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 1, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 2, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 3, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 4, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 5, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 6, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 7, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707001548, 8, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 1, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 2, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 3, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 4, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 5, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 6, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 7, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 8, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 9, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 10, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 11, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 12, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 13, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916001549, 14, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017001550, 1, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017001550, 2, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017001550, 3, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017001550, 4, 148, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017001550, 5, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 1, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 2, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 3, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 4, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 5, 168, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 6, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 7, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 8, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 9, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 10, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 11, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 12, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 13, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 14, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 15, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 16, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121001551, 17, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 1, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 2, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 3, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 4, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 5, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 6, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 7, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 8, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 9, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 10, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 11, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 12, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 13, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118001552, 14, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 1, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 2, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 3, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 4, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 5, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 6, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 7, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 8, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 9, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124001553, 10, 172, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 1, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 2, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 3, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 4, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 5, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010327001554, 6, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726001555, 1, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726001555, 2, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726001555, 3, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726001555, 4, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 1, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 2, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 3, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 4, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 6, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 7, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401001556, 8, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 1, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 2, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 3, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 4, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 5, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 6, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 7, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 8, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 9, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 10, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 11, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 12, 145, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 13, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 14, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421001557, 15, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001558, 1, 103, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001558, 2, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001558, 3, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010516001558, 4, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 1, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 2, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 3, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 4, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 5, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 6, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 7, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 8, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 9, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 10, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 11, 33, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 12, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 13, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731001559, 14, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 1, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 2, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 3, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 4, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 5, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701001560, 6, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126001561, 1, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126001561, 2, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126001561, 3, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126001561, 4, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 1, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 2, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 3, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 4, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 5, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 6, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 7, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 8, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 9, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 10, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 11, 108, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 12, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 13, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 14, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 15, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 16, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729001562, 17, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 1, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 2, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 3, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 4, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 5, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 6, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 7, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 8, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 9, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 10, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 11, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 12, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 13, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 14, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 15, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 16, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 17, 54, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410001563, 18, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 1, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 2, 124, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 3, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 4, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 5, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 6, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 7, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 8, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 9, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 10, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 11, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919001564, 12, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 1, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 2, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 3, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 4, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 5, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 6, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 7, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 8, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 9, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 10, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 11, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 12, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401001565, 13, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 1, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 2, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 3, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 4, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 5, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 6, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 7, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 8, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 9, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616001566, 10, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 1, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 2, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 3, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 4, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 5, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 6, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 7, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 8, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 9, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 10, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 11, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 12, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 13, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 14, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110001567, 15, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 12, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 13, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223001947, 14, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829001948, 1, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829001948, 2, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829001948, 3, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829001948, 4, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829001948, 5, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 1, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 2, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 3, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 4, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 5, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 6, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 7, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 8, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 9, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 10, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225001949, 11, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017001950, 1, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017001950, 2, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017001950, 3, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129001951, 1, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129001951, 2, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129001951, 3, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129001951, 4, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129001951, 5, 154, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 1, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 2, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 3, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 4, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 5, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 6, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 7, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 8, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 9, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 10, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 11, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 12, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 13, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309001952, 14, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 1, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 2, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 3, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 4, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 5, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 6, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 7, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 8, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 9, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 10, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 11, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 12, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 13, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 14, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511001953, 15, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 1, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 2, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 3, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 4, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 5, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 6, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527001954, 7, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 1, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 2, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 3, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 4, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 5, 66, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 6, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 7, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 8, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 9, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 10, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 11, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507001955, 12, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 1, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 2, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 3, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 4, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 5, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 6, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 7, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 8, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 9, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 10, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 11, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 12, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 13, 181, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224001956, 14, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112001957, 1, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112001957, 2, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112001957, 3, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112001957, 4, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019001958, 1, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019001958, 2, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019001958, 3, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019001958, 4, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 1, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 2, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 3, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 4, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 5, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 6, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 7, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 8, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 9, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 10, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808001959, 11, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 1, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 2, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 3, 29, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 4, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 5, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001960, 6, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 1, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 2, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 3, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 4, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 5, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 6, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 7, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 8, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 9, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 10, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 11, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 12, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 13, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 14, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 15, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225001961, 16, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 1, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 2, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 3, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 4, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 5, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 6, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 7, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 8, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 9, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 10, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 11, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 12, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 13, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 14, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 15, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004001962, 16, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 1, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 2, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 3, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 4, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 5, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 6, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 7, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 8, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 9, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 10, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 11, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 12, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316001963, 13, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 1, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 2, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 3, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 4, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 5, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 6, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 7, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 8, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 9, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 10, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418001964, 11, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 1, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 2, 138, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 3, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 4, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 5, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 6, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 7, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 8, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 9, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 10, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 11, 91, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 12, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 13, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 14, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 15, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 16, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 17, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126001965, 18, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 1, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 2, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 3, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 4, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 5, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 6, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 7, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 8, 1, 24, 3, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 9, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 10, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 11, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 12, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 13, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 14, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 15, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225001966, 16, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 1, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 2, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 3, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 4, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 5, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 6, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 7, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907001967, 8, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 1, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 3, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 4, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 5, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 6, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 7, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 8, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 9, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 10, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 11, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 12, 170, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 13, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 14, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004001968, 15, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 1, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 2, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 3, 99, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 4, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 5, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 6, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 7, 51, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 8, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201001969, 9, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 1, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 2, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 3, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 4, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 5, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 6, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 7, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 8, 161, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 9, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 10, 56, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 11, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 12, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 13, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 14, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 15, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324002329, 16, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 1, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 2, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 3, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 4, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 5, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 6, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 7, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 8, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 9, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923002330, 10, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 1, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 2, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 3, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 4, 191, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 5, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 6, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 7, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 8, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 9, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 10, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 11, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 12, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002331, 13, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 1, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 2, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 3, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 4, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 5, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 6, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 7, 75, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907002332, 8, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102002333, 1, 68, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102002333, 2, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102002333, 3, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102002333, 4, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102002333, 5, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916002334, 1, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916002334, 2, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916002334, 3, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916002334, 4, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916002334, 5, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 1, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 2, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 3, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 4, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 5, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 6, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 7, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 8, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 9, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 10, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 11, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 12, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 13, 54, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828002335, 14, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002336, 1, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002336, 2, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 1, 22, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 2, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 3, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 4, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 5, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 6, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 7, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 8, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 9, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 10, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 11, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 12, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 13, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 14, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 15, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930002337, 16, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121002338, 1, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121002338, 2, 107, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121002338, 3, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121002338, 4, 2, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121002338, 5, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 1, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 2, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 3, 47, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 4, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 5, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 6, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 7, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 8, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 9, 111, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 10, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 11, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002339, 12, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 1, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 2, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 3, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 4, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 5, 127, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 6, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 7, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 8, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 9, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 10, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081219002340, 11, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120002341, 1, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120002341, 2, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120002341, 3, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120002341, 4, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 1, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 2, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 3, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 4, 131, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 5, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 6, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 7, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 8, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 9, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 10, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 11, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 12, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 13, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 14, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 15, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 16, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002002342, 17, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 1, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 2, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 3, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 4, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 5, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 6, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 7, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 8, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 9, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 10, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 11, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120002343, 12, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 1, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 2, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 3, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 4, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 5, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701002344, 6, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 1, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 2, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 3, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 4, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 5, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 6, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 7, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 8, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 9, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 10, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 11, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 12, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821002345, 13, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 1, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 2, 88, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 3, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 4, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 5, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 6, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 7, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 8, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 9, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 10, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 11, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 12, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101002346, 13, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 1, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 2, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 3, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 4, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 5, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 6, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 7, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 8, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627002347, 9, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 1, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 2, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 3, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 4, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 5, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 6, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 7, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 8, 139, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 9, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117002348, 10, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 1, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 2, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 3, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 4, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 5, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 6, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 7, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 8, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 9, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 10, 152, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 11, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 12, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509002349, 13, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 1, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 2, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 3, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 4, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 5, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 6, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 7, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 8, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 9, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 10, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 11, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 12, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417002350, 13, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505002351, 1, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505002351, 2, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505002351, 3, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 1, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 2, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 3, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 4, 1, 12, 3, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 5, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 6, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 7, 115, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 8, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 9, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 10, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217002352, 11, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002353, 1, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 4, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 5, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 6, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 7, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 8, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120001193, 9, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 1, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 2, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 3, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 4, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 5, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 6, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 7, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 8, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 9, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 10, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 11, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 12, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 13, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 14, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 15, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 16, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120519001194, 17, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 1, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 2, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 3, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 4, 82, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 5, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 6, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205001195, 7, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 1, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 2, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 3, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 4, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 5, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 6, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 7, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 8, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 9, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 10, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 11, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 12, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 13, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 14, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 15, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 16, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 17, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220001196, 18, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 1, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 2, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 3, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 4, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 5, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 6, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 7, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 8, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 9, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 10, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622001197, 11, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 1, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 2, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 3, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 4, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 5, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 6, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 7, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 8, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627001198, 9, 155, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001199, 1, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001199, 2, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001199, 3, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107001199, 4, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 1, 109, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 2, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 3, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 4, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 5, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 6, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 7, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 8, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 9, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 10, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 11, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 12, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 13, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213001200, 14, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 1, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 2, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 3, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 4, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 5, 85, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 6, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 7, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 8, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 9, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503001201, 10, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821001202, 1, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821001202, 2, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821001202, 3, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821001202, 4, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 1, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 2, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 3, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 4, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 5, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 6, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 7, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 8, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 9, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 10, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060817001203, 11, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 1, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 2, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 3, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 4, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 5, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 6, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 7, 129, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 8, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 9, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 10, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 11, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 12, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 13, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100510001204, 14, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 1, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 2, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 3, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 4, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 5, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 6, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 7, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 8, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029001205, 9, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 1, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 2, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 3, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 4, 25, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 5, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 6, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 7, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 8, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 9, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 10, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 11, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 12, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001206, 13, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 1, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 3, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 4, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 5, 19, 48, 7, 336);
commit;
prompt 25000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 6, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 7, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621001207, 8, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 1, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 2, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 3, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 4, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 5, 80, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 6, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505001208, 7, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 1, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 2, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 3, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 4, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 5, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221001209, 6, 110, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 1, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 2, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 3, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 4, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 5, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 6, 144, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 7, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 8, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 9, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 10, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 11, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430001210, 12, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 1, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 2, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 3, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 4, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 5, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 6, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 7, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 8, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 9, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531001211, 10, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 1, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 2, 155, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 3, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 4, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 5, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 6, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 7, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 8, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130001212, 9, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 1, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 2, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 3, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 4, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 5, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 6, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510001213, 7, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 1, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 2, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 3, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 4, 182, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 5, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 6, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 7, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 8, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 9, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402001214, 10, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 1, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 2, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 3, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 4, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 5, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 6, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 7, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 8, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 9, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625001215, 10, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 1, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 2, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 3, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 4, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 5, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 6, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 7, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 8, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 9, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601001216, 10, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 1, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 2, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 3, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 1, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 2, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 3, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 4, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 5, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 6, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 7, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 8, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 9, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 10, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 11, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 12, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 13, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 14, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 15, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316001568, 16, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 1, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 2, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 3, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 4, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 5, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 6, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 7, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 8, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 9, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 10, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107001569, 11, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 1, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 2, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 3, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 4, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 5, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 6, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 7, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 8, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104001570, 9, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 1, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 2, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 3, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 4, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 5, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 6, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 7, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 8, 122, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 9, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 10, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425001571, 11, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 1, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 2, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 3, 146, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 4, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 5, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 6, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 7, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 8, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 9, 1, 40, 3, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 10, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 11, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 12, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 13, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222001572, 14, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111001573, 1, 65, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111001573, 2, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111001573, 3, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 1, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 2, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 3, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 4, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 5, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 6, 92, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 7, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 8, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 9, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 10, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 11, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 12, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 13, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 14, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 15, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 16, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 17, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627001574, 18, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208001575, 1, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208001575, 2, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208001575, 3, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208001575, 4, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208001575, 5, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 1, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 2, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 3, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 4, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 5, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 6, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 7, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 8, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005001576, 9, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531001577, 1, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531001577, 2, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531001577, 3, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531001577, 4, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531001577, 5, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 1, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 2, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 3, 71, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 4, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 5, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 6, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 7, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 8, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 9, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 10, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 11, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225001578, 12, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 1, 176, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 2, 158, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 3, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 4, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 5, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 6, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 7, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 8, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 9, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218001579, 10, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 1, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 2, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 3, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 4, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 5, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 6, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225001580, 7, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 1, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 2, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 3, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 4, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 5, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729001581, 6, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 1, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 2, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 3, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 4, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 5, 55, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 6, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 7, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 8, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 9, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 10, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 11, 157, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 12, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 13, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 14, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121001582, 15, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 1, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 2, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 3, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 4, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 5, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 6, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 7, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 8, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 9, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 10, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 11, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 12, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125001583, 13, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105001584, 1, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105001584, 2, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105001584, 3, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105001584, 4, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105001584, 5, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 1, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 2, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 3, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 4, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 5, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 6, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 7, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112001585, 8, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 1, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 2, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 3, 18, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 4, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 5, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 6, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119001586, 7, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 1, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 2, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 3, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 4, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 5, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 6, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 7, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 8, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 9, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 10, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 11, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 12, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 13, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209001587, 14, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820001588, 1, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820001588, 2, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820001588, 3, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820001588, 4, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820001588, 5, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 1, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 2, 89, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 3, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 4, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 5, 22, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 6, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 7, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810001589, 8, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 1, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 2, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 3, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 4, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 5, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 6, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 7, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 8, 161, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 9, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 10, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 11, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 12, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 13, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 14, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 15, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 16, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305001590, 17, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 1, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 2, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 3, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 4, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 5, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009001591, 6, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 1, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 2, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 3, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 4, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 5, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 4, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 5, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 6, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 7, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 8, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 9, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 10, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 11, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810001970, 12, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 1, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 2, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 3, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 4, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 5, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 6, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 7, 131, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 8, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723001971, 9, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 1, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 2, 17, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 3, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 4, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 5, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 6, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430001972, 7, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315001973, 1, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315001973, 2, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315001973, 3, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 1, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 2, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 3, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 4, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 5, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 6, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 7, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 8, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 9, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 10, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 11, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 12, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 13, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 14, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326001974, 15, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 1, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 2, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 3, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 4, 74, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 5, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 6, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608001975, 7, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 1, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 2, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 3, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 4, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 5, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 6, 192, 80, 18, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 7, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 8, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 9, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 10, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 11, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 12, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820001976, 13, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223001977, 1, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223001977, 2, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223001977, 3, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223001977, 4, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 1, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 2, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 3, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 4, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 5, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 6, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 7, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 8, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 9, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 10, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 11, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 12, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 13, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 14, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 15, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229001978, 16, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 1, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 2, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 3, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 4, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 5, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 6, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109001979, 7, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 1, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 2, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 3, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 4, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 5, 52, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 6, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 7, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 8, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 9, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 10, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 11, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 12, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309001980, 13, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 1, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 2, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 3, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 4, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 5, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 6, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 7, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 8, 29, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104001981, 9, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 1, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 2, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 3, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 4, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 5, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 6, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 7, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 8, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 9, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 10, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 11, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 12, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516001982, 13, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 1, 180, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 2, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 3, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 4, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 5, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 6, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 7, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313001983, 8, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417001984, 1, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417001984, 2, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417001984, 3, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417001984, 4, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 1, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 2, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 3, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 4, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 5, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 6, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 7, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 8, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 9, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 10, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703001985, 11, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 1, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 2, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 3, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 4, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 5, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 6, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 7, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 8, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 9, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323001986, 10, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124001987, 1, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124001987, 2, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 1, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 2, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 3, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 4, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 5, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 6, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 7, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 8, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 9, 35, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 10, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 11, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 12, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 13, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 14, 22, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825001988, 15, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 1, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 2, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 3, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 4, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 5, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607001989, 6, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 1, 192, 84, 18, 1512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 2, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 3, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 4, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 5, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 6, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 7, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 8, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 9, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 10, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 11, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 12, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 13, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 14, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016001990, 15, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 1, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 2, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 3, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 4, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 5, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 6, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 7, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 8, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 9, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 10, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 11, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 12, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 13, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 14, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117001991, 15, 107, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 1, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 2, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 3, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 4, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 5, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 6, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 7, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 8, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408001992, 9, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 1, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 2, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 3, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 4, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 5, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 6, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 7, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 8, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 9, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 10, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 11, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 12, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 13, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 14, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819001993, 15, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 1, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 2, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 3, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509001994, 4, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002353, 2, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002353, 3, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002353, 4, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002353, 5, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 1, 94, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 2, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 3, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 4, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 5, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 6, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 7, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 8, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 9, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 10, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509002354, 11, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 1, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 2, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 3, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 4, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 5, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 6, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 7, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 8, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 9, 99, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 10, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 11, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 12, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704002355, 13, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 1, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 2, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 3, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 4, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 5, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 6, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 7, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 8, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 9, 94, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725002356, 10, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 1, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 2, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 3, 103, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 4, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 5, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 6, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 7, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 8, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 9, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 10, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 11, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 12, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 13, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705002357, 14, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 1, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 2, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 3, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 4, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 5, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 6, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 7, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 8, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217002358, 9, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 1, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 2, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 3, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 4, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 5, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 6, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 7, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 8, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 9, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 10, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 11, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 12, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 13, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425002359, 14, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 1, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 2, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 3, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 4, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 5, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416002360, 6, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 1, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 2, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 3, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 4, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 5, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 6, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 7, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 8, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 9, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 10, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 11, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 12, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 13, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 14, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919002361, 15, 7, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 1, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 2, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 3, 6, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 4, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 5, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 6, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 7, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 8, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 9, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 10, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 11, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 12, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 13, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 14, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708002362, 15, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929002363, 1, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929002363, 2, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929002363, 3, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929002363, 4, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 1, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 2, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 3, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 4, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 5, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 6, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 7, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 8, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 9, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 10, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 11, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 12, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 13, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 14, 15, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 15, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 16, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220002364, 17, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 1, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 2, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 3, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 4, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 5, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605002365, 6, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 1, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 2, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 3, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 4, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 5, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 6, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 7, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 8, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 9, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 10, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 11, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 12, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 13, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 14, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 15, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605002366, 16, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 1, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 2, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 3, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 4, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 5, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 6, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 7, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 8, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 9, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 10, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 11, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 12, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 13, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613002367, 14, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 1, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 2, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 3, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 4, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 5, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 6, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 7, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 8, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 9, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 10, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309002368, 11, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 1, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 2, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 3, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 4, 22, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 5, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 6, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112002369, 7, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 1, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 2, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 3, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 4, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 5, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 6, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603002370, 7, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 1, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 2, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 3, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 4, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 5, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008002371, 6, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 1, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 2, 134, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 3, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 4, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 5, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 6, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 7, 192, 45, 18, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 8, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 9, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 10, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 11, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 12, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 13, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002372, 14, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 1, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 2, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 3, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 4, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 5, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 6, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 7, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 8, 55, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823002373, 9, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 1, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 2, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 3, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 4, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 5, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 6, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 7, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010002374, 8, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002375, 1, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002375, 2, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002375, 3, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002375, 4, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 1, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 2, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 3, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 4, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423002376, 5, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 4, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 5, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 6, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 7, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061217001217, 8, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 1, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 2, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 3, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 4, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 5, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 6, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 7, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 8, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 9, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 10, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310001218, 11, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 1, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 2, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 3, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 4, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 5, 142, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 6, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 7, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 8, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 9, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 10, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807001219, 11, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 1, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 2, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 3, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 4, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 5, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 6, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 7, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 8, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 9, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 10, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 11, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 12, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111001220, 13, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 1, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 2, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 3, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 4, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 5, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 6, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 7, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 8, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 9, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 10, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519001221, 11, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 1, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 2, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 3, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 4, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 5, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 6, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 7, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 8, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 9, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 10, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090201001222, 11, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 1, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 2, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 3, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 4, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 5, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 6, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 7, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 8, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 9, 118, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 10, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 11, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 12, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 13, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 14, 117, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 15, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803001223, 16, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 1, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 2, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 3, 96, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 4, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 5, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111001224, 6, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 1, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 2, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 3, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 4, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 5, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 6, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 7, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 8, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 9, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 10, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 11, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 12, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 13, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 14, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 15, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 16, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123001225, 17, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 1, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 2, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 3, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 4, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 5, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 6, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917001226, 7, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 1, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 2, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 3, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 4, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 5, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 6, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 7, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 8, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 9, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 10, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 11, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 12, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504001227, 13, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 1, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 2, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 3, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 4, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 5, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 6, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 7, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 8, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 9, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925001228, 10, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 1, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 2, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 3, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 4, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 5, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 6, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 7, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 8, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 9, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 10, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 11, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 12, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 13, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 14, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717001229, 15, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 1, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 2, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 3, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 4, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 5, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 6, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 7, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 8, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 9, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 10, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 11, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 12, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 13, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 14, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 15, 75, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 16, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221001230, 17, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216001231, 1, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216001231, 2, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216001231, 3, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216001231, 4, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 1, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 2, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 3, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 4, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 5, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 6, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 7, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504001232, 8, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 1, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 2, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 3, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 4, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 5, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 6, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 7, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 8, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 9, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 10, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 11, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629001233, 12, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 1, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 2, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 3, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 4, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 5, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 6, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 7, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 8, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 9, 5, 1, 7, 7);
commit;
prompt 26000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 10, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 11, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 12, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 13, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 14, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 15, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210001234, 16, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612001235, 1, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612001235, 2, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612001235, 3, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612001235, 4, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120001236, 1, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120001236, 2, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120001236, 3, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 1, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 2, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 3, 31, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 4, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 5, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 6, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619001237, 7, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 1, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 2, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 3, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 4, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 5, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 6, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 7, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 8, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 9, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 10, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 11, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 12, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 13, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110001238, 14, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 1, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 2, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 3, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 4, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 5, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 6, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 7, 134, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227001239, 8, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 6, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 7, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 8, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 9, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429001592, 10, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 1, 8, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 2, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 3, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 4, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 5, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 6, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 7, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 8, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 9, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 10, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 11, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 12, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921001593, 13, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222001594, 1, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222001594, 2, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222001594, 3, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222001594, 4, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 1, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 2, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 3, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 4, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 5, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 6, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 7, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 8, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 9, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 10, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 11, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 12, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918001595, 13, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117001596, 1, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117001596, 2, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117001596, 3, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117001596, 4, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 1, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 2, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 3, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 4, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 5, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 6, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 7, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 8, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 9, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 10, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003001597, 11, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 1, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 2, 125, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 3, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 4, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 5, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 6, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 7, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 8, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404001598, 9, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 1, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 2, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 3, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 4, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 5, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 6, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 7, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 8, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 9, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619001599, 10, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 1, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 2, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 3, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 4, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 5, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 6, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 7, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 8, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 9, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 10, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 11, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 12, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 13, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822001600, 14, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 1, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 2, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 3, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 4, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 5, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 6, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 7, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 8, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 9, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 10, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 11, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 12, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 13, 56, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529001601, 14, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 1, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 2, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 3, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 4, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 5, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 6, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 7, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 8, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 9, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 10, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 11, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 12, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 13, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515001602, 14, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 1, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 2, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 3, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 4, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 5, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124001603, 6, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 1, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 2, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 3, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 4, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 5, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312001604, 6, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 1, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 2, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 3, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 4, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 5, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 6, 143, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 7, 149, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 8, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 9, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050319001605, 10, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201001606, 1, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201001606, 2, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201001606, 3, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504001607, 1, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504001607, 2, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504001607, 3, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504001607, 4, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504001607, 5, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709001608, 1, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709001608, 2, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709001608, 3, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709001608, 4, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 1, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 2, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 3, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 4, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 5, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 6, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 7, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 8, 72, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 9, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 10, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 11, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 12, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010001609, 13, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 1, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 2, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 3, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 4, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 5, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 6, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 7, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 8, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 9, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 10, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 11, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 12, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010001610, 13, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 1, 15, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 2, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 3, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 4, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 5, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 6, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 7, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 8, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 9, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 10, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 11, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 12, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 13, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 14, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 15, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 16, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 17, 129, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407001611, 18, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 1, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 2, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 3, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 4, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 5, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 6, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 7, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 8, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 9, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916001612, 10, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 1, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 2, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 3, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 4, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 5, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 6, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 7, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 8, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 9, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 10, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 11, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 12, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 13, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 14, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 15, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 16, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427001613, 17, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 1, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 2, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 3, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 4, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 5, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 6, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 7, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 8, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 9, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 10, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 11, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024001614, 12, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808001615, 1, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808001615, 2, 90, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808001615, 3, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808001615, 4, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808001615, 5, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 1, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 2, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 3, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 4, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 5, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080717001616, 6, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 17, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 1, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 2, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 3, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 4, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 5, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 6, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 7, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 8, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 9, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 10, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 11, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826003117, 12, 22, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 1, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 2, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 3, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 4, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 5, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 6, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 7, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 8, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 9, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 10, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 11, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005003118, 12, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 1, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 2, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 3, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 4, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 5, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 6, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 7, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 8, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 9, 159, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 10, 64, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 11, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 12, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226003119, 13, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 1, 116, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 2, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 3, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 4, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 5, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702003120, 6, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 1, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 2, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 3, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 4, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 5, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 6, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 7, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 8, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 9, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125003121, 10, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 1, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 2, 145, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 3, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 4, 109, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 5, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 6, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 7, 87, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 8, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 9, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 10, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 11, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 12, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 13, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 14, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 15, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 16, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316003122, 17, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 1, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 2, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 3, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 4, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 5, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 6, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 7, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 8, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 9, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003123, 10, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 1, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 2, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 3, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 4, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 5, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 6, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 7, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 8, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 9, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 10, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 11, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 12, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419003124, 13, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 1, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 2, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 3, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 4, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 5, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 6, 51, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304003125, 7, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 1, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 2, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 3, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 4, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 5, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 6, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 7, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 8, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 9, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715003126, 10, 126, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 1, 18, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 2, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 3, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 4, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 5, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 6, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 7, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 8, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 9, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 10, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003127, 11, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 1, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 2, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 3, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 4, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 5, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 6, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 7, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714003128, 8, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 1, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 2, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 3, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 4, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 5, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 6, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 7, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 8, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 9, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 10, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 11, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 12, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 13, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 14, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 15, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 16, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 17, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003129, 18, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 1, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 2, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 3, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 4, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 5, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 6, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 7, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 8, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 9, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 10, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 11, 178, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 12, 86, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 13, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 14, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 15, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 16, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 17, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324003130, 18, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 1, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 2, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 3, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 4, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 5, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 6, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 7, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 8, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 9, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 10, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 11, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 12, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003131, 13, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 1, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 2, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 3, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 4, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 5, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127003132, 6, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 1, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 2, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 3, 55, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 4, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 5, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 6, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 7, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 8, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 9, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 10, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 11, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 12, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 13, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 14, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 15, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 16, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915003133, 17, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 1, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 2, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 3, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 4, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 5, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 6, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015003134, 7, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 1, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 2, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 3, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 4, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 5, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 6, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 7, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 8, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 9, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 10, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 11, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 12, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027003135, 13, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628003136, 1, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628003136, 2, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628003136, 3, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020628003136, 4, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 1, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 2, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 3, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 4, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 5, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 6, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003137, 7, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 1, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 2, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 3, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 4, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 5, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 6, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 8, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 9, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 1, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 2, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 3, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 4, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 5, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 6, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 7, 54, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 8, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 9, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915003477, 10, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 1, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 2, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 3, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 4, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 5, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 6, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 7, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 8, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 9, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 10, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 11, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 12, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 13, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416003478, 14, 42, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 1, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 2, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 3, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 4, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 5, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301003479, 6, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307003480, 1, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000307003480, 2, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 1, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 2, 1, 50, 3, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 3, 139, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 4, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 5, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 6, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 7, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 8, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 9, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 10, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003481, 11, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404003482, 1, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404003482, 2, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404003482, 3, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404003482, 4, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 1, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 2, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 3, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 4, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 5, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 6, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 7, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129003483, 8, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003484, 1, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003484, 2, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003484, 3, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003484, 4, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003484, 5, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 1, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 2, 139, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 3, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 4, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 5, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 6, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 7, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 8, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 9, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101003485, 10, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 1, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 2, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 3, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 4, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 5, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 6, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 7, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 8, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 9, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 10, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 11, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 12, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 13, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 14, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101003486, 15, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 1, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 2, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 3, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 4, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 5, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 6, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 7, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 8, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 9, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 10, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 11, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001003487, 12, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 1, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 2, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 3, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 4, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 5, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 6, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 7, 165, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 8, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 9, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 10, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 11, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126003488, 12, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016003489, 1, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016003489, 2, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016003489, 3, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016003489, 4, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016003489, 5, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 1, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 2, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 3, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 4, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 5, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 6, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 7, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 8, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 9, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 10, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 11, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 12, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100704003490, 13, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 1, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 2, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 3, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 4, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 5, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 6, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 7, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 8, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 9, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 10, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 11, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 12, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 13, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202003491, 14, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 1, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 2, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 3, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 4, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 5, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 6, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002003492, 7, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313003493, 1, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313003493, 2, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313003493, 3, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313003493, 4, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313003493, 5, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 1, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 2, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 3, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 4, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 5, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 6, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 7, 107, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 8, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 9, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 10, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 11, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 12, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 13, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 14, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613003494, 15, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329003495, 1, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329003495, 2, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329003495, 3, 97, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329003495, 4, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 1, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 2, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 3, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 4, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 5, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 6, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 7, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 8, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 9, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 10, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908003496, 11, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 1, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 2, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 3, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 4, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 5, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 6, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 7, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 8, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 9, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 10, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 11, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 12, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 13, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110117003497, 14, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 1, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 2, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 3, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 4, 87, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 5, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 6, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 7, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 8, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306003498, 9, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003499, 1, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003499, 2, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003499, 3, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003499, 4, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003499, 5, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 1, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 2, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 3, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 4, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 5, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 6, 50, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 7, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 8, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 9, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 10, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 11, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 12, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 13, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628003500, 14, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 1, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 2, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 3, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 4, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 5, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 6, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 7, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 8, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 9, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516003501, 10, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128003502, 1, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128003502, 2, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 5, 131, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 6, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 7, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 8, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 9, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 10, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 11, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 12, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 1, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 2, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 3, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 4, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 5, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 6, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 7, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 8, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 9, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 10, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 11, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 12, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 13, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 14, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 15, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 16, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 17, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003857, 18, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 1, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 2, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 3, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 4, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 5, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 6, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 7, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 8, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 9, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 10, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 11, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 12, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 13, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224003858, 14, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 1, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 2, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 3, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 4, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 5, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 6, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 7, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716003859, 8, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 1, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 2, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 3, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 4, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 5, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 6, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 7, 15, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 8, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 9, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 10, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 11, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 12, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 13, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 14, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823003860, 15, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106003861, 1, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106003861, 2, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106003861, 3, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106003861, 4, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106003861, 5, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 1, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 2, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 3, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 4, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 5, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 6, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 7, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 8, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 9, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 10, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 11, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 12, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003862, 13, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003863, 1, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003863, 2, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003863, 3, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003863, 4, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003863, 5, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315003864, 1, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315003864, 2, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315003864, 3, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315003864, 4, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 1, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 2, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 3, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 4, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 5, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 6, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 7, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 8, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 9, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 10, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 11, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 12, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 13, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 14, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003865, 15, 90, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 1, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 2, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 3, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 4, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 5, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 6, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 7, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 8, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 9, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 10, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 11, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 12, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 13, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 14, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 15, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 16, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313003866, 17, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613003867, 1, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613003867, 2, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613003867, 3, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613003867, 4, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722003868, 1, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722003868, 2, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722003868, 3, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722003868, 4, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722003868, 5, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 1, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 2, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 3, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 4, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 5, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 6, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 7, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 8, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 9, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 10, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 11, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 12, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 13, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 14, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 15, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 16, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 17, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614003869, 18, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003870, 1, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003870, 2, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003870, 3, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003870, 4, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003870, 5, 70, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 1, 119, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 2, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 3, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 4, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 5, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 6, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 7, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 8, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202003871, 9, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 1, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 2, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 3, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 4, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 5, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 6, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 7, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 8, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 9, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 10, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 11, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 12, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903003872, 13, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 1, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 2, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 3, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 4, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 5, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 6, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 7, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 8, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 9, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 10, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 11, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 12, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 13, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 14, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 15, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 16, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114003873, 17, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 1, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 2, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 3, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 4, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 5, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 6, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 7, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 8, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 9, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 10, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 11, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 12, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 13, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 14, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003003874, 15, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 1, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 2, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 3, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 4, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 5, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 6, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 7, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 8, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 9, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 10, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 11, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 12, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915003875, 13, 62, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418003876, 1, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418003876, 2, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 1, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 2, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 3, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 4, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 5, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 6, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 7, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 8, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 9, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 10, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 11, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419003877, 12, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 1, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 2, 62, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 3, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 4, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 13, 172, 86, 12, 1032);
commit;
prompt 27000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 14, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 15, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 16, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 17, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 18, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 1, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 2, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 3, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 4, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 5, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 6, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 7, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 8, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 9, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 10, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 11, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 12, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 13, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 14, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915002739, 15, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002740, 1, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002740, 2, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002740, 3, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002740, 4, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010612002740, 5, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 1, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 2, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 3, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 4, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 5, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 6, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 7, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 8, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 9, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 10, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531002741, 11, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029002742, 1, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029002742, 2, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029002742, 3, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029002742, 4, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029002742, 5, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414002743, 1, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414002743, 2, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414002743, 3, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414002743, 4, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414002743, 5, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 1, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 2, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 3, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 4, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 5, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212002744, 6, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 1, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 2, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 3, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 4, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 5, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 6, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 7, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 8, 90, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 9, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 10, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424002745, 11, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214002746, 1, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214002746, 2, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214002746, 3, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214002746, 4, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214002746, 5, 44, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 1, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 2, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 3, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 4, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 5, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 6, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 7, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 8, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 9, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 10, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 11, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 12, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617002747, 13, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 1, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 2, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 3, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 4, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 5, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 6, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 7, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 8, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 9, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913002748, 10, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 1, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 2, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 3, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 4, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 5, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707002749, 6, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002750, 1, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002750, 2, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002750, 3, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002750, 4, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928002750, 5, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 1, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 2, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 3, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 4, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 5, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 6, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 7, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906002751, 8, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 1, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 2, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 3, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 4, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 5, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 6, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 7, 71, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 8, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 9, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 10, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 11, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 12, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 13, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 14, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 15, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 16, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 17, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426002752, 18, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 1, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 2, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 3, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 4, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 5, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 6, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 7, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 8, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 9, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 10, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 11, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515002753, 12, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 1, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 2, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 3, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 4, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 5, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 6, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012002754, 7, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 1, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 2, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 3, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 4, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 5, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 6, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 7, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 8, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527002755, 9, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 1, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 2, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 3, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 4, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 5, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 6, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 7, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 8, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 9, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 10, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 11, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 12, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 13, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730002756, 14, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 1, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 2, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 3, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 4, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 5, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 6, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 7, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 8, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 9, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 10, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 11, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 12, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 13, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 14, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 15, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 16, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105002757, 17, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 1, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 2, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 3, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 4, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 5, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 6, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 7, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918002758, 8, 88, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 1, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 2, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 3, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 4, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 5, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 6, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 7, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 8, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 9, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 10, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 11, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 12, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 13, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 14, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921002759, 15, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 1, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 2, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 3, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 4, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 5, 94, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 6, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 7, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 8, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 9, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 10, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 11, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002760, 12, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 1, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 2, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 3, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 4, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 5, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 6, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 7, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 8, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 9, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 10, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 11, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 12, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 13, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 14, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 15, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529002761, 16, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 7, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 8, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 9, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 10, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 11, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 12, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 13, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 14, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206003138, 15, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 1, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 2, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 3, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 4, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 5, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 6, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804003139, 7, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003140, 1, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003140, 2, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003140, 3, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003140, 4, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003140, 5, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 1, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 2, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 3, 192, 48, 18, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 4, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 5, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009003141, 6, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 1, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 2, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 3, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 4, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 5, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 6, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 7, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 8, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 9, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 10, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 11, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 12, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409003142, 13, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 1, 76, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 2, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 3, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 4, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 5, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 6, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 7, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 8, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 9, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003143, 10, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 1, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 2, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 3, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 4, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 5, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 6, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 7, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 8, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 9, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 10, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 11, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 12, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 13, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 14, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 15, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506003144, 16, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 1, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 2, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 3, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 4, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 5, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 6, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311003145, 7, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 1, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 2, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 3, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 4, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 5, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119003146, 6, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 1, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 2, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 3, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 4, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 5, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 6, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 7, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 8, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 9, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 10, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 11, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 12, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 13, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 14, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 15, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 16, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 17, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426003147, 18, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 1, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 2, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 3, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 4, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 5, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 6, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 7, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 8, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 9, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 10, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 11, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 12, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 13, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 14, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 15, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 16, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 17, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 18, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129003148, 19, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407003149, 1, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407003149, 2, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407003149, 3, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407003149, 4, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407003149, 5, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 1, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 2, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 3, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 4, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 5, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 6, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 7, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 8, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 9, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 10, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 11, 96, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 12, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 13, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 14, 85, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003150, 15, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 1, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 2, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 3, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 4, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 5, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 6, 69, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 7, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 8, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 9, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 10, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 11, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 12, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 13, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517003151, 14, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 1, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 2, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 3, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 4, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 5, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 6, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 7, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 8, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 9, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 10, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 11, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 12, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100217003152, 13, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 1, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 2, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 3, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 4, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 5, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 6, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 7, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 8, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 9, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 10, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 11, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 12, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 13, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003153, 14, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 1, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 2, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 3, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 4, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 5, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 6, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 7, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 8, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 9, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 10, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 11, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 12, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 13, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 14, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130615003154, 15, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003155, 1, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003155, 2, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003155, 3, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 1, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 2, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 3, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 4, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 5, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 6, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 7, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 8, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 9, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 10, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 11, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 12, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 13, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115003156, 14, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 1, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 2, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 3, 75, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 4, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 5, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128003157, 6, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 1, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 2, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 3, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 4, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 5, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 6, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 7, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 8, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 9, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 10, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 11, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 12, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 13, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 14, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829003158, 15, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 1, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 2, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 3, 124, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 4, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 5, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 6, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 7, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 8, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128003502, 3, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128003502, 4, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 1, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 2, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 3, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 4, 117, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 5, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 6, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 7, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 8, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 9, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 10, 34, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 11, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 12, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 13, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 14, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 15, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629003503, 16, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 1, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 2, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 3, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 4, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 5, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 6, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 7, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 8, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427003504, 9, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 1, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 2, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 3, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 4, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 5, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 6, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 7, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003505, 8, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 1, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 2, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 3, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 4, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 5, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 6, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 7, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114003506, 8, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 1, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 2, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 3, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 4, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 5, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512003507, 6, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426003508, 1, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426003508, 2, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426003508, 3, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426003508, 4, 92, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 1, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 2, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 3, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 4, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 5, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319003509, 6, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 1, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 2, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 3, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 4, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 5, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 6, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 7, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003510, 8, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120003511, 1, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120003511, 2, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120003511, 3, 121, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120003511, 4, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120003511, 5, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908003512, 1, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908003512, 2, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908003512, 3, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908003512, 4, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908003512, 5, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201003513, 1, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201003513, 2, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201003513, 3, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201003513, 4, 71, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 1, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 2, 97, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 3, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 4, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 5, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106003514, 6, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801003515, 1, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801003515, 2, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801003515, 3, 158, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801003515, 4, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801003515, 5, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 1, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 2, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 3, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 4, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 5, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 6, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 7, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 8, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 9, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 10, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 11, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 12, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 13, 164, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 14, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003516, 15, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 1, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 2, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 3, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 4, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 5, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 6, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 7, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 8, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 9, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 10, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 11, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717003517, 12, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 1, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 2, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 3, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 4, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 5, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 6, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 7, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 8, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 9, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 10, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 11, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 12, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 13, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424003518, 14, 56, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 1, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 2, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 3, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 4, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 5, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 6, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 7, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 8, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 9, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 10, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003519, 11, 32, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 1, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 2, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 3, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 4, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 5, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 6, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 7, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 8, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 9, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 10, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 11, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 12, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 13, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920003520, 14, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 1, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 2, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 3, 119, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 4, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 5, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 6, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201003521, 7, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325003522, 1, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325003522, 2, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325003522, 3, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325003522, 4, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 1, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 2, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 3, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 4, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 5, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 6, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 7, 131, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 8, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 9, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 10, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 11, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 12, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 13, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518003523, 14, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 1, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 2, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 3, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 4, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 5, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 6, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 7, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 8, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 9, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 10, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 11, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 12, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 13, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 14, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 15, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 16, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730003524, 17, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 1, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 2, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 3, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 4, 49, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 5, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 6, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 7, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926003525, 8, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 1, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 2, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 3, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 4, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 5, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 6, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 7, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 8, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 9, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 10, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 11, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 12, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214003526, 13, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 1, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 2, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 3, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 4, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 5, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 6, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 7, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 8, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 9, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 10, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 11, 134, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 12, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506003527, 13, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 1, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 2, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 3, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 4, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 5, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 5, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 6, 177, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 7, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 8, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 9, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708003878, 10, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 1, 77, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 2, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 3, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 4, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 5, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 6, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 7, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 8, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 9, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127003879, 10, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 1, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 2, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 3, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 4, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 5, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 6, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 7, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 8, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 9, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 10, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 11, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 12, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 13, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 14, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 15, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305003880, 16, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 1, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 2, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 3, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 4, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 5, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 6, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 7, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 8, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 9, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 10, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 11, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003881, 12, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 1, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 2, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 3, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 4, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 5, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 6, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 7, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 8, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 9, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 10, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101003882, 11, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 1, 117, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 2, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 3, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 4, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 5, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 6, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003883, 7, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 1, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 2, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 3, 106, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 4, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 5, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 6, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117003884, 7, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 1, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 2, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 3, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 4, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 5, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 6, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127003885, 7, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 1, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 2, 48, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 3, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 4, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 5, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 6, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 7, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 8, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 9, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 10, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 11, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003886, 12, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623003887, 1, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623003887, 2, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623003887, 3, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 1, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 2, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 3, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 4, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 5, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 6, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003888, 7, 23, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003889, 1, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003889, 2, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003889, 3, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003889, 4, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003889, 5, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 1, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 2, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 3, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 4, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 5, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 6, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 7, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 8, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 9, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 10, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 11, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 12, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 13, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 14, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 15, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302003890, 16, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 1, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 2, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 3, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 4, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 5, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 6, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 7, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 8, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 9, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 10, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 11, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927003891, 12, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009003892, 1, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009003892, 2, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009003892, 3, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009003892, 4, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 1, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 2, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 3, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 4, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 5, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030003893, 6, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719003894, 1, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719003894, 2, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719003894, 3, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719003894, 4, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 1, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 2, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 3, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 4, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 5, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 6, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 7, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 8, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 9, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 10, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 11, 97, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 12, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 13, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 14, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 15, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 16, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425003895, 17, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000423003896, 1, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000423003896, 2, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 1, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 2, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 3, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 4, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 5, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 6, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 7, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 8, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 9, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 10, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 11, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080909003897, 12, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 1, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 2, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 3, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 4, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 5, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 6, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 7, 19, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329003898, 8, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 1, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 2, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 3, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 4, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 5, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 6, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 7, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 8, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 9, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 10, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 11, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 12, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423003899, 13, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410003900, 1, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410003900, 2, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410003900, 3, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410003900, 4, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410003900, 5, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 1, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 2, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 3, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 4, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 5, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 6, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 7, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 8, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 9, 139, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 10, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 11, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 12, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 13, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 14, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003901, 15, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021003902, 1, 22, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021003902, 2, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021003902, 3, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021003902, 4, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021003902, 5, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 1, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 2, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 3, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 4, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 5, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 6, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 7, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 8, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 9, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 10, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 11, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 12, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 13, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 14, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421003903, 15, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003904, 1, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003904, 2, 148, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 1, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 2, 174, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 3, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 4, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 5, 23, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 6, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 7, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 8, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 9, 78, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 10, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 11, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 12, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 13, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 14, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 15, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 16, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204002762, 17, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123002763, 1, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123002763, 2, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123002763, 3, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 1, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 2, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 3, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 4, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 5, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 6, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 7, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 8, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 9, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 10, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 11, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 12, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302002764, 13, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 1, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 2, 101, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 3, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 4, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 5, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 6, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 7, 1, 39, 3, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 8, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 9, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105002765, 10, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 1, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 2, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 3, 10, 51, 5, 255);
commit;
prompt 28000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 4, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 5, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 6, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 7, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 8, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 9, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723002766, 10, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 1, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 2, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 3, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 4, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 5, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106002767, 6, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 1, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 2, 143, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 3, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 4, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 5, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 6, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 7, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 8, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 9, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 10, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 11, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521002768, 12, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122002769, 1, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122002769, 2, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122002769, 3, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122002769, 4, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 1, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 2, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 3, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 4, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 5, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 6, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909002770, 7, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 1, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 2, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 3, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 4, 170, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 5, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 6, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 7, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 8, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024002771, 9, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 1, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 2, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 3, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 4, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 5, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 6, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 7, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 8, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 9, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 10, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 11, 80, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111002772, 12, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 1, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 2, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 3, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 4, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 5, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 6, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 7, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 8, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 9, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 10, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 11, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 12, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 13, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 14, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 15, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 16, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 17, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908002773, 18, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 1, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 2, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 3, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 4, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 5, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 6, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 7, 78, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 8, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 9, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 10, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 11, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 12, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 13, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 14, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 15, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222002774, 16, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 1, 92, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 2, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 3, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 4, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 5, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 6, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 7, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 8, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 9, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 10, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 11, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 12, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 13, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 14, 1, 39, 3, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 15, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 16, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330002775, 17, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126002776, 1, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126002776, 2, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126002776, 3, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126002776, 4, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126002776, 5, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 1, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 2, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 3, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 4, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 5, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 6, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 7, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 8, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002777, 9, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731002778, 1, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731002778, 2, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731002778, 3, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731002778, 4, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731002778, 5, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320002779, 1, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320002779, 2, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320002779, 3, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320002779, 4, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320002779, 5, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415002780, 1, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415002780, 2, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415002780, 3, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415002780, 4, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 1, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 2, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 3, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 4, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 5, 61, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 6, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 7, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 8, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 9, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 10, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 11, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124002781, 12, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 1, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 2, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 3, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 4, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 5, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 6, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 7, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130002782, 8, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 1, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 2, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 3, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 4, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 5, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 6, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 7, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 8, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 9, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 10, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 11, 1, 2, 3, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017002783, 12, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 1, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 2, 177, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 3, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 4, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 5, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 6, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 7, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 8, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 9, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 10, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 11, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 12, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 13, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 14, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124002784, 15, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 1, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 2, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 3, 99, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 4, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 5, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 6, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 7, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 8, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 9, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 10, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 9, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 10, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 11, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119003159, 12, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 1, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 2, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 3, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 4, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 5, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 6, 34, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 7, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 8, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 9, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 10, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 11, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 12, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 13, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 14, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207003160, 15, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 1, 152, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 2, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 3, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 4, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 5, 190, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 6, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015003161, 7, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 1, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 2, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 3, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 4, 59, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 5, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 6, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 7, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 8, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 9, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 10, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 11, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 12, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 13, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 14, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 15, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 16, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510003162, 17, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003163, 1, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003163, 2, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003163, 3, 1, 22, 3, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811003163, 4, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 1, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 2, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 3, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 4, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 5, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 6, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 7, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 8, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 9, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831003164, 10, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 1, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 2, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 3, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 4, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 5, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 6, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 7, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 8, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 9, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423003165, 10, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 1, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 2, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 3, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 4, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 5, 83, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 6, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 7, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 8, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 9, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 10, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003166, 11, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910003167, 1, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910003167, 2, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910003167, 3, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910003167, 4, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 1, 118, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 2, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 3, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 4, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 5, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 6, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 7, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 8, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 9, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 10, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 11, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 12, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 13, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 14, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410003168, 15, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 1, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 2, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 3, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 4, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 5, 1, 79, 3, 237);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 6, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 7, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 8, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 9, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 10, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305003169, 11, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 1, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 2, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 3, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 4, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 5, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 6, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 7, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 8, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 9, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710003170, 10, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 1, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 2, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 3, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 4, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 5, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 6, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 7, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731003171, 8, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 1, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 2, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 3, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 4, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 5, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 6, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 7, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 8, 156, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 9, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 10, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 11, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 12, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 13, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411003172, 14, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 1, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 2, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 3, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 4, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 5, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 6, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 7, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 8, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 9, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 10, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 11, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 12, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 13, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513003173, 14, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 1, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 2, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 3, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 4, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 5, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 6, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 7, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 8, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121003174, 9, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 1, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 2, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 3, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 4, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 5, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 6, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 7, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 8, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 9, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 10, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 11, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 12, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 13, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 14, 83, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230003175, 15, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 1, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 2, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 3, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 4, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 5, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 6, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 7, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 8, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 9, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 10, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 11, 57, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 12, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226003176, 13, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 1, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 2, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 3, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 4, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 5, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 6, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 7, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 8, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 9, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512003177, 10, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023003178, 1, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023003178, 2, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023003178, 3, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023003178, 4, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 1, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 2, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 3, 65, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 4, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 5, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026003179, 6, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 1, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 2, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 3, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 4, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 5, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120003180, 6, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 1, 87, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 2, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 3, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 4, 1, 11, 3, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 5, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 6, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 7, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 8, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 9, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 10, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 11, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 12, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 13, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320003181, 14, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000724003182, 1, 78, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000724003182, 2, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000724003182, 3, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000724003182, 4, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327003183, 1, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327003183, 2, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327003183, 3, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327003183, 4, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 6, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 7, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 8, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 9, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 10, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822003528, 11, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 1, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 2, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 3, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 4, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 5, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 6, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 7, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 8, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 9, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501003529, 10, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806003530, 1, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806003530, 2, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806003530, 3, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806003530, 4, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806003530, 5, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 1, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 2, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 3, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 4, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 5, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 6, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 7, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 8, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 9, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 10, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 11, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 12, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 13, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 14, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 15, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 16, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003531, 17, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 1, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 2, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 3, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 4, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 5, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 6, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 7, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 8, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 9, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 10, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 11, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 12, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714003532, 13, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904003533, 1, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904003533, 2, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904003533, 3, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904003533, 4, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904003533, 5, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 1, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 2, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 3, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 4, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 5, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 6, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 7, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050416003534, 8, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403003535, 1, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403003535, 2, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403003535, 3, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403003535, 4, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 1, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 2, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 3, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 4, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 5, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503003536, 6, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 1, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 2, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 3, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 4, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 5, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 6, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 7, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 8, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 9, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 10, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 11, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 12, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 13, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 14, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 15, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225003537, 16, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 1, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 2, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 3, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 4, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 5, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 6, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 7, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523003538, 8, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 1, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 2, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 3, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 4, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 5, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817003539, 6, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301003540, 1, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301003540, 2, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301003540, 3, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301003540, 4, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 1, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 2, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 3, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 4, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 5, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 6, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 7, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 8, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 9, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 10, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 11, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 12, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 13, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 14, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425003541, 15, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 1, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 2, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 3, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 4, 71, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 5, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040204003542, 6, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 1, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 2, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 3, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 4, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 5, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 6, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 7, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 8, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 9, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 10, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 11, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 12, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 13, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 14, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 15, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416003543, 16, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 1, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 2, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 3, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 4, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 5, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 6, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 7, 130, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714003544, 8, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 1, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 2, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 3, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 4, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 5, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 6, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 7, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 8, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 9, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 10, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 11, 161, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 12, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 13, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011003545, 14, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 1, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 2, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 3, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 4, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 5, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 6, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 7, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 8, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 9, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 10, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304003546, 11, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 1, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 2, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 3, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 4, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 5, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 6, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816003547, 7, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 1, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 2, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 3, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 4, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 5, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 6, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 7, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 8, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130003548, 9, 109, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 1, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 2, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 3, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 4, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 5, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 6, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 7, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 8, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 9, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 10, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 11, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 12, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 13, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 14, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 15, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417003549, 16, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528003550, 1, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528003550, 2, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528003550, 3, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528003550, 4, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 1, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 2, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 3, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 4, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 5, 13, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 6, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 7, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 8, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 9, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 10, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 11, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 12, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331003551, 13, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 1, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 2, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 3, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 4, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 5, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 6, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 7, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 8, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 9, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 10, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 11, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 12, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003904, 3, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003904, 4, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 1, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 2, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 3, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 4, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 5, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 6, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 7, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 8, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 9, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 10, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 11, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606003905, 12, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 1, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 2, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 3, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 4, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 5, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 6, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 7, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 8, 191, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 9, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 10, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 11, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 12, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 13, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 14, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 15, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 16, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 17, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213003906, 18, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 1, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 2, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 3, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 4, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 5, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 6, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 7, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 8, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 9, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 10, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 11, 137, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421003907, 12, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 1, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 2, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 3, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 4, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 5, 189, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 6, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 7, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 8, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 9, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 10, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223003908, 11, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 1, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 2, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 3, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 4, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 5, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 6, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 7, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 8, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 9, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 10, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003909, 11, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000311003910, 1, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000311003910, 2, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000311003910, 3, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000311003910, 4, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 1, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 2, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 3, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 4, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 5, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111003911, 6, 154, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 1, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 2, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 3, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 4, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 5, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 6, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 7, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 8, 27, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 9, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 10, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 11, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 12, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 13, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 14, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514003912, 15, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 1, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 2, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 3, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 4, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 5, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 6, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 7, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 8, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 9, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 10, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 11, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 12, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 13, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 14, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603003913, 15, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 1, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 2, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 3, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 4, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 5, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 6, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 7, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 8, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 9, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 10, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 11, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 12, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 13, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 14, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 15, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003914, 16, 154, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 1, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 2, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 3, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 4, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 5, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 6, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 7, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 8, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 9, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 10, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716003915, 11, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003916, 1, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003916, 2, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003916, 3, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405003916, 4, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 1, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 2, 162, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 3, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 4, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 5, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 6, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 7, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 8, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 9, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 10, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 11, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 12, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 13, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007003917, 14, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 1, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 2, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 3, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 4, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 5, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 6, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 7, 106, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 8, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 9, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 10, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 11, 166, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 12, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004003918, 13, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 1, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 2, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 3, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 4, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 5, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 6, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 7, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 8, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 9, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 10, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 11, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 12, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 13, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 14, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 15, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 16, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725003919, 17, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101003920, 1, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101003920, 2, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101003920, 3, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101003920, 4, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101003920, 5, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 1, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 2, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 3, 176, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 4, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 5, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 6, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 7, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220003921, 8, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720003922, 1, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720003922, 2, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720003922, 3, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 1, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 2, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 3, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 4, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 5, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 6, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 7, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 8, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 9, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 10, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 11, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 12, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 13, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102003923, 14, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 1, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 2, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 3, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 4, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 5, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 6, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724003924, 7, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 1, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 2, 69, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 3, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 4, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 5, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 6, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 7, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 8, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325003925, 9, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 1, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 2, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 3, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 4, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 5, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 6, 171, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 7, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 8, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 9, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 10, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 11, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 12, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 11, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 12, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 13, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410002785, 14, 21, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 1, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 2, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 3, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 4, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 5, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 6, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 7, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 8, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 9, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 10, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 11, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 12, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 13, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323002786, 14, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325002787, 1, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325002787, 2, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325002787, 3, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325002787, 4, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804002788, 1, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804002788, 2, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804002788, 3, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804002788, 4, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 1, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 2, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 3, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 4, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 5, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 6, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 7, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 8, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212002789, 9, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 1, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 2, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 3, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 4, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 5, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 6, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517002790, 7, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 1, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 2, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 3, 133, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 4, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 5, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 6, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 7, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826002791, 8, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510002792, 1, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510002792, 2, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510002792, 3, 47, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510002792, 4, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002793, 1, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002793, 2, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002793, 3, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002793, 4, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002793, 5, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 1, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 2, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 3, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 4, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 5, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 6, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 7, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 8, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 9, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 10, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 11, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 12, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 13, 137, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 14, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 15, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 16, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 17, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705002794, 18, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 1, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 2, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 3, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 4, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 5, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 6, 143, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 7, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 8, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 9, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 10, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 11, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 12, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 13, 103, 65, 12, 780);
commit;
prompt 29000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 14, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 15, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002795, 16, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 1, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 2, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 3, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 4, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 5, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 6, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 7, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 8, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 9, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 10, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 11, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 12, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 13, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 14, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 15, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 16, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702002796, 17, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 1, 155, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 2, 104, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 3, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 4, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 5, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 6, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 7, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 8, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 9, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 10, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002797, 11, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 1, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 2, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 3, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 4, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 5, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 6, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002798, 7, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 1, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 2, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 3, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 4, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 5, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 6, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 7, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 8, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 9, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 10, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 11, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 12, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 13, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002799, 14, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 1, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 2, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 3, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 4, 57, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 5, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 6, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 7, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116002800, 8, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001229002801, 1, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001229002801, 2, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001229002801, 3, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001229002801, 4, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001229002801, 5, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 1, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 2, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 3, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 4, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 5, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 6, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621002802, 7, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 1, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 2, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 3, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 4, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 5, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 6, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 7, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 8, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 9, 19, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630002803, 10, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 1, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 2, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 3, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 4, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 5, 132, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 6, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201002804, 7, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 1, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 2, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 3, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 4, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 5, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 6, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 7, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 8, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 9, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 10, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 11, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 12, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100610002805, 13, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 1, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 2, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 3, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 4, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 5, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 6, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 7, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 8, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 9, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 10, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131002806, 11, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 1, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 2, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 3, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 4, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 5, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 6, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 7, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 8, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 9, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 10, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907002807, 11, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 1, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 2, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 3, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 4, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 5, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 6, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 7, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 8, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 9, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 10, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 11, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 12, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 13, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 14, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422002808, 15, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 1, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 2, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 3, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 4, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 5, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 6, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 7, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103002809, 8, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 1, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 2, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327003183, 5, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 1, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 2, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 3, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 4, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 5, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 6, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 7, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 8, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 9, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 10, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106003184, 11, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 1, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 2, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 3, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 4, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 5, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 6, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 7, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 8, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 9, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 10, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 11, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 12, 43, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 13, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 14, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 15, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 16, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329003185, 17, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 1, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 2, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 3, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 4, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 5, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 6, 72, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 7, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 8, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415003186, 9, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 1, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 2, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 3, 41, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 4, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 5, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630003187, 6, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 1, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 2, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 3, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 4, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 5, 119, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 6, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 7, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 8, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 9, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 10, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 11, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 12, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 13, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 14, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 15, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 16, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221003188, 17, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 1, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 2, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 3, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 4, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 5, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 6, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 7, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 8, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927003189, 9, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 1, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 2, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 3, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 4, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 5, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 6, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 7, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 8, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 9, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 10, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 11, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 12, 124, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 13, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 14, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 15, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 16, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 17, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301003190, 18, 107, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 1, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 2, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 3, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 4, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 5, 165, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 6, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 7, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 8, 150, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 9, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 10, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730003191, 11, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 1, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 2, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 3, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 5, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 6, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 7, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 8, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 9, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 10, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 11, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 12, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 13, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 14, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 15, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226003192, 16, 1, 88, 3, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 1, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 2, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 3, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 4, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 5, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 6, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 7, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 8, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 9, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 10, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 11, 135, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 12, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309003193, 13, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 1, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 2, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 3, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 4, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 5, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 6, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 7, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 8, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 9, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003194, 10, 139, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 1, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 2, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 3, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 4, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 5, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 6, 152, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 7, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 8, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 9, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 10, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 11, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 12, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824003195, 13, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618003196, 1, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618003196, 2, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618003196, 3, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 1, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 2, 192, 87, 18, 1566);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 3, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 4, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 5, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 6, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 7, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 8, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 9, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 10, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 11, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 12, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018003197, 13, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 1, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 2, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 3, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 4, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 5, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 6, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 7, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 8, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 9, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 10, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 11, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 12, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 13, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 14, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003198, 15, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230003199, 1, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230003199, 2, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230003199, 3, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230003199, 4, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 1, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 2, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 3, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 4, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 5, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 6, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 7, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 8, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 9, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 10, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830003200, 11, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 1, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 2, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 3, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 4, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 5, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 6, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051225003201, 7, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401003202, 1, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401003202, 2, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401003202, 3, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 1, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 2, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 3, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 4, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 5, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101003203, 6, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 1, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 2, 83, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 3, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 4, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 5, 176, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 6, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 7, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 8, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 9, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 10, 166, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 11, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 12, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 13, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327003204, 14, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 1, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 2, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 3, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 4, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 5, 118, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 6, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 7, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 8, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 9, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 10, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 11, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 12, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 13, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101003552, 14, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 1, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 2, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 3, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 4, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 5, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 6, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 7, 192, 96, 18, 1728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 8, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 9, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 10, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 11, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 12, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 13, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 14, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 15, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 16, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106003553, 17, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 1, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 2, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 3, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 4, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 5, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320003554, 6, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503003555, 1, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503003555, 2, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503003555, 3, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503003555, 4, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503003555, 5, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 1, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 2, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 3, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 4, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 5, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 6, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 7, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205003556, 8, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003557, 1, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003557, 2, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003557, 3, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003557, 4, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923003557, 5, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 1, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 2, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 3, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 4, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 5, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 6, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 7, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 8, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 9, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 10, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 11, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818003558, 12, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 1, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 2, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 3, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 4, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 5, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 6, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 7, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 8, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 9, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028003559, 10, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 1, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 2, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 3, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 4, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 5, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 6, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 7, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 8, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 9, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 10, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219003560, 11, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 1, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 2, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 3, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 4, 53, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 5, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 6, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 7, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 8, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 9, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 10, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 11, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003561, 12, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 1, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 2, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 3, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 4, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 5, 113, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 6, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 7, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 8, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 9, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 10, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 11, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227003562, 12, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 1, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 2, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 3, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 4, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 5, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 6, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 7, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 8, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 9, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 10, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 11, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 12, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 13, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 14, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 15, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 16, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 17, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118003563, 18, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 1, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 2, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 3, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 4, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 5, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413003564, 6, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 1, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 2, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 3, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 4, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 5, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 6, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 7, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 8, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910003565, 9, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 1, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 2, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 3, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 4, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 5, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 6, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 7, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 8, 13, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 9, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 10, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 11, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 12, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 13, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 14, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 15, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 16, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217003566, 17, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 1, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 2, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 3, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 4, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 5, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 6, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 7, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 8, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430003567, 9, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 1, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 2, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 3, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 4, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 5, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 6, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 7, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 8, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 9, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 10, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 11, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003003568, 12, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 1, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 2, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 3, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 4, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 5, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 6, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115003569, 7, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 1, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 2, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 3, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 4, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 5, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 6, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 7, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 8, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 9, 47, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516003570, 10, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 1, 180, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 2, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 3, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 4, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 5, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 6, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 7, 8, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426003571, 8, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 1, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 2, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 3, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 4, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 5, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 6, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 7, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 8, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 9, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 10, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 11, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 12, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 13, 187, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 14, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 15, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405003572, 16, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 1, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 2, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 3, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 4, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 5, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707003573, 6, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 1, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 2, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 3, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 4, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 5, 47, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 6, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108003574, 7, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 1, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 2, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 3, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 4, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 5, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 6, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 7, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 8, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 9, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 10, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 11, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 12, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 13, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 14, 91, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 13, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 14, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002003926, 15, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 1, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 2, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 3, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 4, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 5, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 6, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 7, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809003927, 8, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 1, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 2, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 3, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 4, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 5, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 6, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 7, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 8, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 9, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 10, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 11, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 12, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 13, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 14, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003928, 15, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 1, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 2, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 3, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 4, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 5, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 6, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 7, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 8, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 9, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 10, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 11, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815003929, 12, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 1, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 2, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 3, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 4, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 5, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 6, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108003930, 7, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 1, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 2, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 3, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 4, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 5, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 6, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 7, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040117003931, 8, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 1, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 2, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 3, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 4, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 5, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 6, 107, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 7, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 8, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 9, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 10, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 11, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104003932, 12, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 1, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 2, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 3, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 4, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 5, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 6, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 7, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414003933, 8, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 1, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 2, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 3, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 4, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 5, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 6, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 7, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 8, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 9, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 10, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 11, 154, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 12, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 13, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 14, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 15, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 16, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003934, 17, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011003935, 1, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011003935, 2, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011003935, 3, 29, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011003935, 4, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 1, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 2, 139, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 3, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 4, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 5, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 6, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 7, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 8, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 9, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 10, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 11, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 12, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 13, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 14, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 15, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110810003936, 16, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 1, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 2, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 3, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 4, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 5, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 6, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 7, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 8, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 9, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 10, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 11, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 12, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 13, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 14, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625003937, 15, 147, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 1, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 2, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 3, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 4, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 5, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 6, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826003938, 7, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 1, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 2, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 3, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 4, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 5, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 6, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 7, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 8, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 9, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 10, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 11, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 12, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 13, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 14, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 15, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712003939, 16, 120, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 1, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 2, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 3, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 4, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 5, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 6, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 7, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 8, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 9, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 10, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 11, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522003940, 12, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 1, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 2, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 3, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 4, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 5, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 6, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 7, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 8, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 9, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 10, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 11, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 12, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 13, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910003941, 14, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 1, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 2, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 3, 165, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 4, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 5, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 6, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 7, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 8, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 9, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 10, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 11, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 12, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 13, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 14, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 15, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912003942, 16, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 1, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 2, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 3, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 4, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 5, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 6, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227003943, 7, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 1, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 2, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 3, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 4, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 5, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806003944, 6, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 1, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 2, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 3, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 4, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 5, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 6, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030527003945, 7, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 1, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 2, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 3, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 4, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 5, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 6, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 7, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 8, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 9, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 10, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 11, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 12, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 13, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 14, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908003946, 15, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 1, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 2, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 3, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 4, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 5, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 6, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 7, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 8, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 9, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 10, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 11, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 12, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 13, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 14, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 3, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 4, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 5, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 6, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 7, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 8, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 9, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 10, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 11, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 12, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 13, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929002810, 14, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 1, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 2, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 3, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 4, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 5, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 6, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 7, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 8, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 9, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 10, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023002811, 11, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 1, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 2, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 3, 192, 41, 18, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 4, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 5, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 6, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 7, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 8, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730002812, 9, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313002813, 1, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313002813, 2, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313002813, 3, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313002813, 4, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313002813, 5, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 1, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 2, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 3, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 4, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 5, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 6, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 7, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 8, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 9, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 10, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 11, 69, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 12, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 13, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 14, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002814, 15, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103002815, 1, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103002815, 2, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103002815, 3, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103002815, 4, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103002815, 5, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 1, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 2, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 3, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 4, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 5, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 6, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 7, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 8, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 9, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 10, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 11, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 12, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 13, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 14, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 15, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 16, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828002816, 17, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903002817, 1, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903002817, 2, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903002817, 3, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903002817, 4, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903002817, 5, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 1, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 2, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 3, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 4, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 5, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 6, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 7, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 8, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 9, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 10, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107002818, 11, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 1, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 2, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 3, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 4, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 5, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 6, 167, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 7, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017002819, 8, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 1, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 2, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 3, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 4, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 5, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 6, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 7, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 8, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 9, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 10, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 11, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 12, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 13, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 14, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 15, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627002820, 16, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 1, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 2, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 3, 126, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 4, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 5, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 6, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 7, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 8, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 9, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 10, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 11, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 12, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 13, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 14, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 15, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 16, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806002821, 17, 41, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 1, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 2, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 3, 192, 78, 18, 1404);
commit;
prompt 30000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 4, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 5, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 6, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 7, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 8, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 9, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 10, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812002822, 11, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 1, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 2, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 3, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 4, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 5, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627002823, 6, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 1, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 2, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 3, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 4, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 5, 180, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 6, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 7, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 8, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 9, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 10, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 11, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213002824, 12, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 1, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 2, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 3, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 4, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 5, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 6, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 7, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 8, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 9, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 10, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 11, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 12, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324002825, 13, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 1, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 2, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 3, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 4, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 5, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 6, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 7, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129002826, 8, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 1, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 2, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 3, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 4, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 5, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 6, 161, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 7, 68, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 8, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 9, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 10, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 11, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 12, 90, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 13, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423002827, 14, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 1, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 2, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 3, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 4, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 5, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 6, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423002828, 7, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 1, 183, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 2, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 3, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 4, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 5, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 6, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 7, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 8, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 9, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 10, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 11, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 12, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 13, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 14, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 15, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 16, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321002829, 17, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 1, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 2, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 3, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 4, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 5, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 6, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 7, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 8, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 9, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 10, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722002830, 11, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 1, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 2, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 3, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 4, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 5, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210002831, 6, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124002832, 1, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124002832, 2, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124002832, 3, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 13, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 14, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 15, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227003205, 16, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808003206, 1, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808003206, 2, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808003206, 3, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808003206, 4, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808003206, 5, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 1, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 2, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 3, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 4, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 5, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 6, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 7, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 8, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 9, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 10, 145, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 11, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 12, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501003207, 13, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 1, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 2, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 3, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 4, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 5, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 6, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 7, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 8, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 9, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 10, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 11, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 12, 100, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 13, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003208, 14, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 1, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 2, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 3, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 4, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 5, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 6, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 7, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 8, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004003209, 9, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 1, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 2, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 3, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 4, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 5, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 6, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 7, 84, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 8, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927003210, 9, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 1, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 2, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 3, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 4, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 5, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 6, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 7, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 8, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 9, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 10, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 11, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 12, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 13, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110720003211, 14, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 1, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 2, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 3, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 4, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 5, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 6, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 7, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 8, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 9, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 10, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 11, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222003212, 12, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 1, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 2, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 3, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 4, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 5, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 6, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003213, 7, 93, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 1, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 2, 151, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 3, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 4, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 5, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 6, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316003214, 7, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 1, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 2, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 3, 89, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 4, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 5, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 6, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 7, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 8, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 9, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 10, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 11, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 12, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 13, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 14, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 15, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 16, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722003215, 17, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 1, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 2, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 3, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 4, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 5, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 6, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 7, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 8, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 9, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 10, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 11, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 12, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 13, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 14, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 15, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 16, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511003216, 17, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 1, 9, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 2, 146, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 3, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 4, 161, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 5, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020108003217, 6, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 1, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 2, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 3, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 4, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 5, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 6, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 7, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 8, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 9, 49, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 10, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 11, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 12, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 13, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090420003218, 14, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 1, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 2, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 3, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 4, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 5, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 6, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 7, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 8, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122003219, 9, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 1, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 2, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 3, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 4, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 5, 67, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 6, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031003220, 7, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 1, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 2, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 3, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 4, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 5, 35, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 6, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 7, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 8, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 9, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 10, 48, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607003221, 11, 177, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222003222, 1, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222003222, 2, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222003222, 3, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222003222, 4, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 1, 1, 27, 3, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 2, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 3, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 4, 76, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 5, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 6, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 7, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 8, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 9, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 10, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 11, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 12, 1, 50, 3, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 13, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 14, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110730003223, 15, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510003224, 1, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510003224, 2, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510003224, 3, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 1, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 2, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 3, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 4, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 5, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 6, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 7, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 8, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 9, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 10, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 11, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 12, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 13, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 14, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 15, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120511003225, 16, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123003226, 1, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123003226, 2, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123003226, 3, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123003226, 4, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 1, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 2, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 3, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 4, 111, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 5, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 6, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 7, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 8, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 9, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 10, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 11, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 12, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 13, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009003227, 14, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 1, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 2, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 3, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 4, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 5, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 6, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 7, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 8, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 15, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 16, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116003575, 17, 25, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 1, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 2, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 3, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 4, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 5, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 6, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 7, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 8, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 9, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 10, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 11, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 12, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 13, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 14, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130423003576, 15, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 1, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 2, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 3, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 4, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 5, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 6, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 7, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 8, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 9, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 10, 51, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 11, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 12, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 13, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017003577, 14, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 1, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 2, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 3, 69, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 4, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 5, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 6, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 7, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 8, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 9, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 10, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 11, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 12, 154, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 13, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 14, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 15, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 16, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120003578, 17, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 1, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 2, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 3, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 4, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 5, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 6, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 7, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 8, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 9, 161, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 10, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 11, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109003579, 12, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 1, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 2, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 3, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 4, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 5, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707003580, 6, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 1, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 2, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 3, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 4, 35, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 5, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 6, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 7, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 8, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 9, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 10, 131, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207003581, 11, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 1, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 2, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 3, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 4, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 5, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 6, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 7, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 8, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 9, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 10, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 11, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 12, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 13, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 14, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711003582, 15, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 1, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 2, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 3, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 4, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 5, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 6, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 7, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 8, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 9, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 10, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713003583, 11, 192, 75, 18, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 1, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 2, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 3, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 4, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 5, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 6, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 7, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 8, 89, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 9, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 10, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 11, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 12, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 13, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426003584, 14, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 1, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 2, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 3, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 4, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 5, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 6, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 7, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 8, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 9, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 10, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 11, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 12, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 13, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 14, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917003585, 15, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 1, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 2, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 3, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 4, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 5, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 6, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 7, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 8, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 9, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 10, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 11, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 12, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 13, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 14, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911003586, 15, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 1, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 2, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 3, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 4, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 5, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 6, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 7, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 8, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 9, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 10, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 11, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 12, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 13, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 14, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 15, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 16, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 17, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 18, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206003587, 19, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715003588, 1, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715003588, 2, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715003588, 3, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 1, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 2, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 3, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 4, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 5, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 6, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 7, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 8, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 9, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 10, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924003589, 11, 83, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 1, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 2, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 3, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 4, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 5, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 6, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 7, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 8, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 9, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 10, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 11, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 12, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 13, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 14, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 15, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 16, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310003590, 17, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 1, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 2, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 3, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 4, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 5, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 6, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 7, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 8, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 9, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 10, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 11, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 12, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 13, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 14, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 15, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823003591, 16, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 1, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 2, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 3, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 4, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 5, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 6, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 7, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 8, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 9, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 10, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 11, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 12, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 13, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003592, 14, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 1, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 2, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 3, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 4, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 5, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930003593, 6, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 1, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 2, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 3, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 4, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 3, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 4, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 5, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 6, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 7, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 8, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 9, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 10, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 1, 23, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 2, 185, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 3, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 4, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 5, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 6, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 7, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 8, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 9, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 10, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 11, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 12, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509004038, 13, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 1, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 2, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 3, 111, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 4, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 5, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 6, 68, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 7, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 8, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 9, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 10, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 11, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 12, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513004039, 13, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 1, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 2, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 3, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 4, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 5, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 6, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 7, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 8, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 9, 110, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004040, 10, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 1, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 2, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 3, 192, 8, 18, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 4, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 5, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 6, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 7, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 8, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615004041, 9, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 1, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 2, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 3, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 4, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 5, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 6, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211004042, 7, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 1, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 2, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 3, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 4, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 5, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 6, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 7, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 8, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 9, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 10, 41, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 11, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 12, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 13, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411004043, 14, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 1, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 2, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 3, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 4, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 5, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 6, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 7, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 8, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 9, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331004044, 10, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 1, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 2, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 3, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 4, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 5, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 6, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 7, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 8, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 9, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 10, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 11, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414004045, 12, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 1, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 2, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 3, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 4, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 5, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 6, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 7, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 8, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 9, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 10, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 11, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 12, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 13, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 14, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 15, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 16, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 17, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 18, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109004046, 19, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 1, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 2, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 3, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 4, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 5, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 6, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 7, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712004047, 8, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608004048, 1, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608004048, 2, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716004049, 1, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716004049, 2, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716004049, 3, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716004049, 4, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 1, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 2, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 3, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 4, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 5, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 6, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 7, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 8, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 9, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 10, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 11, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 12, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 13, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004050, 14, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004051, 1, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004051, 2, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004051, 3, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004051, 4, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004051, 5, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 1, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 2, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 3, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 4, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 5, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 6, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 7, 129, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 8, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 9, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 10, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 11, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 12, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 13, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090926004052, 14, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507004053, 1, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507004053, 2, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507004053, 3, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507004053, 4, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507004053, 5, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 1, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 2, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 3, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 4, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 5, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 6, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 7, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 8, 66, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 9, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 10, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 11, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 12, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 13, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004054, 14, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 1, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 2, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 3, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 4, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 5, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 6, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 7, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 8, 65, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 9, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 10, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013004055, 11, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 1, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 2, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 3, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 4, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 5, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 6, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 7, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 8, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 9, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 10, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930004056, 11, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 1, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 2, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 3, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 4, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 5, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 6, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 7, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 8, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 9, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 10, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 11, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 12, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 13, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903004057, 14, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 1, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 2, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 3, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 4, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 5, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 6, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 7, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526004058, 8, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 1, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 2, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 3, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 4, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 5, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 6, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 7, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 8, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 9, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 10, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 11, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 12, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 13, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 14, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124002832, 4, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124002832, 5, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 1, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 2, 74, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 3, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 4, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 5, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 6, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 7, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 8, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 9, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228002833, 10, 10, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 1, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 2, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 3, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 4, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 5, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 6, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 7, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002834, 8, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 1, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 2, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 3, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 4, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 5, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 6, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 7, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 8, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 9, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 10, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 11, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 12, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 13, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002835, 14, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 1, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 2, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 3, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 4, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 5, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110002836, 6, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 1, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 2, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 3, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 4, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 5, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 6, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 7, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 8, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 9, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 10, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 11, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 12, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 13, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 14, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 15, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 16, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 17, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803002837, 18, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 1, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 2, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 3, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 4, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 5, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 6, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 7, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 8, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 9, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 10, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 11, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 12, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129002838, 13, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 1, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 2, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 3, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 4, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 5, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 6, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 7, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 8, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 9, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 10, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 11, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 12, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 13, 142, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 14, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 15, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 16, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 17, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407002839, 18, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 1, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 2, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 3, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 4, 41, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 5, 167, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210002840, 6, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002841, 1, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002841, 2, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002841, 3, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015002841, 4, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 1, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 2, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 3, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 4, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 5, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 6, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 7, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 8, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 9, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 10, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 11, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 12, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 13, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 14, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220002842, 15, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 1, 109, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 2, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 3, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 4, 29, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 5, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 6, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 7, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 8, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 9, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 10, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 11, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 12, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 13, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 14, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 15, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618002843, 16, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 1, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 2, 29, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 3, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 4, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 5, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 6, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 7, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 8, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 9, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 10, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 11, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 12, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 13, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 14, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 15, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108002844, 16, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 1, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 2, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 3, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 4, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 5, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 6, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126002845, 7, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 1, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 2, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 3, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 4, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 5, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 6, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 7, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 8, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 9, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 10, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 11, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116002846, 12, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629002847, 1, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629002847, 2, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629002847, 3, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629002847, 4, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629002847, 5, 67, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 1, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 2, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 3, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 4, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 5, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 6, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 7, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 8, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 9, 63, 78, 13, 1014);
commit;
prompt 31000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 10, 144, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 11, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618002848, 12, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 1, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 2, 187, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 3, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 4, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 5, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 6, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 7, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 8, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 9, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 10, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 11, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 12, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 13, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 14, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008002849, 15, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 1, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 2, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 3, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 4, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 5, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 6, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 7, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 8, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 9, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 10, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824002850, 11, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 1, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 2, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 3, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 4, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 5, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 6, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 7, 55, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 8, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 9, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 10, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 11, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 12, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 13, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 14, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 15, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120209002851, 16, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 1, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 2, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 3, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 4, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 5, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 6, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 7, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 8, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 9, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 10, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 11, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 12, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 13, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 14, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 15, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322003228, 9, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 1, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 2, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 3, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 4, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 5, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 6, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 7, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 8, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120003229, 9, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 1, 66, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 2, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 3, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 4, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 5, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 6, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 7, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212003230, 8, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 1, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 2, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 3, 123, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 4, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 5, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 6, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 7, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 8, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 9, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 10, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 11, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 12, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 13, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503003231, 14, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 1, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 2, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 3, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 4, 103, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 5, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 6, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 7, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 8, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210003232, 9, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 1, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 2, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 3, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 4, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 5, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 6, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 7, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 8, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 9, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 10, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624003233, 11, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 1, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 2, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 3, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 4, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 5, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 6, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 7, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623003234, 8, 185, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 1, 45, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 2, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 3, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 4, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 5, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 6, 25, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 7, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 8, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 9, 21, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 10, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 11, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 12, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828003235, 13, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 1, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 2, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 3, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 4, 179, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 5, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 6, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 7, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 8, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 9, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 10, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 11, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 12, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 13, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 14, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 15, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619003236, 16, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 1, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 2, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 3, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 4, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 5, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 6, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003237, 7, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 1, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 2, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 3, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 4, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 5, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 6, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 7, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 8, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 9, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 10, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 11, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 12, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 13, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 14, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003238, 15, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 1, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 2, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 3, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 4, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 5, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 6, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 7, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 8, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 9, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 10, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 11, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 12, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 13, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513003239, 14, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 1, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 2, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 3, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 4, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 5, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 6, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 7, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 8, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 9, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 10, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 11, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 12, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 13, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 14, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919003240, 15, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 1, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 2, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 3, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 4, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 5, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 6, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 7, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 8, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 9, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050121003241, 10, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 1, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 2, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 3, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 4, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 5, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 6, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 7, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129003242, 8, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 1, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 2, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 3, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 4, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 5, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 6, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 7, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 8, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 9, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 10, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 11, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003243, 12, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314003244, 1, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314003244, 2, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314003244, 3, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314003244, 4, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314003244, 5, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 1, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 2, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 3, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 4, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 5, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 6, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 7, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 8, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 9, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 10, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 11, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 12, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 13, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120807003245, 14, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 1, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 2, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 3, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 4, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 5, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 6, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 7, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 8, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 9, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 10, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813003246, 11, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 1, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 2, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 3, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 4, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 5, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 6, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 7, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 8, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 9, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 10, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 11, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012003247, 12, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713003248, 1, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713003248, 2, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713003248, 3, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713003248, 4, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 1, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 2, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 3, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 4, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 5, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 6, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 7, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405003249, 8, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 1, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 2, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 3, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 4, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 5, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 6, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 7, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 8, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 9, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 10, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 11, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 12, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 13, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 14, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 15, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 5, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 6, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 7, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 8, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 9, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 10, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 11, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 12, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 13, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 14, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927003594, 15, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011019003595, 1, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011019003595, 2, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011019003595, 3, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011019003595, 4, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011019003595, 5, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 1, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 2, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 3, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 4, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 5, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 6, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 7, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 8, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 9, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061214003596, 10, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811003597, 1, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811003597, 2, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811003597, 3, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811003597, 4, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503003598, 1, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503003598, 2, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 1, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 2, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 3, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 4, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 5, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 6, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 7, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 8, 177, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 9, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 10, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205003599, 11, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 1, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 2, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 3, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 4, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 5, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 6, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 7, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 8, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 9, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 10, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 11, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129003600, 12, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920003601, 1, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920003601, 2, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920003601, 3, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920003601, 4, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920003601, 5, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206003602, 1, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206003602, 2, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206003602, 3, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206003602, 4, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 1, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 2, 192, 11, 18, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 3, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 4, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 5, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 6, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 7, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 8, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102003603, 9, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 1, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 2, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 3, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 4, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 5, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 6, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 7, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 8, 108, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 9, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 10, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 11, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 12, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630003604, 13, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 1, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 2, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 3, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 4, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 5, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 6, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 7, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215003605, 8, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 1, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 2, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 3, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 4, 163, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 5, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 6, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723003606, 7, 8, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003607, 1, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003607, 2, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003607, 3, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003607, 4, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003607, 5, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 1, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 2, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 3, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 4, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 5, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 6, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108003608, 7, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 1, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 2, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 3, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 4, 157, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 5, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 6, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 7, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 8, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 9, 77, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 10, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 11, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817003609, 12, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 1, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 2, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 3, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 4, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 5, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712003610, 6, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 1, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 2, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 3, 152, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 4, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 5, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 6, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 7, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 8, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 9, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214003611, 10, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 1, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 2, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 3, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 4, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 5, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 6, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 7, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012003612, 8, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 1, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 2, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 3, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 4, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 5, 56, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 6, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 7, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 8, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 9, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 10, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 11, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 12, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 13, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 14, 176, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 15, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 16, 44, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 17, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 18, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306003613, 19, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 1, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 2, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 3, 125, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 4, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 5, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 6, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018003614, 7, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 1, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 2, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 3, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 4, 48, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 5, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 6, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 7, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 8, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 9, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 10, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 11, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 12, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 13, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814003615, 14, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 1, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 2, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 3, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 4, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 5, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 6, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 7, 72, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 8, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 9, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 10, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 11, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 12, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 13, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012003616, 14, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 1, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 2, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 3, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 4, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 5, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 6, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 7, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 8, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 9, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 10, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 11, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231003617, 12, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120003618, 1, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120003618, 2, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120003618, 3, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120003618, 4, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120003618, 5, 31, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 1, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 2, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 3, 11, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 4, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 5, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 6, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 7, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724003619, 8, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422003620, 1, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422003620, 2, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422003620, 3, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422003620, 4, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 1, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 2, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 3, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 4, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 5, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 6, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615003621, 7, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014003947, 15, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 1, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 2, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 3, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 4, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 5, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 6, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906003948, 7, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 1, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 2, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 3, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 4, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 5, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 6, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 7, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 8, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015003949, 9, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 1, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 2, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 3, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 4, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 5, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718003950, 6, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 1, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 2, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 3, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 4, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 5, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 6, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 7, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 8, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 9, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 10, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 11, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 12, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 13, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 14, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 15, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517003951, 16, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716003952, 1, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716003952, 2, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716003952, 3, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716003952, 4, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 1, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 2, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 3, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 4, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 5, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 6, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 7, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128003953, 8, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828003954, 1, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828003954, 2, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828003954, 3, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828003954, 4, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 1, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 2, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 3, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 4, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 5, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 6, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 7, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 8, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 9, 73, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917003955, 10, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 1, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 2, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 3, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 4, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 5, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 6, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 7, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 8, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 9, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 10, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 11, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 12, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 13, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 14, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 15, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 16, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 17, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 18, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321003956, 19, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 1, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 2, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 3, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 4, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 5, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 6, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 7, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 8, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 9, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601003957, 10, 181, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129003958, 1, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129003958, 2, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129003958, 3, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129003958, 4, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129003958, 5, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 1, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 2, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 3, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 4, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 5, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 6, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 7, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 8, 36, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 9, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 10, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 11, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 12, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 13, 96, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 14, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 15, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 16, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127003959, 17, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 1, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 2, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 3, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 4, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 5, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 6, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 7, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 8, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 9, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126003960, 10, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 1, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 2, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 3, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 4, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 5, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 6, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 7, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715003961, 8, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 1, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 2, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 3, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 4, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 5, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 6, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 7, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 8, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 9, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 10, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 11, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 12, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 13, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 14, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011003962, 15, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127003963, 1, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127003963, 2, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127003963, 3, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127003963, 4, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127003963, 5, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 1, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 2, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 3, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 4, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 5, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 6, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 7, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 8, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 9, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 10, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822003964, 11, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 1, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 2, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 3, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 4, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 5, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 6, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 7, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 8, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003965, 9, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 1, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 2, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 3, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 4, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 5, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 6, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 7, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 8, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 9, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307003966, 10, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 1, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 2, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 3, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 4, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 5, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 6, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823003967, 7, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 1, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 2, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 3, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 4, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 5, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317003968, 6, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 1, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 2, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 3, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 4, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 5, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 6, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 7, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 8, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129003969, 9, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 1, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 2, 2, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 3, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 4, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 5, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 6, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723003970, 7, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 1, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 2, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 3, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 4, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 5, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 6, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 7, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 8, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 9, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 10, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 11, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 12, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 13, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 14, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 15, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 16, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118003971, 17, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 1, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 2, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 3, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 4, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 5, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 6, 96, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 7, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 8, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 9, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429002852, 16, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 1, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 2, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 3, 21, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 4, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 5, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 6, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 7, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 8, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 9, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 10, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 11, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 12, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 13, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608002853, 14, 91, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 1, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 2, 31, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 3, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 4, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 5, 12, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 6, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 7, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819002854, 8, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 1, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 2, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 3, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 4, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 5, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 6, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 7, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424002855, 8, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 1, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 2, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 3, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 4, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 5, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 6, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 7, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406002856, 8, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 1, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 2, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 3, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 4, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 5, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 6, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 7, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 8, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 9, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 10, 108, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 11, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 12, 45, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 13, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522002857, 14, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002002858, 1, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002002858, 2, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002002858, 3, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002859, 1, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113002859, 2, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 1, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 2, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 3, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 4, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 5, 95, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 6, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 7, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 8, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 9, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 10, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 11, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 12, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 13, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 14, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808002860, 15, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 1, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 2, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 3, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 4, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 5, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 6, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 7, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 8, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 9, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010002861, 10, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 1, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 2, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 3, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 4, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 5, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 6, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 7, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 8, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 9, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 10, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702002862, 11, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002863, 1, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002863, 2, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002863, 3, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002863, 4, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719002863, 5, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 1, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 2, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 3, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 4, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 5, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 6, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 7, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 8, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 9, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 10, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 11, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205002864, 12, 2, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 1, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 2, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 3, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 4, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 5, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 6, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417002865, 7, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 1, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 2, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 3, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 4, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 5, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 6, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 7, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 8, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 9, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 10, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 11, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 12, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 13, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 14, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425002866, 15, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213002867, 1, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213002867, 2, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213002867, 3, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213002867, 4, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 1, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 2, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 3, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 4, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 5, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 6, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 7, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 8, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 9, 190, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 10, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009002868, 11, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 1, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 2, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 3, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 4, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 5, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 6, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 7, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 8, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 9, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 10, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 11, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 12, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 13, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 14, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114002869, 15, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 1, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 2, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 3, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 4, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 5, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 6, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 7, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 8, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 9, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 10, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 11, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 12, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102002870, 13, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 1, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 2, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 3, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 4, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 5, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 6, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 7, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 8, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 9, 85, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 10, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 11, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 12, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 13, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 14, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 15, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 16, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319002871, 17, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 1, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 2, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 3, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 4, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 5, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 6, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 7, 157, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 8, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 9, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 10, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 11, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 12, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 13, 135, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 14, 189, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 15, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 16, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404002872, 17, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 1, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 2, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 3, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 4, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 5, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 6, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 7, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 8, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110002873, 9, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123002874, 1, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123002874, 2, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123002874, 3, 6, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123002874, 4, 96, 10, 15, 150);
commit;
prompt 32000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123002874, 5, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326002875, 1, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326002875, 2, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326002875, 3, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326002875, 4, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 1, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 2, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 3, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 4, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 5, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 6, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 7, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 8, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120002876, 9, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 1, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 2, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 16, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 17, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 18, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423003250, 19, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 1, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 2, 28, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 3, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 4, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 5, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 6, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 7, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 8, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 9, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 10, 150, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 11, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 12, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 13, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608003251, 14, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 1, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 2, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 3, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 4, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 5, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 6, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 7, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 8, 134, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 9, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 10, 1, 52, 3, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 11, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 12, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 13, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121003252, 14, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307003253, 1, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307003253, 2, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307003253, 3, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307003253, 4, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307003253, 5, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227003254, 1, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227003254, 2, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227003254, 3, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227003254, 4, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227003254, 5, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404003255, 1, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404003255, 2, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404003255, 3, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404003255, 4, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911003256, 1, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911003256, 2, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911003256, 3, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911003256, 4, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 1, 7, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 2, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 3, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 4, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 5, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 6, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 7, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 8, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 9, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 10, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211003257, 11, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 1, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 2, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 3, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 4, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 5, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 6, 41, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 7, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 8, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 9, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 10, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 11, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080829003258, 12, 190, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 1, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 2, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 3, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 4, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 5, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 6, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 7, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 8, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 9, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 10, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 11, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 12, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412003259, 13, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 1, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 2, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 3, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 4, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 5, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 6, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 7, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 8, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 9, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 10, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 11, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 12, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010003260, 13, 53, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 1, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 2, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 3, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 4, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 5, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921003261, 6, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318003262, 1, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318003262, 2, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318003262, 3, 107, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318003262, 4, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 1, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 2, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 3, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 4, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 5, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 6, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 7, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 8, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 9, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 10, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 11, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520003263, 12, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 1, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 2, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 3, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 4, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 5, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 6, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 7, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 8, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 9, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 10, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 11, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 12, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100809003264, 13, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 1, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 2, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 3, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 4, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 5, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 6, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 7, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 8, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 9, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 10, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730003265, 11, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220003266, 1, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220003266, 2, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220003266, 3, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220003266, 4, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 1, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 2, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 3, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 4, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 5, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 6, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 7, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 8, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 9, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 10, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 11, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 12, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 13, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 14, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 15, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 16, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311003267, 17, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 1, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 2, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 3, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 4, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 5, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 6, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 7, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 8, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 9, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 10, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 11, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 12, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522003268, 13, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 1, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 2, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 3, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 4, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 5, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 6, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 7, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 8, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 9, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 10, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 11, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 12, 100, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 13, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 14, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 15, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615003269, 16, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 1, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 2, 113, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 3, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 4, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 5, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 6, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 7, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 8, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 9, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 10, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017003270, 11, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 1, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 2, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 3, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 4, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 5, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 6, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 7, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 8, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 9, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 10, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 11, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319003271, 12, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209003272, 1, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209003272, 2, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209003272, 3, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209003272, 4, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209003272, 5, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 1, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 2, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 3, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 4, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 5, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 6, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 7, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 8, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 9, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814003273, 10, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 1, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 2, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 3, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 4, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 5, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 6, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 1, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 2, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 3, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 4, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 5, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 6, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 7, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 8, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110003622, 9, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 1, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 2, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 3, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 4, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 5, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 6, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 7, 49, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316003623, 8, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 1, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 2, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 3, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 4, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 5, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426003624, 6, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 1, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 2, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 3, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 4, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 5, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 6, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 7, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 8, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 9, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026003625, 10, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 1, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 2, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 3, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 4, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 5, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 6, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 7, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 8, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 9, 192, 79, 18, 1422);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 10, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 11, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 12, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 13, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 14, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 15, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701003626, 16, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 1, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 2, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 3, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 4, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 5, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002003627, 6, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 1, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 2, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 3, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 4, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 5, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 6, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111003628, 7, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 1, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 2, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 3, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 4, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 5, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 6, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 7, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 8, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 9, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 10, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217003629, 11, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 1, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 2, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 3, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 4, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 5, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 6, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 7, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 8, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731003630, 9, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 1, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 2, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 3, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 4, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 5, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104003631, 6, 54, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 1, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 2, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 3, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 4, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 5, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 6, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 7, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 8, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 9, 98, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 10, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215003632, 11, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413003633, 1, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413003633, 2, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413003633, 3, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000413003633, 4, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 1, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 2, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 3, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 4, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 5, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 6, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 7, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 8, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 9, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 10, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 11, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 12, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 13, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 14, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707003634, 15, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 1, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 2, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 3, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 4, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 5, 99, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 6, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 7, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 8, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 9, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 10, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 11, 189, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 12, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306003635, 13, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 1, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 2, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 3, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 4, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 5, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 6, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216003636, 7, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 1, 172, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 2, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 3, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 4, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 5, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 6, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 7, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 8, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 9, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 10, 107, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 11, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 12, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 13, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 14, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 15, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529003637, 16, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 1, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 2, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 3, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 4, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 5, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 6, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 7, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 8, 137, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 9, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 10, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 11, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 12, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013003638, 13, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 1, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 2, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 3, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 4, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 5, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 6, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 7, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 8, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 9, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 10, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 11, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 12, 107, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 13, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 14, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 15, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523003639, 16, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 1, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 2, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 3, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 4, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 5, 49, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 6, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 7, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701003640, 8, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 1, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 2, 68, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 3, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 4, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 5, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 6, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 7, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 8, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 9, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 10, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 11, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 12, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 13, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 14, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 15, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 16, 188, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109003641, 17, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219003642, 1, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219003642, 2, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219003642, 3, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219003642, 4, 39, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219003642, 5, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 1, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 2, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 3, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 4, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 5, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 6, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 7, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003643, 8, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 1, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 2, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 3, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 4, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 5, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 6, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 7, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 8, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 9, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 10, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 11, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 12, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226003644, 13, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211003645, 1, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211003645, 2, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211003645, 3, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211003645, 4, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322003646, 1, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 6, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 7, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 8, 189, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 9, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 10, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 11, 64, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 12, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 13, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 14, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 1, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 2, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 3, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 4, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 5, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210003996, 6, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 1, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 2, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 3, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 4, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 5, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 6, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 7, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 8, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 9, 21, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804003997, 10, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 1, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 2, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 3, 137, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 4, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 5, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 6, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107003998, 7, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 1, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 2, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 3, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 4, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 5, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 6, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 7, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 8, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 9, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 10, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313003999, 11, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101004000, 1, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101004000, 2, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101004000, 3, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101004000, 4, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 1, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 2, 70, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 3, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 4, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 5, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 6, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 7, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 8, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 9, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214004001, 10, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 1, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 2, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 3, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 4, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 5, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 6, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 7, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 8, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 9, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 10, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 11, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 12, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 13, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 14, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 15, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207004002, 16, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 1, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 2, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 3, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 4, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 5, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 6, 120, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521004003, 7, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 1, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 2, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 3, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 4, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 5, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 6, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 7, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 8, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 9, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 10, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 11, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 12, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727004004, 13, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 1, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 2, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 3, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 4, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 5, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 6, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 7, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 8, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 9, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 10, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 11, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 12, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 13, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 14, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229004005, 15, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 1, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 2, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 3, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 4, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 5, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 6, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 7, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 8, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 9, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 10, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 11, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 12, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 13, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810004006, 14, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501004007, 1, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501004007, 2, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501004007, 3, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501004007, 4, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 1, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 2, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 3, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 4, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 5, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 6, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 7, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 8, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 9, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 10, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 11, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106004008, 12, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 1, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 2, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 3, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 4, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 5, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 6, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 7, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 8, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 9, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 10, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 11, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 12, 94, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422004009, 13, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621004010, 1, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621004010, 2, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621004010, 3, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621004010, 4, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621004010, 5, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 1, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 2, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 3, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 4, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 5, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 6, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 7, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 8, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 9, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 10, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 11, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 12, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 13, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 14, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717004011, 15, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 1, 25, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 2, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 3, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 4, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 5, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 6, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 7, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114004012, 8, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905004013, 1, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905004013, 2, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905004013, 3, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 1, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 2, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 3, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 4, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 5, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 6, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 7, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 8, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 9, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 10, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 11, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 12, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004014, 13, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 1, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 2, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 3, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 4, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 5, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 6, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 7, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 8, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 9, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 10, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 11, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 12, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 13, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090130004015, 14, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 1, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 2, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 3, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 4, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 5, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 6, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 7, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 8, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 9, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 10, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 11, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 12, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 13, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 14, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 15, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627004016, 16, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 1, 14, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 2, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 3, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 4, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 5, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 6, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 7, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 8, 84, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 9, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 10, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 11, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 12, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 13, 128, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 14, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 3, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 4, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 5, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 6, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 7, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905002877, 8, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 1, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 2, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 3, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 4, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 5, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 6, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 7, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 8, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 9, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 10, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 11, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 12, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 13, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122002878, 14, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 1, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 2, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 3, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 4, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 5, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 6, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 7, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015002879, 8, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405002880, 1, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405002880, 2, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405002880, 3, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405002880, 4, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405002880, 5, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230002881, 1, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230002881, 2, 43, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230002881, 3, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 1, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 2, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 3, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 4, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 5, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 6, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 7, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 8, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120002882, 9, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 1, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 2, 29, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 3, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 4, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 5, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 6, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 7, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 8, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 9, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 10, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 11, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511002883, 12, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 1, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 2, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 3, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 4, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 5, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 6, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 7, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 8, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820002884, 9, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230002885, 1, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230002885, 2, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230002885, 3, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230002885, 4, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230002885, 5, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 1, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 2, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 3, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 4, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 5, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 6, 24, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 7, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 8, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 9, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 10, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 11, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 12, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 13, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906002886, 14, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 1, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 2, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 3, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 4, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 5, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 6, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 7, 123, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217002887, 8, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 1, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 2, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 3, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 4, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 5, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 6, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 7, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221002888, 8, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616002889, 1, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616002889, 2, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616002889, 3, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616002889, 4, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 1, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 2, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 3, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 4, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 5, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 6, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 7, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 8, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 9, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 10, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 11, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 12, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 13, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 14, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002890, 15, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 1, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 2, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 3, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 4, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 5, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 6, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 7, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 8, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719002891, 9, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 1, 116, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 2, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 3, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 4, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 5, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 6, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 7, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 8, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050819002892, 9, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 1, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 2, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 3, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 4, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 5, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 6, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 7, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 8, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 9, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 10, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 11, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 12, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 13, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 14, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 15, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 16, 23, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 17, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002893, 18, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 1, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 2, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 3, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 4, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 5, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 6, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 7, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 8, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 9, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 10, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 11, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512002894, 12, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 1, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 2, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 3, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 4, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 5, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 6, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 7, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 8, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504002895, 9, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708002896, 1, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708002896, 2, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708002896, 3, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708002896, 4, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708002896, 5, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306002897, 1, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306002897, 2, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306002897, 3, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 1, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 2, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 3, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 4, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 5, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 6, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 7, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 8, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 9, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 10, 69, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 11, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 12, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 13, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 14, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 15, 190, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409002898, 16, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 1, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 2, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 3, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 4, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 5, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 6, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 7, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130002899, 8, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 1, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 2, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 3, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 4, 56, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 5, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128002900, 6, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 1, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 2, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 3, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 4, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 5, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505002901, 6, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 1, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 2, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 3, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 4, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 5, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 6, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 7, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 8, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 9, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 10, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 11, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 12, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 13, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 14, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002902, 15, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 1, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 2, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 3, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 7, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 8, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 9, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 10, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105003274, 11, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826003275, 1, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826003275, 2, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826003275, 3, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826003275, 4, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826003275, 5, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 1, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 2, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 3, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 4, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 5, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 6, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 7, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 8, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 9, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 10, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 11, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024003276, 12, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 1, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 2, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 3, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 4, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 5, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 6, 104, 92, 13, 1196);
commit;
prompt 33000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 7, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 8, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 9, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 10, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 11, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 12, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 13, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624003277, 14, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 1, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 2, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 3, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 4, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 5, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 6, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 7, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 8, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 9, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 10, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 11, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 12, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 13, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502003278, 14, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 1, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 2, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 3, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 4, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 5, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 6, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 7, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 8, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 9, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408003279, 10, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 1, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 2, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 3, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 4, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 5, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 6, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 7, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 8, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 9, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 10, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 11, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 12, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 13, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 14, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 15, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204003280, 16, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 1, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 2, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 3, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 4, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 5, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 6, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 7, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 8, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 9, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 10, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 11, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 12, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 13, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 14, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 15, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 16, 17, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112003281, 17, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 1, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 2, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 3, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 4, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 5, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 6, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 7, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 8, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 9, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 10, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805003282, 11, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 1, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 2, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 3, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 4, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 5, 3, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 6, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 7, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050127003283, 8, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 1, 67, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 2, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 3, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 4, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 5, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 6, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 7, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 8, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 9, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 10, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 11, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 12, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 13, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 14, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123003284, 15, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 1, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 2, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 3, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 4, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 5, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 6, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209003285, 7, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 1, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 2, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 3, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 4, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 5, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 6, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 7, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 8, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 9, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 10, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 11, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 12, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 13, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 14, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 15, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 16, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 17, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131204003286, 18, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 1, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 2, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 3, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 4, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 5, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 6, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 7, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 8, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 9, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 10, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 11, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 12, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 13, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003287, 14, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 1, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 2, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 3, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 4, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 5, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 6, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 7, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 8, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 9, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 10, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 11, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 12, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003288, 13, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 1, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 2, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 3, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 4, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 6, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 7, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 8, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 9, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 10, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 11, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 12, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 13, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 14, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 15, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 16, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126003289, 17, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 1, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 2, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 3, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 4, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 5, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 6, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 7, 108, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 8, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 9, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 10, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 11, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412003290, 12, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 1, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 2, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 3, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 4, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 5, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915003291, 6, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 1, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 2, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 3, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 4, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 5, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 6, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 7, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 8, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 9, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 10, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 11, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 12, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 13, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 14, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304003292, 15, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 1, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 2, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 3, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 4, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 5, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 6, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 7, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 8, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 9, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 10, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322003646, 2, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322003646, 3, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 1, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 2, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 3, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 4, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 5, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 6, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 7, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 8, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 9, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 10, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 11, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 12, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 13, 74, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 14, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 15, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726003647, 16, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 1, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 2, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 3, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 4, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 5, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 6, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 7, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216003648, 8, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 1, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 2, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 3, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 4, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 5, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 6, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 7, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 8, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 9, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 10, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 11, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 12, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813003649, 13, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 1, 127, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 2, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 3, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 4, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 5, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 6, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 7, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 8, 122, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 9, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 10, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 11, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 12, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 13, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 14, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 15, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213003650, 16, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 1, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 2, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 3, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 4, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 5, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 6, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 7, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 8, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 9, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 10, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 11, 103, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 12, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 13, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 14, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003651, 15, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 1, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 2, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 3, 80, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 4, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 5, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 6, 156, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 7, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411003652, 8, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 1, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 2, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 3, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 4, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 5, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 6, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 7, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 8, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 9, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 10, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421003653, 11, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123003654, 1, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123003654, 2, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123003654, 3, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123003654, 4, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000123003654, 5, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 1, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 2, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 3, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 4, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 5, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 6, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 7, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 8, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 9, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 10, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 11, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 12, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 13, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003655, 14, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 1, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 2, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 3, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 4, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 5, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 6, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 7, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 8, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 9, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 10, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 11, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 12, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 13, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 14, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 15, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213003656, 16, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 1, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 2, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 3, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 4, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 5, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 6, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 7, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 8, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 9, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 10, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 11, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 12, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 13, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502003657, 14, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 1, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 2, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 3, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 4, 121, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 5, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 6, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 8, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 9, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 10, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 11, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 12, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906003658, 13, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 1, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 2, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 3, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 4, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 5, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 6, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 7, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 8, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 9, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 10, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 11, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 12, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 13, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 14, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 15, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628003659, 16, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 1, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 2, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 3, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 4, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 5, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 6, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 7, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725003660, 8, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 1, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 2, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 3, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 4, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 5, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 6, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 7, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 8, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 9, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 10, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 11, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 12, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 13, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 14, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 15, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003661, 16, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 1, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 2, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 3, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 4, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 5, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 6, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 7, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 8, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 9, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 10, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 11, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 12, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 13, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 14, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 15, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 16, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120528003662, 17, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 1, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 2, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 3, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 4, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 5, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 6, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 7, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 8, 71, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 9, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113003663, 10, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 1, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 2, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 3, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 4, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 5, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 6, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 7, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 8, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 9, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 10, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 11, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 12, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030003664, 13, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628003665, 1, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628003665, 2, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628003665, 3, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628003665, 4, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 1, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 2, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 3, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 4, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 15, 72, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 16, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413004059, 17, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 1, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 2, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 3, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 4, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 5, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 6, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 7, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 8, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 9, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 10, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 11, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 12, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802004060, 13, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 1, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 2, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 3, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 4, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 5, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216004061, 6, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 1, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 2, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 3, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 4, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 5, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 6, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 7, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 8, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 9, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912004062, 10, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 1, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 2, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 3, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 4, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 5, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417004063, 6, 154, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 1, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 2, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 3, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 4, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 5, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314004064, 6, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004065, 1, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004065, 2, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004065, 3, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004065, 4, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004065, 5, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 1, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 2, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 3, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 4, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 5, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 6, 185, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 7, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514004066, 8, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 1, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 2, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 3, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 4, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 5, 125, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 6, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 7, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 8, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618004067, 9, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203004068, 1, 27, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203004068, 2, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203004068, 3, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203004068, 4, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701004069, 1, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701004069, 2, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701004069, 3, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701004069, 4, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701004069, 5, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 1, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 2, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 3, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 4, 167, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 5, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128004070, 6, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 1, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 2, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 3, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 4, 19, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 5, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 6, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 7, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 8, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 9, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 10, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 11, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 12, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 13, 19, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 14, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 15, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230004071, 16, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 1, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 2, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 3, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 4, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 5, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 6, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 7, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 8, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 9, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 10, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 11, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 12, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 13, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 14, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 15, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 16, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 17, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725004072, 18, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 1, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 2, 170, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 3, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 4, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 5, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 6, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 7, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 8, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720004073, 9, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 1, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 2, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 3, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 4, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 5, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 6, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 7, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122004074, 8, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 1, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 2, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 3, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 4, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 5, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 6, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 7, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 8, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 9, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520004075, 10, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 1, 128, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 2, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 3, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 4, 126, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 5, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 6, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 7, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 8, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 9, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329004076, 10, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 1, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 2, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 3, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 4, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 5, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 6, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 7, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 8, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 9, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 10, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 11, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 12, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 13, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 14, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725004077, 15, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 1, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 2, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 3, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 4, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 5, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 6, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 7, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 8, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004078, 9, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 1, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 2, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 3, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 4, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 5, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908004079, 6, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 1, 179, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 2, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 3, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 4, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 5, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 6, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 7, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 8, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 9, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 10, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 11, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401004080, 12, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 1, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 2, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 3, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 4, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 5, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 6, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 7, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 8, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 9, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 10, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 11, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 12, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111004081, 13, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 1, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 2, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 3, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 4, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 5, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 6, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 7, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 8, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108004082, 9, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 1, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 2, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 3, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 4, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 5, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 6, 48, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 7, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 8, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 9, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 10, 19, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 11, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 12, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 13, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 14, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 15, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 16, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206004083, 17, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022004084, 1, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022004084, 2, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022004084, 3, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022004084, 4, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022004084, 5, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903004085, 1, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 4, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 5, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 6, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 7, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 8, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 9, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 10, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724002903, 11, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316002904, 1, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316002904, 2, 75, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316002904, 3, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316002904, 4, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316002904, 5, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 1, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 2, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 3, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 4, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 5, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 6, 126, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 7, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 8, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 9, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 10, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 11, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528002905, 12, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525002906, 1, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525002906, 2, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525002906, 3, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525002906, 4, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525002906, 5, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 1, 161, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 2, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 3, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 4, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 5, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 6, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 7, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 8, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 9, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 10, 174, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125002907, 11, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 1, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 2, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 3, 75, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 4, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 5, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 6, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 7, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630002908, 8, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 1, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 2, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 3, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 4, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 5, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 6, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 7, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 8, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 9, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 10, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003002909, 11, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 1, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 2, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 3, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 4, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 5, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 6, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 7, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 8, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 9, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 10, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114002910, 11, 70, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 1, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 2, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 3, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 4, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 5, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 6, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629002911, 7, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 1, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 2, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 3, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 4, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 5, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 6, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 7, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 8, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 9, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 10, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 11, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 12, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110002912, 13, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 1, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 2, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 3, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 4, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 5, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 6, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 7, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 8, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 9, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 10, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 11, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 12, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104002913, 13, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002914, 1, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002914, 2, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002914, 3, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002914, 4, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002914, 5, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 1, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 2, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 3, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 4, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 5, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 6, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 7, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608002915, 8, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 1, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 2, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 3, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 4, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 5, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 6, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 7, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 8, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 9, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 10, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 11, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 12, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 13, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208002916, 14, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525002917, 1, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525002917, 2, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525002917, 3, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 1, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 2, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 3, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 4, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 5, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 6, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820002918, 7, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 1, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 2, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 3, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 4, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 5, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025002919, 6, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 1, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 2, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 3, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 4, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 5, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 6, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 7, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 8, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 9, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 10, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 11, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 12, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207002920, 13, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 1, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 2, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 3, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 4, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 5, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 6, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 7, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 8, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 9, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 10, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 11, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 12, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 13, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 14, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908002921, 15, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 1, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 2, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 3, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 4, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 5, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 6, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 7, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 8, 131, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 9, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 10, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 11, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 12, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002922, 13, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 1, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 2, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 3, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 4, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 5, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 6, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 7, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 8, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 9, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 10, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 11, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 12, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 13, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 14, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 15, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707002923, 16, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 1, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 2, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 3, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 4, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 5, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 6, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 7, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 8, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 9, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 10, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 11, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 12, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 13, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704002924, 14, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620002925, 1, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620002925, 2, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620002925, 3, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620002925, 4, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620002925, 5, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 1, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 2, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 3, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 4, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 5, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 6, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 7, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 8, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071124002926, 9, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823002927, 1, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823002927, 2, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823002927, 3, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 1, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 2, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 3, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 4, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 11, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923003293, 12, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 1, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 2, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 3, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 4, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 5, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 6, 124, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 7, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 8, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 9, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 10, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 11, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 12, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 13, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214003294, 14, 150, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 1, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 2, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 3, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 4, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 5, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 6, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 7, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611003295, 8, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 1, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 2, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 3, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 4, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 5, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 6, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 7, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 8, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 9, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 10, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614003296, 11, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 1, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 2, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 3, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 4, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 5, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 6, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 7, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 8, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 9, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 10, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 11, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 12, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 13, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218003297, 14, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 1, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 2, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 3, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 4, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 5, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 6, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 7, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 8, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 9, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 10, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 11, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916003298, 12, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 1, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 2, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 3, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 4, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 5, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 6, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 7, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 8, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 9, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 10, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 11, 151, 34, 15, 510);
commit;
prompt 34000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 12, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 13, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 14, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909003299, 15, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630003300, 1, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630003300, 2, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630003300, 3, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 1, 187, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 2, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 3, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 4, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 5, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 6, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 7, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 8, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 9, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 10, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 11, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417003301, 12, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 1, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 2, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 3, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 4, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 5, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 6, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 7, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 8, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 9, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 10, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 11, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003302, 12, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 1, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 2, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 3, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 4, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 5, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 6, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 7, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 8, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 9, 126, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 10, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 11, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714003303, 12, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131003304, 1, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131003304, 2, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131003304, 3, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205003305, 1, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205003305, 2, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205003305, 3, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205003305, 4, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205003305, 5, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 1, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 2, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 3, 192, 27, 18, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 4, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 5, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 6, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 7, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 8, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 9, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511003306, 10, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 1, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 2, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 3, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 4, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 5, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 6, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 7, 129, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 8, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831003307, 9, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 1, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 2, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 3, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 4, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 5, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 6, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 7, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 8, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 9, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 10, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 11, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 12, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 13, 97, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812003308, 14, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925003309, 1, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925003309, 2, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 1, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 2, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 3, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 4, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 5, 132, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 6, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425003310, 7, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 1, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 2, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 3, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 4, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 5, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 6, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 7, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824003311, 8, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 1, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 2, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 4, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 5, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 6, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 7, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 8, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 9, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 10, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 11, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 12, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310003312, 13, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127003313, 1, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127003313, 2, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127003313, 3, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127003313, 4, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 1, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 2, 130, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 3, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 4, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 5, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402003314, 6, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003315, 1, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003315, 2, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003315, 3, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723003315, 4, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 1, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 2, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 3, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 4, 137, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 5, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 6, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 7, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 8, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131003316, 9, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 1, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 2, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 3, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 4, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 5, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 6, 51, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 7, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 8, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003317, 9, 154, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 1, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 2, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 3, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 4, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 5, 108, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 6, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 7, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 8, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 9, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 10, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128003318, 11, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 1, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 2, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 3, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 4, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 5, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 6, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 7, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 8, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 9, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 10, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 5, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025003666, 6, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 1, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 2, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 3, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 4, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 5, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 6, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 7, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 8, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 9, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 10, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118003667, 11, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 1, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 2, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 3, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 4, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 5, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 6, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 7, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 8, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 9, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 10, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619003668, 11, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 1, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 2, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 3, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 4, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 5, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 6, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 7, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 8, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 9, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 10, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 11, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 12, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 13, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 14, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 15, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 16, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617003669, 17, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 1, 146, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 2, 90, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 3, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 4, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 5, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 6, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 7, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 8, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 9, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 10, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 11, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 12, 6, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 13, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 14, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804003670, 15, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 1, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 2, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 3, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 4, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 5, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 6, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 7, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 8, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 9, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 10, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 11, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 12, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 13, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003671, 14, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 1, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 2, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 3, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 4, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 5, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 6, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 7, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 8, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 9, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 10, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925003672, 11, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 1, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 2, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 3, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 4, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 5, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 6, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 7, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 8, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 9, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 10, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 11, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 12, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909003673, 13, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 1, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 2, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 3, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 4, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 5, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 6, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 7, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 8, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070727003674, 9, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 1, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 2, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 3, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 4, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 5, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306003675, 6, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130003676, 1, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130003676, 2, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130003676, 3, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130003676, 4, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417003677, 1, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417003677, 2, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417003677, 3, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020417003677, 4, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 1, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 2, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 3, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 4, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 5, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 6, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 7, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 8, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 9, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 10, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 11, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 12, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412003678, 13, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 1, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 2, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 3, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 4, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 5, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 6, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 7, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226003679, 8, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304003680, 1, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304003680, 2, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304003680, 3, 177, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304003680, 4, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010409003681, 1, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010409003681, 2, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010409003681, 3, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010409003681, 4, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 1, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 2, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 3, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 4, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 5, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 6, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 7, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 8, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 9, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 10, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 11, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 12, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 13, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 14, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 15, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 16, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 17, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413003682, 18, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 1, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 2, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 3, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 4, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 5, 192, 3, 18, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 6, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 7, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 8, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 9, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 10, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 11, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 12, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 13, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 14, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 15, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304003683, 16, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 1, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 2, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 3, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 4, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 5, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 6, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 7, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106003684, 8, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 1, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 2, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 3, 51, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 4, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 5, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909003685, 6, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507003686, 1, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507003686, 2, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507003686, 3, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507003686, 4, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 1, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 2, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 3, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 4, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 5, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 6, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 7, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 8, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060514003687, 9, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 1, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 2, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 3, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 4, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 5, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 6, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 7, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 8, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 9, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 10, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 11, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 12, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 13, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 14, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 15, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 16, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419003688, 17, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 1, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 2, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 3, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 4, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 5, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 6, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 7, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 8, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 9, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 10, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 11, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 12, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127003689, 13, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 1, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 2, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019003972, 10, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 1, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 2, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 3, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 4, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 5, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 6, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 7, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 8, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 9, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317003973, 10, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 1, 174, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 2, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 3, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 4, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 5, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929003974, 6, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 1, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 2, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 3, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 4, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 5, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 6, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 7, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 8, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 9, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613003975, 10, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 1, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 2, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 3, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 4, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 5, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 6, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 7, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 8, 183, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 9, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 10, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 11, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225003976, 12, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 1, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 2, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 3, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 4, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 5, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 6, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502003977, 7, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 1, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 2, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 3, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 4, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 5, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 6, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 7, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 8, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 9, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 10, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 11, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 12, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923003978, 13, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 1, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 2, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 3, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 4, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 5, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 6, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 7, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 8, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 9, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 10, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 11, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 12, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 13, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 14, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 15, 177, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003979, 16, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 1, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 2, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 3, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 4, 56, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 5, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 6, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 7, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 8, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 9, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 10, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 11, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 12, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 13, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 14, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930003980, 15, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012003981, 1, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012003981, 2, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012003981, 3, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012003981, 4, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 1, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 2, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 3, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 4, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 5, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 6, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 7, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 8, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 9, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 10, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 11, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 12, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 13, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003982, 14, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 1, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 2, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 3, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 4, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 5, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829003983, 6, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 1, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 2, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 3, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 4, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 5, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 6, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 7, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 8, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 9, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 10, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 11, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 12, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 13, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 14, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 15, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 16, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 17, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326003984, 18, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 1, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 2, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 3, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 4, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 5, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 6, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 7, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 8, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 9, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 10, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430003985, 11, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 1, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 2, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 3, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 4, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 5, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 6, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 7, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 8, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 9, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003986, 10, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 1, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 2, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 3, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 4, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 5, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 6, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 7, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 8, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 9, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305003987, 10, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 1, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 2, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 3, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 4, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 5, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 6, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 7, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 8, 142, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 9, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 10, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 11, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 12, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 13, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915003988, 14, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 1, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 2, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 3, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 4, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 5, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 6, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 7, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 8, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 9, 148, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 10, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 11, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100301003989, 12, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 1, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 2, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 3, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 4, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 5, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 6, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628003990, 7, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 1, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 2, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 3, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 4, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 5, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 6, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 7, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 8, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 9, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 10, 1, 33, 3, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 11, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 12, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090715003991, 13, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 1, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 2, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 3, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 4, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 5, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 6, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 7, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 8, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 9, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 10, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 11, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 12, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 13, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204003992, 14, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921003993, 1, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921003993, 2, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921003993, 3, 37, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921003993, 4, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921003993, 5, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 1, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 2, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 3, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 4, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 5, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119003994, 6, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 1, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 2, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 3, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 4, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906003995, 5, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 5, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509002928, 6, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421002929, 1, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421002929, 2, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421002929, 3, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421002929, 4, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 1, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 2, 183, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 3, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 4, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 5, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 6, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 7, 126, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 8, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 9, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 10, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070718002930, 11, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 1, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 2, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 3, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 4, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 5, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 6, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002931, 7, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 1, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 2, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 3, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 4, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 5, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 6, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 7, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 8, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 9, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 10, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 11, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 12, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 13, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 14, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 15, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709002932, 16, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522002933, 1, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522002933, 2, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522002933, 3, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522002933, 4, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 1, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 2, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 3, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 4, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 5, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 6, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 7, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 8, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 9, 154, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 10, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 11, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 12, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 13, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 14, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 15, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131208002934, 16, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 1, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 2, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 3, 43, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 4, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 5, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 6, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 7, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 8, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 9, 67, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 10, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 11, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 12, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 13, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 14, 125, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 15, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 16, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022002935, 17, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 1, 12, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 2, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 3, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 4, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 5, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 6, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 7, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 8, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 9, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 10, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 11, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614002936, 12, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 1, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 2, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 3, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 4, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 5, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 6, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 7, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208002937, 8, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207002938, 1, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207002938, 2, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207002938, 3, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207002938, 4, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 1, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 2, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 3, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 4, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 5, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 6, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 7, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209002939, 8, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 1, 67, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 2, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 3, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 4, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 5, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 6, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 7, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 8, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 9, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 10, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 11, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 12, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 13, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 14, 49, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 15, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228002940, 16, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 1, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 2, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 3, 100, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 4, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 5, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 6, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118002941, 7, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 1, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 2, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 3, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 4, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 5, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 6, 92, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 7, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 8, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326002942, 9, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103002943, 1, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103002943, 2, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103002943, 3, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103002943, 4, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103002943, 5, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 1, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 2, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 3, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 4, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 5, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 6, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 7, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 8, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 9, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 10, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 11, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108002944, 12, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 1, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 2, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 3, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 4, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 5, 10, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025002945, 6, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211002946, 1, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211002946, 2, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211002946, 3, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211002946, 4, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 1, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 2, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 3, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 4, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 5, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 6, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 7, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 8, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 9, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 10, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027002947, 11, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811002948, 1, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811002948, 2, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811002948, 3, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000423002949, 1, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000423002949, 2, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000423002949, 3, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 1, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 2, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 3, 185, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 4, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 5, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 6, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 7, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 8, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 9, 81, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 10, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 11, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 12, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 13, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 14, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 15, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 16, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 17, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126002950, 18, 88, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 1, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 2, 192, 9, 18, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 3, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 4, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 5, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 6, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 7, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 8, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 9, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830002951, 10, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321002952, 1, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321002952, 2, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321002952, 3, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321002952, 4, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321002952, 5, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002953, 1, 134, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002953, 2, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002953, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002953, 4, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002953, 5, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002954, 1, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002954, 2, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002954, 3, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002954, 4, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404002954, 5, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 1, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 2, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 3, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 4, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 5, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 6, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 7, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 8, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 9, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 10, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 11, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 11, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 12, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 13, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 14, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207003319, 15, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 1, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 2, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 3, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 4, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 5, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 6, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 7, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 8, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003320, 9, 56, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 1, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 2, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 3, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 4, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 5, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 6, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 7, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 8, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 9, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 10, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 11, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 12, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 13, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 14, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 15, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124003321, 16, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 1, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 2, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 3, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 4, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 5, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 6, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 7, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 8, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 9, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 10, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 11, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 12, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727003322, 13, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 1, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 2, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 3, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 4, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 5, 175, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 6, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 7, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 8, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 9, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 10, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 11, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 12, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 13, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 14, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 15, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 16, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 17, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101003323, 18, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 1, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 2, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 3, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 4, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 5, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 6, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 7, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004003324, 8, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 1, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 2, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 3, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 4, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 5, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 6, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 7, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 8, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050109003325, 9, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 1, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 2, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 3, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 4, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 5, 154, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 6, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 7, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 8, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 9, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 10, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 11, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 12, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 13, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 14, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120910003326, 15, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003327, 1, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003327, 2, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003327, 3, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003327, 4, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 1, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 2, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 3, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 4, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 5, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 6, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 7, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 8, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 9, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 10, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 11, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 12, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 13, 119, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820003328, 14, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905003329, 1, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905003329, 2, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905003329, 3, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905003329, 4, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905003329, 5, 89, 67, 8, 536);
commit;
prompt 35000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 1, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 2, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 3, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 4, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 5, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 6, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 7, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 8, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 9, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001003330, 10, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 1, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 2, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 3, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 4, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 5, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 6, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201003331, 7, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 1, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 3, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 4, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 5, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 6, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 7, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603003332, 8, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 1, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 2, 126, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 3, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 4, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 5, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 6, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 7, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 8, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 9, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207003333, 10, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 1, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 2, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 3, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 4, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 5, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 6, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 7, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526003334, 8, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 1, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 2, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 3, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 4, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 5, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 6, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 7, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 8, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 9, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 10, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 11, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 12, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 13, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 14, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926003335, 15, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 1, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 2, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 3, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 4, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 5, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 6, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 7, 65, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 8, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 9, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 10, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 11, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 12, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 13, 53, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 14, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210003336, 15, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 1, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 2, 95, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 3, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 4, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 5, 74, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 6, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 7, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 8, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 9, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 10, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 11, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 12, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 13, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 14, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 15, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 16, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217003337, 17, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 1, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 2, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 3, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 4, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 5, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 6, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 7, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 8, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524003338, 9, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 1, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 2, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 3, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 4, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 5, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807003339, 6, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 1, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 2, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 3, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 4, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 5, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 6, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 7, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 8, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 9, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 10, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 11, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 12, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 13, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 14, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827003340, 15, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 1, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 2, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 3, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 3, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 4, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 5, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 6, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 7, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 8, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 9, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 10, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 11, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 12, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 13, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 14, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 15, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613003690, 16, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 1, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 2, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 3, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 4, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 5, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 6, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 7, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 8, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 9, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 10, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 11, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 12, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 13, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 14, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723003691, 15, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 1, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 2, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 3, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 4, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 5, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 6, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 7, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 8, 13, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421003692, 9, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 1, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 2, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 3, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 4, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 5, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 6, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 7, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 8, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 9, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 10, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 11, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 12, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 13, 89, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908003693, 14, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 1, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 2, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 3, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 4, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 5, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 6, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 7, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 8, 120, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 9, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714003694, 10, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 1, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 2, 78, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 3, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 4, 24, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 5, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 6, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 7, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 8, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122003695, 9, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 1, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 2, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 3, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 4, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 5, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 6, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 7, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 8, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 9, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 10, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 11, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 12, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 13, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 14, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 15, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 16, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520003696, 17, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 1, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 2, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 3, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 4, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 5, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 6, 1, 49, 3, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 7, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 8, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 9, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 10, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622003697, 11, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 1, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 2, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 3, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 4, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 5, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 6, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 7, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 8, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 9, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 10, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 11, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 12, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 13, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003698, 14, 115, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111003699, 1, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111003699, 2, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111003699, 3, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 1, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 2, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 3, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 4, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 5, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 6, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 7, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316003700, 8, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 1, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 2, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 3, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 4, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 5, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 6, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 7, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 8, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 9, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 10, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 11, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 12, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904003701, 13, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 1, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 2, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 3, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 4, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 5, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 6, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 7, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 8, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 9, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 10, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 11, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 12, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 13, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 14, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 15, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003702, 16, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 1, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 2, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 3, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 4, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 5, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 6, 160, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 7, 177, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 8, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 9, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203003703, 10, 51, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 1, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 2, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 3, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 4, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 5, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005003704, 6, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414003705, 1, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414003705, 2, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414003705, 3, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414003705, 4, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 1, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 2, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 3, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 4, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 5, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 6, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 7, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 8, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 9, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727003706, 10, 20, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 1, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 2, 144, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 3, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 4, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 5, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 6, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 7, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 8, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 9, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 10, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 11, 122, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 12, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 13, 192, 90, 18, 1620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105003707, 14, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703003708, 1, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703003708, 2, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703003708, 3, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703003708, 4, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703003708, 5, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 1, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 2, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 3, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 4, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 5, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 6, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 7, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 8, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 9, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 10, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 11, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 12, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 13, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 14, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 15, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128003709, 16, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 1, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 2, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 3, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 4, 127, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 5, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 6, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 7, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 8, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 9, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516003710, 10, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 1, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 2, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 3, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 4, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 5, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 6, 100, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 7, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 8, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 9, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227003711, 10, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 1, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 15, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004017, 16, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 1, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 2, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 3, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 4, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 5, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031004018, 6, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 1, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 2, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 3, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 4, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 5, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 6, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 7, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 8, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 9, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 10, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 11, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 12, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 13, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 14, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 15, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727004019, 16, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 1, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 2, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 3, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 4, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 5, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 6, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 7, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 8, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 9, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 10, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 11, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 12, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 13, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608004020, 14, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 1, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 2, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 3, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 4, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 5, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 6, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 7, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 8, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 9, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 10, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 11, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 12, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 13, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 14, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 15, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 16, 93, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902004021, 17, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 1, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 2, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 3, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 4, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 5, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 6, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 7, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 8, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 9, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 10, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 11, 67, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409004022, 12, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 1, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 2, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 3, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 4, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 5, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 6, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 7, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 8, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 9, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 10, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 11, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 12, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 13, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412004023, 14, 26, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 1, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 2, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 3, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 4, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 5, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 6, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 7, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 8, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004024, 9, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 1, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 2, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 3, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 4, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 5, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 6, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 7, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 8, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 9, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 10, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 11, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 12, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 13, 129, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813004025, 14, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 1, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 2, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 3, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 4, 183, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 5, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 6, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 7, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 8, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104004026, 9, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 1, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 2, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 3, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 4, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 5, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 6, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 7, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 8, 166, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 9, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808004027, 10, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 1, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 2, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 3, 89, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 4, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 5, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 6, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 7, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 8, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706004028, 9, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 1, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 2, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 3, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 4, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 5, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 6, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 7, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 8, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 9, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004029, 10, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 1, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 2, 55, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 3, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 4, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 5, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 6, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 7, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 8, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 9, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 10, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 11, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 12, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 13, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 14, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004030, 15, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 1, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 2, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 3, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 4, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 5, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 6, 128, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 7, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 8, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 9, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 10, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 11, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 12, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 13, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 14, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 15, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104004031, 16, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 1, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 2, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 3, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 4, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 5, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 6, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 7, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 8, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 9, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 10, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 11, 101, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 12, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 13, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 14, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 15, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817004032, 16, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 1, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 2, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 3, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 4, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 5, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 6, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 7, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 8, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211004033, 9, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 1, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 2, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 3, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 4, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 5, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 6, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 7, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 8, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 9, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 10, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 11, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 12, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108004034, 13, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 1, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 2, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 3, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 4, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 5, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 6, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 7, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 8, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 9, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 10, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 11, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090224004035, 12, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 1, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 2, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 3, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 4, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 5, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 6, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 7, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 8, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 9, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 10, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 11, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 12, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 13, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123004036, 14, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 1, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224004037, 2, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 12, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 13, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 14, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 15, 175, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 16, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 17, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 18, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111002955, 19, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124002956, 1, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124002956, 2, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124002956, 3, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 1, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 2, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 3, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 4, 9, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 5, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 6, 99, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 7, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 8, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 9, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 10, 121, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 11, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 12, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 13, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 14, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026002957, 15, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216002958, 1, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216002958, 2, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216002958, 3, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216002958, 4, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216002958, 5, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002959, 1, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002959, 2, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002959, 3, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914002959, 4, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 1, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 2, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 3, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 4, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 5, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 6, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002960, 7, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 1, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 2, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 3, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 4, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 5, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 6, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 7, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 8, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 9, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 10, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 11, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 12, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 13, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 14, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 15, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510002961, 16, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 1, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 2, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 3, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 4, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 5, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 6, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101002962, 7, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129002963, 1, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129002963, 2, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129002963, 3, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129002963, 4, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 1, 87, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 2, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 3, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 4, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 5, 47, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 6, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 7, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 8, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 9, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 10, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 11, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 12, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228002964, 13, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 1, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 2, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 3, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 4, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 5, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 6, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 7, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 8, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 9, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 10, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411002965, 11, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 1, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 2, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 3, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 4, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 5, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 6, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 7, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 8, 123, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 9, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 10, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 11, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091214002966, 12, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228002967, 1, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228002967, 2, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228002967, 3, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228002967, 4, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228002967, 5, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430002968, 1, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430002968, 2, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430002968, 3, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203002969, 1, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203002969, 2, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203002969, 3, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 1, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 2, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 3, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 4, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 5, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 6, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 7, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 8, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 9, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 10, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 11, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 12, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913002970, 13, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 1, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 2, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 3, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 4, 78, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 5, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421002971, 6, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002972, 1, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002972, 2, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002972, 3, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430002972, 4, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 1, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 2, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 3, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 4, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 5, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 6, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 7, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 8, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 9, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215002973, 10, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 1, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 2, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 3, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 4, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 5, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 6, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 7, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 8, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819002974, 9, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 1, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 2, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 3, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 4, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 5, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 6, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 7, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 8, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 9, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 10, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 11, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 12, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528002975, 13, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 1, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 2, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 3, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 4, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 5, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 6, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 7, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 8, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 9, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 10, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 11, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026002976, 12, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 1, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 2, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 3, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 4, 155, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 5, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 6, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 7, 168, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615002977, 8, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 1, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 2, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 3, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 4, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 5, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 6, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 7, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506002978, 8, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 1, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 2, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 3, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 4, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 5, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 6, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 7, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 8, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 9, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831002979, 10, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 1, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 2, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 3, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 4, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 5, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 6, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 7, 103, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 9, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 10, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 11, 51, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 12, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020002980, 13, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 1, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 2, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 3, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 4, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 5, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806002981, 6, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513002982, 1, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513002982, 2, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513002982, 3, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513002982, 4, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513002982, 5, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002983, 1, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002983, 2, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018002983, 3, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 1, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 2, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 4, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 5, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 6, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 7, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 8, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060620003341, 9, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 1, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 2, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 3, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 4, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 5, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 6, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 7, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 8, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 9, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 10, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218003342, 11, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 1, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 2, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 3, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 4, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 5, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 6, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 7, 134, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 8, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 9, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 10, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 11, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 12, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827003343, 13, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 1, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 2, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 3, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 4, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 5, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 6, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 7, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 8, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003344, 9, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 1, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 2, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 3, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 4, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 5, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 6, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 7, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 8, 58, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702003345, 9, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 1, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 2, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 3, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 4, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 5, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 6, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 7, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 8, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 9, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 10, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 11, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 12, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 13, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 14, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 15, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 16, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107003346, 17, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 1, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 2, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 3, 25, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 4, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 5, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003003347, 6, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 1, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 2, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 3, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 4, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 5, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 6, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 7, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 8, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 9, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 10, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 11, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129003348, 12, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 1, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 2, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 3, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 4, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 5, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 6, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 7, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 8, 95, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 9, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625003349, 10, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 1, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 2, 45, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 3, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 4, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 5, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 6, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020003350, 7, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 1, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 2, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 3, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 4, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 5, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 6, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 7, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 8, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 9, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 10, 20, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 11, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814003351, 12, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 1, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 2, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 3, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 4, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 5, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901003352, 6, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818003353, 1, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818003353, 2, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818003353, 3, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818003353, 4, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818003353, 5, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 1, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 2, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 3, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 4, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 5, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 6, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 7, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 8, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024003354, 9, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 1, 147, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 2, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 3, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 4, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 5, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 6, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 7, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 8, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 9, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 10, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 11, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202003355, 12, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 1, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 2, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 3, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 4, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 5, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 6, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 7, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 8, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 9, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 10, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402003356, 11, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 1, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 2, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 3, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 4, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 5, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 6, 185, 22, 11, 242);
commit;
prompt 36000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 7, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 8, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 9, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 10, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 11, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 12, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 13, 187, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125003357, 14, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 1, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 2, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 3, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 4, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 5, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 6, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 7, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 8, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 9, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 10, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 11, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 12, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030003358, 13, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 1, 20, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 2, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 3, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 4, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 5, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 6, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 7, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 8, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 9, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 10, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 11, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 12, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 13, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 14, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120330003359, 15, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 1, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 2, 179, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 3, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 4, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 5, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 6, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 7, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 8, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608003360, 9, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 1, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 2, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 3, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 4, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 5, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 6, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 7, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 8, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 9, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 10, 100, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 11, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 12, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323003361, 13, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 1, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 2, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 3, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 4, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 5, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 6, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 7, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 8, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 9, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207003362, 10, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 1, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 2, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 3, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 4, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 5, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828003363, 6, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 1, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 2, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 3, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 4, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 2, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 3, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 4, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 5, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 6, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 7, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 8, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 9, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 10, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 11, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 12, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 13, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 14, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727003712, 15, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000406003713, 1, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000406003713, 2, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 1, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 2, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 3, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 4, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 5, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 6, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 7, 97, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 8, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 9, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 10, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 11, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513003714, 12, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 1, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 2, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 3, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 4, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 5, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 6, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 7, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 8, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 9, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713003715, 10, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 1, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 2, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 3, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 4, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 5, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 6, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 7, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 8, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 9, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003716, 10, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 1, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 2, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 3, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 4, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 5, 1, 28, 3, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 6, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 7, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210003717, 8, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912003718, 1, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912003718, 2, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912003718, 3, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 1, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 2, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 3, 12, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 4, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 5, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 6, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 7, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 8, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 9, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 10, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 11, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 12, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008003719, 13, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 1, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 2, 178, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 3, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 4, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 5, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 6, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 7, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 8, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 9, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 10, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 11, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802003720, 12, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 1, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 2, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 3, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 4, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 5, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 6, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 7, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 8, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 9, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 10, 55, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 11, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 12, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112003721, 13, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815003722, 1, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815003722, 2, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815003722, 3, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815003722, 4, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815003722, 5, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923003723, 1, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923003723, 2, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923003723, 3, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923003723, 4, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 1, 45, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 2, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 3, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 4, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 5, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 6, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 7, 6, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 8, 159, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 9, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 10, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 11, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 12, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 13, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 14, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 15, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 16, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022003724, 17, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928003725, 1, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928003725, 2, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928003725, 3, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928003725, 4, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928003725, 5, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730003726, 1, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730003726, 2, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020003727, 1, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020003727, 2, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020003727, 3, 19, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020003727, 4, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 1, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 2, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 3, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 4, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 5, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 6, 14, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 7, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 8, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 9, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 10, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 11, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 12, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 13, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 14, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 15, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 16, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402003728, 17, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 1, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 2, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 3, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 4, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 5, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 6, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 7, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 8, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410003729, 9, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 1, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 2, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 3, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 4, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 5, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 6, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 7, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 8, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 9, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 10, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 11, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207003730, 12, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 1, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 2, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 3, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 4, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 5, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 6, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205003731, 7, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 1, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 2, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 3, 99, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 4, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 5, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 6, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102003732, 7, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 1, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 2, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 3, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 4, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 5, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 6, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 7, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 8, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 9, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 10, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 11, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 12, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327003733, 13, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 1, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 2, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 3, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 4, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 5, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 6, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 7, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 8, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430003734, 9, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222003735, 1, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222003735, 2, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222003735, 3, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222003735, 4, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615003736, 1, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615003736, 2, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615003736, 3, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 1, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 2, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 3, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 4, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 5, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 6, 97, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 7, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 8, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 9, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 10, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 11, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111003737, 12, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 1, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 2, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 3, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 4, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 5, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 6, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003738, 7, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 1, 96, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 2, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 3, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 4, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 5, 145, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 6, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 7, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 8, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 9, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 10, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422002600, 11, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 1, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 2, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 3, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 4, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 5, 134, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 6, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 7, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106002601, 8, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 1, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 2, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 3, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 4, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 5, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 6, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 7, 32, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 8, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 9, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 10, 48, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 11, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 12, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226002602, 13, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 1, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 2, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 3, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 4, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 5, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 6, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329002603, 7, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 1, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 2, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 3, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 4, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 5, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 6, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 7, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 8, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 9, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 10, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 11, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 12, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403002604, 13, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 1, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 2, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 3, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 4, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 5, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 6, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 7, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 8, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213002605, 9, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 1, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 2, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 3, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 4, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 5, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216002606, 6, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620002607, 1, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620002607, 2, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620002607, 3, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620002607, 4, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620002607, 5, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 1, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 2, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 3, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 4, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 5, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 6, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 7, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 8, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 9, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 10, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 11, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801002608, 12, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 1, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 2, 173, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 3, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 4, 70, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 5, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 6, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 7, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 8, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 9, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 10, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 11, 96, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 12, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002609, 13, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111002610, 1, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111002610, 2, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111002610, 3, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111002610, 4, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111002610, 5, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 1, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 2, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 3, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 4, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 5, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 6, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612002611, 7, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 1, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 2, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 3, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 4, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 5, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 6, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 7, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 8, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 9, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 10, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 11, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 12, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 13, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 14, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 15, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 16, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526002612, 17, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 1, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 2, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 3, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 4, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 5, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 6, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 7, 192, 37, 18, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 8, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 9, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 10, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 11, 111, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 12, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 13, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 14, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 15, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 16, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227002613, 17, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 1, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 2, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 3, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 4, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 5, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 6, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 7, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 8, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 9, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 10, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 11, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 12, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 13, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 14, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822002614, 15, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 1, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 2, 145, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 3, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 4, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 5, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 6, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122002615, 7, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 1, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 2, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 3, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 4, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 5, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 6, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 7, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924002616, 8, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 1, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 2, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 3, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 4, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 5, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 6, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 7, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 8, 192, 84, 18, 1512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 9, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 10, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 11, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 12, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623002617, 13, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 1, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 2, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 3, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 4, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 5, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 6, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 7, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 8, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 9, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 10, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 11, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 12, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317002618, 13, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 1, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 2, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 3, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 4, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 5, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916002619, 6, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 1, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 2, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 3, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 4, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 5, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 6, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 7, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 8, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 9, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 10, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 11, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 12, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 13, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 14, 9, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 15, 88, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 16, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 17, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525002620, 18, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 1, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 2, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 3, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 4, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 5, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 6, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 7, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 8, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 9, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 10, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 11, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 12, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816002621, 13, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 1, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 2, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 3, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 4, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 5, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 6, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 7, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321002622, 8, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 3, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 4, 23, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 5, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 6, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 7, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503002984, 8, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 1, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 2, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 3, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 4, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 5, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 6, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 7, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 8, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 9, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 10, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 11, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 12, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 13, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501002985, 14, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 1, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 2, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 3, 91, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 4, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 5, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 6, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 7, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 8, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 9, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 10, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 11, 174, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 12, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 13, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 14, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 15, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310002986, 16, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 1, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 2, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 3, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 4, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 5, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 6, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 7, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 8, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 9, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322002987, 10, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 1, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 2, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 3, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 4, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 5, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 6, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 7, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 8, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 9, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 10, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 11, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 12, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 13, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102002988, 14, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 1, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 2, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 3, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 4, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 5, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 6, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 7, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 8, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 9, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 10, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122002989, 11, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 1, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 2, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 3, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 4, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 5, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 6, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716002990, 7, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 1, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 2, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 3, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 4, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 5, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 6, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 7, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 8, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 9, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 10, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 11, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 12, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 13, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 14, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 15, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014002991, 16, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 1, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 2, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 3, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 4, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 5, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 6, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 7, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 8, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930002992, 9, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 1, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 2, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 3, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 4, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 5, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 6, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 7, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 8, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 9, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 10, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 11, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 12, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104002993, 13, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813002994, 1, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813002994, 2, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813002994, 3, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813002994, 4, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 1, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 2, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 3, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 4, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 5, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 6, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 7, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 8, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 9, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 10, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 11, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 12, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531002995, 13, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 1, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 2, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 3, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 4, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 5, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 6, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 7, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 8, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 9, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 10, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 11, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 12, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 13, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114002996, 14, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 1, 180, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 2, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 3, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 4, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 5, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 6, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 7, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115002997, 8, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 1, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 2, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 3, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 4, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 5, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 6, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 7, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 8, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 9, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 10, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 11, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 12, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 13, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012002998, 14, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 1, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 2, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 4, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 5, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 6, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 7, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209002999, 8, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 1, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 2, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 3, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 4, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 5, 102, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 6, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 7, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 8, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 9, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 10, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 11, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 12, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 13, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 14, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 15, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 16, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 17, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 18, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107003000, 19, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726003001, 1, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726003001, 2, 41, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726003001, 3, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 1, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 2, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 3, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 4, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 5, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 6, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 7, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 8, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 9, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 10, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 11, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 12, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 13, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 14, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 15, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003002, 16, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023003003, 1, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023003003, 2, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023003003, 3, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023003003, 4, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023003003, 5, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112003004, 1, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112003004, 2, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112003004, 3, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112003004, 4, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 1, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 2, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 3, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 4, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 5, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 6, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428003005, 7, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 1, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 2, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 3, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 4, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 5, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 6, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 7, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 8, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 9, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 5, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 6, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 7, 70, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 8, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 9, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 10, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 11, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 12, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003364, 13, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 1, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 2, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 3, 177, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 4, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 5, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 6, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224003365, 7, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 1, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 2, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 3, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 4, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 5, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 6, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 7, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422003366, 8, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 1, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 2, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 3, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 4, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 5, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 6, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 7, 66, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 8, 3, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 9, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027003367, 10, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 1, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 2, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 3, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 5, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 6, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 7, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 8, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901003368, 9, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 1, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 2, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 3, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 4, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 5, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 6, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 7, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 8, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 9, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 10, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 11, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 12, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 13, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 14, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 15, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111003369, 16, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 1, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 2, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 3, 52, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 4, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 5, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 6, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 7, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 8, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 9, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 10, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 11, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528003370, 12, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 1, 139, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 2, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 3, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 4, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 5, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 6, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 7, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 8, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060707003371, 9, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 1, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 2, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 3, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 4, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 5, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 6, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003372, 7, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 1, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 2, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 3, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 4, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 5, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 6, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 7, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 8, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 9, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 10, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 11, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 12, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302003373, 13, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 1, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 2, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 3, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 4, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 5, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 6, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 7, 89, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 8, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 9, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 10, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 11, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 12, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 13, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 14, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103003374, 15, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 1, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 2, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 3, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 4, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 5, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 6, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 7, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 8, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 9, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 10, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 11, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 12, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 13, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 14, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 15, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101003375, 16, 192, 23, 18, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 1, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 2, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 3, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 4, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 5, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 6, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 7, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 8, 150, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 9, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 10, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919003376, 11, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 1, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 2, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 3, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 4, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 5, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 6, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 7, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 8, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 9, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 10, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 11, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 12, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 13, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614003377, 14, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615003378, 1, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615003378, 2, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615003378, 3, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615003378, 4, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615003378, 5, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005003379, 1, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005003379, 2, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005003379, 3, 51, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005003379, 4, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005003379, 5, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 1, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 2, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 3, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 4, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 5, 13, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 6, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 7, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 8, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 9, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 10, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120003380, 11, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228003381, 1, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228003381, 2, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228003381, 3, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228003381, 4, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228003381, 5, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 1, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 2, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 3, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 4, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 5, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 6, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 7, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 8, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 9, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 10, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410003382, 11, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 1, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 2, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 3, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 4, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 5, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 6, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 7, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 8, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 9, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120003383, 10, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 1, 86, 56, 12, 672);
commit;
prompt 37000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 2, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 3, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 4, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 5, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714003384, 6, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218003385, 1, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218003385, 2, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218003385, 3, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218003385, 4, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 1, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 2, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 3, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 4, 1, 95, 3, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 5, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 6, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 7, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 8, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 9, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 10, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128003386, 11, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 1, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 2, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 3, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 4, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 5, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 6, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 7, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 8, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 9, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 10, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 11, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 12, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 13, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 14, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 15, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 16, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 6, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 7, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 8, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 9, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 10, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 11, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 12, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 13, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721003739, 14, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 1, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 2, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 3, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 4, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 5, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 6, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 7, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 8, 96, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 9, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 10, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 11, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 12, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 13, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 14, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 15, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125003740, 16, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 1, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 2, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 3, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 4, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 5, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 6, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 7, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 8, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 9, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 10, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 11, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 12, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022003741, 13, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302003742, 1, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302003742, 2, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302003742, 3, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302003742, 4, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302003742, 5, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 1, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 2, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 3, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 4, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 5, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 6, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 7, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 8, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 9, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 10, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904003743, 11, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 1, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 2, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 3, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 5, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 6, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 7, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 8, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 9, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 10, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 11, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 12, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 13, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 14, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 15, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 16, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812003744, 17, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 1, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 2, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 3, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 4, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 5, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 6, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 7, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 8, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 9, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 10, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 11, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 12, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 13, 78, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 14, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 15, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117003745, 16, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319003746, 1, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319003746, 2, 148, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319003746, 3, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319003746, 4, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319003746, 5, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 1, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 2, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 3, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 4, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 5, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 6, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 7, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 8, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 9, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 10, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 11, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 12, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 13, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110003747, 14, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 1, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 2, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 3, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 4, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 5, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 6, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 7, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 8, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 9, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 10, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 11, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 12, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 13, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422003748, 14, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 1, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 2, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 3, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 4, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 5, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 6, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 7, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 8, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 9, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 10, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625003749, 11, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 1, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 2, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 3, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 4, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 5, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 6, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 7, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 8, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 9, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 10, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 11, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202003750, 12, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 1, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 2, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 3, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 4, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 5, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 6, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 7, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710003751, 8, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217003752, 1, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217003752, 2, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217003752, 3, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217003752, 4, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217003752, 5, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204003753, 1, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204003753, 2, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204003753, 3, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204003753, 4, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 1, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 2, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 3, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 4, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 5, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 6, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 7, 151, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 8, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 9, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050716003754, 10, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 1, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 2, 62, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 3, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 4, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 5, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 6, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 7, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 8, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 9, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 10, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 11, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 12, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 13, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 14, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 15, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 16, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003755, 17, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 1, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 2, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 3, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 4, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 5, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 6, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 7, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 8, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 9, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 10, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 11, 184, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 12, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 13, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 14, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130826003756, 15, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 1, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 2, 60, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 3, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 4, 111, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 5, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003757, 6, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 1, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 2, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 3, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 4, 4, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 5, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 6, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 7, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 8, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 9, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 10, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 11, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 12, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 13, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 14, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124003758, 15, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 1, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 2, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 3, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 4, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 5, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 6, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 7, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 8, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 9, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 10, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 11, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 12, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 13, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 14, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023003759, 15, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 1, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 1, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 2, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 3, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 4, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 5, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 6, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 7, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 8, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418002623, 9, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 1, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 2, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 3, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 4, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 5, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 6, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 7, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 8, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 9, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 10, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 11, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112002624, 12, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 1, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 2, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 3, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 4, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 5, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 6, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 7, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 8, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 9, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 10, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 11, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 12, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 13, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 14, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 15, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130002625, 16, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815002626, 1, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815002626, 2, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815002626, 3, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815002626, 4, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 1, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 2, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 3, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 4, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 5, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 6, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 7, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 8, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328002627, 9, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 1, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 2, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 3, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 4, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 5, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 6, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 7, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 8, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 9, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 10, 124, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 11, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 12, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712002628, 13, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 1, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 2, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 3, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 4, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 5, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 6, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 7, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 8, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 9, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 10, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 11, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 12, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 13, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805002629, 14, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 1, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 2, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 3, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 4, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 5, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 6, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 7, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126002630, 8, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 1, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 2, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 3, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 4, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 5, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 6, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413002631, 7, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325002632, 1, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325002632, 2, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909002633, 1, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909002633, 2, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909002633, 3, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909002633, 4, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 1, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 2, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 3, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 4, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 5, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 6, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 7, 6, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 8, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 9, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 10, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 11, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812002634, 12, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002635, 1, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002635, 2, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002635, 3, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002635, 4, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314002635, 5, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 1, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 2, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 3, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 4, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 5, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 6, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 7, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 8, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926002636, 9, 48, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515002637, 1, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515002637, 2, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515002637, 3, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515002637, 4, 25, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515002637, 5, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 1, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 2, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 3, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 4, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 5, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 6, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 7, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 8, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 9, 78, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 10, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 11, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 12, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 13, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 14, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711002638, 15, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 1, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 2, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 3, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 4, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 5, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 6, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 7, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 8, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 9, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 10, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 11, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 12, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 13, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 14, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 15, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112002639, 16, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 1, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 2, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 3, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 4, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 5, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 6, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 8, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 9, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 10, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 11, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 12, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 13, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 14, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 15, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 16, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027002640, 17, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 2, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 3, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 4, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 5, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 6, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 7, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 8, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 9, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 10, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 11, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 12, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 13, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 14, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 15, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016002641, 16, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 1, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 2, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 3, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 4, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 5, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 6, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 7, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 8, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 9, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 10, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 11, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 12, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 13, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 14, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 15, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 16, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130002642, 17, 73, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 1, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 2, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 3, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 4, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 5, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 6, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 7, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 8, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 9, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 10, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 11, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 12, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 13, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701002643, 14, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 1, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 2, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 3, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 4, 183, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 5, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 6, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 7, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 8, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 9, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 10, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 11, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727002644, 12, 6, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 1, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 2, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 3, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 10, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 11, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 12, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 13, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 14, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 15, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324003006, 16, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 1, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 2, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 3, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 4, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 5, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 6, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 7, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 8, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 9, 192, 18, 18, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 10, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802003007, 11, 83, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 1, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 2, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 3, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 4, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 5, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 6, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 7, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 8, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 9, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 10, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 11, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 12, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 13, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 14, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 15, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 16, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123003008, 17, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 1, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 2, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 3, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 4, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 5, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 6, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 7, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 8, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 9, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 10, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 11, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419003009, 12, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 1, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 2, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 3, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 4, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 5, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 6, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 7, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 8, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 9, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 10, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 11, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 12, 91, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 13, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 14, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 15, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822003010, 16, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 1, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 2, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 3, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 4, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 5, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 6, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 7, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 8, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 9, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 10, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 11, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 12, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 13, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625003011, 14, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 1, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 2, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 3, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 4, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 5, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 6, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104003012, 7, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 1, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 2, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 3, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 4, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 5, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 6, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 7, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 8, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 9, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 10, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 11, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 12, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 13, 45, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019003013, 14, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 1, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 2, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 3, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 4, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 5, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 6, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 7, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 8, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 9, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 10, 160, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 11, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 12, 103, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 13, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 14, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 15, 111, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 16, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 17, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 18, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327003014, 19, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 1, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 2, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 3, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 4, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 5, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 6, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712003015, 7, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 1, 32, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 2, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 3, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 4, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 5, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 6, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 7, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 8, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 9, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 10, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071019003016, 11, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 1, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 2, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 3, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 4, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 5, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 6, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 7, 158, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 8, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 9, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301003017, 10, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003018, 1, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003018, 2, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003018, 3, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003018, 4, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320003018, 5, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 1, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 2, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 3, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 4, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 5, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 6, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705003019, 7, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 1, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 2, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 3, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 4, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 5, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 6, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 7, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114003020, 8, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 1, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 2, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 3, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 4, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 5, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 6, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 7, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 8, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228003021, 9, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 1, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 2, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 3, 10, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 4, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 5, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 6, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 7, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 8, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 9, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228003022, 10, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 1, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 2, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 3, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 4, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 5, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430003023, 6, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116003024, 1, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116003024, 2, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116003024, 3, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 1, 154, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 2, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 3, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 4, 51, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 5, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 6, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 7, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 8, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 9, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 10, 14, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 11, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 12, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 13, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 14, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 15, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418003025, 16, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 1, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 2, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 3, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 4, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 5, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 6, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 7, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 8, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 9, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 10, 24, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 11, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 12, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 13, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 14, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708003026, 15, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 1, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 2, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 3, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 4, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 5, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 6, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 7, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 8, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 9, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 10, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 11, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 12, 39, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 13, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 14, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 15, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917003387, 17, 31, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 1, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 2, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 3, 149, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 4, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 5, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 6, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 7, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 8, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 9, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 10, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 11, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 12, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 13, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 14, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003388, 15, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 1, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 2, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 3, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 4, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 5, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 6, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 7, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 8, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 9, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019003389, 10, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 1, 1, 56, 3, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 2, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 3, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 4, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 5, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 6, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 7, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 8, 88, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 9, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 10, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 11, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 12, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 13, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 14, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 15, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220003390, 16, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 1, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 2, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 3, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 5, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 6, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 7, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 8, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 9, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 10, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603003391, 11, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117003392, 1, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117003392, 2, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 1, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 2, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 3, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 4, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 5, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 6, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 7, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 8, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 9, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071013003393, 10, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 1, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 2, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 3, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 4, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 5, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907003394, 6, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 1, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 2, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 3, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 4, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 5, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 6, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 7, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 8, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 9, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 10, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 11, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 12, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 13, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 14, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001003395, 15, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 1, 71, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 2, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 3, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 4, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 5, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031003396, 6, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 1, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 2, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 3, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 4, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 5, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 6, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 7, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 8, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 9, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 10, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 11, 133, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 12, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 13, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928003397, 14, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 1, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 2, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 3, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 4, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 5, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 6, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 7, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 8, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 9, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 10, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 11, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 12, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 13, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 14, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 15, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709003398, 16, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 1, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 2, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 3, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 4, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 5, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 6, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523003399, 7, 168, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012003400, 1, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012003400, 2, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001012003400, 3, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 1, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 2, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 3, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 4, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 5, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 6, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 7, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 8, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 9, 180, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 10, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 11, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 12, 67, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 13, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 14, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515003401, 15, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 1, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 2, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 3, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 4, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 5, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 6, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 7, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 8, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313003402, 9, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 1, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 2, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 3, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 4, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 5, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 6, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 7, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 8, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 9, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 10, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 11, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 12, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 13, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 14, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 15, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 16, 133, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215003403, 17, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 1, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 3, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 4, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 5, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 6, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 7, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 8, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 9, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 10, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 11, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129003404, 12, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 1, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 2, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 3, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 4, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 5, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 6, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 7, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 8, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 9, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 10, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 11, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 12, 4, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824003405, 13, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 1, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 2, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 3, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 4, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 5, 30, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 6, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 7, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505003406, 8, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 1, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 2, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 3, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 4, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 5, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 6, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 7, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 8, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 9, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 10, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 11, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 12, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612003407, 13, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 1, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 2, 145, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 3, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 4, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 5, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 6, 134, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711003408, 7, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 1, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 2, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 3, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 4, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 5, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 6, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 7, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224003409, 8, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 1, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 2, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 3, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 4, 122, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 5, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 2, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 3, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 4, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 5, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327003760, 6, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 1, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 2, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 3, 86, 56, 12, 672);
commit;
prompt 38000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 4, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 5, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 6, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 7, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 8, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 9, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 10, 37, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225003761, 11, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 1, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 2, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 3, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 4, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 5, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 6, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 7, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 8, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 9, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 10, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 11, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 12, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 13, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 14, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 15, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 16, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101003762, 17, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 1, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 2, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 3, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 4, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 5, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 6, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 7, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 8, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 9, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 10, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 11, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 12, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 13, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 14, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812003763, 15, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 1, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 2, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 3, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 4, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 5, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 6, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 7, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 8, 151, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429003764, 9, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 1, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 2, 143, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 3, 187, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 4, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 5, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 6, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 8, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 9, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 10, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 11, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 12, 149, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 13, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412003765, 14, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 1, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 2, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 3, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 4, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 5, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 6, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 7, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 8, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 9, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 10, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 11, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 12, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004003766, 13, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 1, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 2, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 3, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 4, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 5, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104003767, 6, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 1, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 2, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 3, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 4, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 5, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 6, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 7, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830003768, 8, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 1, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 2, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 3, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 4, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 5, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 6, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 7, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 8, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 9, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 10, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 11, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 12, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 13, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009003769, 14, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 1, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 2, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 3, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 4, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 5, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 6, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 7, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 8, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 9, 155, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 10, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213003770, 11, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 1, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 2, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 3, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 4, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 5, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 6, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 7, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 8, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 9, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 10, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 11, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 12, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 13, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 14, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811003771, 15, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523003772, 1, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523003772, 2, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523003772, 3, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 1, 78, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 2, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 3, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 4, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 5, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 6, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 7, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 8, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 9, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 10, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 11, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 12, 34, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 13, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 14, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 15, 146, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208003773, 16, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116003774, 1, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116003774, 2, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116003774, 3, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 1, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 2, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 3, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 4, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 5, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913003775, 6, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 1, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 2, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 3, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 4, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 5, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 6, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222003776, 7, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 1, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 2, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 3, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 4, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 5, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 6, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 7, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 8, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 9, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517003777, 10, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 1, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 2, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 3, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 4, 145, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 5, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 6, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 7, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 8, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 9, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815003778, 10, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 1, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 2, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 3, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 4, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 5, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 6, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 7, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 8, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 9, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 10, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024003779, 11, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 1, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 2, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 3, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 4, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 5, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 6, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 7, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 8, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 9, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 10, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 11, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 12, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 13, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 14, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109003780, 15, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 1, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 2, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 3, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 4, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 5, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 6, 190, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 7, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051203003781, 8, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 1, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 2, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 3, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 4, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 5, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 6, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 7, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 8, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 9, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102003782, 10, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 1, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 4, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 5, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 6, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 7, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 8, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 9, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 10, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 11, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 12, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804002645, 13, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002646, 1, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002646, 2, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002646, 3, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703002646, 4, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226002647, 1, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226002647, 2, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226002647, 3, 153, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226002647, 4, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226002647, 5, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 1, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 2, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 3, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 4, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 5, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 6, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 7, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 8, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 9, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 10, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 11, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 12, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 13, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802002648, 14, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 1, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 2, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 3, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 4, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 5, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 6, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 7, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111002649, 8, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201002650, 1, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201002650, 2, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201002650, 3, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201002650, 4, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201002650, 5, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 1, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 2, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 3, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 4, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 5, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 6, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 7, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 8, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 9, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 10, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 11, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 12, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 13, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 14, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 15, 80, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 16, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726002651, 17, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115002652, 1, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115002652, 2, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115002652, 3, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115002652, 4, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115002652, 5, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 1, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 2, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 3, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 4, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 5, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 6, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 7, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 8, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 9, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 10, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 11, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 12, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606002653, 13, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 1, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 2, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 3, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 4, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 5, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 6, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 7, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 8, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827002654, 9, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002655, 1, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002655, 2, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009002655, 3, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002656, 1, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002656, 2, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002656, 3, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002656, 4, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324002656, 5, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 1, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 2, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 3, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 4, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 5, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 6, 141, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801002657, 7, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227002658, 1, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227002658, 2, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227002658, 3, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227002658, 4, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227002658, 5, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 1, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 2, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 3, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 4, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 5, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 6, 63, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 7, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 8, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 9, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 10, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 11, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 12, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 13, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 14, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206002659, 15, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 1, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 2, 176, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 3, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 4, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 5, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 6, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 7, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 8, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 9, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 10, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 11, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 12, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 13, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 14, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 15, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 16, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 17, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823002660, 18, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 1, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 2, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 3, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 4, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 5, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 6, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 7, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 8, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 9, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 10, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 11, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 12, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017002661, 13, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 1, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 2, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 3, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 4, 166, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 5, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 6, 122, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 7, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 8, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 9, 6, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 10, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 11, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 12, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 13, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 14, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 15, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 16, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 17, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107002662, 18, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 1, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 2, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 3, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 4, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 5, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 6, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 7, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 8, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617002663, 9, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 1, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 2, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 3, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 4, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 5, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 6, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 7, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 8, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319002664, 9, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 1, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 2, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 3, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 4, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 5, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 6, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 7, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 8, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 9, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026002665, 10, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 1, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 2, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 3, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 4, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 5, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 6, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 7, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 8, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 9, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 10, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 11, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 12, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 13, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 14, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418002666, 15, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 1, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 2, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 3, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 4, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 5, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 6, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 7, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 8, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205002667, 9, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 1, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 2, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 3, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 4, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 5, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 6, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129002668, 7, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212002669, 1, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212002669, 2, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212002669, 3, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212002669, 4, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212002669, 5, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 1, 30, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719003027, 16, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 1, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 2, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 3, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 4, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 5, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 6, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 7, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 8, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 9, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 10, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930003028, 11, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 1, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 2, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 3, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 4, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 5, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 6, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030807003029, 7, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109003030, 1, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109003030, 2, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109003030, 3, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109003030, 4, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511003031, 1, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511003031, 2, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511003031, 3, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511003031, 4, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 1, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 2, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 3, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 4, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 5, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 6, 107, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 7, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 8, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 9, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 10, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 11, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831003032, 12, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 1, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 2, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 3, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 4, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 5, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 6, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815003033, 7, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624003034, 1, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624003034, 2, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624003034, 3, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624003034, 4, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624003034, 5, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714003035, 1, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714003035, 2, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714003035, 3, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 1, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 2, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 3, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 4, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 5, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 6, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 7, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 8, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 9, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 10, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 11, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080124003036, 12, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003037, 1, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003037, 2, 68, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003037, 3, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003037, 4, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010328003037, 5, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 1, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 2, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 3, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 4, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 5, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 6, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 7, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 8, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 9, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 10, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 11, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 12, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 13, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 14, 130, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 15, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 16, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121122003038, 17, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 1, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 2, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 3, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 4, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 5, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 6, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 7, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 8, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 9, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928003039, 10, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204003040, 1, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204003040, 2, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204003040, 3, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204003040, 4, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 1, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 2, 19, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 3, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 4, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 5, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 6, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523003041, 7, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 1, 52, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 2, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 3, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 4, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 5, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 6, 192, 79, 18, 1422);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 7, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 8, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 9, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 10, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 11, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 12, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 13, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 14, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 15, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604003042, 16, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027003043, 1, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027003043, 2, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027003043, 3, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027003043, 4, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027003043, 5, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 1, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 2, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 3, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 4, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 5, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 6, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 7, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 8, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 9, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 10, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 11, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 12, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 13, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 14, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 15, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203003044, 16, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 1, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 2, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 3, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 4, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 5, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 6, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 7, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 8, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 9, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 10, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 11, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 12, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 13, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 14, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003045, 15, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 1, 132, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 2, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 3, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 4, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 5, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 6, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 7, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 8, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 9, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 10, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 11, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 12, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 13, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 14, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 15, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025003046, 16, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003047, 1, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003047, 2, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003047, 3, 182, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003047, 4, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003047, 5, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 1, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 2, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 3, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 4, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 5, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 6, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 7, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 8, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 9, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 10, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221003048, 11, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 1, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 2, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 3, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 4, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 5, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 6, 69, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 7, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 8, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 9, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 10, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 11, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 12, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 13, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 14, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 15, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422003049, 16, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 1, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 2, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 3, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 4, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 5, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 6, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 7, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 8, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 9, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 10, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 11, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 12, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 13, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 14, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502003050, 15, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 1, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 2, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 3, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 4, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 5, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 6, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 7, 189, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 8, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 9, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 10, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 11, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 12, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 13, 157, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 14, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 15, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 6, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 7, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 8, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 9, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 10, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 11, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 12, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 13, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 14, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 15, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 16, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 17, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121003410, 18, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 1, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 2, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 3, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 4, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 5, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 6, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 7, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 8, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 9, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 10, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 11, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 12, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 13, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 14, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825003411, 15, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 1, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 2, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 3, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 4, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 5, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 6, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 7, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 8, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 9, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 10, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 11, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 12, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 13, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 14, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 15, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315003412, 16, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 1, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 2, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 3, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 4, 175, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 5, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 6, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030224003413, 7, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 1, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 2, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 3, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 4, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 5, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 6, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 7, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 8, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 9, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213003414, 10, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 1, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 2, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 3, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 4, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 5, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 6, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 7, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 8, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 9, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831003415, 10, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 1, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 2, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 3, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 4, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 5, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 6, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 7, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 8, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 9, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 10, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 11, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 12, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 13, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 14, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009003416, 15, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 1, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 2, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 3, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 4, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 5, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 6, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 7, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 8, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 9, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 10, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 11, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 12, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 13, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 14, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 15, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 16, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308003417, 17, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 1, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 2, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 3, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 4, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 5, 132, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 6, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 7, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030003418, 8, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 1, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 2, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 3, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 4, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 5, 27, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 6, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 7, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 8, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 9, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 10, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 11, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 12, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818003419, 13, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 1, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 2, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 3, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 4, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 5, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 6, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 7, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 8, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 9, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 10, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 11, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610003420, 12, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 1, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 2, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 3, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 4, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 5, 181, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 6, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301003421, 7, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 1, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 2, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 3, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 4, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 5, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 6, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 7, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 8, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 9, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 10, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 11, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 12, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 13, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118003422, 14, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003423, 1, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003423, 2, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003423, 3, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003423, 4, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003423, 5, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 1, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 2, 88, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 3, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 4, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 5, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 6, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 7, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 8, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 9, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 10, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 11, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318003424, 12, 73, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 1, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 2, 183, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 3, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 4, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 5, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 6, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327003425, 7, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 1, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 2, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 3, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 4, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 5, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212003426, 6, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 1, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 2, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 3, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 4, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 5, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 6, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 7, 168, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 8, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726003427, 9, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 1, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 2, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 3, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 4, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 5, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 6, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 7, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 8, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 9, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 10, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 11, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 12, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 13, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823003428, 14, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 1, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 2, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 3, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 4, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 5, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 6, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 7, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 8, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 9, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118003429, 10, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003430, 1, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003430, 2, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003430, 3, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003003430, 4, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 1, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 2, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 3, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 4, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 5, 4, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 6, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 7, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 8, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 9, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050621003431, 10, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 1, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 2, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 3, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 4, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 5, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 2, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 3, 109, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 4, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 5, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 6, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 7, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 8, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 9, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524003783, 10, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 1, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 2, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 3, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 4, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 5, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 6, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 7, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 8, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 9, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 10, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 11, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104003784, 12, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 1, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 2, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 3, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 4, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 5, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 6, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011003785, 7, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 1, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 2, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 3, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 4, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 5, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 6, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 7, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 8, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 9, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604003786, 10, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003787, 1, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003787, 2, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003787, 3, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003787, 4, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 1, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 2, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 3, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 4, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 5, 122, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 6, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 7, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 8, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723003788, 9, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 1, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 2, 110, 2, 12, 24);
commit;
prompt 39000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 3, 32, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 4, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 5, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924003789, 6, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 1, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 2, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 3, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 4, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 5, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 6, 76, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 7, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 8, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014003790, 9, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 1, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 2, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 3, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 4, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 5, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 6, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 7, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 8, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 9, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 10, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 11, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 12, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 13, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 14, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 15, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 16, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219003791, 17, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 1, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 2, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 3, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 4, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 5, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 6, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 7, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305003792, 8, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 1, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 2, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 3, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 4, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 5, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 6, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 7, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207003793, 8, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 1, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 2, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 3, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 4, 167, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 5, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 6, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 7, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 8, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 9, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 10, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 11, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 12, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 13, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801003794, 14, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 1, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 2, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 3, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 4, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 5, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 6, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 7, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 8, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 9, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 10, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 11, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 12, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201003795, 13, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 1, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 2, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 3, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 4, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 5, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 6, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 7, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 8, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 9, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 10, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 11, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 12, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 13, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 14, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 15, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415003796, 16, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 1, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 2, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 3, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 4, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 5, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 6, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 7, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 8, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 9, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 10, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110003797, 11, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 1, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 2, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 3, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 4, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 5, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 6, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 7, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820003798, 8, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 1, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 2, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 3, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 4, 51, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 5, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 6, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 7, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 8, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 9, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505003799, 10, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 1, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 2, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 3, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 4, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 5, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 6, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 7, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 8, 10, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 9, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 10, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517003800, 11, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 1, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 2, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 3, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 4, 23, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 5, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 6, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 7, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 8, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060314003801, 9, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 1, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 2, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 3, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 4, 41, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 5, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003802, 6, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 1, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 2, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 3, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 4, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 5, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 6, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 7, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 8, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 9, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 10, 81, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 11, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 12, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409003803, 13, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 1, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 2, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 3, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 4, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 5, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 6, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 7, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 8, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 9, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 10, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 11, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 12, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 13, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 14, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 15, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 16, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408003804, 17, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 1, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 2, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 3, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 4, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 5, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 6, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 7, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 8, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 9, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201003805, 10, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 1, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 2, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 3, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 2, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 3, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 4, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 5, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 6, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608002670, 7, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 1, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 2, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 3, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 4, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 5, 143, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 6, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 7, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 8, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 9, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 10, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 11, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610002671, 12, 19, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 1, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 2, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 3, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 4, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 5, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 6, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 7, 192, 85, 18, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023002672, 8, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 1, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 2, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 3, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 4, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 5, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 6, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 7, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 8, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 9, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 10, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 11, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 12, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 13, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 14, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 15, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128002673, 16, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 1, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 2, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 3, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 4, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 5, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 6, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 7, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 8, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 9, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 10, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 11, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 12, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 13, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 14, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 15, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 16, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406002674, 17, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 1, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 2, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 3, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 4, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 5, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020002675, 6, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113002676, 1, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113002676, 2, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113002676, 3, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113002676, 4, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113002676, 5, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 1, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 2, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 3, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 4, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 5, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 6, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 7, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531002677, 8, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 1, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 2, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 3, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 4, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 5, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 6, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 7, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 8, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 9, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 10, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 11, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 12, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 13, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330002678, 14, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219002679, 1, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219002679, 2, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219002679, 3, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219002679, 4, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219002679, 5, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 1, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 2, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 3, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 4, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 5, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 6, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 7, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 8, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107002680, 9, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 1, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 2, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 3, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 4, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 5, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 6, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 7, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511002681, 8, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002682, 1, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002682, 2, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002682, 3, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002682, 4, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624002682, 5, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 1, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 2, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 3, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 4, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 5, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 6, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702002683, 7, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212002684, 1, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212002684, 2, 125, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212002684, 3, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212002684, 4, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904002685, 1, 10, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904002685, 2, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904002685, 3, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 1, 104, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 2, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 3, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 4, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 5, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 6, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 7, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328002686, 8, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 1, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 2, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 3, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 4, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 5, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 6, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 7, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 8, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 9, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 10, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 11, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926002687, 12, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 1, 192, 94, 18, 1692);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 2, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 3, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 4, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 5, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 6, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 7, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 8, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 9, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 10, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 11, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 12, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921002688, 13, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 1, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 2, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 3, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 4, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 5, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 6, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 7, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 8, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 9, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 10, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 11, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 12, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 13, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428002689, 14, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 1, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 2, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 3, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 4, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 5, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 6, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 7, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 8, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 9, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 10, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 11, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 12, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315002690, 13, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 1, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 2, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 3, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 4, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 5, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 6, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 7, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 8, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108002691, 9, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 1, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 2, 67, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 3, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 4, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 5, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 6, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 7, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 8, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 9, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 10, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 11, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 12, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929002692, 13, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 1, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 2, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 3, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 4, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 5, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 6, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 7, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 8, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 9, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 10, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 11, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 12, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 13, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 14, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131102002693, 15, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 1, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 2, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 3, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 4, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 5, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 6, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 7, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 8, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 9, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 16, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 17, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218003051, 18, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 1, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 2, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 3, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 4, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 5, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 6, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 7, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 8, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 9, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 10, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 11, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 12, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 13, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 14, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 15, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 16, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131003052, 17, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 1, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 2, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 3, 39, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 4, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 5, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 6, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 7, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 8, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 9, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 10, 190, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 11, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 12, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090822003053, 13, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003054, 1, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003054, 2, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003054, 3, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003054, 4, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003054, 5, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 1, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 2, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 3, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 4, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 5, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 6, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 7, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 8, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 9, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 10, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014003055, 11, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 1, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 2, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 3, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 4, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 5, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 6, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 7, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 8, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 9, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 10, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 11, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 12, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 13, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 14, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 15, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 16, 40, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113003056, 17, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 1, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 2, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 3, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 4, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 5, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 6, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 7, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 8, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 9, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 10, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 11, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314003057, 12, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 1, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 2, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 3, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 4, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 5, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 6, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330003058, 7, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001105003059, 1, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001105003059, 2, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001105003059, 3, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330003060, 1, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330003060, 2, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330003060, 3, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330003060, 4, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330003060, 5, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 1, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 2, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 3, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 4, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 5, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 6, 136, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 7, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 8, 78, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 9, 70, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 10, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 11, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 12, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310003061, 13, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 1, 49, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 2, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 3, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 4, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 5, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 6, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 7, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 8, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 9, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 10, 42, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 11, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 12, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307003062, 13, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003063, 1, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003063, 2, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003063, 3, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003063, 4, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904003063, 5, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504003064, 1, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504003064, 2, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504003064, 3, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504003064, 4, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504003064, 5, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 1, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 2, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 3, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 4, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 5, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 6, 155, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 7, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 8, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 9, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 10, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 11, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 12, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 13, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 14, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 15, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 16, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 17, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112003065, 18, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 1, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 2, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 3, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 4, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 5, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 6, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 7, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 8, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 9, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329003066, 10, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 1, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 2, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 3, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 4, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 5, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 6, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 7, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 8, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 9, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 10, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 11, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 12, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 13, 39, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 14, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620003067, 15, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 1, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 2, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 3, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 4, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 5, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 6, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 7, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 8, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 9, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 10, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 11, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 12, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 13, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 14, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 15, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 16, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 17, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118003068, 18, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 1, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 2, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 3, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 4, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 5, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 6, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 7, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 8, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 9, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 10, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 11, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 12, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 13, 89, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 14, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 15, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 16, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119003069, 17, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 1, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 2, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 3, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 4, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 5, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 6, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 7, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 8, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 9, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 10, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 11, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 12, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 13, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 14, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 15, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 16, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 17, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003070, 18, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 1, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 2, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 3, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 4, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 5, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 6, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 7, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708003071, 8, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 1, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 2, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 3, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 4, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 5, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 6, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 6, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729003432, 7, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625003433, 1, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625003433, 2, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625003433, 3, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625003433, 4, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625003433, 5, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 1, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 2, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 3, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 4, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 5, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 6, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207003434, 7, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 1, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 2, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 3, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 4, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 5, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 6, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 7, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519003435, 8, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003436, 1, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003436, 2, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003436, 3, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409003436, 4, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112003437, 1, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112003437, 2, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112003437, 3, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 1, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 2, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 3, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 4, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 5, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 6, 160, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 7, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 8, 154, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 9, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 10, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 11, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 12, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622003438, 13, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 1, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 2, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 3, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 4, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 5, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 6, 160, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 7, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 8, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 9, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 10, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 11, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 12, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 13, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 14, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 15, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802003439, 16, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 1, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 2, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 3, 41, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 4, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 5, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 6, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 7, 24, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 8, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 9, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 10, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918003440, 11, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 1, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 2, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 3, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 4, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 5, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 6, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 7, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 8, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 9, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 10, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 11, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 12, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 13, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 14, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031003441, 15, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 1, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 2, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 3, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 4, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 5, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 6, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 7, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 8, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 9, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 10, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 11, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603003442, 12, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 1, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 2, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 3, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 4, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 5, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 6, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 7, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 8, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 9, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 10, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 11, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 12, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 13, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 14, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 15, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 16, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225003443, 17, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 1, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 2, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 3, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 4, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 5, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 6, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 7, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 8, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 9, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 10, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118003444, 11, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 1, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 2, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 3, 153, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 4, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 5, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 6, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 7, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 8, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 9, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117003445, 10, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 1, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 2, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 3, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 4, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 5, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 6, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 7, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 8, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 9, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 10, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 11, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 12, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 13, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 14, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 15, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511003446, 16, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 1, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 2, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 3, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 4, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 5, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 6, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 7, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227003447, 8, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 1, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 2, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 3, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 4, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 5, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 6, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 7, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 8, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130003448, 9, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 1, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 2, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 3, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 4, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 5, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 6, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 7, 2, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 8, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 9, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 10, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 11, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 12, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 13, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519003449, 14, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 1, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 2, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 3, 89, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 4, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 5, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 6, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 7, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 8, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807003450, 9, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 1, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 2, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 3, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 4, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 5, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 6, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618003451, 7, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 1, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 2, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 3, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 4, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 5, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 6, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 7, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 8, 37, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 9, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 10, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 11, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 12, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 13, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 14, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 15, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627003452, 16, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 1, 48, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 2, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 3, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 4, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 5, 105, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 6, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 7, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 8, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 9, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 10, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 11, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 12, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 13, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 14, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 15, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 16, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 17, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921003453, 18, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 1, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 2, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 3, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 4, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 5, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 6, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 7, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417003454, 8, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 4, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 5, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 6, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 7, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 8, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 9, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 10, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 11, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330003806, 12, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603003807, 1, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603003807, 2, 114, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010603003807, 3, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 1, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 2, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 3, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 4, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 5, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 6, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020825003808, 7, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 1, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 2, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 3, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 4, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 5, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 6, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 7, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 8, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 9, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 10, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 11, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 12, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 13, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 14, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 15, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215003809, 16, 120, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726003810, 1, 123, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726003810, 2, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726003810, 3, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726003810, 4, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726003810, 5, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 1, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 2, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 3, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 4, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 5, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 6, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218003811, 7, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 1, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 2, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 3, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 4, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 5, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 6, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 7, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 8, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 9, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 10, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 11, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 12, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 13, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 14, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214003812, 15, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927003813, 1, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927003813, 2, 57, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927003813, 3, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927003813, 4, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003814, 1, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003814, 2, 175, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118003814, 3, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 1, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 2, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 3, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 4, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 5, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 6, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 7, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 8, 137, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 9, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 10, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 11, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 12, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 13, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427003815, 14, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 1, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 2, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 3, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 4, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 5, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 6, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 7, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 8, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 9, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 10, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 11, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 12, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 13, 192, 22, 18, 396);
commit;
prompt 40000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 14, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130003816, 15, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 1, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 2, 118, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 3, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 4, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 5, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 6, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 7, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 8, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 9, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926003817, 10, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 1, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 2, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 3, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 4, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 5, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 6, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 7, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110003818, 8, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 1, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 2, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 3, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 4, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 5, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 6, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 7, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 8, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 9, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 10, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 11, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 12, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 13, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 14, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 15, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620003819, 16, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 1, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 2, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 3, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 4, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 5, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 6, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 7, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602003820, 8, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 1, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 2, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 3, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 4, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 5, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 6, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 7, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 8, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 9, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 10, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 11, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 12, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 13, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 14, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 15, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 16, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 17, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119003821, 18, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003822, 1, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003822, 2, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003822, 3, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015003822, 4, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 1, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 2, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 3, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 4, 90, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 5, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 6, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 7, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 8, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 9, 2, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108003823, 10, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 1, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 2, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 3, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 4, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 5, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 6, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121003824, 7, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502003825, 1, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502003825, 2, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502003825, 3, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502003825, 4, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 1, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 2, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 3, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 4, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 5, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 6, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 7, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 8, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 9, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 10, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 11, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114003826, 12, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 1, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 2, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 3, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 4, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 5, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 6, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 7, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 8, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 9, 25, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 10, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 11, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121003827, 12, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 1, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 2, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 3, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 4, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 5, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 6, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023003828, 7, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 1, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 2, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 3, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 4, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 5, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524003829, 6, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 1, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 2, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 3, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 4, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 5, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 6, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 7, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 8, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 9, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 10, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 11, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 12, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015003830, 13, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 1, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 2, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 3, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 4, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 5, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 10, 112, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 11, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129002694, 12, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 1, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 2, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 3, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 4, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 5, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 6, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 7, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 8, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 9, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 10, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 11, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 12, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331002695, 13, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 1, 192, 58, 18, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 2, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 3, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 4, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 5, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 6, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 7, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 8, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 9, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 10, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 11, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 12, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 13, 108, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 14, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 15, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111002696, 16, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 1, 27, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 2, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 3, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 4, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 5, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 6, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827002697, 7, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 1, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 2, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 3, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 4, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 5, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 6, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 7, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 8, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 9, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 10, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515002698, 11, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 1, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 2, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 3, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 4, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 5, 17, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 6, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 7, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 8, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117002699, 9, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529002700, 1, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529002700, 2, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529002700, 3, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529002700, 4, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529002700, 5, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 1, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 2, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 3, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 4, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 5, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 6, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 7, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 8, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 9, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 10, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 11, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624002701, 12, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 1, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 2, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 3, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 4, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 5, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 6, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 7, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 8, 174, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 9, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 10, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318002702, 11, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 1, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 2, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 3, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 4, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 5, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 6, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 7, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 8, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 9, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 10, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 11, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 12, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 13, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 14, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130002703, 15, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 1, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 2, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 3, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 4, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 5, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 6, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 7, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 8, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 9, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 10, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209002704, 11, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 1, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 2, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 3, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 4, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 5, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 6, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 7, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 8, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 9, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 10, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 11, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 12, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 13, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901002705, 14, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 1, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 2, 182, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 3, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 4, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 5, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 6, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 7, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 8, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 9, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 10, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 11, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 12, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 13, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731002706, 14, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 1, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 2, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 3, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 4, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 5, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 6, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 7, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 8, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 9, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 10, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 11, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 12, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 13, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 14, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110412002707, 15, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703002708, 1, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703002708, 2, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703002708, 3, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 1, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 2, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 3, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 4, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 5, 186, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 6, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 7, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 8, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 9, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 10, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 11, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 12, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904002709, 13, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 1, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 2, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 3, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 4, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 5, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 6, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 7, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 8, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 9, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 10, 148, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 11, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 12, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615002710, 13, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 1, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 2, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 3, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 4, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 5, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 6, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 7, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 8, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 9, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 10, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 11, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 12, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 13, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 14, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 15, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 16, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 17, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131002711, 18, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921002712, 1, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921002712, 2, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 1, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 2, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 3, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 4, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 5, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 6, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 7, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 8, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112002713, 9, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 1, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 2, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 3, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 4, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 5, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311002714, 6, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 1, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 2, 93, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 3, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 4, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 5, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 6, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 7, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 8, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 9, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 10, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 11, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 12, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224002715, 13, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119002716, 1, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119002716, 2, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 1, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 2, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 3, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 7, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 8, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 9, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209003072, 10, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 1, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 2, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 3, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 4, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 5, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 6, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 7, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 8, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 9, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 10, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 11, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 12, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 13, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330003073, 14, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003074, 1, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003074, 2, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003074, 3, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003074, 4, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425003074, 5, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 1, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 2, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 3, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 4, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 5, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 6, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 7, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 8, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 9, 131, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626003075, 10, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 1, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 2, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 3, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 4, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 5, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 6, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 7, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 8, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 9, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 10, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 11, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 12, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 13, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414003076, 14, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 1, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 2, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 3, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 4, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 5, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 6, 60, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 7, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 8, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061209003077, 9, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 1, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 2, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 3, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 4, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 5, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 6, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 7, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 8, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 9, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 10, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 11, 56, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 12, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 13, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 14, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 15, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117003078, 16, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 1, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 2, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 4, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 5, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 6, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 7, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 8, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 9, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 10, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 11, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 12, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 13, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 14, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116003079, 15, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326003080, 1, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326003080, 2, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326003080, 3, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326003080, 4, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 1, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 2, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 3, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 4, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 5, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 6, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 7, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 8, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 9, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 10, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 11, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 12, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 13, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 14, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 15, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719003081, 16, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 1, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 2, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 3, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 4, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 5, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 6, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 7, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 8, 1, 88, 3, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 9, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 10, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 11, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 12, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 13, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 14, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 15, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621003082, 16, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 1, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 2, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 3, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 4, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 5, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216003083, 6, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 1, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 2, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 3, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 4, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 5, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 6, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 7, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 8, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 9, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 10, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 11, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 12, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 13, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 14, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124003084, 15, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 1, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 2, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 3, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 4, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 5, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 6, 102, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 7, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 8, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 9, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 10, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 11, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 12, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 13, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 14, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719003085, 15, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 1, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 2, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 3, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 4, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 5, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 6, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 7, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 8, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 9, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 10, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 11, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 12, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 13, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918003086, 14, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 1, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 2, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 3, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 4, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 5, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 6, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 7, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 8, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 9, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207003087, 10, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206003088, 1, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206003088, 2, 16, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206003088, 3, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206003088, 4, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 1, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 2, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 3, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 4, 74, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 5, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 6, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 7, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 8, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 9, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706003089, 10, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 1, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 2, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 3, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 4, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 5, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 6, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 7, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419003090, 8, 144, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 1, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 2, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 3, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 4, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 5, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 6, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 7, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 8, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 9, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 10, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 11, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 12, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 13, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 14, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 15, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709003091, 16, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 1, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 2, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 3, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 4, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 5, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 6, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 7, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 8, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 9, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 10, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 11, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 12, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 13, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 14, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 15, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 16, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522003092, 17, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 1, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 1, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 2, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 3, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 4, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 5, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 6, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 7, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 8, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 9, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 10, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 11, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 12, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 13, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 14, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 15, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 16, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924003455, 17, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 1, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 2, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 3, 1, 30, 3, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 4, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 5, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506003456, 6, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 1, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 2, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 3, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 4, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 5, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 6, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 7, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 8, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 9, 88, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530003457, 10, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 1, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 2, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 3, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 4, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 5, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 6, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 7, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 8, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 9, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 10, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 11, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203003458, 12, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 1, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 2, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 3, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 4, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 5, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 6, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 7, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 8, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 9, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 10, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 11, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 12, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 13, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913003459, 14, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 1, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 2, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 3, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 4, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 5, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 6, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 7, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 8, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 9, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 10, 70, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080420003460, 11, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 1, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 2, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 3, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 4, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 5, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 6, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 7, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 8, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 9, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 10, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 11, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 12, 20, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 13, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123003461, 14, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 1, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 2, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 3, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 4, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 5, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 6, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 7, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 8, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 9, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 10, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 11, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 12, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 13, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 14, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220003462, 15, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331003463, 1, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331003463, 2, 88, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331003463, 3, 190, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331003463, 4, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 1, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 2, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 3, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 4, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 5, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 6, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 7, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 8, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 9, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 10, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 11, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 12, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 13, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209003464, 14, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 1, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 2, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 3, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 4, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 5, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 6, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 7, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 8, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 9, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 10, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 11, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100316003465, 12, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 1, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 2, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 3, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 4, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 5, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 6, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 7, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 8, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 9, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 10, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 11, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 12, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026003466, 13, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 1, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 2, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 3, 128, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 4, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 5, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 6, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203003467, 7, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 1, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 2, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 3, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 4, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 5, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 6, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 7, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 8, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104003468, 9, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 1, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 2, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 3, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 5, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 6, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 7, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 8, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 9, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 10, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 11, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 12, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 13, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 14, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518003469, 15, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203003470, 1, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203003470, 2, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203003470, 3, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203003470, 4, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 1, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 2, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 3, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 4, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 5, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 6, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 7, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 8, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 9, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 10, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 11, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124003471, 12, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 1, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 2, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 3, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 4, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 5, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 6, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 7, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 8, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 9, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616003472, 10, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 1, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 2, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 3, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 4, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 5, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 6, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825003473, 7, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 1, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 2, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 3, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 4, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 5, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 6, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 7, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 8, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 9, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 10, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 11, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 12, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 13, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 14, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 15, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 16, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106003474, 17, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 1, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 2, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 3, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 4, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 5, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 6, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 7, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703003475, 8, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 1, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 2, 185, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 3, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 4, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 5, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 6, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830003476, 7, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 6, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 7, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 8, 125, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 9, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 10, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105003831, 11, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 1, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 2, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 3, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 4, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 5, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 6, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 7, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 8, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 9, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 10, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 11, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 12, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 13, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 14, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224003832, 15, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 1, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 2, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 3, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 4, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 5, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 6, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 7, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 8, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 9, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 10, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 11, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 12, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 13, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 14, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231003833, 15, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 1, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 2, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 3, 69, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 4, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 5, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811003834, 6, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 1, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 2, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 3, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 4, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 5, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 6, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 7, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 8, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 9, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 10, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 11, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011003835, 12, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 1, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 2, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 3, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 4, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 5, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 6, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 7, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050531003836, 8, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 1, 177, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 2, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 3, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 4, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 5, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 6, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 7, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 8, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 9, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 10, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 11, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 12, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005003837, 13, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 1, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 2, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 3, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 4, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 5, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 6, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 7, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 8, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507003838, 9, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 1, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 2, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 3, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 4, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 5, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 6, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 7, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 8, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 9, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 10, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 11, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 12, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 13, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115003839, 14, 30, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 1, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 2, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 3, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 4, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 5, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 6, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326003840, 7, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 1, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 2, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 3, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 4, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 5, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408003841, 6, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730003842, 1, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730003842, 2, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730003842, 3, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 1, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 2, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 3, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 4, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 5, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 6, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 7, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 8, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 9, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 10, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 11, 160, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 12, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 13, 171, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 14, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801003843, 15, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003844, 1, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003844, 2, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226003844, 3, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729003845, 1, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729003845, 2, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729003845, 3, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729003845, 4, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 1, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 2, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 3, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 4, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 5, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121003846, 6, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 1, 155, 5, 12, 60);
commit;
prompt 41000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 2, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 3, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 4, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 5, 55, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 6, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 7, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 8, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 9, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 10, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 11, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507003847, 12, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 1, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 2, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 3, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 4, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 5, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 6, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 7, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 8, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 9, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 10, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 11, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 12, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 13, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 14, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709003848, 15, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702003849, 1, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702003849, 2, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702003849, 3, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702003849, 4, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710003850, 1, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710003850, 2, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710003850, 3, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 1, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 2, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 3, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 4, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 5, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 6, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 7, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 8, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 9, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 10, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 11, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100322003851, 12, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 1, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 2, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 3, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 4, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 5, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 6, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 7, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 8, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 9, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 10, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912003852, 11, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 1, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 2, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 3, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 4, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 5, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309003853, 6, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 1, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 2, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 3, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 4, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 5, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 6, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 7, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 8, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 9, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 10, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 11, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 12, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 13, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 14, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 15, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220003854, 16, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 1, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 2, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 3, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 4, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 5, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 6, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 7, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 8, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 9, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 10, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 11, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 12, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102003855, 13, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 1, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 2, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 3, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703003856, 4, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 4, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 5, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 6, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 7, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 8, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 9, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 10, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 11, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 12, 48, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 13, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 14, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 15, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 16, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120002717, 17, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 1, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 2, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 3, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 4, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 5, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 6, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 7, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 8, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 9, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 10, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 11, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 12, 50, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 13, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 14, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110513002718, 15, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 1, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 2, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 3, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 4, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 5, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204002719, 6, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 1, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 2, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 3, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 4, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 5, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 6, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 7, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 8, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 9, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 10, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 11, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 12, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 13, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 14, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227002720, 15, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 1, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 2, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 3, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 4, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 5, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512002721, 6, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 1, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 2, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 3, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 4, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 5, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 6, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 7, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 8, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 9, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 10, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 11, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 12, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 13, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 14, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 15, 182, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901002722, 16, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 1, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 2, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 3, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 4, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 5, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 6, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606002723, 7, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 1, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 2, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 3, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 4, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 5, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 6, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 7, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 8, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 9, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209002724, 10, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 1, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 2, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 3, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 4, 13, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 5, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 6, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 7, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 8, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 9, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 10, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 11, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818002725, 12, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 1, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 2, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 3, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 4, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 5, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 6, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 7, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 8, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 9, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 10, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 11, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 12, 52, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609002726, 13, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 1, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 2, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 3, 151, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 4, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 5, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 6, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 7, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 8, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 9, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 10, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 11, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 12, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 13, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 14, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504002727, 15, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 1, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 2, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 3, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 4, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 5, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 6, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 7, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 8, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 9, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 10, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 11, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 12, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213002728, 13, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 1, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 2, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 3, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 4, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 5, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 6, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 7, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 8, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 9, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 10, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 11, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 12, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 13, 78, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 14, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 15, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 16, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811002729, 17, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002730, 1, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002730, 2, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001003002730, 3, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 1, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 2, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 3, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 4, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 5, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 6, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 7, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 8, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 9, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 10, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 11, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611002731, 12, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 1, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 2, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 3, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 4, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 5, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 6, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 7, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 8, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 9, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051116002732, 10, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 1, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 2, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 3, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 4, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 5, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125002733, 6, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 1, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 2, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 3, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 4, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 5, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 6, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 7, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 8, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 9, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 10, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605002734, 11, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 1, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 2, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 3, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 4, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 5, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 6, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 7, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 8, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 9, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 10, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 11, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 12, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 13, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 14, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 15, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111002735, 16, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 1, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 2, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 3, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 4, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 5, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 6, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224002736, 7, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109002737, 1, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109002737, 2, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 1, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 2, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 3, 165, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 4, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 5, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 6, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 7, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 8, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 9, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 10, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 11, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311002738, 12, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 2, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 4, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 5, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 6, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 7, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 8, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 9, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 10, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 11, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117003093, 12, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 1, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 2, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 3, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 4, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 5, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 6, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 7, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 8, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 9, 28, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 10, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 11, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210003094, 12, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717003095, 1, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717003095, 2, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717003095, 3, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717003095, 4, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717003095, 5, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 1, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 2, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 3, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 4, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 5, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 6, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 7, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208003096, 8, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117003097, 1, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117003097, 2, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117003097, 3, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011117003097, 4, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 1, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 2, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 3, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 4, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 5, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213003098, 6, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 1, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 2, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 3, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 4, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 5, 60, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 6, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 7, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 8, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 9, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 10, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 11, 16, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 12, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 13, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 14, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221003099, 15, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 1, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 2, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 3, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 4, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 5, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 6, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 7, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 8, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 9, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 10, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 11, 46, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 12, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 13, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 14, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 15, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901003100, 16, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 1, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 2, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 3, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 4, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 5, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 6, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 7, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 8, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 9, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 10, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 11, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 12, 104, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 13, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830003101, 14, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 1, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 2, 48, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 3, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 4, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 5, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 6, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 7, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 8, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 9, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 10, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725003102, 11, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 1, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 2, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 3, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 4, 162, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 5, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 6, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 7, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 8, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 9, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 10, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106003103, 11, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726003104, 1, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726003104, 2, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726003104, 3, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726003104, 4, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726003104, 5, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 1, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 2, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 3, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 4, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 5, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 6, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 7, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 8, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 9, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 10, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 11, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 12, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 13, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 14, 192, 95, 18, 1710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817003105, 15, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917003106, 1, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917003106, 2, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917003106, 3, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917003106, 4, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917003106, 5, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 1, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 2, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 3, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 4, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 5, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211003107, 6, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 1, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 2, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 3, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 4, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 5, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 6, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 7, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 8, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 9, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217003108, 10, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 1, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 2, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 3, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 4, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 5, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 6, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 7, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 8, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 9, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 10, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 11, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 12, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227003109, 13, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 1, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 2, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 3, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 4, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 5, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506003110, 6, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 1, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 2, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 3, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 4, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 5, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803003111, 6, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 1, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 2, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 3, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 4, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 5, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 6, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 7, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 8, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 9, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 10, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 11, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 12, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 13, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 14, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514003112, 15, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 1, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 2, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 3, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 4, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 5, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 6, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 7, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 8, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 9, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 10, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 11, 18, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 12, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921003113, 13, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 1, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 2, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 3, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 4, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 5, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 6, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 7, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 8, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 9, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324003114, 10, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 1, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 2, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 3, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 4, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 5, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926003115, 6, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 1, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 2, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 3, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 4, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 5, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 6, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 7, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 8, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 9, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 10, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 11, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 12, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 13, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 14, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 15, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824003116, 16, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605004595, 4, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511004596, 1, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511004596, 2, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511004596, 3, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511004596, 4, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511004596, 5, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 1, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 2, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 3, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 4, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 5, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 6, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 7, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 8, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 9, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 10, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 11, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 12, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 13, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 14, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 15, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 16, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523004597, 17, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 1, 67, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 2, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 3, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 4, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 5, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 6, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 7, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 8, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 9, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 10, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605004598, 11, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 1, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 2, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 3, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 4, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 5, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 6, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 7, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 8, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 9, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 10, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 11, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 12, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 13, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 14, 142, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912004599, 15, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 1, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 2, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 3, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 4, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 5, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 6, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 7, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 8, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 9, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 10, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 11, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 12, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 13, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 14, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911004600, 15, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 1, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 2, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 3, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 4, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 5, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 6, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 7, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 8, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 9, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 10, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 11, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 12, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 13, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 14, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004601, 15, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 1, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 2, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 3, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 4, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 5, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 6, 4, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920004602, 7, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 1, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 2, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 3, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 4, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 5, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 6, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 7, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 8, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 9, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 10, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 11, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 12, 182, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 13, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004603, 14, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813004604, 1, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813004604, 2, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813004604, 3, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813004604, 4, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 1, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 2, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 3, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 4, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 5, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 6, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004605, 7, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 1, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 2, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 3, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 4, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 5, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 6, 138, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 7, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 8, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 9, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 10, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 11, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 12, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609004606, 13, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 1, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 2, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 3, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 4, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 5, 44, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 6, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 7, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 8, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 9, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 10, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 11, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 12, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 13, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323004607, 14, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 1, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 2, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 3, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 4, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 5, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 6, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 7, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 8, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 9, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 10, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 11, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 12, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 13, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110410004608, 14, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 1, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 2, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 3, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 4, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 5, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207004609, 6, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 1, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 2, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 3, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 4, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 5, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 6, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 7, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 8, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 9, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 10, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928004610, 11, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 1, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 2, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 3, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 4, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 5, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 6, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 7, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 8, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 9, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080311004611, 10, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622004612, 1, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622004612, 2, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121004613, 1, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121004613, 2, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121004613, 3, 112, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 1, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 2, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 3, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 4, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 5, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 6, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 7, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 8, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 9, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 10, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 11, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 12, 24, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 13, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 14, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 15, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 16, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211004614, 17, 155, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 1, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 2, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 3, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 4, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 5, 141, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 6, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 7, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 8, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 9, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 10, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 11, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004615, 12, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 1, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 2, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 3, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 4, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 5, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 6, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 7, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 8, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 9, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509004616, 10, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 1, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 2, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 3, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 4, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 5, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 6, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 7, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 8, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 9, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 10, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 11, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 12, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 13, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 14, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 15, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 16, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004617, 17, 170, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 5, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 6, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 7, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 8, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 9, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 1, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 2, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 3, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 4, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 5, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 6, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 7, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218004975, 8, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 1, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 2, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 3, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 4, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 5, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 6, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 7, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 8, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 9, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625004976, 10, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 1, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 2, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 3, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 4, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 5, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 6, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 7, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 8, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 9, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 10, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929004977, 11, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 1, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 2, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 3, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 4, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 5, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 6, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 7, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209004978, 8, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 1, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 2, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 3, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 4, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 5, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 6, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 7, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019004979, 8, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 1, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 2, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 3, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 4, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 5, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 6, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 7, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 8, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 9, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 10, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 11, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 12, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 13, 1, 53, 3, 159);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 14, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 15, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130004980, 16, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 1, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 2, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 3, 165, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 4, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 5, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 6, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 7, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 8, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 9, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 10, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 11, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607004981, 12, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 1, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 2, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 3, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 4, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 5, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 6, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 7, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 8, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 9, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 10, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 11, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 12, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024004982, 13, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824004983, 1, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824004983, 2, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824004983, 3, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125004984, 1, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125004984, 2, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125004984, 3, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125004984, 4, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125004984, 5, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124004985, 1, 174, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001124004985, 2, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 1, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 2, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 3, 187, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 4, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 5, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 6, 90, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 7, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908004986, 8, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 1, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 2, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 3, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 4, 192, 54, 18, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 5, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 6, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 7, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 8, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 9, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 10, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 11, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 12, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029004987, 13, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 1, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 2, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 3, 81, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 4, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 5, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 6, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 7, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 8, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 9, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 10, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 11, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 12, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402004988, 13, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 1, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 2, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 3, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 4, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 5, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812004989, 6, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 1, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 2, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 3, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 4, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 5, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 6, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 7, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 8, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 9, 15, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 10, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 11, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 12, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111004990, 13, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 1, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 2, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 3, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 4, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 5, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 6, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 7, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 8, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 9, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 10, 185, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 11, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 12, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 13, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 14, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 15, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004991, 16, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 1, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 2, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 3, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 4, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 5, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 6, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 7, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 8, 71, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 9, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 10, 8, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 11, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 12, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 13, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 14, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 15, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728004992, 16, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 1, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 2, 119, 7, 14, 98);
commit;
prompt 42000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 3, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 4, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 5, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 6, 72, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 7, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 8, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 9, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 10, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 11, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004993, 12, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212004994, 1, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212004994, 2, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212004994, 3, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212004994, 4, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212004994, 5, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 1, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 2, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 3, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 4, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 5, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 6, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418004995, 7, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 1, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 2, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 3, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 4, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 5, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 6, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918004996, 7, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 1, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 2, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 3, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 4, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 5, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321004997, 6, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 1, 156, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 2, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 3, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 4, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 5, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 6, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 7, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 8, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 9, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 10, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 11, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 12, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 13, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421004998, 14, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808004999, 1, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 1, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 2, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 3, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 4, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 5, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 6, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 7, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 8, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 9, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 10, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 11, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 12, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 13, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 14, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 15, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005355, 16, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101005356, 1, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101005356, 2, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101005356, 3, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101005356, 4, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101005356, 5, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 1, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 2, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 3, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 4, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 5, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 6, 94, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 7, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424005357, 8, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 1, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 2, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 3, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 4, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 5, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 6, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 7, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 8, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 9, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 10, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 11, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 12, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831005358, 13, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303005359, 1, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303005359, 2, 49, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303005359, 3, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303005359, 4, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419005360, 1, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419005360, 2, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419005360, 3, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419005360, 4, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 1, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 2, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 3, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 4, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 5, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 6, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 7, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 8, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 9, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 10, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 11, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005361, 12, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 1, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 2, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 3, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 4, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 5, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 6, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 7, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 8, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 9, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 10, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 11, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 12, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203005362, 13, 8, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 1, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 2, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 3, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 4, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 5, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 6, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 7, 86, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 8, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 9, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 10, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 11, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 12, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207005363, 13, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 1, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 2, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 3, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 4, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 5, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004005364, 6, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 1, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 2, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 3, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 4, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 5, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119005365, 6, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 1, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 2, 141, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 3, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 4, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 5, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 6, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 7, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 8, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 9, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060207005366, 10, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 1, 131, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 2, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 3, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 4, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 5, 88, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 6, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 7, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 8, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 9, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 10, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 11, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617005367, 12, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 1, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 2, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 3, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 4, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 5, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 6, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 7, 117, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 8, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 9, 19, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 10, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 11, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 12, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 13, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 14, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 15, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 16, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312005368, 17, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 1, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 2, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 3, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 4, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 5, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 6, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 7, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 8, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 9, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 10, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 11, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 12, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 13, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 14, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 15, 138, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224005369, 16, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 1, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 2, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 3, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 4, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 5, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005370, 6, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016005371, 1, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016005371, 2, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016005371, 3, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016005371, 4, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 1, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 2, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 3, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 4, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 5, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 6, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 7, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 8, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 9, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 10, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005372, 11, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 1, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 2, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 3, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 4, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 5, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 6, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 7, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 8, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 9, 147, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 10, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 11, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 12, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 13, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 14, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 15, 185, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031005373, 16, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 1, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 2, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 3, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 4, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 5, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 6, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 7, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 8, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 9, 186, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 10, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 11, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 12, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 13, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116005374, 14, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923005375, 1, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923005375, 2, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923005375, 3, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005376, 1, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005376, 2, 131, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005376, 3, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 1, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 2, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 3, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 4, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 5, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 6, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 7, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 8, 130, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 9, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911005377, 10, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007005378, 1, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007005378, 2, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007005378, 3, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007005378, 4, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 1, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 2, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 3, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 4, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 5, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011005379, 6, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 1, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 2, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 3, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 4, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 5, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 6, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 11, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 12, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 13, 30, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019004228, 1, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019004228, 2, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019004228, 3, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019004228, 4, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 1, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 2, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 3, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 4, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 5, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 6, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 7, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 8, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 9, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 10, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 11, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 12, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 13, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 14, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 15, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 16, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309004229, 17, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606004230, 1, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606004230, 2, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606004230, 3, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000606004230, 4, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 1, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 2, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 3, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 4, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 5, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 6, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 7, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 8, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 9, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 10, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 11, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 12, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 13, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 14, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 15, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330004231, 16, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208004232, 1, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208004232, 2, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208004232, 3, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 1, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 3, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 4, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 5, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 6, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 7, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 8, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 9, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 10, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 11, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 12, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 13, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 14, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 15, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107004233, 16, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 1, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 2, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 3, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 4, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 5, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 6, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 7, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 8, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 9, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 10, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 11, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 12, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 13, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 14, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 15, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 16, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309004234, 17, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 1, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 2, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 3, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 4, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 5, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 6, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 7, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 8, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 9, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 10, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810004235, 11, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 1, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 2, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 3, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 4, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 5, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231004236, 6, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004237, 1, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004237, 2, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004237, 3, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004237, 4, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004237, 5, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 1, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 2, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 3, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 4, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 5, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 6, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 7, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 8, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 9, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 10, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 11, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416004238, 12, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215004239, 1, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215004239, 2, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215004239, 3, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 1, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 2, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 3, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 4, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 5, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 6, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 7, 112, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 8, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 9, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 10, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 11, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 12, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 13, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 14, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 15, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916004240, 16, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 1, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 2, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 3, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 4, 94, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 5, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 6, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 7, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 8, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208004241, 9, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917004242, 1, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917004242, 2, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917004242, 3, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917004242, 4, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917004242, 5, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 1, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 2, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 3, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 4, 37, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 5, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 6, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 7, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 8, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 9, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426004243, 10, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 1, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 2, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 3, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 4, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 5, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 6, 34, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 7, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 8, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 9, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 10, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 11, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 12, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 13, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 14, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909004244, 15, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 1, 55, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 2, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 3, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 4, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 5, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 6, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 7, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 8, 4, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 9, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 10, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029004245, 11, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 1, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 2, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 3, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 4, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 5, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 6, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 7, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 8, 6, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 9, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 10, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 11, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 12, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 13, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127004246, 14, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 1, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 2, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 3, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 4, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 5, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 6, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 7, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 8, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 9, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 10, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 11, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 12, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 13, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 14, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 15, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 16, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 17, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407004247, 18, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 1, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 2, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 3, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 4, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 5, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 6, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 7, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 8, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411004248, 9, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 1, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 2, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 3, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 4, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 5, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 6, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 7, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319004249, 8, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 1, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 2, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 3, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 4, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 5, 152, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004250, 6, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 1, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117004618, 1, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117004618, 2, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117004618, 3, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117004618, 4, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117004618, 5, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 1, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 2, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 3, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 4, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 5, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 6, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727004619, 7, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228004620, 1, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228004620, 2, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228004620, 3, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228004620, 4, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228004620, 5, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 1, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 2, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 3, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 4, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 5, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 6, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 7, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210004621, 8, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718004622, 1, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718004622, 2, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718004622, 3, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718004622, 4, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 1, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 2, 33, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 3, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 4, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 5, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 6, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 7, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 8, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 9, 25, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 10, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 11, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 12, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 13, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 14, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 15, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216004623, 16, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 1, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 2, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 3, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 4, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 5, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030414004624, 6, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 1, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 2, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 3, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 4, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 5, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 6, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 7, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 8, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 9, 105, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 10, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 11, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 12, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 13, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 14, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810004625, 15, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 1, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 2, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 3, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 4, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 5, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 6, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 7, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 8, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 9, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 10, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 11, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 12, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923004626, 13, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 1, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 2, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 3, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 4, 73, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 5, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 6, 20, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 7, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 8, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 9, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 10, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 11, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831004627, 12, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 1, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 2, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 3, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 4, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 5, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 6, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 7, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 8, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 9, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 10, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 11, 58, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 12, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 13, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 14, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205004628, 15, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422004629, 1, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422004629, 2, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422004629, 3, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 1, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 2, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 3, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 4, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 5, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 6, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503004630, 7, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807004631, 1, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807004631, 2, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807004631, 3, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807004631, 4, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 1, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 2, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 3, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 4, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 5, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 6, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 7, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 8, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 9, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 10, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 11, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 12, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 13, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 14, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 15, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 16, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209004632, 17, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 1, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 2, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 3, 127, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 4, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 5, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 6, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 7, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 8, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927004633, 9, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510004634, 1, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510004634, 2, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 1, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 2, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 3, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 4, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 5, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 6, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317004635, 7, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 1, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 2, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 3, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 4, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 5, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101004636, 6, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 1, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 2, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 3, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 4, 76, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 5, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 6, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 7, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 8, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 9, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081206004637, 10, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 1, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 2, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 3, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 4, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 5, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 6, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 7, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 8, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 9, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 10, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 11, 125, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 12, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214004638, 13, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 1, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 2, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 3, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 4, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 5, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 6, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 7, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 8, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 9, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 10, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 11, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080328004639, 12, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 1, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 2, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 3, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 4, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 5, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119004640, 6, 9, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 1, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 2, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 3, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 4, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 5, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 6, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 7, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 8, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 9, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 10, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 11, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 12, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 13, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 14, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 15, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140324004641, 16, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 1, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 2, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 3, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 4, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 5, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 6, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 7, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 8, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 9, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 10, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219004642, 11, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 1, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 2, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 3, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 4, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 6, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 7, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 8, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 9, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 10, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808004999, 2, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808004999, 3, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808004999, 4, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 1, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 2, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 3, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 4, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 5, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 6, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 7, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 8, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 9, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 10, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 11, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 12, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 13, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 14, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 15, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 16, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623005000, 17, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 1, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 2, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 3, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 4, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 5, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 6, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 7, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321005001, 8, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 1, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 2, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 3, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 4, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 5, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 6, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603005002, 7, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 1, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 2, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 3, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 4, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 5, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 6, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 7, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 8, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 9, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 10, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 11, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 12, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805005003, 13, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 1, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 2, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 3, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 4, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 5, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311005004, 6, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001005005, 1, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001005005, 2, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001005005, 3, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001005005, 4, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001005005, 5, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 1, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 2, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 3, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 4, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 5, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 6, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 7, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 8, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 9, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 10, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091122005006, 11, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 1, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 2, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 3, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 4, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 5, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 6, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 7, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 8, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313005007, 9, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 1, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 2, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 3, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 4, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 5, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005008, 6, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 1, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 2, 89, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 3, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 4, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 5, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 6, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 7, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005009, 8, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 1, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 2, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 3, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 4, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 5, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 6, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 7, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 8, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 9, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 10, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 11, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 12, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 13, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 14, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311005010, 15, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 1, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 2, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 3, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 4, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 5, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 6, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 7, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 8, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 9, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 10, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 11, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 12, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004005011, 13, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 1, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 2, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 3, 119, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 4, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 5, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 6, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 7, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 8, 170, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 9, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928005012, 10, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 1, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 2, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 3, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 4, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 5, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 6, 110, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 7, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 8, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 9, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 10, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129005013, 11, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030005014, 1, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030005014, 2, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030005014, 3, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 1, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 2, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 3, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 4, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 5, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 6, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 7, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 8, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 9, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 10, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 11, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 12, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 13, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 14, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119005015, 15, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 1, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 2, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 3, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 4, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 5, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 6, 79, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 7, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 8, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 9, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 10, 131, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 11, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 12, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 13, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 14, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019005016, 15, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 1, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 2, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 3, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 4, 67, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 5, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 6, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 7, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 8, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 9, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 10, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 11, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 12, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 13, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 14, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 15, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 16, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306005017, 17, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 1, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 2, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 3, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 4, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 5, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701005018, 6, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 1, 100, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 2, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 3, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 4, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 5, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 6, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 7, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 8, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 9, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 10, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 11, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 12, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 13, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 14, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710005019, 15, 143, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 1, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 2, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 3, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 4, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 5, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 6, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 7, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 8, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 9, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 10, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 11, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 12, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 13, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101224005020, 14, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 1, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 2, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 3, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 4, 83, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 5, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 6, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 7, 124, 95, 12, 1140);
commit;
prompt 43000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 8, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 9, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 10, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 11, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118005021, 12, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 7, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 8, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 9, 103, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 10, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005380, 11, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 1, 34, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 2, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 3, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 4, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 5, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 6, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 7, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 8, 15, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821005381, 9, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 1, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 2, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 3, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 4, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 5, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 6, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 7, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 8, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 9, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 10, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 11, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 12, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 13, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 14, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 15, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 16, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 17, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140330005382, 18, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515005383, 1, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515005383, 2, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515005383, 3, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515005383, 4, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 1, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 2, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 3, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 4, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 5, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 6, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 7, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 8, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 9, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 10, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 11, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 12, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 13, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 14, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 15, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 16, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 17, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005384, 18, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 1, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 2, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 3, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 4, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 5, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 6, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 7, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 8, 126, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 9, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 10, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 11, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 12, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 13, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908005385, 14, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 1, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 2, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 3, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 4, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 5, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 6, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128005386, 7, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 1, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 2, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 3, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 4, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 5, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 6, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 7, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 8, 56, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071125005387, 9, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 1, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 2, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 3, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 4, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 5, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 6, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 7, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 8, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 9, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502005388, 10, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 1, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 2, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 3, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 4, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 5, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 6, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 7, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 8, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 9, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 10, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719005389, 11, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005390, 1, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005390, 2, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005390, 3, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026005390, 4, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 1, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 2, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 3, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 4, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 5, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029005391, 6, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 1, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 2, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 3, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 4, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 5, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 6, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025005392, 7, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 1, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 2, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 3, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 4, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 5, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 6, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 7, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 8, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 9, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 10, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 11, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714005393, 12, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 1, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 2, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 3, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 4, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 5, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 6, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 7, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005394, 8, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 1, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 2, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 3, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 4, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 5, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 6, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 7, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 8, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 9, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 10, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 11, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 12, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 13, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 14, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 15, 166, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130607005395, 16, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 1, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 2, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 3, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 4, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 5, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 6, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 7, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 8, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 9, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 10, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 11, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 12, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 13, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 14, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 15, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510005396, 16, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 1, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 2, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 3, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 4, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 5, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 6, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 7, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 8, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205005397, 9, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 1, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 2, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 3, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 4, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 5, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 6, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 7, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 8, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 9, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 10, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 11, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 12, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 13, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928005398, 14, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 1, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 2, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 3, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 4, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 5, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 6, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 7, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 8, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 9, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 10, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 11, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 12, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 13, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 14, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 15, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113005399, 16, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 1, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 2, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 3, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 4, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 5, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 6, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 7, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 8, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 9, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 10, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 11, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 12, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215005400, 13, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 1, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 2, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 3, 22, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 4, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 5, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005401, 6, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 1, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 2, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 3, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 4, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 5, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 6, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 7, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 2, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 3, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 4, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 5, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 6, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 7, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 8, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 9, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 10, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 11, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 12, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 13, 69, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 14, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 15, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 16, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 17, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 18, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106004251, 19, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 1, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 2, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 3, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 4, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 5, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 6, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 7, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 8, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 9, 114, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 10, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 11, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 12, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 13, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 14, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 15, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202004252, 16, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 1, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 2, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 3, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 4, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 5, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 6, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 7, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 8, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 9, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231004253, 10, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 1, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 2, 24, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 3, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 4, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 5, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 6, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 7, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 8, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307004254, 9, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 1, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 2, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 3, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 4, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 5, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 6, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 7, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 8, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 9, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 10, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 11, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004255, 12, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 1, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 2, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 3, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 4, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 5, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 6, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414004256, 7, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 1, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 2, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 3, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 4, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 5, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 6, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 7, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 8, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 9, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 10, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 11, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 12, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 13, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 14, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 15, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 16, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 17, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604004257, 18, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 1, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 2, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 3, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 4, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 5, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 6, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 7, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004258, 8, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 1, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 2, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 3, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 4, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 5, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 6, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 7, 192, 36, 18, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 8, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 9, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626004259, 10, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 1, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 2, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 3, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 4, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 5, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 6, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 7, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 8, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 9, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111004260, 10, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 1, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 2, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 3, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 4, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 5, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 6, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 7, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 8, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310004261, 9, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 1, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 2, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 3, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 4, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 5, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 6, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407004262, 7, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710004263, 1, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710004263, 2, 8, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710004263, 3, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 1, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 2, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 3, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 4, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 5, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 6, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 7, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 8, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 9, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206004264, 10, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 1, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 2, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 3, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 4, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 5, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004265, 6, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 1, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 2, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 3, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 4, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 5, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004266, 6, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 1, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 2, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 3, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 4, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 5, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902004267, 6, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 1, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 2, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 3, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 4, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 5, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 6, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 7, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 8, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 9, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 10, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 11, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 12, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 13, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 14, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205004268, 15, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 1, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 2, 1, 38, 3, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 3, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 4, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 5, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 6, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 7, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 8, 137, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 9, 17, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 10, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 11, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 12, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 13, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 14, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 15, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 16, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121214004269, 17, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 1, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 2, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 3, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 4, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 5, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 6, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 7, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 8, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 9, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 10, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 11, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 12, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 13, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 14, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120325004270, 15, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 1, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 2, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 3, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 4, 179, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 5, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 6, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 7, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925004271, 8, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119004272, 1, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119004272, 2, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119004272, 3, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119004272, 4, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 1, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 2, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 3, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 4, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 5, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 6, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 7, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 8, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 9, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 10, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111004273, 11, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 1, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 2, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 3, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 11, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 12, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 13, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929004643, 14, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 1, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 2, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 3, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 4, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 5, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 6, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 7, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 8, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 9, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 10, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 11, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 12, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004644, 13, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 1, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 2, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 3, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 4, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 5, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 6, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 7, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 8, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 9, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407004645, 10, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 1, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 2, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 3, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 4, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 5, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 6, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 7, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 8, 184, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 9, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 10, 82, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 11, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 12, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 13, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 14, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 15, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625004646, 16, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 1, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 2, 72, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 3, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 4, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 5, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 6, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 7, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 8, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024004647, 9, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 1, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 2, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 3, 69, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 4, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 5, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 6, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 7, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 8, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 9, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 10, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 11, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 12, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 13, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520004648, 14, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 1, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 2, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 3, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 4, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 5, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 6, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 7, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 8, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 9, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 10, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 11, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 12, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 13, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 14, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 15, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019004649, 16, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411004650, 1, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411004650, 2, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212004651, 1, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212004651, 2, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212004651, 3, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212004651, 4, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212004651, 5, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 1, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 2, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 3, 71, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 4, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 5, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 6, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 7, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 8, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004652, 9, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 1, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 2, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 3, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 4, 70, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 5, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 6, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 7, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 8, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 9, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 10, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004653, 11, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929004654, 1, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929004654, 2, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929004654, 3, 126, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 1, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 2, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 3, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 4, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 5, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 6, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004655, 7, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 1, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 2, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 3, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 4, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 5, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 6, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 7, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 8, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 9, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 10, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 11, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 12, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 13, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 14, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419004656, 15, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 1, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 2, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 3, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 4, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 5, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 6, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 7, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 8, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 9, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 10, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719004657, 11, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 1, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 2, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 3, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 4, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 5, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 6, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 7, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 8, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 9, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 10, 78, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 11, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 12, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 13, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 14, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 15, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 16, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215004658, 17, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321004659, 1, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321004659, 2, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321004659, 3, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321004659, 4, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 1, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 2, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 3, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 4, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 5, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 6, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 7, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 8, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 9, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 10, 73, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709004660, 11, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 1, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 2, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 3, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 4, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 5, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 6, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 7, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 8, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 9, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 10, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 11, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119004661, 12, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 1, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 2, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 3, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 4, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 5, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 6, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 7, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 8, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 9, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 10, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004662, 11, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 1, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 2, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 3, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 4, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 5, 94, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 6, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 7, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 8, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 9, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 10, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 11, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 12, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109004663, 13, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 1, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 2, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 3, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 4, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 5, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 6, 59, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412004664, 7, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 1, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 2, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 3, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 4, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 5, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 7, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 8, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 9, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 10, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 11, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 12, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004665, 13, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 1, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 2, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 3, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 4, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 5, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 6, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 1, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 2, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 3, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 4, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 5, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 6, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 7, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 8, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 9, 192, 92, 18, 1656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 10, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 11, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810005022, 12, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 1, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 2, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 3, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 4, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 5, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 6, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 7, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 8, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 9, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 10, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909005023, 11, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 1, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 2, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 3, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 4, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 5, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 6, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041001005024, 7, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 1, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 2, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 3, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 4, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 5, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 6, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223005025, 7, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529005026, 1, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529005026, 2, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529005026, 3, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529005026, 4, 166, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529005026, 5, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 1, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 2, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 3, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 4, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 5, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 6, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 7, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 8, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 9, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 10, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 11, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 12, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 13, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 14, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 15, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131004005027, 16, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 1, 182, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 2, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 3, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 4, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 5, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 6, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018005028, 7, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 1, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 2, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 3, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 4, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 5, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 6, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 7, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418005029, 8, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 1, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 2, 131, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 3, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 4, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 5, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 6, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 7, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 8, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 9, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 10, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 11, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 12, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 13, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 14, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 15, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 16, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113005030, 17, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 1, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 2, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 3, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 4, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 5, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331005031, 6, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 1, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 2, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 3, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 4, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 5, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106005032, 6, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 1, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 2, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 3, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 4, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 5, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 6, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 7, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 8, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 9, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 10, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 11, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 12, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 13, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 14, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 15, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306005033, 16, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 1, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 2, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 3, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 4, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 5, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 6, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 7, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 8, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 9, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 10, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 11, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 12, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 13, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 14, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 15, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 16, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 17, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117005034, 18, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 1, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 2, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 3, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 4, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 5, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021005035, 6, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 1, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 2, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 3, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 4, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 5, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 6, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 7, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 8, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 9, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005036, 10, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 1, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 2, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 3, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 4, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 5, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 6, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 7, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 8, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603005037, 9, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 1, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 2, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 3, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 4, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 5, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 6, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 7, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 8, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 9, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223005038, 10, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 1, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 2, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 3, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 4, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 5, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 6, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318005039, 7, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 1, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 2, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 3, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 4, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 5, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 6, 154, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 7, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 8, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 9, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 10, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 11, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524005040, 12, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 1, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 2, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 3, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 4, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 5, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 6, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 7, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701005041, 8, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 1, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 2, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 3, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 4, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 5, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 6, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 7, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 8, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 9, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 10, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019005042, 11, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 1, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 2, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 3, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 4, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 5, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 6, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 7, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 8, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 9, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 10, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 11, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 12, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011005043, 13, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 1, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 2, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 3, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 4, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 5, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 6, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 7, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 8, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 9, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 10, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005044, 11, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 1, 90, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 2, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 3, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 4, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 5, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 6, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 8, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 9, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 10, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529005402, 11, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 1, 28, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 2, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 3, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 4, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 5, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 6, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 7, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 8, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 9, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 10, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504005403, 11, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623005404, 1, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623005404, 2, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623005404, 3, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623005404, 4, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 1, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 2, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 3, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 4, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 5, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 6, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 7, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 8, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323005405, 9, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 1, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 2, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 3, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 4, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 5, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 6, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 7, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 8, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 9, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 10, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 11, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 12, 28, 19, 9, 171);
commit;
prompt 44000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723005406, 13, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005407, 1, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005407, 2, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005407, 3, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005407, 4, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 1, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 2, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 3, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 4, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 5, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 6, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 7, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 8, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 9, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 10, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 11, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 12, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810005408, 13, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 1, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 2, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 3, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 4, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 5, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 6, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 7, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 8, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 9, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 10, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 11, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 12, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 13, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207005409, 14, 139, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625005410, 1, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625005410, 2, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625005410, 3, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 1, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 2, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 3, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 4, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 5, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 6, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 7, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 8, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 9, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 10, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 11, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 12, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309005411, 13, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 1, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 2, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 3, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 4, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 5, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 6, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408005412, 7, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 1, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 2, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 3, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 4, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 5, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 6, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 7, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 8, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105005413, 9, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119005414, 1, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119005414, 2, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119005414, 3, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119005414, 4, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701005415, 1, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701005415, 2, 149, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701005415, 3, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701005415, 4, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701005415, 5, 154, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 1, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 2, 127, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 3, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 4, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 5, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 6, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 7, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 8, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 9, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 10, 99, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 11, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 12, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 13, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 14, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111020005416, 15, 98, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 1, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 2, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 3, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 4, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 5, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 6, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 7, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 8, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 9, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 10, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205005417, 11, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904005418, 1, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904005418, 2, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904005418, 3, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904005418, 4, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904005418, 5, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 1, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 2, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 3, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 4, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 5, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 6, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 7, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 8, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 9, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 10, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 11, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 12, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 13, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 14, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 15, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903005419, 16, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118005420, 1, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118005420, 2, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118005420, 3, 65, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118005420, 4, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 1, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 2, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 3, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 4, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 5, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 6, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 7, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 8, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 9, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 10, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 11, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 12, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 13, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 14, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 15, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201005421, 16, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 1, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 2, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 3, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 4, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 5, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 6, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 7, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508005422, 8, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 1, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 2, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 3, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 4, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 5, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 6, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 7, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 8, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 9, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 10, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 11, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 12, 115, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521005423, 13, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 1, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 2, 180, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 3, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 4, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 5, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 6, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 7, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 8, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 9, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 10, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 11, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 12, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 13, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 14, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 15, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 16, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 17, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423005424, 18, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 1, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 2, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 3, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 4, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 5, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 6, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 7, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 8, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 9, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 10, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 11, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 12, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 13, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 14, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 15, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 16, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005425, 17, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818005426, 1, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818005426, 2, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818005426, 3, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 4, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 5, 144, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 6, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 7, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 8, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 9, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 10, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 11, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 12, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226004274, 13, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 1, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 2, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 3, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 4, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 5, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 6, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 7, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 8, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 9, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 10, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 11, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 12, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 13, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 14, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 15, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 16, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123004275, 17, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 1, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 2, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 3, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 4, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 5, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 6, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 7, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 8, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 9, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 10, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 11, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 12, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523004276, 13, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 1, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 2, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 3, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 4, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 5, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 6, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 7, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 8, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 9, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 10, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 11, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 12, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 13, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 14, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 15, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421004277, 16, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722004278, 1, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722004278, 2, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722004278, 3, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722004278, 4, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722004278, 5, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 1, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 2, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 3, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 4, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 5, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 6, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 7, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 8, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 9, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 10, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 11, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 12, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 13, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 14, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 15, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318004279, 16, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 1, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 2, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 3, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 4, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 5, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 6, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 7, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 8, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 9, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 10, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 11, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 12, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 13, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 14, 1, 96, 3, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 15, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231004280, 16, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 1, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 2, 81, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 3, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 4, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 5, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 6, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 7, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 8, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 9, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 10, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 11, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 12, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 13, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 14, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 15, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102004281, 16, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 1, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 2, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 3, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 4, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 5, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 6, 68, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004282, 7, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517004283, 1, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517004283, 2, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517004283, 3, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517004283, 4, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010517004283, 5, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 1, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 2, 37, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 3, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 4, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 5, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 6, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 7, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 8, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 9, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 10, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 11, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 12, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 13, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 14, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120429004284, 15, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 1, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 2, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 3, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 4, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 5, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 6, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 7, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 8, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 9, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308004285, 10, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 1, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 2, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 3, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 4, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 5, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 6, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 7, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 8, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 9, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 10, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 11, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004286, 12, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 1, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 2, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 3, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 4, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 5, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 6, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 7, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 8, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 9, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522004287, 10, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 1, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 2, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 3, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 4, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 5, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 6, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 7, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 8, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 9, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 10, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 11, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 12, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121004288, 13, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 1, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 2, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 3, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 4, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 5, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 6, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 7, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 8, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 9, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628004289, 10, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 1, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 2, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 3, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 4, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 5, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 6, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 7, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 8, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913004290, 9, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 1, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 2, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 3, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 4, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 5, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 6, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 7, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401004291, 8, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 1, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 2, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 3, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 4, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 5, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 6, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 7, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 8, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 9, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 10, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 11, 115, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 12, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516004292, 13, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530004293, 1, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530004293, 2, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530004293, 3, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530004293, 4, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010530004293, 5, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 1, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 2, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 3, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 4, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 5, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 6, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 7, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 8, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 9, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 10, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 11, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 12, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 13, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 7, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 8, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 9, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 10, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 11, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 12, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 13, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217004666, 14, 8, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 1, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 2, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 3, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 4, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 5, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 6, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 7, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 8, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 9, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 10, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 11, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 12, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 13, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012004667, 14, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 1, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 2, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 3, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 4, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 5, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 6, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 7, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 8, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 9, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 10, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 11, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 12, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 13, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 14, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712004668, 15, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 1, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 2, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 3, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 4, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 5, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 6, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 7, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 8, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 9, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 10, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 11, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 12, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731004669, 13, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 1, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 2, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 3, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 4, 47, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 5, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 6, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 7, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 8, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 9, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 10, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 11, 57, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 12, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 13, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 14, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 15, 39, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 16, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515004670, 17, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 1, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 2, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 3, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 4, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 5, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 6, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 7, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 8, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 9, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 10, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 11, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 12, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 13, 192, 46, 18, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 14, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 15, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 16, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226004671, 17, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 1, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 2, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 3, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 4, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 5, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 6, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 7, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 8, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 9, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 10, 66, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 11, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 12, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 13, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 14, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716004672, 15, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 1, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 2, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 3, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 4, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 5, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 6, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 7, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 8, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 9, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 10, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 11, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 12, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 13, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 14, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 15, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108004673, 16, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 1, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 2, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 3, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 4, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 5, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 6, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 7, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 8, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 9, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 10, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 11, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 12, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 13, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 14, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726004674, 15, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004675, 1, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004675, 2, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004675, 3, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901004675, 4, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 1, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 2, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 3, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 4, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 5, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 6, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 7, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 8, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 9, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 10, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 11, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 12, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 13, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618004676, 14, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 1, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 2, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 3, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 4, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 5, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 6, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 7, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004677, 8, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 1, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 2, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 3, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 4, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 5, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 6, 42, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 7, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 8, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 9, 42, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 10, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004678, 11, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 1, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 2, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 3, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 4, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 5, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 6, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 7, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 8, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 9, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 10, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 11, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 12, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 13, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 14, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 15, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 16, 29, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521004679, 17, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814004680, 1, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814004680, 2, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814004680, 3, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814004680, 4, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 1, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 2, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 3, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 4, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 5, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 6, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 7, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 8, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625004681, 9, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 1, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 2, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 3, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 4, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 5, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 6, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 7, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 8, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 9, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 10, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219004682, 11, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407004683, 1, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407004683, 2, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 1, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 2, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 3, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 4, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 5, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615004684, 6, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 1, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 2, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 3, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 4, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 5, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 6, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 7, 69, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 8, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 9, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 10, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 11, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 12, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121004685, 13, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 1, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 2, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 3, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 4, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 5, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 6, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 7, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 8, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 9, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 10, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 7, 103, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 8, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 9, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 10, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 11, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 12, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 13, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308005045, 14, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 1, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 2, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 3, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 4, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 5, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 6, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115005046, 7, 143, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 1, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 2, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 3, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 4, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 5, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 6, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 7, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 8, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228005047, 9, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 1, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 2, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 3, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 4, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 5, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 6, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 7, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716005048, 8, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 1, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 2, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 3, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 4, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 5, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 6, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 7, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 8, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 9, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202005049, 10, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 1, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 2, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 3, 108, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 4, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 5, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 6, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 7, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 8, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 9, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316005050, 10, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 1, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 2, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 3, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 4, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 5, 54, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 6, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 7, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 8, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 9, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 10, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 11, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 12, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104005051, 13, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 1, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 2, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 3, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 4, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 5, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 6, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 7, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905005052, 8, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 1, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 2, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 3, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 4, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 5, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 6, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 7, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 8, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 9, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 10, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 11, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 12, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 13, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208005053, 14, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 1, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 2, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 3, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 4, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 5, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 6, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051206005054, 7, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 1, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 2, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 3, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 4, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 5, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513005055, 6, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 1, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 2, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 3, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 4, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 5, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510005056, 6, 143, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216005057, 1, 21, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216005057, 2, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216005057, 3, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216005057, 4, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216005057, 5, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 1, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 2, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 3, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 4, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 5, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 6, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 7, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 8, 48, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005058, 9, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227005059, 1, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227005059, 2, 107, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227005059, 3, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304005060, 1, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304005060, 2, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 1, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 2, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 3, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 4, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 5, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 6, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 7, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 8, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005061, 9, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 1, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 2, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 3, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 4, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 5, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 6, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 7, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 8, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 9, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 10, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 11, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 12, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226005062, 13, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209005063, 1, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209005063, 2, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209005063, 3, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209005063, 4, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209005063, 5, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415005064, 1, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415005064, 2, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415005064, 3, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 1, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 2, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 3, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 4, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 5, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 6, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 7, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 8, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 9, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 10, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 11, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 12, 35, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 13, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 14, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 15, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 16, 136, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621005065, 17, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430005066, 1, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430005066, 2, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430005066, 3, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430005066, 4, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430005066, 5, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607005067, 1, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607005067, 2, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607005067, 3, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607005067, 4, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 1, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 2, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 3, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 4, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 5, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 6, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 7, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 8, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 9, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125005068, 10, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 1, 44, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 2, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 3, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 4, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 5, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903005069, 6, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 1, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 2, 4, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 3, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 4, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 5, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 6, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 7, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 8, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 9, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 10, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 11, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 12, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 13, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215005070, 14, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 1, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 2, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 3, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 4, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 5, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 6, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 7, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 8, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 9, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 10, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 11, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005071, 12, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101005072, 1, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101005072, 2, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101005072, 3, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101005072, 4, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101005072, 5, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 1, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 2, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 3, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 4, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 5, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 6, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 7, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 8, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 9, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 10, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502005073, 11, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818005426, 4, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818005426, 5, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 1, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 2, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 3, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 4, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 5, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 6, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 7, 4, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 8, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 9, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 10, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005427, 11, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 1, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 2, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 3, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 4, 139, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 5, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 6, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 7, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 8, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 9, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 10, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 11, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 12, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620005428, 13, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 1, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 2, 88, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 3, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 4, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 5, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 6, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 7, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 8, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 9, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 10, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 11, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 12, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 13, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 14, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 15, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222005429, 16, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 1, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 2, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 3, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 4, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 5, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 6, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 7, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 8, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 9, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 10, 54, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 11, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101011005430, 12, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 1, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 2, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 3, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 4, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 5, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 6, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 7, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 8, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 9, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 10, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 11, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 12, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 13, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 14, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005431, 15, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 1, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 2, 148, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 3, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 4, 60, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 5, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 6, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 7, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916005432, 8, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 1, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 2, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 3, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 4, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 5, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 6, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 7, 27, 57, 8, 456);
commit;
prompt 45000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 8, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 9, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 10, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 11, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 12, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 13, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 14, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 15, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907005433, 16, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031005434, 1, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031005434, 2, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031005434, 3, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031005434, 4, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 1, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 2, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 3, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 4, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 5, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116005435, 6, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 1, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 2, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 3, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 4, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 5, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 6, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 7, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 8, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 9, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 10, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 11, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 12, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 13, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 14, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 15, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005436, 16, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 1, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 2, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 3, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 4, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 5, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 6, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 7, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 8, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 9, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 10, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 11, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 12, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 13, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 14, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114005437, 15, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 1, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 2, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 3, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 4, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 5, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 6, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018005438, 7, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 1, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 2, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 3, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 4, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 5, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 6, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005439, 7, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 1, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 2, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 3, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 4, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 5, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 6, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 7, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 8, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 9, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524005440, 10, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 1, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 2, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 3, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 4, 192, 8, 18, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 5, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 6, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 7, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 8, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616005441, 9, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207005442, 1, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207005442, 2, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207005442, 3, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207005442, 4, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207005442, 5, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916005443, 1, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916005443, 2, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916005443, 3, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916005443, 4, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916005443, 5, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 1, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 2, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 3, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 4, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 5, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 6, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 7, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 8, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 9, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 10, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 11, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201005444, 12, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115005445, 1, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115005445, 2, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115005445, 3, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115005445, 4, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115005445, 5, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 1, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 2, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 3, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 4, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 5, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 6, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 7, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 8, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 9, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 10, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 11, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 12, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 13, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 14, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 15, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731005446, 16, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 1, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 2, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 3, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 4, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 5, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 6, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 7, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 8, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 9, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 10, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 11, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 12, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 13, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 14, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025005447, 15, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 1, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 2, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 3, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 4, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 5, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 6, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 7, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 8, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825005448, 9, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 1, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 2, 180, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 3, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 4, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 5, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 14, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 15, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921004294, 16, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 1, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 2, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 3, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 4, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 5, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 6, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 7, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 8, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 9, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 10, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619004295, 11, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 1, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 2, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 3, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 4, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 5, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 6, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504004296, 7, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 1, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 2, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 3, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 4, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 5, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 6, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823004297, 7, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 1, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 2, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 3, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 4, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 5, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 6, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 7, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 8, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 9, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 10, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 11, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 12, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 13, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 14, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127004298, 15, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 1, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 2, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 3, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 4, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 5, 183, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 6, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 7, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 8, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 9, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004299, 10, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 1, 181, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 2, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 3, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 4, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 5, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 6, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 7, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 8, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 9, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004300, 10, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 1, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 2, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 3, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 4, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 5, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 6, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 7, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 8, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 9, 27, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 10, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817004301, 11, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 1, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 2, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 3, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 4, 14, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 5, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 6, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 7, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 8, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 9, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 10, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 11, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 12, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601004302, 13, 97, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 1, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 2, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 3, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 4, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 5, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 6, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 7, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 8, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 9, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 10, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 11, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 12, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 13, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 14, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108004303, 15, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 1, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 2, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 3, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 4, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 5, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 6, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 7, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 8, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 9, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 10, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 11, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 12, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 13, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 14, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 15, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 16, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 17, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 18, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421004304, 19, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 1, 84, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 2, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 3, 146, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 4, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 5, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 6, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 7, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519004305, 8, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 1, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 2, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 3, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 4, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 5, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 6, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 7, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 8, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729004306, 9, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 1, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 2, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 3, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 4, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 5, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 6, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 7, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 8, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 9, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 10, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610004307, 11, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 1, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 2, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 3, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 4, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 5, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 6, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102004308, 7, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 1, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 2, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 3, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 4, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 5, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 6, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 7, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 8, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 9, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 10, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 11, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910004309, 12, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 1, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 2, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 3, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 4, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 5, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525004310, 6, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 1, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 2, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 3, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 4, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 5, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 6, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 7, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 8, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 9, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 10, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 11, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 12, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 13, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 14, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 15, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 16, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320004311, 17, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004312, 1, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004312, 2, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004312, 3, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004312, 4, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004312, 5, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 1, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 2, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 3, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 4, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 5, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 6, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129004313, 7, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 1, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 2, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 3, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 4, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 5, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 6, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 7, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 8, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 9, 104, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 10, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 11, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 12, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 13, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 14, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 15, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430004314, 16, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221004315, 1, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221004315, 2, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221004315, 3, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 1, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 2, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 3, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 4, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 5, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 6, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 7, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 8, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 9, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 10, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 11, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 12, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609004316, 13, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 1, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 2, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 3, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 4, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 11, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 12, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 13, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 14, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204004686, 15, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 1, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 2, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 3, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 4, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 5, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 6, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 7, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 8, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 9, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 10, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 11, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 12, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 13, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 14, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331004687, 15, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 1, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 2, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 3, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 4, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 5, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 6, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120004688, 7, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 1, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 2, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 3, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 4, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 5, 74, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 6, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706004689, 7, 50, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 1, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 2, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 3, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 4, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 5, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 6, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 7, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 8, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 9, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 10, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 11, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004690, 12, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 1, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 2, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 3, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 4, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 5, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 6, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 7, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 8, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 9, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 10, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 11, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120004691, 12, 68, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 1, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 2, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 3, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 4, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 5, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004692, 6, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 1, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 2, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 3, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 4, 19, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 5, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 6, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 7, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 8, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 9, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 10, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 11, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 12, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 13, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 14, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420004693, 15, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 1, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 2, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 3, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 4, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 5, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 6, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 7, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 8, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 9, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 10, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 11, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 12, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 13, 62, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 14, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 15, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030004694, 16, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904004695, 1, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904004695, 2, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904004695, 3, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904004695, 4, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 1, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 2, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 3, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 4, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 5, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 6, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 7, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 8, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 9, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 10, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 11, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 12, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 13, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107004696, 14, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 1, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 2, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 3, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 4, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 5, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 6, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 7, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 8, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 9, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 10, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 11, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311004697, 12, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 1, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 2, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 3, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 4, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 5, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 6, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 7, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 8, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 9, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 10, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 11, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 12, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515004698, 13, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 1, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 2, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 3, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 4, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 5, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 6, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 7, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 8, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 9, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 10, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 11, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 12, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 13, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 14, 174, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 15, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107004699, 16, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 1, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 2, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 3, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 4, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 5, 24, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 6, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 7, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 8, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 9, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130004700, 10, 23, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 1, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 2, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 3, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 4, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 5, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 6, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 7, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 8, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 9, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 10, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115004701, 11, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 1, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 2, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 3, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 4, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 5, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 6, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 7, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 8, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 9, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 10, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 11, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 12, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 13, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 14, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616004702, 15, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 1, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 2, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 3, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 4, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 5, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 6, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 7, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 8, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 9, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 10, 55, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219004703, 11, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 1, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 2, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 3, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 4, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 5, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 6, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 7, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 8, 160, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 9, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 10, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 11, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 12, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027004704, 13, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 1, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 2, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 3, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 4, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 5, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 6, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 7, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 8, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 9, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 10, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 11, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 12, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 13, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 14, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418004705, 15, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004706, 1, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004706, 2, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004706, 3, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004706, 4, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 1, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 2, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 3, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 4, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 5, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 6, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 1, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 2, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 3, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 4, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 5, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131005074, 6, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 1, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 2, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 3, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 4, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 5, 158, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 6, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 7, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 8, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113005075, 9, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 1, 103, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 2, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 3, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 4, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 5, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616005076, 6, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 1, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 2, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 3, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 4, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 5, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 6, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612005077, 7, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 1, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 2, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 3, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 4, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 5, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 6, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 7, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 8, 161, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 9, 33, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 10, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 11, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627005078, 12, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 1, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 2, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 3, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 4, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 5, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 6, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 7, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 8, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 9, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 10, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 11, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 12, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 13, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 14, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312005079, 15, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 1, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 2, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 3, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 4, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 5, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 6, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 7, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 8, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 9, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 10, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 11, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125005080, 12, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704005081, 1, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704005081, 2, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704005081, 3, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704005081, 4, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 1, 132, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 2, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 3, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 4, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 5, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 6, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 7, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 8, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 9, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 10, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 11, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 12, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 13, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402005082, 14, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 1, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 2, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 3, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 4, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 5, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 6, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 7, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 8, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 9, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 10, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 11, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 12, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505005083, 13, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 1, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 2, 192, 92, 18, 1656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 3, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 4, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 5, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005084, 6, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 1, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 2, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 3, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 4, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 5, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 6, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 7, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 8, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 9, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 10, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 11, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 12, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 13, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 14, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 15, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804005085, 16, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 1, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 2, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 3, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 4, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 5, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005086, 6, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 1, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 2, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 3, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 4, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 5, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 6, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 7, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 8, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 9, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 10, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402005087, 11, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 1, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 2, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 3, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 4, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 5, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 6, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 7, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617005088, 8, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 1, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 2, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 3, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 4, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 5, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 6, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 7, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 8, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 9, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 10, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327005089, 11, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 1, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 2, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 3, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 4, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 5, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218005090, 6, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 1, 108, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 2, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 3, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 4, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 5, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 6, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 7, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 8, 137, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 9, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 10, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 11, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 12, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 13, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 14, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 15, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201005091, 16, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 1, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 2, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 3, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 4, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 5, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 6, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 7, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 8, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 9, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 10, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 11, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 12, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 13, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 14, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 15, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109005092, 16, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 1, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 2, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 3, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 4, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 5, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 6, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 7, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 8, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 9, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005093, 10, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 1, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 2, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 3, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 4, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 5, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 6, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 7, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605005094, 8, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 1, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 2, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 3, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 4, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 5, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 6, 119, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 7, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 8, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 9, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 10, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 11, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 12, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 13, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100903005095, 14, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 1, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 2, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 3, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 4, 56, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 5, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 6, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 7, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 8, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 9, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 10, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 11, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 12, 88, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518005096, 13, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 5, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 6, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 7, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 8, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 9, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 10, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 11, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 12, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 13, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 14, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 15, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 16, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 17, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 1, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 2, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 3, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 4, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 5, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 6, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 7, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009005548, 8, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 1, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 2, 110, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 3, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 4, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 5, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 6, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 7, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 8, 130, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602005549, 9, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 1, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 2, 116, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 3, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 4, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 5, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 6, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 7, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 8, 96, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 9, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 10, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 11, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 12, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005550, 13, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 1, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 2, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 3, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 4, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 5, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 6, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 7, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 8, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 9, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 10, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 11, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 12, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 13, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 14, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120106005551, 15, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005552, 1, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005552, 2, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005552, 3, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005552, 4, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209005553, 1, 84, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209005553, 2, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209005553, 3, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209005553, 4, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209005553, 5, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 1, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 2, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 3, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 4, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 5, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 6, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 7, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 8, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 9, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008005554, 10, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 1, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 2, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 3, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 4, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 5, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 6, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 7, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 8, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 9, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 10, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 11, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 12, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602005555, 13, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 1, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 2, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 3, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 4, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 5, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 6, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 7, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531005556, 8, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 1, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 2, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 3, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 4, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 5, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 6, 105, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 7, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 8, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 9, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 10, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 11, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 12, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 13, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809005557, 14, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 1, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 2, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 3, 179, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 4, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 5, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 6, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 7, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 8, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416005558, 9, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622005559, 1, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622005559, 2, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622005559, 3, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622005559, 4, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622005559, 5, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711005560, 1, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711005560, 2, 116, 55, 11, 605);
commit;
prompt 46000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711005560, 3, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711005560, 4, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711005560, 5, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016005561, 1, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016005561, 2, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016005561, 3, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016005561, 4, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016005561, 5, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 1, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 2, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 3, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 4, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 5, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 6, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 7, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 8, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 9, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 10, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 11, 34, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415005562, 12, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 1, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 2, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 3, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 4, 145, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 5, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 6, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 7, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 8, 156, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 9, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 10, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 11, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 12, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 13, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 14, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 15, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 16, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 17, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416005563, 18, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 1, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 2, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 3, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 4, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 5, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 6, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529005564, 7, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 1, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 2, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 3, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 4, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 5, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 6, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 7, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 8, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 9, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 10, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 11, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313005565, 12, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 1, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 2, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 3, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 4, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 5, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 6, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 7, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 8, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 9, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 10, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118005566, 11, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 1, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 2, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 3, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 4, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 5, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208005567, 6, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 1, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 2, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 3, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 4, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 5, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 6, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051114005568, 7, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 1, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 2, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 3, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 4, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 5, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 6, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 7, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 8, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 9, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 10, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 11, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 12, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 13, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 14, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 15, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 16, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924005569, 17, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 1, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 2, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 3, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 4, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 5, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 6, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 7, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 8, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 9, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 10, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 11, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908005570, 12, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 1, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 5, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 6, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 7, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 8, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313004317, 9, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 1, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 2, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 3, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 4, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 5, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 6, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 7, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 8, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 9, 59, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 10, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 11, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 12, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 13, 34, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124004318, 14, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 1, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 2, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 3, 102, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 4, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 5, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 6, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 7, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 8, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 9, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703004319, 10, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 1, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 2, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 3, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 4, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 5, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 6, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630004320, 7, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 1, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 2, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 3, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 4, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 5, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 6, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 7, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 8, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 9, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 10, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 11, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 12, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308004321, 13, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210004322, 1, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210004322, 2, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210004322, 3, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210004322, 4, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 1, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 2, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 3, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 4, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 5, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 6, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 7, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 8, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 9, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805004323, 10, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 1, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 2, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 3, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 4, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 5, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 6, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 7, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 8, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 9, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 10, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 11, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 12, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 13, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 14, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 15, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 16, 3, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801004324, 17, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 1, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 2, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 3, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 4, 76, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 5, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 6, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923004325, 7, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 1, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 2, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 3, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 4, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 5, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213004326, 6, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 1, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 2, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 3, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 4, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 5, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 6, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 7, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 8, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 9, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004327, 10, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114004328, 1, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114004328, 2, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114004328, 3, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114004328, 4, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114004328, 5, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 1, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 2, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 3, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 4, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 5, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 6, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 7, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 8, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 9, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 10, 178, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018004329, 11, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 1, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 2, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 3, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 4, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 5, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 6, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 7, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 8, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 9, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 10, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 11, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 12, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 13, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 14, 190, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 15, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 16, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140406004330, 17, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 1, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 2, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 3, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 4, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 5, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 6, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 7, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031004331, 8, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 1, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 2, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 3, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 4, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 5, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 6, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 7, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 8, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 9, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 10, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 11, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 12, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104004332, 13, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 1, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 2, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 3, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 4, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 5, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 6, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 7, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210004333, 8, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 1, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 2, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 3, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 4, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 5, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 6, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 7, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 8, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 9, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 10, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080118004334, 11, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 1, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 2, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 3, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 4, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 5, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 6, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 7, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 8, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 9, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 10, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 11, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 12, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 13, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125004335, 14, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 1, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 2, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 3, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 4, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 5, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 6, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 7, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 8, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304004336, 9, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216004337, 1, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216004337, 2, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216004337, 3, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216004337, 4, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216004337, 5, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 1, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 2, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 3, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 4, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 5, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 6, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 7, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 8, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829004338, 9, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709004339, 1, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709004339, 2, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709004339, 3, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709004339, 4, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 1, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 2, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 3, 79, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 4, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 5, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004340, 6, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 1, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 2, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 3, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 4, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 5, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 6, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 7, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 8, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 9, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 10, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 11, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 12, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 13, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 14, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 15, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618004341, 16, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 7, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 8, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 9, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 10, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 11, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612004707, 12, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 1, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 2, 80, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 3, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 4, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 5, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 6, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 7, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 8, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 9, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 10, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 11, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 12, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 13, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 14, 175, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 15, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 16, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526004708, 17, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 1, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 2, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 3, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 4, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 5, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 6, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 7, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 8, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 9, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 10, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 11, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 12, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 13, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 14, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004709, 15, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004710, 1, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004710, 2, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011104004710, 3, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 1, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 2, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 3, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 4, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 5, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 6, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 7, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 8, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 9, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 10, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 11, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 12, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 13, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 14, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 15, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 16, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604004711, 17, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 1, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 2, 176, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 3, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 4, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 5, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 6, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 7, 145, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 8, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 9, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 10, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923004712, 11, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 1, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 2, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 3, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 4, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 5, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 6, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 7, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 8, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 9, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 10, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 11, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 12, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 13, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 14, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 15, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 16, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131114004713, 17, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 1, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 2, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 3, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 4, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 5, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211004714, 6, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 1, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 2, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 3, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 4, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 5, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 6, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 7, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 8, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 9, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 10, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 11, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004715, 12, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524004716, 1, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524004716, 2, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524004716, 3, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524004716, 4, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524004716, 5, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 1, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 2, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 3, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 4, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 5, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 6, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 7, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 8, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 9, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 10, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 11, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117004717, 12, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626004718, 1, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626004718, 2, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626004718, 3, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626004718, 4, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626004718, 5, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 1, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 2, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 3, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 4, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 5, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 6, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 7, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 8, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 9, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 10, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 11, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 12, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 13, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 14, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 15, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811004719, 16, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 1, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 2, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 3, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 4, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 5, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 6, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 7, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 8, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 9, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 10, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 11, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908004720, 12, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004721, 1, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004721, 2, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004721, 3, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004721, 4, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028004722, 1, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028004722, 2, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028004722, 3, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028004722, 4, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028004722, 5, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 1, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 2, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 3, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 4, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 5, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 6, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 7, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 8, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 9, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 10, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 11, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 12, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 13, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921004723, 14, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 1, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 2, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 3, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 4, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 5, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221004724, 6, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 1, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 2, 107, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 3, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 4, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 5, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 6, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 7, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 8, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 9, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 10, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 11, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 12, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 13, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 14, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114004725, 15, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 1, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 2, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 3, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 4, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 5, 80, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 6, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 7, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 8, 131, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 9, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 10, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 11, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004726, 12, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 1, 102, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 2, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 3, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 4, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 5, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 6, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 7, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030004727, 8, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 1, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 2, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 3, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 4, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 5, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 6, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 7, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 8, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 9, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 10, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 11, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 12, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 13, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511004728, 14, 80, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 1, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 2, 191, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 3, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 4, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 5, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 6, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 1, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 2, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 3, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 4, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 5, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 6, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 7, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 8, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 9, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 10, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 11, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 12, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111005097, 13, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 1, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 2, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 3, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 4, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 5, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722005098, 6, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 1, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 2, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 3, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 4, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 5, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 6, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 7, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 8, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 9, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 10, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 11, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225005099, 12, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 1, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 2, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 3, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 4, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 5, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 6, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 7, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 8, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 9, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 10, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 11, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 12, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 13, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 14, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317005100, 15, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 1, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 2, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 3, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 4, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 5, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 6, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 7, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 8, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 9, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 10, 106, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 11, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 12, 107, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 13, 148, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 14, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 15, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630005101, 16, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 1, 84, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 2, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 3, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 4, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 5, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 6, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 7, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908005102, 8, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 1, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 2, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 3, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 4, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 5, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 6, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 7, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 8, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005103, 9, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 1, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 2, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 3, 99, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 4, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 5, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 6, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 7, 3, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 8, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 9, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 10, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 11, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 12, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 13, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 14, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 15, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 16, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 17, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005104, 18, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 1, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 2, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 3, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 4, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 5, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 6, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 7, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 8, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 9, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 10, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 11, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 12, 189, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 13, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409005105, 14, 126, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 1, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 2, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 3, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 4, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 5, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 6, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 7, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 8, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 9, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 10, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 11, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 12, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 13, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 14, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 15, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 16, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424005106, 17, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 1, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 2, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 3, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 4, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 5, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 6, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 7, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 8, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 9, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 10, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226005107, 11, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 1, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 2, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 3, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 4, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 5, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 6, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 7, 27, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507005108, 8, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 1, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 2, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 3, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 4, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 5, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 6, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 7, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 8, 8, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 9, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 10, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 11, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 12, 132, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 13, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 14, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110130005109, 15, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 1, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 2, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 3, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 5, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 6, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 7, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 8, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 9, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 10, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 11, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 12, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 13, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 14, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330005110, 15, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 1, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 2, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 3, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 4, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 5, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 6, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 7, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 8, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 9, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 10, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916005111, 11, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 1, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 2, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 3, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 4, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 5, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 6, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 7, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 8, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 9, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 10, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 11, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120005112, 12, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 1, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 2, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 3, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 4, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 5, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 6, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 7, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 8, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 9, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 10, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829005113, 11, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 1, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 2, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 3, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 4, 22, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 5, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 6, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 7, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 8, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 9, 44, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 10, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 11, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 12, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 13, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510005114, 14, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 1, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 2, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 3, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 4, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 5, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 6, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 7, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 8, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 9, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 10, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 11, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 12, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 13, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 14, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008005115, 15, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 6, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 7, 129, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 8, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329005449, 9, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 1, 188, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 2, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 3, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 4, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 5, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 6, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 7, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 8, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 9, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 10, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809005450, 11, 65, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005451, 1, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005451, 2, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005451, 3, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005451, 4, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 1, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 2, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 3, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 4, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 5, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 6, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 7, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 8, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 9, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 10, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 11, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005452, 12, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 1, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 2, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 3, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 4, 91, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 5, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 6, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 7, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005453, 8, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 1, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 2, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 3, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 4, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 5, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 6, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 7, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 8, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 9, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 10, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 11, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 12, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126005454, 13, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 1, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 2, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 3, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 4, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 5, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 6, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 7, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 8, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 9, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005455, 10, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 1, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 2, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 3, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 4, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 5, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 6, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 7, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 8, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 9, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 10, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216005456, 11, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 1, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 2, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 3, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 4, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 5, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 6, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 7, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 8, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 9, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 10, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 11, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 12, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 13, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816005457, 14, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 1, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 2, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 3, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 4, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 5, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 6, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 7, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 8, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 9, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 10, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 11, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 12, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009005458, 13, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 1, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 2, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 3, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 4, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 5, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 6, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 7, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 8, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 9, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 10, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 11, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 12, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 13, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 14, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 15, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 16, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005459, 17, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 1, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 2, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 3, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 4, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 5, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 6, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 7, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 8, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 9, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 10, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 11, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 12, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 13, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 14, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 15, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 16, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 17, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119005460, 18, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 1, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 2, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 3, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 4, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 5, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 6, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 7, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 8, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 9, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 10, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112005461, 11, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721005462, 1, 150, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721005462, 2, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721005462, 3, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721005462, 4, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 1, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 2, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 3, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 4, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 5, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 6, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 7, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 8, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027005463, 9, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 1, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 2, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 3, 189, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 4, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 5, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 6, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 7, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 8, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 9, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 10, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 11, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 12, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 13, 94, 6, 13, 78);
commit;
prompt 47000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 14, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 15, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821005464, 16, 74, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 1, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 2, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 3, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 4, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 5, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 6, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219005465, 7, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 1, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 2, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 3, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 4, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 5, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 6, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 7, 1, 11, 3, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 8, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 9, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501005466, 10, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 1, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 2, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 3, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 4, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 5, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 6, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 7, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722005467, 8, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217005468, 1, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217005468, 2, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 1, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 2, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 3, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 4, 11, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 5, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 6, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 7, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 8, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 9, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 10, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 11, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 12, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 13, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 14, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 15, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 16, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 17, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430005469, 18, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 1, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 2, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 3, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 4, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 5, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 6, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 7, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525005470, 8, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 1, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 2, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 3, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 4, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 5, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 6, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 7, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 8, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 9, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 10, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 11, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115004342, 1, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115004342, 2, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115004342, 3, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115004342, 4, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 1, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 2, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 4, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 5, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 6, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 7, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 8, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 9, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 10, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 11, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 12, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614004343, 13, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 1, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 2, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 3, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 4, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 5, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 6, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 7, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 8, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 9, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 10, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103004344, 11, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 1, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 2, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 3, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 4, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 5, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 6, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 7, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 8, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 9, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 10, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 11, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 12, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 13, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 14, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 15, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004345, 16, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 1, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 2, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 3, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 4, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 5, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019004346, 6, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 1, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 2, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 3, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 4, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 5, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 6, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 7, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729004347, 8, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 1, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 2, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 3, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 4, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 5, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 6, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 7, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 8, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326004348, 9, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 1, 164, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 2, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 3, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 4, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 5, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 6, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 7, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 8, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 9, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 10, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 11, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 12, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 13, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 14, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 15, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 16, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 17, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004349, 18, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 1, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 2, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 3, 178, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 4, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 5, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 6, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 7, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 8, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 9, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 10, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808004350, 11, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 1, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 2, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 3, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 4, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 5, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 6, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 7, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 8, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 9, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 10, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 11, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 12, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 13, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 14, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 15, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 16, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130301004351, 17, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 1, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 2, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 3, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 4, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 5, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 6, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807004352, 7, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 1, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 2, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 3, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 4, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 5, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 6, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 7, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 8, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 9, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 10, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 11, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131004353, 12, 176, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 1, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 2, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 3, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 4, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 5, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 6, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 7, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 8, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004354, 9, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 1, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 2, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 4, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 5, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021030004355, 6, 71, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 1, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 2, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 3, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 4, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 5, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 6, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 7, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 8, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 9, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 10, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 11, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 12, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920004356, 13, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 1, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 2, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 3, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 4, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 5, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 6, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 7, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 8, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 9, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 10, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 11, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 12, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 13, 99, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 14, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 15, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004357, 16, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 1, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 2, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 3, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 4, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 5, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 6, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 7, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 8, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 9, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 10, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724004358, 11, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 1, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 2, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 3, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 4, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 5, 51, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420004359, 6, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 1, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 2, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 3, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 4, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 5, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 6, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 7, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 8, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 9, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830004360, 10, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 1, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 2, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 3, 185, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 4, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 5, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 6, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 7, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 8, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 9, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 10, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 11, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 12, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 13, 54, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 14, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703004361, 15, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325004362, 1, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325004362, 2, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325004362, 3, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325004362, 4, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325004362, 5, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 1, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 2, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 3, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 4, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 5, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 6, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823004363, 7, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 1, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 2, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 3, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 4, 109, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 5, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229004364, 6, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 1, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 2, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 3, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 7, 182, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 8, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 9, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 10, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 11, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 12, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 13, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 14, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 15, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 16, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131110004729, 17, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 1, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 2, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 3, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 4, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 5, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 6, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020929004730, 7, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 1, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 2, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 3, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 4, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 5, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 6, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 7, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 8, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 9, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 10, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 11, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 12, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 13, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 14, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 15, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221004731, 16, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 1, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 2, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 3, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 4, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 5, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 6, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 7, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 8, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 9, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 10, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 11, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 12, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 13, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 14, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109004732, 15, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 1, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 2, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 3, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 4, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 5, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007004733, 6, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 1, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 2, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 3, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 4, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 5, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 6, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 7, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 8, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 9, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 10, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916004734, 11, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 1, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 2, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 3, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 4, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 5, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 6, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 7, 33, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 8, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 9, 54, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 10, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720004735, 11, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 1, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 2, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 3, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 4, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 5, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 6, 77, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 7, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 8, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 9, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207004736, 10, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004737, 1, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004737, 2, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004737, 3, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004737, 4, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 1, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 2, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 3, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 4, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 5, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011112004738, 6, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226004739, 1, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226004739, 2, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226004739, 3, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226004739, 4, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226004739, 5, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 1, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 2, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 3, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 4, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 5, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 6, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 7, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 8, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 9, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 10, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 11, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 12, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 13, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 14, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111225004740, 15, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 1, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 2, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 3, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 4, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 5, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 6, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 7, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922004741, 8, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 1, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 2, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 3, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 4, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 5, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 6, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 7, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 8, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226004742, 9, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 1, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 2, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 3, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 4, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 5, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 6, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 7, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 8, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 9, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 10, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 11, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 12, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 13, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004743, 14, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 1, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 2, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 3, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 4, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 5, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 6, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 7, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 8, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 9, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 10, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 11, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 12, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 13, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 14, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407004744, 15, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 1, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 2, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 3, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 4, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 5, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 6, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 7, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314004745, 8, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 1, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 2, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 3, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 4, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 5, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 6, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 7, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 8, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 9, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 10, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004746, 11, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 1, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 2, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 3, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 4, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 5, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 6, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 7, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 8, 35, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 9, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 10, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 11, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 12, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 13, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 14, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 15, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 16, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 17, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326004747, 18, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 1, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 2, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 3, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 4, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 5, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020004748, 6, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401004749, 1, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401004749, 2, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401004749, 3, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401004749, 4, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401004749, 5, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 1, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 2, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 3, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 4, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 5, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 6, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 7, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 8, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 9, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 10, 157, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 11, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 12, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 13, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204004750, 14, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 1, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 2, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 3, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 4, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 5, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210004751, 6, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603004752, 1, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603004752, 2, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603004752, 3, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603004752, 4, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113004753, 1, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113004753, 2, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113004753, 3, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113004753, 4, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208005116, 1, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208005116, 2, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208005116, 3, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 1, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 2, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 3, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 4, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 5, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030125005117, 6, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 1, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 2, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 3, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 4, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 5, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 6, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 7, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 8, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 9, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 10, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005118, 11, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504005119, 1, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504005119, 2, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504005119, 3, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504005119, 4, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 1, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 2, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 3, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 4, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 5, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 6, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005120, 7, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 1, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 2, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 3, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 4, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 5, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 6, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 7, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 8, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 9, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 10, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 11, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610005121, 12, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 1, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 2, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 3, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 4, 6, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 5, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 6, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521005122, 7, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 1, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 2, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 3, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 4, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 5, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 6, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 7, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 8, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 9, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 10, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 11, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102005123, 12, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 1, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 2, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 3, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 4, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 5, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 6, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629005124, 7, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511005125, 1, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511005125, 2, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511005125, 3, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511005125, 4, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 1, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 2, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 3, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 4, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 5, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 6, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 7, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 8, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105005126, 9, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013005127, 1, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013005127, 2, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013005127, 3, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013005127, 4, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013005127, 5, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 1, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 2, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 3, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 4, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 5, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 6, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 7, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 8, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 9, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 10, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 11, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 12, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 13, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130005128, 14, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 1, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 2, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 3, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 4, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 5, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322005129, 6, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818005130, 1, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818005130, 2, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818005130, 3, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818005130, 4, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818005130, 5, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 1, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 2, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 3, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 4, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 5, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 6, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 7, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 8, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 9, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005131, 10, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 1, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 2, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 3, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 4, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 5, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 6, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217005132, 7, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 1, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 2, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 3, 1, 1, 3, 3);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 4, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 5, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 6, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 7, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 8, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 9, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 10, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 11, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091229005133, 12, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 1, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 2, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 3, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 4, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 5, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 6, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 7, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 8, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 9, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 10, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922005134, 11, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 1, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 2, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 3, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 4, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 5, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 6, 188, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 7, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 8, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 9, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 10, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 11, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 12, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417005135, 13, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 1, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 2, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 3, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 4, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 5, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 6, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 7, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 8, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 9, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206005136, 10, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 1, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 2, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 3, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 4, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 5, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 6, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 7, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 8, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 9, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006005137, 10, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 1, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 2, 26, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 3, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 4, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 5, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 6, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 7, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619005138, 8, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 1, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 2, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 3, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 4, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 5, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 6, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005139, 7, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 1, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 2, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 3, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 4, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 5, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 6, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 7, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 8, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 9, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 10, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 11, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 12, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 13, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 14, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 15, 127, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 16, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112005140, 17, 192, 48, 18, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 1, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 2, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 3, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 4, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 5, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 6, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 7, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 9, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 10, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 11, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 12, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 13, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 14, 14, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 15, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115005141, 16, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 1, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 2, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 3, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 4, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 5, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 6, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 10, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 11, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 12, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 13, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 14, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 15, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 16, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 1, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 2, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 3, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 4, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 5, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 6, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 7, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 8, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 9, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 10, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 11, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071009005495, 12, 131, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 1, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 2, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 3, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 4, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 5, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 6, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 7, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 8, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 9, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 10, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 11, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 12, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 13, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 14, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 15, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 16, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 17, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005496, 18, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 1, 137, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 2, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 3, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 4, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 5, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 6, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 7, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 8, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 9, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 10, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 11, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 12, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123005497, 13, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 1, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 2, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 3, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 4, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 5, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 6, 15, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020115005498, 7, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 1, 146, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 2, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 3, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 4, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 5, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 6, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 7, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 8, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 9, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018005499, 10, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 1, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 2, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 3, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 4, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 5, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 6, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011005500, 7, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 1, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 2, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 3, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 4, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 5, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 6, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 7, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 8, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 9, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012005501, 10, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127005502, 1, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127005502, 2, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127005502, 3, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127005502, 4, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127005502, 5, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 1, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 2, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 3, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 4, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 5, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 6, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 7, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 8, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507005503, 9, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226005504, 1, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226005504, 2, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419005505, 1, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419005505, 2, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419005505, 3, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419005505, 4, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419005505, 5, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 1, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 2, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 3, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 4, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 5, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 6, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 7, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 8, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 9, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 10, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 11, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 12, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411005506, 13, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 1, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 2, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 3, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 4, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 5, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 6, 110, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 7, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 8, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 9, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 10, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 11, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 12, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 13, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100405005507, 14, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 1, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 2, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 3, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 4, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 5, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 6, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 7, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 8, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 9, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 10, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317005508, 11, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823005509, 1, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823005509, 2, 96, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823005509, 3, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 1, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 2, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 3, 59, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 4, 79, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 5, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 6, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324005510, 7, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 1, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 2, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 3, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 4, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 5, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 6, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 7, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 8, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 9, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 10, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 11, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 12, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005511, 13, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001122005512, 1, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001122005512, 2, 19, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001122005512, 3, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001122005512, 4, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 1, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 2, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 3, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 4, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 5, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111005513, 6, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 1, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 2, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 3, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 4, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 5, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327005514, 6, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 1, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 2, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 3, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 4, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 5, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 6, 113, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 7, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 8, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 9, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 10, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 11, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 12, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 13, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 14, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 15, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 16, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021005515, 17, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 1, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 2, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 3, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 4, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 5, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 6, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 7, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601005516, 8, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 1, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 2, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 3, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 4, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 5, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 6, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 7, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 8, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 9, 156, 17, 13, 221);
commit;
prompt 48000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909005517, 10, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 1, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 2, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 3, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 4, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 5, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 6, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 7, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005518, 8, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 1, 145, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 2, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 3, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 4, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 5, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 6, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 7, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 8, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628005519, 9, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809005520, 1, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809005520, 2, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809005520, 3, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809005520, 4, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809005520, 5, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 4, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 5, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 6, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 7, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 8, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 9, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 10, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 11, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 12, 16, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 13, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 14, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 15, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 16, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223004365, 17, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 1, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 2, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 3, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 4, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 5, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 6, 107, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124004366, 7, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 1, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 2, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 3, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 4, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 5, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 6, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 7, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 8, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 9, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 10, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 11, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 12, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813004367, 13, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 1, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 2, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 3, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 4, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 5, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 6, 97, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 7, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 8, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831004368, 9, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 1, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 2, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 3, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 4, 189, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 5, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 6, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 7, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326004369, 8, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 1, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 2, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 3, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 4, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 5, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 6, 139, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 7, 90, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 8, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 9, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303004370, 10, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 1, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 2, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 3, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 4, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 5, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 6, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 7, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 8, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 9, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 10, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 11, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 12, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 13, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 14, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 15, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 16, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707004371, 17, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 1, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 2, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 3, 33, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 5, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 6, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 7, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 8, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 9, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 10, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 11, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 12, 41, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 13, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415004372, 14, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 1, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 2, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 3, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 4, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 5, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 6, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 7, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 8, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 9, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 10, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 11, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514004373, 12, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 1, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 2, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 3, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 4, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 5, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 6, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030930004374, 7, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025004375, 1, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025004375, 2, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025004375, 3, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025004375, 4, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 1, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 2, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 3, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 4, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 5, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 6, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 7, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 8, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 9, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 10, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 11, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 12, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830004376, 13, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 1, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 2, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 3, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 4, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 5, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 6, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 7, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 8, 189, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 9, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 10, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 11, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 12, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 13, 96, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220004377, 14, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 1, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 2, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 3, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 4, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 5, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 6, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 7, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 8, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924004378, 9, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 1, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 2, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 3, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 4, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 5, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 6, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 7, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 8, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 9, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 10, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 11, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 12, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 13, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 14, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 15, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922004379, 16, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 1, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 2, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 3, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 4, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 5, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 6, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204004380, 7, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121004381, 1, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121004381, 2, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121004381, 3, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121004381, 4, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828004382, 1, 168, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828004382, 2, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828004382, 3, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000828004382, 4, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 1, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 2, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 3, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 4, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 5, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 6, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 7, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 8, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815004383, 9, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 1, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 2, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 3, 192, 41, 18, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 4, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 5, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 6, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 7, 128, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 8, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620004384, 9, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 1, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 2, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 3, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 4, 121, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 5, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 6, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 7, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910004385, 8, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 1, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 2, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 3, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 4, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 5, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 6, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 7, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 8, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 9, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 10, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 11, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230004386, 12, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 1, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 2, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 3, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 4, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 5, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102004387, 6, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 1, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 2, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 3, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 4, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 5, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 6, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 7, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 8, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 9, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 10, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 11, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 12, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 13, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 1, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 2, 109, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 3, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 4, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 5, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 6, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 7, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 8, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 9, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920004754, 10, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 1, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 2, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 3, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 4, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 5, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 6, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 7, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422004755, 8, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 1, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 2, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 3, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 4, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 5, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 6, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 7, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 8, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 9, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926004756, 10, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 1, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 2, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 3, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 5, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 6, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 7, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 8, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 9, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 10, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 11, 131, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 12, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 13, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117004757, 14, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 1, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 2, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 3, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 4, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 5, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 6, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 7, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 8, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 9, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 10, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 11, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 12, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126004758, 13, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019004759, 1, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019004759, 2, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019004759, 3, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019004759, 4, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019004759, 5, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 1, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 2, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 3, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 4, 24, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 5, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 6, 154, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126004760, 7, 1, 12, 3, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 1, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 2, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 3, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 4, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 5, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 6, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 7, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 8, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 9, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 10, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 11, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005004761, 12, 161, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 1, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 2, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 3, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 4, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 5, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 6, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 7, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 8, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 9, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 10, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 11, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 12, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 13, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 14, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 15, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004762, 16, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 1, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 2, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 3, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 4, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 5, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004763, 6, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 1, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 2, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 3, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 4, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 5, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 6, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 7, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 8, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 9, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 10, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601004764, 11, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 1, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 2, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 3, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 4, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 5, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 6, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 7, 170, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 8, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 9, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 10, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 11, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811004765, 12, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 1, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 2, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 3, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 4, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 5, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 6, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 7, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 8, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 9, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 10, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 11, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 12, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 13, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 14, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 15, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 16, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018004766, 17, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 1, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 2, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 3, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 4, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 5, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306004767, 6, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 1, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 2, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 3, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 4, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 5, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 6, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 7, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 8, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108004768, 9, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 1, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 2, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 3, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 4, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 5, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 6, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 7, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 8, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 9, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 10, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 11, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 12, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 13, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126004769, 14, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 1, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 2, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 3, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 4, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 5, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 6, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 7, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021004770, 8, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706004771, 1, 16, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706004771, 2, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706004771, 3, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706004771, 4, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706004771, 5, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 1, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 2, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 3, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 4, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 5, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 6, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419004772, 7, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 1, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 2, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 3, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 4, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 5, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 6, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 7, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 8, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 9, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114004773, 10, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815004774, 1, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815004774, 2, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815004774, 3, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815004774, 4, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 1, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 2, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 3, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 4, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 5, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010209004775, 6, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 1, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 2, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 3, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 4, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 5, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 6, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 7, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 8, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 9, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401004776, 10, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 1, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 2, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 3, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 4, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 5, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 6, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 7, 16, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 8, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 9, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 10, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 11, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 12, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 13, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428004777, 14, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 2, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 3, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 4, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 5, 153, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 7, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 8, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 9, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605005142, 10, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 1, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 2, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 3, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 4, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 5, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 6, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 7, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 8, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 9, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 10, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 11, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 12, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 13, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 14, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 15, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 16, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 17, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005143, 18, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 1, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 2, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 3, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 4, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 5, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 6, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 7, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 8, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 9, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924005144, 10, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 1, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 2, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 3, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 4, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 5, 79, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 6, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 7, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 8, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 9, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 10, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 11, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 12, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 13, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 14, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 15, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 16, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005145, 17, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413005146, 1, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413005146, 2, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413005146, 3, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413005146, 4, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413005146, 5, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 1, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 2, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 3, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 4, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 5, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 6, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 7, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020005147, 8, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 1, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 2, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 3, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 4, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 5, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 6, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 7, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 8, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 9, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 10, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 11, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625005148, 12, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 1, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 2, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 3, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 4, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 5, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 6, 110, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 7, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 8, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608005149, 9, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 1, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 2, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 3, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 4, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 5, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 6, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 7, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 8, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 9, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 10, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817005150, 11, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 1, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 2, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 3, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 4, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 5, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 6, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614005151, 7, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 1, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 2, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 3, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 4, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 5, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 6, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 7, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 8, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 9, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226005152, 10, 6, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 1, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 2, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 3, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 4, 90, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 5, 155, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 6, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 7, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 8, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 9, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 10, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 11, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 12, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 13, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 14, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912005153, 15, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 1, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 2, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 3, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 4, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 5, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 6, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 7, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419005154, 8, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 1, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 2, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 3, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 4, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 5, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 6, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 7, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 8, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 9, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516005155, 10, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 1, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 2, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 3, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 4, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 5, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030129005156, 6, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 1, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 2, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 3, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 4, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 5, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 6, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 7, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 8, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 9, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005157, 10, 101, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 1, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 2, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 3, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 4, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 5, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 6, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 7, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104005158, 8, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 1, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 2, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 3, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 4, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 5, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 6, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 7, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 8, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 9, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 10, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 11, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 12, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 13, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 14, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 15, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813005159, 16, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608005160, 1, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608005160, 2, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608005160, 3, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608005160, 4, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608005160, 5, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000316005161, 1, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000316005161, 2, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000316005161, 3, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000316005161, 4, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 1, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 2, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 3, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 4, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 5, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 6, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 7, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 8, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 9, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 10, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 11, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 12, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 13, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 14, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 15, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 16, 62, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 17, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129005162, 18, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503005163, 1, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503005163, 2, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503005163, 3, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503005163, 4, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503005163, 5, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 1, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 2, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 3, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 4, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 5, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 6, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 7, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 8, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921005164, 9, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010126005165, 1, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010126005165, 2, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010126005165, 3, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010126005165, 4, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010126005165, 5, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 1, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 2, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 3, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 4, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 5, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507005166, 6, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630005167, 1, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630005167, 2, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630005167, 3, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 2, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 3, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 4, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 5, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 6, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 7, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821005571, 8, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 1, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 2, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 3, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 4, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 5, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 6, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 7, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 8, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 9, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 10, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 11, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100828005572, 12, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 1, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 2, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 3, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 4, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 5, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 6, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 7, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 8, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 9, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 10, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 11, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 12, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320005573, 13, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 1, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 2, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 3, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 4, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 5, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 6, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 7, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 8, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005574, 9, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605005575, 1, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605005575, 2, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605005575, 3, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 1, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 2, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 3, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 4, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 5, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005576, 6, 59, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 1, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 2, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 3, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 4, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 5, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 6, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 7, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 8, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 9, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070108005577, 10, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 1, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 2, 116, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 3, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 4, 177, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 5, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 6, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 7, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 8, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 9, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 10, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426005578, 11, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 1, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 2, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 3, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 4, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 5, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 6, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105005579, 7, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 1, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 2, 99, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 3, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 4, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 5, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 6, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 7, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 8, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040114005580, 9, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 1, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 2, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 3, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 4, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 5, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003005581, 6, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 1, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 2, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 3, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 4, 25, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 5, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 6, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 7, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 8, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 9, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 10, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 11, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 12, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 13, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726005582, 14, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726005583, 1, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726005583, 2, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726005583, 3, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726005583, 4, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726005583, 5, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 1, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 2, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 3, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 4, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 5, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 6, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 7, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 8, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 9, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 10, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 11, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320005584, 12, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 1, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 2, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 3, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 4, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 5, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005585, 6, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 1, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 2, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 3, 2, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 4, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 5, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 6, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 7, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 8, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 9, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 10, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 11, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 12, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 13, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 14, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 15, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121222005586, 16, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 1, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 2, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 3, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 4, 156, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 5, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405005587, 6, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 1, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 2, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 3, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 4, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 5, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 6, 153, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 7, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 8, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910005588, 9, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 1, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 2, 76, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 3, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 4, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 5, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 6, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326005589, 7, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 1, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 2, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 3, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 4, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 5, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 6, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 7, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 8, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 9, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 10, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 11, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 12, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 13, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 14, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 15, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131206005590, 16, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612005591, 1, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612005591, 2, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612005591, 3, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612005591, 4, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005592, 1, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005592, 2, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005592, 3, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005592, 4, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420005592, 5, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 1, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 2, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 3, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 4, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 5, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 6, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 7, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 8, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 9, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824005593, 10, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 1, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 2, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 3, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 4, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 5, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 6, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 7, 84, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 8, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 9, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210005594, 10, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 1, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 2, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 3, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 4, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 5, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 6, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031023005595, 7, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 1, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 2, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 3, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 4, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 5, 90, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 6, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 7, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109005596, 8, 46, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 1, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 2, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 3, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 4, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 5, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128005597, 6, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 1, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 2, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 3, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 4, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 14, 94, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 15, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 16, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330004388, 17, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 1, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 2, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 3, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 4, 78, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 5, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 6, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 7, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 8, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 9, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 10, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 11, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 12, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008004389, 13, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 1, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 2, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 3, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 4, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 5, 158, 78, 15, 1170);
commit;
prompt 49000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 6, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 7, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 8, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 9, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 10, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 11, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 12, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 13, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 14, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519004390, 15, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 1, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 2, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 3, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 4, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 5, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 6, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 7, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 8, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 9, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 10, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 11, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 12, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 13, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 14, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 15, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908004391, 16, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 1, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 2, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 3, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 4, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 5, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 6, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 7, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 8, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 9, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 10, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 11, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 12, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 13, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315004392, 14, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 1, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 2, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 3, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 4, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 5, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513004393, 6, 64, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 1, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 2, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 3, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 4, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 5, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 6, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 7, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 8, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 9, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924004394, 10, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 1, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 2, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 3, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 4, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 5, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 6, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 7, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 8, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 9, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 10, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 11, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 12, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 13, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 14, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 15, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324004395, 16, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 1, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 2, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 3, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 4, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 5, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 6, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 7, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 8, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 9, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 10, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 11, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 12, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016004396, 13, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130004397, 1, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130004397, 2, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130004397, 3, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130004397, 4, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130004397, 5, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 1, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 2, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 3, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 4, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 5, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 6, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 7, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 8, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 9, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429004398, 10, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 1, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 2, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 3, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 4, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 5, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 6, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 7, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 8, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 9, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 10, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 11, 16, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 12, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 13, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 14, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 15, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117004399, 16, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 1, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 2, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 3, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 4, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 5, 12, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 6, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 7, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 8, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 9, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 10, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 11, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524004400, 12, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 1, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 2, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 3, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 4, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 5, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 6, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 7, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 8, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 9, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 10, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417004401, 11, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 1, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 2, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 3, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 4, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 5, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 6, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 7, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030203004402, 8, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 1, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 2, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 3, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 4, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 5, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 6, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 7, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 8, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 9, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 10, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 11, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 12, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 13, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 14, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 15, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503004403, 16, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023004404, 1, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023004404, 2, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023004404, 3, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 1, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 2, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 3, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 4, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 5, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 6, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004405, 7, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512004406, 1, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512004406, 2, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512004406, 3, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512004406, 4, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512004406, 5, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 1, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 2, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 3, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 4, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 5, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 6, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 7, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050704004407, 8, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 1, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 2, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 3, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 4, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 5, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 6, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 7, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 8, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 9, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 10, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 11, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 12, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 13, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 14, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 15, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606004408, 16, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 1, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 2, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 3, 109, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 4, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 5, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 6, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 7, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 8, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 9, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106004409, 10, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 1, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 2, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 3, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 4, 123, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 5, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 6, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 6, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 7, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106004778, 8, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 1, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 2, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 3, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 4, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 5, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 6, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 7, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317004779, 8, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 1, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 2, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 3, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 4, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 5, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 6, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 7, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 8, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 9, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 10, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 11, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 12, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 13, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607004780, 14, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 1, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 2, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 3, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 4, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 5, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 6, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050128004781, 7, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 1, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 2, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 3, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 4, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 5, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 6, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 7, 118, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 8, 43, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 9, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 10, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 11, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 12, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 13, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620004782, 14, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 1, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 2, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 3, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 4, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 5, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 6, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 7, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 8, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 9, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 10, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 11, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 12, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 13, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 14, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 15, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 16, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131010004783, 17, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 1, 158, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 2, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 3, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 4, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 5, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 6, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 7, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 8, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 9, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 10, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 11, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721004784, 12, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001104004785, 1, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001104004785, 2, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001104004785, 3, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 1, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 2, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 3, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 4, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 5, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 6, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 7, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 8, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603004786, 9, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 1, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 2, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 3, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 4, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 5, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 6, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 7, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 8, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 9, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 10, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526004787, 11, 11, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 1, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 2, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 3, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 4, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 5, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227004788, 6, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 1, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 2, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 3, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 4, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 5, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 6, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 7, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 8, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 9, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 10, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 11, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 12, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314004789, 13, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004790, 1, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004790, 2, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004790, 3, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004790, 4, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114004790, 5, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 1, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 2, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 3, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 4, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 5, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 6, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 7, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 8, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 9, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 10, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 11, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004791, 12, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 1, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 2, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 3, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 4, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 5, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 6, 68, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 7, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126004792, 8, 4, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 1, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 2, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 3, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 4, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 5, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 6, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 7, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 8, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 9, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004004793, 10, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 1, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 2, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 3, 169, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 4, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 5, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830004794, 6, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912004795, 1, 135, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912004795, 2, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912004795, 3, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104004796, 1, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104004796, 2, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104004796, 3, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104004796, 4, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104004796, 5, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 1, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 2, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 3, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 4, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 5, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 6, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 7, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 8, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 9, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 10, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 11, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 12, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 13, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 14, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321004797, 15, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 1, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 2, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 3, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 4, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 5, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 6, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 7, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 8, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225004798, 9, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110004799, 1, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110004799, 2, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110004799, 3, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110004799, 4, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 1, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 2, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 3, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 4, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 5, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 6, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030923004800, 7, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 1, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 2, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 3, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 4, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 5, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 6, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429004801, 7, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 1, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 2, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 3, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 4, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 5, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 6, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 7, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 8, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805004802, 9, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 1, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 2, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 3, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 4, 16, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 5, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 6, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 7, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 8, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 9, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 10, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 11, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 12, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 13, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026004803, 14, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 1, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 2, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 3, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 4, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 5, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 6, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 7, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 8, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630005167, 4, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010630005167, 5, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 1, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 2, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 3, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 4, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 5, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 6, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 7, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 8, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 9, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906005168, 10, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808005169, 1, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808005169, 2, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808005169, 3, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808005169, 4, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010808005169, 5, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519005170, 1, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519005170, 2, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519005170, 3, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519005170, 4, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519005170, 5, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 1, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 2, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 3, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 4, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 5, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 6, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 7, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 8, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 9, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 10, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 11, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 12, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326005171, 13, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 1, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 2, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 3, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 4, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 5, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 6, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 7, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815005172, 8, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 1, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 2, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 3, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 4, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 5, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 6, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 7, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 8, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 9, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 10, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 11, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 12, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 13, 96, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 14, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 15, 190, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223005173, 16, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 1, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 2, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 3, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 4, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 5, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 6, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 7, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 8, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 9, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 10, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 11, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 12, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220005174, 13, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 1, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 2, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 3, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 4, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 5, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 6, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819005175, 7, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 1, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 2, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 3, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 4, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 5, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 6, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 7, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 8, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023005176, 9, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 1, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 2, 32, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 3, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 4, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 5, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 6, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 7, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 8, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 9, 127, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 10, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 11, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 12, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 13, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 14, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 15, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005177, 16, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 1, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 2, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 3, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 4, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 5, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 6, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 7, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114005178, 8, 41, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521005179, 1, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521005179, 2, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521005179, 3, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521005179, 4, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521005179, 5, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 1, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 2, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 3, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 4, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 5, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 6, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 7, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 8, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 9, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 10, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 11, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 12, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522005180, 13, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 1, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 2, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 3, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 4, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 5, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 6, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 7, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802005181, 8, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 1, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 2, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 3, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 4, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 5, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 6, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 7, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 8, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 9, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 10, 102, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 11, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230005182, 12, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 1, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 2, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 3, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 4, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 5, 59, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 6, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 7, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 8, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 9, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110005183, 10, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 1, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 2, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 3, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 4, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 5, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 6, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 7, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 8, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 9, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 10, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818005184, 11, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215005185, 1, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215005185, 2, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 1, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 2, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 3, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 4, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 5, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 6, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 7, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 8, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 9, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 10, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 11, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 12, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121005186, 13, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 1, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 2, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 3, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 4, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 5, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 6, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 7, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 8, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 9, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 10, 116, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 11, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 12, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 13, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 14, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 15, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209005187, 16, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 1, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 2, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 3, 192, 14, 18, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 4, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 5, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 6, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 7, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 8, 150, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 9, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 10, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831005188, 11, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 1, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 2, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 3, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 4, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 5, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 6, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 7, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103005189, 8, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 1, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 2, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 3, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 4, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 5, 184, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901005190, 6, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 1, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 2, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 3, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 4, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 5, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 6, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 7, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 8, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103005191, 9, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 1, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 2, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 3, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 12, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 13, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507005471, 14, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 1, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 2, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 3, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 4, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 5, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 6, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 7, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 8, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 9, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 10, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 11, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 12, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 13, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 14, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 15, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929005472, 16, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 1, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 2, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 3, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 4, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 5, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 6, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 7, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 8, 55, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 9, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 10, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 11, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901005473, 12, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 1, 69, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 2, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 3, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 4, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 5, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 6, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 7, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114005474, 8, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 1, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 2, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 3, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 4, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 5, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 6, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 7, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 8, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 9, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 10, 117, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 11, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 12, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 13, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 14, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 15, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 16, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715005475, 17, 102, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 1, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 2, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 3, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 4, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 5, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 6, 23, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 7, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 8, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222005476, 9, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 1, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 2, 178, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 3, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 4, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 5, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 6, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 7, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411005477, 8, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 1, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 2, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 3, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 4, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 5, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 6, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 7, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 8, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 9, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005478, 10, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 1, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 2, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 3, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 4, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 5, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 6, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 7, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060122005479, 8, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 1, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 2, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 3, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 4, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 5, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 6, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 7, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 8, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 9, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 10, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 11, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 12, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 13, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423005480, 14, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 1, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 2, 100, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 3, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 4, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 5, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 6, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 7, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 8, 109, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 9, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 10, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207005481, 11, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 1, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 2, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 3, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 4, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 5, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 6, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 7, 155, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320005482, 8, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 1, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 2, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 3, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 4, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 5, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 6, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 7, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 8, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904005483, 9, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617005484, 1, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617005484, 2, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617005484, 3, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617005484, 4, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 1, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 2, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 3, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 4, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 5, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 6, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 7, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 8, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 9, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 10, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204005485, 11, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610005486, 1, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610005486, 2, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610005486, 3, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610005486, 4, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 1, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 2, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 3, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 4, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 5, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 6, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607005487, 7, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 1, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 2, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 3, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 4, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 5, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 6, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 7, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 8, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 9, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 10, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 11, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 12, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 13, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 14, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 15, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 16, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006005488, 17, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 1, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 2, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 3, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 4, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 5, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 6, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 7, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 8, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 9, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 10, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 11, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121005489, 12, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 1, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 2, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 3, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 4, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 5, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 6, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 7, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513005490, 8, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 1, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 2, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 3, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 4, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 5, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423005491, 6, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 1, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 2, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 3, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 4, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 5, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 6, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 7, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 8, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 9, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607005492, 10, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 1, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 2, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 3, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 4, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 5, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 6, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 7, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 8, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 9, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 10, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 11, 62, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 12, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 13, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 14, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 15, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 16, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 17, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225005493, 18, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 1, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 2, 100, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 3, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 4, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 5, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 6, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 7, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 8, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305005494, 9, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 7, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 8, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 9, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 10, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061016004410, 11, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 1, 182, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 2, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 3, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 4, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 5, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 6, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 7, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 8, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 9, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 10, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 11, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711004411, 12, 107, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 1, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 2, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 3, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 4, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 5, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 6, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 7, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 8, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 9, 182, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 10, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 11, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 12, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 13, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 14, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 15, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105004412, 16, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 1, 146, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 2, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 3, 8, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 4, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 5, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 6, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 7, 80, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 8, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 9, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 10, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 11, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 12, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 13, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029004413, 14, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 1, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 2, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 3, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 4, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 5, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 6, 119, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 7, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 8, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 9, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 10, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 11, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 12, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510004414, 13, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 1, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 2, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 3, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 4, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 5, 93, 25, 12, 300);
commit;
prompt 50000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 6, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 7, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 8, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 9, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 10, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 11, 49, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 12, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 13, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128004415, 14, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 1, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 2, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 3, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 4, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 5, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707004416, 6, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 1, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 2, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 3, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 4, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 5, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 6, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 7, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 8, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 9, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 10, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 11, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 12, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 13, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 14, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 15, 42, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203004417, 16, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 1, 183, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 2, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 3, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 4, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 5, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 6, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 7, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 8, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 9, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 10, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 11, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 12, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 13, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 14, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 15, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417004418, 16, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026004419, 1, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026004419, 2, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026004419, 3, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026004419, 4, 152, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026004419, 5, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 1, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 2, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 3, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 4, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 5, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 6, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 7, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 8, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 9, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 10, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 11, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 12, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 13, 192, 44, 18, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919004420, 14, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 1, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 2, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 3, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 4, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 5, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 6, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 7, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 8, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 9, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 10, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429004421, 11, 80, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 1, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 2, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 3, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 4, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 5, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 6, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 7, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414004422, 8, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 1, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 2, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 3, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 4, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 5, 34, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 6, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 7, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 8, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 9, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208004423, 10, 77, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 1, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 2, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 3, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 4, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 5, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 6, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 7, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 8, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 9, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 10, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 11, 55, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 12, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 13, 92, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325004424, 14, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 1, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 2, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 3, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 4, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 5, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 6, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 7, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 8, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 9, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104004425, 10, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427004426, 1, 141, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427004426, 2, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427004426, 3, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427004426, 4, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427004426, 5, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 1, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 2, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 4, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 5, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 6, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 7, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 8, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129004427, 9, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 1, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 2, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 3, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 4, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 5, 165, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 6, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 7, 162, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 8, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 9, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 10, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 11, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004428, 12, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 1, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 2, 7, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 3, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 4, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 5, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 6, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 7, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320004429, 8, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 1, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 2, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 3, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 4, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 5, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 6, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 7, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 8, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525004430, 9, 96, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 1, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 2, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 3, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 4, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 5, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 6, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 7, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 8, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 9, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 10, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 11, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105004431, 12, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 9, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328004804, 10, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 1, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 2, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 3, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 4, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 5, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 6, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 7, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 8, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 9, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 10, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 11, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 12, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114004805, 13, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 1, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 2, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 3, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 4, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 5, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 6, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 7, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 8, 83, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 9, 24, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 10, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 11, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 12, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 13, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 14, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120713004806, 15, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 1, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 2, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 3, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 4, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 5, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 6, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 7, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 8, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016004807, 9, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420004808, 1, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420004808, 2, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420004808, 3, 16, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420004808, 4, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 1, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 2, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 3, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 4, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 5, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 6, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 7, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407004809, 8, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 1, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 2, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 3, 186, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 4, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 5, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216004810, 6, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315004811, 1, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315004811, 2, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315004811, 3, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315004811, 4, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315004811, 5, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 1, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 2, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 3, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 4, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 5, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 6, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004812, 7, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 1, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 2, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 3, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 4, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 5, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 6, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 7, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 8, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 9, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 10, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 11, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 12, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 13, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 14, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213004813, 15, 90, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 1, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 2, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 3, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 4, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 5, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 6, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 7, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209004814, 8, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 2, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 3, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 4, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 5, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 6, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 7, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409004815, 8, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 1, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 2, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 3, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 4, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 5, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 6, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004816, 7, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306004817, 1, 152, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306004817, 2, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306004817, 3, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306004817, 4, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306004817, 5, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 1, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 2, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 3, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 4, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 5, 182, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 6, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 7, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 8, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 9, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 10, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004818, 11, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 1, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 2, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 3, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 4, 104, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 5, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 6, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 7, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 8, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 9, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216004819, 10, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929004820, 1, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929004820, 2, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929004820, 3, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929004820, 4, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 1, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 2, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 3, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 4, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 5, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 6, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 7, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 8, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 9, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 10, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 11, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 12, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 13, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 14, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 15, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004821, 16, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 1, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 2, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 3, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 4, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 5, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 6, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 7, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 8, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 9, 185, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 10, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 11, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606004822, 12, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 1, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 2, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 3, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 4, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 5, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 6, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 7, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 8, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 9, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 10, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 11, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 12, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110004823, 13, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 1, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 2, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 3, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 4, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 5, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 6, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 7, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 8, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122004824, 9, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 1, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 2, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 3, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 4, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 5, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 6, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 7, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 8, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221004825, 9, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502004826, 1, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502004826, 2, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502004826, 3, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502004826, 4, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 1, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 2, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 3, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 4, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 5, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 6, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 7, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721004827, 8, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 1, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 2, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 3, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 4, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 5, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 6, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 7, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 8, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 9, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 10, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711004828, 11, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 1, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 2, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 3, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 4, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 5, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 6, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 7, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 8, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 9, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 10, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 11, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 12, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 13, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 14, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 15, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704004829, 16, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 1, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 2, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 3, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 4, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 4, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 5, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 6, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622005192, 7, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 1, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 2, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 3, 136, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 4, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 5, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 6, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050710005193, 7, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 1, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 2, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 3, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 4, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 5, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005194, 6, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 1, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 2, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 3, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 4, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 5, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 6, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108005195, 7, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 1, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 2, 101, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 3, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 4, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 5, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 6, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 7, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 8, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 9, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 10, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 11, 180, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 12, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 13, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628005196, 14, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 1, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 2, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 3, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 4, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 5, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 6, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 7, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 8, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 9, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809005197, 10, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 1, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 2, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 3, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 4, 22, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 5, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 6, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 7, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 8, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411005198, 9, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 1, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 2, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 3, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 4, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 5, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 6, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 7, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 8, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 9, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 10, 92, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 11, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 12, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 13, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 14, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 15, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822005199, 16, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 1, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 2, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 3, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 4, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 5, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 6, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 7, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 8, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 9, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 10, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 11, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071030005200, 12, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228005201, 1, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228005201, 2, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228005201, 3, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228005201, 4, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020228005201, 5, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 1, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 2, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 3, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 4, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 5, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 6, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 7, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 8, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 9, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 10, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071117005202, 11, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 1, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 2, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 3, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 4, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 5, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 6, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 7, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 8, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 9, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924005203, 10, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 1, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 2, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 3, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 4, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 5, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 6, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 7, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 8, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 9, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 10, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813005204, 11, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 1, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 2, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 3, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 4, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 5, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 6, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 7, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 8, 178, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 9, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 10, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 11, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023005205, 12, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 1, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 2, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 3, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 4, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 5, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 6, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 7, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 8, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 9, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 10, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 11, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005206, 12, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 1, 139, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 2, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 3, 118, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 4, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 5, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210005207, 6, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 1, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 2, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 3, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 4, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 5, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 6, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 7, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 8, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 9, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 10, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410005208, 11, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 1, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 2, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 3, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 4, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 5, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 6, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 7, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 8, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 9, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 10, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 11, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090729005209, 12, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 1, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 2, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 3, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 4, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 5, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 6, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 7, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 8, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208005210, 9, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 1, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 2, 175, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 3, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 4, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 5, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 6, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 7, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 8, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 9, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 10, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 11, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 12, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 13, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 14, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 15, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531005211, 16, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 1, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 2, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 3, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 4, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 5, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 6, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 7, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 8, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 9, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 10, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 11, 95, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 12, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 13, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 14, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 15, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015005212, 16, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 1, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 2, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 3, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 4, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 5, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 6, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 7, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 8, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 9, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 10, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101005213, 11, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112005214, 1, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112005214, 2, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112005214, 3, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 1, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 2, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 3, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 4, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 5, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 6, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 7, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 8, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 9, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 1, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 2, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 3, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 4, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 5, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 6, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 7, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 8, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 9, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 10, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 11, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 12, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 13, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 14, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803005521, 15, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 1, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 2, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 3, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 4, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 5, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 6, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 7, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 8, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 9, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229005522, 10, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005523, 1, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005523, 2, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005523, 3, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005523, 4, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 1, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 2, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 3, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 4, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 5, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 6, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 7, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 8, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 9, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080127005524, 10, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 1, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 2, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 3, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 4, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 5, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 6, 21, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 7, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208005525, 8, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 1, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 2, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 3, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 4, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 5, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 6, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 7, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 8, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 9, 71, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 10, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 11, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 12, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 13, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 14, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516005526, 15, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302005527, 1, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302005527, 2, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302005527, 3, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302005527, 4, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302005527, 5, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 1, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 2, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 3, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 4, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 5, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 6, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 7, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 8, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 9, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928005528, 10, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 1, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 2, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 3, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 4, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 5, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 6, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 7, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 8, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 9, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 10, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612005529, 11, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 1, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 2, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 3, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 4, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 5, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 6, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 7, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 8, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 9, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 10, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 11, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 12, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 13, 90, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 14, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614005530, 15, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 1, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 2, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 3, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 4, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 5, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623005531, 6, 109, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 1, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 2, 29, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 3, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 4, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 5, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 6, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 7, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 8, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 9, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 10, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 11, 1, 77, 3, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826005532, 12, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 1, 154, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 2, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 3, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 4, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 5, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 6, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 7, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 8, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 9, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 10, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 11, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 12, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 13, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416005533, 14, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 1, 1, 92, 3, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 2, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 3, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 4, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 5, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 6, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911005534, 7, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911005535, 1, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911005535, 2, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911005535, 3, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911005535, 4, 30, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204005536, 1, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204005536, 2, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204005536, 3, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204005536, 4, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204005536, 5, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308005537, 1, 112, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308005537, 2, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308005537, 3, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308005537, 4, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308005537, 5, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 1, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 2, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 3, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 4, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 5, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 6, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 7, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 8, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 9, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 10, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 11, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 12, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 13, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100922005538, 14, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 1, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 2, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 3, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 4, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 5, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 6, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 7, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 8, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 9, 81, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 10, 24, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617005539, 11, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 1, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 2, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 3, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 4, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 5, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608005540, 6, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 1, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 2, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 3, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 4, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 5, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 6, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 7, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 8, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 9, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 10, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016005541, 11, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905005542, 1, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905005542, 2, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905005542, 3, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905005542, 4, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905005542, 5, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 1, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 2, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 3, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 4, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 5, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 6, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 7, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 8, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 9, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 10, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 11, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 12, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615005543, 13, 177, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031005544, 1, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031005544, 2, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031005544, 3, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005545, 1, 164, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005545, 2, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005545, 3, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905005545, 4, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 1, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 2, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 3, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 4, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 5, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 6, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 7, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 8, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 9, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 10, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 11, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728005546, 12, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 1, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 2, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 3, 158, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913005547, 4, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 1, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 2, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 3, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 4, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 5, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 6, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714004432, 7, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 1, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 2, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 3, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 4, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 5, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 6, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 7, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 8, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 9, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 10, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 11, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 12, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 13, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523004433, 14, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 1, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 2, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 3, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 4, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 5, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 6, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 7, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428004434, 8, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 1, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 2, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 3, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 4, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 5, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 6, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521004435, 7, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 1, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 2, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 3, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 4, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 5, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 6, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 7, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 8, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 9, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 10, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 11, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208004436, 12, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 1, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 2, 39, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 3, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 4, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 5, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 6, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321004437, 7, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 1, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 2, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 3, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 4, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 5, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 6, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113004438, 7, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 1, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 2, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 3, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 4, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 5, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701004439, 6, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 1, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 2, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 3, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 4, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 5, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 6, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 7, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 8, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 9, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 10, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061105004440, 11, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 1, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 2, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 3, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 4, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 5, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 6, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 7, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 8, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 9, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 10, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301004441, 11, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924004442, 1, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924004442, 2, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924004442, 3, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 1, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 2, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 3, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 4, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 5, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 6, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 7, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 8, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 9, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 10, 84, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 11, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802004443, 12, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 1, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 2, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 3, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 4, 171, 49, 11, 539);
commit;
prompt 51000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 5, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 6, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 7, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 8, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 9, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 10, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 11, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 12, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204004444, 13, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 1, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 2, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 3, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 4, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 5, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 6, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 7, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928004445, 8, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 1, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 2, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 3, 122, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 4, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 5, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 6, 131, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 7, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 8, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 9, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 10, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 11, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 12, 182, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 13, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 14, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317004446, 15, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 1, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 2, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 3, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 4, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 5, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 6, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 7, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 8, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 9, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 10, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 11, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 12, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 13, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 14, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 15, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322004447, 16, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 1, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 2, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 3, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 4, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 5, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 6, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 7, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 8, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 9, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128004448, 10, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622004449, 1, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622004449, 2, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622004449, 3, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622004449, 4, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622004449, 5, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 1, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 2, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 3, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 4, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 5, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 6, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613004450, 7, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224004451, 1, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224004451, 2, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224004451, 3, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224004451, 4, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 1, 30, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 2, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 3, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 4, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 5, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 6, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 7, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040207004452, 8, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 1, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 2, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 3, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 4, 174, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 5, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 6, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525004453, 7, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 1, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 2, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 3, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 4, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 5, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 6, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 7, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 8, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 9, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 10, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 11, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 12, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718004454, 13, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 1, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 2, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 3, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 4, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 5, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 6, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 7, 109, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 8, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 9, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 10, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 11, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 12, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 13, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214004455, 14, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 1, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 2, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 3, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 4, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 5, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 6, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 7, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 8, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 9, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 10, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 11, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 12, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 13, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322004456, 14, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 5, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 6, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 7, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 8, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 9, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 10, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 11, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 12, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 13, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110408004830, 14, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 1, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 2, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 3, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 4, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 5, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 6, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 7, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 8, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207004831, 9, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 1, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 2, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 3, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 4, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 5, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 6, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 7, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620004832, 8, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 1, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 2, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 3, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 4, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 5, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 6, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 7, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 8, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 9, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 10, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028004833, 11, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 1, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 2, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 3, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 4, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 5, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 6, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 7, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429004834, 8, 57, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 1, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 2, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 3, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 4, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 5, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 6, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 7, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 8, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 9, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 10, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 11, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 12, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 13, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 14, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915004835, 15, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 1, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 2, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 3, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 4, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 5, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 6, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 7, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 8, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216004836, 9, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 1, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 2, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 3, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 4, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 5, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 6, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 7, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 8, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 9, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014004837, 10, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 1, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 2, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 3, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 4, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 5, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 6, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 7, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 8, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 9, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 10, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 11, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 12, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 13, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820004838, 14, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605004839, 1, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605004839, 2, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605004839, 3, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605004839, 4, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605004839, 5, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 1, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 2, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 3, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 4, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 5, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 6, 147, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 7, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 8, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819004840, 9, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 1, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 2, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 3, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 4, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 5, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 6, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 7, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 8, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 9, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 10, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 11, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 12, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215004841, 13, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 1, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 2, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 3, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 4, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 5, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 6, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 7, 78, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 8, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 9, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324004842, 10, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011004843, 1, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011004843, 2, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 1, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 2, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 3, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 4, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 5, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 6, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 7, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 8, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 9, 131, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 10, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 11, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 12, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 13, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123004844, 14, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 1, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 2, 168, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 3, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 4, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 5, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 6, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 7, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 8, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 9, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 10, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 11, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 12, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 13, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 14, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 15, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409004845, 16, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 1, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 2, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 3, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 4, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 5, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 6, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 7, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 8, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 9, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 10, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 11, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605004846, 12, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 1, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 2, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 3, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 4, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 5, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 6, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 7, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 8, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 9, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 10, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 11, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 12, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 13, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 14, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 15, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825004847, 16, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 1, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 2, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 3, 74, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 4, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 5, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 6, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 7, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 8, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 9, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 10, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 11, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118004848, 12, 192, 54, 18, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 1, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 2, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 3, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 4, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 5, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 6, 104, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 7, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 8, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021004849, 9, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516004850, 1, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516004850, 2, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516004850, 3, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516004850, 4, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516004850, 5, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 1, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 2, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 3, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 4, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 5, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 6, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 7, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 8, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 9, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 10, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 11, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 12, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 13, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 14, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 15, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 16, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517004851, 17, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 1, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 2, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 3, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 4, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 5, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 10, 142, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 11, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 12, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918005215, 13, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 1, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 2, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 3, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 4, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 5, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 6, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 7, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 8, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 9, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 10, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 11, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312005216, 12, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 1, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 2, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 3, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 4, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 5, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 6, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 7, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 8, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 9, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228005217, 10, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210005218, 1, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210005218, 2, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210005218, 3, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210005218, 4, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918005219, 1, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918005219, 2, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918005219, 3, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918005219, 4, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 1, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 2, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 3, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 4, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 5, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104005220, 6, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 1, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 2, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 3, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 4, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 5, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 6, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 7, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 8, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 9, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 10, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 11, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 12, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 13, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 14, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005221, 15, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 1, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 2, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 3, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 4, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 5, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 6, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 7, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 8, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318005222, 9, 152, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 1, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 2, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 3, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 4, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 5, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 6, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 7, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 8, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 9, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519005223, 10, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 1, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 2, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 3, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 4, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 5, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 6, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 7, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 8, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 9, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 10, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 11, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 12, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 13, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 14, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523005224, 15, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 1, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 2, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 3, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 4, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 5, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 6, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 7, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 8, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 9, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 10, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 11, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 12, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 13, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005225, 14, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 1, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 2, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 3, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 5, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 6, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 7, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423005226, 8, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 1, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 2, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 3, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 4, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 5, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 6, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 7, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 8, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 9, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 10, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 11, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 12, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 13, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121005227, 14, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 1, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 2, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 3, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 4, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 5, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 6, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 7, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 8, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 9, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411005228, 10, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005229, 1, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005229, 2, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005229, 3, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005229, 4, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105005229, 5, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617005230, 1, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617005230, 2, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617005230, 3, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 1, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 2, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 3, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 4, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 5, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 6, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 7, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 8, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 9, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 10, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 11, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 12, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 13, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 14, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 15, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 16, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323005231, 17, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 1, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 2, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 3, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 4, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 5, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 6, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 7, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 8, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 9, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 10, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 11, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 12, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 13, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 14, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 15, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 16, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023005232, 17, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 1, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 2, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 3, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 4, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 5, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 6, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 7, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 8, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 9, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 10, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 11, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 12, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 13, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 14, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 15, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601005233, 16, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 1, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 2, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 3, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 4, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 5, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 6, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 7, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930005234, 8, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 1, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 2, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 3, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 4, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 5, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 6, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411005235, 7, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 1, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 2, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 3, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 4, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 5, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 6, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 7, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107005236, 8, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 1, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 2, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 3, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 4, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 5, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 6, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 7, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 8, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 9, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 10, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 11, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105005237, 12, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119005238, 1, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119005238, 2, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119005238, 3, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119005238, 4, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 1, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 2, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 3, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 4, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 5, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 6, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903004085, 2, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903004085, 3, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903004085, 4, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 1, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 2, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 3, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 4, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 5, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 6, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 7, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 8, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 9, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 10, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 11, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 12, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 13, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 14, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 15, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 16, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426004086, 17, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 1, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 2, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 3, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 4, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 5, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 6, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 7, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 8, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 9, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 10, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 11, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 12, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628004087, 13, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 1, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 2, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 3, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 4, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 5, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 6, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 7, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 8, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 9, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 10, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 11, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 12, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 13, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 14, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504004088, 15, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 1, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 2, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 3, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 4, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 5, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 6, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 7, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 8, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 9, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 10, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 11, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 12, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 13, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 14, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004089, 15, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818004090, 1, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818004090, 2, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818004090, 3, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818004090, 4, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818004090, 5, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 1, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 2, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 3, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 4, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 5, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 6, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 7, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 8, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 9, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202004091, 10, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 1, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 2, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 3, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 4, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 5, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 6, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 7, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 8, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 9, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 10, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 11, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 12, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 13, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516004092, 14, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 1, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 2, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 3, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 4, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 5, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 6, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 7, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421004093, 8, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 1, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 2, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 3, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 4, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 5, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004094, 6, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 1, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 2, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 3, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 4, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 5, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 6, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 7, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 8, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004095, 9, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 1, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 2, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 3, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 4, 74, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 5, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 6, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 7, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 8, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 9, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 10, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 11, 131, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100902004096, 12, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 1, 19, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 2, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 3, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 4, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 5, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 6, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 7, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 8, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 9, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 10, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 11, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 12, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004097, 13, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616004098, 1, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616004098, 2, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616004098, 3, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616004098, 4, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616004098, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004099, 1, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004099, 2, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004099, 3, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820004099, 4, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 1, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 2, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 3, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 4, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 5, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 6, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 7, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 8, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 9, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128004100, 10, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 1, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 2, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 3, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 4, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 5, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 6, 167, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 7, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 8, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 9, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 10, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 11, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 12, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 13, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328004101, 14, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612004102, 1, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612004102, 2, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612004102, 3, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612004102, 4, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 1, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 2, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 3, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 4, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 5, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 6, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 7, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107004103, 8, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 1, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 2, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 3, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 4, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 5, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 6, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227004104, 7, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 1, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 2, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 3, 100, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 4, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 5, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 6, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 7, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 8, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 9, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 10, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126004105, 11, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 1, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 2, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 3, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 4, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 5, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 6, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 7, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 8, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 9, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 10, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 11, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 12, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 13, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 14, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 15, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 16, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102004106, 17, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002004107, 1, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002004107, 2, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002004107, 3, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029004108, 1, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029004108, 2, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029004108, 3, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029004108, 4, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008004109, 1, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008004109, 2, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008004109, 3, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008004109, 4, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916004110, 1, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916004110, 2, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916004110, 3, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916004110, 4, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916004110, 5, 118, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 1, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 2, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 3, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 1, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 2, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 3, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 4, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 5, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 6, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004457, 7, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 1, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 2, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 3, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 4, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 5, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 6, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 7, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 8, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 9, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 10, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 11, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527004458, 12, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 1, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 2, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 3, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 4, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 5, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 6, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 7, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 8, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 9, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120004459, 10, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 1, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 2, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 3, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 4, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 5, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 6, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 7, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 8, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 9, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 10, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 11, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 12, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 13, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 14, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 15, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 16, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130429004460, 17, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 1, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 2, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 3, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 4, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 5, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 6, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 7, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 8, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 9, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 10, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230004461, 11, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 1, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 2, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 3, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 4, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 5, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 6, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 7, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 8, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 9, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 10, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 11, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622004462, 12, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 1, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 2, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 3, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 4, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 5, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 6, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 7, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 8, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 9, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 10, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 11, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 12, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 13, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 14, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 15, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 16, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 17, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530004463, 18, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 1, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 2, 150, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 3, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 4, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 5, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 6, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 7, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 8, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 9, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 10, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 11, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 12, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 13, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 14, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 15, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 16, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613004464, 17, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117004465, 1, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117004465, 2, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117004465, 3, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117004465, 4, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117004465, 5, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221004466, 1, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221004466, 2, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221004466, 3, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221004466, 4, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221004466, 5, 145, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 1, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 2, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 3, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 4, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 5, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 6, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 8, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 9, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 10, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820004467, 11, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 1, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 2, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 3, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 4, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 5, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 6, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 7, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 8, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 9, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 10, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 11, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 12, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 13, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 14, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 15, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811004468, 16, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 1, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 2, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 3, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 4, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 5, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 6, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 7, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 8, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 9, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 10, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 11, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 12, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821004469, 13, 111, 77, 13, 1001);
commit;
prompt 52000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 1, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 2, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 3, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 4, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 5, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726004470, 6, 109, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913004471, 1, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913004471, 2, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913004471, 3, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913004471, 4, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 1, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 2, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 3, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 4, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 5, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 6, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 7, 24, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 8, 23, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 9, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 10, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 11, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 12, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 13, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228004472, 14, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 1, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 2, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 3, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 4, 171, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 5, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 6, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 7, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 8, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103004473, 9, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 1, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 2, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 3, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 4, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 5, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 6, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 7, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 8, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 9, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 10, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 11, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 12, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 13, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 14, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 15, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131004474, 16, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 1, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 2, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 3, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 4, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 5, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 6, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 7, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 8, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223004475, 9, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 1, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 2, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 3, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 4, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 5, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 6, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 7, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004476, 8, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000827004477, 1, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000827004477, 2, 127, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000827004477, 3, 167, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 1, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 2, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 3, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 4, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 5, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 6, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 7, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 8, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 9, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 10, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 11, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 12, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 13, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 14, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 15, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201004478, 16, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 6, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 7, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 8, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 9, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 10, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 11, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 12, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 13, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 14, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 15, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 16, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 17, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204004852, 18, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 1, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 2, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 3, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 4, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 5, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 6, 68, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 7, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 8, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 9, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 10, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 11, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 12, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309004853, 13, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 1, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 2, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 3, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 4, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 5, 144, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 6, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 7, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 8, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 9, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304004854, 10, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 1, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 2, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 3, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 4, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 5, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 6, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 7, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 8, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 9, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 10, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 11, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 12, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 13, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116004855, 14, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 1, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 2, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 3, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 4, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 5, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 6, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 7, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 8, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070824004856, 9, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 1, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 2, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 3, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 4, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 5, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 6, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 7, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 8, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 9, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 10, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 11, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 12, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 13, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 14, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803004857, 15, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 1, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 2, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 3, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 4, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 5, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 6, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018004858, 7, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330004859, 1, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330004859, 2, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330004859, 3, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330004859, 4, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330004859, 5, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 1, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 2, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 3, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 4, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 5, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 6, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 7, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 8, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 9, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 10, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 11, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 12, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 13, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529004860, 14, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 1, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 2, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 3, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 4, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 5, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 6, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 7, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 8, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 9, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 10, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 11, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 12, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100212004861, 13, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 1, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 2, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 3, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 4, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 5, 178, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 6, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 7, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 8, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 9, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 10, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218004862, 11, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 1, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 2, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 3, 73, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 4, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 5, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 6, 191, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 7, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 8, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 9, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 10, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 11, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 12, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 13, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 14, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 15, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 16, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 17, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115004863, 18, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 1, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 2, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 3, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 4, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 5, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 6, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 7, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 8, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 9, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 10, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 11, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 12, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925004864, 13, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 1, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 2, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 3, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 4, 186, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 5, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 6, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 7, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 8, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 9, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002004865, 10, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 1, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 2, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 3, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 4, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 5, 179, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 6, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 7, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 8, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 9, 69, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 10, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 11, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 12, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 13, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824004866, 14, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 1, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 2, 156, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 3, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 4, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 5, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126004867, 6, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 1, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 2, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 3, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 4, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 5, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507004868, 6, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326004869, 1, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326004869, 2, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326004869, 3, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326004869, 4, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326004869, 5, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 1, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 2, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 3, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 4, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 5, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 6, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218004870, 7, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 1, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 2, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 3, 96, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 4, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 5, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 6, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 7, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 8, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 9, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 10, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004871, 11, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 1, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 2, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 3, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 4, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 5, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 6, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 7, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 8, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 9, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419004872, 10, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 1, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 2, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 3, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 4, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 5, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 6, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 7, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 8, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128004873, 9, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103004874, 1, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103004874, 2, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103004874, 3, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103004874, 4, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103004874, 5, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 1, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 7, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 8, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 9, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 10, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 11, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 12, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 13, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 14, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 15, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 16, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130005239, 17, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005240, 1, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005240, 2, 98, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005240, 3, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 1, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 2, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 3, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 4, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 5, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720005241, 6, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 1, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 2, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 3, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 4, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 5, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 6, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224005242, 7, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 1, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 2, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 3, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 4, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 5, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 6, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130005243, 7, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 1, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 2, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 3, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 4, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 5, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 6, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 7, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 8, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 9, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 10, 128, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 11, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 12, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 13, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701005244, 14, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 1, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 2, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 3, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 4, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 5, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 6, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 7, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 8, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 9, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 10, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 11, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731005245, 12, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 1, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 2, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 3, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 4, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 5, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 6, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 7, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 8, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206005246, 9, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 1, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 2, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 3, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 4, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 5, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309005247, 6, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 1, 133, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 2, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 3, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 4, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 5, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 6, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 7, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 8, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 9, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 10, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 11, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 12, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 13, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 14, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 15, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 16, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 17, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 18, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126005248, 19, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 1, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 2, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 3, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 4, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 5, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 6, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 7, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521005249, 8, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 1, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 2, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 3, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 4, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 5, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 6, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 7, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 8, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307005250, 9, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 1, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 2, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 3, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 4, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 5, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 6, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 7, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 8, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101005251, 9, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 1, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 2, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 3, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 4, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 5, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 6, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 7, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110005252, 8, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 1, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 2, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 3, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 4, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 5, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 6, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 7, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 8, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 9, 158, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 10, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 11, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215005253, 12, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 1, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 2, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 3, 99, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 4, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 5, 87, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 6, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 7, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 8, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329005254, 9, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 1, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 2, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 3, 21, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 4, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 5, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 6, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706005255, 7, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 1, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 2, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 3, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 4, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 5, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 6, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 7, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 8, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 9, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 10, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 11, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 12, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 13, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 14, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 15, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 16, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625005256, 17, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 1, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 2, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 3, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 4, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 5, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 6, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 7, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 8, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 9, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 10, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 11, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 12, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126005257, 13, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719005258, 1, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719005258, 2, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719005258, 3, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719005258, 4, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 1, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 2, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 3, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 4, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 5, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 6, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 7, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 8, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 9, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 10, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 11, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 12, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 13, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 14, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 15, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 16, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 17, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606005259, 18, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 1, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 2, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 3, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 4, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 5, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316005260, 6, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 1, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 2, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 3, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 4, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 5, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 6, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 7, 158, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 8, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 9, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 10, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 11, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 12, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 13, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 14, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919005261, 15, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 1, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 2, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 3, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 4, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 5, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 6, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 7, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 8, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 9, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 10, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 4, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 5, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 6, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 7, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 8, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 9, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702004111, 10, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 1, 109, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 2, 190, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 3, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 4, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 5, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 6, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 7, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 8, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 9, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 10, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 11, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408004112, 12, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605004113, 1, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605004113, 2, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 1, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 2, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 3, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 4, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 5, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 6, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 7, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 8, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 9, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 10, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 11, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 12, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 13, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718004114, 14, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 1, 68, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 2, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 3, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 5, 92, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 6, 1, 14, 3, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203004115, 7, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 1, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 2, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 3, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 4, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 5, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 6, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 7, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 8, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 9, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 10, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 11, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 12, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 13, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 14, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130224004116, 15, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 1, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 2, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 3, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 4, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 5, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 6, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 7, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 8, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 9, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007004117, 10, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 1, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 2, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 3, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 4, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 5, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 6, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 7, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 8, 186, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 9, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 10, 138, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 11, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004118, 12, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 1, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 2, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 3, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 4, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 5, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010326004119, 6, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 1, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 2, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 3, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 4, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 5, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 6, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 7, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406004120, 8, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 1, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 2, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 3, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 4, 57, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 5, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 6, 113, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 7, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 8, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 9, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 10, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 11, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 12, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807004121, 13, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 1, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 2, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 3, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 4, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 5, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 6, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 7, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 8, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 9, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 10, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 11, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 12, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 13, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212004122, 14, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 1, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 2, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 4, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 5, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 6, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 7, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 8, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 9, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 10, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107004123, 11, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725004124, 1, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725004124, 2, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725004124, 3, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725004124, 4, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725004124, 5, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 1, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 2, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 3, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 4, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 5, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 6, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 7, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 8, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 9, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 10, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 11, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 12, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 13, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 14, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 15, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 16, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220004125, 17, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 1, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 2, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 3, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 4, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 5, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 6, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 7, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 8, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 9, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930004126, 10, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 1, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 2, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 3, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 4, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 5, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 6, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 7, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 8, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227004127, 9, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 1, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 2, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 3, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 4, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 5, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302004128, 6, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 1, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 2, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 3, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 4, 126, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 5, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 6, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050812004129, 7, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 1, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 2, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 3, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 4, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 5, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 6, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504004130, 7, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 1, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 2, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 3, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 4, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 5, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 6, 18, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 7, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 8, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 9, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 10, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 11, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809004131, 12, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122004132, 1, 143, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122004132, 2, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122004132, 3, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010122004132, 4, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 1, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 2, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 3, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 4, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 5, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 6, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 7, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 8, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 9, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 10, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624004133, 11, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 1, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 2, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 3, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 4, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 5, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 6, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 7, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921004134, 8, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 1, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 2, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 3, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 4, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 5, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 6, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 7, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 8, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 9, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 10, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 11, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 12, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 1, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 2, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 3, 171, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 4, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 5, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 7, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 8, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 9, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 10, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 11, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 12, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 13, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 14, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126004479, 15, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 1, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 2, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 3, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 4, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 5, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 6, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 7, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 8, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 9, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 10, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723004480, 11, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 1, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 2, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 3, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 4, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 5, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 6, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 7, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 8, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004481, 9, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 1, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 2, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 3, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 4, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 5, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 6, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 7, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 8, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 9, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004482, 10, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 1, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 2, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 3, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 4, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 5, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 6, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 7, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 8, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 9, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060611004483, 10, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 1, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 2, 56, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 3, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 4, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 5, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 6, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 7, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 8, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 9, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012004484, 10, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 1, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 2, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 3, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 4, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 5, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 6, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 7, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229004485, 8, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911004486, 1, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911004486, 2, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911004486, 3, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911004486, 4, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911004486, 5, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 1, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 2, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 3, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 4, 8, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 5, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 6, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 7, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 8, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 9, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 10, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070217004487, 11, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 1, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 2, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 3, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 4, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 5, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 6, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 7, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 8, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 9, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 10, 96, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 11, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 12, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228004488, 13, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 1, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 2, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 3, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 4, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 5, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 6, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 7, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227004489, 8, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 1, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 2, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 3, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 4, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 5, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 6, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428004490, 7, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 1, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 2, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 3, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 4, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 5, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 6, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 7, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 8, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 9, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 10, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 11, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 12, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 13, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311004491, 14, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 1, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 2, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 3, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 4, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 5, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 6, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 7, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 8, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 9, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 10, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 11, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 12, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 13, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 14, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 15, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918004492, 16, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 1, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 2, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 3, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 4, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 5, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 6, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 7, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 8, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 9, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 10, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 11, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 12, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 13, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110501004493, 14, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 1, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 2, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 3, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 4, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 5, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 6, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 7, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 8, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513004494, 9, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 1, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 2, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 3, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 4, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 5, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 6, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 7, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 8, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 9, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 10, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 11, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 12, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 13, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 14, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 15, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 16, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 17, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901004495, 18, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619004496, 1, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619004496, 2, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619004496, 3, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 1, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 2, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 3, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 4, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 5, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 6, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 7, 84, 5, 10, 50);
commit;
prompt 53000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 8, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 9, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070225004497, 10, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615004498, 1, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615004498, 2, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615004498, 3, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 1, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 2, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 3, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 4, 73, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 5, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 6, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213004499, 7, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 1, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 2, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 3, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 4, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 5, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 6, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 7, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 8, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 9, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 10, 78, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 11, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 12, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 13, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 14, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 15, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721004500, 16, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 1, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 2, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 3, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 4, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 5, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 6, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 7, 154, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 8, 54, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 9, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901004501, 10, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 1, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 2, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 2, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 3, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 4, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 5, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 6, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 7, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 8, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 9, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 10, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 11, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 12, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 13, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706004875, 14, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 1, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 2, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 3, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 4, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 5, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 6, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 7, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103004876, 8, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 1, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 2, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 3, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 4, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 5, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 6, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 7, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208004877, 8, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 1, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 2, 165, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 3, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 4, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 5, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 6, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 7, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 8, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 9, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 10, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 11, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 12, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 13, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731004878, 14, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 1, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 2, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 3, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 4, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 5, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213004879, 6, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 1, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 2, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 3, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 4, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 5, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 6, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 7, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 8, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101004880, 9, 119, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214004881, 1, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214004881, 2, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214004881, 3, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 1, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 2, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 3, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 4, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 5, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 6, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 7, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 8, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 9, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 10, 70, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 11, 71, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 12, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 13, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 14, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 15, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 16, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327004882, 17, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 1, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 2, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 3, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 4, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 5, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 6, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 7, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 8, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 9, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 10, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 11, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 12, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 13, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210004883, 14, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219004884, 1, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219004884, 2, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219004884, 3, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219004884, 4, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219004884, 5, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003004885, 1, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003004885, 2, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003004885, 3, 20, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003004885, 4, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003004885, 5, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 1, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 2, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 3, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 4, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 5, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212004886, 6, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 1, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 2, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 3, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 4, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 5, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 6, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 7, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 8, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 9, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 10, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 11, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 12, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080105004887, 13, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424004888, 1, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424004888, 2, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000424004888, 3, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 1, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 2, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 3, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 4, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 5, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 6, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 7, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 8, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 9, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 10, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 11, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 12, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 13, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 14, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 15, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624004889, 16, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 1, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 2, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 3, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 4, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 5, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 6, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 7, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 8, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 9, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 10, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 11, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 12, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406004890, 13, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921004891, 1, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921004891, 2, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921004891, 3, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921004891, 4, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921004891, 5, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 1, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 2, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 3, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 4, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 5, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 6, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 7, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 8, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 9, 161, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 10, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316004892, 11, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 1, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 2, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 3, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 4, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 5, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 6, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 7, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 8, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 9, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 10, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 11, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213004893, 12, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010730004894, 1, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010730004894, 2, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010730004894, 3, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 1, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 2, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 3, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 4, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 5, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 6, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 7, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 8, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 9, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 10, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 11, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 12, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 13, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323004895, 14, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426004896, 1, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426004896, 2, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426004896, 3, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 1, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 2, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 3, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 4, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 5, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021004897, 6, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624004898, 1, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624004898, 2, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000624004898, 3, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 1, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 2, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 3, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 4, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 5, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 6, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 7, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927004899, 8, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 1, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 2, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 3, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 4, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 5, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 6, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 7, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 8, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004900, 9, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 1, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 2, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 3, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 4, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 5, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 6, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 7, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 8, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 9, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920004901, 10, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 1, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 2, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 11, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 12, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 13, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205005262, 14, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 1, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 2, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 3, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 4, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 5, 160, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 6, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 7, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 8, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 9, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 10, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 11, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 12, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723005263, 13, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 1, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 2, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 3, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 4, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 5, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716005264, 6, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 1, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 2, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 3, 155, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 4, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 5, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 6, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 7, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 8, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 9, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 10, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 11, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 12, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 13, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 14, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 15, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 16, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622005265, 17, 59, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730005266, 1, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730005266, 2, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730005266, 3, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730005266, 4, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730005266, 5, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 1, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 2, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 3, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 4, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 5, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 6, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 7, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 8, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 9, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005267, 10, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 1, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 2, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 3, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 4, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 5, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 6, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 7, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 8, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 9, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 10, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224005268, 11, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 1, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 2, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 3, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 4, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 5, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 6, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 7, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 8, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 9, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 10, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 11, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 12, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 13, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 14, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924005269, 15, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 1, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 2, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 3, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 4, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 5, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318005270, 6, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101005271, 1, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101005271, 2, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101005271, 3, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101005271, 4, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 1, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 2, 183, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 3, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 4, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 5, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 6, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 7, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 8, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 9, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 10, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 11, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 12, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628005272, 13, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 1, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 2, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 3, 140, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 4, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 5, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 6, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 7, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 8, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 9, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 10, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005273, 11, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 1, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 2, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 3, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 4, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 5, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 6, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 7, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 8, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 9, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 10, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091220005274, 11, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 1, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 2, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 3, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 4, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 5, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 6, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 7, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 8, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523005275, 9, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 1, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 2, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 3, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 4, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 5, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 6, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030911005276, 7, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 1, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 2, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 3, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 4, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 5, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 6, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 7, 86, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 8, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 9, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 10, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 11, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 12, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 13, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 14, 79, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526005277, 15, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 1, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 2, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 3, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 4, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 5, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 6, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 7, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 8, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 9, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 10, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 11, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 12, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 13, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210005278, 14, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 1, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 2, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 3, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 4, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 5, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 6, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 7, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 8, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 9, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 10, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 11, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 12, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 13, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 14, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 15, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 16, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408005279, 17, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 1, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 2, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 3, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 4, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 5, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 6, 56, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 7, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 8, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 9, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 10, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 11, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 12, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303005280, 13, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 1, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 2, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 3, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 4, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 5, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 6, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 7, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 8, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 9, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 10, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 11, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 12, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 13, 106, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 14, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 15, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 16, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 17, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611005281, 18, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 1, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 2, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 3, 190, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 4, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 5, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 6, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 7, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 8, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218005282, 9, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 1, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 2, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 3, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 4, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 5, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 6, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217005283, 7, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 1, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 2, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 3, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 4, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 13, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115004135, 14, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930004136, 1, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930004136, 2, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930004136, 3, 183, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930004136, 4, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 1, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 2, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 3, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 4, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 5, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 6, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 7, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 8, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 9, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 10, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428004137, 11, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 1, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 2, 112, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 3, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 4, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 5, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 6, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 7, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 8, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 9, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 10, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 11, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 12, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 13, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 14, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 15, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122004138, 16, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 1, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 2, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 3, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 4, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 5, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 6, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 7, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 8, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 9, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 10, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623004139, 11, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 1, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 2, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 3, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 4, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 5, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 6, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 7, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 8, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 9, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122004140, 10, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 1, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 2, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 3, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 4, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 5, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 6, 160, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827004141, 7, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 1, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 2, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 3, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 4, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 5, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 6, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 7, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 8, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 9, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 10, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 11, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 12, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 13, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 14, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 15, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 16, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824004142, 17, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 1, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 2, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 3, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 4, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 5, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 6, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 7, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 8, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606004143, 9, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 1, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 2, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 3, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 4, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 5, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 6, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728004144, 7, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 1, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 2, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 3, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 4, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 5, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 6, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 7, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 8, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 9, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 10, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070323004145, 11, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 1, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 2, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 3, 23, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 4, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 5, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 6, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 7, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 8, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 9, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513004146, 10, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 1, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 2, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 3, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 4, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 5, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 6, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 7, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 8, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 9, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 10, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004147, 11, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 1, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 2, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 3, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 4, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 5, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 6, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 7, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 8, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 9, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 10, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 11, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 12, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 13, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212004148, 14, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607004149, 1, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607004149, 2, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607004149, 3, 2, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607004149, 4, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607004149, 5, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 1, 126, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 2, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 3, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 4, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 5, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 6, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 7, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 8, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 9, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 10, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 11, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 12, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313004150, 13, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826004151, 1, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826004151, 2, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826004151, 3, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826004151, 4, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826004151, 5, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 1, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 2, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 3, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 4, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 5, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 6, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706004152, 7, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 1, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 2, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 3, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 4, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 5, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907004153, 6, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 1, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 2, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 3, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 4, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 5, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 6, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 7, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108004154, 8, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 1, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 2, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 3, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 4, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 5, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 6, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 7, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 8, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 9, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 10, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 11, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 12, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 13, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 14, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516004155, 15, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 1, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 2, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 3, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 4, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 5, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 6, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615004156, 7, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 1, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 2, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 3, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 4, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 5, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 6, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 7, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 8, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118004157, 9, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 1, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 2, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 3, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 4, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 5, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 6, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 7, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 8, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 9, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 10, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 11, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 12, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214004158, 13, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 1, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 2, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 3, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 4, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 5, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 6, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 7, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 8, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413004159, 9, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009004160, 1, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009004160, 2, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 3, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 4, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 5, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 6, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 7, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 8, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 9, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 10, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 11, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 12, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317004502, 13, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 1, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 2, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 3, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 4, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 5, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 6, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921004503, 7, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 1, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 2, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 3, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 4, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 5, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 6, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 7, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705004504, 8, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 1, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 2, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 3, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 4, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 5, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731004505, 6, 170, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 1, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 2, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 3, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 4, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 5, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 6, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 7, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 8, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 9, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 10, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 11, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080115004506, 12, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 1, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 2, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 3, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 4, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 5, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 6, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 7, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 8, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 9, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 10, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 11, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 12, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 13, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 14, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 15, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721004507, 16, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 1, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 2, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 3, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 4, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 5, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 6, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 7, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 8, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 9, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 10, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 11, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 12, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 13, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 14, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 15, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826004508, 16, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 1, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 2, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 3, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 4, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 5, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 6, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 7, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 8, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 9, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 10, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 11, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 12, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 13, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 14, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 15, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 16, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224004509, 17, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 1, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 2, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 3, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 4, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 5, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 6, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415004510, 7, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 1, 41, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 2, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 3, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 4, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 5, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 6, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 7, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 8, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 9, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202004511, 10, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 1, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 2, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 3, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 4, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 5, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 6, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 7, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 8, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 9, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 10, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 11, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 12, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 13, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419004512, 14, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 1, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 2, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 3, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 4, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 5, 131, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 6, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 7, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 8, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 9, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 10, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 11, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 12, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110004513, 13, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 1, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 2, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 3, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 4, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 5, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 6, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 7, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 8, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 9, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 10, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 11, 187, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 12, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 13, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 14, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 15, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517004514, 16, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 1, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 2, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 3, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 4, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 5, 101, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 6, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 7, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 8, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 9, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 10, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004515, 11, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 1, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 2, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 3, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 4, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 5, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 6, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 7, 83, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 8, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 9, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604004516, 10, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 1, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 2, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 3, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 4, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 5, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910004517, 6, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409004518, 1, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409004518, 2, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 1, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 2, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 3, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 4, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 5, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 6, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 7, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 8, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 9, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 10, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 11, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 12, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014004519, 13, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207004520, 1, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207004520, 2, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207004520, 3, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207004520, 4, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 1, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 2, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 3, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 4, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 5, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 6, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 7, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909004521, 8, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217004522, 1, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217004522, 2, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217004522, 3, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217004522, 4, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217004522, 5, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011004523, 1, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011004523, 2, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011004523, 3, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 1, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 2, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 3, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 4, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 5, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 6, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 7, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 8, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 9, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 10, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 11, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 12, 33, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031004524, 13, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 1, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 2, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 3, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 4, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 5, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 6, 112, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 7, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 8, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 9, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 10, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 3, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 4, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 5, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 6, 54, 53, 11, 583);
commit;
prompt 54000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 7, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 8, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 9, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 10, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 11, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 12, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 13, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004902, 14, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703004903, 1, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703004903, 2, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703004903, 3, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 1, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 2, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 3, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 4, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 5, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 6, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 7, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 8, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 9, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 10, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 11, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 12, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 13, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 14, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 15, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 16, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 17, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303004904, 18, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 1, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 2, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 3, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 4, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 5, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 6, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 7, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 8, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 9, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 10, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 11, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112004905, 12, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 1, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 2, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 3, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 4, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 5, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 6, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 7, 14, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 8, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 9, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 10, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113004906, 11, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 1, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 2, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 3, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 4, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 5, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 6, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 7, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 8, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 9, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 10, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 11, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004907, 12, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 1, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 2, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 3, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 4, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 5, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 6, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 7, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 8, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 9, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 10, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006004908, 11, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 1, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 2, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 3, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 4, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 5, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 6, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 7, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212004909, 8, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 1, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 2, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 3, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 4, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 5, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 6, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 7, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 8, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 9, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 10, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070414004910, 11, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 1, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 2, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 3, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 4, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 5, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 6, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 7, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 8, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 9, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 10, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216004911, 11, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 1, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 2, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 3, 177, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 4, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 5, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 6, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 7, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 8, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 9, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 10, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009004912, 11, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 1, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 2, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 3, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 4, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 5, 61, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 6, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 7, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 8, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 9, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 10, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 11, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 12, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 13, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 14, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 15, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 16, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404004913, 17, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 1, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 2, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 3, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 4, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 5, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 6, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 7, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 8, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 9, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 10, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 11, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 12, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 13, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 14, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729004914, 15, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923004915, 1, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923004915, 2, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923004915, 3, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 1, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 2, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 3, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 4, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 5, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 6, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 7, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 8, 10, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 9, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110004916, 10, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 1, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 2, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 3, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 4, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 5, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 6, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 7, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 8, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 9, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 10, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 11, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 12, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025004917, 13, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620004918, 1, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620004918, 2, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620004918, 3, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620004918, 4, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620004918, 5, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 1, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 2, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 3, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 4, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 5, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 6, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 7, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 8, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 9, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 10, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416004919, 11, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 1, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 2, 153, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 3, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 4, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 5, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 6, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 7, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 8, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 9, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 10, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 11, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 12, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 13, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 14, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114004920, 15, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 1, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 2, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 3, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 4, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 5, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 6, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 7, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 8, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119004921, 9, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230004922, 1, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230004922, 2, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 1, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 2, 91, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 3, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 4, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 5, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 6, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 7, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 8, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 9, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004923, 10, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 1, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 2, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 3, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 4, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 5, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 6, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 7, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022004924, 8, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823004925, 1, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 5, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 6, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 7, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226005284, 8, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 1, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 2, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 3, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 4, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 5, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 6, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 7, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226005285, 8, 166, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 1, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 2, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 3, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 4, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 5, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 6, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 7, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 8, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 9, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 10, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 11, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 12, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407005286, 13, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 1, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 2, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 3, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 4, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 5, 68, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 6, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 7, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 8, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017005287, 9, 24, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 1, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 2, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 3, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 4, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 5, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 6, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 7, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 8, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 9, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517005288, 10, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 1, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 2, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 3, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 4, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 5, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 6, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113005289, 7, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 1, 30, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 2, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 3, 97, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 4, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 5, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 6, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 7, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 8, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 9, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 10, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 11, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 12, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 13, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 14, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 15, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 16, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 17, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 18, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426005290, 19, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 1, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 2, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 3, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 4, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 5, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921005291, 6, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 1, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 2, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 3, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 4, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 5, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 6, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 7, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 8, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 9, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 10, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 11, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319005292, 12, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 1, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 2, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 3, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 4, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 5, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 6, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 7, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 8, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 9, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 10, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 11, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 12, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 13, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 14, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 15, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 16, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 17, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524005293, 18, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102005294, 1, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102005294, 2, 146, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102005294, 3, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215005295, 1, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215005295, 2, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215005295, 3, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215005295, 4, 98, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215005295, 5, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 1, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 2, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 3, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 4, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 5, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219005296, 6, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 1, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 2, 92, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 3, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 4, 163, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 5, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 6, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 7, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 8, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018005297, 9, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 1, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 2, 11, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 3, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 4, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 5, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 6, 158, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 7, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 8, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 9, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 10, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 11, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 12, 28, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 13, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 14, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 15, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328005298, 16, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 1, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 2, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 3, 56, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 4, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 5, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 6, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007005299, 7, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 1, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 2, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 3, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 4, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 5, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 6, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 7, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 8, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 9, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 10, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 11, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 12, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 13, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 14, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 15, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030005300, 16, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 1, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 2, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 3, 182, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 4, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 5, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 6, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729005301, 7, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 1, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 2, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 3, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 4, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 5, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 6, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 7, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 8, 107, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 9, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918005302, 10, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 1, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 2, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 3, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 4, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 5, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 6, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 7, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 8, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 9, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 10, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112005303, 11, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 1, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 2, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 3, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 4, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 5, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 6, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 7, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 8, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 9, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 10, 96, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 11, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 12, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 13, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504005304, 14, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 1, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 2, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 3, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 4, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 5, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 6, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 7, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 8, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 9, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 10, 125, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 11, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 12, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 13, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 14, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411005305, 15, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 1, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 2, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 3, 138, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 4, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 5, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 6, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 7, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023005306, 8, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 1, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 2, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 3, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 4, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 5, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 6, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009004160, 3, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009004160, 4, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206004161, 1, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206004161, 2, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206004161, 3, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206004161, 4, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 1, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 2, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 3, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 4, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 5, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 6, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 7, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 8, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 9, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 10, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403004162, 11, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 1, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 2, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 3, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 4, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 5, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 6, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 7, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916004163, 8, 81, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 1, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 2, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 3, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 4, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 5, 154, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 6, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426004164, 7, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110004165, 1, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110004165, 2, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110004165, 3, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 1, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 2, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 3, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 4, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 5, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 6, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 7, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 8, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 9, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 10, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 11, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 12, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 13, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 14, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 15, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 16, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225004166, 17, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 1, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 2, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 3, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 4, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 5, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 6, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111004167, 7, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 1, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 2, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 3, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 4, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 5, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 6, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 7, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 8, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 9, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 10, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 11, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 12, 44, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 13, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 14, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 15, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 16, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 17, 31, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304004168, 18, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608004169, 1, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608004169, 2, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608004169, 3, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608004169, 4, 18, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608004169, 5, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 1, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 2, 128, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 3, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 4, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 5, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 6, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 7, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 8, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 9, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 10, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 11, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 12, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 13, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 14, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 15, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 16, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 17, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027004170, 18, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 1, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 2, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 3, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 4, 106, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 5, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 6, 65, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 7, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 8, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 9, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 10, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 11, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 12, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 13, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 14, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 15, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 16, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140306004171, 17, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 1, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 2, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 3, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 4, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 5, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 6, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 7, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 8, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 9, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 10, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 11, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 12, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 13, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 14, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131013004172, 15, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 1, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 2, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 3, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 4, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 5, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 6, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 7, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204004173, 8, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 1, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 2, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 3, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 4, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 5, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 6, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 7, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 8, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004004174, 9, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107004175, 1, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107004175, 2, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107004175, 3, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107004175, 4, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107004175, 5, 164, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 1, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 2, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 3, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 4, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 5, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 6, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 7, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 8, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 9, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 10, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 11, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 12, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 13, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613004176, 14, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 1, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 2, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 3, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 4, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 5, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 6, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 7, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 8, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 9, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 10, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 11, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 12, 66, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 13, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207004177, 14, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 1, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 2, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 3, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 4, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 5, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 6, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 7, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117004178, 8, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 1, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 2, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 3, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 4, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 5, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727004179, 6, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 1, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 2, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 3, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 4, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 5, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 6, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 7, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 8, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 9, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 10, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 11, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905004180, 12, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 1, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 2, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 3, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 4, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 5, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 6, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 7, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 8, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 9, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 10, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 11, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 12, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 13, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 14, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406004181, 15, 115, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 1, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 2, 24, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 3, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 4, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 5, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 6, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 7, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 8, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 9, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 10, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 11, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 12, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 13, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 14, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 15, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 11, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004004525, 12, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 1, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 2, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 3, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 4, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 5, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 6, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 7, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 8, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 9, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 10, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 11, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 12, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101003004526, 13, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 1, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 2, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 3, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 4, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 5, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 6, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 7, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 8, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 9, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 10, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 11, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512004527, 12, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 1, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 2, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 3, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 4, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 5, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 6, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 7, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 8, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 9, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 10, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004528, 11, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 1, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 2, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 3, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 4, 98, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 5, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 6, 73, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 7, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 8, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826004529, 9, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526004530, 1, 103, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526004530, 2, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526004530, 3, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526004530, 4, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526004530, 5, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 1, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 2, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 3, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 4, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 5, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 6, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 7, 88, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 8, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 9, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 10, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 11, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 12, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 13, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 14, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524004531, 15, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 1, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 2, 73, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 3, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 4, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 5, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 6, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508004532, 7, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 1, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 2, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 3, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 4, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 5, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 6, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 7, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 8, 73, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 9, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121004533, 10, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 1, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 2, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 3, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 4, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 5, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 6, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 7, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 8, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 9, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104004534, 10, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 1, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 2, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 3, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 4, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 5, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331004535, 6, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 1, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 2, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 3, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 4, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 5, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 6, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004536, 7, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 1, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 2, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 3, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 4, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 5, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 6, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 7, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 8, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 9, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 10, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 11, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621004537, 12, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 1, 70, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 2, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 3, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 4, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 5, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 6, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110004538, 7, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 1, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 2, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 3, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 4, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 5, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 6, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 7, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 8, 182, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608004539, 9, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 1, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 2, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 3, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 4, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 5, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 6, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 7, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 8, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 9, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 10, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 11, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 12, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 13, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529004540, 14, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 1, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 2, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 3, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 4, 129, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 5, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 6, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 7, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 8, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 9, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 10, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 11, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 12, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717004541, 13, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 1, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 2, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 3, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 4, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 5, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 6, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 7, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 8, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 9, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 10, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 11, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 12, 80, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 13, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 14, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220004542, 15, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 1, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 2, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 3, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 4, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 5, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 6, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 7, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 8, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 9, 163, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 10, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 11, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 12, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 13, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 14, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 15, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 16, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601004543, 17, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 1, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 2, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 3, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 4, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 5, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 6, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 7, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 8, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060411004544, 9, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125004545, 1, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125004545, 2, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125004545, 3, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609004546, 1, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609004546, 2, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609004546, 3, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 1, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 2, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 3, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 4, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 5, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213004547, 6, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 1, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 2, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 3, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 4, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 5, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 6, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 7, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 8, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 9, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 10, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 11, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 12, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 13, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218004548, 14, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 1, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 2, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 3, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 4, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 5, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 6, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 7, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 8, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 9, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 10, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823004925, 2, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823004925, 3, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823004925, 4, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 1, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 2, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 3, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 4, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 5, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 6, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 7, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 8, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906004926, 9, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004927, 1, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004927, 2, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004927, 3, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004927, 4, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101004927, 5, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004928, 1, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004928, 2, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004928, 3, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124004928, 4, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 1, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 2, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 3, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 4, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 5, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 6, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030829004929, 7, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 1, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 2, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 3, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 4, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 5, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 6, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 7, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 8, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 9, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 10, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918004930, 11, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 1, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 2, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 3, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 4, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 5, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 6, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 7, 137, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 8, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 9, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 10, 56, 18, 13, 234);
commit;
prompt 55000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307004931, 11, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 1, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 2, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 3, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 4, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 5, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 6, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 7, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 8, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004932, 9, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903004933, 1, 131, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903004933, 2, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903004933, 3, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903004933, 4, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 1, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 2, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 3, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 4, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 5, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629004934, 6, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 1, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 2, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 3, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 4, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 5, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 6, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 7, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 8, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 9, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220004935, 10, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 1, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 2, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 3, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 4, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 5, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 6, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 7, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 8, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 9, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 10, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 11, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 12, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 13, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 14, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415004936, 15, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 1, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 2, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 3, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 4, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 5, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 6, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 7, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 8, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 9, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602004937, 10, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 1, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 2, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 3, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 4, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 5, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 6, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 7, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 8, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 9, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 10, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 11, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 12, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 13, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112004938, 14, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 1, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 2, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 3, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 4, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 5, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 6, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 7, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 8, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420004939, 9, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 1, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 2, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 3, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 4, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 5, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 7, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 8, 168, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 9, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 10, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502004940, 11, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 1, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 2, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 3, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 4, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 5, 135, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 6, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 7, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821004941, 8, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 1, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 2, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 3, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 4, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 5, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 6, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 7, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 8, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214004942, 9, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 1, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 2, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 3, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 4, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 5, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 6, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 7, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 8, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 9, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008004943, 10, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 1, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 2, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 3, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 4, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 5, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 6, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 7, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 8, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 9, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 10, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 11, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 12, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 13, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 14, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 15, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 16, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514004944, 17, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 1, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 2, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 3, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 4, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 5, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 6, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 7, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 8, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061022004945, 9, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 1, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 2, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 3, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 4, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 5, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 6, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025004946, 7, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 1, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 2, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 3, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 4, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 5, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 6, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 7, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 8, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 9, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 10, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 11, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 12, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 13, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 14, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 15, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 16, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624004947, 17, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 1, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 2, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 3, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 4, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 5, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 6, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 7, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 8, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 9, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 10, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 11, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 12, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004948, 13, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 1, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 2, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 3, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 4, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 5, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 6, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 7, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 8, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 9, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 10, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123005307, 7, 64, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 1, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 2, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 3, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 4, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 5, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 6, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 7, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 8, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 9, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 10, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715005308, 11, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 1, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 2, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 3, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 4, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 5, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123005309, 6, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 1, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 2, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 3, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 4, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 5, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905005310, 6, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 1, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 2, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 3, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 4, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 5, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 6, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 7, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 8, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 9, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 10, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 11, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005311, 12, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 1, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 2, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 3, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 4, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 5, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 6, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 7, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 8, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 9, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 10, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616005312, 11, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 1, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 2, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 3, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 4, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 5, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 6, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 7, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 8, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 9, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 10, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 11, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 12, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120005313, 13, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 1, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 2, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 3, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 4, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 5, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 6, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 7, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 8, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 9, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 10, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112005314, 11, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 1, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 2, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 3, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 4, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 5, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 6, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 7, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 8, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071016005315, 9, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 1, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 2, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 3, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 4, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 5, 169, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 6, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 7, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 8, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 9, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 10, 52, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 11, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 12, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 13, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 14, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421005316, 15, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 1, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 2, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 3, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 4, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 5, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120005317, 6, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 1, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 2, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 3, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 4, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 5, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 6, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 7, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 8, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 9, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105005318, 10, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005319, 1, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005319, 2, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005319, 3, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005319, 4, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005319, 5, 186, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030005320, 1, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030005320, 2, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 1, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 2, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 3, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 4, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 5, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 6, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 7, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 8, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 9, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 10, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 11, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 12, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 13, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 14, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 15, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 16, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601005321, 17, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 1, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 2, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 3, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 4, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 5, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 6, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 7, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005322, 8, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 1, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 2, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 3, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 4, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 5, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 6, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 7, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 8, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 9, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 10, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 11, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 12, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 13, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 14, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619005323, 15, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 1, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 2, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 3, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 4, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 5, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 6, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 7, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 8, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 9, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 10, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 11, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 12, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 13, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 14, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108005324, 15, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 1, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 2, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 3, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 4, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 5, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 6, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 7, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 8, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 9, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 10, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 11, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424005325, 12, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 1, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 2, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 3, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 4, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 5, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 6, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 7, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 8, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 9, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404005326, 10, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 1, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 2, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 3, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 4, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 5, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 6, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 7, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011005327, 8, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 1, 192, 17, 18, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 2, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 3, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 4, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 5, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003005328, 6, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 1, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 2, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 3, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 4, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 5, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 6, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 7, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 8, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060610005329, 9, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107005330, 1, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107005330, 2, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107005330, 3, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230005331, 1, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230005331, 2, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230005331, 3, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230005331, 4, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230005331, 5, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 1, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 2, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 3, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 4, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 5, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 6, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 7, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 8, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 9, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 10, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 11, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 12, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 13, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 16, 141, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106004182, 17, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 1, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 2, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 3, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 4, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 5, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 6, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 7, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 8, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420004183, 9, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 1, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 2, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 3, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 4, 91, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 5, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 6, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 7, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 8, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 9, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 10, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 11, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 12, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 13, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 14, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225004184, 15, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 1, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 2, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 3, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 4, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 5, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 6, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 7, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914004185, 8, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 1, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 2, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 3, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 4, 119, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 5, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 6, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 7, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303004186, 8, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 1, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 2, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 3, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 4, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 5, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 6, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 7, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 8, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 9, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 10, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 11, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 12, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328004187, 13, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 1, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 2, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 3, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 4, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 5, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805004188, 6, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 1, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 2, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 3, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 4, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 5, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 6, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 7, 71, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 8, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803004189, 9, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 1, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 2, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 3, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 4, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 5, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 6, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 7, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 8, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 9, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 10, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 11, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020004190, 12, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 1, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 2, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 3, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 4, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 5, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 6, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 7, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 8, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 9, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 10, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 11, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 12, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 13, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 14, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111004191, 15, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 1, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 2, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 3, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 4, 27, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 5, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 6, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 7, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 8, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 9, 47, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 10, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611004192, 11, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 1, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 2, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 3, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 4, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 5, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 6, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 7, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 8, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 9, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 10, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 11, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 12, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202004193, 13, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 1, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 2, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 3, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 4, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 5, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 6, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427004194, 7, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 1, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 2, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 3, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 4, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 5, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 6, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 7, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 8, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 9, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627004195, 10, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 1, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 2, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 3, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 4, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 5, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 6, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 7, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 8, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 9, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 10, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 11, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 12, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127004196, 13, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 1, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 2, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 3, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 4, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 5, 187, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 6, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 7, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 8, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 9, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 10, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 11, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 12, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080618004197, 13, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004198, 1, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004198, 2, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004198, 3, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217004198, 4, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 1, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 2, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 3, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 4, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 5, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 6, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603004199, 7, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 1, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 2, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 3, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 4, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 5, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408004200, 6, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 1, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 2, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 3, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 4, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 5, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 6, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 7, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 8, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 9, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 10, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 11, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 12, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 13, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 14, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 15, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 16, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207004201, 17, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 1, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 2, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 3, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 4, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 5, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 6, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508004202, 7, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 1, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 2, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 3, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 4, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 5, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 6, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214004203, 7, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 1, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 2, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 3, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 4, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 5, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 6, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 7, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325004204, 8, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 1, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 2, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 3, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 4, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 5, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 6, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003004205, 7, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 1, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 2, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 3, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 4, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 5, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 6, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 7, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 8, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 9, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 10, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 11, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 12, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 11, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 12, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 13, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 14, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 15, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 16, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821004549, 17, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 1, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 2, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 3, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 4, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 5, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 6, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 7, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 8, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 9, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 10, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607004550, 11, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 1, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 2, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 3, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 4, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 5, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 6, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 7, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 8, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 9, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110004551, 10, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 1, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 2, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 3, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 4, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 5, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 6, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 7, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 8, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 9, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 10, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 11, 6, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 12, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 13, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 14, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 15, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 16, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 17, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108004552, 18, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 1, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 2, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 3, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 4, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 5, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 6, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 7, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 8, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 9, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 10, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 11, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 12, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311004553, 13, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 1, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 2, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 3, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 4, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 5, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 6, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 7, 150, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 8, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 9, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 10, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 11, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080323004554, 12, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 1, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 2, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 3, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 4, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 5, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 6, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 7, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 8, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 9, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060503004555, 10, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704004556, 1, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704004556, 2, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704004556, 3, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 1, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 2, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 3, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 4, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 5, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 6, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 7, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 8, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 9, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229004557, 10, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 1, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 2, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 3, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 4, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 5, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 6, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430004558, 7, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702004559, 1, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702004559, 2, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702004559, 3, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702004559, 4, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702004559, 5, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 1, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 2, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 3, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 4, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 5, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 6, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 7, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 8, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 9, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 10, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 11, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425004560, 12, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 1, 180, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 2, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 3, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 4, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 5, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 6, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 7, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 8, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 9, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 10, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 11, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 12, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306004561, 13, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 1, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 2, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 3, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 4, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 5, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 6, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 7, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 8, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 9, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 10, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 11, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507004562, 12, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 1, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 2, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 3, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 4, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 5, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 6, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 7, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503004563, 8, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 1, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 2, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 3, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 4, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 5, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 6, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 7, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 8, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 9, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 10, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 11, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 12, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 13, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100517004564, 14, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 1, 90, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 2, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 3, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 4, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 5, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 6, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 7, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 8, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 9, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 10, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 11, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 12, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 13, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 14, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915004565, 15, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 1, 173, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 2, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 3, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 4, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 5, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427004566, 6, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 1, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 2, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 3, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 4, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 5, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 6, 14, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 7, 5, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623004567, 8, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 1, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 2, 141, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 3, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 4, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 5, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116004568, 6, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 1, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 2, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 3, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 4, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 5, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 6, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 7, 22, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 8, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 9, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 10, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 11, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 12, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 13, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 14, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 15, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202004569, 16, 163, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 1, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 2, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 3, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 4, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 5, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 6, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 7, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 8, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 9, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814004570, 10, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 1, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 2, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 3, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 4, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 5, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223004571, 6, 85, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 1, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 2, 188, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 3, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 4, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 5, 126, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 6, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 11, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 12, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 13, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 14, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111004949, 15, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922004950, 1, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922004950, 2, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922004950, 3, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922004950, 4, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922004950, 5, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 1, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 2, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 3, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 4, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 5, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 6, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 7, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 8, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 9, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 10, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 11, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 12, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408004951, 13, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004952, 1, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004952, 2, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004952, 3, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004952, 4, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211004952, 5, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 1, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 2, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 3, 65, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 4, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 5, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 6, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 7, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 8, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 9, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 10, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 11, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 12, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 13, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221004953, 14, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009004954, 1, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009004954, 2, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009004954, 3, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009004954, 4, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009004954, 5, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 1, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 2, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 3, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 4, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 5, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 6, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 7, 72, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 8, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 9, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 10, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825004955, 11, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 1, 110, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 2, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 3, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 4, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 5, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 6, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 7, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 8, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305004956, 9, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 1, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 2, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 3, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 4, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 5, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 6, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 7, 118, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 8, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 9, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 10, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505004957, 11, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 1, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 2, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 3, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 4, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 5, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 6, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 7, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 8, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526004958, 9, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714004959, 1, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714004959, 2, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714004959, 3, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 1, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 2, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 3, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 4, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 5, 61, 43, 11, 473);
commit;
prompt 56000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 6, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 7, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 8, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219004960, 9, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 1, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 2, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 3, 79, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 4, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 5, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 6, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 7, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 8, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 9, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 10, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 11, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 12, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 13, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 14, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 15, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 16, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125004961, 17, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 1, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 2, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 3, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 4, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 5, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 6, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112004962, 7, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 1, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 2, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 3, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 5, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 6, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 7, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 8, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 9, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524004963, 10, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220004964, 1, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220004964, 2, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220004964, 3, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 1, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 2, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 3, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 4, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 5, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 6, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 7, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 8, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 9, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 10, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 11, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 12, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 13, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 14, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 15, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 16, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 17, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117004965, 18, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 1, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 2, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 3, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 4, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 5, 38, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 6, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 7, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 8, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 9, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 10, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806004966, 11, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004967, 1, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004967, 2, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004967, 3, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004967, 4, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916004967, 5, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815004968, 1, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815004968, 2, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000815004968, 3, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 1, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 2, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 3, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 4, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 5, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 6, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 7, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 8, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 9, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 10, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 11, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 12, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 13, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 14, 162, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 15, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120004969, 16, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 1, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 2, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 3, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 4, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 5, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 6, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 7, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 8, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 9, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006004970, 10, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 1, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 2, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 3, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 4, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 5, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 6, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 7, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 8, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 9, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 10, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 11, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 12, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 13, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 14, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603004971, 15, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 1, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 2, 49, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 3, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 4, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 5, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 6, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 7, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 8, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 9, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 10, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123004972, 11, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 1, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 2, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 3, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 4, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 5, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 6, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 7, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 8, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 9, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123004973, 10, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 1, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 2, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 3, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709004974, 4, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 14, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005332, 15, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005333, 1, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005333, 2, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005333, 3, 73, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005333, 4, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005333, 5, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 1, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 2, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 3, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 4, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 5, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 6, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 7, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 8, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 9, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 10, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 11, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 12, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626005334, 13, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 1, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 2, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 3, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 4, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 5, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 6, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 7, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 9, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 10, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 11, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 12, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 13, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 14, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214005335, 15, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 1, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 2, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 3, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 4, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 5, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 6, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 7, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 8, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 9, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 10, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816005336, 11, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 1, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 2, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 3, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 4, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 5, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 6, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213005337, 7, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005338, 1, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005338, 2, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005338, 3, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005338, 4, 93, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901005338, 5, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 1, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 2, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 3, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 4, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 5, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 6, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 7, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 8, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 9, 154, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 10, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 11, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 12, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 13, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 14, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 15, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 16, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922005339, 17, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 1, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 2, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 3, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 4, 141, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 5, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 6, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 7, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 8, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 9, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 10, 63, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 11, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 12, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209005340, 13, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 1, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 2, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 3, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 4, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 5, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 6, 174, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 7, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 8, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 9, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505005341, 10, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 1, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 2, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 3, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 4, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 5, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802005342, 6, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 1, 97, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 2, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 3, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 4, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 5, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 6, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 7, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 8, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 9, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 10, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 11, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 12, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 13, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 14, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 15, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515005343, 16, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 1, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 2, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 3, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 4, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 5, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 6, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 7, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 8, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 9, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 10, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 11, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 12, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 13, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821005344, 14, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 1, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 2, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 3, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 4, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 5, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 6, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 7, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 8, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 9, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 10, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 11, 25, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910005345, 12, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 1, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 2, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 3, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 4, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 5, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 6, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 7, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 8, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 9, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 10, 65, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 11, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314005346, 12, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 1, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 2, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 3, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 4, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 5, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 6, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 7, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 8, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 9, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503005347, 10, 63, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 1, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 2, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 4, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 5, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 6, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 7, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 8, 67, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 9, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 10, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 11, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 12, 148, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 13, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 14, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726005348, 15, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 1, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 2, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 3, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 4, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 5, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 6, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 7, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 8, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 9, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 10, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320005349, 11, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 1, 65, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 2, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 3, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 4, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 5, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 6, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 7, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 8, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 9, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080203005350, 10, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 1, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 2, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 3, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 4, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 5, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 6, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 7, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 8, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 9, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 10, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 11, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 12, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 13, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907005351, 14, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 1, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 2, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 3, 43, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 4, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 5, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 6, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 7, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209005352, 8, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 1, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 2, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 3, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 4, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 5, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 6, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218005353, 7, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 1, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 2, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 3, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 4, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 5, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427005354, 6, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 13, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 14, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031004206, 15, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 1, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 2, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 3, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 4, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 5, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 6, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 7, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 8, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 9, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 10, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 11, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 12, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 13, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 14, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 15, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 16, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 17, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211004207, 18, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 1, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 2, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 3, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 4, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 5, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 6, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 7, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 8, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 9, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 10, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 11, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 12, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101004208, 13, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 1, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 2, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 3, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 4, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 5, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 6, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 7, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 8, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060510004209, 9, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 1, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 2, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 3, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 4, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 5, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 6, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 7, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 8, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 9, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 10, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906004210, 11, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004211, 1, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004211, 2, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004211, 3, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004211, 4, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426004211, 5, 138, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 1, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 2, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 3, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 4, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 5, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 6, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 7, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 8, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 9, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 10, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 11, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 12, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 13, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115004212, 14, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 1, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 2, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 3, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 4, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 5, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 6, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 7, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040523004213, 8, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 1, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 2, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 3, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 4, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 5, 157, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 6, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 7, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 8, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 9, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 10, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 11, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 12, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 13, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 14, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 15, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708004214, 16, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 1, 101, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 2, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 3, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 4, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 5, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 6, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 7, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 8, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 9, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 10, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 11, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 12, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506004215, 13, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 1, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 2, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 3, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 4, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 5, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 6, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928004216, 7, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 1, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 2, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 3, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 4, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 5, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 6, 21, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 7, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 8, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 9, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 10, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 11, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 12, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508004217, 13, 147, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 1, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 2, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 3, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 4, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 5, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 6, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 7, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 8, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 9, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 10, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 11, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 12, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 13, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 14, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 15, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527004218, 16, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 1, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 2, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 3, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 4, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 5, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 6, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 7, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 8, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822004219, 9, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 1, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 2, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 3, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 4, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 5, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 6, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 7, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 8, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 9, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 10, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726004220, 11, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 1, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 2, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 3, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 4, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 5, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 6, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 7, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 8, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 9, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815004221, 10, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 1, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 2, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 3, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 4, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 5, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 6, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 7, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 8, 187, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915004222, 9, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 1, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 2, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 3, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 4, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 5, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 6, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 7, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 8, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 9, 158, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 10, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 11, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315004223, 12, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 1, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 2, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 3, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 4, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 5, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 6, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 7, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 8, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 9, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 10, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312004224, 11, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 1, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 2, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 3, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 4, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 5, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 6, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 7, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 8, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 9, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 10, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 11, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 12, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 13, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009004225, 14, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 1, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 2, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 3, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 4, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 5, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 6, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309004226, 7, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 1, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 2, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 3, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 4, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 5, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 6, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 7, 137, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 8, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 9, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727004227, 10, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 7, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 8, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 9, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 10, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 11, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 12, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 13, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 14, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 15, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402004572, 16, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 1, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 2, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 3, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 4, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 5, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 6, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 7, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 8, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 9, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 10, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 11, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718004573, 12, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120004574, 1, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120004574, 2, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120004574, 3, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120004574, 4, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120004574, 5, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 1, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 2, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 3, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 4, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 5, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 6, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 7, 140, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 8, 40, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 9, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 10, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 11, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 12, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 13, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 14, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230004575, 15, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 1, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 2, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 3, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 4, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 5, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 6, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 7, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 8, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 9, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 10, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 11, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 12, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423004576, 13, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 1, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 2, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 3, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 4, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 5, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 6, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 7, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 8, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014004577, 9, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202004578, 1, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202004578, 2, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202004578, 3, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 1, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 2, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 3, 12, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 4, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 5, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 6, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 7, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614004579, 8, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 1, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 2, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 3, 76, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 4, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 5, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 6, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 7, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 8, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040221004580, 9, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 1, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 2, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 3, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 4, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 5, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 6, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 7, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 8, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 9, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 10, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907004581, 11, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 1, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 2, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 3, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 4, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 5, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 6, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203004582, 7, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 1, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 2, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 3, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 4, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 5, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 6, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 7, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 8, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 9, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 10, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 11, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 12, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 13, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 14, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121025004583, 15, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706004584, 1, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706004584, 2, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706004584, 3, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706004584, 4, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706004584, 5, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 1, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 2, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 3, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 4, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 5, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 6, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 7, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 8, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 9, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 10, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903004585, 11, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 1, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 2, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 3, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 4, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 5, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 6, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 7, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 8, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 9, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 10, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 11, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 12, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101004586, 13, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 1, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 2, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 3, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 4, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 5, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 6, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 7, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 8, 80, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 9, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 10, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 11, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412004587, 12, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 1, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 2, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 3, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 4, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 5, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 6, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 7, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 8, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 9, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 10, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 11, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 12, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 13, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 14, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 15, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 16, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131002004588, 17, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 1, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 2, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 3, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 4, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 5, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 6, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 7, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 8, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 9, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 10, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 11, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 12, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021004589, 13, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 1, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 2, 145, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 3, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 4, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 5, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 6, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 7, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 8, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 9, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 10, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 11, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 12, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 13, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 14, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 15, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 16, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 17, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727004590, 18, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 1, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 2, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 3, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 4, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 5, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 6, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 7, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 8, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 9, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060821004591, 10, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621004592, 1, 145, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621004592, 2, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621004592, 3, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621004592, 4, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 1, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 2, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 3, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 4, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 5, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725004593, 6, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 1, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 2, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 3, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 4, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 5, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 6, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 7, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 8, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 9, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215004594, 10, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605004595, 1, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605004595, 2, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605004595, 3, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 12, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 13, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 14, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 1, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 2, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 3, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 4, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 5, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 6, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 7, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 8, 70, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 9, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 10, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022006122, 11, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 1, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 2, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 3, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 4, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 5, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 6, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006123, 7, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 1, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 2, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 3, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 4, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 5, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505006124, 6, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 1, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 2, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 3, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 4, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 5, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 6, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 7, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 8, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 9, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315006125, 10, 168, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 1, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 2, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 3, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 4, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 5, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 6, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 7, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 8, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 9, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 10, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 11, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 12, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006126, 13, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422006127, 1, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422006127, 2, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422006127, 3, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422006127, 4, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422006127, 5, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 1, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 2, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 3, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 4, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 5, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 6, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 7, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 8, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 9, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 10, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 11, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 12, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 13, 102, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 14, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901006128, 15, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 1, 166, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 2, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 3, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 4, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 5, 131, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 6, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 7, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216006129, 8, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 1, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 2, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 3, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 4, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 5, 179, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 6, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030713006130, 7, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 1, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 2, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 3, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 4, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 5, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 6, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623006131, 7, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 1, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 2, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 3, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 4, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 5, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 6, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 7, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 8, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 9, 85, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 10, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 11, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 12, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 13, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006132, 14, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 1, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 2, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 3, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 4, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 5, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 6, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 7, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 8, 44, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217006133, 9, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 1, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 2, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 3, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 4, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 5, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 6, 192, 94, 18, 1692);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 7, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 8, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407006134, 9, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006135, 1, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006135, 2, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006135, 3, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 1, 42, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 2, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 3, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 4, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 5, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 6, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 7, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 8, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 9, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 10, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 11, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 12, 59, 11, 9, 99);
commit;
prompt 57000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 13, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006136, 14, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006137, 1, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006137, 2, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006137, 3, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 1, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 2, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 3, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 4, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 5, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 6, 110, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 7, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 8, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 9, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 10, 25, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110006138, 11, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907006139, 1, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907006139, 2, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907006139, 3, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907006139, 4, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907006139, 5, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 1, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 2, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 3, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 4, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 5, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 6, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 7, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717006140, 8, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 1, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 2, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 3, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 4, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 5, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 6, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 7, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 8, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 9, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060206006141, 10, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 1, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 2, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 3, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 4, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 5, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 6, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 7, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 8, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 9, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515006142, 10, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 1, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 2, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 3, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 4, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 5, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 6, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 7, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 8, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 9, 67, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 10, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 11, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 12, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330006143, 13, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115006144, 1, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115006144, 2, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115006144, 3, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115006144, 4, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115006144, 5, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507006145, 1, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507006145, 2, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507006145, 3, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507006145, 4, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507006145, 5, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 1, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 2, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 3, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 4, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 5, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 6, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 7, 124, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 8, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 9, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 10, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 11, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706006146, 12, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122006147, 1, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122006147, 2, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122006147, 3, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122006147, 4, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 1, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 2, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 3, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 4, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 5, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 6, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 7, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 8, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 9, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 10, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 11, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 12, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918006502, 3, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918006502, 4, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 1, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 2, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 3, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 4, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 5, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 6, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 7, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 8, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 9, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328006503, 10, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021006504, 1, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021006504, 2, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021006504, 3, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021006504, 4, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909006505, 1, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909006505, 2, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000909006505, 3, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 1, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 2, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 3, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 4, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 5, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 6, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 7, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 8, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 9, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 10, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725006506, 11, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207006507, 1, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207006507, 2, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 1, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 2, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 3, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 4, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 5, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 6, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 7, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 8, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 9, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 10, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 11, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 12, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616006508, 13, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 1, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 2, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 3, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 4, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 5, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 6, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 7, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 8, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 9, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 10, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 11, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 12, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 13, 97, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 14, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 15, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 16, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911006509, 17, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 1, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 2, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 3, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 4, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 5, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 6, 80, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 7, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 8, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 9, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 10, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 11, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 12, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 13, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 14, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 15, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926006510, 16, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 1, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 2, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 3, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 4, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 5, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006511, 6, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 1, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 2, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 3, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 4, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 5, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 6, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 7, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 8, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 9, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 10, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 11, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091127006512, 12, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 1, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 2, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 4, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 5, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 6, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130006513, 7, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 1, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 2, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 3, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 4, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 5, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 6, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 7, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 8, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 9, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 10, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 11, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 12, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006514, 13, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 1, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 2, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 3, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 4, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 5, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416006515, 6, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 1, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 2, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 3, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 4, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 5, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 6, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 7, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006516, 8, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 1, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 2, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 3, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 4, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 5, 126, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 6, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 7, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 8, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121006517, 9, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 1, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 2, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 3, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 4, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 5, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 6, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026006518, 7, 35, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 1, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 2, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 3, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 4, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 5, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 6, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 7, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210006519, 8, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 1, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 2, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 3, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 4, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 5, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 6, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 7, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 8, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501006520, 9, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 1, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 2, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 3, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 4, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 5, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 6, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 7, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 8, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 9, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 10, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 11, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 12, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 13, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504006521, 14, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 1, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 2, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 3, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 4, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 5, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 6, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 7, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 8, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006522, 9, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123006523, 1, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123006523, 2, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123006523, 3, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 1, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 2, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 3, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 4, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 5, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 6, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 7, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 8, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 9, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 10, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116006524, 11, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 1, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 2, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 3, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 4, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 5, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 6, 71, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 7, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 8, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 9, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 10, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822006525, 11, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 1, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 2, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 3, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 4, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 5, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 6, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 7, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006526, 8, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716006527, 1, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716006527, 2, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 1, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 2, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 3, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 4, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 5, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 6, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 7, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 8, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 9, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 10, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 11, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 12, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 13, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 14, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 15, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109006528, 16, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 1, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 2, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 11, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 1, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 2, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 3, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 4, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 5, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 6, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 7, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 8, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 9, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 10, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 11, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 12, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831006875, 13, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 1, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 2, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 3, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 4, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 5, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 6, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 7, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 8, 106, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 9, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 10, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 11, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 12, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 13, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 14, 164, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821006876, 15, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 1, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 2, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 3, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 4, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 5, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 6, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 7, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423006877, 8, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 1, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 2, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 3, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 4, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 5, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 6, 104, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 7, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 8, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 9, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415006878, 10, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 1, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 2, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 3, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 4, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 5, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 6, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 7, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 8, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 9, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 10, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 11, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 12, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 13, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 14, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001006879, 15, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 1, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 2, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 3, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 4, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 5, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 6, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 7, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 8, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 9, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 10, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 11, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 12, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 13, 79, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 14, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106006880, 15, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 1, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 2, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 3, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 4, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 5, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007006881, 6, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 1, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 2, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 3, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 4, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 5, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 6, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030810006882, 7, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119006883, 1, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119006883, 2, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119006883, 3, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119006883, 4, 115, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119006883, 5, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 1, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 2, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 3, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 4, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 5, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 6, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 7, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 8, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 9, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 10, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 11, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 12, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 13, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 14, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120006884, 15, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211006885, 1, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211006885, 2, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211006885, 3, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001211006885, 4, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917006886, 1, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917006886, 2, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917006886, 3, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917006886, 4, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917006886, 5, 165, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228006887, 1, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228006887, 2, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 1, 110, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 2, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 3, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 4, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 5, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 6, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 7, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 8, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 9, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 10, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 11, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 12, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 13, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100302006888, 14, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 1, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 2, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 3, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 4, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 5, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 6, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 7, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 8, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 9, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 10, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707006889, 11, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006890, 1, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006890, 2, 192, 22, 18, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006890, 3, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006890, 4, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006890, 5, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 1, 111, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 2, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 3, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 4, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 5, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 6, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 7, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 8, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121006891, 9, 110, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 1, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 2, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 3, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 4, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 5, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 6, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924006892, 7, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 1, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 2, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 3, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 4, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 5, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 6, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 7, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 8, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 9, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 10, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 11, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 12, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 13, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 14, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 15, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 16, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206006893, 17, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 1, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 2, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 3, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 4, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 5, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 6, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 7, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 8, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 9, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 10, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006894, 11, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011218006895, 1, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011218006895, 2, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011218006895, 3, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 1, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 2, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 3, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 4, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 5, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 6, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 7, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 8, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 9, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006896, 10, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 1, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 2, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 3, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 4, 124, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 6, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 7, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 8, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 9, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 10, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 11, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 12, 62, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426006897, 13, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 1, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 2, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 3, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 4, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 5, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 6, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 7, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 8, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322006898, 9, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 1, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 2, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 3, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 4, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 5, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 6, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 7, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 8, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 9, 179, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 8, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 9, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 10, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 1, 43, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 2, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 3, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 4, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 5, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 6, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 7, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 8, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 9, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 10, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 11, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 12, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725005731, 13, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010509005732, 1, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010509005732, 2, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010509005732, 3, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010509005732, 4, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521005733, 1, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521005733, 2, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521005733, 3, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521005733, 4, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521005733, 5, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203005734, 1, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203005734, 2, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 1, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 2, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 3, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 4, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 5, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 6, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 7, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 8, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 9, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 10, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 11, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 12, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 13, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 14, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204005735, 15, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 1, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 2, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 3, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 4, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 5, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 6, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 7, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 8, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 9, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 10, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312005736, 11, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706005737, 1, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706005737, 2, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706005737, 3, 84, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706005737, 4, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 1, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 2, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 3, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 4, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 5, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 6, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 7, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826005738, 8, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426005739, 1, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426005739, 2, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426005739, 3, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426005739, 4, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426005739, 5, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 1, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 2, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 3, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 4, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 5, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 6, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 7, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 8, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 9, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313005740, 10, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 1, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 2, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 3, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 4, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 5, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 6, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 7, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 8, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 9, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215005741, 10, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 1, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 2, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 3, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 4, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 5, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 6, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 7, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201005742, 8, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 1, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 2, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 3, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 4, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 5, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 6, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 7, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 8, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 9, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 10, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 11, 17, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080724005743, 12, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005744, 1, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005744, 2, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005744, 3, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005744, 4, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616005744, 5, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 1, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 2, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 3, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 4, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 5, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 6, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 7, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215005745, 8, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 1, 168, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 2, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 3, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 4, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 5, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 6, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 7, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 8, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 9, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005746, 10, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 1, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 2, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 3, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 4, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 5, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 6, 39, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 7, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 8, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 9, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 10, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 11, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 12, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 13, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 14, 183, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224005747, 15, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 1, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 2, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 3, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 4, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 5, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 6, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 7, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 8, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 9, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005748, 10, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 1, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 2, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 3, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 4, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 5, 149, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 6, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 7, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 8, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 9, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 10, 79, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 11, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917005749, 12, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 1, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 2, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 3, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 4, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 5, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 6, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 7, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 8, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 9, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204005750, 10, 83, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728005751, 1, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728005751, 2, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728005751, 3, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728005751, 4, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728005751, 5, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 1, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 2, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 3, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 4, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 5, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 6, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005752, 7, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805005753, 1, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805005753, 2, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805005753, 3, 75, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805005753, 4, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 1, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 2, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 3, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 4, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 5, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 6, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 7, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 8, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 9, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 10, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 11, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507005754, 12, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 1, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 2, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 3, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 4, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 5, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 6, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 7, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409005755, 8, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 1, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 2, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 3, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 4, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 5, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 6, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 7, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 8, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 9, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 10, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 11, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 12, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 13, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 14, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418005756, 15, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 1, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 2, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 3, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 4, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 5, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 6, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 7, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 8, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 13, 121, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508006148, 14, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 1, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 2, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 3, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 4, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 5, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 6, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 7, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229006149, 8, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 1, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 2, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 3, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 4, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 5, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006150, 6, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 1, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 2, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 3, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 4, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 5, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 6, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 7, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216006151, 8, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 1, 182, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 2, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 3, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 4, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 5, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 6, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051122006152, 7, 109, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707006153, 1, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707006153, 2, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707006153, 3, 52, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707006153, 4, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020707006153, 5, 31, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 1, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 2, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 3, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 4, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 5, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316006154, 6, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 1, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 2, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 3, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 4, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 5, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 6, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 7, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 8, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 9, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614006155, 10, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 1, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 3, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 4, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 5, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 6, 137, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 7, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 8, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 9, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 10, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 11, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 12, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 13, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 14, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 15, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 16, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 17, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331006156, 18, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 1, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 2, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 3, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 4, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 5, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 6, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 7, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 8, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 9, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 10, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 11, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 12, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 13, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 14, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 15, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230006157, 16, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 1, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 2, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 3, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 4, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 5, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 6, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 7, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 8, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 9, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 10, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613006158, 11, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 1, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 2, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 3, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 4, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 5, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 6, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 7, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 8, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907006159, 9, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 1, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 2, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 3, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 4, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 5, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 6, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006160, 7, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 1, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 2, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 3, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 4, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 5, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 6, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 7, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609006161, 8, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 1, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 2, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 3, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 4, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 5, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513006162, 6, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 1, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 2, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 3, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 4, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 5, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 6, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116006163, 7, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408006164, 1, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408006164, 2, 117, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408006164, 3, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 1, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 2, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 3, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 4, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 5, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 6, 60, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 7, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 8, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 9, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 10, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 11, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 12, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 13, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920006165, 14, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 1, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 2, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 3, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 4, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 5, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 6, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 7, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 8, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422006166, 9, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 1, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 2, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 3, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 4, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 5, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 6, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 7, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 8, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 9, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428006167, 10, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 1, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 2, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 3, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 4, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 5, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 6, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 7, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 8, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 9, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 10, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 11, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 12, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 13, 36, 100, 7, 700);
commit;
prompt 58000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 14, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108006168, 15, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 1, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 2, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 3, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 4, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 5, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 6, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 7, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 8, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 9, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 10, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 11, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 12, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 13, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 14, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 15, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418006169, 16, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 1, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 2, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 3, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 4, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 5, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 6, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 7, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 8, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 9, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 10, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 11, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006170, 12, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 1, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 2, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 3, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 4, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 5, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 6, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 7, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 8, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 9, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 10, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 11, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 12, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 13, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403006171, 14, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 1, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 2, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 3, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 4, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 5, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 6, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 7, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930006172, 8, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 1, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 2, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 3, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 4, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 3, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 4, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 5, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 6, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 7, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 8, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 9, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126006529, 10, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 1, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 2, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 3, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 4, 186, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 5, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 6, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 7, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 8, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 9, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522006530, 10, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 1, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 2, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 3, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 4, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 5, 140, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 6, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 7, 178, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922006531, 8, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 1, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 2, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 3, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 4, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 5, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 6, 131, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 7, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 8, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 9, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928006532, 10, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 1, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 2, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 3, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 4, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 5, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 6, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 7, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 8, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817006533, 9, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 1, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 2, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 3, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 4, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 5, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 6, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 7, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 8, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 9, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 10, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 11, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 12, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 13, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 14, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223006534, 15, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 1, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 2, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 3, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 4, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 5, 186, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510006535, 6, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023006536, 1, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023006536, 2, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023006536, 3, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023006536, 4, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 1, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 2, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 3, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 4, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 5, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 6, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 7, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006537, 8, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 1, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 2, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 3, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 4, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 5, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 6, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 7, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 8, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 9, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 10, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 11, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 12, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 13, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 14, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 15, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922006538, 16, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209006539, 1, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209006539, 2, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209006539, 3, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209006539, 4, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209006539, 5, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827006540, 1, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827006540, 2, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827006540, 3, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827006540, 4, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827006540, 5, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 1, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 2, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 3, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 4, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 5, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 6, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 7, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229006541, 8, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 1, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 2, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 3, 56, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 4, 105, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 5, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 6, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006542, 7, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 1, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 2, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 3, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 4, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 5, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 6, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 7, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 8, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 9, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 10, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 11, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212006543, 12, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 1, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 2, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 3, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 4, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 5, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 6, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 7, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 8, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 9, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 10, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 11, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 12, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 13, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 14, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006544, 15, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 1, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 2, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 3, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 4, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 5, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 6, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 7, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729006545, 8, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 1, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 2, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 3, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 4, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 5, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 6, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 7, 77, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 8, 185, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 9, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423006546, 10, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 1, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 2, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 3, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 4, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 5, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 6, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 7, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 8, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 9, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 10, 135, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 11, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622006547, 12, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 1, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 2, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 3, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 4, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 5, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 6, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 7, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 8, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 9, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 10, 132, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 11, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 12, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 13, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917006548, 14, 171, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 1, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 2, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 3, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 4, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 5, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 6, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 7, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 8, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 9, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 10, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 11, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120006549, 12, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 1, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 2, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 3, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 4, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 5, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 6, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 7, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 8, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 9, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 10, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726006550, 11, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 1, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 2, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 3, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 4, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 5, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 6, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 7, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 8, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 9, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 10, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 11, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 12, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 13, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 14, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516006551, 15, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 1, 10, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 2, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 3, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 4, 72, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 5, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 6, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 7, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 8, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 9, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 10, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507006552, 11, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 10, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 11, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 12, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 13, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006899, 14, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010503006900, 1, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010503006900, 2, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010503006900, 3, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010503006900, 4, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010503006900, 5, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 1, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 2, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 3, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 4, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 5, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006901, 6, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 1, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 2, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 3, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 4, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 5, 30, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 6, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 7, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 8, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 9, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 10, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 11, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 12, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508006902, 13, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 1, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 2, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 3, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 4, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 5, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 6, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 7, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 8, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 9, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 10, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 11, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 12, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 13, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705006903, 14, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 1, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 2, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 3, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 4, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 5, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 6, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 7, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 8, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 9, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714006904, 10, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 1, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 2, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 3, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 4, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 5, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 6, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 7, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 8, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123006905, 9, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 1, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 2, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 3, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 4, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 5, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 6, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 7, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 8, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006906, 9, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 1, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 2, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 3, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 4, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 5, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527006907, 6, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 1, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 2, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 3, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 4, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 5, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 6, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 7, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 8, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 9, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 10, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 11, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 12, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 13, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 14, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 15, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201006908, 16, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 1, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 2, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 3, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 4, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 5, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 6, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 7, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 8, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222006909, 9, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 1, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 2, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 3, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 4, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 5, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508006910, 6, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 1, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 2, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 3, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 4, 80, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 5, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 6, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 7, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 8, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 9, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 10, 26, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 11, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 12, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 13, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 14, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 15, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 16, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 17, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218006911, 18, 153, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 1, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 2, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 3, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 4, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 5, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 6, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 7, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 8, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 9, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 10, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 11, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 12, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 13, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 14, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130907006912, 15, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 1, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 2, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 3, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 4, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 5, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008006913, 6, 4, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 1, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 2, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 3, 44, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 4, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 5, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 6, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 7, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 8, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 9, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 10, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 11, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 12, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610006914, 13, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 1, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 2, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 3, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 4, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 5, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 6, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 7, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 8, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 9, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 10, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 11, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 12, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 13, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 14, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 15, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 16, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 17, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123006915, 18, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 1, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 2, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 3, 96, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 4, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 5, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 6, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 7, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 8, 192, 11, 18, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 9, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 10, 81, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 11, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 12, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 13, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 14, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 15, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423006916, 16, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 1, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 2, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 3, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 4, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 5, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 6, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 7, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 8, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 9, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 10, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 11, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 12, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 13, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 14, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129006917, 15, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 1, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 2, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 3, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 4, 121, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 5, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 6, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 7, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 8, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060516006918, 9, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714006919, 1, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714006919, 2, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714006919, 3, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 1, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 2, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 3, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 4, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 5, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104006920, 6, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 1, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 2, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 3, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 4, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 5, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 6, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 7, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 8, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 9, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 10, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 11, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 12, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 9, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 10, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 11, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 12, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 13, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 14, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 15, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012005757, 16, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 1, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 2, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 3, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 4, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 5, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 6, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 7, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 8, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 9, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 10, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 11, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 12, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 13, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 14, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 15, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120005758, 16, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005759, 1, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005759, 2, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005759, 3, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005759, 4, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107005759, 5, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120005760, 1, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120005760, 2, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120005760, 3, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120005760, 4, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802005761, 1, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802005761, 2, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802005761, 3, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802005761, 4, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 1, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 2, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 3, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 4, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 5, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 6, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 7, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 8, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 9, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 10, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 11, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 12, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 13, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506005762, 14, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 1, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 2, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 3, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 4, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 5, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208005763, 6, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 1, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 2, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 3, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 4, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 5, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 6, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 7, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 8, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 9, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 10, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426005764, 11, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 1, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 2, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 3, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 4, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 5, 46, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 6, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 7, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 8, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 9, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 10, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 11, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 12, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615005765, 13, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 1, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 2, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 3, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 4, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 5, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 6, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040222005766, 7, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005767, 1, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005767, 2, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005767, 3, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005767, 4, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601005767, 5, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 1, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 2, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 3, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 4, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 5, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 6, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423005768, 7, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 1, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 2, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 3, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 4, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 5, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 6, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 7, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 8, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 9, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 10, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 11, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 12, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 13, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 14, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 15, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 16, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129005769, 17, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 1, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 2, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 3, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 4, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 5, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 6, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 7, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 8, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 9, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 10, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 11, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525005770, 12, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518005771, 1, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518005771, 2, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518005771, 3, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518005771, 4, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518005771, 5, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 1, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 2, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 3, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 4, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 5, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 6, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 7, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 8, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325005772, 9, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 1, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 2, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 3, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 4, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 5, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 6, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 7, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 8, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 9, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 10, 30, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 11, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 12, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 13, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414005773, 14, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 1, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 2, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 3, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 4, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 5, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918005774, 6, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 1, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 2, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 3, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 4, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 5, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 6, 140, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 7, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902005775, 8, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 1, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 2, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 3, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 4, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 5, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 6, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 7, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 8, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 9, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213005776, 10, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 1, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 2, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 3, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 4, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 5, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 6, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 7, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 8, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 9, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 10, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 11, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 12, 129, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 13, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 14, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110005777, 15, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 1, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 2, 146, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 3, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 4, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 5, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 6, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 7, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 8, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 9, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 10, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 11, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 12, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 13, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 14, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029005778, 15, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 1, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 2, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 3, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 4, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 5, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 6, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 7, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 8, 126, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 9, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 10, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 11, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 12, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 13, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818005779, 14, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 1, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 2, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 3, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 4, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 5, 107, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 6, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402005780, 7, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 1, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 2, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 3, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 4, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 5, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 6, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 7, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 5, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 6, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 7, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 8, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 9, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 10, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 11, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 12, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 13, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 14, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 15, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618006173, 16, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 1, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 2, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 3, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 4, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 5, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019006174, 6, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 1, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 2, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 3, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 4, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 5, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 6, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 7, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 8, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 9, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 10, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 11, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 12, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231006175, 13, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006176, 1, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006176, 2, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006176, 3, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006176, 4, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216006177, 1, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216006177, 2, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216006177, 3, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216006177, 4, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216006177, 5, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 1, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 2, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 3, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 4, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 5, 10, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 6, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 7, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 8, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 9, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 10, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 11, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 12, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 13, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007006178, 14, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 1, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 2, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 3, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 4, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 5, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 6, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 7, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 8, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 9, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 10, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 11, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 12, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 13, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 14, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 15, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 16, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 17, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130006179, 18, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 1, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 2, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 3, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 4, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 5, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 6, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 7, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 8, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 9, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 10, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 11, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 12, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 13, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 14, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216006180, 15, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 1, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 2, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 3, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 4, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 5, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 6, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 7, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 8, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 9, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 10, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 11, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409006181, 12, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 1, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 2, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 3, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 4, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 5, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 6, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 7, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 8, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 9, 20, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 10, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 11, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 12, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006182, 13, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 1, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 2, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 3, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 4, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 5, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 6, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 7, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 8, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 9, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404006183, 10, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 1, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 2, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 3, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 4, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 5, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 6, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 7, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 8, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 9, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006184, 10, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 1, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 2, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 3, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 4, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 5, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 6, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 7, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 8, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 9, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 10, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 11, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 12, 192, 5, 18, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 13, 105, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 14, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 15, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223006185, 16, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113006186, 1, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113006186, 2, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113006186, 3, 179, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113006186, 4, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113006186, 5, 161, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 1, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 2, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 3, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 4, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 5, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 6, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 7, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 8, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 9, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 10, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 11, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218006187, 12, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119006188, 1, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119006188, 2, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119006188, 3, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119006188, 4, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119006188, 5, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 1, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 2, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 3, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 4, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 5, 100, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 6, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629006189, 7, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 1, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 2, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 3, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 4, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 5, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 6, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 7, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 8, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721006190, 9, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 1, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 2, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 3, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 4, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 5, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 6, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 7, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 8, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 9, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 10, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 11, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 12, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006191, 13, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 1, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 2, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 3, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 4, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 5, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 6, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 7, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 8, 91, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 9, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 10, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 11, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 12, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 13, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 14, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 15, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 16, 76, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 17, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427006192, 18, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 1, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 2, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 3, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 4, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 5, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 6, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 7, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403006193, 8, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818006194, 1, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818006194, 2, 72, 17, 12, 204);
commit;
prompt 59000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818006194, 3, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 1, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 2, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 3, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 4, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 5, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 6, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 7, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006195, 8, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510006196, 1, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510006196, 2, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 1, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 1, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 2, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 3, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 4, 74, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 5, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 6, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 7, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 8, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 9, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824006553, 10, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 1, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 2, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 3, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 4, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 5, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 6, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310006554, 7, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 1, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 2, 64, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 3, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 4, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 5, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513006555, 6, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 1, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 2, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 3, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 4, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 5, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 6, 92, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127006556, 7, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 1, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 2, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 3, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 4, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 5, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 6, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 7, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 8, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 9, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 10, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 11, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 12, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 13, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 14, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 15, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110227006557, 16, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 1, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 2, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 3, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 4, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 5, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 6, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030615006558, 7, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 1, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 2, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 3, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 4, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 5, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 6, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 7, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 8, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 9, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 10, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 11, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 12, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 13, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 14, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 15, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204006559, 16, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 1, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 2, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 3, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 4, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 5, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 6, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 7, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 8, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 9, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 10, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 11, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 12, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 13, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 14, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113006560, 15, 10, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 1, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 2, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 3, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 4, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 5, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 6, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 7, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 8, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914006561, 9, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 1, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 2, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 3, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 4, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 5, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 6, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 7, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 8, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 9, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 10, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 11, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 12, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110006562, 13, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 1, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 2, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 3, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 4, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 5, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 6, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 7, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 8, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 9, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 10, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 11, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 12, 78, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006563, 13, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 1, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 2, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 3, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 4, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 5, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 6, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 7, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 8, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 9, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 10, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 11, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824006564, 12, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 1, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 2, 72, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 3, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 4, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 5, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 6, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 7, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 8, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 9, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 10, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103006565, 11, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 1, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 2, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 3, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 4, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 5, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301006566, 6, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 1, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 2, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 3, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 4, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 5, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 6, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121006567, 7, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206006568, 1, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206006568, 2, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206006568, 3, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206006568, 4, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206006568, 5, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 1, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 2, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 3, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 4, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 5, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 6, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 7, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110006569, 8, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 1, 159, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 2, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 3, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 4, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 5, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 6, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 7, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 8, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 9, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 10, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 11, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 12, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 13, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 14, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006570, 15, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 1, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 2, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 3, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 4, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 5, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 6, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 7, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 8, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 9, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 10, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 11, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 12, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 13, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 14, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 15, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 16, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 17, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 18, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140422006571, 19, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 1, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 2, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 3, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 4, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 5, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414006572, 6, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 1, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 2, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 3, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 4, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 5, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 6, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 7, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231006573, 8, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 1, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 2, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 3, 192, 57, 18, 1026);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 4, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 5, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 6, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 7, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 8, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 9, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 10, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 11, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 12, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527006574, 13, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 1, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 2, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 3, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 4, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 5, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 6, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 7, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 8, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 9, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 10, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 13, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 14, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 15, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 16, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117006921, 17, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 1, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 2, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 3, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 4, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 5, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 6, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 7, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 8, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 9, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 10, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 11, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 12, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 13, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 14, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 15, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 16, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411006922, 17, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107006923, 1, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107006923, 2, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 1, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 2, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 3, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 4, 28, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 5, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 6, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 7, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 8, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914006924, 9, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 1, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 2, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 3, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 4, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 5, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 6, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 7, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 8, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 9, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 10, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 11, 2, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 12, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 13, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 14, 122, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313006925, 15, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419006926, 1, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419006926, 2, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419006926, 3, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419006926, 4, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 1, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 2, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 3, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 4, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 5, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 6, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 7, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 8, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 9, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 10, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 11, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 12, 134, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 13, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021006927, 14, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527006928, 1, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527006928, 2, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527006928, 3, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527006928, 4, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503006929, 1, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503006929, 2, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503006929, 3, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503006929, 4, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503006929, 5, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612006930, 1, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612006930, 2, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612006930, 3, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612006930, 4, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612006930, 5, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515006931, 1, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515006931, 2, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515006931, 3, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515006931, 4, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515006931, 5, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612006932, 1, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612006932, 2, 62, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 1, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 2, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 3, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 4, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 5, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 6, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 7, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202006933, 8, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 1, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 2, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 3, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 4, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 5, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 6, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 7, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 8, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816006934, 9, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 1, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 2, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 3, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 4, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 5, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 6, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 7, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 8, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 9, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 10, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 11, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 12, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 13, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 14, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 15, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120908006935, 16, 168, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 1, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 2, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 3, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 4, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 5, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 6, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 7, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 8, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806006936, 9, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 1, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 2, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 3, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 4, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 5, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006937, 6, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 1, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 2, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 3, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 4, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 5, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 6, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 7, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 8, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 9, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 10, 182, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 11, 70, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 12, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 13, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 14, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 15, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 16, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906006938, 17, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 1, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 2, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 3, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 4, 157, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 5, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 6, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 7, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 8, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 9, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 10, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 11, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 12, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 13, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 14, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 15, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 16, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323006939, 17, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 1, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 2, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 3, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 4, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 5, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 6, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 7, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113006940, 8, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124006941, 1, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124006941, 2, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124006941, 3, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124006941, 4, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 1, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 2, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 3, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 4, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 5, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 6, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 7, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230006942, 8, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 1, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 2, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 3, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 4, 96, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 5, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 6, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 7, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 8, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 9, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 10, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 11, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 12, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 13, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131006943, 14, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 1, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 2, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 3, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 4, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 5, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 6, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 7, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 8, 166, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 9, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722006944, 10, 22, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 1, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 2, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 3, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 4, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 5, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006945, 6, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 1, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 2, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 3, 16, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 4, 10, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 5, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716006946, 6, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 1, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 2, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 3, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 4, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 5, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 6, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 7, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 8, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060427006947, 9, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 1, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 2, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 3, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 4, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 5, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214005781, 8, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 1, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 2, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 3, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 4, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 5, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 6, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 7, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 8, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 9, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 10, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 11, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 12, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 13, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100912005782, 14, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 1, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 2, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 3, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 4, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 5, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 6, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 7, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 8, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 9, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 10, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 11, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617005783, 12, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 1, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 2, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 3, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 4, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 5, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 6, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 7, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302005784, 8, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 1, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 2, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 3, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 4, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 5, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 6, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 7, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127005785, 8, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 1, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 2, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 3, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 4, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 5, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 6, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 7, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 8, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 9, 168, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 10, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 11, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 12, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 13, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 14, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 15, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 16, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802005786, 17, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230005787, 1, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230005787, 2, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230005787, 3, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217005788, 1, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217005788, 2, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217005788, 3, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217005788, 4, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217005788, 5, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 1, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 2, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 3, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 4, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 5, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 6, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 7, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 8, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 9, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 10, 182, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 11, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 12, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 13, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 14, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 15, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 16, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130523005789, 17, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 1, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 2, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 3, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 4, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 5, 165, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 6, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 7, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 8, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 9, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 10, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 11, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081122005790, 12, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 1, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 2, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 3, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 4, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 5, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 6, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 7, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 8, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 9, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 10, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319005791, 11, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 1, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 2, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 3, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 4, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 5, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 6, 61, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 7, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 8, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 9, 61, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 10, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 11, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 12, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 13, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090413005792, 14, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215005793, 1, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215005793, 2, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215005793, 3, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215005793, 4, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215005793, 5, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 1, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 2, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 3, 51, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 4, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 5, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 6, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 7, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 8, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 9, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080921005794, 10, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 1, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 2, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 3, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 4, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 5, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005795, 6, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 2, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 3, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 4, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 5, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 6, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 7, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 8, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 9, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 10, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 11, 11, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 12, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417005796, 13, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 1, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 2, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 3, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 4, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 5, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 6, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 7, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 8, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 9, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 10, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 11, 86, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 12, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215005797, 13, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 1, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 2, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 3, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 4, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 5, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 6, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 7, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 8, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 9, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 10, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 11, 41, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 12, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 13, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 14, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130005798, 15, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 1, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 2, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 3, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 4, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 5, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 6, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 7, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 8, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 9, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 10, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 11, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 12, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 13, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 14, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405005799, 15, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 1, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 2, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 3, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 4, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 5, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 6, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 7, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 8, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 9, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 10, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 11, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 12, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 13, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 14, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110801005800, 15, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 1, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 2, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 3, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 4, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 5, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524005801, 6, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426005802, 1, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426005802, 2, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426005802, 3, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426005802, 4, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 1, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 2, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 3, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 4, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 5, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 6, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005005803, 7, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 1, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 2, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 3, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 4, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 5, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 6, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 7, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 8, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 2, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 3, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 5, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 6, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 7, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 8, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 9, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 10, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 11, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 12, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 13, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 14, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 15, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 16, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526006197, 17, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831006198, 1, 109, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831006198, 2, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831006198, 3, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831006198, 4, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 1, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 2, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 3, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 4, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 5, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 6, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 7, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 8, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 9, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 10, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 11, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 12, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 13, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090602006199, 14, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 1, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 2, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 3, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 4, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 5, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 6, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 7, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 8, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 9, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 10, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 11, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 12, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 13, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100502006200, 14, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 1, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 2, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 3, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 4, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 5, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 6, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 7, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 8, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 9, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718006201, 10, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 1, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 2, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 3, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 4, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 5, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211006202, 6, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 1, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 2, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 3, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 4, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 5, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 6, 74, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 7, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 8, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050330006203, 9, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 1, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 2, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 3, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 4, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 5, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808006204, 6, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 1, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 2, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 3, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 4, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 5, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 6, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 7, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 8, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 9, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 10, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 11, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 12, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 13, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 14, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106006205, 15, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215006206, 1, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215006206, 2, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215006206, 3, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006207, 1, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006207, 2, 27, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831006207, 3, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 1, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 2, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 3, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 4, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 5, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 6, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 7, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 8, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 9, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524006208, 10, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 1, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 2, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 3, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 4, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 5, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 6, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 7, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 8, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518006209, 9, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830006210, 1, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830006210, 2, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830006210, 3, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830006210, 4, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 1, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 2, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 3, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 4, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 5, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 6, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 7, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 8, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402006211, 9, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 1, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 2, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 3, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 4, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 5, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 6, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 7, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 8, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 9, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 10, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 11, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 12, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 13, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 14, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 15, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 16, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 17, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223006212, 18, 24, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 1, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 2, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 3, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 4, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 5, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 6, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 7, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 8, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 9, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 10, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 11, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006213, 12, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 1, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 2, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 3, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 4, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 5, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 6, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523006214, 7, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 1, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 2, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 3, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 4, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 5, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 6, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 7, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 8, 166, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609006215, 9, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 1, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 2, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 3, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 4, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 5, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 6, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 7, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 8, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217006216, 9, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 1, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 2, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 3, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 4, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 5, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 6, 111, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 7, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 8, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 9, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 10, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 11, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 12, 57, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 13, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 14, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 15, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 16, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 17, 144, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616006217, 18, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 1, 15, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 2, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 3, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 4, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 5, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 6, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 7, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 8, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 9, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 10, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 11, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 12, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 13, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 14, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 15, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208006218, 16, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 1, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 2, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 3, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 4, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 5, 85, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 6, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 7, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 8, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 9, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 10, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 11, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 12, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 13, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 14, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609006219, 15, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 1, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 2, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 3, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 11, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 12, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723006575, 13, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111006576, 1, 113, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111006576, 2, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111006576, 3, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111006576, 4, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 1, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 2, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 3, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 4, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 5, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 6, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802006577, 7, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 1, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 2, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 3, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 4, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 5, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 6, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 7, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 8, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 9, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 10, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 11, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 12, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423006578, 13, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 1, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 2, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 3, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 4, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 5, 114, 1, 9, 9);
commit;
prompt 60000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 6, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 7, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 8, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529006579, 9, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 1, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 2, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 3, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 4, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 5, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 6, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 7, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 8, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006580, 9, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 1, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 2, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 3, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 4, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 5, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 6, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 7, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 8, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 9, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 10, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 11, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 12, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 13, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 14, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 15, 82, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414006581, 16, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 1, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 2, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 3, 36, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 4, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 5, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 6, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 7, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 8, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 9, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 10, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 11, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 12, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 13, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309006582, 14, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 1, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 2, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 3, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 4, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 5, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 6, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 7, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510006583, 8, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 1, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 2, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 3, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 4, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 5, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 6, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 7, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 8, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 9, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 10, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 11, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508006584, 12, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225006585, 1, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225006585, 2, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225006585, 3, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225006585, 4, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 1, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 2, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 3, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 4, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 5, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 6, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 7, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 8, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 9, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 10, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 11, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 12, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 13, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 14, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 15, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922006586, 16, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 1, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 2, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 3, 28, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 4, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 5, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101006587, 6, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 1, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 2, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 3, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 4, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 5, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 6, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 7, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 8, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 9, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 10, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 11, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 12, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 13, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 14, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 15, 83, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006588, 16, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 1, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 2, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 3, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 4, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 5, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 6, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 7, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215006589, 8, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 1, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 2, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 3, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 4, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 5, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 6, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 7, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 8, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017006590, 9, 156, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117006591, 1, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117006591, 2, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117006591, 3, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117006591, 4, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 1, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 2, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 3, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 4, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 5, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006592, 6, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 1, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 2, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 3, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 4, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 5, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 6, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 7, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 8, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 9, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414006593, 10, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 1, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 2, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 3, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 4, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 5, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 6, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 7, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 8, 109, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 9, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 10, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 11, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801006594, 12, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 1, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 2, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 3, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 4, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 5, 41, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 6, 85, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 7, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 8, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 9, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 10, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201006595, 11, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 1, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 2, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 3, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 4, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 5, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 6, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 7, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 8, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 9, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 10, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 11, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721006596, 12, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 1, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 2, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 3, 183, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 4, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 5, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 6, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019006597, 7, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 1, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 2, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 3, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 4, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 5, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 6, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 7, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 8, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 9, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 10, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 11, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 12, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 13, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006598, 14, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 1, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 2, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 3, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 4, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 5, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 6, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 7, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 8, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 9, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 6, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 7, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 8, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 9, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 10, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 11, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 12, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 13, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 14, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 15, 176, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006948, 16, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 1, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 2, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 3, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 4, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 5, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 6, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 7, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 8, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 9, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 10, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 11, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 12, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 13, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 14, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 15, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 16, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006949, 17, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 1, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 2, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 3, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 4, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 5, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 6, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 7, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 8, 85, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 9, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 10, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 11, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 12, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 13, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 14, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110515006950, 15, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 1, 187, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 2, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 3, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 4, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 5, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 6, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 7, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 8, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050709006951, 9, 64, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 1, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 2, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 3, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 4, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 5, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030504006952, 6, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 1, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 2, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 3, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 4, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 5, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 6, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 7, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 8, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 9, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 10, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225006953, 11, 43, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 1, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 2, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 3, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 4, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 6, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 7, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 8, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040502006954, 9, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 1, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 2, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 3, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 4, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 5, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 6, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 7, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 8, 31, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 9, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006955, 10, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 1, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 2, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 3, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 4, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 5, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 6, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 7, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 8, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 9, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 10, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 11, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 12, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100122006956, 13, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 1, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 2, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 3, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 4, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 5, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605006957, 6, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 1, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 2, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 3, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 4, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 5, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 6, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 8, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 9, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 10, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 11, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 12, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 13, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921006958, 14, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 1, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 2, 97, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 3, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 4, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 5, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 6, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006959, 7, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 1, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 2, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 3, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 4, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 5, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 6, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 7, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 8, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040321006960, 9, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 1, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 2, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 3, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 4, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 5, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 6, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 7, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 8, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825006961, 9, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 1, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 2, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 3, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 4, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 5, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 6, 94, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 7, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 8, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 9, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803006962, 10, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 1, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 2, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 3, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 4, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 5, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 6, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220006963, 7, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 1, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 2, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 3, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 4, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 5, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 6, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417006964, 7, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 1, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 2, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 3, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 4, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 5, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323006965, 6, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119006966, 1, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119006966, 2, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119006966, 3, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119006966, 4, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006967, 1, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006967, 2, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006967, 3, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006967, 4, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006967, 5, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421006968, 1, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421006968, 2, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421006968, 3, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820006969, 1, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820006969, 2, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820006969, 3, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820006969, 4, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 1, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 2, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 3, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 4, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 5, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 6, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 7, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 8, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 9, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 10, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 11, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 12, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 13, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 14, 167, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308006970, 15, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 1, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 2, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 3, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 4, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 5, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 6, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 7, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 8, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 9, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 10, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 11, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 12, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 13, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 14, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 15, 127, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 16, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321006971, 17, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 1, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 2, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 3, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 4, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 5, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 6, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023006972, 7, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716006973, 1, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716006973, 2, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716006973, 3, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716006973, 4, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716006973, 5, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 1, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 2, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 3, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 9, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 10, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 11, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 12, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 13, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 14, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 15, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627005804, 16, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 1, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 2, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 3, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 4, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 5, 60, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 6, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 7, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 8, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 9, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 10, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 11, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 12, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 13, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618005805, 14, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130005806, 1, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130005806, 2, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130005806, 3, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130005806, 4, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130005806, 5, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 1, 174, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 2, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 3, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 4, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 5, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 6, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 7, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 8, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 9, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 10, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 11, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 12, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026005807, 13, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 1, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 2, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 3, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 4, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 5, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 6, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 7, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 8, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 9, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 10, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 11, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 12, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 13, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807005808, 14, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 1, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 2, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 3, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 4, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 5, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 6, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 7, 72, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 8, 1, 47, 3, 141);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 9, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017005809, 10, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 1, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 2, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 3, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 4, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 5, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 6, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 7, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 8, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 9, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 10, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 11, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 12, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 13, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 14, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 15, 25, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 16, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017005810, 17, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312005811, 1, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312005811, 2, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312005811, 3, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 1, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 2, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 3, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 4, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 5, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 6, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912005812, 7, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 1, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 2, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 3, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 4, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 5, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 6, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 7, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 8, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 9, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 10, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 11, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 12, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 13, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 14, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 15, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130809005813, 16, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514005814, 1, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514005814, 2, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514005814, 3, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514005814, 4, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 1, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 2, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 3, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 4, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 5, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 6, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 7, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 8, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208005815, 9, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 1, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 2, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 3, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 4, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 5, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 6, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 7, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 8, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070521005816, 9, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 1, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 2, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 3, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 4, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 5, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 6, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 7, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 8, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 9, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407005817, 10, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 1, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 2, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 3, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 4, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 5, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201005818, 6, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 1, 59, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 2, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 3, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 4, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 5, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 6, 137, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 7, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 8, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220005819, 9, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 1, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 2, 141, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 3, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 4, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 5, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 6, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 7, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217005820, 8, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710005821, 1, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710005821, 2, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710005821, 3, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 1, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 2, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 3, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 4, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 5, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 6, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 7, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 8, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 9, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 10, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 11, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 12, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001005822, 13, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 1, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 2, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 3, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 4, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 5, 179, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 6, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213005823, 7, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907005824, 1, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907005824, 2, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907005824, 3, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907005824, 4, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 1, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 2, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 3, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 5, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 6, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 7, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 8, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 9, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 10, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725005825, 11, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 1, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 2, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 3, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 4, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 5, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 6, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 7, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 8, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 9, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207005826, 10, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 1, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 2, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 3, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 4, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 5, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820005827, 6, 100, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021005828, 1, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021005828, 2, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021005828, 3, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021005828, 4, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021005828, 5, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 1, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 2, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 3, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 4, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 5, 15, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 6, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 7, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 8, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 9, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329005829, 10, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 1, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 2, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 3, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 4, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 5, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 6, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 7, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 8, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 4, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 5, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 6, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 7, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 8, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 9, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 10, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 11, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 12, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 13, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 14, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 15, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120902006220, 16, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 1, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 2, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 3, 179, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 4, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 5, 51, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 6, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 7, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 8, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 9, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 10, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 11, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 12, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503006221, 13, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 1, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 2, 148, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 3, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 4, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 5, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 6, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 7, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810006222, 8, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 1, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 2, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 3, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 4, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 5, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 6, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 7, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 8, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 9, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 10, 97, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 11, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701006223, 12, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 1, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 2, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 3, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 4, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 5, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 6, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 7, 158, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 8, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 9, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606006224, 10, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 1, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 2, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 3, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 4, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 5, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 6, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 7, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 8, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 9, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 10, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 11, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401006225, 12, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 1, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 2, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 3, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 4, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 5, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 6, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 7, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 8, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 9, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 10, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 11, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 12, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 13, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 14, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220006226, 15, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 1, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 2, 54, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 3, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 4, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 5, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 6, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 7, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 8, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 9, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 10, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231006227, 11, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 1, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 2, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 3, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 4, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 5, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 6, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 7, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 8, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 9, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 10, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824006228, 11, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 1, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 2, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 3, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 4, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 5, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 6, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 7, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040511006229, 8, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 1, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 2, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 3, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 4, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 5, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 6, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 7, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 8, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 9, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 10, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 11, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 12, 18, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 13, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 14, 63, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 15, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 16, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926006230, 17, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 1, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 2, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 3, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 4, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 5, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 6, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 7, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 8, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 9, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024006231, 10, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 1, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 2, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 3, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 4, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 5, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 6, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 7, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 8, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 9, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 10, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129006232, 11, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 1, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 2, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 3, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 4, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 5, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 6, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 7, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029006233, 8, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 1, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 2, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 3, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 4, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 5, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125006234, 6, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 1, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 2, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 3, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 4, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 5, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 6, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 7, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507006235, 8, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 1, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 2, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 3, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 4, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 5, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 6, 12, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 7, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 8, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 9, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 10, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 11, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 12, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 13, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 14, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006236, 15, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 1, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 2, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 3, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 4, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 5, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 6, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913006237, 7, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 1, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 2, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 3, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 4, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 5, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 6, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 7, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 8, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 9, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 10, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 11, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 12, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 13, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006238, 14, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108006239, 1, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108006239, 2, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108006239, 3, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108006239, 4, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108006239, 5, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 1, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 2, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 3, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 4, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 5, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 6, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811006240, 7, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 1, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 2, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 3, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 4, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 5, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 6, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 7, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 8, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 9, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 10, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 11, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 12, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408006241, 13, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 1, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 2, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 3, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 4, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 5, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 10, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 11, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 12, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 13, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 14, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 15, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606006599, 16, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722006600, 1, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722006600, 2, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722006600, 3, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722006600, 4, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722006600, 5, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609006601, 1, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609006601, 2, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609006601, 3, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609006601, 4, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609006601, 5, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 1, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 2, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 3, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 4, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 5, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 6, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 7, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 8, 86, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013006602, 9, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 1, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 2, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 3, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 4, 74, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 5, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 6, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 7, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 8, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416006603, 9, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 1, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 2, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 3, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 4, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 5, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 6, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 7, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 8, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 9, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 10, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 11, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081227006604, 12, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207006605, 1, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207006605, 2, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207006605, 3, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115006606, 1, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115006606, 2, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115006606, 3, 107, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115006606, 4, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 1, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 2, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 3, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 4, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 5, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 6, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 7, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 8, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 9, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 10, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826006607, 11, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 1, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 2, 192, 36, 18, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 3, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 4, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 5, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 6, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 7, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 8, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 9, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 10, 177, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 11, 163, 58, 10, 580);
commit;
prompt 61000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081202006608, 12, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817006609, 1, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817006609, 2, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817006609, 3, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 1, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 2, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 3, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 4, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 5, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 6, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 7, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 8, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 9, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 10, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 11, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 12, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 13, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 14, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 15, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 16, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 17, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 18, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006610, 19, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 1, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 3, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 4, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 5, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 6, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 7, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 8, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 9, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 10, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 11, 187, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 12, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 13, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006611, 14, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 1, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 2, 127, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 3, 132, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 4, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 5, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 6, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 7, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 8, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 9, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228006612, 10, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 1, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 2, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 3, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 4, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 5, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 6, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 7, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 8, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 9, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 10, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 11, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 12, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 13, 114, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 14, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 15, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006613, 16, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 1, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 2, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 3, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 4, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 5, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928006614, 6, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 1, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 2, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 3, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 4, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 5, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 6, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 7, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 8, 20, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 9, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 10, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 11, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615006615, 12, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510006616, 1, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510006616, 2, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 1, 127, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 2, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 3, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 4, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 5, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 6, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 7, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 8, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 9, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 10, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 11, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129006617, 12, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006618, 1, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006618, 2, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006618, 3, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006618, 4, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006618, 5, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 1, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 2, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 3, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 4, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 5, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 6, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 7, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 8, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 9, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 10, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 11, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 12, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 13, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 14, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 15, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127006619, 16, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 1, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 2, 84, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 3, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 4, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 5, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 6, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801006620, 7, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 1, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 2, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 3, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 4, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 5, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 6, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 7, 27, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 8, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 9, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712006621, 10, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 1, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 2, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 3, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 4, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 5, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 6, 162, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 7, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520006622, 8, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 1, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 2, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 3, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 4, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 5, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 6, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 7, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 8, 98, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 9, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 10, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408006623, 11, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 1, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 2, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 3, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 4, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 5, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 6, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 7, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 8, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 9, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 10, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 11, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 1, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 2, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 3, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 4, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 5, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 6, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 7, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 8, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 9, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 10, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 11, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 12, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 13, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 14, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 15, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 16, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230007074, 17, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325007075, 1, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325007075, 2, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325007075, 3, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325007075, 4, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325007075, 5, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007076, 1, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007076, 2, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007076, 3, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007076, 4, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 1, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 2, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 3, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 4, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 5, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 6, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 7, 122, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823007077, 8, 34, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 1, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 2, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 3, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 4, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 5, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 6, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 7, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 8, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 9, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 10, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 11, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 12, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 13, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612007078, 14, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604007079, 1, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604007079, 2, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604007079, 3, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604007079, 4, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 1, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 2, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 3, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 4, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 5, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 6, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 7, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 8, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 9, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 10, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 11, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 12, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 13, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 14, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 15, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 16, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603007080, 17, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 1, 109, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 2, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 3, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 4, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 5, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721007081, 6, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 1, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 2, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 3, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 4, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 5, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 6, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 7, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 8, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 9, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 10, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 11, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 12, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 13, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 14, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131007082, 15, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 1, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 2, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 3, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 4, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 5, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 6, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 7, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 8, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 9, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 10, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070417007083, 11, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 1, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 2, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 3, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 4, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 5, 133, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 6, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 7, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 8, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 9, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720007084, 10, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 1, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 2, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 3, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 4, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 5, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225007085, 6, 113, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 1, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 2, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 3, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 4, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 5, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 6, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 7, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 8, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 9, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110007086, 10, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 1, 131, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 2, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 3, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 4, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 5, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 6, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 7, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 8, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 9, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 10, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 11, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 12, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 13, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 14, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 15, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 16, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628007087, 17, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 1, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 2, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 3, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 4, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 5, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 6, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 7, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 8, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 9, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 10, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 11, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 12, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228007088, 13, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 1, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 2, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 3, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 4, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 5, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 6, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 7, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 8, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 9, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 10, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 11, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 12, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 13, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 14, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224007089, 15, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 1, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 2, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 3, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 4, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 5, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 6, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 7, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 8, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 9, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007090, 10, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 1, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 2, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 3, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 4, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 5, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 6, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 7, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 8, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108007091, 9, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903007092, 1, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903007092, 2, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903007092, 3, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903007092, 4, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903007092, 5, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007093, 1, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007093, 2, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007093, 3, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007093, 4, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007093, 5, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 1, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 2, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 3, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 4, 111, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 5, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 6, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 7, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 8, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 9, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 10, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 11, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 12, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 13, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 14, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920007094, 15, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 1, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 2, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 3, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 4, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 5, 136, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 6, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 7, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 8, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 9, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 10, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 11, 6, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 12, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 13, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606007095, 14, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 1, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 2, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 3, 22, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 4, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 5, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 6, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 7, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 8, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 9, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 9, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 10, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 11, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 12, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 13, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108005830, 14, 28, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 1, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 2, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 3, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 4, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 5, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 6, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 7, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 8, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005831, 9, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 1, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 2, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 3, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 4, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 5, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 6, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 7, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807005832, 8, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 1, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 2, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 3, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 4, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 5, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 6, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 7, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 8, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 9, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 10, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 11, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 12, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803005833, 13, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 1, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 2, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 3, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 4, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 5, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 6, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 7, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 8, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 9, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410005834, 10, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 1, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 2, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 3, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 4, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 5, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 6, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 7, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 8, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 9, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 10, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 11, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814005835, 12, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 1, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 2, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 3, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 4, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 5, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 6, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 7, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 8, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 9, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 10, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 11, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 12, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319005836, 13, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 1, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 2, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 3, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 4, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 5, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 6, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 7, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 8, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706005837, 9, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 1, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 2, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 3, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 4, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 5, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 6, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222005838, 7, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 1, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 2, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 3, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 4, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 5, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 6, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 7, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 8, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 9, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104005839, 10, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 1, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 2, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 3, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 4, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 5, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 6, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 7, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 8, 192, 8, 18, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 9, 149, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 10, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024005840, 11, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730005841, 1, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730005841, 2, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730005841, 3, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000730005841, 4, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 1, 163, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 2, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 3, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 4, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 5, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 6, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227005842, 7, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 1, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 2, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 3, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 4, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 5, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 6, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 7, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 8, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 9, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 10, 189, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 11, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 12, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425005843, 13, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 1, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 2, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 3, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 4, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 5, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214005844, 6, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 1, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 2, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 3, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 4, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 5, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 6, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 7, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 8, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 9, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 10, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 11, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 12, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125005845, 13, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 1, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 2, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 3, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 4, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 5, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 6, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 7, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 8, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 9, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 10, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 11, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 12, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 13, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 14, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623005846, 15, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709005847, 1, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709005847, 2, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709005847, 3, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 1, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 2, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 3, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 4, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 5, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 6, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 7, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 8, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 9, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 10, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 11, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319005848, 12, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 1, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 2, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 3, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 4, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 5, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 6, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 7, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 8, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 9, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 10, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 11, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 12, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 13, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107005849, 14, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 1, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 2, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 3, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 4, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 5, 157, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 6, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 7, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 8, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 9, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424005850, 10, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 1, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 2, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 3, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 4, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 5, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 6, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107005851, 7, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 1, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 2, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 3, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 4, 192, 9, 18, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 5, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 6, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 7, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 8, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 9, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 10, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218005852, 11, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715005853, 1, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715005853, 2, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715005853, 3, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715005853, 4, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715005853, 5, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623005854, 1, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623005854, 2, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623005854, 3, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623005854, 4, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623005854, 5, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 1, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 2, 41, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 3, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 4, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 5, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 6, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 6, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 7, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 8, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 9, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 10, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 11, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 12, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 13, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 14, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 15, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 16, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120219006242, 17, 112, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 1, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 2, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 3, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 4, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 5, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 6, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 7, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 8, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 9, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 10, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 11, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208006243, 12, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 1, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 2, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 3, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 4, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 5, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 6, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 7, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 8, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 9, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 10, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 11, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 12, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 13, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 14, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118006244, 15, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 1, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 2, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 3, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 4, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 5, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 6, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 7, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 8, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 9, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 10, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 11, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 12, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 13, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 14, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006245, 15, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 1, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 2, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 3, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 4, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 5, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 6, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 7, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 8, 96, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126006246, 9, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916006247, 1, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916006247, 2, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916006247, 3, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 1, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 2, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 3, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 4, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 5, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 6, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 7, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 8, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725006248, 9, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 1, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 2, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 3, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 4, 170, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 5, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 6, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 7, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 8, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 9, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 10, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 11, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 12, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 13, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006249, 14, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614006250, 1, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614006250, 2, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614006250, 3, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614006250, 4, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 1, 36, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 2, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 3, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 4, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 5, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 6, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 7, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 8, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 9, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 10, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 11, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 12, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 13, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 14, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201006251, 15, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 1, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 2, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 3, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 4, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 5, 63, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 6, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 7, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 8, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911006252, 9, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130006253, 1, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130006253, 2, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130006253, 3, 115, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130006253, 4, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 1, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 2, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 3, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 4, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 5, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 6, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 7, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 8, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 9, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 10, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 11, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 12, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 13, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090217006254, 14, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 1, 15, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 2, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 3, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 4, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 5, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 6, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 7, 140, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302006255, 8, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118006256, 1, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118006256, 2, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118006256, 3, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118006256, 4, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 1, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 2, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 3, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 4, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 5, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 6, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 7, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 8, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 9, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 10, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 11, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 12, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091109006257, 13, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 1, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 2, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 3, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 4, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 5, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 6, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 7, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 8, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 9, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 10, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028006258, 11, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 1, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 2, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 3, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 4, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 5, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 6, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 7, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 8, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 9, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 10, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 11, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 12, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 13, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 14, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 15, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309006259, 16, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 1, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 2, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 3, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 4, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 5, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 6, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 7, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 8, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 9, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 10, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 11, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 12, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 13, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 14, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930006260, 15, 21, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 1, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 2, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 3, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 4, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 5, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 6, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 7, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 8, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 9, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 10, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 11, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 12, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 13, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 14, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721006261, 15, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 1, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 2, 31, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 3, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 4, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 5, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 6, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 7, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 8, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 9, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531006262, 10, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607006263, 1, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607006263, 2, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607006263, 3, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607006263, 4, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303006264, 1, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303006264, 2, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303006264, 3, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 1, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 2, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 3, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 4, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 5, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 12, 78, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 13, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 14, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 15, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 16, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006624, 17, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 1, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 2, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 3, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 4, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 5, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512006625, 6, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 1, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 2, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 3, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 4, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 5, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 6, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 7, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 8, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 9, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 10, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 11, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 12, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 13, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 14, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 15, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502006626, 16, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 1, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 2, 3, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 3, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 4, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 5, 165, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 6, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 7, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 8, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 9, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 10, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 11, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 12, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 13, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 14, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 15, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424006627, 16, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 1, 16, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 2, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 3, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 4, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 5, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 6, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 7, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 8, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 9, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329006628, 10, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 1, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 2, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 3, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 4, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 5, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 6, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 7, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 8, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 9, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 10, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 11, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525006629, 12, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 1, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 2, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 3, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 4, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 5, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 6, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 7, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805006630, 8, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 1, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 2, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 3, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 4, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 5, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 6, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 7, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 8, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 9, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 10, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 11, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 12, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 13, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090202006631, 14, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 1, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 2, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 3, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 4, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 5, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 6, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 7, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 8, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 9, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 10, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 11, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 12, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 13, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 14, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 15, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 16, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530006632, 17, 192, 64, 18, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 1, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 2, 168, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 3, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 4, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 5, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 6, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 7, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 8, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 9, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 10, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 11, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 12, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114006633, 13, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 1, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 2, 38, 23, 9, 207);
commit;
prompt 62000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 3, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 4, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 5, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 6, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 7, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 8, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 9, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 10, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 11, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 12, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 13, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 14, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 15, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006006634, 16, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 1, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 2, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 3, 45, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 4, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 5, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 6, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006006635, 7, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 1, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 2, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 3, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 4, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 5, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 6, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 7, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 8, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 9, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 10, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 11, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 12, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 13, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 14, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006636, 15, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 1, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 2, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 3, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 4, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 5, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 6, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 7, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 8, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 9, 46, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 10, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 11, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 12, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 13, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 14, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 15, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 16, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417006637, 17, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222006638, 1, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222006638, 2, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222006638, 3, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222006638, 4, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409006639, 1, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409006639, 2, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409006639, 3, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409006639, 4, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 1, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 2, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 3, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 4, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 5, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 6, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040413006640, 7, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717006641, 1, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717006641, 2, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717006641, 3, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717006641, 4, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717006641, 5, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 1, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 2, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 3, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 4, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 5, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 6, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 7, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 8, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 9, 169, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 10, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 11, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 12, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 13, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 14, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517006642, 15, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 1, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 2, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 3, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 4, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 5, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 6, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703006643, 7, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000801006644, 1, 80, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000801006644, 2, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000801006644, 3, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000801006644, 4, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 1, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 2, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 3, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 4, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 5, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 6, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 7, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 8, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 9, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 10, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417006645, 11, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 1, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 2, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 3, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 4, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 5, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 6, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 7, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 8, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 9, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 4, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 5, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 6, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427006974, 7, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105006975, 1, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105006975, 2, 173, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105006975, 3, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 1, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 2, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 3, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 4, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 5, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 6, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 7, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 8, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 9, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 10, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006976, 11, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 1, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 2, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 3, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 4, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 5, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 6, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 7, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 8, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 9, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 10, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 11, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502006977, 12, 88, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 1, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 2, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 3, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 4, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 5, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 6, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 7, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 8, 47, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 9, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 10, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119006978, 11, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 1, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 2, 141, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 3, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 4, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 5, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 6, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 7, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101006979, 8, 127, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 1, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 2, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 3, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 4, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 5, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 6, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 7, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 8, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 9, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 10, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222006980, 11, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 1, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 2, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 3, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 4, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 5, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118006981, 6, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 1, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 2, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 3, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 4, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 5, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 6, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 7, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 8, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 9, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 10, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 11, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 12, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 13, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 14, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706006982, 15, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 1, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 2, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 3, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 4, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 5, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 6, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 7, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505006983, 8, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 1, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 2, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 3, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 4, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 5, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006984, 6, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 1, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 2, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 3, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 4, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 5, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 6, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 7, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 8, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 9, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006985, 10, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 1, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 2, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 3, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 4, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 5, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 6, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 7, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 8, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 9, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 10, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 11, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 12, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 13, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 14, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 15, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006986, 16, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131006987, 1, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131006987, 2, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131006987, 3, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131006987, 4, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131006987, 5, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101006988, 1, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101006988, 2, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101006988, 3, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101006988, 4, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 1, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 2, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 3, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 4, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 5, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 6, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 7, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615006989, 8, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006990, 1, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006990, 2, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006990, 3, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006990, 4, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006990, 5, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006991, 1, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006991, 2, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710006991, 3, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 1, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 2, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 3, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 4, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 5, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 6, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 7, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 8, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 9, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 10, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228006992, 11, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 1, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 2, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 3, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 4, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 5, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 6, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 7, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 8, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 9, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 10, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 11, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 12, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 13, 162, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525006993, 14, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 1, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 2, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 3, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 4, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 5, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 6, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 7, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 8, 110, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 9, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060326006994, 10, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 1, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 2, 189, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 3, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 4, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 5, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 6, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 7, 110, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810006995, 8, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 1, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 2, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 3, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 4, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 5, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 6, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 7, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 8, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 9, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 10, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 11, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 12, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080620006996, 13, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 1, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 2, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 3, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 4, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 5, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 6, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 7, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 8, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 9, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 10, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 11, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080318006997, 12, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 1, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 2, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 3, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 4, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 5, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801006998, 6, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000114006999, 1, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000114006999, 2, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000114006999, 3, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 1, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 2, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 3, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 4, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 5, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 6, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 7, 1, 49, 3, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 8, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 9, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 10, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 11, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007000, 12, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 1, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 2, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 3, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 4, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 7, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 8, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 9, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 10, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 11, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 12, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 13, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 14, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620005855, 15, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 1, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 2, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 3, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 4, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 5, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 6, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 7, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 8, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 9, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 10, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 11, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 12, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 13, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 14, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217005856, 15, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005857, 1, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005857, 2, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005857, 3, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118005857, 4, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516005858, 1, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516005858, 2, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516005858, 3, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516005858, 4, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 1, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 2, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 3, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 4, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 5, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 6, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 7, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 8, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 9, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126005859, 10, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913005860, 1, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913005860, 2, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913005860, 3, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020913005860, 4, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 1, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 2, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 3, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 4, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 5, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 6, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 7, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 8, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 9, 8, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 10, 54, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 11, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 12, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 13, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119005861, 14, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 1, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 2, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 3, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 4, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 5, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 6, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017005862, 7, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808005863, 1, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808005863, 2, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808005863, 3, 63, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808005863, 4, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808005863, 5, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 1, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 2, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 3, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 4, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 5, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 6, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 7, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 8, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 9, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 10, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 11, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 12, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 13, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 14, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 15, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219005864, 16, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 1, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 2, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 3, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 4, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 5, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 6, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 7, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 8, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 9, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122005865, 10, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 1, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 2, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 3, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 4, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 5, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905005866, 6, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000214005867, 1, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000214005867, 2, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000214005867, 3, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000214005867, 4, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000214005867, 5, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 1, 179, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 2, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 3, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 4, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 5, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 6, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 7, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 8, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 9, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 10, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 11, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 12, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 13, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 14, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 15, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130920005868, 16, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 1, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 2, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 3, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 4, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 5, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 6, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 7, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 8, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214005869, 9, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314005870, 1, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314005870, 2, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314005870, 3, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314005870, 4, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314005870, 5, 192, 62, 18, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 1, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 2, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 3, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 4, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 5, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 6, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 7, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 8, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 9, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 10, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 11, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 12, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 13, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 14, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 15, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 16, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318005871, 17, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315005872, 1, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315005872, 2, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315005872, 3, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315005872, 4, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 1, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 2, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 3, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 4, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 5, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725005873, 6, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411005874, 1, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411005874, 2, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411005874, 3, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 1, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 2, 131, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 3, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 4, 60, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 5, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 6, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 7, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 8, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 9, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 10, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 11, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 12, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 13, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 14, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 15, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130622005875, 16, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 1, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 2, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 3, 68, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 4, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 5, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 6, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 7, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 8, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 9, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 10, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 11, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 12, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 13, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 14, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 15, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123005876, 16, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 1, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 2, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 3, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 4, 178, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 5, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 6, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 7, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 8, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 9, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 10, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 11, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 12, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227005877, 13, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 1, 164, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 2, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 3, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 4, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 5, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 6, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 7, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 9, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 10, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815005878, 11, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 1, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 2, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 3, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 4, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 5, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 6, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 7, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 8, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 9, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 10, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 11, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 12, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922005879, 13, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 6, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 7, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 8, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 9, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 10, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 11, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 12, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 13, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811006265, 14, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 1, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 2, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 3, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 4, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 5, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006266, 6, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108006267, 1, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108006267, 2, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108006267, 3, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108006267, 4, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108006267, 5, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 1, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 2, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 3, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 4, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 5, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 6, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 7, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 8, 172, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 9, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 10, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 11, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 12, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 13, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214006268, 14, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 1, 10, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 2, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 3, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 4, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 5, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 6, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 7, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 8, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 9, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 10, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 11, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 12, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930006269, 13, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113006270, 1, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113006270, 2, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113006270, 3, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113006270, 4, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 1, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 2, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 3, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 4, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 5, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 6, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 7, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 8, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 9, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 10, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 11, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813006271, 12, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006272, 1, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006272, 2, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006272, 3, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 1, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 2, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 3, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 4, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 5, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 6, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 7, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 8, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 9, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 10, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 11, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 12, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 13, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006273, 14, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 1, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 2, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 3, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 4, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 5, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 6, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 7, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 8, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 9, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 10, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 11, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 12, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 13, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430006274, 14, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 1, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 2, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 3, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 4, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 5, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 6, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 7, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 8, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 9, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 10, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 11, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 12, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090212006275, 13, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 1, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 2, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 3, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 4, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 5, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 6, 48, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 7, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 8, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 9, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 10, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 11, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115006276, 12, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 1, 4, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 2, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 3, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 4, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 5, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 6, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 7, 30, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 8, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 9, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 10, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 11, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 12, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006277, 13, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 1, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 2, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 3, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 4, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 5, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 6, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 7, 148, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 8, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022006278, 9, 141, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 1, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 2, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 3, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 4, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 5, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 6, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 7, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 8, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 9, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 10, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 11, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 12, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 13, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 14, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 15, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 16, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401006279, 17, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403006280, 1, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403006280, 2, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403006280, 3, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403006280, 4, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 1, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 2, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 3, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 4, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 5, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 6, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 7, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 8, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 9, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515006281, 10, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 1, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 2, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 3, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 4, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 5, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 6, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 7, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 8, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 9, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 10, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120006282, 11, 85, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 1, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 2, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 3, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 4, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 5, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 6, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 7, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 8, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 9, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 10, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 11, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 12, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 13, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 14, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 15, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 16, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131103006283, 17, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 1, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 2, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 3, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 4, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 5, 111, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 6, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 7, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 8, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 9, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 10, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 11, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 12, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 13, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 14, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 15, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006284, 16, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212006285, 1, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212006285, 2, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212006285, 3, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212006285, 4, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212006285, 5, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 1, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 2, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 3, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 4, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 5, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 6, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 7, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216006286, 8, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 1, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 2, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 3, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 4, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 5, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 6, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002006287, 7, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829006288, 1, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829006288, 2, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 10, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 11, 41, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 12, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 13, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 14, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 15, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803006646, 16, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 1, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 2, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 3, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 4, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 5, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 6, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 7, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 8, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 9, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 10, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 11, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 12, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 13, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818006647, 14, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 1, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 2, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 3, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 4, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 5, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 6, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 7, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 8, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 9, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 10, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 11, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 12, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 13, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126006648, 14, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 1, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 2, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 3, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 4, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 5, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 6, 183, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 7, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011006649, 8, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706006650, 1, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706006650, 2, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706006650, 3, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706006650, 4, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706006650, 5, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 1, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 2, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 3, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 4, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 5, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 6, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 7, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 8, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 9, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 10, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 11, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 12, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 13, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 14, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 15, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130515006651, 16, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 1, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 2, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 3, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 4, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 5, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 6, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 7, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 8, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810006652, 9, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 1, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 2, 65, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 3, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 4, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 5, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 6, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 7, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 8, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 9, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 10, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 11, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 12, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 13, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 14, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111231006653, 15, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 1, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 2, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 3, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 4, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 5, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 6, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 7, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 8, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 9, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 10, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522006654, 11, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 1, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 2, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 3, 36, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 4, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 5, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 6, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 7, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 8, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 9, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 10, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021006655, 11, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 1, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 2, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 3, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 4, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 5, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 6, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 7, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 8, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 9, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 10, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 11, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 12, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 13, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 14, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621006656, 15, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 1, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 2, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 3, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 4, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 5, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 6, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 7, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 8, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 9, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006657, 10, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 1, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 2, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 3, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 4, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 5, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 6, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 7, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 8, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 9, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 10, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 11, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813006658, 12, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 1, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 2, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 3, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 4, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 5, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 6, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 7, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 8, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 9, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 10, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 11, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 12, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 13, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 14, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 15, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 16, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611006659, 17, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 1, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 2, 2, 27, 4, 108);
commit;
prompt 63000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 3, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 4, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 5, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 6, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 7, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 8, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 9, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 10, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 11, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 12, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 13, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 14, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 15, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 16, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 17, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112006660, 18, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 1, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 2, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 3, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 4, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 5, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 6, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 7, 171, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 8, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 9, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 10, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006661, 11, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914006662, 1, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914006662, 2, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914006662, 3, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914006662, 4, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 1, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 2, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 3, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 4, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 5, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 6, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 7, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 8, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 9, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826006663, 10, 161, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 1, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 2, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 3, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 4, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 5, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 6, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 7, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 8, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 9, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 10, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422006664, 11, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 1, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 2, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 3, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 4, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 5, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 6, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 7, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 8, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 9, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 10, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927006665, 11, 46, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 1, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 2, 32, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 3, 155, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 4, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 5, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 6, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 7, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 8, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 9, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 10, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 3, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 4, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 5, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 6, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 7, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 8, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 9, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 10, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 11, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 12, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 13, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 14, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 1, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 2, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 3, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 4, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 5, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 6, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 7, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 8, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 9, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 10, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 11, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 12, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 13, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 14, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007025, 15, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 1, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 2, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 3, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 4, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 5, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 6, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 7, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 8, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 9, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 10, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 11, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 12, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910007026, 13, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 1, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 2, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 3, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 4, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 5, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 6, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 7, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 8, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 9, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 10, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 11, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 12, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 13, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 14, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 15, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126007027, 16, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 1, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 2, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 3, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 4, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 5, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 6, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 7, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 8, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 9, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 10, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 11, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 12, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229007028, 13, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 1, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 2, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 3, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 4, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 5, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703007029, 6, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026007030, 1, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026007030, 2, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026007030, 3, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026007030, 4, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026007030, 5, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 1, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 2, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 3, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 4, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 5, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 6, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 7, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326007031, 8, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 1, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 2, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 3, 122, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 4, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 5, 119, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323007032, 6, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116007033, 1, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116007033, 2, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116007033, 3, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 1, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 2, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 3, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 4, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 5, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 6, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 7, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 8, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 9, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 10, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 11, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 12, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 13, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 14, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 15, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 16, 47, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416007034, 17, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 1, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 2, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 3, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 4, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 5, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 6, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 7, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007035, 8, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 1, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 2, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 3, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 4, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 5, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 6, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101007036, 7, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 1, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 2, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 3, 54, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 4, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 5, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 6, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 7, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 8, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 9, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 10, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 11, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 12, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215007037, 13, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 1, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 2, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 3, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 4, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 5, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217007038, 6, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 1, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 2, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 3, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 4, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 5, 155, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 6, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 7, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 8, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 9, 118, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 10, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 11, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081009007039, 12, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 1, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 2, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 3, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 4, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 5, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 6, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 7, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 8, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 9, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 10, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 11, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008007040, 12, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007041, 1, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007041, 2, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007041, 3, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007041, 4, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 1, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 2, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 3, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 4, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 5, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 6, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 7, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 8, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 9, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 10, 192, 49, 18, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 11, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 12, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101128007042, 13, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 1, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 2, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 3, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 4, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 5, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 6, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212007043, 7, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 1, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 2, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 3, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 4, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 5, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 6, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 7, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 8, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 9, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 10, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 11, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 12, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 13, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 14, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 15, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709007044, 16, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 1, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 2, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 3, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 4, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 5, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 6, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 7, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 8, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 9, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070822007045, 10, 168, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007046, 1, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007046, 2, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007046, 3, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007046, 4, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 1, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 2, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 3, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 4, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 5, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 6, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 7, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 8, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 9, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 10, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 11, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 12, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 1, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 2, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 3, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 4, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 5, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 6, 32, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 7, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 8, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 9, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216005880, 10, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308005881, 1, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308005881, 2, 1, 30, 3, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308005881, 3, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308005881, 4, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308005881, 5, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 1, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 2, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 3, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 4, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 5, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 6, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 7, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 8, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 9, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 10, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 11, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 12, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 13, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 14, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 15, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621005882, 16, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 1, 62, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 2, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 3, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 4, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 5, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303005883, 6, 191, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 1, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 2, 63, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 3, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 4, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 5, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 6, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 7, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 8, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 9, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625005884, 10, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 1, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 2, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 3, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 4, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 5, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 6, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 7, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 8, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 9, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 10, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 11, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 12, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 13, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 14, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 15, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 16, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322005885, 17, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 1, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 2, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 3, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 4, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 5, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 6, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 7, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 8, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 9, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 10, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 11, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 12, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 13, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 14, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 15, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 16, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227005886, 17, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 1, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 2, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 3, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 4, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 5, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 6, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 7, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 8, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122005887, 9, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 1, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 2, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 3, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 4, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 5, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 6, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109005888, 7, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005889, 1, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005889, 2, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005889, 3, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005889, 4, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005889, 5, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219005890, 1, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219005890, 2, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219005890, 3, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 1, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 2, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 3, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 4, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 5, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113005891, 6, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 1, 146, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 2, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 3, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 4, 72, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 5, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 6, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 7, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 8, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120005892, 9, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011005893, 1, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011005893, 2, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011005893, 3, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011005893, 4, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011005893, 5, 90, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 1, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 2, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 3, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 4, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 5, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 6, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 7, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 8, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427005894, 9, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 1, 118, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 2, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 3, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 4, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 5, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 6, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 7, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 8, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 9, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 10, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 11, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 12, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405005895, 13, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220005896, 1, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220005896, 2, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220005896, 3, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220005896, 4, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220005896, 5, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 1, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 2, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 3, 177, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 4, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 5, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 6, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 7, 100, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 8, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 9, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 10, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 11, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 12, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 13, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 14, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120128005897, 15, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 1, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 2, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 3, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 4, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 5, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 6, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 7, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 8, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 9, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 10, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801005898, 11, 146, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 1, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 2, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 3, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 5, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 6, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 7, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 8, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 9, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 10, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 11, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 12, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 13, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 14, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 15, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 16, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123005899, 17, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 1, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 2, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 3, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 4, 129, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 5, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 6, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 7, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 8, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 9, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 10, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 11, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605005900, 12, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508005901, 1, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508005901, 2, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508005901, 3, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508005901, 4, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 1, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 2, 80, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 3, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 4, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 5, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 6, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 7, 4, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 8, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 9, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 10, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 11, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 12, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130005902, 13, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 1, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 2, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 3, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 4, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 5, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 6, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 7, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 8, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120005903, 9, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 1, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 2, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 3, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 4, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 5, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 6, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829006288, 3, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829006288, 4, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 1, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 2, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 3, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 4, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 5, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 6, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 7, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 8, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 9, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 10, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 11, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 12, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 13, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 14, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110630006289, 15, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 1, 114, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 2, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 3, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 4, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 5, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809006290, 6, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213006291, 1, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213006291, 2, 105, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213006291, 3, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213006291, 4, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715006292, 1, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715006292, 2, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715006292, 3, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715006292, 4, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715006292, 5, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 1, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 2, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 3, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 4, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 5, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 6, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 7, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 8, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107006293, 9, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 1, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 2, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 3, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 4, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 5, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602006294, 6, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 1, 175, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 2, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 3, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 4, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 5, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 6, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 7, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 8, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 9, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 10, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 11, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 12, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 13, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 14, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 15, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 16, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227006295, 17, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 1, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 2, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 3, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 4, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 5, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 6, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 7, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 8, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 9, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 10, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 11, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 12, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 13, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 14, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027006296, 15, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031118006297, 1, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031118006297, 2, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031118006297, 3, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031118006297, 4, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031118006297, 5, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 1, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 2, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 3, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 4, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 5, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 6, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 7, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 8, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 9, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 10, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 11, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109006298, 12, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 1, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 2, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 3, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 4, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 5, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 6, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 7, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 8, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 9, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 10, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 11, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 12, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 13, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 14, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 15, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128006299, 16, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114006300, 1, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114006300, 2, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114006300, 3, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114006300, 4, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329006301, 1, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329006301, 2, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329006301, 3, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329006301, 4, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228006302, 1, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228006302, 2, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228006302, 3, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228006302, 4, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228006302, 5, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 1, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 2, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 3, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 4, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 5, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 6, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 7, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 8, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 9, 51, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 10, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117006303, 11, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 1, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 2, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 3, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 4, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 5, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 6, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 7, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 8, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 9, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 10, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 11, 187, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 12, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 13, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124006304, 14, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 1, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 2, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 3, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 4, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 5, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 6, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 7, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 8, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617006305, 9, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 1, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 2, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 3, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 4, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 5, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 6, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 7, 192, 38, 18, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 8, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 9, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 10, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070502006306, 11, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 1, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 2, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 3, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 4, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 5, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 6, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 7, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 8, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 9, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 10, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 11, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 12, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 13, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407006307, 14, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 1, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 2, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 3, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 4, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 5, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 6, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 7, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 8, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 9, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 10, 128, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 11, 160, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 12, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 13, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 14, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 15, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 16, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822006308, 17, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 1, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 2, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 3, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 4, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 5, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 6, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 7, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 8, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 9, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 10, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 11, 30, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 12, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 13, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 14, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 15, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008006309, 16, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 1, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 2, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 3, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 4, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 5, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 6, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 7, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 8, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 9, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 10, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 11, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 12, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 13, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 14, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 15, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 16, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503006310, 17, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 1, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 2, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 3, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 4, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 11, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 12, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006666, 13, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 1, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 2, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 3, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 4, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 5, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 6, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 7, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107006667, 8, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616006668, 1, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616006668, 2, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616006668, 3, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000616006668, 4, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 1, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 2, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 3, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 5, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 6, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 7, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 8, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 9, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 10, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 11, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 12, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 13, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 14, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110325006669, 15, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 1, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 2, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 3, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 4, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 5, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 6, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 7, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 8, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 9, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 10, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 11, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 12, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821006670, 13, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 1, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 2, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 3, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 4, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 5, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 6, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 7, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 8, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 9, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 10, 93, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 11, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 12, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 13, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 14, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211006671, 15, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 1, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 2, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 3, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 4, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 5, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 6, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 7, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 8, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 9, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 10, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 11, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090723006672, 12, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 1, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 2, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 3, 145, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 4, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 5, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020006673, 6, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 1, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 2, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 3, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 4, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 5, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 6, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 7, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 8, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 9, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 10, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 11, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 12, 64, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 13, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726006674, 14, 50, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 1, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 2, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 3, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 4, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 5, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 6, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 7, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 8, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929006675, 9, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620006676, 1, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620006676, 2, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620006676, 3, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620006676, 4, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 1, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 2, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 3, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 4, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 5, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 6, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 7, 123, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127006677, 8, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 1, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 2, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 3, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 4, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 5, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 6, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 7, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050829006678, 8, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 1, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 2, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 3, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 4, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 5, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 6, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 7, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 8, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 9, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 10, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 11, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081207006679, 12, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 1, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 2, 150, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 3, 112, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 4, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 5, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 6, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 7, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030701006680, 8, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131006681, 1, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131006681, 2, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131006681, 3, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010131006681, 4, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 1, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 2, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 3, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 4, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 5, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 6, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 7, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 8, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113006682, 9, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 1, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 2, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 3, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 4, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 5, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 6, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 7, 10, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 8, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 9, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 10, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 11, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 12, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026006683, 13, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 1, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 2, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 3, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 4, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 5, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227006684, 6, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 1, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 2, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 3, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 4, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 5, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 6, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 7, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 8, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 9, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 10, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 11, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 12, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 13, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 14, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223006685, 15, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 1, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 2, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 3, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 4, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 5, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 6, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 7, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120006686, 8, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 1, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 2, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 3, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 4, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 5, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 6, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 7, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 8, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 9, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 10, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 11, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 12, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 13, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 14, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506006687, 15, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 1, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 2, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 3, 106, 26, 8, 208);
commit;
prompt 64000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 4, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 5, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 6, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 7, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006688, 8, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 1, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 2, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 3, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 4, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 5, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 6, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 7, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 8, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 9, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 10, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 11, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 12, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626006689, 13, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 1, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 2, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 3, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 4, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 5, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 6, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 7, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 8, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 9, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 10, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 11, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 12, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 13, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 14, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 15, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 16, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 17, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130815007096, 18, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 1, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 2, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 3, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 4, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 5, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 6, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019007097, 7, 116, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 1, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 2, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 3, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 4, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 5, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 6, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 7, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 8, 167, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 9, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 10, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 11, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 12, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128007098, 13, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 1, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 2, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 3, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 4, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 5, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 6, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525007099, 7, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 1, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 2, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 3, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 4, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 5, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 6, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 7, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 8, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 9, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 10, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007100, 11, 138, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 1, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 2, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 3, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 4, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 5, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107007101, 6, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710007102, 1, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710007102, 2, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710007102, 3, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710007102, 4, 82, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710007102, 5, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 1, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 2, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 3, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 4, 74, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 5, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 6, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 7, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 8, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 9, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402007103, 10, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 1, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 2, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 3, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 4, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 5, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 6, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 7, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 8, 117, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 9, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 10, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522007104, 11, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 1, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 2, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 3, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 4, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 5, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 6, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040720007105, 7, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 1, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 2, 69, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 3, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 4, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 5, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 6, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 7, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 8, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 9, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 10, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 11, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 12, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 13, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 14, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 15, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 16, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323007106, 17, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 1, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 2, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 3, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 4, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 5, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 6, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 7, 165, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724007107, 8, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 1, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 2, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 3, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 4, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 5, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 6, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 7, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 8, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 9, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 10, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 11, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 12, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 13, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 14, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 15, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007108, 16, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 1, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 2, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 3, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 4, 65, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 5, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 6, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 7, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 8, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 9, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 10, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 11, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225007109, 12, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815007110, 1, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815007110, 2, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815007110, 3, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815007110, 4, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815007110, 5, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 1, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 2, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 3, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 4, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 5, 31, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 6, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 7, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305007111, 8, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 1, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 2, 7, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 3, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 4, 163, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 5, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 6, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 7, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 8, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 9, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 10, 90, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 11, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 12, 182, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 13, 176, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 14, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131202007112, 15, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 1, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 2, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 3, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 4, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 5, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212007113, 6, 60, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 1, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 2, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 3, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 4, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 5, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 6, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 7, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 8, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 9, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 10, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 11, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322007114, 12, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 1, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 2, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 3, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 4, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 5, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 6, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 7, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 8, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710007115, 9, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 1, 35, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 2, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 3, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 4, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 5, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 6, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 7, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 8, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 9, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 10, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 11, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 12, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509007116, 13, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 1, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 2, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 3, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 4, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 5, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 6, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 7, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 8, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 9, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 10, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 11, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 12, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 13, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 14, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007117, 15, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 1, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 2, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 3, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 4, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 5, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 6, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 7, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 8, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 9, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 10, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 11, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 12, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090920007118, 13, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 1, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 2, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 3, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 4, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 7, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 8, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 9, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 10, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 11, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 12, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 13, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327005904, 14, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 1, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 2, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 3, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 4, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 5, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 6, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 7, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 8, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040501005905, 9, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 1, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 2, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 3, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 4, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 5, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 6, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 7, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 8, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 9, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 10, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 11, 57, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 12, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 13, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 14, 72, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102005906, 15, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 1, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 2, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 3, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 4, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 5, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 6, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 7, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 8, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 9, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 10, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208005907, 11, 16, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 1, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 2, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 3, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 4, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 5, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 6, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 7, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 8, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 9, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 10, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 11, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 12, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 13, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 14, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814005908, 15, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 1, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 2, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 3, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 4, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 5, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 6, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 7, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 8, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 9, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 10, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 11, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224005909, 12, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 1, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 2, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 3, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 4, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 5, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 6, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 7, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 8, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 9, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 10, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090122005910, 11, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 1, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 2, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 3, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 4, 113, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 5, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 6, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 7, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 8, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 9, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 10, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 11, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 12, 160, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125005911, 13, 32, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604005912, 1, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604005912, 2, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604005912, 3, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 1, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 2, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 3, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 4, 99, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 5, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 6, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030116005913, 7, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 1, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 2, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 3, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 4, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 5, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708005914, 6, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511005915, 1, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511005915, 2, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511005915, 3, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 1, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 2, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 3, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 4, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 5, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 6, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 7, 1, 94, 3, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 8, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 9, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 10, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 11, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 12, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 13, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 14, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 15, 157, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 16, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303005916, 17, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 1, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 2, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 3, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 4, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 5, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 6, 192, 87, 18, 1566);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 7, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 8, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 9, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 10, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 11, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 12, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413005917, 13, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 1, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 2, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 3, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 4, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 5, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 6, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 7, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 8, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 9, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 10, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 11, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 12, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103005918, 13, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 1, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 2, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 3, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 4, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 5, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 6, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314005919, 7, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 1, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 2, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 3, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 4, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 5, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 6, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 7, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 8, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 9, 116, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 10, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 11, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 12, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 13, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 14, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617005920, 15, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 1, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 2, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 3, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 4, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 5, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 6, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 7, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 8, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 9, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 10, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 11, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 12, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 13, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 14, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505005921, 15, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715005922, 1, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715005922, 2, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715005922, 3, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 1, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 2, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 3, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 4, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 5, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 6, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 7, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 8, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 9, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 10, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 11, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 12, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 13, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129005923, 14, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 1, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 2, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 3, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 4, 123, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 5, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403005924, 6, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129005925, 1, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129005925, 2, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129005925, 3, 46, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129005925, 4, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 1, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 2, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 3, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 4, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 5, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 6, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 7, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423005926, 8, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 1, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 2, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 3, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 4, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 5, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 6, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 7, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 8, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 9, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926005927, 10, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 1, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 5, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 6, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 7, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 8, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 9, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 10, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 11, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 12, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 13, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 14, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403006311, 15, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 1, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 2, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 3, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 4, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 5, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040307006312, 6, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 1, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 2, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 3, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 4, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 5, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 6, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 7, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 8, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 9, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 10, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222006313, 11, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029006314, 1, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029006314, 2, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029006314, 3, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029006314, 4, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029006314, 5, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203006315, 1, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203006315, 2, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203006315, 3, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203006315, 4, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 1, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 2, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 3, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 4, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 5, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 6, 105, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 7, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 8, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 9, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 10, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222006316, 11, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 1, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 2, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 3, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 4, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 5, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 6, 31, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 7, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 8, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 9, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 10, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060904006317, 11, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 1, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 2, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 3, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 4, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 5, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 6, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 7, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808006318, 8, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 1, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 2, 189, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 3, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 4, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 5, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 6, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 7, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 8, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 9, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 10, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 11, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 12, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105006319, 13, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 1, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 2, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 3, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 4, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 5, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210006320, 6, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 1, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 2, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 3, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 4, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 5, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 6, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 7, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 8, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 9, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 10, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 11, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 12, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 13, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 14, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 15, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 16, 186, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 17, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413006321, 18, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308006322, 1, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308006322, 2, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308006322, 3, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308006322, 4, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308006322, 5, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127006323, 1, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127006323, 2, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 1, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 2, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 3, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 4, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 5, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 6, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 7, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 8, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 9, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 10, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 11, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 12, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 13, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 14, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 15, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725006324, 16, 54, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 1, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 2, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 3, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 4, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 5, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 6, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 7, 69, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 8, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 9, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 10, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 11, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 12, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 13, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 14, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004006325, 15, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 1, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 2, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 3, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 4, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 5, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 6, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 7, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 8, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 9, 122, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 10, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 11, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 12, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 13, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118006326, 14, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 1, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 2, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 3, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 4, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 5, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 6, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 7, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 8, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 9, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 10, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 11, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 12, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 13, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821006327, 14, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 1, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 2, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 3, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 4, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 5, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 6, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 7, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006328, 8, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 1, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 2, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 3, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 4, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 5, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 6, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715006329, 7, 93, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 1, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 2, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 3, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 4, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 5, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 6, 116, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 7, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 8, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 9, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 10, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 11, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 12, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 13, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 14, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 15, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310006330, 16, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 1, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 2, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 3, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 4, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 5, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406006331, 6, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131006332, 1, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131006332, 2, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131006332, 3, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131006332, 4, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131006332, 5, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 1, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 2, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 3, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 4, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 5, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 6, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 7, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 8, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 9, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 10, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710006333, 11, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702006334, 1, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702006334, 2, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702006334, 3, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 1, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 2, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 3, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 4, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 5, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 6, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 7, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 8, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 9, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 10, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 11, 137, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 12, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 13, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 10, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 11, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 12, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 13, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717006690, 14, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 1, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 2, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 3, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 4, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 5, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 6, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 7, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 8, 121, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 9, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 10, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928006691, 11, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 1, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 2, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 3, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 4, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 5, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 6, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 7, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 8, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 9, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 10, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 11, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 12, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707006692, 13, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 1, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 2, 81, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 3, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 4, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 5, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 6, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 7, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 8, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 9, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327006693, 10, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 1, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 2, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 3, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 4, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 5, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 6, 181, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 7, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208006694, 8, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 1, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 2, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 3, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 4, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 5, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 6, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 7, 15, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 8, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 9, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115006695, 10, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 1, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 2, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 3, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 4, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 5, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511006696, 6, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 1, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 2, 164, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 3, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 4, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 5, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 6, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 7, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 8, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 9, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411006697, 10, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 1, 152, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 2, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 3, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 4, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 5, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 6, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 7, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 8, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 9, 84, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 10, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 11, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 12, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 13, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 14, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 15, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 16, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520006698, 17, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 1, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 2, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 3, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 4, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 5, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 6, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 7, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 8, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 9, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 10, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 11, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804006699, 12, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 1, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 2, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 3, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 4, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 5, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 6, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050603006700, 7, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014006701, 1, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014006701, 2, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014006701, 3, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006702, 1, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006702, 2, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006702, 3, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006702, 4, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621006703, 1, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621006703, 2, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621006703, 3, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621006703, 4, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 1, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 2, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 3, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 4, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 5, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 6, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 7, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 8, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 9, 99, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719006704, 10, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006705, 1, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006705, 2, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006705, 3, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006705, 4, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006705, 5, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 1, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 2, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 3, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 4, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 5, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211006706, 6, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 1, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 2, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 3, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 4, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 5, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 6, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 7, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 8, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 9, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 10, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 11, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 12, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 13, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 14, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420006707, 15, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 1, 38, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 2, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 3, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 4, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 5, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 6, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 7, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 8, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 9, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502006708, 10, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 1, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 2, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 3, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 4, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 5, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 6, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 7, 161, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 8, 167, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 9, 120, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 10, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 11, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006709, 12, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 1, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 2, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 3, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 4, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 5, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 6, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 7, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 8, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 9, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 10, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 11, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006710, 12, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 1, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 2, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 3, 64, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 4, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 5, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 6, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 7, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 8, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 9, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 10, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 11, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 12, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 13, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 14, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 15, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312006711, 16, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 1, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 2, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 3, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 4, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 5, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111006712, 6, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 1, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 2, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 3, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 4, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 5, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 6, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 7, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 8, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 9, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 10, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 11, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 12, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 13, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 14, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017006713, 15, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 1, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 2, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 3, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 4, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 5, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 6, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 7, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 8, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 9, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 10, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 11, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 12, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 5, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 6, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 7, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 8, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417007001, 9, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108007002, 1, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108007002, 2, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108007002, 3, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108007002, 4, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108007002, 5, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 1, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 2, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 3, 99, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 4, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 5, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 6, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 7, 70, 95, 10, 950);
commit;
prompt 65000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 8, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 9, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 10, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 11, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 12, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 13, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 14, 51, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419007003, 15, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 1, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 2, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 3, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 4, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 5, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 6, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111007004, 7, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 1, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 2, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 3, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 4, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 5, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 6, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 7, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 8, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 9, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 10, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 11, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007005, 12, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 1, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 2, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 3, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 4, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 5, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524007006, 6, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215007007, 1, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215007007, 2, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 1, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 2, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 3, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 4, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 5, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 6, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 7, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 8, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 9, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 10, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 11, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126007008, 12, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 1, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 2, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 3, 168, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 4, 32, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 5, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 6, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 7, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 8, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 9, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 10, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006007009, 11, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513007010, 1, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513007010, 2, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513007010, 3, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513007010, 4, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 1, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 2, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 3, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 4, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 5, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 6, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 7, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 8, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 9, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 10, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 11, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 12, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 13, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 14, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314007011, 15, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 1, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 2, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 3, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 4, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 5, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 6, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 7, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 8, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 9, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 10, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102007012, 11, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 1, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 2, 103, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 3, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 4, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 5, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 6, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 7, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 8, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 9, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821007013, 10, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109007014, 1, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109007014, 2, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109007014, 3, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109007014, 4, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 1, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 2, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 3, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 4, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 5, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 6, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 7, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 8, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 9, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810007015, 10, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 1, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 2, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 3, 166, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 4, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 5, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 6, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 7, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 8, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 9, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 10, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 11, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 12, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090107007016, 13, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 1, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 2, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 3, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 4, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 5, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 6, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 7, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 8, 168, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 9, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 10, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 11, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 12, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 13, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 14, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 15, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 16, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 17, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 18, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408007017, 19, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 1, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 2, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 3, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 4, 59, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 5, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 6, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 7, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 8, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 9, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 10, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 11, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 12, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 13, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 14, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129007018, 15, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 1, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 2, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 3, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 4, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 5, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 6, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 7, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 8, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 9, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 10, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 11, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 12, 192, 81, 18, 1458);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 13, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 14, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120508007019, 15, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 1, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 2, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 3, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 4, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 5, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 6, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 7, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007020, 8, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 1, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 2, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 3, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 4, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 5, 176, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 6, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 7, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 8, 178, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 9, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 10, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 11, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 12, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 13, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 14, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007021, 15, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 1, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 2, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 3, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 4, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 5, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 6, 158, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 7, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 8, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 9, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 10, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 11, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 12, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106007022, 13, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 1, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 3, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 4, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 5, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 6, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 7, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 8, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 9, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215007023, 10, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 1, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424007024, 2, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 2, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 3, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 4, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 5, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 6, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 7, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008005928, 8, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 1, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 2, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 3, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 4, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 5, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 6, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 7, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 8, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 9, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409005929, 10, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117005930, 1, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117005930, 2, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 1, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 2, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 3, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 4, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 5, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 6, 3, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 7, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603005931, 8, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005932, 1, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005932, 2, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005932, 3, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005932, 4, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005932, 5, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 1, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 2, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 3, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 4, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 5, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 6, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 7, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630005933, 8, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005934, 1, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005934, 2, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002005934, 3, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 1, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 2, 54, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 3, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 4, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 5, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 6, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 7, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 8, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 9, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 10, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 11, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006005935, 12, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 1, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 2, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 3, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 4, 125, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 5, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 6, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 7, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 8, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 9, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 10, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117005936, 11, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111005937, 1, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111005937, 2, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111005937, 3, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 1, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 2, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 3, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 4, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 5, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 6, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 7, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 8, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 9, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 10, 184, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 11, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 12, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 13, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 14, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 15, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 16, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104005938, 17, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 1, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 2, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 3, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 4, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 5, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 6, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 7, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 8, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 9, 148, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070320005939, 10, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 1, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 2, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 3, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 4, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 5, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109005940, 6, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 1, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 2, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 3, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 4, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 5, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 6, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 7, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908005941, 8, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 1, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 2, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 3, 152, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 4, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 5, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 6, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 7, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 8, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 9, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 10, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 11, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 12, 174, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 13, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 14, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 15, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 16, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427005942, 17, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 1, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 2, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 3, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 4, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 5, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 6, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 7, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723005943, 8, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 1, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 2, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 3, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 4, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 5, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 6, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 7, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 8, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 9, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 10, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005944, 11, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 1, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 2, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 3, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 4, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 5, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 6, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 7, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 8, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 9, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 10, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 11, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 12, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124005945, 13, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 1, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 2, 132, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 3, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 4, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 5, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 6, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 7, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 8, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 9, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 10, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 11, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 12, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 13, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403005946, 14, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 1, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 2, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 3, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 4, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 5, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 6, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 7, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 8, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 9, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 10, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 11, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525005947, 12, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 1, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 2, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 3, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 4, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 5, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 6, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 7, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 8, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 9, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 10, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823005948, 11, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 1, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 2, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 3, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 4, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 5, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 6, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 7, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 8, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 9, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316005949, 10, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 1, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 2, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 3, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 4, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 5, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 6, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 7, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 8, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 9, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022005950, 10, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 1, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 2, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 3, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 4, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 5, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 6, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 7, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 8, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 9, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901005951, 10, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 1, 170, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 2, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 3, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 4, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 5, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 6, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 7, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 8, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 9, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 10, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 11, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 12, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 13, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 14, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501006335, 15, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408006336, 1, 177, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408006336, 2, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226006337, 1, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226006337, 2, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226006337, 3, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226006337, 4, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 1, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 2, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 3, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 4, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 5, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 6, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 7, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 8, 66, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 9, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015006338, 10, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407006339, 1, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000407006339, 2, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210006340, 1, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210006340, 2, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210006340, 3, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210006340, 4, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604006341, 1, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604006341, 2, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604006341, 3, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000604006341, 4, 19, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123006342, 1, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123006342, 2, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123006342, 3, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123006342, 4, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615006343, 1, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615006343, 2, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615006343, 3, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 1, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 2, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 3, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 4, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 5, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 6, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 7, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 8, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 9, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617006344, 10, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 1, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 2, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 3, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 4, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 5, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 6, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 7, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 8, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 9, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 10, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 11, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 12, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 13, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 14, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 15, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203006345, 16, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213006346, 1, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213006346, 2, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213006346, 3, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 1, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 2, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 3, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 4, 150, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 5, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 6, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 7, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 8, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 9, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 10, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 11, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 12, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 13, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 14, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 15, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420006347, 16, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 1, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 2, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 3, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 4, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 5, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 6, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 7, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 8, 108, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 9, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002006348, 10, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 1, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 2, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 3, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 4, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 5, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 7, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 8, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 9, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 10, 17, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122006349, 11, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 1, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 2, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 3, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 4, 72, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 5, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 6, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 7, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 8, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 9, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 10, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 11, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 12, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 13, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 14, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 15, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726006350, 16, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 1, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 2, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 3, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 4, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 5, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 6, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 7, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922006351, 8, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 1, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 2, 132, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 3, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 4, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 5, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 6, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 7, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 8, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 9, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 10, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 11, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 12, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 13, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 14, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 15, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 16, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140110006352, 17, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 1, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 2, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 3, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 4, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 5, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220006353, 6, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 1, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 2, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 3, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 4, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 5, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 6, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 7, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 8, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 9, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 10, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 11, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 12, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218006354, 13, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006355, 1, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006355, 2, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622006355, 3, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 1, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 2, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 3, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 4, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 5, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 6, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 7, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 8, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 9, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917006356, 10, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 1, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 2, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 3, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 4, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 5, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 6, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 7, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 8, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 9, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424006357, 10, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 1, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 2, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 3, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 4, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 5, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530006358, 6, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 1, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 2, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 3, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 4, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 5, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410006359, 6, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 1, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 2, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 3, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 4, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 5, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 6, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 7, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 8, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421006360, 9, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 1, 77, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 2, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 3, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 4, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 5, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 6, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 7, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 8, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 9, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 10, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 11, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 12, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 13, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227006361, 14, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 1, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 2, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 3, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 4, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 5, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 6, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 7, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 8, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228006362, 9, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 1, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 2, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 3, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 4, 51, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 5, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 6, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 7, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 8, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 9, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 10, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516006363, 11, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 13, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 14, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709006714, 15, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 1, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 2, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 3, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 4, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 5, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 6, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 7, 167, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 8, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 9, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 10, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 11, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 12, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 13, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 14, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908006715, 15, 124, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 1, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 2, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 3, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 4, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 5, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 6, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 7, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 8, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 9, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 10, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522006716, 11, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 1, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 2, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 3, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 4, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 5, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 6, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708006717, 7, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 1, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 2, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 3, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 4, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 5, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 6, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 7, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 8, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 9, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050818006718, 10, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 1, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 2, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 3, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 4, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 5, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 6, 97, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 7, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 8, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 9, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 10, 45, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114006719, 11, 25, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 1, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 2, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 3, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 4, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 5, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 6, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 7, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 8, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 9, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 10, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 11, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 12, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409006720, 13, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 1, 189, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 2, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 3, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 4, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 5, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 6, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 7, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 8, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 9, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 10, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006721, 11, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 1, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 2, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 3, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 4, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 5, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 6, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 7, 147, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 8, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 9, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 10, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 11, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 12, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 13, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324006722, 14, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 1, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 2, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 3, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 4, 152, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 5, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 6, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 7, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 8, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 9, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 10, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 11, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080808006723, 12, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 1, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 2, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 3, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 4, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 5, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 6, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 7, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 8, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 9, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 10, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 11, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 12, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 13, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915006724, 14, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 1, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 2, 22, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 3, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 4, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 5, 159, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 6, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 7, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 8, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 9, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 10, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 11, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 12, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 13, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 14, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 15, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007006725, 16, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219006726, 1, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219006726, 2, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219006726, 3, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219006726, 4, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 1, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 2, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 3, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 4, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 5, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 6, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 7, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 8, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 9, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 10, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 11, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 12, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 13, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224006727, 14, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 1, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 2, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 3, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 4, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 5, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 6, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 7, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 8, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 9, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 10, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 11, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 12, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702006728, 13, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 1, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 2, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 3, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 4, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 5, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 6, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 7, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 8, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 9, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 10, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023006729, 11, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317006730, 1, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317006730, 2, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317006730, 3, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317006730, 4, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317006730, 5, 116, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 1, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 2, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 3, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 4, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 5, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 6, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 7, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 8, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 9, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 10, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 11, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319006731, 12, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 1, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 2, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 3, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 4, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 5, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 6, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 7, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006732, 8, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 1, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 2, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 3, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 4, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 5, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 6, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 7, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 8, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 9, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 10, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 11, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 12, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 13, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 14, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130916006733, 15, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 1, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 2, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 3, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 4, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 5, 94, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 6, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 7, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 8, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 9, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 10, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 11, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 12, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 13, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 14, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 15, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006734, 16, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 1, 46, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 2, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 3, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 4, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 13, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821007047, 14, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 1, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 2, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 3, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 4, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 5, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 6, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 7, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 8, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 9, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 10, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226007048, 11, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 1, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 2, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 3, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 4, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 5, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 6, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017007049, 7, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 1, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 2, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 3, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 4, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 5, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 6, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 7, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 8, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 9, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 10, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 11, 73, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903007050, 12, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023007051, 1, 25, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023007051, 2, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023007051, 3, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023007051, 4, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023007051, 5, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 1, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 2, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 3, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 4, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 5, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 6, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 7, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 8, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 9, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 10, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 11, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 12, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 13, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 14, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321007052, 15, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 1, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 2, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 3, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 4, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 5, 128, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 6, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 7, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 8, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 9, 11, 14, 6, 84);
commit;
prompt 66000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 10, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 11, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 12, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 13, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 14, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819007053, 15, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412007054, 1, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412007054, 2, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412007054, 3, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412007054, 4, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 1, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 2, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 3, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 4, 99, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 5, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 6, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 7, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 8, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 9, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 10, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 11, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 12, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 13, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 14, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 15, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110302007055, 16, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116007056, 1, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116007056, 2, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116007056, 3, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116007056, 4, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116007056, 5, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 1, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 2, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 3, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 4, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 5, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 6, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 7, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 8, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604007057, 9, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 1, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 2, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 3, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 4, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 5, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 6, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 7, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 8, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 9, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 10, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 11, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 12, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728007058, 13, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 1, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 2, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 3, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 4, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 5, 139, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 6, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 7, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 8, 101, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 9, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 10, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 11, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118007059, 12, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123007060, 1, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123007060, 2, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123007060, 3, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123007060, 4, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123007060, 5, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021007061, 1, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021007061, 2, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021007061, 3, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011021007061, 4, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 1, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 2, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 3, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 4, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 5, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 6, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 7, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 8, 105, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 9, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 10, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 11, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202007062, 12, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309007063, 1, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309007063, 2, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309007063, 3, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309007063, 4, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309007063, 5, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 1, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 2, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 3, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 4, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 5, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 6, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 7, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 8, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 9, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 10, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505007064, 11, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 1, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 2, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 3, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 4, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 5, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 6, 192, 43, 18, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 7, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 8, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 9, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 10, 185, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 11, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 12, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 13, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 14, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301007065, 15, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007066, 1, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007066, 2, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007066, 3, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007066, 4, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705007066, 5, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007067, 1, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007067, 2, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007067, 3, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007067, 4, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 1, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 2, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 3, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 4, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 5, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 6, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 7, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 8, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 9, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 10, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 11, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 12, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 13, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 14, 31, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406007068, 15, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119007069, 1, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119007069, 2, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119007069, 3, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820007070, 1, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820007070, 2, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820007070, 3, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820007070, 4, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 1, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 2, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 3, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 4, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 5, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712007071, 6, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 1, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 2, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 3, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 4, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 5, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 6, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007072, 7, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 1, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 2, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 3, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 4, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 5, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 6, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 7, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 8, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 9, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 10, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 11, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 12, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 13, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 14, 140, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 15, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 16, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205007073, 17, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 14, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 15, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 16, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426005952, 17, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 1, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 2, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 3, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 4, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 5, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 6, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 7, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 8, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 9, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 10, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210005953, 11, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501005954, 1, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501005954, 2, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501005954, 3, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 1, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 2, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 3, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 4, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 5, 120, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 6, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 7, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 8, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 9, 53, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 10, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716005955, 11, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 1, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 2, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 3, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 4, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 5, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 6, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 7, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316005956, 8, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 1, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 2, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 3, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 4, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 5, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708005957, 6, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 1, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 2, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 3, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 4, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 5, 56, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 6, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114005958, 7, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 1, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 2, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 3, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 4, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 5, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 6, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 7, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 8, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060308005959, 9, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 1, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 3, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 4, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 5, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 6, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 7, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 8, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 9, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 10, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 11, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 12, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 13, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 14, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 15, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002005960, 16, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 1, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 2, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 3, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 4, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 5, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 6, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 7, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 8, 17, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 9, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310005961, 10, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 1, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 2, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 3, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 4, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 5, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 6, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 7, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 8, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 9, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 10, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 11, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 12, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807005962, 13, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 1, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 2, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 3, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 4, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 5, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210005963, 6, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 1, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 2, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 3, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 4, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 5, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 6, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 7, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 8, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 9, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 10, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 11, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 12, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 13, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220005964, 14, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 1, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 2, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 3, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 4, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 5, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 6, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 7, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 8, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 9, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 10, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627005965, 11, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911005966, 1, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911005966, 2, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 1, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 2, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 3, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 4, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 5, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 6, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 7, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 8, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 9, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 10, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 11, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 12, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902005967, 13, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 1, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 2, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 3, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 4, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 6, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 7, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 8, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 9, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 10, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 11, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 12, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 13, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 14, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 15, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 16, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616005968, 17, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 1, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 2, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 3, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 4, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 5, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 6, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 7, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 8, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 9, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 10, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 11, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928005969, 12, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 1, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 2, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 3, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 4, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 5, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 6, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 7, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 8, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 9, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 10, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 11, 143, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 12, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 13, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 14, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 15, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321005970, 16, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 1, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 2, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 3, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 4, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 5, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 6, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 7, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 8, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 9, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208005971, 10, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 1, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 2, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 3, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 4, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 5, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 6, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 7, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227005972, 8, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 1, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 2, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 3, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 4, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 5, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 6, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 7, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 8, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 9, 145, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 10, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 11, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 12, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 13, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 14, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 15, 57, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728005973, 16, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 1, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 2, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 3, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 4, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 5, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 6, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 7, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 8, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 9, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 10, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 11, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 12, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 13, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703005974, 14, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 1, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 2, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 1, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 2, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 3, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 4, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 5, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 6, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 7, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 8, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329006364, 9, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 1, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 2, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 3, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 4, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 5, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 6, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 7, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 8, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 9, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 10, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 11, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 12, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825006365, 13, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 1, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 2, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 3, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 4, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 5, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 6, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 7, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 8, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 9, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 10, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 11, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 12, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 13, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317006366, 14, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707006367, 1, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707006367, 2, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707006367, 3, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707006367, 4, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007006368, 1, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007006368, 2, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007006368, 3, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007006368, 4, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007006368, 5, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 1, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 2, 54, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 3, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 4, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 5, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 6, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 7, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 8, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 9, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 10, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 11, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 12, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 13, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 14, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225006369, 15, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 1, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 2, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 3, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 4, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 5, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 6, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 7, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 8, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 9, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 10, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626006370, 11, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 1, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 2, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 3, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 4, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 5, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 6, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 7, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 8, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 9, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319006371, 10, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 1, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 2, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 3, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 4, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 5, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 6, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 7, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 8, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 9, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308006372, 10, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 1, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 2, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 3, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 4, 141, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 5, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 6, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 7, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 8, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 9, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 10, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 11, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 12, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 13, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818006373, 14, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 1, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 2, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 3, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 4, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 5, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 6, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 7, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 8, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 9, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 10, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 11, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 12, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 13, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 14, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006374, 15, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 1, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 2, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 3, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 4, 51, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 5, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 6, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 7, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 8, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 9, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 10, 176, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 11, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409006375, 12, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 1, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 2, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 3, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 4, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 5, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 6, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 7, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 8, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 9, 175, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 10, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 11, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 12, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 13, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 14, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 15, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 16, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315006376, 17, 185, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 1, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 2, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 3, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 4, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 5, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 6, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 7, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 8, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 9, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 10, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 11, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090721006377, 12, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 1, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 2, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 3, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 4, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 5, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323006378, 6, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 1, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 2, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 3, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 4, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 5, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 6, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 7, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 8, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813006379, 9, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 1, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 2, 64, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 3, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 4, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 5, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 6, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 7, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 8, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 9, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 10, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 11, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 12, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 13, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504006380, 14, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 1, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 2, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 3, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 4, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 5, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 6, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 7, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 8, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 9, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 10, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 11, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 12, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006381, 13, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 1, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 2, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 3, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 4, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 5, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 6, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108006382, 7, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 1, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 2, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 3, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 4, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 5, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 6, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 7, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 8, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 9, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 10, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 11, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 12, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 13, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110625006383, 14, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302006384, 1, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302006384, 2, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302006384, 3, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302006384, 4, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 1, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 2, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 3, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 4, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 5, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 6, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 7, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227006385, 8, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 1, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 2, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 5, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 6, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 7, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 8, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 9, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 10, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 11, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 12, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 13, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 14, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 15, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616006735, 16, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 1, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 2, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 3, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 4, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 5, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313006736, 6, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 1, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 2, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 3, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 4, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 5, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 6, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207006737, 7, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 1, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 2, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 3, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 4, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 5, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 6, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 7, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 8, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 9, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 10, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 11, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 12, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605006738, 13, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 1, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 2, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 3, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 4, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 5, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 6, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 7, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 8, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 9, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 10, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 11, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 12, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 13, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 14, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 15, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110526006739, 16, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 1, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 2, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 3, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 4, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 5, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 6, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 7, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 8, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 9, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 10, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 11, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030006740, 12, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 1, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 2, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 3, 190, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 4, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 5, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301006741, 6, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 1, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 2, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 3, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 4, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 5, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 6, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 7, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 8, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 9, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 10, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 11, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 12, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 13, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 14, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 15, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906006742, 16, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 1, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 2, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 3, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 4, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 5, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 6, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809006743, 7, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 1, 18, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 2, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 3, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 4, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 5, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 6, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 7, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 8, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 9, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 10, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113006744, 11, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 1, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 2, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 3, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 4, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 5, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 6, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 7, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 8, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126006745, 9, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 1, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 2, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 3, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 4, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 5, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 6, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926006746, 8, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 1, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 2, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 3, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 4, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 5, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 6, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 7, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 8, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 9, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 10, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 11, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 12, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113006747, 13, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 1, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 2, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 3, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 4, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 5, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 6, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 7, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325006748, 8, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 1, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 2, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 3, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 4, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 5, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 6, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 7, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 8, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304006749, 9, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 1, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 2, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 3, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 4, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 5, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 6, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 7, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 8, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 9, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 10, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 11, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 12, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 13, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 14, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 15, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006750, 16, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 1, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 2, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 3, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 4, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 5, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 6, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 7, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511006751, 8, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 1, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 2, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 3, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 4, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 5, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 6, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215006752, 7, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 1, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 2, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 3, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 4, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 5, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 6, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 7, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 8, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 9, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 10, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525006753, 11, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 1, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 2, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 3, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 4, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 5, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 6, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030204006754, 7, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 1, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 2, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 3, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 4, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 5, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 6, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 7, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 8, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 9, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 10, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 11, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108006755, 12, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 1, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 2, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 3, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 4, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 5, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 6, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 7, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 8, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 9, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 10, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 11, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 12, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 13, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630006756, 14, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 1, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 2, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 3, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 4, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 5, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 6, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 7, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116006757, 8, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102006758, 1, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102006758, 2, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102006758, 3, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 5, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 6, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 7, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 8, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 9, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 10, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 11, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 12, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 13, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 14, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 15, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121227005598, 16, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 1, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 2, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 3, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 4, 190, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 5, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 6, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 7, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 8, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 9, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 10, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 11, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 12, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 13, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213005599, 14, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 1, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 2, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 3, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 4, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 5, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 6, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 7, 112, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 8, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 9, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 10, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 11, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126005600, 12, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 1, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 2, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 3, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 4, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 5, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 6, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 7, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 8, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 9, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 10, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210005601, 11, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 1, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 2, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 3, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 4, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 5, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 6, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 7, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 8, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 9, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 10, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 11, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 12, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 13, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 14, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 15, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 16, 60, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106005602, 17, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727005603, 1, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727005603, 2, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727005603, 3, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727005603, 4, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010316005604, 1, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010316005604, 2, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010316005604, 3, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010316005604, 4, 81, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010316005604, 5, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 1, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 2, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 3, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 4, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 5, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 6, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 7, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 8, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 9, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 10, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 11, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 12, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 13, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 14, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 15, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106005605, 16, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 1, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 2, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 3, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 4, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 5, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 6, 145, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 7, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 8, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 9, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 10, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 11, 23, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104005606, 12, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 1, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 2, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 3, 64, 91, 14, 1274);
commit;
prompt 67000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 4, 150, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 5, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 6, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721005607, 7, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 1, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 2, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 3, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 4, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 5, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 6, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 7, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 8, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 9, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 10, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 11, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 12, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 13, 152, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 14, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822005608, 15, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 1, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 2, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 3, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 4, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 5, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 6, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 7, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 8, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 9, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 10, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 11, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070908005609, 12, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 1, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 2, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 3, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 4, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 5, 35, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 6, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 7, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 8, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 9, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 10, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 11, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 12, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 13, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 14, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419005610, 15, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125005611, 1, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125005611, 2, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125005611, 3, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125005611, 4, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606005612, 1, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606005612, 2, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606005612, 3, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606005612, 4, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 1, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 2, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 3, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 4, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 5, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 6, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 7, 176, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 8, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 9, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 10, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 11, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 12, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 13, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 14, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 15, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122005613, 16, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 1, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 2, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 3, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 4, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 5, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523005614, 6, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 1, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 2, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 3, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 4, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 5, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 6, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 7, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 8, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124005615, 9, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101005616, 1, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101005616, 2, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101005616, 3, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101005616, 4, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011101005616, 5, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 1, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 2, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 3, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 4, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 5, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 6, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 7, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 8, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 9, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 10, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203005617, 11, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 1, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 2, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 3, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 4, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 5, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 6, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 7, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 8, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 9, 190, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 10, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 11, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503005618, 12, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 1, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 2, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 3, 1, 29, 3, 87);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 4, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 5, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 6, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702005619, 7, 72, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107005620, 1, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107005620, 2, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107005620, 3, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107005620, 4, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030107005620, 5, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 1, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 2, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 3, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 4, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 5, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 6, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 7, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 8, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 3, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 4, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 5, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 6, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 7, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 8, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 9, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 10, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 11, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 12, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 13, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 14, 37, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 15, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 16, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722005975, 17, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 1, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 2, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 3, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 4, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 5, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108005976, 6, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 1, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 2, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 3, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 4, 55, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 5, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 6, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 7, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 8, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 9, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 10, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106005977, 11, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 1, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 2, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 3, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 4, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 5, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 6, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 7, 56, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 8, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 9, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909005978, 10, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 1, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 2, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 3, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 4, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 5, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 6, 139, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 7, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 8, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 9, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 10, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 11, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 12, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 13, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 14, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729005979, 15, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 1, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 2, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 3, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 4, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 5, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 6, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728005980, 7, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811005981, 1, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811005981, 2, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811005981, 3, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 1, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 2, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 3, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 4, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 5, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 6, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216005982, 7, 99, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 1, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 2, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 3, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 4, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 5, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 6, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 7, 57, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 8, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 9, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 10, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 11, 96, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 12, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 13, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 14, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802005983, 15, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 1, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 2, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 3, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 4, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 5, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 6, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 7, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 8, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 9, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 10, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 11, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 12, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 13, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921005984, 14, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005985, 1, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005985, 2, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005985, 3, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005985, 4, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512005985, 5, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 1, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 2, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 3, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 4, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 5, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 6, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 7, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 8, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 9, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 10, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 11, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 12, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 13, 192, 94, 18, 1692);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 14, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 15, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 16, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 17, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210005986, 18, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005987, 1, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005987, 2, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005987, 3, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005987, 4, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 1, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 2, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 3, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 4, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 5, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 6, 131, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 7, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 8, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005988, 9, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 1, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 2, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 3, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 4, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 5, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 6, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 7, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 8, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 9, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 10, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 11, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 12, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 13, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711005989, 14, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 1, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 2, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 3, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 4, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 5, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 6, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 7, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 8, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 9, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 10, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 11, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108005990, 12, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 1, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 2, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 3, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 4, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 5, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 6, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 7, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 8, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 9, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 10, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061024005991, 11, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 2, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 3, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 4, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 5, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714005992, 6, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 1, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 2, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 3, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 4, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 5, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 6, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 7, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612005993, 8, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 1, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 2, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 3, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 4, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 5, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 6, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 7, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 8, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 9, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 10, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 11, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 12, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 13, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331005994, 14, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 1, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 2, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 3, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 4, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 5, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 6, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 7, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 8, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 9, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 10, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 11, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 12, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 13, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714005995, 14, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 1, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 2, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 3, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 4, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 5, 90, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 6, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 7, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 8, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 9, 14, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 10, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 11, 64, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 12, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 13, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 14, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 15, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916005996, 16, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 1, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 2, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 3, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 4, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 5, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 3, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 4, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 5, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 6, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403006386, 7, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 1, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 2, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 3, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 4, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 5, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 6, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 7, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 8, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 9, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 10, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 11, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 12, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 13, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 14, 11, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624006387, 15, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 1, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 2, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 3, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 4, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 5, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 6, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 7, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 8, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 9, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529006388, 10, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522006389, 1, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522006389, 2, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 1, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 2, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 3, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 4, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 5, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 6, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 7, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 8, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804006390, 9, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 1, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 2, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 3, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 4, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 5, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 6, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 7, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 8, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 9, 30, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017006391, 10, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 1, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 2, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 3, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 4, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 5, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030708006392, 6, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 1, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 2, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 3, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 4, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 5, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 6, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 7, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 8, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 9, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523006393, 10, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 1, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 2, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 3, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 4, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 5, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 6, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 7, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 8, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 9, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 10, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 11, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 12, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 13, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 14, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728006394, 15, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 1, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 2, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 3, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 4, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 5, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 6, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 7, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 8, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 9, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 10, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 11, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 12, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409006395, 13, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002006396, 1, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002006396, 2, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002006396, 3, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 1, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 2, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 3, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 4, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 5, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 6, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 7, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 8, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 9, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 10, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 11, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 12, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 13, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615006397, 14, 29, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 1, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 2, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 3, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 4, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 5, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 6, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105006398, 7, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 1, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 2, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 3, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 4, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 5, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 6, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 7, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 8, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 9, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 10, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070724006399, 11, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115006400, 1, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115006400, 2, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115006400, 3, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115006400, 4, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403006401, 1, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403006401, 2, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403006401, 3, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403006401, 4, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403006401, 5, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 1, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 2, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 3, 78, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 4, 161, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 5, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 6, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 7, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 8, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 9, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 10, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 11, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 12, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 13, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 14, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 15, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415006402, 16, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 1, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 2, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 3, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 4, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 5, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 6, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 7, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117006403, 8, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 1, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 2, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 3, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 4, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 5, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 6, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 7, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 8, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612006404, 9, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 1, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 2, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 3, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 4, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 5, 47, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 6, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 7, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 8, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 9, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213006405, 10, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 1, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 2, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 3, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 4, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 5, 99, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 6, 173, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 7, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 8, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 9, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 10, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 11, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006406, 12, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 1, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 2, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 3, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 4, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 5, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 6, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 7, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 8, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 9, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 10, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213006407, 11, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 1, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 2, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 3, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 4, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 5, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 6, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 7, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 8, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 9, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 10, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 11, 129, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 12, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 13, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 14, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 15, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 16, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603006408, 17, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 1, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 2, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 3, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 4, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 5, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 6, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 7, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 8, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 9, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 10, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 11, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 12, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412006409, 13, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 1, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 2, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 3, 28, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 4, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102006758, 4, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 1, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 2, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 3, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 4, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 5, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 6, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 7, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 8, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 9, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 10, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 11, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 12, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 13, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 14, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 15, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006759, 16, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 1, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 2, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 3, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 4, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 5, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 6, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 7, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 8, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006760, 9, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 1, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 2, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 3, 16, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 4, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 5, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 6, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 7, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913006761, 8, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 1, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 2, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 3, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 4, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 5, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727006762, 6, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000206006763, 1, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000206006763, 2, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000206006763, 3, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129006764, 1, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129006764, 2, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129006764, 3, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129006764, 4, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129006764, 5, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 1, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 2, 55, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 3, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 4, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 5, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 6, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 7, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 8, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 9, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 10, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202006765, 11, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 1, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 2, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 3, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 4, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 5, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 6, 63, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 7, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 8, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 9, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 10, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 11, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 12, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110901006766, 13, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 1, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 2, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 3, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 4, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 5, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 6, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 7, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 8, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 9, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 10, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 11, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 12, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325006767, 13, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102006768, 1, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102006768, 2, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102006768, 3, 142, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102006768, 4, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102006768, 5, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 1, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 2, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 3, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 4, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 5, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 6, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 7, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 8, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 9, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 10, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 11, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090317006769, 12, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 1, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 2, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 3, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 4, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 5, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 6, 14, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103006770, 7, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 1, 91, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 2, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 3, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 4, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 5, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 6, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 7, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 8, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 9, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 10, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 11, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 12, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 13, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 14, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307006771, 15, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 1, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 2, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 3, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 4, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 5, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 6, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 7, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 8, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 9, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 10, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 11, 31, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 12, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 13, 175, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 14, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 15, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312006772, 16, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 1, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 2, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 3, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 4, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 5, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 6, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 7, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 8, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 9, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 10, 21, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 11, 103, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 12, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 13, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 14, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502006773, 15, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 1, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 2, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 3, 147, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 4, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 5, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 6, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 7, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 8, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 9, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 10, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 11, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 12, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 13, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 14, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 15, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127006774, 16, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 1, 185, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 2, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 3, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 4, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 5, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 6, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 7, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019006775, 8, 87, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 1, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 2, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 3, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 4, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 5, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 6, 185, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 7, 143, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 8, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 9, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 10, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012006776, 11, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101006777, 1, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101006777, 2, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101006777, 3, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101006777, 4, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 1, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 2, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 3, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 4, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 5, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 6, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 7, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 8, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 9, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 10, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090101006778, 11, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020207006779, 1, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020207006779, 2, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020207006779, 3, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020207006779, 4, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203006780, 1, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203006780, 2, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203006780, 3, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203006780, 4, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623006781, 1, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623006781, 2, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623006781, 3, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 1, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 2, 56, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 3, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 4, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 5, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 6, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 7, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 8, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305006782, 9, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107006783, 1, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107006783, 2, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107006783, 3, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107006783, 4, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 1, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 2, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 3, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 4, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 5, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 6, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 7, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 8, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 9, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 10, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 9, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 10, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 11, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 12, 132, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 13, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505005621, 14, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223005622, 1, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223005622, 2, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223005622, 3, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 1, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 2, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 3, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 4, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 5, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 6, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 7, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 8, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 9, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 10, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 11, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 12, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 13, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101214005623, 14, 137, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 1, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 2, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 3, 149, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 4, 112, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 5, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 6, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 7, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 8, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 9, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107005624, 10, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502005625, 1, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502005625, 2, 64, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502005625, 3, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502005625, 4, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502005625, 5, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 1, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 2, 119, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 3, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 4, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 5, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 6, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 7, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 8, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 9, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 10, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 11, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 12, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 13, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 14, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120127005626, 15, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 1, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 2, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 3, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 4, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 5, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422005627, 6, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 1, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 2, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 3, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 4, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 5, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 6, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 7, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 8, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720005628, 9, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 1, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 2, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 3, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 4, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 5, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 6, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 7, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405005629, 8, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 1, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 2, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 3, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 4, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 5, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 6, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 7, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 8, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 9, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 10, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 11, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215005630, 12, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 1, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 2, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 3, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 4, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 5, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 6, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 7, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 8, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 9, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 10, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 11, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 12, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228005631, 13, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 1, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 2, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 3, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 4, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 5, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 6, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 7, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 8, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 9, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 10, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 11, 14, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 12, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 13, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 14, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013005632, 15, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 1, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 2, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 3, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 4, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 5, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 6, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 7, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 8, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 9, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 10, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 11, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827005633, 12, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 1, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 2, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 3, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 4, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 5, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 6, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 7, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040921005634, 8, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 1, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 2, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 3, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 4, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 5, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 6, 97, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 7, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 8, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050804005635, 9, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 1, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 2, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 3, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 4, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 5, 138, 8, 9, 72);
commit;
prompt 68000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427005636, 6, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 1, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 2, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 3, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 4, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 5, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 6, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 7, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 8, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 9, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 10, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 11, 188, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 12, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 13, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 14, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107005637, 15, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 1, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 2, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 3, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 4, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 5, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 6, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 7, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 8, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 9, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 10, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 11, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208005638, 12, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 1, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 2, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 3, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 4, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 5, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 6, 192, 22, 18, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 7, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 8, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 9, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 10, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 11, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 12, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301005639, 13, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 1, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 2, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 3, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 4, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 5, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 6, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 7, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 8, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 9, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 10, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 11, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070905005640, 12, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 1, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 2, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 3, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 4, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 5, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 6, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005641, 7, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921005642, 1, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921005642, 2, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921005642, 3, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921005642, 4, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921005642, 5, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 1, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 2, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 3, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 4, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 5, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 6, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 7, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 8, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 9, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 10, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 11, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 12, 66, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410005643, 13, 182, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 1, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 2, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 3, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 4, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 5, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 6, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 7, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 8, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601005644, 9, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 1, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 2, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530005997, 6, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 1, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 2, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 3, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 4, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 5, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008005998, 6, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 1, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 2, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 3, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 4, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 5, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 6, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 7, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709005999, 8, 107, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 1, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 2, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 3, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 4, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 5, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905006000, 6, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 1, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 2, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 3, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 4, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 5, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 6, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 7, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 8, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 9, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 10, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 11, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 12, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 13, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 14, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 15, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 16, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729006001, 17, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003006002, 1, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003006002, 2, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003006002, 3, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003006002, 4, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 1, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 2, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 3, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 4, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 5, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 6, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 7, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 8, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 9, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 10, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115006003, 11, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 1, 162, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 2, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 3, 23, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 4, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 5, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 6, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 7, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 8, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 9, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 10, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 11, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 12, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 13, 119, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 14, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 15, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 16, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413006004, 17, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 1, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 2, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 3, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 4, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 5, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 6, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 7, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 8, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 9, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 10, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 11, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 12, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 13, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 14, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 15, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 16, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427006005, 17, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 1, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 2, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 3, 12, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 4, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 5, 3, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 6, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 7, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 8, 176, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 9, 161, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 10, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 11, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 12, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 13, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118006006, 14, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 1, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 2, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 3, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 4, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 5, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 6, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 7, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 8, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712006007, 9, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 1, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 2, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 3, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 4, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 5, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 6, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923006008, 7, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 1, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 2, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 3, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 4, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 5, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 6, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 7, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 8, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 9, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 10, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 11, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 12, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 13, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828006009, 14, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 1, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 2, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 3, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 4, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 5, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 6, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 7, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 8, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 9, 137, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 10, 97, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907006010, 11, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 1, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 2, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 3, 19, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 4, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 5, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 6, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402006011, 7, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 1, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 2, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 3, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 4, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 5, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 6, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 7, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 8, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 9, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 10, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 11, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 12, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 13, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604006012, 14, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 1, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 2, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 3, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 4, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 5, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310006013, 6, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 1, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 2, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 3, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 4, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 5, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502006014, 6, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 1, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 2, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 3, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 4, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 5, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 6, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 7, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 8, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 9, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 10, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410006015, 11, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525006016, 1, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525006016, 2, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525006016, 3, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525006016, 4, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525006016, 5, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219006017, 1, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219006017, 2, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219006017, 3, 174, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219006017, 4, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219006017, 5, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 1, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 2, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 3, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 4, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 5, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 6, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 7, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 8, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 9, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 10, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 11, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 12, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 13, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425006018, 14, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 1, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 2, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 3, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 4, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 5, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 6, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 7, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 8, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 9, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 10, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 11, 166, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001006019, 12, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 1, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 2, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 3, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 4, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 5, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 6, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 7, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122006020, 8, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 1, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 2, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 3, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 4, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 5, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 6, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 7, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 8, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506006021, 9, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 5, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 6, 51, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 7, 101, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 8, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 9, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 10, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 11, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 12, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027006410, 13, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 1, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 2, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 3, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 4, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 5, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 6, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 7, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 8, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 9, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 10, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 11, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 12, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 13, 39, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 14, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105006411, 15, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 1, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 2, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 3, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 4, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 5, 137, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 6, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 7, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 8, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 9, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 10, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 11, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 12, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006412, 13, 73, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 1, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 2, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 3, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 4, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 5, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041216006413, 6, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 1, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 2, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 3, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 4, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 5, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 6, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 7, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 8, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 9, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 10, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 11, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 12, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924006414, 13, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 1, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 2, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 3, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 4, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 5, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 6, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 7, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820006415, 8, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 1, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 2, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 3, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 4, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 5, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 6, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 7, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 8, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 9, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 10, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808006416, 11, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704006417, 1, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704006417, 2, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 1, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 2, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 3, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 4, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 5, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 6, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617006418, 7, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526006419, 1, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526006419, 2, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526006419, 3, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526006419, 4, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010526006419, 5, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 1, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 2, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 3, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 4, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 5, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 6, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 7, 63, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 8, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 9, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210006420, 10, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 1, 143, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 2, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 3, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 4, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 5, 66, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 6, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 7, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 8, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027006421, 9, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229006422, 1, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229006422, 2, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229006422, 3, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011229006422, 4, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 1, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 2, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 3, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 4, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 5, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 6, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 7, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 8, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 9, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 10, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 11, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 12, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113006423, 13, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 1, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 2, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 3, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 4, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 5, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 6, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 7, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324006424, 8, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 1, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 2, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 3, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 4, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 5, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 6, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 7, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 8, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 9, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 10, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 11, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 12, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 13, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 14, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527006425, 15, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 1, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 2, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 3, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 4, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 5, 170, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 6, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 7, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 8, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 9, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 10, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 11, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121006426, 12, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720006427, 1, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720006427, 2, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720006427, 3, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720006427, 4, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720006427, 5, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 1, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 2, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 3, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 4, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 5, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 6, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 7, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 8, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 9, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 10, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 11, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 12, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 13, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 14, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 15, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 16, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 17, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904006428, 18, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 1, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 2, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 3, 180, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 4, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 5, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 6, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 7, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 8, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 9, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 10, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 11, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006429, 12, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 1, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 2, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 3, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 4, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 5, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 6, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628006430, 7, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 1, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 2, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 3, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 4, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 5, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 6, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 7, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 8, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 9, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080709006431, 10, 154, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 1, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 2, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 3, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 4, 192, 80, 18, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 5, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 6, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 7, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 8, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 9, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 10, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 11, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 12, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 13, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006432, 14, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 1, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 2, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 3, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 4, 49, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 5, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 6, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 7, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 8, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 9, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 10, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 11, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 12, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 13, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 11, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 12, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 13, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 14, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026006784, 15, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 1, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 2, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 3, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 4, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 5, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 6, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 7, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 8, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 9, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 10, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115006785, 11, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 1, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 2, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 3, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 4, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 5, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 6, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 7, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 8, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 9, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 10, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 11, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 12, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 13, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 14, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 15, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130828006786, 16, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 1, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 2, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 3, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 4, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 5, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 6, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 7, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 8, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 9, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 10, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 11, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 12, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 13, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224006787, 14, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 1, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 2, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 3, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 4, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 5, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 6, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 7, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 8, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 9, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 10, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 11, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 12, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090702006788, 13, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 1, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 2, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 3, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 4, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 5, 137, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 6, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 7, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 8, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 9, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 10, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 11, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307006789, 12, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 1, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 2, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 3, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 4, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 5, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 6, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 7, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 8, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 9, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 10, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 11, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 12, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 13, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 14, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213006790, 15, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814006791, 1, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814006791, 2, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814006791, 3, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814006791, 4, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814006791, 5, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 1, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 2, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 3, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 4, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 5, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 6, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 7, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902006792, 8, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 1, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 2, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 3, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 4, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 5, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 6, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 7, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 8, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 9, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 10, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 11, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 12, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 13, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218006793, 14, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801006794, 1, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801006794, 2, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801006794, 3, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801006794, 4, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801006794, 5, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823006795, 1, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823006795, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823006795, 3, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000823006795, 4, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 1, 1, 51, 3, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 2, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 3, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 4, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 5, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 6, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 7, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 8, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 9, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 10, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 11, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 12, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 13, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 14, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 15, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108006796, 16, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 1, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 2, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 3, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 4, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 5, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 6, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 7, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521006797, 8, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 1, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 2, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 3, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 4, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 5, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 6, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 7, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 8, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 9, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 10, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 11, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 12, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 13, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102006798, 14, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 1, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 2, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 3, 106, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 4, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 5, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 6, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 7, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 8, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 9, 126, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 10, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 11, 175, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 12, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 13, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 14, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 15, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 16, 192, 23, 18, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428006799, 17, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 1, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 2, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 3, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 4, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 5, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 6, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 7, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 8, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 9, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 10, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 11, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117006800, 12, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 1, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 2, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 3, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 4, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 5, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 6, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112006801, 7, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 1, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 2, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 3, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 4, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 5, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 6, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 7, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 8, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 9, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 10, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 11, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 12, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 13, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 14, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714006802, 15, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 1, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 2, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 3, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 4, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 5, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 6, 130, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 7, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 8, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 9, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 10, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 11, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 12, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 13, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310006803, 14, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 1, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 2, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 3, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 4, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 5, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 6, 56, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 7, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 8, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 9, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102006804, 10, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 1, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 2, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 3, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 4, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 3, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 4, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 5, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 6, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 7, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 8, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 9, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 10, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 11, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 12, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 13, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614005645, 14, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 1, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 2, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 3, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 4, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 5, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 6, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 7, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 8, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 9, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 10, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 11, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080321005646, 12, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 1, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 2, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 3, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 4, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 5, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 6, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 7, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 8, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 9, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 10, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 11, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 12, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 13, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 14, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 15, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 16, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109005647, 17, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 1, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 2, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 3, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 4, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 5, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 6, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 7, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 8, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 9, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111005648, 10, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 1, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 2, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 3, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 4, 140, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 5, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 6, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 7, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 8, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 9, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 10, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 11, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 12, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 13, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 14, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 15, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 16, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 17, 111, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609005649, 18, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 1, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 2, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 3, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 4, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 5, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 6, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 7, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 8, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 9, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 10, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 11, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 12, 68, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 13, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 14, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 15, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626005650, 16, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 1, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 2, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 3, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 4, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 5, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020726005651, 6, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000806005652, 1, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000806005652, 2, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000806005652, 3, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000806005652, 4, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 1, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 2, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 3, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 4, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 5, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 6, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 7, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 8, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 9, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305005653, 10, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 1, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 2, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 3, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 4, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 5, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 6, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 7, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 8, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 9, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 10, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 11, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729005654, 12, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 1, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 2, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 3, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 4, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 5, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 6, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123005655, 7, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 1, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 2, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 3, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 4, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 5, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 6, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 7, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 8, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 9, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030005656, 10, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 1, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 2, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 3, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 4, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 5, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 6, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 7, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 8, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 9, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 10, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 11, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001005657, 12, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 1, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 2, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 3, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 4, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 5, 103, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524005658, 6, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 1, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 2, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 3, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 4, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 5, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 6, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 7, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 8, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 9, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108005659, 10, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 1, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 2, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 3, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 4, 13, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 5, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 6, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 7, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 8, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 9, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 10, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 11, 180, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 12, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 13, 84, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 14, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405005660, 15, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 1, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 2, 25, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 3, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 4, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 5, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 6, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 7, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 8, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 9, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811005661, 10, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 1, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 2, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 3, 92, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 4, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 5, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 6, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 7, 131, 77, 9, 693);
commit;
prompt 69000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 8, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 9, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 10, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 11, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 12, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 13, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406005662, 14, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 1, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 2, 44, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 3, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 4, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 5, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 6, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 7, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 8, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 9, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 10, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 11, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027005663, 12, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 1, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 2, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 3, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 4, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 5, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 6, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 7, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 8, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070214005664, 9, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 1, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 2, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 3, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 4, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 5, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 6, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213005665, 7, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 1, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 2, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 3, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 4, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 5, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 6, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 7, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 8, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 9, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 10, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703006022, 1, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703006022, 2, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703006022, 3, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703006022, 4, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 1, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 2, 127, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 3, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 4, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 5, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 6, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 7, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 8, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 9, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 10, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 11, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 12, 96, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 13, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 14, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 15, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019006023, 16, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 1, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 2, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 3, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 4, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 5, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 6, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 7, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 8, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 9, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 10, 89, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 11, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 12, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 13, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 14, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208006024, 15, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 1, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 2, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 3, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 4, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 5, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 6, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 7, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 8, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 9, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 10, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 11, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080726006025, 12, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 1, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 2, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 3, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 4, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 5, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 6, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 7, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829006026, 8, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 1, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 2, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 3, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 4, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 5, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 6, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 7, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 8, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 9, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 10, 137, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 11, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 12, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 13, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 14, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 15, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517006027, 16, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006028, 1, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006028, 2, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006028, 3, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020110006028, 4, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 1, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 2, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 3, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 4, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 5, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 6, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 7, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 8, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 9, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 10, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 11, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 12, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 13, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 14, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 15, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 16, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215006029, 17, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 1, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 2, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 3, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 4, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 5, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 6, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 7, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 8, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 9, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 10, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 11, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 12, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 13, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826006030, 14, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 1, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 2, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 3, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 4, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 5, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 6, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 7, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 8, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 9, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 10, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 11, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 12, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100822006031, 13, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522006032, 1, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522006032, 2, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522006032, 3, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522006032, 4, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010522006032, 5, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 1, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 2, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 3, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 4, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 5, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 6, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 7, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 8, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 9, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 10, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 11, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116006033, 12, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 1, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 2, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 3, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 4, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 5, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 6, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 7, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 8, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 9, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 10, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 11, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122006034, 12, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 1, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 2, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 3, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 4, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 5, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 6, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 7, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 8, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 9, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 10, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127006035, 11, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221006036, 1, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221006036, 2, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221006036, 3, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221006036, 4, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010315006037, 1, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010315006037, 2, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010315006037, 3, 71, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010315006037, 4, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 1, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 2, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 3, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 4, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 5, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 6, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 7, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 8, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 9, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 10, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 11, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 12, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 13, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 14, 8, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028006038, 15, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 1, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 2, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 3, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 4, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 5, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 6, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 7, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 8, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 9, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 10, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 11, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 12, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 13, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 14, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 15, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 16, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721006039, 17, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720006040, 1, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720006040, 2, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720006040, 3, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720006040, 4, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 1, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 2, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 3, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 4, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 5, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 6, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 7, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 8, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 9, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 10, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 11, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 12, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 13, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 14, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006041, 15, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006042, 1, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006042, 2, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006042, 3, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930006042, 4, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 1, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 2, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 3, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 4, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 5, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 6, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 7, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 8, 49, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 9, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070507006043, 10, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 1, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 2, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 3, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 4, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 5, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 6, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 7, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 14, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829006433, 15, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 1, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 2, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 3, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 4, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 5, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 6, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624006434, 7, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 1, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 2, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 3, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 4, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 5, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001006435, 6, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 1, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 2, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 3, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 4, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 5, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 6, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421006436, 7, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 1, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 2, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 3, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 4, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 5, 70, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 6, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 7, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 8, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 9, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 10, 180, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 11, 71, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090623006437, 12, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213006438, 1, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213006438, 2, 154, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213006438, 3, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213006438, 4, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918006439, 1, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918006439, 2, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918006439, 3, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918006439, 4, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729006440, 1, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729006440, 2, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729006440, 3, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729006440, 4, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729006440, 5, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 1, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 2, 122, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 3, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 4, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 5, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 6, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 7, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 8, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206006441, 9, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329006442, 1, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329006442, 2, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329006442, 3, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329006442, 4, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329006442, 5, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 1, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 2, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 4, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 5, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 6, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 7, 164, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 8, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 9, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 10, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 11, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408006443, 12, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 1, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 2, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 3, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 4, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 5, 156, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 6, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 7, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 8, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 9, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 10, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719006444, 11, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 1, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 2, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 3, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 4, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 5, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 6, 125, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 7, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 8, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 9, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 10, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 11, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 12, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 13, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 14, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 15, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510006445, 16, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 1, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 2, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 3, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 4, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 5, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 6, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 7, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 8, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 9, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 10, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 11, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 12, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 13, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 14, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130623006446, 15, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 1, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 2, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 3, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 4, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 5, 127, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 6, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 7, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 8, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 9, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222006447, 10, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 1, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 2, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 3, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 4, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 5, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 6, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 7, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 8, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 9, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 10, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 11, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 12, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 13, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 14, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206006448, 15, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 1, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 2, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 3, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 4, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 5, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 6, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 7, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 8, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 9, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 10, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 11, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 12, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 13, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 14, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126006449, 15, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 1, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 2, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 3, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 4, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 5, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 6, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 7, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 8, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 9, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 10, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 11, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 12, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 13, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 14, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 15, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919006450, 16, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 1, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 2, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 3, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 4, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 5, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 6, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 7, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 8, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 9, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 10, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 11, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 12, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118006451, 13, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 1, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 2, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 3, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 4, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 5, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222006452, 6, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 1, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 2, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 3, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 4, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 5, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 6, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219006453, 7, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 1, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 2, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 3, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 4, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 5, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 6, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 7, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 8, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 9, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 10, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 11, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070102006454, 12, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 1, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 2, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 3, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 4, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 5, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 6, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 7, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 8, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 9, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 10, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 11, 183, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 12, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422006455, 13, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006456, 1, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006456, 2, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006456, 3, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006456, 4, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203006456, 5, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 1, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 2, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 3, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 4, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 5, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 6, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 7, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 8, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 9, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 10, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 11, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 5, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 6, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 7, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 8, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410006805, 9, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 1, 34, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 2, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 3, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 4, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 5, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 6, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 7, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 8, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 9, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 10, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 11, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108006806, 12, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 1, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 2, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 3, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 4, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 5, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 6, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 7, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 8, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 9, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 10, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 11, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 12, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 13, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108006807, 14, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 1, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 2, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 3, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 4, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 5, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 6, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 7, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 8, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822006808, 9, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 1, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 2, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 3, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 4, 157, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 5, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 6, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 7, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 8, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 9, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326006809, 10, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 1, 37, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 2, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 3, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 4, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 5, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 6, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 7, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603006810, 8, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 1, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 2, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 3, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 4, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 5, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 6, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 7, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 8, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 9, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224006811, 10, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 1, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 2, 136, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 3, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 4, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 5, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 6, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 7, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 8, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 9, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 10, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 11, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 12, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 13, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004006812, 14, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 1, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 2, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 3, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 4, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 5, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 6, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 7, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 8, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 9, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 10, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 11, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100101006813, 12, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 1, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 2, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 3, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 4, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 5, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 6, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 7, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 8, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 9, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 10, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 11, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 12, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 13, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 14, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 15, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805006814, 16, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 1, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 2, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 3, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 4, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 5, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122006815, 6, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 1, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 2, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 3, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 4, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 5, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 6, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 7, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 8, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051217006816, 9, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 1, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 2, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 3, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 4, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 5, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 6, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 7, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 8, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 9, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 10, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 11, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 12, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 13, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 14, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 15, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803006817, 16, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 1, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 2, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 3, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 4, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 5, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 6, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 7, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 8, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 9, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 10, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 11, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 12, 19, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124006818, 13, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606006819, 1, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606006819, 2, 180, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606006819, 3, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606006819, 4, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606006819, 5, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508006820, 1, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508006820, 2, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508006820, 3, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 1, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 2, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 3, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 4, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 5, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 6, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203006821, 7, 1, 31, 3, 93);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 1, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 2, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 3, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 4, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 5, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511006822, 6, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 1, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 2, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 3, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 4, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 5, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 6, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 7, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 8, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 9, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 10, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 11, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 12, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223006823, 13, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314006824, 1, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314006824, 2, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314006824, 3, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 1, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 2, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 3, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 4, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 5, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 6, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 7, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 8, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 9, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325006825, 10, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 1, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 2, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 3, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 4, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 5, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 6, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924006826, 7, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 1, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 2, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 3, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 4, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 5, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927006827, 6, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 1, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 2, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 3, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 4, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 5, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 6, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 7, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 8, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 9, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 10, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 11, 133, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018006828, 12, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 1, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 2, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 3, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 4, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 5, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 6, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 7, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 8, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115006829, 9, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 1, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 2, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 3, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 4, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 11, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 12, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 13, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 14, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 15, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215005666, 16, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 1, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 2, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 3, 12, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 4, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 5, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 6, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 7, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 8, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 9, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 10, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 11, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 12, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 13, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 14, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 15, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104005667, 16, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 1, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 2, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 3, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 4, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 5, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 6, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 7, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 8, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 9, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 10, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 11, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 12, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 13, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 14, 75, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 15, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207005668, 16, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 1, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 2, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 3, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 4, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 5, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 6, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 7, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 8, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 9, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 10, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 11, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 12, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709005669, 13, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 1, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 2, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 3, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 4, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 5, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 6, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 7, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 8, 144, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 9, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 10, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 11, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 12, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 13, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 14, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018005670, 15, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005671, 1, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005671, 2, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005671, 3, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005671, 4, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005671, 5, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 1, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 2, 192, 92, 18, 1656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 3, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 4, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 5, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 6, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912005672, 7, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 1, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 2, 126, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 3, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 4, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 5, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 6, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 7, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 8, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 9, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 10, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 11, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 12, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915005673, 13, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 1, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 2, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 3, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 4, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 5, 121, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 6, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 7, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 8, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 9, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 10, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 11, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 12, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 13, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 14, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 15, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111005674, 16, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 1, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 2, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 3, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 4, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 5, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 6, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 7, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 8, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 9, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 10, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 11, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 12, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 13, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 14, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 15, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 16, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 17, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416005675, 18, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 1, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 2, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 3, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 4, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 5, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 6, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 7, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 8, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 9, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 10, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 11, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 12, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 13, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 14, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 15, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 16, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128005676, 17, 145, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005677, 1, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005677, 2, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005677, 3, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027005677, 4, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 1, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 2, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 3, 142, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 4, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 5, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907005678, 6, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 1, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 2, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 3, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 4, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 5, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 6, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 7, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 8, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 9, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 10, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 11, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102005679, 12, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 1, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 2, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 3, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 4, 10, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 5, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 6, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 7, 191, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 8, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 9, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626005680, 10, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 1, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 2, 189, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 3, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 4, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 5, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 6, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 7, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 8, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 9, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 10, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 11, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 12, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 13, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728005681, 14, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 1, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 2, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 3, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 4, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 5, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 6, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315005682, 7, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 1, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 2, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 3, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 4, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 5, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 6, 97, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 7, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 8, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 9, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 10, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 11, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 12, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 13, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 14, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 15, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010005683, 16, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 1, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 2, 55, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 3, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 4, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 5, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 6, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 7, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 8, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 9, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 10, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 11, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 12, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 13, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420005684, 14, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 1, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 2, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 3, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 4, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 5, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 6, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 7, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 8, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 9, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 10, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 11, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 12, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 13, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 8, 109, 25, 11, 275);
commit;
prompt 70000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 9, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 10, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 11, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109006044, 12, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 1, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 2, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 3, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 4, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 5, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 6, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 7, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 8, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 9, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 10, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 11, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923006045, 12, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 1, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 2, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 3, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 4, 192, 90, 18, 1620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 5, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 6, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 7, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 8, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 9, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128006046, 10, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 1, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 2, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 3, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 4, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 5, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 6, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 7, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 8, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 9, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 10, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 11, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327006047, 12, 38, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 1, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 2, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 3, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 4, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 5, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 6, 57, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 7, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 8, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 9, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 10, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 11, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 12, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 13, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 14, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 15, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 16, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130221006048, 17, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 1, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 2, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 3, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 4, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 5, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 6, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 7, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 8, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 9, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 10, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 11, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 12, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 13, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929006049, 14, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 1, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 2, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 3, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 4, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 5, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 6, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 7, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 8, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006006050, 9, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 1, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 2, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 3, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 4, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 5, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 6, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 7, 27, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 8, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 9, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 10, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 11, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 12, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 13, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 14, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 15, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402006051, 16, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 1, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 2, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 3, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 4, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 5, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 6, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 7, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 8, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 9, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 10, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214006052, 11, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 1, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 2, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 3, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 4, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 5, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 6, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130006053, 7, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 1, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 2, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 3, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 4, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 5, 57, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 6, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 7, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 8, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 9, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705006054, 10, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 1, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 2, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 3, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 4, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 5, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214006055, 6, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 1, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 2, 159, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 3, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 4, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 5, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 6, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 7, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 8, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050528006056, 9, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006057, 1, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006057, 2, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006057, 3, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102006058, 1, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102006058, 2, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000102006058, 3, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 1, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 2, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 3, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 4, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 5, 39, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 6, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 7, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 8, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 9, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 10, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 11, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 12, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607006059, 13, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 1, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 2, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 3, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 4, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 5, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 6, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823006060, 7, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010006061, 1, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010006061, 2, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010006061, 3, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 1, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 2, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 3, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 4, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 5, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 6, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 7, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 8, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 9, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108006062, 10, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706006063, 1, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706006063, 2, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706006063, 3, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 1, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 2, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 3, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 4, 81, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 5, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 6, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 7, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 8, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 9, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 10, 47, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 11, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 12, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 13, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 14, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221006064, 15, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 1, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 2, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 3, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 4, 30, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 5, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 6, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 7, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 8, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926006065, 9, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 1, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 2, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 3, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 4, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 5, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 6, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 7, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 8, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 9, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060820006066, 10, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 1, 77, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 2, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 3, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 4, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 5, 167, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 6, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 7, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 8, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110006067, 9, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 1, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 2, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 3, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 4, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 5, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 6, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 7, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 8, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 9, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 10, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 11, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 12, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 13, 157, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 14, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 15, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 16, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 12, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 13, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 14, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 15, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203006457, 16, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 1, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 2, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 3, 156, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 4, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 5, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 6, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 7, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412006458, 8, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 1, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 2, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 3, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 4, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 5, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 6, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 7, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 8, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 9, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 10, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 11, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 12, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 13, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130006459, 14, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006460, 1, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006460, 2, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006460, 3, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711006460, 4, 68, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 1, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 2, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 3, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 4, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 5, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 6, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 7, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 8, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 9, 29, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 10, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 11, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 12, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 13, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 14, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006461, 15, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 1, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 2, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 3, 39, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 4, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 5, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606006462, 6, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 1, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 2, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 3, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 4, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 5, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 6, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 7, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 8, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 9, 179, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 10, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 11, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 12, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 13, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110204006463, 14, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 1, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 2, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 3, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 4, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 5, 83, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 6, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 7, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 8, 34, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 9, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 10, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 11, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 12, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 13, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 14, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 15, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427006464, 16, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 1, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 2, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 3, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 4, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 5, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 6, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006006465, 7, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 1, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 2, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 3, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 4, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 5, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 6, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520006466, 7, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 1, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 2, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 3, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 4, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 5, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 6, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 7, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 8, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 9, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 10, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006467, 11, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007006468, 1, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007006468, 2, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007006468, 3, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001007006468, 4, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 1, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 2, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 3, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 4, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 5, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 6, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 7, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 8, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 9, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 10, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 11, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 12, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 13, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 14, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 15, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218006469, 16, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222006470, 1, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222006470, 2, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222006470, 3, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222006470, 4, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021222006470, 5, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 1, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 2, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 3, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 4, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 5, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 6, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 7, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 8, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 9, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 10, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 11, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 12, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 13, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318006471, 14, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006472, 1, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006472, 2, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006472, 3, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006472, 4, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408006472, 5, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 1, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 2, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 3, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 4, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 5, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 6, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 7, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 8, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 9, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 10, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 11, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 12, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 13, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106006473, 14, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 1, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 2, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 3, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 4, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 5, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 6, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 7, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 8, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 9, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 10, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 11, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 12, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 13, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101230006474, 14, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 1, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 2, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 3, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 4, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 5, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 6, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 7, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 8, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 9, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 10, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 11, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 12, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 13, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 14, 65, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120204006475, 15, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 1, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 2, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 3, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 4, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 5, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104006476, 6, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825006477, 1, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825006477, 2, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825006477, 3, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825006477, 4, 192, 38, 18, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603006478, 1, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603006478, 2, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603006478, 3, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603006478, 4, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 1, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 2, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 3, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 4, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 5, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 6, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 7, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 8, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060104006479, 9, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 1, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 2, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 3, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 4, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 5, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 6, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 7, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 8, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 9, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 10, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 11, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 12, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 13, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 14, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 15, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 16, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 17, 92, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817006480, 18, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 1, 68, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 2, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 3, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 4, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 5, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 6, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 7, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 8, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 9, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 10, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 11, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 12, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 13, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 14, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 15, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725006830, 16, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 1, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 2, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 3, 1, 26, 3, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 4, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 5, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 6, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525006831, 7, 39, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 1, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 2, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 3, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 4, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 5, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 6, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 7, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111006832, 8, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 1, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 2, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 3, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 4, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 5, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 6, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 7, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 8, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 9, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 10, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 11, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 12, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 13, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 14, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804006833, 15, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 1, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 2, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 3, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 4, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 5, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 6, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 7, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 8, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 9, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 10, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503006834, 11, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 1, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 2, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 3, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 4, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 5, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 6, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 7, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 8, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 9, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920006835, 10, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 1, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 2, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 3, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 4, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 5, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 6, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 7, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 8, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 9, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 10, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 11, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930006836, 12, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 1, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 2, 24, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 3, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 4, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 5, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 6, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 7, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 8, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 9, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 10, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 11, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 12, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 13, 178, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 14, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 15, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 16, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117006837, 17, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 1, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 2, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 3, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 4, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 5, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 6, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 7, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 8, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 9, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 10, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 11, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 12, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 13, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925006838, 14, 144, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 1, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 2, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 3, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 4, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 5, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 6, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 7, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 8, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 9, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 10, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 11, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080419006839, 12, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 1, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 2, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 3, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 4, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 5, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 6, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 7, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 8, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 9, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 10, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 11, 164, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 12, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 13, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210006840, 14, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 1, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 2, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 3, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 4, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 5, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 6, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 7, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 8, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 9, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912006841, 10, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924006842, 1, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924006842, 2, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924006842, 3, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924006842, 4, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924006842, 5, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 1, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 2, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 3, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 4, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 5, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 6, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 7, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 8, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 9, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 10, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 11, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 12, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 13, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628006843, 14, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 1, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 2, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 3, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 4, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 5, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 6, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020223006844, 7, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 1, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 2, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 3, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 4, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 5, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 6, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 7, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127006845, 8, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 1, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 2, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 3, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 4, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 5, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 6, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 7, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 8, 105, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 9, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 10, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 11, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 12, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 13, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120317006846, 14, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312006847, 1, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312006847, 2, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312006847, 3, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312006847, 4, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312006847, 5, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915006848, 1, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915006848, 2, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915006848, 3, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915006848, 4, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915006848, 5, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 1, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 2, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 3, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 4, 72, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 5, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 6, 156, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420006849, 7, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 1, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 2, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 3, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 4, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 5, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 6, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 7, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 8, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 9, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 10, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 11, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 12, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121006850, 13, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 1, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 2, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 3, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 4, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 5, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 6, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 7, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 8, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 9, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 10, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 11, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 12, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 13, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 14, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830006851, 15, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 1, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 2, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 3, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 4, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109005685, 14, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017005686, 1, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017005686, 2, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017005686, 3, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017005686, 4, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 1, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 2, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 3, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 4, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 5, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 6, 122, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 7, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 8, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 9, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 10, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 11, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 12, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 13, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 14, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424005687, 15, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 1, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 2, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 3, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 4, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 5, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 6, 27, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 7, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 8, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 9, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 10, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 11, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 12, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 13, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618005688, 14, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 1, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 2, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 3, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 4, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 5, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 6, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 7, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 8, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 9, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 10, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 11, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223005689, 12, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 1, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 2, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 3, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 4, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 5, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 6, 167, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 7, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902005690, 8, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 1, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 2, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 3, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 4, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 5, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 6, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 7, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 8, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330005691, 9, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102005692, 1, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102005692, 2, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102005692, 3, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102005692, 4, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102005692, 5, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 1, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 2, 134, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 3, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 4, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 5, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 6, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208005693, 7, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 1, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 2, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 3, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 4, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 5, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 6, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 7, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 8, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 9, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 10, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 11, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 12, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 13, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 14, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116005694, 15, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 1, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 2, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 3, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 4, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 5, 100, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 6, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 7, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226005695, 8, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 1, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 2, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 3, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 4, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 5, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 6, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505005696, 7, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 1, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 2, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 3, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 4, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 5, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 6, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 7, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 8, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 9, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 10, 81, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 11, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 12, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 13, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121005697, 14, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 1, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 2, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 4, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 5, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 6, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 7, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 8, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 9, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 10, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115005698, 11, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 1, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 2, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 3, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 4, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 5, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 6, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 7, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 8, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 9, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 10, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 11, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 12, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 13, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425005699, 14, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 1, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 2, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 3, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 4, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 5, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 6, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 7, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 8, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 9, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 10, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 11, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 12, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 13, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 14, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107005700, 15, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 1, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 2, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 3, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 4, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 5, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 6, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 7, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 8, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 9, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 10, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 11, 189, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 12, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 13, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 14, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120207005701, 15, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 1, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 2, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 3, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 4, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 5, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 6, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 7, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 8, 146, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 9, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 10, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 11, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403005702, 12, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 1, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 2, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 3, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 4, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 5, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 6, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 7, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 8, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519005703, 9, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 1, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 2, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 3, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 4, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 5, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 6, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 7, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 8, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123005704, 9, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 1, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 2, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 3, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 4, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 5, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 6, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 7, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106005705, 8, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 1, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 2, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 3, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 4, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 5, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 6, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 7, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 8, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 9, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607005706, 10, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 1, 92, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 2, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 3, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 4, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 5, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 6, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 7, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 8, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040329005707, 9, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 1, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 2, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 3, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 4, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 5, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 6, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 7, 169, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 8, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323006068, 17, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 1, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 2, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 3, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 4, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 5, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 6, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 7, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 8, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 9, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 10, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 11, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 12, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 13, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210006069, 14, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000915006070, 1, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000915006070, 2, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000915006070, 3, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 1, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 2, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 3, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 4, 92, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 5, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 6, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040319006071, 7, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017006072, 1, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017006072, 2, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017006072, 3, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017006072, 4, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207006073, 1, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207006073, 2, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 1, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 2, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 3, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 4, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 5, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 6, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 7, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 8, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 9, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 10, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 11, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 12, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515006074, 13, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923006075, 1, 104, 92, 13, 1196);
commit;
prompt 71000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923006075, 2, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923006075, 3, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 1, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 2, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 3, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 4, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 5, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 6, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 7, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 8, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 9, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 10, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916006076, 11, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 1, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 2, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 3, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 4, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 5, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 6, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 7, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 8, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 9, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 10, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218006077, 11, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024006078, 1, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024006078, 2, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024006078, 3, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 1, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 2, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 3, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 4, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 5, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 6, 189, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 7, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 8, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 9, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 10, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081107006079, 11, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 1, 12, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 2, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 3, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 4, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 5, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 6, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 7, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 8, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 9, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 10, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608006080, 11, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 1, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 2, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 3, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 4, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 5, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 6, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 7, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 8, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 9, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050331006081, 10, 143, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 1, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 2, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 3, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 4, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 5, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 6, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030328006082, 7, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 1, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 2, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 3, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 4, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 5, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 6, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 7, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 8, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211006083, 9, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006084, 1, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006084, 2, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006084, 3, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902006084, 4, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128006085, 1, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128006085, 2, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128006085, 3, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128006085, 4, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128006085, 5, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 1, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 2, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 3, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 4, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 5, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 6, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 7, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 8, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 9, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 10, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 11, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 12, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 13, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 14, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613006086, 15, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 1, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 2, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 3, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 4, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 5, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401006087, 6, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 1, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 2, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 3, 51, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 4, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 5, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 6, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 7, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 8, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 9, 45, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 10, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 11, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070826006088, 12, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 1, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 2, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 3, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 4, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 5, 17, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 6, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 7, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119006089, 8, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405006090, 1, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405006090, 2, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405006090, 3, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405006090, 4, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405006090, 5, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 1, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 2, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 3, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 4, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 5, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 6, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 7, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128006091, 8, 119, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 1, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 2, 36, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 3, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 4, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 5, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 6, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 7, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 8, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 9, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116006092, 10, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129006093, 1, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129006093, 2, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129006093, 3, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000619006094, 1, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000619006094, 2, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000619006094, 3, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000619006094, 4, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000619006094, 5, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313006095, 1, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313006095, 2, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313006095, 3, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313006095, 4, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715006096, 1, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715006096, 2, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715006096, 3, 83, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 1, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 2, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 3, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 4, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 5, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 6, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 7, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 8, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 9, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 10, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 11, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 12, 30, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 13, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 14, 95, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 15, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209006097, 16, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 1, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 2, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 3, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 4, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 5, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 6, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 7, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 8, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 9, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 10, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 11, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 12, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 13, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 14, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210006098, 15, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 5, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 6, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 7, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 8, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 9, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 10, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 11, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 12, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 13, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 14, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127006481, 15, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 1, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 2, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 3, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 4, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 5, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 6, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 7, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040128006482, 8, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 1, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 2, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 3, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 4, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 5, 47, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 6, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 7, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 8, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 9, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 10, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 11, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 12, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 13, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323006483, 14, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 1, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 2, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 3, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 4, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 5, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 6, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 7, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 8, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 9, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 10, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 11, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 12, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 13, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 14, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 15, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 16, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225006484, 17, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 1, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 2, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 3, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 4, 116, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 5, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 6, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 7, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703006485, 8, 44, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 1, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 2, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 3, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 4, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 5, 28, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 6, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 7, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 8, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 9, 42, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 10, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 11, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 12, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 13, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 14, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 15, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111203006486, 16, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 1, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 2, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 3, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 4, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 5, 150, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 6, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 7, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 8, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 9, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 10, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 11, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 12, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731006487, 13, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 1, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 2, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 3, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 4, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 5, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 6, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 7, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 8, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 9, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 10, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 11, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 12, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 13, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 14, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802006488, 15, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 1, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 2, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 3, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 4, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 5, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515006489, 6, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 1, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 2, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 3, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 4, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 5, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 6, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 7, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322006490, 8, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 1, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 2, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 3, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 4, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 5, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 6, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 7, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 8, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 9, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 10, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 11, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 12, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 13, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 14, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 15, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209006491, 16, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 1, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 2, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 3, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 4, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 5, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 6, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 7, 29, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 8, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 9, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 10, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 11, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 12, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 13, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319006492, 14, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 1, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 2, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 3, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 4, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 5, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 6, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 7, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625006493, 8, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 1, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 2, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 3, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 4, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 5, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 6, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 7, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 8, 4, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 9, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 10, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105006494, 11, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 1, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 2, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 3, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 4, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 5, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 6, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 7, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 8, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 9, 137, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 10, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 11, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 12, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 13, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 14, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120821006495, 15, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 1, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 2, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 3, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 4, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 5, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 6, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 7, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 8, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 9, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 10, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 11, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 12, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 13, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 14, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 15, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 16, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806006496, 17, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006497, 1, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006497, 2, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613006497, 3, 174, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 1, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 2, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 3, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 4, 23, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 5, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 6, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 7, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212006498, 8, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 1, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 2, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 3, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 4, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 5, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 6, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 7, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625006499, 8, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 1, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 2, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 3, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 4, 61, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 5, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 6, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 7, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 8, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 9, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 10, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 11, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 12, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 13, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 14, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 15, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412006500, 16, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 1, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 2, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 3, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 4, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 5, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120006501, 6, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918006502, 1, 181, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918006502, 2, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 5, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 6, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 7, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 8, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 9, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 10, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 11, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 12, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 13, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224006852, 14, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228006853, 1, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228006853, 2, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 1, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 2, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 3, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 4, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 5, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 6, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 7, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 8, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 9, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 10, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 11, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614006854, 12, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 1, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 2, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 3, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 4, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 5, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 6, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202006855, 7, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 1, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 2, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 3, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 4, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 5, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 6, 33, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 7, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 8, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 9, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 10, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903006856, 11, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 1, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 2, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 3, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 4, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 5, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 6, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210006857, 7, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 1, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 2, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 3, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 4, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 5, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 6, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 7, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 8, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 9, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 10, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 11, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 12, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012006858, 13, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 1, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 2, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 3, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 4, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 5, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 6, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 7, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 8, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 9, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 10, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 11, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 12, 37, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 13, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 14, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 15, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026006859, 16, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 1, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 2, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 3, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 4, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 5, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 6, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 7, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 8, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 9, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 10, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022006860, 11, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 1, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 2, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 3, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 4, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 5, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 6, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 7, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 8, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 9, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 10, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 11, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 12, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 13, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 14, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110304006861, 15, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813006862, 1, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813006862, 2, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813006862, 3, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813006862, 4, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813006862, 5, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 1, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 2, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 3, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 4, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 5, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 6, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 7, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 8, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 9, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 10, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 11, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 12, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 13, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 14, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 15, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511006863, 16, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 1, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 2, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 3, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 4, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 5, 127, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 6, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 7, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 8, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 9, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 10, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130006864, 11, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220006865, 1, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220006865, 2, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 1, 110, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 2, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 3, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 4, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 5, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930006866, 6, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 1, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 2, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 3, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 4, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 5, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 6, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 7, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 8, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 9, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 10, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 11, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 12, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 13, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 14, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301006867, 15, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 1, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 2, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 3, 77, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 4, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 5, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 6, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 7, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 8, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025006868, 9, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 1, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 2, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 3, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 4, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 5, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 6, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 7, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 8, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 9, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 10, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 11, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 12, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 13, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121123006869, 14, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 1, 163, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 2, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 3, 122, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 4, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 5, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 6, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 7, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 8, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131006870, 9, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 1, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 2, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 3, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 4, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 5, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 6, 90, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 7, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 8, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 9, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 10, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 11, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 12, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221006871, 13, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 1, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 2, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 3, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 4, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 5, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 6, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 7, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 8, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 9, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 10, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 11, 158, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 12, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321006872, 13, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 1, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 2, 138, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 3, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 4, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 5, 99, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 6, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 7, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 8, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 9, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 10, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 11, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081222006873, 12, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 1, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 2, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 3, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 4, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 5, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 6, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 7, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 8, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 9, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080219006874, 10, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 9, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 10, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 11, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 12, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100404005708, 13, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 1, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 2, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 3, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 4, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 5, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 6, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 7, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 8, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102005709, 9, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 1, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 2, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 3, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 4, 154, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 5, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 6, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 7, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 8, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125005710, 9, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 1, 92, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 2, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 3, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 4, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 5, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 6, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 7, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612005711, 8, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 1, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 2, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 3, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 4, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 5, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 6, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 7, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030225005712, 8, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 1, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 2, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 3, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 4, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 5, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 6, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 7, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 8, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 9, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 10, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 11, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 12, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 13, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 14, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 15, 119, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620005713, 16, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 1, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 2, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 3, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 4, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 5, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 6, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 7, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 8, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 9, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 10, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 11, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 12, 4, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090810005714, 13, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 1, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 2, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 3, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 4, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 5, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 6, 188, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 7, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 8, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 9, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 10, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 11, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 12, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 13, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 14, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 15, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324005715, 16, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921005716, 1, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921005716, 2, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921005716, 3, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921005716, 4, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 1, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 2, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 3, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 4, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 5, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 6, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 7, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822005717, 8, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 1, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 2, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 3, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 4, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 5, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 6, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 7, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 8, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 9, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 10, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 11, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 12, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 13, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 14, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 15, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 16, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 17, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 18, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220005718, 19, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 1, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 2, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 3, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 4, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 5, 72, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 6, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 7, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 8, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 9, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 10, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 11, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304005719, 12, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005720, 1, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005720, 2, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005720, 3, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005720, 4, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201005720, 5, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 1, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 2, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 3, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 4, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 5, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 6, 186, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 7, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 8, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 9, 24, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 10, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 11, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 12, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 13, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 14, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 15, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122005721, 16, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 1, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 2, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 3, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 4, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 5, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031127005722, 6, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 1, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 2, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 3, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 4, 61, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 5, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 6, 66, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 7, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 8, 192, 62, 18, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 9, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 10, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803005723, 11, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 1, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 2, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 3, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 4, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 5, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 6, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 7, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 8, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 9, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 10, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 11, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 12, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 13, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 14, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 15, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303005724, 16, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 1, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 2, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 3, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 4, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 5, 10, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 6, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 7, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 8, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 9, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 10, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 11, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120005725, 12, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 1, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 2, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 3, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 4, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 5, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 6, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 7, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 8, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 9, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 10, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 11, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 12, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214005726, 13, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 1, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 2, 78, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 3, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 4, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 5, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 6, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 7, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 8, 36, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023005727, 9, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 1, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 2, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 3, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 4, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 5, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 6, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 7, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210005728, 8, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 1, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 2, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 3, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 4, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 5, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 6, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 7, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 8, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012005729, 9, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 1, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 2, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 3, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 4, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 5, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 6, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211005730, 7, 23, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 1, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 2, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 3, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 4, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 5, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 6, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 7, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 8, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 9, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071219006099, 10, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 1, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 2, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 3, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 4, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 5, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 6, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806006100, 7, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 1, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 2, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 3, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 4, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 5, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 6, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 7, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 8, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 9, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 10, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601006101, 11, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 1, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 2, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 3, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 4, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 5, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 6, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 7, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 8, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 9, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 10, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 11, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080207006102, 12, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 1, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 2, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 3, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 4, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 5, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 6, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 7, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 8, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 9, 182, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 10, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 11, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 12, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 13, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101001006103, 14, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 1, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 2, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 3, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 4, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 5, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 6, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 7, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 8, 108, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 9, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 10, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 11, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 12, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 13, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 14, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 15, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120308006104, 16, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 1, 81, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 2, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 3, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 4, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 5, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 6, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 7, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 8, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 9, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 10, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 11, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 12, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 13, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 14, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203006105, 15, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 1, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 2, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 3, 61, 33, 11, 363);
commit;
prompt 72000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 4, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 5, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 6, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 7, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 8, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 9, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 10, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 11, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 12, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 13, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616006106, 14, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 1, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 2, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 3, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 4, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 5, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 6, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 7, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825006107, 8, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208006108, 1, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208006108, 2, 108, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208006108, 3, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208006108, 4, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 1, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 2, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 3, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 4, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 5, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 6, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 7, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 8, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116006109, 9, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 1, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 2, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 3, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 4, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 5, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 6, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 7, 1, 97, 3, 291);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 8, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404006110, 9, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000509006111, 1, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000509006111, 2, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 1, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 2, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 3, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 4, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 5, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 6, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 7, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 8, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413006112, 9, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 1, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 2, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 3, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 4, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 5, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 6, 48, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 7, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 8, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 9, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 10, 155, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 11, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 12, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 13, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 14, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 15, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 16, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 17, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421006113, 18, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 1, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 2, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 3, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 4, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 5, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 6, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 7, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918006114, 8, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 1, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 2, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 3, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 4, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 5, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 6, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 7, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 8, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 9, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 10, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 11, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 12, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 13, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 14, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 15, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 16, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 17, 155, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 18, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112006115, 19, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728006116, 1, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728006116, 2, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728006116, 3, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 1, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 2, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 3, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 4, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 5, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 6, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050419006117, 7, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 1, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 2, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 3, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 4, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 5, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 6, 13, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 7, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 8, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 9, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420006118, 10, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 1, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 2, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 3, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 4, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 5, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 6, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 7, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 8, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 9, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 10, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 11, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090701006119, 12, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 1, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 2, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 3, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 4, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 5, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 6, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 7, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 8, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 9, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 10, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902006120, 11, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 1, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 2, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 3, 1, 75, 3, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 4, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 5, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 6, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 7, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 8, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 9, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 10, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090515006121, 11, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 14, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 15, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 16, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 17, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 1, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 2, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 3, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 4, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 5, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 6, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 7, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 8, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 9, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 10, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 11, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 12, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 13, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 14, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222007636, 15, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 1, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 2, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 3, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 4, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 5, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 6, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 7, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 8, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 9, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706007637, 10, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127007638, 1, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127007638, 2, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127007638, 3, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127007638, 4, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127007638, 5, 174, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 1, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 2, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 3, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 4, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 5, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 6, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 7, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809007639, 8, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 1, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 2, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 3, 1, 29, 3, 87);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 4, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 5, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 6, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 7, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 8, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 9, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 10, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809007640, 11, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 1, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 2, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 3, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 4, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 5, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 6, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 7, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 8, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 9, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070215007641, 10, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108007642, 1, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108007642, 2, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108007642, 3, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108007642, 4, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108007642, 5, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 1, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 2, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 3, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 4, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 5, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 6, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 7, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 8, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 9, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 10, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327007643, 11, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 1, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 2, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 3, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 4, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 5, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 6, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 7, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 8, 22, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 9, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 10, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 11, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 12, 68, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 13, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210007644, 14, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 1, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 2, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 3, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 4, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 5, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 6, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 7, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007645, 8, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 1, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 2, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 3, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 4, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 5, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 6, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 7, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 8, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029007646, 9, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 1, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 2, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 3, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 4, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 5, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 6, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 7, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050922007647, 8, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 1, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 2, 191, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 3, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 4, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 5, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 6, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 7, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 8, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 9, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 10, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 11, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 12, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 13, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 14, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620007648, 15, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 1, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 2, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 3, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 4, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 5, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 6, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 7, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 8, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 9, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 10, 41, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 11, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 12, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 13, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 14, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 15, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823007649, 16, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 1, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 2, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 3, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 4, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 5, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 6, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 7, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 8, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 9, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 10, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 11, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812007650, 12, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 1, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 2, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 3, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 4, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 5, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 6, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 7, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 8, 6, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 9, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 10, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071203007651, 11, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 1, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 2, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 3, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 4, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 5, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 6, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 7, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 8, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 9, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219007652, 10, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310007653, 1, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310007653, 2, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 1, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 2, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 3, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 4, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 5, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 6, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 7, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 8, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 9, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050809007654, 10, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 1, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 2, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 3, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 4, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 5, 74, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 6, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 7, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 8, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 9, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 10, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070216007655, 11, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 1, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 2, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 3, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 4, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 5, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 6, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 7, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 8, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 9, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 10, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 11, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 12, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 13, 14, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119007656, 14, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007657, 1, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007657, 2, 191, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007657, 3, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007657, 4, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624007658, 1, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624007658, 2, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624007658, 3, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624007658, 4, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 1, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 2, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 3, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 4, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 5, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014007659, 6, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 1, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 2, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 3, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 4, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 5, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 6, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 5, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 6, 27, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 7, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 8, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 1, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 2, 89, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 3, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 4, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 5, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 6, 151, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 7, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 8, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 9, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 10, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 11, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028008001, 12, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 1, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 2, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 3, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 4, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 5, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 6, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 7, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 8, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 9, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214008002, 10, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 1, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 3, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 4, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 5, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 6, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 7, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 8, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 9, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210008003, 10, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 1, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 2, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 3, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 4, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 5, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 6, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 7, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 8, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 9, 15, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 10, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 11, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 12, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 13, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 14, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703008004, 15, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 1, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 2, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 3, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 4, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 5, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 6, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 7, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 8, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 9, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 10, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 11, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 12, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 13, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 14, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 15, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231008005, 16, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 1, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 2, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 3, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 4, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 5, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521008006, 6, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 1, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 2, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 3, 149, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 4, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 5, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 6, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 7, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 8, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 9, 165, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 10, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 11, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 12, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604008007, 13, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 1, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 2, 155, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 3, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 4, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 5, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 6, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 7, 8, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 8, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 9, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 10, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 11, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 12, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 13, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 14, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130008008, 15, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 1, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 2, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 3, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 4, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 5, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 6, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 7, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 8, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 9, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 10, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080322008009, 11, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916008010, 1, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916008010, 2, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916008010, 3, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916008010, 4, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916008010, 5, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 1, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 2, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 3, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 4, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 5, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 6, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118008011, 7, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 1, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 2, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 3, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 4, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 5, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 6, 87, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 7, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924008012, 8, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 1, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 2, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 3, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 4, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 5, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 6, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 7, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 8, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 9, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 10, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 11, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707008013, 12, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008014, 1, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008014, 2, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008014, 3, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008014, 4, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008014, 5, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 1, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 2, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 3, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 4, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 5, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 6, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308008015, 7, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 1, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 2, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 3, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 4, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 5, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 6, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008016, 7, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 1, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 2, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 3, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 4, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 5, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 6, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 7, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510008017, 8, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 1, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 2, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 3, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 4, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 5, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 6, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 7, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 8, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 9, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 10, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 11, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 12, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 13, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008018, 14, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 1, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 2, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 3, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 4, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 5, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 6, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 7, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 8, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 9, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 10, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 11, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 12, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101122008019, 13, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 1, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 2, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 3, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 4, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 5, 22, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 6, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 7, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 8, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 9, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 10, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 11, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 12, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419008020, 13, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 1, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 2, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 3, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 4, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 5, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 6, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 7, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060717008021, 8, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 1, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 2, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 3, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 4, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 5, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 6, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 7, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 8, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525008022, 9, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 1, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 2, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 3, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 4, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 5, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 6, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 7, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 8, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 9, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 10, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 11, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 4, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 5, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 6, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 7, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 8, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 9, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 10, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 11, 68, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 12, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 1, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 2, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 3, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 4, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 5, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 6, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 7, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 8, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 9, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 10, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 11, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 12, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 13, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 14, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008386, 15, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 1, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 2, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 3, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 4, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 5, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 6, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 7, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 8, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 9, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228008387, 10, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 1, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 2, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 3, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 4, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 5, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 6, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 7, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008388, 8, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212008389, 1, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212008389, 2, 170, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212008389, 3, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212008389, 4, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 1, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 2, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 3, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 4, 148, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 5, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008390, 6, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000128008391, 1, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000128008391, 2, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701008392, 1, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701008392, 2, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701008392, 3, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701008392, 4, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 1, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 2, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 3, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 4, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 5, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 6, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 7, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 8, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 9, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 10, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 11, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 12, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 13, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008393, 14, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 1, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 2, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 3, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 4, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 5, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 6, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 7, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 8, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 9, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 10, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 11, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 12, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 13, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 14, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208008394, 15, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 1, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 2, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 3, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 4, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 5, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 6, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 7, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 8, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 9, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 10, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 11, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330008395, 12, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 1, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 2, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 3, 46, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 4, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 5, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 6, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 7, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 8, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 9, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 10, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013008396, 11, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 1, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 2, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 3, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 4, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 5, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 6, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 7, 31, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 8, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 9, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 10, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 11, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729008397, 12, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323008398, 1, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323008398, 2, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323008398, 3, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010323008398, 4, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126008399, 1, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126008399, 2, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126008399, 3, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126008399, 4, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 1, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 2, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 3, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 4, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 5, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 6, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 7, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 8, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528008400, 9, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 1, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 2, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 3, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 4, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 5, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 6, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 7, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 8, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 9, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 10, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919008401, 11, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 1, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 2, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 3, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 4, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 5, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 6, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 7, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 8, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 9, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 10, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 11, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 12, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 13, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 14, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 15, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008402, 16, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 1, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 2, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 3, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 4, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 5, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 6, 41, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 7, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 8, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 9, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 10, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008403, 11, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 1, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 2, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 3, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 4, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 5, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 6, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 7, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 8, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 9, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 10, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 11, 167, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 12, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 13, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 14, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 15, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 16, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008404, 17, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 1, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 2, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 3, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 4, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 5, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 6, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 7, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 8, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 9, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 10, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 11, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 12, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 13, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 14, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220008405, 15, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 1, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 2, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 3, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 4, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 5, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 6, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 7, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 8, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 9, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 10, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 11, 144, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 12, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725008406, 13, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 1, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 2, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 3, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 4, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 5, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 6, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 7, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 8, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 9, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317008407, 10, 48, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604008408, 1, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604008408, 2, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604008408, 3, 78, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604008408, 4, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604008408, 5, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 1, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 2, 94, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 3, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 4, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 5, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 6, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 7, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 8, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 9, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 10, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 11, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 12, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 13, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 14, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 1, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 2, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 3, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 4, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 5, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 6, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 7, 5, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 8, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007262, 9, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421007263, 1, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421007263, 2, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421007263, 3, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 1, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 2, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 3, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 4, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 5, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 6, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 7, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 8, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 9, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 10, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 11, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 12, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 13, 55, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 14, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 15, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 16, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 17, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122007264, 18, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 1, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 2, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 3, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 4, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 5, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 6, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 7, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 8, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930007265, 9, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 1, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 2, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 3, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 4, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 5, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 6, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 7, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111007266, 8, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 1, 76, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 2, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 3, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 4, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 5, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007267, 6, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 1, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 2, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 3, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 4, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 5, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 6, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 7, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 8, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 9, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820007268, 10, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 1, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 2, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 3, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 4, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 5, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 6, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 7, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 8, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 9, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 10, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404007269, 11, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 1, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 2, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 3, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 4, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 5, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 6, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 7, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 8, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 9, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 10, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 11, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 12, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 13, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430007270, 14, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 1, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 2, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 3, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 4, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 5, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 6, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 7, 14, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 8, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603007271, 9, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 1, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 2, 34, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 3, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 4, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 5, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 6, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320007272, 7, 89, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325007273, 1, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325007273, 2, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325007273, 3, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325007273, 4, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 1, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 2, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 3, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 4, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 5, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 6, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 7, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324007274, 8, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 1, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 2, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 3, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 4, 84, 71, 10, 710);
commit;
prompt 73000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 5, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 6, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 7, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 8, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 9, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 10, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 11, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 12, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 13, 25, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 14, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 15, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 16, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430007275, 17, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723007276, 1, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723007276, 2, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723007276, 3, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723007276, 4, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723007276, 5, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 1, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 2, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 3, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 4, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 5, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 6, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 7, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 8, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 9, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 10, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 11, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 12, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110007277, 13, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 1, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 2, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 3, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 4, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 5, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 6, 74, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 7, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 8, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513007278, 9, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 1, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 2, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 3, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 4, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 5, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 6, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 7, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 8, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 9, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 10, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 11, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 12, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 13, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519007279, 14, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 1, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 2, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 3, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 4, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 5, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 6, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 7, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 8, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 9, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 10, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408007280, 11, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 1, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 2, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 3, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 4, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 5, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 6, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 7, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219007281, 8, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 1, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 2, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 3, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 4, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 5, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 6, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 7, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 8, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 9, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 10, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 11, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013007282, 12, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 1, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 2, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 3, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 4, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 5, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 6, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020824007283, 7, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 1, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 2, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 3, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 4, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 5, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 6, 54, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825007284, 7, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909007285, 1, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909007285, 2, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010909007285, 3, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609007286, 1, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609007286, 2, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609007286, 3, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609007286, 4, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815007660, 7, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 1, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 2, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 3, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 4, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 5, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 6, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124007661, 7, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 1, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 2, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 3, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 4, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 5, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 6, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 7, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507007662, 8, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 1, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 2, 66, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 3, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 4, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 5, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 6, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 7, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007663, 8, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 1, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 2, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 3, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 4, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 5, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612007664, 6, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 1, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 2, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 3, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 4, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 5, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 6, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 7, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 8, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 9, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 10, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 11, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401007665, 12, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824007666, 1, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824007666, 2, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824007666, 3, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824007666, 4, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824007666, 5, 54, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610007667, 1, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610007667, 2, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610007667, 3, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610007667, 4, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610007667, 5, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 1, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 2, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 3, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 4, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 5, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 6, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 7, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 8, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 9, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 10, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 11, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 12, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 13, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228007668, 14, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 1, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 2, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 3, 2, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 4, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 5, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 6, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050926007669, 7, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215007670, 1, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215007670, 2, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215007670, 3, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215007670, 4, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215007670, 5, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 1, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 2, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 3, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 4, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 5, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 6, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 7, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 8, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 9, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 10, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 11, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 12, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 13, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 14, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 15, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 16, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 17, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 18, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007671, 19, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 1, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 2, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 3, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 4, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 5, 39, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 6, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 7, 93, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 8, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 9, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425007672, 10, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031007673, 1, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031007673, 2, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031007673, 3, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031007673, 4, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 1, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 2, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 3, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 4, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 5, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 6, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 7, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 8, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 9, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 10, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 11, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 12, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 13, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 14, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728007674, 15, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007675, 1, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007675, 2, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007675, 3, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 1, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 2, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 3, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 4, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 5, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 6, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 7, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 8, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 9, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 10, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 11, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 12, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 13, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 14, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 15, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111007676, 16, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 1, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 2, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 3, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 4, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 5, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 6, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327007677, 7, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 1, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 2, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 3, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 4, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 5, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 6, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 7, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 8, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 9, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 10, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 11, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 12, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 13, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 14, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804007678, 15, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 1, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 2, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 3, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 4, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 5, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 6, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 7, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 8, 189, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 9, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 10, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711007679, 11, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 1, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 2, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 3, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 4, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 5, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 6, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 7, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 8, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 9, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721007680, 10, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 1, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 2, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 3, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 4, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 5, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021122007681, 6, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 1, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 2, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 3, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 4, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 5, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308007682, 6, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 1, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 2, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 3, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 4, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 5, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 6, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 7, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 8, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211007683, 9, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 1, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 2, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 3, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 4, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 5, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 6, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 7, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 8, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 9, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 10, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 11, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 12, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 13, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110826007684, 14, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 1, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 2, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 3, 180, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 4, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 5, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 6, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 7, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 8, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 9, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 10, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 11, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 12, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 13, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 14, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903007685, 15, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 1, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 12, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 13, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008023, 14, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008024, 1, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008024, 2, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008024, 3, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008024, 4, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008024, 5, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 1, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 2, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 3, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 4, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 5, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 7, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 8, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 9, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 10, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 11, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 12, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 13, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 14, 163, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 15, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604008025, 16, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 1, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 2, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 3, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 4, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 5, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 6, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 7, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 8, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071108008026, 9, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 1, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 2, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 3, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 4, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 5, 148, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 6, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 7, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 8, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 9, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 10, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 11, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001008027, 12, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111008028, 1, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111008028, 2, 174, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111008028, 3, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111008028, 4, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008029, 1, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008029, 2, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008029, 3, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008029, 4, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 1, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 2, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 3, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 4, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 5, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 6, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 7, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 8, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 9, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805008030, 10, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 1, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 2, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 3, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 4, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 5, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 6, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 7, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 8, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 9, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 10, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 11, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 12, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 13, 96, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 14, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 15, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 16, 156, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120521008031, 17, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 1, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 2, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 3, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 4, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 5, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 6, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 7, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 8, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 9, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 10, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 11, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 12, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 13, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 14, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 15, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 16, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 17, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507008032, 18, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 1, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 2, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 3, 125, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 4, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 5, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 6, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 7, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 8, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 9, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 10, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 11, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 12, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 13, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 14, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101109008033, 15, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 1, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 2, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 3, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 4, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 5, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 6, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 7, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 8, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 9, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 10, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008034, 11, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 1, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 2, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 3, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 4, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 5, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411008035, 6, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 1, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 2, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 3, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 4, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 5, 24, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 6, 27, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 7, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 8, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 9, 154, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 10, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 11, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 12, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 13, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121008036, 14, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 1, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 2, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 3, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 4, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 5, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 6, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 7, 153, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 8, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 9, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 10, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 11, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 12, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 13, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 14, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602008037, 15, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 1, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 2, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 3, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 4, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 5, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 6, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 7, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 8, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060304008038, 9, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 1, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 2, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 3, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 4, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 5, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 6, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 7, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 8, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 9, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 10, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 11, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519008039, 12, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 1, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 2, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 3, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 4, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 5, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 6, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 7, 38, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 8, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 9, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 10, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716008040, 11, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 1, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 2, 44, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 3, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 4, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 5, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 6, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 7, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 8, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 9, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502008041, 10, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 1, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 2, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 3, 145, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 4, 124, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 5, 10, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 6, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 7, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 8, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 9, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 10, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 11, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 12, 6, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 13, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 14, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115008042, 15, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 1, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 2, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 3, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 4, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 5, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 6, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 7, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 8, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040622008043, 9, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310008044, 1, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310008044, 2, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008045, 1, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008045, 2, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008045, 3, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111008046, 1, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111008046, 2, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111008046, 3, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 1, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 2, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 3, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 4, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 5, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 6, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 2, 133, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 3, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 4, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 5, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020209008409, 6, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 1, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 2, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 3, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 4, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 5, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 6, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041204008410, 7, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 1, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 2, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 3, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 4, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 5, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 6, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805008411, 7, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 1, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 2, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 3, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 4, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 5, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 6, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 7, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 8, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 9, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713008412, 10, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 1, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 2, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 3, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 4, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 5, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 6, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 7, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 8, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 9, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 10, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 11, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 12, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 13, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 14, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 15, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825008413, 16, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 1, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 2, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 3, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 4, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 5, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 6, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 7, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 8, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 9, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 10, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 11, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 12, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 13, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 14, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 15, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 16, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 17, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130520008414, 18, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 1, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 2, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 3, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 4, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 5, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 6, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 7, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430008415, 8, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 1, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 2, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 3, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 4, 165, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 5, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 6, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 7, 88, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 8, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 9, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008416, 10, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 1, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 2, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 3, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 4, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 5, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 6, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 7, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 8, 16, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 9, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408008417, 10, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 1, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 2, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 3, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 4, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 5, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 6, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 7, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 8, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 9, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 10, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008418, 11, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 1, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 2, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 3, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 4, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 5, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 6, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 7, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 8, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 9, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 10, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 11, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 12, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 13, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 14, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 15, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 16, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 17, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911008419, 18, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 1, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 2, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 3, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 4, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 5, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 6, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 7, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 8, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 9, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 10, 70, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308008420, 11, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 1, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 2, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 3, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 4, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 5, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 6, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 7, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 8, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219008421, 9, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 1, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 2, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 3, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 4, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 5, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 6, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 7, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 8, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 9, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 10, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 11, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 12, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 13, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 14, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214008422, 15, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 1, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 2, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 3, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 4, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 5, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 6, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 7, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 8, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 9, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 10, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 11, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 12, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 13, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 14, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 15, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709008423, 16, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 1, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 2, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 3, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 4, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 5, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 6, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 7, 12, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 8, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 9, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 10, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 11, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 12, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 13, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 14, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 15, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618008424, 16, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 1, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 2, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 3, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 4, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 5, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 6, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 7, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 8, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 9, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 10, 142, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 11, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008425, 12, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004008426, 1, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004008426, 2, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004008426, 3, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004008426, 4, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004008426, 5, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 1, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 2, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 3, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 4, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 5, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 6, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 7, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 8, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 9, 5, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 10, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 11, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 12, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702008427, 13, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 1, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 2, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 3, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 4, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 5, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 6, 153, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 7, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 8, 100, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 9, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 10, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216008428, 11, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 1, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 2, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 3, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 4, 84, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 5, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 6, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002008429, 7, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 1, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 2, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 3, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 4, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 1, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 2, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 3, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 4, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 5, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007287, 6, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 1, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 2, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 3, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 4, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 5, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 6, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 7, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 8, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 9, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728007288, 10, 126, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425007289, 1, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425007289, 2, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425007289, 3, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425007289, 4, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425007289, 5, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 1, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 2, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 3, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 4, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 5, 8, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 6, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 7, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 8, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129007290, 9, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 1, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 2, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 3, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 4, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 5, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007291, 6, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016007292, 1, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016007292, 2, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016007292, 3, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212007293, 1, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212007293, 2, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212007293, 3, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 1, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 2, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 3, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 4, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 5, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 6, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 7, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007294, 8, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 1, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 2, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 3, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 4, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 5, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 6, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 7, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 8, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 9, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 10, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 11, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 12, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 13, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 14, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030007295, 15, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 1, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 2, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 3, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 4, 79, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 5, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 6, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 7, 171, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 8, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 9, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 10, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 11, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 12, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 13, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427007296, 14, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 1, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 2, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 3, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 4, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 5, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627007297, 6, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 1, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 2, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 3, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 4, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 5, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 6, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 7, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 8, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 9, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 10, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007298, 11, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 1, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 2, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 3, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 4, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 5, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 6, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 7, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 8, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 9, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 10, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 11, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 12, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829007299, 13, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 1, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 2, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 3, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 4, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 5, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 6, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411007300, 7, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 1, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 2, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 3, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 4, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 5, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 6, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 7, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 8, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 9, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 10, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 11, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729007301, 12, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 1, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 2, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 3, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 4, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 5, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 6, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 7, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 8, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 9, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 10, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 11, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 12, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100408007302, 13, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 1, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 2, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 3, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 4, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 5, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 6, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 7, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 8, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 9, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 10, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 11, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 12, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 13, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 14, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 15, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 16, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007303, 17, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 1, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 2, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 3, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 4, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 5, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 6, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 7, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 8, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 9, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 10, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 11, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 12, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131007304, 13, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 1, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 2, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 3, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 4, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 5, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 6, 105, 100, 7, 700);
commit;
prompt 74000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 7, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 8, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 9, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 10, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081209007305, 11, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430007306, 1, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430007306, 2, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430007306, 3, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430007306, 4, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 1, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 2, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 3, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 4, 12, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 5, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 6, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 7, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 8, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 9, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 10, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 11, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 12, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 13, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 14, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 15, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 16, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 17, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226007307, 18, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 1, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 2, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 3, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 4, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 5, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 6, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 7, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 8, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 9, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 10, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 11, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304007308, 12, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 1, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 2, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 3, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 4, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 5, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 6, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 7, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 8, 109, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 9, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 10, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 11, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 12, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 13, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 14, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226007309, 15, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007310, 1, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007310, 2, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007310, 3, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007310, 4, 192, 64, 18, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028007311, 1, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028007311, 2, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028007311, 3, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028007311, 4, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 2, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 3, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 4, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 5, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 6, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 7, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 8, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 9, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 10, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611007686, 11, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214007687, 1, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214007687, 2, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214007687, 3, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 1, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 2, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 3, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 4, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 5, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 6, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111007688, 7, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 1, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 2, 174, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 3, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 4, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 5, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 6, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 7, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620007689, 8, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 1, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 2, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 3, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 4, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 5, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 6, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 7, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 8, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 9, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 10, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 11, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 12, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302007690, 13, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816007691, 1, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816007691, 2, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816007691, 3, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816007691, 4, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 1, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 2, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 3, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 4, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 5, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 6, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 7, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 8, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 9, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 10, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 11, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 12, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 13, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530007692, 14, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 1, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 2, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 3, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 4, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 5, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031103007693, 6, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 1, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 2, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 3, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 4, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 5, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 6, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 7, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 8, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 9, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 10, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 11, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 12, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 13, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 14, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 15, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108007694, 16, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 1, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 2, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 3, 83, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 4, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 5, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 6, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 7, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128007695, 8, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718007696, 1, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718007696, 2, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718007696, 3, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 1, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 2, 162, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 3, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 4, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 5, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 6, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 7, 140, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 8, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624007697, 9, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 1, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 2, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 3, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 4, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 5, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 6, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 7, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 8, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 9, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 10, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 11, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 12, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 13, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007698, 14, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 1, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 2, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 3, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 4, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 5, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 6, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002007699, 7, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 1, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 2, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 3, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 4, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 5, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 6, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 7, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 8, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 9, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 10, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 11, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 12, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 13, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 14, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 15, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221007700, 16, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 1, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 2, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 3, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 4, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 5, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 6, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 7, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 8, 24, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 9, 121, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 10, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 11, 19, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 12, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 13, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 14, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007701, 15, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 1, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 2, 107, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 3, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 4, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 5, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 6, 99, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 7, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 8, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 9, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 10, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202007702, 11, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 1, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 2, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 3, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 4, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 5, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520007703, 6, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 1, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 2, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 3, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 4, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 5, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 6, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 7, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 8, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 9, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 10, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 11, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100119007704, 12, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 1, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 2, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 3, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 4, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 5, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 6, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429007705, 7, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912007706, 1, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912007706, 2, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912007706, 3, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912007706, 4, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912007706, 5, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 1, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 2, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 3, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 4, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 5, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013007707, 6, 174, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 1, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 2, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 3, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 4, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 5, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 6, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 7, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 8, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 9, 64, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 10, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811007708, 11, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 1, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 2, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 3, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 4, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 5, 27, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 6, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 7, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 8, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 9, 182, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 10, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 11, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 12, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007709, 13, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 1, 48, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 2, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 3, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 4, 107, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 5, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 6, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 7, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 8, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 9, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 10, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 11, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 12, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 13, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 14, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 15, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 7, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 8, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 9, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 10, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 11, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 12, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 13, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 14, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 15, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016008047, 16, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 1, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 2, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 3, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 4, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 5, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 6, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 7, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 8, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 9, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 10, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 11, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 12, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 13, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228008048, 14, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 1, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 2, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 3, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 4, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 5, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 6, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 7, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 8, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 9, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 10, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 11, 12, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 12, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008049, 13, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 1, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 2, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 3, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 4, 42, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 5, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 6, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 7, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009008050, 8, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027008051, 1, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027008051, 2, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027008051, 3, 169, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027008051, 4, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027008051, 5, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 1, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 2, 19, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 3, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 4, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 5, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 6, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 7, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 8, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 9, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 10, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 11, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 12, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402008052, 13, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 1, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 2, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 3, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 4, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 5, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 6, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 7, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223008053, 8, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 1, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 2, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 3, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 4, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 5, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 6, 154, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 7, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 8, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 9, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008054, 10, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008055, 1, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008055, 2, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008055, 3, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008055, 4, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008055, 5, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705008056, 1, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705008056, 2, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705008056, 3, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705008056, 4, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705008056, 5, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 1, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 3, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 4, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 5, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014008057, 6, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 1, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 2, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 3, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 4, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 5, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 6, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 7, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 8, 128, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 9, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 10, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824008058, 11, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 1, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 2, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 3, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 4, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 5, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 6, 39, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 7, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008059, 8, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 1, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 2, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 3, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 4, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 5, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 6, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 7, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 8, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 9, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 10, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 11, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 12, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 13, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 14, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 15, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 16, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915008060, 17, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 1, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 2, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 3, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 4, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 5, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 6, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 7, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 8, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 9, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 10, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 11, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008061, 12, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 1, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 2, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 3, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 4, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 5, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110008062, 6, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 1, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 2, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 3, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 4, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 5, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 6, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 7, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 8, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 9, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 10, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 11, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 12, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 13, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 14, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117008063, 15, 59, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525008064, 1, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525008064, 2, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525008064, 3, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525008064, 4, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525008064, 5, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 1, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 2, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 3, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 5, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112008065, 6, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 1, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 2, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 3, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 4, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 5, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 6, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 7, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 8, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 9, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907008066, 10, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 1, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 2, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 3, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 4, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 5, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828008067, 6, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 1, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 2, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 3, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 4, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 5, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 6, 127, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 7, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 8, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 9, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 10, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 11, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 12, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 13, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 14, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724008068, 15, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619008069, 1, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619008069, 2, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619008069, 3, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619008069, 4, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619008069, 5, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 1, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 2, 92, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 3, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 4, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 5, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 6, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 7, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 8, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 9, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 10, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611008070, 11, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 1, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 2, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 3, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 4, 134, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 5, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 6, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 7, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 8, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 9, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 10, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008071, 11, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227008072, 1, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227008072, 2, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227008072, 3, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227008072, 4, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 5, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 6, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 7, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 8, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 9, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 10, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 11, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 12, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 13, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 14, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309008430, 15, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310008431, 1, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310008431, 2, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310008431, 3, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310008431, 4, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310008431, 5, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 1, 27, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 2, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 3, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 4, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 5, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 6, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 7, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 8, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 9, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 10, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 11, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 12, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518008432, 13, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 1, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 2, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 3, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 4, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 5, 20, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625008433, 6, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 1, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 2, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 3, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 4, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 5, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206008434, 6, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 1, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 2, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 3, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 4, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 5, 43, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 6, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 7, 183, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108008435, 8, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 1, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 2, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 3, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 4, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 5, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 6, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 7, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 8, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 9, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 10, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 11, 84, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 12, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 13, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018008436, 14, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 1, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 2, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 3, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 4, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 5, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 6, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 7, 189, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 8, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 9, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 10, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 11, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307008437, 12, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 1, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 2, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 3, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 4, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 5, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 6, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 7, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 8, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 9, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 10, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212008438, 11, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 1, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 2, 113, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 3, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 4, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 5, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 6, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 7, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 8, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 9, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 10, 142, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 11, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 12, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 13, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 14, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 15, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713008439, 16, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102008440, 1, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102008440, 2, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102008440, 3, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102008440, 4, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102008440, 5, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 1, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 2, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 3, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 4, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 5, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 6, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 7, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218008441, 8, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 1, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 2, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 3, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 5, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 6, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 7, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 8, 154, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 9, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 10, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 11, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 12, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 13, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 14, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 15, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 16, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 17, 56, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 18, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008442, 19, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 1, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 2, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 3, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 4, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 5, 65, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 6, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 7, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 8, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 9, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822008443, 10, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 1, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 2, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 3, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 4, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 5, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 6, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521008444, 7, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 1, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 2, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 3, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 4, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 5, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 6, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 7, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 8, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 9, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 10, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 11, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 12, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 13, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008008445, 14, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 1, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 2, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 3, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 4, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 5, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 6, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 7, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 8, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008446, 9, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 1, 103, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 2, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 3, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 4, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 5, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 6, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 7, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 8, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 9, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 10, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 11, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 12, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 13, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 14, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613008447, 15, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 1, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 2, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 3, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 4, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 5, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 6, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 7, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 8, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 9, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 10, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 11, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 12, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 13, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 14, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 15, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 16, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204008448, 17, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 1, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 2, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 3, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 4, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 5, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 6, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 7, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 8, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 9, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428008449, 10, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901008450, 1, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901008450, 2, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901008450, 3, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901008450, 4, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901008450, 5, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 1, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 2, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 3, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 5, 93, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 6, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 7, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 8, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 9, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725008451, 10, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 1, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 2, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 3, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 4, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 5, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008452, 6, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 1, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 2, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028007311, 5, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 1, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 2, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 3, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 4, 141, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 5, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 6, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 7, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 8, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 9, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 10, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 11, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 12, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 13, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 14, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007312, 15, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 1, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 2, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 3, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 4, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 5, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 6, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007313, 7, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 1, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 2, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 3, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 4, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 5, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 6, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 7, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 8, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 9, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 10, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007314, 11, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 1, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 2, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 3, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 4, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 5, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 6, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 7, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 8, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 9, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 10, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424007315, 11, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705007316, 1, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705007316, 2, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705007316, 3, 24, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 1, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 2, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 3, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 4, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 5, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 6, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 7, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 8, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 9, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 10, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 11, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007317, 12, 74, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 1, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 2, 52, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 3, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 4, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 5, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 6, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 7, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 8, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 9, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023007318, 10, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112007319, 1, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112007319, 2, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112007319, 3, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010112007319, 4, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 1, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 2, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 3, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 4, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 5, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 6, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 7, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060719007320, 8, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 1, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 2, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 3, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 4, 89, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 5, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 6, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 7, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 8, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 9, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 10, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 11, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 12, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007321, 13, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 1, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 2, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 3, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 4, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 5, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 6, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629007322, 7, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217007323, 1, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217007323, 2, 145, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217007323, 3, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217007323, 4, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217007323, 5, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 1, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 2, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 3, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 4, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 5, 176, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 6, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 7, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 8, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 9, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 10, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523007324, 11, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 1, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 2, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 3, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 4, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 5, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 6, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 7, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 8, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 9, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 10, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201007325, 11, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 1, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 2, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 3, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 4, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 5, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 6, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 7, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 8, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 9, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 10, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 11, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 12, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225007326, 13, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007327, 1, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007327, 2, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007327, 3, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007327, 4, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 1, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 2, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 3, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 4, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 5, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 6, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 7, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 8, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612007328, 9, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 1, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 2, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 3, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 4, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 5, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 6, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 7, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 8, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 9, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 10, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 11, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 12, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 13, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201007329, 14, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 1, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 2, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 3, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 4, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 5, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 6, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 7, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 8, 158, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 9, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 10, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 11, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 12, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 13, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101206007330, 14, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 1, 127, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 2, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 3, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 4, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 5, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 6, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 7, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 8, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 9, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 10, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 11, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 12, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 13, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 14, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918007331, 15, 182, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 1, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 2, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 3, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 4, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 5, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 6, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 7, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 8, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 9, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 10, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 11, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103007332, 12, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 1, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 2, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 3, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 4, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 5, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 6, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 7, 102, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 8, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 9, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111007333, 10, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 1, 103, 68, 12, 816);
commit;
prompt 75000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 2, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 3, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 4, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 5, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 6, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 7, 146, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 8, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 9, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 10, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 11, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 12, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810007334, 13, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 1, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 2, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 3, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 4, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 5, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603007335, 6, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 16, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107007710, 17, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 1, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 2, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 3, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 4, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 5, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 6, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 7, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 8, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228007711, 9, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 1, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 2, 169, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 3, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 4, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 5, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 6, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 7, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606007712, 8, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 1, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 2, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 3, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 4, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 5, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507007713, 6, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 1, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 2, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 3, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 4, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 5, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 6, 15, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 7, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420007714, 8, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 1, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 2, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 3, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 4, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 5, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 6, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 7, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 8, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208007715, 9, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 1, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 2, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 3, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 4, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 5, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 6, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 7, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008007716, 8, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 1, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 2, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 3, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 4, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 5, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 6, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231007717, 7, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 1, 119, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 2, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 3, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 4, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 5, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 6, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 7, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 8, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 9, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 10, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 11, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306007718, 12, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 1, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 2, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 3, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 4, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 5, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 6, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512007719, 7, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 1, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 2, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 3, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 4, 135, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 5, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 6, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 7, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 8, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 9, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 10, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 11, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 12, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101026007720, 13, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 1, 137, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 2, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 3, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 4, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 5, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 6, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 7, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 8, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 9, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 10, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 11, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 12, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506007721, 13, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 1, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 2, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 3, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 4, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 5, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 6, 133, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 7, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 8, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 9, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 10, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 11, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 12, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 13, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090402007722, 14, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 1, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 2, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 3, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 4, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 5, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 6, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 7, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 8, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 9, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 10, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 11, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 12, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 13, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 14, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 15, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810007723, 16, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 1, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 2, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 3, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 4, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 5, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 6, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 7, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 8, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 9, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 10, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 11, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 12, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 13, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 14, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 15, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 16, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 17, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 18, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007724, 19, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 1, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 2, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 3, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 4, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 5, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 6, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 7, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 8, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 9, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071029007725, 10, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 1, 87, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 2, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 3, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 4, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 5, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 6, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 7, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 8, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 9, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 10, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 11, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 12, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 13, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 14, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221007726, 15, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 1, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 2, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 3, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 4, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 5, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 6, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 7, 146, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 8, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 9, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916007727, 10, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 1, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 2, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 3, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 4, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 5, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 6, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 7, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 8, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 9, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 10, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101007728, 11, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 1, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 2, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 3, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 4, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 5, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 6, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 7, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 8, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 9, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004007729, 10, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813007730, 1, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813007730, 2, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813007730, 3, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813007730, 4, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 1, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 2, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 3, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 4, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 5, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 6, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 7, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128007731, 8, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 1, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 2, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 3, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 4, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 5, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 6, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 7, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 8, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 9, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 10, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 11, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 12, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 13, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621007732, 14, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 1, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 2, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 3, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 4, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 5, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 6, 44, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227008072, 5, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218008073, 1, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218008073, 2, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218008073, 3, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218008073, 4, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218008073, 5, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 1, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 2, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 3, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 4, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 5, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 6, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 7, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 8, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 9, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 10, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 11, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 12, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417008074, 13, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011025008075, 1, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011025008075, 2, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011025008075, 3, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011025008075, 4, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917008076, 1, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917008076, 2, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917008076, 3, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000917008076, 4, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207008077, 1, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207008077, 2, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207008077, 3, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819008078, 1, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819008078, 2, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819008078, 3, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819008078, 4, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819008078, 5, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 1, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 2, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 3, 161, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 4, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 5, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 6, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 7, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 8, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 9, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 10, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 11, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 12, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720008079, 13, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 1, 190, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 2, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 3, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 4, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 5, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 6, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 7, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 8, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 9, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 10, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 11, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 12, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 13, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 14, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008080, 15, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 1, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 2, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 3, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 4, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 5, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 6, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 7, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 8, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 9, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 10, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 11, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 12, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 13, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 14, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008081, 15, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216008082, 1, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216008082, 2, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 1, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 2, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 3, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 4, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 5, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 6, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 7, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 8, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 9, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 10, 145, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 11, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 12, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 13, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 14, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008083, 15, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008084, 1, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008084, 2, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008084, 3, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008084, 4, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 1, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 2, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 3, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 4, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 5, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 6, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613008085, 7, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 1, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 2, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 3, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 4, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 5, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 6, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 7, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 8, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002008086, 9, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131008087, 1, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131008087, 2, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131008087, 3, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131008087, 4, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 1, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 2, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 3, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 4, 64, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 6, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 7, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 8, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 9, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 10, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 11, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 12, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 13, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 14, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 15, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120704008088, 16, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222008089, 1, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222008089, 2, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222008089, 3, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222008089, 4, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 1, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 2, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 3, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 4, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 5, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 6, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 7, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 8, 111, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 9, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807008090, 10, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 1, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 2, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 3, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 4, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 5, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 6, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 7, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 8, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 9, 42, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 10, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 11, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 12, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 13, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 14, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120008091, 15, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 1, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 2, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 3, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 4, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 5, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 6, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 7, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424008092, 8, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 1, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 2, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 3, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 4, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 5, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 6, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 7, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 8, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513008093, 9, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 1, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 2, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 3, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 4, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 5, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 6, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 7, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 8, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 9, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 10, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214008094, 11, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 1, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 2, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 3, 109, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 4, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 5, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008095, 6, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 1, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 2, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 3, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 4, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 5, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 6, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 7, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 8, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 9, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 10, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 11, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 12, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 13, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 14, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 15, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 16, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 17, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109008096, 18, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008097, 1, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008097, 2, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008097, 3, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008097, 4, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 1, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 2, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 3, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 4, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 5, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 6, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 7, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 8, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 9, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 10, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 11, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 12, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 13, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111031008098, 14, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019008099, 1, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019008099, 2, 156, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019008099, 3, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001019008099, 4, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 1, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 3, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 4, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 5, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 6, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 7, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 8, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 9, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 10, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 11, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722008453, 12, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 1, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 2, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 3, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 4, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 5, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 6, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 7, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 8, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522008454, 9, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708008455, 1, 35, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708008455, 2, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708008455, 3, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 1, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 2, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 3, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 4, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 5, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 6, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 7, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 8, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 9, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604008456, 10, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 1, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 2, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 3, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 4, 167, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 5, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 6, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 7, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 8, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 9, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 10, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 11, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 12, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213008457, 13, 84, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 1, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 2, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 3, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 4, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 5, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 6, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 7, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 8, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101008458, 9, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 1, 183, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 2, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 3, 102, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 4, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 5, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 6, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 7, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 8, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 9, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 10, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006008459, 11, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 1, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 2, 156, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 3, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 4, 126, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 5, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 6, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 7, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 8, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 9, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 10, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 11, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 12, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 13, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607008460, 14, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 1, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 2, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 3, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 4, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 5, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 6, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 7, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 8, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 9, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 10, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 11, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827008461, 12, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 1, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 2, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 3, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 4, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 5, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 6, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 7, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 8, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204008462, 9, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008008463, 1, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008008463, 2, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008008463, 3, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008008463, 4, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008008463, 5, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 1, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 2, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 3, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 4, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 5, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 6, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 7, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 8, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 9, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 10, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 11, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 12, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128008464, 13, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217008465, 1, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217008465, 2, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217008465, 3, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217008465, 4, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 1, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 2, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 3, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 4, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 5, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030402008466, 6, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 1, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 2, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 3, 152, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 4, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 5, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 6, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 7, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 8, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 9, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 10, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 11, 98, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 12, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 13, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 14, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328008467, 15, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 1, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 2, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 3, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 4, 116, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 5, 187, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 6, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 7, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 8, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930008468, 9, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411008469, 1, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411008469, 2, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411008469, 3, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411008469, 4, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411008469, 5, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 1, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 2, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 3, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 4, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 5, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105008470, 6, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 1, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 2, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 3, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 4, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 5, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 6, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 7, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 8, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 9, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 10, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 11, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 12, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 13, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309008471, 14, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 1, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 2, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 3, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 4, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 5, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 6, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 7, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 8, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 9, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 10, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 11, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 12, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 13, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 14, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 15, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008472, 16, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 1, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 2, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 3, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 4, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 5, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 6, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 7, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010008473, 8, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 1, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 2, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 3, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 4, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 5, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 6, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 7, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623008474, 8, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 1, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 2, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 3, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 4, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 5, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 6, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 7, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905008475, 8, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 1, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 2, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 3, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 4, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 5, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 6, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 7, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 8, 109, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 9, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 10, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 11, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406008476, 12, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 1, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 2, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 3, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 4, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 5, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 6, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 7, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 8, 54, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 9, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 10, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 1, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 2, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 3, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 4, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 5, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040202007336, 6, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 1, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 2, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 3, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 4, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 5, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 6, 118, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723007337, 7, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 1, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 2, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 3, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 4, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 5, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 6, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 7, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803007338, 8, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 1, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 2, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 3, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 4, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 5, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611007339, 6, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 1, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 2, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 3, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 4, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 5, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 6, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 7, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416007340, 8, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 1, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 2, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 3, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 4, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 5, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 6, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 7, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 8, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 9, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 10, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707007341, 11, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221007342, 1, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221007342, 2, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221007342, 3, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221007342, 4, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221007342, 5, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 1, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 2, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 3, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 4, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 5, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 6, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 7, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 8, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 9, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 10, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127007343, 11, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 1, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 2, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 3, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 4, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 5, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 6, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 7, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 8, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 9, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 10, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 11, 48, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 12, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 13, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120007344, 14, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 1, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 2, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 3, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 4, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 5, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 6, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 7, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 8, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 9, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 10, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617007345, 11, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 1, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 2, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 3, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 4, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 5, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 6, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 7, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030917007346, 8, 119, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 1, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 2, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 3, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 4, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 5, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 6, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 7, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 8, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 9, 155, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 10, 1, 68, 3, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 11, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 12, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 13, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207007347, 14, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605007348, 1, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605007348, 2, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605007348, 3, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605007348, 4, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 1, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 2, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 3, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 4, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 5, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 6, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 7, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210007349, 8, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 1, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 2, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 3, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 4, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 5, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 6, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503007350, 7, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 1, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 2, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 3, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 4, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 5, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 6, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 7, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 8, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 9, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 10, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 11, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 12, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 13, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 14, 27, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131120007351, 15, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 1, 116, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 2, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 3, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 4, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 5, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 6, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 7, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 8, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 9, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 10, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 11, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 12, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 13, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 14, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219007352, 15, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 1, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 2, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 3, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 4, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 5, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 6, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 7, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 8, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 9, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 10, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 11, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 12, 52, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213007353, 13, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 1, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 2, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 3, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 4, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 5, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 6, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 7, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 8, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 9, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 10, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 11, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 12, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 13, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104007354, 14, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621007355, 1, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621007355, 2, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621007355, 3, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621007355, 4, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 1, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 2, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 3, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 4, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 5, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 6, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 7, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 8, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 9, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 10, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 11, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 12, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917007356, 13, 151, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 1, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 2, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 3, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 4, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 5, 87, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 6, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 7, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 8, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 9, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007357, 10, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 1, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 2, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 3, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 4, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 5, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 6, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 7, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 8, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007358, 9, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 1, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 2, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 3, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 4, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 5, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 6, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 7, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 8, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005007359, 9, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 1, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 2, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 3, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 4, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 5, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 6, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 7, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 8, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 9, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 7, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 8, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 9, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 10, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 11, 90, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814007733, 12, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 1, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 2, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 3, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 4, 25, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 5, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 6, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 7, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 8, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 9, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 10, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007734, 11, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209007735, 1, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209007735, 2, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209007735, 3, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209007735, 4, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209007735, 5, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 1, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 2, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 3, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 4, 88, 29, 14, 406);
commit;
prompt 76000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 5, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 6, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 7, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 8, 153, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 9, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 10, 28, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908007736, 11, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 1, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 2, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 3, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 4, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 5, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 6, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 7, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 8, 132, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 9, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 10, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 11, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 12, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 13, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 14, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618007737, 15, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 1, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 2, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 3, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 4, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 5, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 6, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 7, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 8, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 9, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013007738, 10, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 1, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 2, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 3, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 4, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 5, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 6, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 7, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 8, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 9, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 10, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 11, 174, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 12, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 13, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 14, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 15, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110827007739, 16, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 1, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 2, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 3, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 4, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 5, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 6, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 7, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 8, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 9, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128007740, 10, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 1, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 2, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 3, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 4, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 5, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 6, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 7, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 8, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 9, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 10, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 11, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 12, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 13, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 14, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 15, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629007741, 16, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 1, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 2, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 3, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 4, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 5, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 6, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 7, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 8, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 9, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 10, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 11, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 12, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 13, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 14, 59, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 15, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 16, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130407007742, 17, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 1, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 2, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 3, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 4, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 5, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 6, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001007743, 7, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 1, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 2, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 3, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 4, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 5, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 6, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 7, 125, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 8, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 9, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 10, 74, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 11, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 12, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 13, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110007744, 14, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 1, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 2, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 3, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 4, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 5, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 6, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 7, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 8, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 9, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 10, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 11, 93, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 12, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 13, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 14, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 15, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007745, 16, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 1, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 2, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 3, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 4, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 5, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 6, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 7, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 8, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 9, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 10, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 11, 189, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 12, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 13, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 14, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 15, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 16, 134, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121006007746, 17, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 1, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 2, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 3, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 4, 148, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 5, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 6, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 7, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 8, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 9, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 10, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 11, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 12, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315007747, 13, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 1, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 2, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 3, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 4, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 5, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 6, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 7, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 8, 75, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 9, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 10, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 11, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 12, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 13, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 14, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806007748, 15, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126007749, 1, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126007749, 2, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126007749, 3, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 1, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 2, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 3, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 4, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 5, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030502007750, 6, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 1, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 2, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 3, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 4, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 5, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 6, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 7, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 8, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 9, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 10, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320007751, 11, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 1, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 2, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 3, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 4, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 5, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 6, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 7, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 8, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 9, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 10, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 11, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 12, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625007752, 13, 39, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 1, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 2, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 3, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 4, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 5, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 6, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 2, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 3, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 4, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 5, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 6, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 7, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 8, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116008100, 9, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 1, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 2, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 3, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 4, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 5, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 6, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 7, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 8, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008101, 9, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508008102, 1, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508008102, 2, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508008102, 3, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508008102, 4, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 1, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 2, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 3, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 4, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 5, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 6, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 7, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008103, 8, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204008104, 1, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204008104, 2, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204008104, 3, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 1, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 2, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 3, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 4, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 5, 152, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 6, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 7, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 8, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 9, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 10, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 11, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 12, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 13, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 14, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 15, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717008105, 16, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 1, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 2, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 3, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 4, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 5, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522008106, 6, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008107, 1, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008107, 2, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008107, 3, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008107, 4, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 1, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 2, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 3, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 4, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 5, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 6, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 7, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614008108, 8, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 1, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 2, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 3, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 4, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 5, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 6, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 7, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 8, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 9, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 10, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 11, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 12, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080228008109, 13, 65, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304008110, 1, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304008110, 2, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304008110, 3, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304008110, 4, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 1, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 2, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 3, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 4, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 5, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 6, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318008111, 7, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008112, 1, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008112, 2, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008112, 3, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008112, 4, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008112, 5, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 1, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 2, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 3, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 4, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 5, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 6, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 7, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 8, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 9, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 10, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 11, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 12, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 13, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008113, 14, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 1, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 2, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 3, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 4, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 5, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 6, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 7, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 8, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206008114, 9, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103008115, 1, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103008115, 2, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103008115, 3, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103008115, 4, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103008115, 5, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 1, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 2, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 3, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 4, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 5, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 6, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 7, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 8, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 9, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008116, 10, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 1, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 2, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 3, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 4, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 5, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 6, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 7, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 8, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 9, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 10, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 11, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 12, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801008117, 13, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 1, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 2, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 3, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 4, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 5, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 6, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 7, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 8, 1, 14, 3, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 9, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 10, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 11, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 12, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008118, 13, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 1, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 2, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 3, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 4, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 5, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 6, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008119, 7, 119, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028008120, 1, 119, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028008120, 2, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028008120, 3, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028008120, 4, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028008120, 5, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 1, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 2, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 3, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 4, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 5, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 6, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 7, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 8, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 9, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 10, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513008121, 11, 133, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 1, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 2, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 3, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 4, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 5, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 6, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 7, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 8, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 9, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 10, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 11, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224008122, 12, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 1, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 2, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 3, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 4, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 5, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 6, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 7, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 8, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 9, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008123, 10, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 1, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 2, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 3, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 4, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 5, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 6, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 7, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 8, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029008124, 9, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 1, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 2, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 3, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 4, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 5, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 6, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 7, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 8, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 9, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 10, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 11, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100617008125, 12, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 1, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 2, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 3, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 4, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 5, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 6, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 7, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 8, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 9, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 10, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 11, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 12, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129008126, 13, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 1, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 7, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 8, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 9, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 10, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 11, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 12, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 13, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 14, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 15, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 16, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 17, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 18, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 1, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 2, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 3, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 4, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 5, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 6, 192, 78, 18, 1404);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920008574, 7, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 1, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 2, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 3, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 4, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 5, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 6, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 7, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 8, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 9, 125, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 10, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 11, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 12, 22, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110405008575, 13, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721008576, 1, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721008576, 2, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 1, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 2, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 3, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 4, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 5, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 6, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 7, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 8, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 9, 14, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 10, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080512008577, 11, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 1, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 2, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 3, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 4, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 5, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 6, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 7, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712008578, 8, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008579, 1, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008579, 2, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008579, 3, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008579, 4, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008579, 5, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 1, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 2, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 3, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 4, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 5, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 6, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 7, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 8, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 9, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 10, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 11, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 12, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405008580, 13, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 1, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 2, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 3, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 4, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 5, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 6, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 7, 156, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 8, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 9, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 10, 174, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 11, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 12, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 13, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 14, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 15, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008581, 16, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 1, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 2, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 3, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 4, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 5, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 6, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 7, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 8, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 9, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 10, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 11, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 12, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 13, 184, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 14, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 15, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304008582, 16, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 1, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 2, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 3, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 4, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 5, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 6, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 7, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 8, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 9, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 10, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 11, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203008583, 12, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 1, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 2, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 3, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 4, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 5, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 6, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 7, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 8, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 9, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 10, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 11, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 12, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 13, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 14, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 15, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521008584, 16, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 1, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 2, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 3, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 4, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 5, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 6, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 7, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 8, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 9, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 10, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 11, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 12, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 13, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 14, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 15, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 16, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621008585, 17, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 1, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 2, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 3, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 4, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 5, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 6, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 7, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 8, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 9, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306008586, 10, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302008587, 1, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302008587, 2, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302008587, 3, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302008587, 4, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 1, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 2, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 3, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 4, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 5, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 6, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 7, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 8, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 9, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 10, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 11, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 12, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 13, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119008588, 14, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 1, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 2, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 3, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 4, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 5, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 6, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 7, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 8, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 9, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 10, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315008589, 11, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 1, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 2, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 3, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 5, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 6, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 7, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 8, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 9, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 10, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 11, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 12, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 13, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 14, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 15, 58, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008590, 16, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 1, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 2, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 3, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 4, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 5, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 6, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 7, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 8, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 9, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 10, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 11, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 12, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905008591, 13, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008592, 1, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008592, 2, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008592, 3, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 1, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 2, 93, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 3, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 4, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 5, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 6, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 7, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 8, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 9, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 10, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 11, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 12, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 13, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606008593, 14, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 1, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 2, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 3, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 4, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 5, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 6, 58, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 10, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 11, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 12, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 13, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 14, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 15, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 16, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729007360, 17, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 1, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 2, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 3, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 4, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 5, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 6, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 7, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007361, 8, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 1, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 2, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 3, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 4, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 5, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 6, 182, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007362, 7, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124007363, 1, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124007363, 2, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124007363, 3, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124007363, 4, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 1, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 2, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 3, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 4, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 5, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 6, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 7, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 8, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 9, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 10, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 11, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 12, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 13, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319007364, 14, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 1, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 2, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 3, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 4, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 5, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 6, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 7, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 8, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218007365, 9, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 1, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 2, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 3, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 4, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 5, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 6, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 7, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 8, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 9, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 10, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 11, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 12, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917007366, 13, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804007367, 1, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804007367, 2, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804007367, 3, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804007367, 4, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804007367, 5, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518007368, 1, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518007368, 2, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518007368, 3, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518007368, 4, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020518007368, 5, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 1, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 2, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 3, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 4, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 5, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 6, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 7, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104007369, 8, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102007370, 1, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102007370, 2, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102007370, 3, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102007370, 4, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102007370, 5, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 1, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 2, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 3, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 4, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 5, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 6, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 7, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 8, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 9, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 10, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 11, 169, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 12, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 13, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 14, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 15, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 16, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007371, 17, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329007372, 1, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329007372, 2, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329007372, 3, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329007372, 4, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 1, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 2, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 3, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 4, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 5, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622007373, 6, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 1, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 2, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 3, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 4, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 5, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 6, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 7, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 8, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 9, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913007374, 10, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 1, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 2, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 3, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 4, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 5, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 6, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 7, 154, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 8, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 9, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 10, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 11, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 12, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 13, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523007375, 14, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 1, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 2, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 3, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 4, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 5, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 6, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301007376, 7, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 1, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 2, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 3, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 4, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 5, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 6, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 7, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 8, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 9, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 10, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 11, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 12, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 13, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 14, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 15, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206007377, 16, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 1, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 2, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 3, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 4, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 5, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 6, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 7, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806007378, 8, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 1, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 2, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 3, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 4, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 5, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 6, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 7, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 8, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 9, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 10, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 11, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019007379, 12, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 1, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 2, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 3, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 4, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 5, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 6, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 7, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 8, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 9, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723007380, 10, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 1, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 2, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 3, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 4, 187, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 5, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 6, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 7, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 8, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 9, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 10, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 11, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 12, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 13, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208007381, 14, 44, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 1, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 2, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 3, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 4, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 5, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 6, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 7, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 8, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 9, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 10, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 11, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 12, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 13, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 14, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 15, 123, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 16, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219007382, 17, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 1, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 2, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 3, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 4, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 5, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 6, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 7, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 8, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 9, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060703007383, 10, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 1, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 2, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 3, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 4, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 5, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 6, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 7, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 8, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 7, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 8, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 9, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 10, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 11, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 12, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 13, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 14, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 15, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113007753, 16, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511007754, 1, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511007754, 2, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511007754, 3, 51, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511007754, 4, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013007755, 1, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013007755, 2, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013007755, 3, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013007755, 4, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013007755, 5, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 1, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 2, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 3, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 4, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 5, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818007756, 6, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 1, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 2, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 3, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 4, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 5, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 6, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 7, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 8, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 9, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 10, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 11, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224007757, 12, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 1, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 2, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 3, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 4, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 5, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 6, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 7, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 8, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 9, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 10, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 11, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 12, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 13, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527007758, 14, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 1, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 2, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 3, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 4, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 5, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 6, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 7, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 8, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 9, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 10, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 11, 86, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 12, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115007759, 13, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007760, 1, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007760, 2, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007760, 3, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007760, 4, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007760, 5, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 1, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 2, 56, 49, 13, 637);
commit;
prompt 77000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 3, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 4, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 5, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 6, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 7, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 8, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 9, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007761, 10, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 1, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 2, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 3, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 4, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 5, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030209007762, 6, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 1, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 2, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 3, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 4, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 5, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 6, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 7, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 8, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 9, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616007763, 10, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 1, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 2, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 3, 72, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 4, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 5, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 6, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 7, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 8, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 9, 160, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 10, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 11, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 12, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 13, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 14, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 15, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110226007764, 16, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 1, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 2, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 3, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 4, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 5, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 6, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 7, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 8, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 9, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 10, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 11, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227007765, 12, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 1, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 2, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 3, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 4, 89, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 5, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020927007766, 6, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 1, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 2, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 3, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 4, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 5, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 6, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 7, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 8, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 9, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 10, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 11, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 12, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 13, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 14, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 15, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910007767, 16, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020007768, 1, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020007768, 2, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020007768, 3, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 1, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 2, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 3, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 4, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 5, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 6, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 7, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 8, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 9, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 10, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 11, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 12, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 13, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 14, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 15, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015007769, 16, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 1, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 2, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 3, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 4, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 5, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 6, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 7, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 8, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 9, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 10, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 11, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905007770, 12, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 1, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 2, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 3, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 4, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 5, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 6, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 7, 183, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 8, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 9, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 10, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 11, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 12, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608007771, 13, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 1, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 2, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 3, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 4, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 5, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104007772, 6, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 1, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 2, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 3, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 4, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 5, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 6, 25, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 7, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 8, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 9, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 10, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 11, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 12, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 13, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 14, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 15, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231007773, 16, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 1, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 2, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 3, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 4, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 5, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 6, 168, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 7, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 8, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 9, 136, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 10, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 11, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 12, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416007774, 13, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 1, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 2, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 3, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 4, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 5, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 6, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 7, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417007775, 8, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 1, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 2, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 3, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 4, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 5, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 6, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 7, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 2, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 3, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 4, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 5, 129, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 6, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 7, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 8, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 9, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 10, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 11, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617008127, 12, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 1, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 2, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 3, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 4, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 5, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 6, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 7, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 8, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 9, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 10, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 11, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 12, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 13, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 14, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 15, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413008128, 16, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 1, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 2, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 3, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 4, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 5, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 6, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902008129, 7, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 1, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 2, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 3, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 4, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 5, 144, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 6, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 7, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 8, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 9, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 10, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 11, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 12, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 13, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 14, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 15, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206008130, 16, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 1, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 2, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 3, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 4, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 5, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 6, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 7, 54, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 8, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 9, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 10, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 11, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 12, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303008131, 13, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 1, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 2, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 3, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 4, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 5, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 6, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 7, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 8, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805008132, 9, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 1, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 2, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 3, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 4, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 5, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 6, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 7, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 8, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 9, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 10, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 11, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 12, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 13, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 14, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 15, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911008133, 16, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 1, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 2, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 3, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 4, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 5, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 6, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 7, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 8, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 9, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 10, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 11, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 12, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 13, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008134, 14, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 1, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 2, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 3, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 4, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 5, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 6, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 7, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 8, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 9, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 10, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 11, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 12, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 13, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 14, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 15, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 16, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008135, 17, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 1, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 2, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 3, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 4, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 5, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 6, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 7, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 8, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 9, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 10, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 11, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 12, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 13, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103008136, 14, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 1, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 2, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 3, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 4, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 5, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 6, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 7, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041123008137, 8, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 1, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 2, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 3, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 4, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 5, 55, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 6, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 7, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 8, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 9, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 10, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 11, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 12, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 13, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 14, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902008138, 15, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020831008139, 1, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020831008139, 2, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020831008139, 3, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020831008139, 4, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008140, 1, 56, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008140, 2, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008140, 3, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 1, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 2, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 3, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 4, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 5, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 6, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 7, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 8, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 9, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 10, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 11, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 12, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 13, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404008141, 14, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 1, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 2, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 3, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 4, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 5, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117008142, 6, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 1, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 2, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 3, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 4, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 5, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 6, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 7, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 8, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 9, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 10, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 11, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 12, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 13, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 14, 60, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 15, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008143, 16, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 1, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 2, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 3, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 4, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 5, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 6, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 7, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 8, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 9, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 10, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 11, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 12, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210008144, 13, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 1, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 2, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 3, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 4, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 5, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516008145, 6, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 1, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 2, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 3, 82, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 4, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 5, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 6, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 7, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 8, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 9, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 10, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 11, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 12, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 13, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 14, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130608008146, 15, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 1, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 2, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 3, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 4, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 5, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 6, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 11, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 12, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 13, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 14, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 15, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 16, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008477, 17, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925008478, 1, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925008478, 2, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925008478, 3, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 1, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 2, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 3, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 4, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 5, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 6, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 7, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 8, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 9, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 10, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 11, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 12, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 13, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204008479, 14, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029008480, 1, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029008480, 2, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029008480, 3, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029008480, 4, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029008480, 5, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 1, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 2, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 3, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 4, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 5, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 6, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 7, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 8, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 9, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 10, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 11, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 12, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014008481, 13, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 1, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 2, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 3, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 4, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 5, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 6, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 7, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 8, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 9, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008482, 10, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 1, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 2, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 3, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 4, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 5, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 6, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 7, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 8, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 9, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 10, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 11, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 12, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 13, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 14, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 15, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120604008483, 16, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 1, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 2, 10, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 3, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 4, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 5, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 6, 166, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 7, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 8, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 9, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 10, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 11, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 12, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 13, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 14, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120301008484, 15, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 1, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 2, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 3, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 4, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 5, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 6, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 7, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 8, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 9, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 10, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 11, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 12, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 13, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 14, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 15, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901008485, 16, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 1, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 2, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 3, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 4, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 5, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 6, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 7, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008486, 8, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 1, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 2, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 3, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 4, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 5, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 6, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 7, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125008487, 8, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 1, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 2, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 3, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 4, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 5, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 6, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 7, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 8, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 9, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 10, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 11, 76, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 12, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 13, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100203008488, 14, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 1, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 2, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 3, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 4, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 5, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 6, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 7, 150, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 8, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 9, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 10, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 11, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 12, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 13, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 14, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110718008489, 15, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 1, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 2, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 3, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 4, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 5, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 6, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 7, 54, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 8, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 9, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 10, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 11, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 12, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 13, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413008490, 14, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 1, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 2, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 3, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 4, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 5, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 6, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 7, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 8, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 9, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 10, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 11, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 12, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 13, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120008491, 14, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410008492, 1, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410008492, 2, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410008492, 3, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030817008493, 1, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030817008493, 2, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030817008493, 3, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030817008493, 4, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030817008493, 5, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 1, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 2, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 3, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 4, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 5, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 6, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 7, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 8, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 9, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211008494, 10, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 1, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 2, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 3, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 4, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 5, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 6, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 7, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 8, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403008495, 9, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 1, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 2, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 3, 23, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 4, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 5, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 6, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029008496, 7, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 1, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 2, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 3, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 4, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 5, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 6, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 7, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 8, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 9, 138, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 10, 131, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 11, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 12, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101008497, 13, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 1, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 2, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 3, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 4, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 5, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 6, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 7, 59, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 8, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 9, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 10, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 11, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 12, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 13, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 14, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518008498, 15, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 1, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 2, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 3, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 4, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 5, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 9, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 10, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 11, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 12, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 13, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 14, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 15, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 16, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802007384, 17, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 1, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 2, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 3, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 4, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 5, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 6, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 7, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 8, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070115007385, 9, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 1, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 2, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 3, 20, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 4, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 5, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 6, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 7, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 8, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 9, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070420007386, 10, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 1, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 2, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 3, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 4, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 5, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 6, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 7, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 8, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 9, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 10, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 11, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004007387, 12, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 1, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 2, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 3, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 4, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 5, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 6, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 7, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 8, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 9, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 10, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 11, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 12, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728007388, 13, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209007389, 1, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209007389, 2, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209007389, 3, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209007389, 4, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 1, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 2, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 3, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 4, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 5, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 6, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 7, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 8, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 9, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 10, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 11, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 12, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 13, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209007390, 14, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 1, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 2, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 3, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 4, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 5, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 6, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 7, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 8, 192, 18, 18, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 9, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 10, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 11, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 12, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 13, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 14, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 15, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 16, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140121007391, 17, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 1, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 2, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 3, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 5, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 6, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 7, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 8, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 9, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 10, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 11, 51, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923007392, 12, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 1, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 2, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 3, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 4, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 5, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 6, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 7, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 8, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 9, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 10, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 11, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 12, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 13, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 14, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521007393, 15, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 1, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 2, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 3, 12, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 4, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 5, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 6, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 7, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 8, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 9, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 10, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 11, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626007394, 12, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 1, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 2, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 3, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 4, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 5, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 6, 180, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 7, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 8, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629007395, 9, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 1, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 2, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 3, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 4, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 5, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 6, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 7, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 8, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 9, 91, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 10, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 11, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 12, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 13, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007396, 14, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 1, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 2, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 3, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 4, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 5, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 6, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 7, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 8, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007397, 9, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 1, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 2, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 3, 1, 33, 3, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 4, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 5, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 6, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 7, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 8, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 9, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 10, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 11, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 12, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306007398, 13, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 1, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 2, 192, 5, 18, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 3, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 4, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 5, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 6, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 7, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 8, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 9, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 10, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 11, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 12, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 13, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127007399, 14, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 1, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 2, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 3, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 4, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 5, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 6, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 7, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 8, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 9, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 10, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 11, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 12, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108007400, 13, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 1, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 2, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 3, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 4, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 5, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 6, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 7, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 8, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 9, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 10, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 11, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 12, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 13, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 14, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 15, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 16, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140122007401, 17, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 1, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 2, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 3, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 4, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 5, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 6, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 7, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 8, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 9, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 10, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205007402, 11, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 1, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 2, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 3, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 4, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 5, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 6, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 7, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 8, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 9, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 10, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 11, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 12, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 13, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 8, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 9, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 10, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 11, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 12, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 13, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 14, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 15, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427007776, 16, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 1, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 2, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 3, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 4, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 5, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 6, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 7, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 8, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 9, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 10, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 11, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528007777, 12, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 1, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 2, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 3, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 4, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 5, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 6, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 7, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218007778, 8, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 1, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 2, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 3, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 4, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 5, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 6, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 7, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 8, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 9, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 10, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 11, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 12, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 13, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011007779, 14, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 1, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 2, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 3, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 4, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 5, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 6, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 7, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 8, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 9, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714007780, 10, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 1, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 2, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 3, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 4, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 5, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 6, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 7, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 8, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 9, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 10, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 11, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 12, 50, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 13, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 14, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 15, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 16, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 17, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 18, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129007781, 19, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 1, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 2, 16, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 3, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 4, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 5, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 6, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 7, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 8, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 9, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 10, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 11, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 12, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421007782, 13, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 1, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 2, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 3, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 4, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 5, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 6, 24, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 7, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 8, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 9, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 10, 27, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 11, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 12, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 13, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 14, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 15, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 16, 182, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224007783, 17, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 1, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 2, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 3, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 4, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 5, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 6, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 7, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 8, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123007784, 9, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 1, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 2, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 3, 129, 94, 7, 658);
commit;
prompt 78000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 4, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 5, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 6, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 7, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 8, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 9, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 10, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727007785, 11, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 1, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 2, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 3, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 4, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 5, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 6, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 7, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 8, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 9, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 10, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 11, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112007786, 12, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 1, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 2, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 3, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 4, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 5, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 6, 28, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 7, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 8, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 9, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 10, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 11, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311007787, 12, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 1, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 2, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 3, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 4, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 5, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 6, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 7, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 8, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 9, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 10, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 11, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 12, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 13, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809007788, 14, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007789, 1, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007789, 2, 161, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007789, 3, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007789, 4, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007789, 5, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007790, 1, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007790, 2, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007790, 3, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702007790, 4, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 1, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 2, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 3, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 4, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 5, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024007791, 6, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610007792, 1, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610007792, 2, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610007792, 3, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704007793, 1, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704007793, 2, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704007793, 3, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704007793, 4, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704007793, 5, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007794, 1, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007794, 2, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007794, 3, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007794, 4, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923007794, 5, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 1, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 2, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 3, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 4, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 5, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 6, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416007795, 7, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 1, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 2, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 3, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 4, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 5, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 6, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 7, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 8, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 9, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 10, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 11, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 12, 187, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 13, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 14, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528007796, 15, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 1, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 2, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 3, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 4, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 5, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 6, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 7, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 8, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 9, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 10, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 11, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 12, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625007797, 13, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 1, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 2, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 3, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 4, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 5, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 6, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 7, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 8, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 9, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 10, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 11, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824007798, 12, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 1, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 2, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 3, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 4, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 7, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 8, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619008147, 9, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 1, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 2, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 3, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 4, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 5, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 6, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 7, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040122008148, 8, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 1, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 2, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 3, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 4, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 5, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 6, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 7, 109, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 8, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 9, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 10, 73, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008149, 11, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 1, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 2, 171, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 3, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 4, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 5, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 6, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 7, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528008150, 8, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301008151, 1, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301008151, 2, 71, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000301008151, 3, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925008152, 1, 154, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000925008152, 2, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 1, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 2, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 3, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 4, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 5, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 6, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 7, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 8, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708008153, 9, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 1, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 2, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 3, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 4, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 5, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 6, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 7, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 8, 124, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610008154, 9, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 1, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 2, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 3, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 4, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 5, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 6, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 7, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 8, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 9, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 10, 128, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 11, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 12, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 13, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 14, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 15, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 16, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 17, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140416008155, 18, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 1, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 2, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 3, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 4, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 5, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 6, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 7, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625008156, 8, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 1, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 2, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 3, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 4, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 5, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 6, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 7, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 8, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 9, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 10, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 11, 170, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 12, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 13, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 14, 153, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 15, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219008157, 16, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 1, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 2, 114, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 3, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 4, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 5, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 6, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 7, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 8, 150, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 9, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 10, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 11, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 12, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 13, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008158, 14, 130, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 1, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 2, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 3, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 4, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 5, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 6, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 7, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 8, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 9, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 10, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 11, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112008159, 12, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 1, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 2, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 3, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 4, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 5, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 6, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110008160, 7, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 1, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 2, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 3, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 4, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 5, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622008161, 6, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 1, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 2, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 3, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 4, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 5, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 6, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216008162, 7, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 1, 164, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 2, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 3, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 4, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 5, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 6, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 7, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 8, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 9, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825008163, 10, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 1, 120, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 2, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 3, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 4, 176, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 5, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 6, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 7, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 8, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 9, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 10, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 11, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 12, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614008164, 13, 21, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922008165, 1, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922008165, 2, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922008165, 3, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922008165, 4, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922008165, 5, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 1, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 2, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 3, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 4, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 5, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 6, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 7, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 8, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 9, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009008166, 10, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830008167, 1, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830008167, 2, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830008167, 3, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623008168, 1, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623008168, 2, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010623008168, 3, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 1, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 2, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 3, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 4, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 5, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 6, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 7, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 8, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 9, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 10, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 11, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713008169, 12, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 1, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 2, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 3, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 4, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 5, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 6, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 7, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 8, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 9, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008170, 10, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 1, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 2, 136, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 3, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 4, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 5, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 6, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702008171, 7, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 1, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 2, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 3, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 4, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 5, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 6, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 7, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221008172, 8, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 1, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 2, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 3, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 4, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 5, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 6, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 7, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 8, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 9, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 10, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 11, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080225008173, 12, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 1, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 2, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 3, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 4, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 5, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521008522, 1, 99, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521008522, 2, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521008522, 3, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521008522, 4, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 1, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 2, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 3, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 4, 188, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 5, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 6, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 7, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 8, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 9, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 10, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 11, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 12, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 13, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 14, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421008523, 15, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 1, 78, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 2, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 3, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 4, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 5, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 6, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 7, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 8, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 9, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 10, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 11, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 12, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 13, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 14, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 15, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 16, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 17, 134, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307008524, 18, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 1, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 2, 192, 92, 18, 1656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 3, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 4, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 5, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 6, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 7, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 8, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 9, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 10, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 11, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 12, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 13, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525008525, 14, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008526, 1, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008526, 2, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008526, 3, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008526, 4, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011001008526, 5, 72, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010423008527, 1, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010423008527, 2, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010423008527, 3, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010423008527, 4, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010423008527, 5, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 1, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 2, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 3, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 4, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 5, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 6, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217008528, 7, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 1, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 2, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 3, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 4, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 5, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 6, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 7, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 8, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 9, 144, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050914008529, 10, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008530, 1, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008530, 2, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008530, 3, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008530, 4, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008530, 5, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 1, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 2, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 3, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 4, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 5, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 6, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008531, 7, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008532, 1, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008532, 2, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008532, 3, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008532, 4, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914008532, 5, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 1, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 2, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 3, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 4, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 5, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 6, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 7, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 8, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 9, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 10, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 11, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 12, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 13, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110428008533, 14, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708008534, 1, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708008534, 2, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708008534, 3, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 1, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 2, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 3, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 4, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 5, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 6, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 7, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420008535, 8, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 1, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 2, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 3, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 4, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 5, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 6, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 7, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 8, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 9, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419008536, 10, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 1, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 2, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 3, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 4, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 5, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 6, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 7, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 8, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 9, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 10, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 11, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 12, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 13, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223008537, 14, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 1, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 2, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 3, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 4, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 5, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 6, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041013008538, 7, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824008539, 1, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824008539, 2, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824008539, 3, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010824008539, 4, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 2, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 3, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 4, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 5, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 6, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 7, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 8, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618008540, 9, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 1, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 2, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 3, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 4, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 5, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 6, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 7, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 8, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 9, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 10, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 11, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 12, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821008541, 13, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 1, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 2, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 3, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 4, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 5, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 6, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614008542, 7, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 1, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 2, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 3, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 4, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 5, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 6, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 7, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 8, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 9, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 10, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 11, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 12, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225008543, 13, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 1, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 2, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 3, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 4, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 5, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 6, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 7, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 8, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 9, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 10, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 11, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 12, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423008544, 13, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 1, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 2, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 3, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 4, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 5, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 6, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 7, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 8, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 9, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070512008545, 10, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 1, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 2, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 3, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 4, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 5, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 6, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 7, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 8, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 9, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513008546, 10, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105008547, 1, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105008547, 2, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105008547, 3, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105008547, 4, 80, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105008547, 5, 174, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 1, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 2, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 3, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 4, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 14, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 15, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 16, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007403, 17, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 1, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 2, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 3, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 4, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 5, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 6, 25, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 7, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 8, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 9, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 10, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 11, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 12, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 13, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 14, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 15, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 16, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023007404, 17, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 1, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 2, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 3, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 4, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 5, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 6, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719007405, 7, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007406, 1, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007406, 2, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007406, 3, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519007406, 4, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 1, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 2, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 3, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 4, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 5, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 6, 76, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 7, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430007407, 8, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 1, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 2, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 3, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 4, 179, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 5, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007408, 6, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 1, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 2, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 3, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 4, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 5, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 6, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 7, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 8, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 9, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 10, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 11, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 12, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 13, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225007409, 14, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 1, 129, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 2, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 3, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 4, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 5, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 6, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 7, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 8, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 9, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306007410, 10, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 1, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 2, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 3, 9, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 4, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 5, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 6, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 7, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 8, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 9, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 10, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 11, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 12, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 13, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 14, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 15, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 16, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 17, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 18, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117007411, 19, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 1, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 2, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 3, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 4, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 5, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 6, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928007412, 7, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 1, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 2, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 3, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 4, 185, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 5, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 6, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 7, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 8, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 9, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 10, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 11, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521007413, 12, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 1, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 2, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 3, 152, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 4, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 5, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 6, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 7, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 8, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731007414, 9, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 1, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 2, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 3, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 4, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 5, 164, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 6, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 7, 119, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 8, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 9, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 10, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 11, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007415, 12, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120007416, 1, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120007416, 2, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120007416, 3, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120007416, 4, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 1, 9, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 2, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 3, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 4, 119, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 5, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 6, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 7, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 8, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 9, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 10, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 11, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 12, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216007417, 13, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 1, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 2, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 3, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 4, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 5, 84, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 6, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 7, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 8, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 9, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810007418, 10, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 1, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 2, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 3, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 4, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 5, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 6, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 7, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 8, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 9, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 10, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 11, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 12, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 13, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804007419, 14, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 1, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 2, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 3, 25, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 4, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 5, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 6, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 7, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 8, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 9, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 10, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 11, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 12, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 13, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 14, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930007420, 15, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 1, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 2, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 3, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 4, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 5, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007421, 6, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 1, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 2, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 3, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 4, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 5, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 6, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 7, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 8, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 9, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 10, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 11, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 12, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 13, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 14, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 15, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027007422, 16, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 1, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 2, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 3, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 4, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 5, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 6, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 7, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 8, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 9, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 10, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 11, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 12, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 13, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 14, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007423, 15, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 1, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 2, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 3, 148, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 4, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 5, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 6, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 7, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 8, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 9, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 10, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 11, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924007424, 12, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 1, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 2, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 3, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 4, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 5, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 5, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 6, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 7, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 8, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 9, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 10, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 11, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 12, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 13, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 14, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818007799, 15, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 1, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 2, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 3, 176, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 4, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 5, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 6, 150, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 7, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 8, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 9, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 10, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 11, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 12, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 13, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 14, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501007800, 15, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 1, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 2, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 3, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 4, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 5, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 6, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 7, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 8, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701007801, 9, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 1, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 2, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 3, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 4, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 5, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 6, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 7, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815007802, 8, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 1, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 2, 38, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 3, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 4, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 5, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 6, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 7, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 8, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 9, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429007803, 10, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 1, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 2, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 3, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 4, 134, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 5, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 6, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 7, 1, 87, 3, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007804, 8, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 1, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 2, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 3, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 4, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 5, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 6, 95, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 7, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 8, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 9, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 10, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 11, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 12, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 13, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 14, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 15, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204007805, 16, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 1, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 2, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 3, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 4, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 5, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 6, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 7, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 8, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 9, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 10, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 11, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 12, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 13, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 14, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 15, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 16, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118007806, 17, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 1, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 2, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 3, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 4, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 5, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 6, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 7, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 8, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 9, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 10, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 11, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 12, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 13, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606007807, 14, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319007808, 1, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319007808, 2, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319007808, 3, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 1, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 2, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 3, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 4, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 5, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 6, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 7, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 8, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914007809, 9, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 1, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 2, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 3, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 5, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 6, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 7, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 8, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 9, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 10, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906007810, 11, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 1, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 2, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 3, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 4, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 5, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 6, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 7, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 8, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 9, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928007811, 10, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 1, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 2, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 3, 96, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 4, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 5, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 6, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 7, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 8, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 9, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 10, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 11, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 12, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726007812, 13, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 1, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 2, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 3, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 4, 192, 74, 18, 1332);
commit;
prompt 79000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 5, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 6, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 7, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 8, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 9, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 10, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 11, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 12, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 13, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 14, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120721007813, 15, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 1, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 2, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 3, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 4, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 5, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 6, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 7, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 8, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 9, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 10, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 11, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 12, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 13, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825007814, 14, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 1, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 2, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 3, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 4, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 5, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 6, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 7, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 8, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020007815, 9, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 1, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 2, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 3, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 4, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 5, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 6, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 7, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 8, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 9, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 10, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 11, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 12, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 13, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 14, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 15, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 16, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803007816, 17, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 1, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 2, 78, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 3, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 4, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 5, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 6, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 7, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 8, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 9, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 10, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 11, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 12, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 13, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 14, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813007817, 15, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 1, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 2, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 3, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 4, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 5, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527007818, 6, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 1, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 2, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 3, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 4, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 5, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 6, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 7, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230007819, 8, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 1, 90, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 6, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 7, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008174, 8, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123008175, 1, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123008175, 2, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123008175, 3, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123008175, 4, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 1, 90, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 2, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 3, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 4, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 5, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 6, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 7, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 8, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806008176, 9, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 1, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 2, 191, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 3, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 4, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 5, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 6, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 7, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 8, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 9, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 10, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320008177, 11, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 1, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 2, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 3, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 4, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 5, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 6, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 7, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 8, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 9, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 10, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 11, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005008178, 12, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 1, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 2, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 3, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 4, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 5, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 6, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 7, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 8, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 9, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 10, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 11, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 12, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 13, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 14, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 15, 93, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 16, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209008179, 17, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 1, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 2, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 3, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 4, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 5, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 6, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 7, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 8, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 9, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 10, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 11, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 12, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 13, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008180, 14, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 1, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 2, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 3, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 4, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 5, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 6, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 7, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 8, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 9, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 10, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 11, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914008181, 12, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 1, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 2, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 3, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 4, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 5, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 6, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 7, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 8, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 9, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812008182, 10, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 1, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 2, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 3, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 4, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 5, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 6, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 7, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 8, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 9, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 10, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 11, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 12, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 13, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 14, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 15, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 16, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 17, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129008183, 18, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 1, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 2, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 3, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 4, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 5, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 6, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 7, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 8, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 9, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 10, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 11, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 12, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 13, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 14, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 15, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 16, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 17, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419008184, 18, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 1, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 2, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 3, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 4, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 5, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 6, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008185, 7, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 1, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 2, 66, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 3, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 4, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 5, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 6, 192, 51, 18, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 7, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 8, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 9, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 10, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002008186, 11, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 1, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 2, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 3, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 4, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 5, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 6, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 7, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 8, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 9, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130008187, 10, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214008188, 1, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214008188, 2, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214008188, 3, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 1, 8, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 2, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 3, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 4, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 5, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 6, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021214008189, 7, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 1, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 2, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 3, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 4, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 5, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 6, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 7, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 8, 187, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 9, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 10, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 11, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 12, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126008190, 13, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 1, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 2, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 3, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 4, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 5, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 6, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 7, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 8, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 9, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230008191, 10, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 1, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 2, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 3, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 4, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 5, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 6, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 7, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 8, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 9, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 10, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 11, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 12, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 13, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 14, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008192, 15, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 1, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 2, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 3, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 4, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 5, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 6, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 7, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 8, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 9, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 10, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 11, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125008193, 12, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 1, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 2, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 3, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 4, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 5, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509008194, 6, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219008195, 1, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219008195, 2, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219008195, 3, 148, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219008195, 4, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219008195, 5, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 1, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 2, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 3, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 4, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 5, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 6, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 7, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 8, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 9, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 10, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 11, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 12, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829008594, 7, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104008595, 1, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104008595, 2, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104008595, 3, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104008595, 4, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020104008595, 5, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 1, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 2, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 3, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 4, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 5, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209008596, 6, 111, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 1, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 2, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 3, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 4, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 5, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 6, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 7, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 8, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 9, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 10, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 11, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 12, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 13, 135, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706008597, 14, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921008598, 1, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921008598, 2, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921008598, 3, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921008598, 4, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921008598, 5, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 1, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 2, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 3, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 4, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 5, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 6, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310008599, 7, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 1, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 2, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 3, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 4, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 5, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 6, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 7, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 8, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723008600, 9, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 1, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 2, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 3, 96, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 4, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 5, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 6, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 7, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 8, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 9, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 10, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 11, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 12, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 13, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 14, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 15, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115008601, 16, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 1, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 2, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 3, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 4, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 5, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 6, 75, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 7, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717008602, 8, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 1, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 2, 181, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 3, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 4, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 5, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208008603, 6, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028008604, 1, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028008604, 2, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028008604, 3, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028008604, 4, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 1, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 2, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 3, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 4, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 5, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 6, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 7, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 8, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911008605, 9, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 1, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 2, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 3, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 4, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 5, 154, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 6, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 7, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109008606, 8, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 1, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 2, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 3, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 5, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602008607, 6, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 1, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 2, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 3, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 4, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 5, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 6, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 7, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 8, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001008608, 9, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 1, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 2, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 3, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 4, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 5, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 6, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 7, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 8, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 9, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 10, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 11, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 12, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 13, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 14, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 15, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820008609, 16, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 1, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 2, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 3, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 4, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 5, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 6, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 7, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 8, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 9, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008610, 10, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 1, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 2, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 3, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 4, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 5, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 6, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 7, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 8, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 9, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 10, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 11, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 12, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 13, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 14, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 15, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120812008611, 16, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831008612, 1, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831008612, 2, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831008612, 3, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831008612, 4, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 1, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 2, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 3, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 4, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 5, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 6, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 7, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 8, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 9, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 10, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701008613, 11, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512008614, 1, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512008614, 2, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512008614, 3, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512008614, 4, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010512008614, 5, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 1, 1, 40, 3, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 2, 41, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 3, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 4, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 5, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 6, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 7, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 8, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 9, 94, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 10, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 11, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 12, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424008615, 13, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 1, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 2, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 3, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 4, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 5, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 6, 180, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 7, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060125008616, 8, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 1, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 2, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 3, 79, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 4, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 5, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 6, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 7, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 8, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 9, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 10, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 11, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 12, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 13, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711008617, 14, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 1, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 2, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 3, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 4, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 5, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 6, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 7, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 8, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 9, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 10, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 11, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 12, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090717008618, 13, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121008619, 1, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121008619, 2, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121008619, 3, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121008619, 4, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010121008619, 5, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 1, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 2, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 3, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 4, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 5, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 6, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 7, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 8, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 9, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 10, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 11, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 6, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 7, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 8, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 9, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 10, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 11, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 12, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 13, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727007425, 14, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210007426, 1, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210007426, 2, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210007426, 3, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210007426, 4, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210007426, 5, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314007427, 1, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314007427, 2, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 1, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 2, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 3, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 4, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 5, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922007428, 6, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 1, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 2, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 3, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 4, 159, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 5, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 6, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 7, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 8, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 9, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 10, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 11, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 12, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 13, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 14, 128, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 15, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713007429, 16, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 1, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 2, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 3, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 4, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 5, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 6, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 7, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 8, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 9, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 10, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 11, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 12, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828007430, 13, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 1, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 2, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 3, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 4, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 5, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 6, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 7, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 8, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 9, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 10, 22, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 11, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 12, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 13, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123007431, 14, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619007432, 1, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619007432, 2, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619007432, 3, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619007432, 4, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 1, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 2, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 3, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 4, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 5, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 6, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 7, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 8, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 9, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 10, 186, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401007433, 11, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 1, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 2, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 3, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 4, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 5, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 6, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 7, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 8, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 9, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 10, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805007434, 11, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 1, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 2, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 3, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 4, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 5, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 6, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218007435, 7, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 1, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 2, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 3, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 4, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 5, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 6, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 7, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 8, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 9, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 10, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 11, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 12, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 13, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 14, 119, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 15, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731007436, 16, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 1, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 2, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 3, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 4, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 5, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 6, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 7, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 8, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 9, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 10, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 11, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118007437, 12, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 1, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 2, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 3, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 4, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 5, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 6, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 7, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108007438, 8, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 1, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 2, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 3, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 4, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 5, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 6, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 7, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105007439, 8, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 1, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 2, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 3, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 4, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 5, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 6, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 7, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 8, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615007440, 9, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 1, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 2, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 3, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 4, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 5, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 6, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 7, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 8, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 9, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 10, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 11, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 12, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 13, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 14, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 15, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 16, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 17, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413007441, 18, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 1, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 2, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 3, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 4, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 5, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 6, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 7, 138, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 8, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 9, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213007442, 10, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 1, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 2, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 3, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 4, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 5, 1, 27, 3, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 6, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020422007443, 7, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007444, 1, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007444, 2, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007444, 3, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007444, 4, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 1, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 2, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 3, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 4, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 5, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 6, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 7, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 8, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 9, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 10, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 11, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 12, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 13, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 14, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 15, 27, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 16, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130906007445, 17, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 1, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 2, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 3, 167, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 4, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 5, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 6, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 7, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 8, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 9, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 10, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 11, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 12, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 13, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 14, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 15, 134, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 16, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530007446, 17, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 1, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 2, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 3, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 4, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 5, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 6, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 7, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 8, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 9, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 10, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 11, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 12, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 13, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 14, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 15, 81, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 2, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 3, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 4, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 5, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807007820, 6, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 1, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 2, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 3, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 4, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 5, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 6, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 7, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 8, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 9, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908007821, 10, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 1, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 2, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 3, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 4, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 5, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 6, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 7, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 8, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 9, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 10, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 11, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 12, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 13, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 14, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 15, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 16, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602007822, 17, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 1, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 2, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 3, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 4, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 5, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 6, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 7, 14, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 8, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 9, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 10, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 11, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222007823, 12, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 1, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 2, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 3, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 4, 31, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 5, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 6, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 7, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 8, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 9, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 10, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 11, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 12, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 13, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 14, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 15, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 16, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 17, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 18, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414007824, 19, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 1, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 2, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 3, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 4, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 5, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 6, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 7, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 8, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 9, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 10, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 11, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 12, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 13, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 14, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915007825, 15, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 1, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 2, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 3, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 4, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 5, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 6, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 7, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 8, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 9, 19, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 10, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 11, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 12, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 13, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 14, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101013007826, 15, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 1, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 2, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 3, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 4, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 5, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 6, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 7, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 8, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 9, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 10, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 11, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 12, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206007827, 13, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 1, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 2, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 3, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 4, 52, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 5, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 6, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 7, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 8, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 9, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 10, 165, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 11, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 12, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 13, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726007828, 14, 134, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 1, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 2, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 3, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 4, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 5, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 6, 78, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 7, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 8, 58, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215007829, 9, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 1, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 2, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 3, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 4, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 5, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 6, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 7, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308007830, 8, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 1, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 2, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 3, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 4, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 5, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 6, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 7, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 8, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 9, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 10, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 11, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 12, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 13, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813007831, 14, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 1, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 2, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 3, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 4, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 5, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 6, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 7, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 8, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 9, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730007832, 10, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 1, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 2, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 3, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 4, 138, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 5, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 6, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 7, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 8, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227007833, 9, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 1, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 2, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 3, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 4, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 5, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 6, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 7, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 8, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 9, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 10, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 11, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924007834, 12, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 1, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 2, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 3, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 4, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 5, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 6, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 7, 145, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 8, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 9, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 10, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 11, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 12, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 13, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 14, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709007835, 15, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 1, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 3, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 4, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 5, 65, 96, 5, 480);
commit;
prompt 80000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 6, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 7, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205007836, 8, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 1, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 2, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 3, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 4, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 5, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 6, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 7, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 8, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 9, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 10, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 11, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 12, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 13, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616007837, 14, 191, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224007838, 1, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224007838, 2, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224007838, 3, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224007838, 4, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224007838, 5, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 1, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 2, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 3, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 4, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 5, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 6, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 7, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 8, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 9, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 10, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 11, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 12, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 13, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225007839, 14, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 1, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 13, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 14, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 15, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 16, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403008196, 17, 43, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 1, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 2, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 3, 128, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 4, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 5, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 6, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 7, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 8, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 9, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 10, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816008197, 11, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 1, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 2, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 3, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 4, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 5, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 6, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 7, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 8, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 9, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 10, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 11, 79, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 12, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 13, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008198, 14, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 1, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 2, 30, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 3, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 4, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 5, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 6, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 7, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 8, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 9, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 10, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008199, 11, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 1, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 2, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 3, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 4, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 5, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 6, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 7, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 8, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 9, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 10, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070817008200, 11, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 1, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 2, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 3, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 4, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 5, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 6, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 7, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 8, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 9, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 10, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 11, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 12, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 13, 187, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 14, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 15, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008201, 16, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 1, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 2, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 3, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 4, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 5, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 6, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 7, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040525008202, 8, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 1, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 2, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 3, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 4, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 5, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 6, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 7, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 8, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 9, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 10, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 11, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 12, 133, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101130008203, 13, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 1, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 2, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 3, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 4, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 5, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 6, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 7, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 8, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 9, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 10, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 11, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 12, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 13, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 14, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 15, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 16, 18, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406008204, 17, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507008205, 1, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507008205, 2, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507008205, 3, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507008205, 4, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 1, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 2, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 3, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 4, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 5, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 6, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 7, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 8, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206008206, 9, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 1, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 2, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 3, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 4, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 5, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121008207, 6, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409008208, 1, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409008208, 2, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409008208, 3, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409008208, 4, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 1, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 2, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 3, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 4, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 5, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 6, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 7, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 8, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 9, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107008209, 10, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 1, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 2, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 3, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 4, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 5, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 6, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 7, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 8, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317008210, 9, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 1, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 2, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 3, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 4, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 5, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 6, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 7, 20, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 8, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 9, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 10, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 11, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201008211, 12, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 1, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 2, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 3, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 4, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 5, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 6, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 7, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 8, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 9, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 10, 114, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205008212, 11, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 1, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 2, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 3, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 4, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 5, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 6, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 7, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 8, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 9, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 10, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319008213, 11, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 1, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 2, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 3, 1, 39, 3, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 4, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 5, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 6, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 7, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222008214, 8, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119008215, 1, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119008215, 2, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119008215, 3, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119008215, 4, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119008215, 5, 178, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 1, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 2, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 3, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 4, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 5, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731008216, 6, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728008217, 1, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728008217, 2, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 1, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 2, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 3, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 4, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 5, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 6, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 7, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 8, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 9, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 10, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 11, 120, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 12, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 13, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 14, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008218, 15, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 1, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 2, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 3, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 4, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 5, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 6, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 7, 141, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 8, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 9, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 10, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 11, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 12, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 13, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 14, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 15, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008219, 16, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 1, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 2, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 3, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 4, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 6, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 7, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 8, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 9, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 10, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630008499, 11, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 1, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 2, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 3, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 4, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 5, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 6, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 7, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 8, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 9, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 10, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221008500, 11, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 1, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 3, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 4, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 5, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 6, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 7, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 8, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 9, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 10, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 11, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 12, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 13, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008501, 14, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 1, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 2, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 3, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 4, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 5, 157, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 6, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 7, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 8, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 9, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 10, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 11, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 12, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 13, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 14, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 15, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 16, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008502, 17, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 1, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 2, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 3, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 4, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 5, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 6, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 7, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 8, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 9, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 10, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619008503, 11, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 1, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 2, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 3, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 4, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 5, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114008504, 6, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 1, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 2, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 3, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 4, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 5, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 6, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 7, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111008505, 8, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 1, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 2, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 3, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 4, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 5, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 6, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 7, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 8, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 9, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 10, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 11, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 12, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 13, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 14, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008506, 15, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 1, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 2, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 3, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 4, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 5, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 6, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 7, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 8, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060226008507, 9, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 1, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 2, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 3, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 4, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 5, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 6, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827008508, 7, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 1, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 2, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 3, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 4, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 5, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 6, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 7, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 8, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 9, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514008509, 10, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 1, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 2, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 3, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 4, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 5, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 6, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 7, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 8, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 9, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 10, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 11, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 12, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 13, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227008510, 14, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008511, 1, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008511, 2, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008511, 3, 157, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 1, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 2, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 3, 153, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 4, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 5, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 6, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 7, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 8, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 9, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 10, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 11, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 12, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 13, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 14, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 15, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 16, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130531008512, 17, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 1, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 2, 192, 89, 18, 1602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 3, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 4, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 5, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 6, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 7, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 8, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 9, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050719008513, 10, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015008514, 1, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015008514, 2, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015008514, 3, 65, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015008514, 4, 190, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 1, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 2, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 3, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 4, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 5, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 6, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 7, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 8, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 9, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 10, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 11, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 12, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 13, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 14, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 15, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 16, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 17, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211008515, 18, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 1, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 2, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 3, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 4, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 5, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 6, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 7, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 8, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 9, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 10, 190, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 11, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 12, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 13, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110612008516, 14, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 1, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 2, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 3, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 4, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 5, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 6, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 7, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 8, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 9, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 10, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 11, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311008517, 12, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129008518, 1, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129008518, 2, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129008518, 3, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129008518, 4, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129008518, 5, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 1, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 2, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 3, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 4, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 5, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 6, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 7, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 8, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 9, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112008519, 10, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 1, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 2, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 3, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 4, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 5, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 6, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 7, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 8, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 9, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 10, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 11, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 12, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228008520, 13, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502008521, 1, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502008521, 2, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502008521, 3, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502008521, 4, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502008521, 5, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 16, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 17, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314007447, 18, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 1, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 2, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 3, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 4, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 5, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 6, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 7, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 8, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 9, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 10, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221007448, 11, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 1, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 2, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 3, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 4, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 5, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 6, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 7, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 8, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 9, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 10, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 11, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 12, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 13, 176, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 14, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 15, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125007449, 16, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 1, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 2, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 3, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 4, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 5, 25, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 6, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 7, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020007450, 8, 1, 14, 3, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 1, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 2, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 3, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 4, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 5, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 6, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 7, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 8, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 9, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 10, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 11, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114007451, 12, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 1, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 2, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 3, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 4, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 5, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 6, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 7, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 8, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 9, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 10, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 11, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611007452, 12, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614007453, 1, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614007453, 2, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614007453, 3, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 1, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 2, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 3, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 4, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 5, 2, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 6, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 7, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 8, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 9, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 10, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 11, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 12, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 13, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111007454, 14, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 1, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 2, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 3, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 4, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 5, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 6, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 7, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 8, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216007455, 9, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 1, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 2, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 3, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 4, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 5, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 6, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818007456, 7, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 1, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 2, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 3, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 4, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 5, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227007457, 6, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 1, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 2, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 3, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 4, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 5, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 6, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 7, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 8, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 9, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 10, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 11, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 12, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 13, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 14, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517007458, 15, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 1, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 2, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 3, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 4, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 5, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 6, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 7, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 8, 152, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 9, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 10, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 11, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 12, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127007459, 13, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013007460, 1, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013007460, 2, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621007461, 1, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621007461, 2, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 1, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 2, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 3, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 4, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 5, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 6, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 7, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 8, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 9, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 10, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 11, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 12, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 13, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 14, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 15, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024007462, 16, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 1, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 2, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 3, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 4, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 5, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 6, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 7, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 8, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 9, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 10, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 11, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 12, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 13, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 14, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 15, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 16, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410007463, 17, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 1, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 2, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 3, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 4, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 5, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029007464, 6, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 1, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 2, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 3, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 4, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 5, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 6, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702007465, 7, 120, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 1, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 2, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 3, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 4, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 5, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 6, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 7, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929007466, 8, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007467, 1, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007467, 2, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007467, 3, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007467, 4, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007467, 5, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 1, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 2, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 3, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 4, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 5, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 6, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 7, 77, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 8, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 9, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 10, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 11, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 12, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 13, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 14, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 15, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 16, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315007468, 17, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 1, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 2, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 3, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 4, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 5, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 6, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 7, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914007469, 8, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 1, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 2, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 3, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 4, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 5, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 6, 74, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 7, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 8, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220007470, 9, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 1, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 2, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 3, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 4, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 5, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 6, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 7, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 8, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 9, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 10, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 11, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 12, 154, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 13, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 2, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 3, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 4, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 5, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 6, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 7, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 8, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 9, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 10, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707007840, 11, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 1, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 2, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 3, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 4, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 5, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 6, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 7, 107, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 8, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 9, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 10, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 11, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 12, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 13, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 14, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121117007841, 15, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 1, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 2, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 3, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 4, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 5, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 6, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 7, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 8, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 9, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 10, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 11, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 12, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 13, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 14, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028007842, 15, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 1, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 2, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 3, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 4, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 5, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 6, 187, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050320007843, 7, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 1, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 2, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 3, 27, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 4, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 5, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 6, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 7, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 8, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 9, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 10, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 11, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 12, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 13, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 14, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820007844, 15, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 1, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 2, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 3, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 4, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 5, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311007845, 6, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 1, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 2, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 3, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 4, 64, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 5, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 6, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 7, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912007846, 8, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 1, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 2, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 3, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 4, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 5, 153, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 6, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 7, 77, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 8, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 9, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 10, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 11, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 12, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 13, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 14, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110930007847, 15, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 1, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 2, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 3, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 4, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 5, 177, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 6, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 7, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 8, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 9, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223007848, 10, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415007849, 1, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415007849, 2, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415007849, 3, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415007849, 4, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 1, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 2, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 3, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 4, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 5, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 6, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 7, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 8, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 9, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 10, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 11, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 12, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 13, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 14, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 15, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110415007850, 16, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 1, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 2, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 3, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 4, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 5, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 6, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 7, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 8, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 9, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 10, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 11, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409007851, 12, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 1, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 2, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 3, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 4, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 5, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427007852, 6, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 1, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 2, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 3, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 4, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 5, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 6, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 7, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 8, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 9, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 10, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 11, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 12, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 13, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 14, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007853, 15, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 1, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 2, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 3, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 4, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 5, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 6, 89, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 7, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007854, 8, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 1, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 2, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 3, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 4, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 5, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 6, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 7, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 8, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 9, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 10, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 11, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 12, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 13, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100331007855, 14, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426007856, 1, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426007856, 2, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426007856, 3, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426007856, 4, 136, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 1, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 2, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 3, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 4, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 5, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 6, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 7, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 8, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 9, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 10, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 11, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 12, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 13, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 14, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 15, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712007857, 16, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007858, 1, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007858, 2, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007858, 3, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007858, 4, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 1, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 2, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 3, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 4, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 5, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 6, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 7, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 8, 192, 57, 18, 1026);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 9, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 10, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 11, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610007859, 12, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830007860, 1, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830007860, 2, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830007860, 3, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830007860, 4, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 1, 9, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 2, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 3, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 4, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 5, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 6, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 7, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125007861, 8, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 1, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 2, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 3, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 4, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 5, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 6, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 7, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 8, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 9, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 10, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 11, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 12, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 13, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 14, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 5, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020405008220, 6, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008221, 1, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008221, 2, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008221, 3, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008221, 4, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 1, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 2, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 3, 124, 34, 12, 408);
commit;
prompt 81000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 4, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 5, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 6, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 7, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 8, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 9, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 10, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 11, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 12, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090304008222, 13, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 1, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 2, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 3, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 4, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 5, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 6, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 7, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 8, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 9, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 10, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 11, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 12, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 13, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 14, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 15, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110407008223, 16, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 1, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 2, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 3, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 4, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 5, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 6, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 7, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 8, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 9, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 10, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 11, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 12, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 13, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620008224, 14, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 1, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 2, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 3, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 4, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 5, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 6, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203008225, 7, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 1, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 2, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 3, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 4, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 5, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 6, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 7, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 8, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 9, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 10, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 11, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 12, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090115008226, 13, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 1, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 2, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 3, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 4, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 5, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 6, 89, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 7, 183, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 8, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 9, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020008227, 10, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 1, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 2, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 3, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 4, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 5, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 6, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 7, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 8, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 9, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 10, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 11, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 12, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 13, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 14, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 15, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 16, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121127008228, 17, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 1, 76, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 2, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 3, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 4, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 5, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 6, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 7, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 8, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 9, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 10, 145, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 11, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 12, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 13, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 14, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 15, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527008229, 16, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 1, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 2, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 3, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 4, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 5, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 6, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 7, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 8, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 9, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 10, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 11, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 12, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 13, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 14, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 15, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120612008230, 16, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 1, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 2, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 3, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 4, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 5, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 6, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 7, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 8, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 9, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 10, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321008231, 11, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 1, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 2, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 3, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 4, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 5, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 6, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 7, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 8, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 9, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 10, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 11, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008232, 12, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 1, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 2, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 3, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 4, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 5, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 6, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 7, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 8, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 9, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 10, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 11, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 12, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 13, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 14, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 15, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 16, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715008233, 17, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 1, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 2, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 3, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 4, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 5, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 6, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 7, 74, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 8, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030008234, 9, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 1, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 2, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 3, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 4, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 5, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 6, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417008235, 7, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008236, 1, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008236, 2, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008236, 3, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008236, 4, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008236, 5, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117008237, 1, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117008237, 2, 88, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117008237, 3, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117008237, 4, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008238, 1, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008238, 2, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 1, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 2, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 3, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 4, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 5, 22, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 6, 1, 89, 3, 267);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 7, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 8, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041212008239, 9, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 1, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 2, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 3, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 4, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 5, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 6, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 7, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 8, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 9, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129008240, 10, 13, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 1, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 2, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 3, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 4, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 5, 55, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 6, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 7, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318008241, 8, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 1, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 2, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 3, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 4, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 5, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 6, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 7, 98, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 8, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 9, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 10, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 11, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 12, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 13, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423008242, 14, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 1, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 2, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 3, 192, 29, 18, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 5, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704008548, 6, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 1, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 2, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 3, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 4, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 5, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 6, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 7, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 8, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 9, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 10, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 11, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 12, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 13, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 14, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 15, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 16, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 17, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211008549, 18, 5, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 1, 54, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 2, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 3, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 4, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 5, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 6, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 7, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040602008550, 8, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 1, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 2, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 3, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 4, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 5, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 6, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 7, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 8, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 9, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 10, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 11, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101101008551, 12, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803008552, 1, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803008552, 2, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803008552, 3, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803008552, 4, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803008552, 5, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 1, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 2, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 3, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 4, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 5, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 6, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 7, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 8, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 9, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 10, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 11, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 12, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 13, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020008553, 14, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 1, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 2, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 3, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 5, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 6, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 7, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 8, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 9, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404008554, 10, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 1, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 2, 140, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 3, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 4, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 5, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 6, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 7, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 8, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 9, 92, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 10, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605008555, 11, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 1, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 2, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 3, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 4, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 5, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 6, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202008556, 7, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 1, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 2, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 3, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 4, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 5, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 6, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 7, 179, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 8, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 9, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919008557, 10, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 1, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 2, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 3, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 4, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 5, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 6, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 7, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 8, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 9, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 10, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 11, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 12, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008558, 13, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810008559, 1, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810008559, 2, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810008559, 3, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810008559, 4, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 1, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 2, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 3, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 4, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 5, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 6, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102008560, 7, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 1, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 2, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 3, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 4, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 5, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 6, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 7, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 8, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 9, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 10, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 11, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824008561, 12, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 1, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 2, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 3, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 4, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 5, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 6, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 7, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626008562, 8, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710008563, 1, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710008563, 2, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710008563, 3, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710008563, 4, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710008563, 5, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303008564, 1, 169, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303008564, 2, 94, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303008564, 3, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303008564, 4, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 1, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 2, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 3, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 4, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 5, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 6, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 7, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 8, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 9, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 10, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008565, 11, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 1, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 2, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 3, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 4, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 5, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 6, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 7, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 8, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127008566, 9, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 1, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 2, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 3, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 4, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 5, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 6, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 7, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 8, 128, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 9, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 10, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 11, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 12, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 13, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 14, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120118008567, 15, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 1, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 2, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 3, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 4, 105, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 5, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 6, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 7, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731008568, 8, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 1, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 2, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 3, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 4, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 5, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 6, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 7, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 8, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 9, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 10, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 11, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 12, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 13, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 14, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 15, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 16, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509008569, 17, 83, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 1, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 2, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 3, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 4, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 5, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 6, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 7, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826008570, 8, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 1, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 2, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 3, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 4, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 5, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 6, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030403008571, 7, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 1, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 2, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 3, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 4, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 5, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 6, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 7, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050423008572, 8, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 1, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 2, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 3, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 4, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 5, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325008573, 6, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 14, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 15, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906007471, 16, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618007472, 1, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618007472, 2, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618007472, 3, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 1, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 2, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 3, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 4, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 5, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 6, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 7, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 8, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 9, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 10, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 11, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 12, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 13, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 14, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 15, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 16, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129007473, 17, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 1, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 2, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 3, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 4, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 5, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 6, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 7, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 8, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 9, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 10, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 11, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708007474, 12, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 1, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 2, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 3, 122, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 4, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 5, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 6, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 7, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 8, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 9, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 10, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 11, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 12, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 13, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 14, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406007475, 15, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 1, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 2, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 3, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 4, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 5, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 6, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 7, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 8, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 9, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 10, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 11, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 12, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 13, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 14, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 15, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525007476, 16, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503007477, 1, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503007477, 2, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503007477, 3, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503007477, 4, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020503007477, 5, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 1, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 2, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 3, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 4, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 5, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115007478, 6, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 1, 109, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 2, 1, 7, 3, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 3, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 4, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 5, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 6, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 7, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 8, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 9, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 10, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 11, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 12, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 13, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226007479, 14, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804007480, 1, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804007480, 2, 141, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804007480, 3, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 1, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 2, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 3, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 4, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 5, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 6, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 7, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 8, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 9, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 10, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 11, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 12, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 13, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 14, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 15, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011007481, 16, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 1, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 2, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 3, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 4, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 5, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 6, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 7, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 8, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 9, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106007482, 10, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 1, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 2, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 3, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 4, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 5, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 6, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 7, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 8, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 9, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 10, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 11, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 12, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 13, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 14, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 15, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102007483, 16, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410007484, 1, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410007484, 2, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410007484, 3, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410007484, 4, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410007484, 5, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 1, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 2, 101, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 3, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 4, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 5, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 6, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 7, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 8, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 9, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 10, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071204007485, 11, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 1, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 2, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 3, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 4, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 5, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 6, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 7, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 8, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 9, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 10, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 11, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 12, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 13, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 14, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 15, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121115007486, 16, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 1, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 2, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 3, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 4, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 5, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 6, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 7, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007487, 8, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 1, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 2, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 3, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 4, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 5, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 6, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 7, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 8, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 9, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 10, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 11, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 12, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 13, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 14, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 15, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328007488, 16, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 1, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 2, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 3, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 4, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 5, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 6, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329007489, 7, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 1, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 2, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 3, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 4, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 5, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 6, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 8, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 9, 31, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 10, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 11, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901007490, 12, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 1, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 2, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 3, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 4, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 5, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 6, 85, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 7, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 8, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 9, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 10, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 11, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822007491, 12, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 1, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 2, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 3, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 4, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 5, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 6, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 7, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 8, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 9, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 10, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201007492, 11, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007493, 1, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007493, 2, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007493, 3, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007493, 4, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006007493, 5, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320007862, 15, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 1, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 2, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 3, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 4, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 5, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 6, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 7, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 8, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 9, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 10, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 11, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 12, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921007863, 13, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 1, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 2, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 3, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 4, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 5, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 6, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 7, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 8, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 9, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 10, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 11, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 12, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 13, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 14, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226007864, 15, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 1, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 2, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 3, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 4, 14, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 5, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 6, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 7, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 8, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302007865, 9, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 1, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 2, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 3, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 4, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 5, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 6, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 7, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 8, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 9, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 10, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 11, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 12, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 13, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 14, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 15, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016007866, 16, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 1, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 2, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 3, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 4, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 5, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 6, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 7, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 8, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 9, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 10, 89, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 11, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 12, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126007867, 13, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 1, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 2, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 3, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 4, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 5, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 6, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 7, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 8, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 9, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 10, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017007868, 11, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315007869, 1, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315007869, 2, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315007869, 3, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315007869, 4, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315007869, 5, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 1, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 2, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 3, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 4, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 5, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 6, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 7, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 8, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 9, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 10, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 11, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 12, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024007870, 13, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 1, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 2, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 3, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 4, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 5, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727007871, 6, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128007872, 1, 20, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128007872, 2, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128007872, 3, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128007872, 4, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 1, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 2, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 3, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 4, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 5, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326007873, 6, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 1, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 2, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 3, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 4, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 5, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 6, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 7, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 8, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 9, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 10, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007874, 11, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 1, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 2, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 3, 74, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 4, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 5, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 6, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 7, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 8, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 9, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 10, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 11, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 12, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 13, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 14, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 15, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 16, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121031007875, 17, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 1, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 2, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 3, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 4, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 5, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 6, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 7, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 8, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 9, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 10, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 11, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 12, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 13, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 14, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917007876, 15, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 1, 14, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 2, 70, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 3, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 4, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 5, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 6, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 7, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 8, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 9, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 10, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 11, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 12, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 13, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120007877, 14, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 1, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 2, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 3, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 4, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 5, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 6, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 7, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 8, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 9, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060930007878, 10, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 1, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 2, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 3, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 4, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 5, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 6, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005007879, 7, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 1, 111, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 2, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 3, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 4, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 5, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 6, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 7, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 8, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910007880, 9, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 1, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 2, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 3, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 4, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 5, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 6, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 7, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 8, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506007881, 9, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426007882, 1, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426007882, 2, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426007882, 3, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426007882, 4, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 1, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 2, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 3, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 4, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 5, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 6, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 7, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 8, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 9, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 10, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 11, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 12, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029007883, 13, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 1, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 2, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 3, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 4, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 5, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 6, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 7, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 8, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 9, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 10, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 11, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 12, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 13, 65, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 14, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 15, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 16, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 17, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 18, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 4, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 5, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 6, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 7, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 8, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130008243, 9, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 1, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 2, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 3, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 4, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 5, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 6, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316008244, 7, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 1, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 2, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 3, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 4, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 5, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 6, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 7, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 8, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 9, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 10, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 11, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 12, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 13, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 14, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 15, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110614008245, 16, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 1, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 2, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 3, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 4, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 5, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 6, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 7, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 8, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716008246, 9, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 1, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 2, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 3, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 4, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 5, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 6, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 7, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 8, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 9, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 10, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 11, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090912008247, 12, 138, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 1, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 2, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 3, 171, 10, 11, 110);
commit;
prompt 82000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 4, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 5, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 6, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 7, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 8, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 9, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 10, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 11, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 12, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 13, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522008248, 14, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 1, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 2, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 3, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 4, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 5, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 6, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219008249, 7, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 1, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 2, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 3, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 4, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 5, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 6, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 7, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 8, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 9, 76, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 10, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 11, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 12, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 13, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 14, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008250, 15, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 1, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 2, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 3, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 4, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 5, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 6, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 7, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113008251, 8, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 1, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 2, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 3, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 4, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 5, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 6, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 7, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 8, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 9, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 10, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 11, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 12, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 13, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 14, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910008252, 15, 116, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 1, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 2, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 3, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 4, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 5, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 6, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 7, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 8, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 9, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 10, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 11, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424008253, 12, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630008254, 1, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630008254, 2, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630008254, 3, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630008254, 4, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630008254, 5, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 1, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 2, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 3, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 4, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 5, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 6, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 7, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 8, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 9, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 10, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 11, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 12, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 13, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 14, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716008255, 15, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 1, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 2, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 3, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 4, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 5, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 6, 150, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 7, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 8, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 9, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 10, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 11, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 12, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 13, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513008256, 14, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 1, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 2, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 3, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 4, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 5, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 6, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 7, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 8, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 9, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 10, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110008257, 11, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 1, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 2, 79, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 3, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 4, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 5, 165, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 6, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 7, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030601008258, 8, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 1, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 2, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 3, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 4, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 5, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 6, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 7, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 8, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 9, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 10, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 11, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406008259, 12, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 1, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 2, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 3, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 4, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 5, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 6, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 7, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114008260, 8, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 1, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 2, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 3, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 4, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 5, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 6, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 7, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 8, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 9, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 10, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026008261, 11, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 1, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 2, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 3, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 4, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 5, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224008262, 6, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 1, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 2, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 3, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 4, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 5, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 6, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 7, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 8, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 9, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 10, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 11, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408008263, 12, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 1, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 2, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 3, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 4, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 5, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 6, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 7, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 8, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 9, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 10, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 11, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 12, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 13, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 14, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 15, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 5, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 6, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 7, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 8, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 9, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 10, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 11, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 12, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 13, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 14, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 15, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120404007119, 16, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 1, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 2, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 3, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 4, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 5, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 6, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 7, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 8, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 9, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 10, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 11, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 12, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 13, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 14, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 15, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007120, 16, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 1, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 2, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 3, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 4, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 5, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 6, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 7, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 8, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 9, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 10, 39, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714007121, 11, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 1, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 2, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 3, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 4, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 5, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 6, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 7, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 8, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 9, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 10, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 11, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 12, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 13, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 14, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007122, 15, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 1, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 2, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 3, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 4, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 5, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 6, 110, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 7, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 8, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 9, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 10, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 11, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 12, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 13, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 14, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 15, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517007123, 16, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018007124, 1, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018007124, 2, 172, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018007124, 3, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018007124, 4, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031018007124, 5, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816007125, 1, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816007125, 2, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816007125, 3, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816007125, 4, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 1, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 2, 129, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 3, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 4, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 5, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 6, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915007126, 7, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 1, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 2, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 3, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 4, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 5, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 6, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 7, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 8, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 9, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 10, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 11, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 12, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 13, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 14, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 15, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125007127, 16, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 1, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 2, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 3, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 4, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 5, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 6, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 7, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512007128, 8, 112, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416007129, 1, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416007129, 2, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416007129, 3, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416007129, 4, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416007129, 5, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 1, 112, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 2, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 3, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 4, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 5, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 6, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 7, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 8, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828007130, 9, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 1, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 2, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 3, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 4, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 5, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 6, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 7, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 8, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 9, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 10, 183, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224007131, 11, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 1, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 2, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 3, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 4, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 5, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 6, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 7, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 8, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 9, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 10, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 11, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 12, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 13, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 14, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128007132, 15, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518007133, 1, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518007133, 2, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518007133, 3, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518007133, 4, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010518007133, 5, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 1, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 2, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 3, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 4, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 5, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 6, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 7, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 8, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 9, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071229007134, 10, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 1, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 2, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 3, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 4, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 5, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 6, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 7, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 8, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 9, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 10, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 11, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 12, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529007135, 13, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 1, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 2, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 3, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 4, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 5, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 6, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 7, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 8, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 9, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 10, 34, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 11, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 12, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 13, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606007136, 14, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 2, 127, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 3, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 4, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 5, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 6, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 7, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 8, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 9, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 10, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 11, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312007137, 12, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 1, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 2, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 3, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 4, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 5, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 6, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 7, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 8, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 9, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 10, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 11, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 12, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100426007138, 13, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 1, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 2, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 3, 174, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 4, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 5, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 6, 24, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 7, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 8, 109, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 9, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 10, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 11, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 12, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 13, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 14, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 15, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 16, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110007139, 17, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 1, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 2, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 3, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 4, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 5, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 1, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 2, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 3, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 4, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 5, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 6, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 7, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 8, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027007494, 9, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 1, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 2, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 3, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 4, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 5, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 6, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 7, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 8, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 9, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 10, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 11, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 12, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 13, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126007495, 14, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 1, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 2, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 3, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 4, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 5, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 6, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 7, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 8, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 9, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 10, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919007496, 11, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 1, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 2, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 3, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 4, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 5, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 6, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 7, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 8, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 9, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 10, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 11, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 12, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 13, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219007497, 14, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826007498, 1, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826007498, 2, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826007498, 3, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826007498, 4, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826007498, 5, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 1, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 2, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 3, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 4, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 5, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 6, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223007499, 7, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 1, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 2, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 3, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 4, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 5, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 6, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 7, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 8, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 9, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060524007500, 10, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 1, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 2, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 3, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 4, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 5, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 6, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 7, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 8, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 9, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 10, 104, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 11, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 12, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 13, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 14, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 15, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925007501, 16, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908007502, 1, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908007502, 2, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908007502, 3, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908007502, 4, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908007502, 5, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509007503, 1, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509007503, 2, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509007503, 3, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509007503, 4, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509007503, 5, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 1, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 2, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 3, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 4, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 5, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 6, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 7, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 8, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 9, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 10, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 11, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627007504, 12, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 1, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 2, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 3, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 4, 178, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 5, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 6, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515007505, 7, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 1, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 2, 1, 18, 3, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 3, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 4, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 5, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 6, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 7, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 8, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 9, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 10, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 11, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 12, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 13, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 14, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 15, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830007506, 16, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007507, 1, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007507, 2, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007507, 3, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007507, 4, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216007507, 5, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 1, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 2, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 3, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 4, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 5, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 6, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 7, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 8, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 9, 22, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 10, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423007508, 11, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 1, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 2, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 3, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 4, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 5, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 6, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 7, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 8, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 9, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 10, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 11, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 12, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 13, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108007509, 14, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 1, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 2, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 3, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 4, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 5, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 6, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 7, 105, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426007510, 8, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 1, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 2, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 3, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 4, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 5, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 6, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 7, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 8, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 9, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 10, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 11, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 12, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 13, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 14, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 15, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 16, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609007511, 17, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 1, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 2, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 3, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 4, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 5, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 6, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 7, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 8, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 9, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 10, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 11, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 12, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 13, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 14, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 15, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 16, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007512, 17, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 1, 90, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 2, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 3, 55, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 4, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 5, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 6, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 7, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 8, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407007513, 9, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908007514, 1, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908007514, 2, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908007514, 3, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908007514, 4, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000908007514, 5, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 1, 177, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 2, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 3, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 4, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 5, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 6, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 7, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 8, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 9, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 10, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 11, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 12, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 13, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130007515, 14, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 1, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 2, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 3, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 4, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 5, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 6, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 7, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 8, 158, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111007884, 19, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 1, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 2, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 3, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 4, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 5, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 6, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 7, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119007885, 8, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 1, 149, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 2, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 3, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 4, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 5, 128, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417007886, 6, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 1, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 2, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 3, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 4, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 5, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 6, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 7, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 8, 55, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 9, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 10, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 11, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 12, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 13, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513007887, 14, 55, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 1, 183, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 2, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 3, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 4, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 5, 3, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 6, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 7, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714007888, 8, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 1, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 2, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 3, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 4, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 5, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027007889, 6, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330007890, 1, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330007890, 2, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330007890, 3, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010330007890, 4, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 1, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 2, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 3, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 4, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 5, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 6, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119007891, 7, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 1, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 2, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 3, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 4, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 5, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 6, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 7, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 8, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 9, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 10, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 11, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 12, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 13, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 14, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122007892, 15, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 1, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 2, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 3, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 4, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 5, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 6, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 7, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 8, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 9, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 10, 48, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 11, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 12, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 13, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228007893, 14, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 1, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 2, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 3, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 4, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 5, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 6, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 7, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 8, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 9, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 10, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 11, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 12, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 13, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 14, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 15, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 16, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007894, 17, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 1, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 2, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 3, 138, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 4, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 5, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 6, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 7, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201007895, 8, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 1, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 2, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 3, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 4, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 5, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 6, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 7, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 8, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 9, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 10, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 11, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 12, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 13, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 14, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005007896, 15, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 1, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 2, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 3, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 4, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 5, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030915007897, 6, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 1, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 2, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 3, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 4, 187, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 5, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 6, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 7, 100, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 8, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 9, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 10, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 11, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 12, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 13, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 14, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227007898, 15, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 1, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 2, 79, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 3, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 4, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 5, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 6, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 7, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 8, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 9, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 10, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 11, 26, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 12, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 13, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210007899, 14, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021007900, 1, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021007900, 2, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021007900, 3, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 1, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 2, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 3, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 4, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 5, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 6, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 7, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 8, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 9, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 10, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 11, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 12, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 13, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129007901, 14, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 1, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 2, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 3, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 4, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 5, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020830007902, 6, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 1, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 2, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 3, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 4, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 5, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 6, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 7, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 8, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 9, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 10, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 11, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 12, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007903, 13, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 1, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 2, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 3, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 4, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 5, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 6, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 7, 70, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 8, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 9, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 10, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 11, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 12, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 13, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818007904, 14, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 1, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 2, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 3, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 4, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 5, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 6, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 7, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 8, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 9, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 10, 188, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 11, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314007905, 12, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 1, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 2, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 3, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 4, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 5, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 6, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 7, 92, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 8, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 9, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207007906, 10, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 1, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 2, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 3, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 4, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 5, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 6, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 7, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 8, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319007907, 9, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 16, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924008264, 17, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 1, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 2, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 3, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 4, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 5, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728008265, 6, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 1, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 2, 27, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 3, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 4, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 5, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 6, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 7, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 8, 89, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 9, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224008266, 10, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108008267, 1, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108008267, 2, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108008267, 3, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108008267, 4, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 1, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 2, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 3, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 4, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 5, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726008268, 6, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 1, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 2, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 3, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 4, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 5, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 6, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 7, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 8, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 9, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 10, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 11, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503008269, 12, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 1, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 2, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 3, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 4, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 5, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 6, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213008270, 7, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 1, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 2, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 3, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 4, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 5, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 6, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 7, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 8, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 9, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081210008271, 10, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124008272, 1, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124008272, 2, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124008272, 3, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124008272, 4, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124008272, 5, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 1, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 2, 167, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 3, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 4, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 5, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 6, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 7, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 8, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 9, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 10, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401008273, 11, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 1, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 2, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 3, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 4, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 5, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 6, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205008274, 7, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516008275, 1, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516008275, 2, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516008275, 3, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516008275, 4, 68, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 1, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 2, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 3, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 4, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 5, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 6, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 7, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 8, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 9, 28, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 10, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 11, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507008276, 12, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008277, 1, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008277, 2, 52, 79, 9, 711);
commit;
prompt 83000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008277, 3, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008277, 4, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019008278, 1, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019008278, 2, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019008278, 3, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019008278, 4, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019008278, 5, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 1, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 2, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 3, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 4, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 5, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 6, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 7, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 8, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 9, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 10, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 11, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 12, 69, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627008279, 13, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 1, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 2, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 3, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 4, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 5, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 6, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 7, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 8, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 9, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 10, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 11, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080510008280, 12, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 1, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 2, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 3, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 4, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 5, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 6, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 7, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 8, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 9, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 10, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 11, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 12, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 13, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 14, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 15, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929008281, 16, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122008282, 1, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122008282, 2, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122008282, 3, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 1, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 2, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 3, 46, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 4, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 5, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 6, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 7, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 8, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050725008283, 9, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 1, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 2, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 3, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 4, 147, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 5, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 6, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 7, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 8, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 9, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 10, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 11, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516008284, 12, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226008285, 1, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226008285, 2, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226008285, 3, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226008285, 4, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 1, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 2, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 3, 98, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 4, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 5, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 6, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 7, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 8, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 9, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 10, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 11, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 12, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217008286, 13, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 1, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 2, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 3, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 4, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 5, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 6, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 7, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 8, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061028008287, 9, 56, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 1, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 2, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 3, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 4, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 5, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 6, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 7, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 8, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311008288, 9, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 1, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 2, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 3, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 4, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 5, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 6, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 7, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 8, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 9, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 10, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 11, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 12, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 13, 107, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 14, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 15, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 16, 74, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117008289, 17, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130008290, 1, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130008290, 2, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130008290, 3, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130008290, 4, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130008290, 5, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924008291, 1, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924008291, 2, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924008291, 3, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 1, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 2, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 3, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 4, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 5, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423008292, 6, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 1, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 2, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 6, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 7, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 8, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 9, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418007140, 10, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 1, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 2, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 3, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 4, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 5, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 6, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 7, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 8, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 9, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 10, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117007141, 11, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 1, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 2, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 3, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 4, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 5, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 6, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016007142, 7, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 1, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 2, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 3, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 4, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 5, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 6, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 7, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 8, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 9, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 10, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 11, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 12, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 13, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 14, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 15, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 16, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816007143, 17, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007144, 1, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007144, 2, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007144, 3, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701007144, 4, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 1, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 2, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 3, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 4, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 5, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 6, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 8, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 9, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 10, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 11, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 12, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 13, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 14, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 15, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 16, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506007145, 17, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318007146, 1, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318007146, 2, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318007146, 3, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318007146, 4, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318007146, 5, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 1, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 2, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 3, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 4, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 5, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 6, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 7, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 8, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 9, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 10, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120007147, 11, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 1, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 2, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 3, 93, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 4, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 5, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 6, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 7, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 8, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 9, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 10, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 11, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 12, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110324007148, 13, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 1, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 2, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 3, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 4, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 5, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 6, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 7, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 8, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 9, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918007149, 10, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 1, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 2, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 3, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 4, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 5, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 6, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809007150, 7, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 1, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 2, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 3, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 4, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 5, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 6, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202007151, 7, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208007152, 1, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208007152, 2, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208007152, 3, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208007152, 4, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208007152, 5, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 1, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 2, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 3, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 4, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 5, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 6, 157, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 7, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 8, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 9, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007153, 10, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 1, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 2, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 3, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 4, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 5, 188, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 6, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 7, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 8, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 9, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 10, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228007154, 11, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 1, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 2, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 3, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 4, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 5, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 6, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 7, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 8, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 9, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 10, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205007155, 11, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 1, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 2, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 3, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 4, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 5, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618007156, 6, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 1, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 2, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 3, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 4, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 5, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 6, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 7, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 8, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060622007157, 9, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303007158, 1, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303007158, 2, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 1, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 2, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 3, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 4, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 5, 37, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 6, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507007159, 7, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 1, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 2, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 3, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 4, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 5, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 6, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 7, 19, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 8, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 9, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 10, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 11, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 12, 177, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509007160, 13, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 1, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 2, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 3, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 4, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 5, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 6, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 7, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 8, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 9, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130007161, 10, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 1, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 2, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 3, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 4, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 5, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 6, 140, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 7, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 8, 1, 13, 3, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 9, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 10, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023007162, 11, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 1, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 2, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 3, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 4, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 5, 116, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 6, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 7, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 8, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 9, 135, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 10, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 11, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507007163, 12, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313007164, 1, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313007164, 2, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313007164, 3, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 1, 126, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 2, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 3, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 4, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 5, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 6, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 7, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 8, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 9, 34, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 10, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210007165, 11, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 1, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 2, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 3, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 4, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 9, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 10, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 11, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 12, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 13, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 14, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 15, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220007516, 16, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 1, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 2, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 3, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 4, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 5, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 6, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 7, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 8, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 9, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 10, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 11, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 12, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 13, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 14, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 15, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110126007517, 16, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 1, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 2, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 3, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 4, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 5, 1, 11, 3, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 6, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 7, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708007518, 8, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 1, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 2, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 3, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 4, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 5, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 6, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 7, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 8, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 9, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208007519, 10, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 1, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 2, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 3, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 4, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 5, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 6, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 7, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 8, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 9, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 10, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 11, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 12, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 13, 188, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 14, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927007520, 15, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 1, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 2, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 3, 4, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 4, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 5, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 6, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 7, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 8, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 9, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 10, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 11, 132, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 12, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 13, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 14, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007521, 15, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 1, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 2, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 3, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 4, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 5, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 6, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050308007522, 7, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 1, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 2, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 3, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 4, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 5, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 6, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 7, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 8, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 9, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 10, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 11, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 12, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 13, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 14, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816007523, 15, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 1, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 2, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 3, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 4, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 5, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 6, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 7, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 8, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 9, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 10, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815007524, 11, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 1, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 2, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 3, 25, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 4, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 5, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 6, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 7, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417007525, 8, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 1, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 2, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 3, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 4, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 5, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 6, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 7, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 8, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030007526, 9, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 1, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 2, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 3, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 4, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 5, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 6, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 7, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 8, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 9, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 10, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 11, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 12, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 13, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 14, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008007527, 15, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 1, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 2, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 3, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 4, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 5, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 6, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 7, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 8, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 9, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 10, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 11, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 12, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902007528, 13, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313007529, 1, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313007529, 2, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313007529, 3, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313007529, 4, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313007529, 5, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 1, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 2, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 3, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 4, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 5, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 6, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 7, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 8, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 9, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 10, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 11, 18, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 12, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 13, 153, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216007530, 14, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 1, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 2, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 3, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 4, 109, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 5, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 6, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 7, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 8, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004007531, 9, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 1, 81, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 2, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 3, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 4, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 5, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 6, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 7, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 8, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 9, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 10, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 11, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 12, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 13, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 14, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222007532, 15, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 1, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 2, 77, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 3, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 4, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 5, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 6, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 7, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 8, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 9, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 10, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 11, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 12, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 13, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 14, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 15, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 16, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119007533, 17, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 1, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 2, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 3, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 4, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 5, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 6, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 7, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030820007534, 8, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 1, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 2, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 3, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 4, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 5, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 6, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 7, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 8, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 9, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509007535, 10, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 1, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 2, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 3, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 4, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 5, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 6, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 7, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 8, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 9, 76, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 10, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 11, 183, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 1, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 2, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 3, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 4, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 5, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 6, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713007908, 7, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 1, 16, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 2, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 3, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 4, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 5, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 6, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 7, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 8, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 9, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 10, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080426007909, 11, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 1, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 2, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 3, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 4, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 5, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 6, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 7, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 8, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518007910, 9, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007911, 1, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007911, 2, 66, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007911, 3, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007911, 4, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007911, 5, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 1, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 2, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 3, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 4, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 5, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 6, 54, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 7, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214007912, 8, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120007913, 1, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120007913, 2, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120007913, 3, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 1, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 2, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 3, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 4, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 5, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731007914, 6, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 1, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 2, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 3, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 4, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 5, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 6, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 7, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 8, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 9, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 10, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 11, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 12, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 13, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115007915, 14, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 1, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 2, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 3, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 4, 91, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 5, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 6, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 7, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 8, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 9, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 10, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 11, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 12, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526007916, 13, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 1, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 2, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 3, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 4, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 5, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 6, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 7, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040608007917, 8, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 1, 50, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 2, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 3, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 4, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 5, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 6, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 7, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 8, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 9, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 10, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 11, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 12, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113007918, 13, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 1, 178, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 2, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 3, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 4, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 5, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 6, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 7, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 8, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 9, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 10, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 11, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 12, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 13, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021007919, 14, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 1, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 2, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 3, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 4, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 5, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 6, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 7, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 8, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 9, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 10, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 11, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 12, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 13, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 14, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 15, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331007920, 16, 129, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 1, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 2, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 3, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 4, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 5, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 6, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 7, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 8, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 9, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 10, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 11, 110, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 12, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107007921, 13, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 1, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 2, 121, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 3, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 4, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 5, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 6, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 7, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 8, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 9, 124, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 10, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 11, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 12, 16, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 13, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 14, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411007922, 15, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 1, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 2, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 3, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 4, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 5, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 6, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 7, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 8, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 9, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 10, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007923, 11, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 1, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 2, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 3, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 4, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 5, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 6, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 7, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 8, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 9, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 10, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 11, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 12, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 13, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 14, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 15, 17, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510007924, 16, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 1, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 2, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 3, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 4, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 5, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 6, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 7, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 8, 145, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 9, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 10, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 11, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 12, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403007925, 13, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 1, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 2, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 3, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 4, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 5, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 6, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 7, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 8, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060626007926, 9, 161, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 1, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 2, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 3, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 4, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 5, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 6, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 7, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 8, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 9, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 10, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009007927, 11, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 1, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 2, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 3, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 4, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 5, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 6, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109007928, 7, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 1, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 2, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 3, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 4, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 5, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 6, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 7, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 8, 19, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 9, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 10, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 11, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 12, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628007929, 13, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607007930, 1, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607007930, 2, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607007930, 3, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607007930, 4, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 3, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 4, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 5, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 6, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 7, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 8, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 9, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 10, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 11, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 12, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 13, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 14, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 15, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 16, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008293, 17, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 1, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 2, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 3, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 4, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 5, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 6, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 7, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 8, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 9, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 10, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 11, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 12, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 13, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216008294, 14, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 1, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 2, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 3, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 4, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 5, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 6, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 7, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 8, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 9, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 10, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 11, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 12, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 13, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 14, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 15, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 16, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405008295, 17, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 1, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 2, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 3, 152, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 4, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 5, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928008296, 6, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 1, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 2, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 3, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 4, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 5, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 6, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 7, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005008297, 8, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 1, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 2, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 3, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 4, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 5, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 6, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 7, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 8, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 9, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 10, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 11, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 12, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 13, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100416008298, 14, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 1, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 2, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 3, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 4, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 5, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 6, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 7, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 8, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803008299, 9, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 1, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 2, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 3, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 4, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 5, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 6, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 7, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 8, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 9, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 10, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 11, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 12, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 13, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 14, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 15, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218008300, 16, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 1, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 2, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 3, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 4, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 5, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 6, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 7, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 8, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729008301, 9, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 1, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 2, 16, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 3, 111, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 4, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 5, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 6, 70, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 7, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 8, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008302, 9, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 1, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 2, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 3, 1, 79, 3, 237);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 4, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 5, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 6, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 7, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 8, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 9, 9, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 10, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 11, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 12, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106008303, 13, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 1, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 2, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 3, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 4, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 5, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030111008304, 6, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 1, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 2, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 3, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 4, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 5, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 6, 54, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809008305, 7, 77, 81, 10, 810);
commit;
prompt 84000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 1, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 2, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 3, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 4, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 5, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 6, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 7, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 8, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 9, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 10, 24, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 11, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 12, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 13, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 14, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 15, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 16, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813008306, 17, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 1, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 2, 21, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 3, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 4, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 5, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 6, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625008307, 7, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 1, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 2, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 3, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 4, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 5, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012008308, 6, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 1, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 2, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 3, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 4, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 5, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 6, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 7, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 8, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 9, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 10, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 11, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 12, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024008309, 13, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 1, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 2, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 3, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 4, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 5, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 6, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 7, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 8, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 9, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 10, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 11, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 12, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 13, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 14, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 15, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 16, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425008310, 17, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008311, 1, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008311, 2, 12, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008311, 3, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802008311, 4, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 1, 192, 44, 18, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 2, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 3, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 4, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 5, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 6, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 7, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 8, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 9, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 10, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 11, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 12, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 13, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 14, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 15, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 16, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008312, 17, 135, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 1, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 2, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 3, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 4, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 5, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 6, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 7, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 8, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 9, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 10, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 11, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 12, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 13, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104008313, 14, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 1, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 2, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 5, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 6, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 7, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 8, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 9, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 10, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 11, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 12, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 13, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708007166, 14, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 1, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 2, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 3, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 4, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 5, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 6, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 7, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 8, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 9, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 10, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 11, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 12, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 13, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 14, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723007167, 15, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 1, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 2, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 3, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 4, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 5, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 6, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 7, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 8, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 9, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526007168, 10, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 1, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 2, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 3, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 4, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 5, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 6, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 7, 82, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 8, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 9, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 10, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 11, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 12, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 13, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 14, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507007169, 15, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 1, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 2, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 3, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 4, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 5, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 6, 165, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 7, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 8, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 9, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 10, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 11, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 12, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 13, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 14, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 15, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 16, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 17, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101007170, 18, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810007171, 1, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810007171, 2, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810007171, 3, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 1, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 2, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 3, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 4, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 5, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 6, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304007172, 7, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 1, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 2, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 3, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 4, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 5, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 6, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 7, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 8, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 9, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 10, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 11, 1, 1, 3, 3);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 12, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 13, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 14, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225007173, 15, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 1, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 2, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 3, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 4, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 5, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 6, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 7, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 8, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 9, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 10, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 11, 149, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 12, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 13, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 14, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926007174, 15, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 1, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 2, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 3, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 4, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 5, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030007175, 6, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007176, 1, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007176, 2, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007176, 3, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007176, 4, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614007176, 5, 118, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 1, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 2, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 3, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 4, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 5, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629007177, 6, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 1, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 2, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 3, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 4, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 5, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 6, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513007178, 7, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 1, 168, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 2, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 3, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 4, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 5, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 6, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 7, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 8, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 9, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 10, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 11, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 12, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 13, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 14, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130413007179, 15, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724007180, 1, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724007180, 2, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724007180, 3, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724007180, 4, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020724007180, 5, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 1, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 2, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 3, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 4, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 5, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 6, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 7, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725007181, 8, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 1, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 2, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 3, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 4, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 5, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 6, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 7, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 8, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 9, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 10, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 11, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 12, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 13, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 14, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 15, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113007182, 16, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 1, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 2, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 3, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 4, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 5, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 6, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 7, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 8, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 9, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 10, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 11, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 12, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 13, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 14, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 15, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130104007183, 16, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 1, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 2, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 3, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 4, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 5, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 6, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201007184, 7, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 1, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 2, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 3, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 4, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 5, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 6, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 7, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 8, 122, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 9, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 10, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 11, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 12, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 13, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 14, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 15, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 16, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 17, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 18, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302007185, 19, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 1, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 2, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 3, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 4, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 5, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806007186, 6, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 1, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 2, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 3, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 4, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 5, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 6, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 7, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 8, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 9, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 10, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222007187, 11, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107007188, 1, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107007188, 2, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107007188, 3, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107007188, 4, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080603007536, 12, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 1, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 2, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 3, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 4, 45, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 5, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 6, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 7, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 8, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820007537, 9, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613007538, 1, 109, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613007538, 2, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613007538, 3, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613007538, 4, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613007538, 5, 72, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 1, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 2, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 3, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 4, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 5, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 6, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 7, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 8, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 9, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 10, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 11, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 12, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 13, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 14, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725007539, 15, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 1, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 2, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 3, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 4, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 5, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 6, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 7, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 8, 113, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 9, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 10, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 11, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403007540, 12, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 1, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 2, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 3, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 4, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 5, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331007541, 6, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414007542, 1, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414007542, 2, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414007542, 3, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 1, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 2, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 3, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 4, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 5, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 6, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 7, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 8, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 9, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 10, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 11, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 12, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 13, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 14, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 15, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 16, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401007543, 17, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 1, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 2, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 3, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 4, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 5, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 6, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 7, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 8, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 9, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 10, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 11, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526007544, 12, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 1, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 2, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 3, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 4, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 5, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 6, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 7, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 8, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 9, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 10, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 11, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831007545, 12, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 1, 97, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 2, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 3, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 4, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 5, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 6, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 7, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 8, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 9, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 10, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 11, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 12, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 13, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 14, 191, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 15, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927007546, 16, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 1, 68, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 2, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 3, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 4, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 5, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 6, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 7, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 8, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 9, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 10, 1, 38, 3, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 11, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 12, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 13, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 14, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312007547, 15, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007548, 1, 21, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007548, 2, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007548, 3, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007548, 4, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127007548, 5, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 1, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 2, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 3, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 4, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 5, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 6, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 7, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 8, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 9, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 10, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209007549, 11, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 1, 134, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 2, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 3, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 4, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 5, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 6, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 7, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 8, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 9, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 10, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 11, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 12, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813007550, 13, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 1, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 2, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 3, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 4, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 5, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031007007551, 6, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521007552, 1, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521007552, 2, 36, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521007552, 3, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521007552, 4, 20, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521007552, 5, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 1, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 2, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 3, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 4, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 5, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 6, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 7, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 8, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 9, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 10, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605007553, 11, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 1, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 2, 135, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 3, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 4, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 5, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108007554, 6, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 1, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 2, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 3, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 4, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 5, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 6, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912007555, 7, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201007556, 1, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201007556, 2, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201007556, 3, 132, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201007556, 4, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201007556, 5, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 1, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 2, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 3, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 4, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 5, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 6, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701007557, 7, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 1, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 2, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 3, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 4, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 5, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 6, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 7, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 8, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 9, 144, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705007558, 10, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007559, 1, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007559, 2, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007559, 3, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007559, 4, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030729007559, 5, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 1, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 2, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 3, 47, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 4, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 5, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030709007560, 6, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903007561, 1, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903007561, 2, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903007561, 3, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 1, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 2, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 3, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 4, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 5, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 6, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 7, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 8, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 9, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 10, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208007562, 11, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807007563, 1, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807007563, 2, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807007563, 3, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807007563, 4, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807007563, 5, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607007930, 5, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 1, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 2, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 3, 89, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 4, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 5, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 6, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 7, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 8, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 9, 111, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525007931, 10, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223007932, 1, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223007932, 2, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223007932, 3, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223007932, 4, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223007932, 5, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 1, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 2, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 3, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 4, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 5, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 6, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 7, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 8, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 9, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 10, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 11, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116007933, 12, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 1, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 2, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 3, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 4, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 5, 73, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 6, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405007934, 7, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 1, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 2, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 3, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 4, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 5, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 6, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 7, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 8, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 9, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 10, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 11, 163, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 12, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 13, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 14, 17, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 15, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 16, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129007935, 17, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 1, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 2, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 3, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 4, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 5, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 6, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 7, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 8, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 9, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 10, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 11, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 12, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823007936, 13, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 1, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 2, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 3, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 4, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 5, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 6, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 7, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 8, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 9, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 10, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 11, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 12, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 13, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007937, 14, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 1, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 2, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 3, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 4, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 5, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 6, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 7, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 8, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 9, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 10, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 11, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 12, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 13, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 14, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 15, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 16, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829007938, 17, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 1, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 2, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 3, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 4, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 5, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 6, 36, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007939, 7, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 1, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 2, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 3, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 4, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 5, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 6, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 7, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 8, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 9, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 10, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 11, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 12, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 13, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 14, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116007940, 15, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 1, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 2, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 3, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 4, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 5, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309007941, 6, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 1, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 2, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 3, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 4, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 5, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 6, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 7, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 8, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070617007942, 9, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 1, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 2, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 3, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 4, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 5, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 6, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 7, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 8, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 9, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 10, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518007943, 11, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 1, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 2, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 3, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 4, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 5, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 6, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 7, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 8, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816007944, 9, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 1, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 2, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 3, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 4, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 5, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 6, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324007945, 7, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 1, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 2, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 3, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 4, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 5, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 6, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 7, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 8, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 9, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 10, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221007946, 11, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112007947, 1, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112007947, 2, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112007947, 3, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000112007947, 4, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 1, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 2, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 3, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 4, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 5, 162, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 6, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 7, 25, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 8, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 9, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 10, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 11, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 12, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 13, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 14, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505007948, 15, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007949, 1, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007949, 2, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007949, 3, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007949, 4, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510007949, 5, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 1, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 2, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 3, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 4, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 5, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 6, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 7, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 8, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529007950, 9, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 1, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 2, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 3, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 4, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 5, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 6, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419007951, 7, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 1, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 2, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 3, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 4, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 5, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 6, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 7, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 8, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 9, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 10, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 11, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 12, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 13, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 14, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 15, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 16, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 17, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407007952, 18, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 1, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 2, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 3, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 4, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 5, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 6, 44, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 7, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 8, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 9, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 3, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 4, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 5, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 6, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 7, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 8, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 9, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 10, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 11, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 12, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 13, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 14, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 15, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008314, 16, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 1, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 2, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 3, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 4, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 5, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 6, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 7, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 8, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 9, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 10, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126008315, 11, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 1, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 2, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 3, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 4, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 5, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 6, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 7, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 8, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 9, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 10, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 11, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 12, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008316, 13, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 1, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 2, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 3, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 4, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 5, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203008317, 6, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 1, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 2, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 3, 14, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 4, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 5, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 6, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 7, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 8, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 9, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 10, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 11, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 12, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 13, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 14, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409008318, 15, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 1, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 2, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 3, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 4, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 5, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 6, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 7, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 8, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 9, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 10, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529008319, 11, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 1, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 2, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 3, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 4, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 5, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 6, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 7, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 8, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 9, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416008320, 10, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 1, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 2, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 3, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 4, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 5, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 6, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 7, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 8, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 9, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 10, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 11, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 12, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100227008321, 13, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127008322, 1, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127008322, 2, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127008322, 3, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127008322, 4, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127008322, 5, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 1, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 2, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 3, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 4, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 5, 31, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 6, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 7, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 8, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 9, 13, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 10, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 11, 107, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 12, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 13, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823008323, 14, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 1, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 2, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 3, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 4, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 5, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 6, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024008324, 7, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 1, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 2, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 3, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 4, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 5, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 6, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 7, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421008325, 8, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 1, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 2, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 3, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 4, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 5, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 6, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 7, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 8, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 9, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 10, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 11, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 12, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 13, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719008326, 14, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 1, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 2, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 3, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 4, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 5, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 6, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 7, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 8, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 9, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 10, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 11, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 12, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 13, 87, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008327, 14, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008328, 1, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008328, 2, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008328, 3, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008328, 4, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000924008328, 5, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 1, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 2, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 3, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 4, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 5, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 6, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328008329, 7, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 1, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 2, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 3, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 4, 186, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 5, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 6, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 7, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 8, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 9, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 10, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 11, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 12, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729008330, 13, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 1, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 2, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 3, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 4, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 5, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 6, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 7, 167, 76, 14, 1064);
commit;
prompt 85000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 8, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 9, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228008331, 10, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 1, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 2, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 3, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 4, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 5, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 6, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 7, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 8, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 9, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 10, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 11, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 12, 132, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 13, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 14, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 15, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110008332, 16, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 1, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 2, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 3, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 4, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 5, 9, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 6, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 7, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 8, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 9, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 10, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 11, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 12, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 13, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912008333, 14, 177, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 1, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 2, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 3, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 4, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 5, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020606008334, 6, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 1, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 2, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 3, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 4, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 5, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 6, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030904008335, 7, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 1, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 2, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 3, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 4, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 5, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 6, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107007188, 5, 63, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712007189, 1, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712007189, 2, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712007189, 3, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712007189, 4, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712007189, 5, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 1, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 2, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 3, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 4, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 5, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 6, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 7, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 8, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204007190, 9, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 1, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 2, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 3, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 4, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 5, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 6, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 7, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 8, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 9, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 10, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 11, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 12, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 13, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090220007191, 14, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 1, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 2, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 3, 171, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 4, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 5, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 6, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 7, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 8, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050718007192, 9, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 1, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 2, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 3, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 4, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 5, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421007193, 6, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 1, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 2, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 3, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 4, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 5, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 6, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 7, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 8, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 9, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 10, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 11, 79, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 12, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 13, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 14, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110320007194, 15, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 1, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 2, 105, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 3, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 4, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 5, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 6, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 7, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 8, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 9, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 10, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 11, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 12, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 13, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 14, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 15, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 16, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924007195, 17, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 1, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 2, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 3, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 4, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 5, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 6, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 7, 49, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 8, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 9, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207007196, 10, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 1, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 2, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 3, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 4, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 5, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 6, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 7, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 8, 24, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 9, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210007197, 10, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 1, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 2, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 3, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 4, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 5, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 6, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 7, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 8, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 9, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 10, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 11, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 12, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707007198, 13, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 1, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 2, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 3, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 4, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 5, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 6, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 7, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 8, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 9, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403007199, 10, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 1, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 2, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 3, 183, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 4, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 5, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 6, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 7, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 8, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 9, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 10, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 11, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 12, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081002007200, 13, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 1, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 2, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 3, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 4, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 5, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 6, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 7, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 8, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 9, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106007201, 10, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 1, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 2, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 3, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 4, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 5, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 6, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 7, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 8, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031007202, 9, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 1, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 2, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 3, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 4, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 5, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 6, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 7, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 8, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 9, 161, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018007203, 10, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 1, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 2, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 3, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 4, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 5, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 6, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 7, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 8, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 9, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 10, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 11, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 12, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 13, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 14, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 15, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 16, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 17, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312007204, 18, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 1, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 2, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 3, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 4, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 5, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 6, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 7, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 8, 127, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 9, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 10, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720007205, 11, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 1, 131, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 2, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 3, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 4, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 5, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 6, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 7, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 8, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 9, 1, 21, 3, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 10, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 11, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 12, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 13, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926007206, 14, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 1, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 2, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 3, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 4, 44, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 5, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007207, 6, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 1, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 2, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 3, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 4, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 5, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 6, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 7, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 8, 6, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 9, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 10, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 11, 18, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 12, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 13, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 14, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 15, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130201007208, 16, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007209, 1, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007209, 2, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007209, 3, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000531007209, 4, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 1, 137, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 2, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 3, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 4, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 5, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 6, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812007210, 7, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 1, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 2, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 1, 134, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 2, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 3, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 4, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 5, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 6, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002007564, 7, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 1, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 2, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 3, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 4, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 5, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 6, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041017007565, 7, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 1, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 2, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 3, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 4, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 5, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 6, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 7, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 8, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 9, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 10, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 11, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 12, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 13, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520007566, 14, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 1, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 2, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 3, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 4, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 5, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 6, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 7, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 8, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 9, 56, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 10, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411007567, 11, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426007568, 1, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426007568, 2, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426007568, 3, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426007568, 4, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 1, 192, 49, 18, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 2, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 3, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 4, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 5, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 6, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 7, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 8, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 9, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321007569, 10, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 1, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 2, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 3, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 4, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 5, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 6, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 7, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 8, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 9, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 10, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 11, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 12, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 13, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 14, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114007570, 15, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 1, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 2, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 3, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 4, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 5, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 6, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 7, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 8, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 9, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 10, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 11, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 12, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 13, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 14, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 15, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 16, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 17, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123007571, 18, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 1, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 2, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 3, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 4, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 5, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 6, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 7, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 8, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509007572, 9, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 1, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 2, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 3, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 4, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 5, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 6, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 7, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 8, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926007573, 9, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 1, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 2, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 3, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 4, 135, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 5, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 6, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 7, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 8, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 9, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 10, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 11, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508007574, 12, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 1, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 2, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 3, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 4, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 5, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 6, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 7, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110007575, 8, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 1, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 2, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 3, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 4, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 5, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 6, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 7, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 8, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 9, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 10, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 11, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 12, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 13, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 14, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 15, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130131007576, 16, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 1, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 2, 49, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 3, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 4, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 5, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 6, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 7, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041116007577, 8, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 1, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 2, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 3, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 4, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 5, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707007578, 6, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 1, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 2, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 3, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 4, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 5, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 6, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 7, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 8, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 9, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061030007579, 10, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404007580, 1, 105, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404007580, 2, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404007580, 3, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404007580, 4, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404007580, 5, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 1, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 2, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 3, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 4, 16, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 5, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 6, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 7, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 8, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 9, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 10, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 11, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 12, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 13, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 14, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 15, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 16, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 17, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507007581, 18, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 1, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 2, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 3, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 4, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 5, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 6, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 7, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 8, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 9, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 10, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 11, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 12, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 13, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 14, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 15, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 16, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 17, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 18, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430007582, 19, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 1, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 2, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 3, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 4, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 5, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 6, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 7, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 8, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 9, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 10, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 11, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 12, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 13, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019007583, 14, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 1, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 2, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 3, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 4, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 5, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604007584, 6, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 1, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 2, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 3, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 4, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 5, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 6, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 7, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 8, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 9, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 10, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 11, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 12, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815007585, 13, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 10, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 11, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208007953, 12, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 1, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 2, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 3, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 4, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 5, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 6, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 7, 122, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 8, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722007954, 9, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 1, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 2, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 3, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 4, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 5, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 6, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 7, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 8, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 9, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 10, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 11, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 12, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 13, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120315007955, 14, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 1, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 2, 180, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 3, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 4, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 5, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 6, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 7, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 8, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 9, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 10, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 11, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 12, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729007956, 13, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713007957, 1, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713007957, 2, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713007957, 3, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713007957, 4, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713007957, 5, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 1, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 2, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 3, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 4, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 5, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 6, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 7, 183, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 8, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726007958, 9, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918007959, 1, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918007959, 2, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 1, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 2, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 3, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 4, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 5, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 6, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 7, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 8, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 9, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 10, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 11, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 12, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 13, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 14, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 15, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 16, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007960, 17, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 1, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 2, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 3, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 4, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 5, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 6, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 7, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 8, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 9, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 10, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 11, 172, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 12, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 13, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 14, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 15, 192, 9, 18, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627007961, 16, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308007962, 1, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308007962, 2, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308007962, 3, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308007962, 4, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 1, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 2, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 3, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 4, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 5, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 6, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408007963, 7, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 1, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 2, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 3, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 4, 74, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 5, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 6, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 7, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 8, 21, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 9, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 10, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 11, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 12, 51, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 13, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 14, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 15, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121120007964, 16, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005007965, 1, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005007965, 2, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005007965, 3, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005007965, 4, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 1, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 2, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 3, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 4, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 5, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 6, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 7, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 8, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 9, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 10, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 11, 192, 43, 18, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626007966, 12, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 1, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 2, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 3, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 4, 157, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 5, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 6, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 7, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 8, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 9, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 10, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 11, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 12, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 13, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 14, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307007967, 15, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 1, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 2, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 3, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 4, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 5, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 6, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 7, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 8, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 9, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 10, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 11, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 12, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 13, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110326007968, 14, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 1, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 2, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 3, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 4, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 5, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 6, 1, 38, 3, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 7, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 8, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102007969, 9, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118007970, 1, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118007970, 2, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118007970, 3, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118007970, 4, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 1, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 2, 39, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 3, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 4, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 5, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 6, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 7, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 8, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 9, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 10, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 11, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 12, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 13, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 14, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 15, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 16, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115007971, 17, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 1, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 2, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 3, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 4, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 5, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621007972, 6, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 1, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 2, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 3, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 4, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 5, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 6, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 7, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 8, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 9, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 10, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 11, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 12, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 13, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 14, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 15, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215007973, 16, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 1, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 2, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 3, 186, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 4, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 5, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 6, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 7, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 8, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 9, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412007974, 10, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 1, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 2, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 3, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 4, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 5, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 6, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 7, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 8, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 9, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 10, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022007975, 11, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 1, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 2, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 3, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 4, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 5, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 6, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 7, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 8, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519008336, 9, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 1, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 2, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 3, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 4, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 5, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 6, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 7, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 8, 86, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207008337, 9, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 1, 184, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 2, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 3, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 4, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 5, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 6, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 7, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 8, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 9, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 10, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 11, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 12, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 13, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 14, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514008338, 15, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 1, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 2, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 3, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 4, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 5, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 6, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 7, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 8, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 9, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 10, 9, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 11, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 12, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601008339, 13, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 1, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 2, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 3, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 4, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 5, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325008340, 6, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421008341, 1, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421008341, 2, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421008341, 3, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421008341, 4, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 1, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 2, 147, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 3, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 4, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 5, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 6, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 7, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 8, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721008342, 9, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008343, 1, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008343, 2, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008343, 3, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008343, 4, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010405008343, 5, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 1, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 2, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 3, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 4, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 5, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 6, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 7, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 8, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 9, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115008344, 10, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 1, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 2, 41, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 3, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 4, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 5, 9, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 6, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 7, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 8, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 9, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 10, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 11, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 12, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 13, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 14, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 15, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130810008345, 16, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 1, 155, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 2, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 3, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 4, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 5, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 6, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 7, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 8, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 9, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 10, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 11, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 12, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110503008346, 13, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 1, 104, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 2, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 3, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 4, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 5, 125, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 6, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 7, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 8, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 9, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 10, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 11, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 12, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128008347, 13, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 1, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 2, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 3, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 4, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 5, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 6, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 7, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 8, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 9, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 10, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 11, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 12, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719008348, 13, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 1, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 2, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 3, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 4, 190, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 5, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 6, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 7, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 8, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314008349, 9, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 1, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 2, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 3, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 4, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 5, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 6, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 7, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 8, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 9, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 10, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 11, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 12, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403008350, 13, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 1, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 2, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 3, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 4, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 5, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 6, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 7, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 8, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 9, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 10, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022008351, 11, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 1, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 2, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 3, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 4, 157, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 5, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 6, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 7, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 8, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 9, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 10, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 11, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 12, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 13, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 14, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 15, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 16, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707008352, 17, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 1, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 2, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 3, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 4, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 5, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 6, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 7, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040723008353, 8, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203008354, 1, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203008354, 2, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203008354, 3, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021203008354, 4, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018008355, 1, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018008355, 2, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018008355, 3, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 1, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 2, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 3, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 4, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 5, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 6, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428008356, 7, 70, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 1, 94, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 2, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 3, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 4, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 5, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 6, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 7, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410008357, 8, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 1, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 2, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 3, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 4, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 5, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 6, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 7, 158, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 8, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209008358, 9, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410008359, 1, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410008359, 2, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410008359, 3, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410008359, 4, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 1, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 2, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 3, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 4, 89, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 5, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 6, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 7, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 8, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 9, 155, 49, 12, 588);
commit;
prompt 86000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 10, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 11, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070603008360, 12, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 1, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 2, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 3, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 4, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 5, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 3, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 4, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 5, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 6, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 7, 162, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 8, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 9, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 10, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 11, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 12, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 13, 61, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812007211, 14, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 1, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 2, 76, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 3, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 4, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 5, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 6, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 7, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 8, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 9, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 10, 118, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 11, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 12, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 13, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 14, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 15, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 16, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002007212, 17, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 1, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 2, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 3, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 4, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 5, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 6, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 7, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 8, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 9, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 10, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 11, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524007213, 12, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 1, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 2, 130, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 3, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 4, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 5, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 6, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 7, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 8, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703007214, 9, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 1, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 2, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 3, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 4, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 5, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 6, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 7, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 8, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 9, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601007215, 10, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313007216, 1, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313007216, 2, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313007216, 3, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313007216, 4, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 1, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 2, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 3, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 4, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 5, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 6, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 7, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302007217, 8, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 1, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 2, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 3, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 4, 179, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 5, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 6, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 7, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 8, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 9, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 10, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 11, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 12, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107007218, 13, 84, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 1, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 2, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 3, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 4, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 5, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 6, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 7, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 8, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 9, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 10, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 11, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 12, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 13, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009007219, 14, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 1, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 2, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 3, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 4, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 5, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 6, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 7, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315007220, 8, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224007221, 1, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224007221, 2, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224007221, 3, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224007221, 4, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914007222, 1, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914007222, 2, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914007222, 3, 153, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914007222, 4, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914007222, 5, 117, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 1, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 2, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 3, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 4, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 5, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 6, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 7, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715007223, 8, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 1, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 2, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 3, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 4, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 5, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 6, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 7, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 8, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 9, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 10, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 11, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 12, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 13, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 14, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 15, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 16, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527007224, 17, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 1, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 2, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 3, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 4, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 5, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 6, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 7, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 8, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 9, 132, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 10, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 11, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 12, 99, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 13, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090518007225, 14, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 1, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 2, 123, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 3, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 4, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 5, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 6, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926007226, 7, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 1, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 2, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 3, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 4, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 5, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114007227, 6, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618007228, 1, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618007228, 2, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 1, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 2, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 3, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 4, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 5, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 6, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 7, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 8, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 9, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 10, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 11, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 12, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106007229, 13, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 1, 7, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 2, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 3, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 4, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 5, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 6, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 7, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 8, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 9, 169, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025007230, 10, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 1, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 2, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 3, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 4, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 5, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 6, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 7, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 8, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 9, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 10, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 11, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 12, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 13, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020007231, 14, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 1, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 2, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 3, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 4, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 5, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 6, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 7, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 8, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 9, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 10, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902007232, 11, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 1, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 2, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 3, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 4, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 5, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028007233, 6, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 1, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 2, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 3, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 4, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 5, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 6, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 7, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 8, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 9, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515007234, 10, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 1, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 2, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 3, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 4, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 5, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 1, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 2, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 3, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 4, 118, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 5, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 6, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 7, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 8, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 9, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 10, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 11, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 12, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 13, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 14, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615007586, 15, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 1, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 2, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 3, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 4, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 5, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 6, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415007587, 7, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 1, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 2, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 3, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 4, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 5, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 6, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 7, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 8, 189, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212007588, 9, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 1, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 2, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 3, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 4, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 5, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 6, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 7, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 8, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 9, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 10, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312007589, 11, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 1, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 2, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 3, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 4, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 5, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 6, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 7, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 8, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 9, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 10, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227007590, 11, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 1, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 2, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 3, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 4, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 5, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 6, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 7, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 8, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 9, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 10, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 11, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100504007591, 12, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 1, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 2, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 3, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 4, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 5, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 6, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 7, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 8, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 9, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 10, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 11, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 12, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 13, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 14, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 15, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 16, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801007592, 17, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304007593, 1, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304007593, 2, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304007593, 3, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304007593, 4, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 1, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 2, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 3, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 4, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 5, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 6, 155, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 7, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 8, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 9, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 10, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 11, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 12, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418007594, 13, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007595, 1, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007595, 2, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007595, 3, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007595, 4, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501007595, 5, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924007596, 1, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924007596, 2, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924007596, 3, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924007596, 4, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 1, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 2, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 3, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 4, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 5, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 6, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 7, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 8, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 9, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 10, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 11, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 12, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 13, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 14, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 15, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 16, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 17, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502007597, 18, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 1, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 2, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 3, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 4, 121, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 5, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 6, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 7, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 8, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224007598, 9, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830007599, 1, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830007599, 2, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830007599, 3, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830007599, 4, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830007599, 5, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 1, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 2, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 3, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 4, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 5, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107007600, 6, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 1, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 2, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 3, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 4, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 5, 167, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 6, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514007601, 7, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219007602, 1, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219007602, 2, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219007602, 3, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219007602, 4, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219007602, 5, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212007603, 1, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212007603, 2, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212007603, 3, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212007603, 4, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 1, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 2, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 3, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 4, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 5, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 6, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 7, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 8, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 9, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 10, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 11, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 12, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 13, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110916007604, 14, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 1, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 2, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 3, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 4, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 5, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 6, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041004007605, 7, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 1, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 2, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 3, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 4, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 5, 156, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 6, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 7, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 8, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 9, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 10, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 11, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 12, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 13, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 14, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 15, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 16, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314007606, 17, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 1, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 2, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 3, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 4, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 5, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 6, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 7, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 8, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 9, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 10, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 11, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 12, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 13, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 14, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 15, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222007607, 16, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720007608, 1, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720007608, 2, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720007608, 3, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720007608, 4, 164, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720007608, 5, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 1, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 2, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 3, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 4, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 5, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729007609, 6, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 1, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 2, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 3, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 4, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 5, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 6, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 7, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 8, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 9, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 10, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 11, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 12, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 7, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 8, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 9, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 10, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 11, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 12, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 13, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 14, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 15, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024007976, 16, 103, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 1, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 2, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 3, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 4, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 5, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 6, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 7, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 8, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 9, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 10, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303007977, 11, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007978, 1, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007978, 2, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007978, 3, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007978, 4, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021007978, 5, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007979, 1, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007979, 2, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007979, 3, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007979, 4, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109007979, 5, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811007980, 1, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811007980, 2, 19, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811007980, 3, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 1, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 2, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 3, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 4, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 5, 48, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 6, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 7, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 8, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 9, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116007981, 10, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 1, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 2, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 3, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 4, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 5, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 6, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 7, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 8, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 9, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 10, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 11, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 12, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513007982, 13, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 1, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 2, 7, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 3, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 4, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 5, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114007983, 6, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 1, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 2, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 3, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 4, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 5, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 6, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 7, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 8, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 9, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 10, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 11, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 12, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 13, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 14, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706007984, 15, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 1, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 2, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 3, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 4, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 5, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 6, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 7, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 8, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 9, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 10, 55, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 11, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 12, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 13, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830007985, 14, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 1, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 2, 128, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 3, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 4, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 5, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 6, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 7, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 8, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 9, 71, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 10, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 11, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 12, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 13, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 14, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029007986, 15, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 1, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 2, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 3, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 4, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 5, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517007987, 6, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 1, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 2, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 3, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 4, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 5, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 6, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 7, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 8, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 9, 177, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 10, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 11, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 12, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 13, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 14, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 15, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312007988, 16, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 1, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 2, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 3, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 4, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 5, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 6, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 7, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 8, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 9, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 10, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 11, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080425007989, 12, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 1, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 2, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 3, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 4, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 5, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 6, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 7, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 8, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 9, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 10, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 11, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 12, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914007990, 13, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 1, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 2, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 3, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 4, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 5, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 6, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 7, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 8, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 9, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 10, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131007991, 11, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 1, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 2, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 3, 129, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 4, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 5, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 6, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128007992, 7, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 1, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 2, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 3, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 4, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 5, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 6, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 7, 48, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 8, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 9, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 10, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 11, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 12, 181, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 13, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910007993, 14, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 1, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 2, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 3, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 4, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 5, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 6, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 7, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114007994, 8, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220007995, 1, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220007995, 2, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220007995, 3, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220007995, 4, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220007995, 5, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 1, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 2, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 3, 111, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 4, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 5, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 6, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 7, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 8, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 9, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520007996, 10, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 1, 134, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 2, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 3, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 4, 29, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 5, 78, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 6, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 7, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 8, 153, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 9, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 10, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 11, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912007997, 12, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 1, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 2, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 3, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 4, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 5, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 6, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 7, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927007998, 8, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 1, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 2, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 3, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 4, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 5, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325007999, 6, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 1, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 2, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 3, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019008000, 4, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 6, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128008361, 7, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 1, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 2, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 3, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 4, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 5, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 6, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 7, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 8, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 9, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 10, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 11, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 12, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 13, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508008362, 14, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 1, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 2, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 3, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 4, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 5, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 6, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 7, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 8, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523008363, 9, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 1, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 2, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 3, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 4, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 5, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721008364, 6, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008365, 1, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008365, 2, 166, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008365, 3, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008365, 4, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 1, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 2, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 3, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 4, 104, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 5, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006008366, 6, 52, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 1, 145, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 2, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 3, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 4, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 5, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 6, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 7, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 8, 183, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 9, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 10, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 11, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 12, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 13, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 14, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 15, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 16, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505008367, 17, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422008368, 1, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422008368, 2, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 1, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 2, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 3, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 4, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 5, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 6, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 7, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 8, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 9, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 10, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210008369, 11, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 1, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 2, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 3, 165, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 4, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 5, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 6, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 7, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 8, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 9, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 10, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602008370, 11, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 1, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 2, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 3, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 4, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 5, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 6, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 7, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 8, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 9, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 10, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 11, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 12, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 13, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 14, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 15, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 16, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917008371, 17, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 1, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 2, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 3, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 4, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 5, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 6, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030506008372, 7, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 1, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 2, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 3, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 4, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 5, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 6, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031030008373, 7, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 1, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 2, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 3, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 4, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 5, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 6, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 7, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 8, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 9, 114, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 10, 159, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 11, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 12, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 13, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 14, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 15, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223008374, 16, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 1, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 2, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 3, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 4, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 5, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 6, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 7, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 8, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 9, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 10, 109, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 11, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 12, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 13, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 14, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 15, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201008375, 16, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008376, 1, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008376, 2, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008376, 3, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402008376, 4, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 1, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 2, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 3, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 4, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 5, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 6, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 7, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 8, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 9, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 10, 148, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906008377, 11, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 1, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 2, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 3, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 4, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 5, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709008378, 6, 41, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 1, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 2, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 3, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 4, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 6, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 7, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 8, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918008379, 9, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 1, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 2, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 3, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 4, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 5, 139, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 6, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 7, 68, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 8, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 9, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 10, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 11, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 12, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 13, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 14, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 15, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 16, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130614008380, 17, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 1, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 2, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 3, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 4, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 5, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 6, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 7, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 8, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 9, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 10, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 11, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901008381, 12, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 1, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 2, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 3, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 4, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 5, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 6, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 7, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040918008382, 8, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 1, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 2, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 3, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 4, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 5, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 6, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 7, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 8, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408008383, 9, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 1, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 2, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 3, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 4, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 5, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 6, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 7, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 8, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 9, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 10, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 11, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 12, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 13, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314008384, 14, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 1, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 2, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008385, 3, 28, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 6, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 7, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 8, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 9, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 10, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 11, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 12, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710007235, 13, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 1, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 2, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 3, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 4, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 5, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 6, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040824007236, 7, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 1, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 2, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 3, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 4, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 5, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 6, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 7, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 8, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 9, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 10, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 11, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731007237, 12, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921007238, 1, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921007238, 2, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921007238, 3, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921007238, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 1, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 2, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 3, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 4, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 5, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 6, 165, 81, 12, 972);
commit;
prompt 87000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 7, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 8, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 9, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 10, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401007239, 11, 184, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 1, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 2, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 3, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 4, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 5, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 6, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 7, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 8, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 9, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 10, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 11, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 12, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 13, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111227007240, 14, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 1, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 2, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 3, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 4, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 5, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 6, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 7, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 8, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 9, 187, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 10, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 11, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 12, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 13, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 14, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019007241, 15, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 1, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 2, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 3, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 4, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 5, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 6, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020623007242, 7, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 1, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 2, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 3, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 4, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 5, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 6, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120007243, 7, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 1, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 2, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 3, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 4, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 5, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 6, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 7, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 8, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 9, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 10, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 11, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 12, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006007244, 13, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 1, 78, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 2, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 3, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 4, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 5, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 6, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 7, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 8, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 9, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 10, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 11, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 12, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 13, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 14, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110007245, 15, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007246, 1, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007246, 2, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007246, 3, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130007247, 1, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130007247, 2, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130007247, 3, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 1, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 2, 9, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 3, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 4, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 5, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 6, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 7, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 8, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 9, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 10, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710007248, 11, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 1, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 2, 180, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 3, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 4, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 5, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 6, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 7, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 8, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 9, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 10, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 11, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002007249, 12, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 1, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 2, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 3, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 4, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 5, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 6, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030715007250, 7, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 1, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 2, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 3, 73, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 4, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 5, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 6, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 7, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 8, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422007251, 9, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 1, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 2, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 3, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 4, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 5, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 6, 71, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 7, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 8, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113007252, 9, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 1, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 2, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 3, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 4, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 5, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 6, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 7, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 8, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 9, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 10, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303007253, 11, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 1, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 2, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 3, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 4, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 5, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 6, 184, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 7, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 8, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 9, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 10, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 11, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513007254, 12, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929007255, 1, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929007255, 2, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929007255, 3, 140, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929007255, 4, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 1, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 2, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 3, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 4, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 5, 1, 80, 3, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 6, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 7, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 8, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 9, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 10, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 11, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 12, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623007256, 13, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815007257, 1, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815007257, 2, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815007257, 3, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815007257, 4, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815007257, 5, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 1, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 2, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 3, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 4, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 5, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 6, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 7, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 8, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 9, 167, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 10, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027007258, 11, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 1, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 2, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 3, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 4, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 5, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 6, 184, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 7, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 8, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019007259, 9, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 1, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 2, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 3, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 4, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 5, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822007260, 6, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111001007261, 1, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 13, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 14, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113007610, 15, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 1, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 2, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 3, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 4, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 5, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 6, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 7, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022007611, 8, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921007612, 1, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921007612, 2, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921007612, 3, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921007612, 4, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 1, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 2, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 3, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 4, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 5, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 6, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 7, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030723007613, 8, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 1, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 2, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 3, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 4, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 5, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 6, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 7, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 8, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 9, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 10, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 11, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 12, 16, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 13, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 14, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120617007614, 15, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 1, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 2, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 3, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 4, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 5, 8, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 6, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 7, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 8, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 9, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 10, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 11, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217007615, 12, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 1, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 2, 101, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 3, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 4, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 5, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 6, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 7, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 8, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 9, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706007616, 10, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 1, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 2, 187, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 3, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 4, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 5, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 6, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 7, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 8, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 9, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721007617, 10, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 1, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 2, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 3, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 4, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 5, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 6, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712007618, 7, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007619, 1, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007619, 2, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001020007619, 3, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 1, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 2, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 3, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 4, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 5, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 6, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 7, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 8, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 9, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304007620, 10, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 1, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 2, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 3, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 4, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 5, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 6, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 7, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916007621, 8, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 1, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 2, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 3, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 4, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 5, 97, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 6, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 7, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 8, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 9, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 10, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 11, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 12, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 13, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 14, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210007622, 15, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 1, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 2, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 3, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 4, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 5, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227007623, 6, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 1, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 2, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 3, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 4, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 5, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 6, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 7, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 8, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 9, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 10, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 11, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 12, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901007624, 13, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 1, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 2, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 3, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 4, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 5, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 6, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 7, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 8, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 9, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 10, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 11, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503007625, 12, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 1, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 2, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 3, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 4, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 5, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 6, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 7, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 8, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 9, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 10, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316007626, 11, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101007627, 1, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101007627, 2, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101007627, 3, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101007627, 4, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101007627, 5, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 1, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 2, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 3, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 4, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 5, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 6, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 7, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 8, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 9, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 10, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 11, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 12, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 13, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 14, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 15, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 16, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 17, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318007628, 18, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 1, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 2, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 3, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 4, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 5, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 6, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 7, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 8, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 9, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 10, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 11, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 12, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 13, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816007629, 14, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 1, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 2, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 3, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 4, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 5, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326007630, 6, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 1, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 2, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 3, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 4, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 5, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703007631, 6, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 1, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 2, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 3, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 4, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 5, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 6, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 7, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 8, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 9, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080704007632, 10, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 1, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 2, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 3, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 4, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 5, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 6, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 7, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202007633, 8, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007634, 1, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007634, 2, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007634, 3, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921007634, 4, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 1, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 2, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 3, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 4, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 5, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 6, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 7, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 8, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 9, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 10, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 11, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 12, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427007635, 13, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 12, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 13, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 1, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 2, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 3, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 4, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 5, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 6, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 7, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 8, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 9, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 10, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 11, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 12, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 13, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030009137, 14, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 1, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 2, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 3, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 4, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 5, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 6, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 7, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 8, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 9, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 10, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 11, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630009138, 12, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 1, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 2, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 3, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 4, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 5, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 6, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 7, 89, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 8, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 9, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 10, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 11, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307009139, 12, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 1, 46, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 2, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 3, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 4, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 5, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 6, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 7, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 8, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 9, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 10, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 11, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 12, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 13, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 14, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 15, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107009140, 16, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209009141, 1, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209009141, 2, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209009141, 3, 134, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209009141, 4, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 1, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 2, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 3, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 4, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 5, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 6, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 7, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 8, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 9, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 10, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 11, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827009142, 12, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204009143, 1, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204009143, 2, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204009143, 3, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204009143, 4, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 1, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 2, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 3, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 4, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 5, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009144, 6, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 1, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 2, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 3, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 4, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 5, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 6, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 7, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 8, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 9, 181, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 10, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 11, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 12, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111216009145, 13, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 1, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 2, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 3, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 4, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 5, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 6, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 7, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 8, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 9, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 10, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 11, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 12, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826009146, 13, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 1, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 2, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 3, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 4, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 5, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 6, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 7, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 8, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 9, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 10, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 11, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 12, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 13, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 14, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314009147, 15, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010614009148, 1, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010614009148, 2, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010614009148, 3, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010614009148, 4, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010614009148, 5, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 1, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 2, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 3, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 4, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 5, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 6, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 7, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 8, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 9, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 10, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 11, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 12, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310009149, 13, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 1, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 2, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 3, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 4, 154, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 5, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 6, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 7, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 8, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 9, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 10, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 11, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 12, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324009150, 13, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 1, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 2, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 3, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 4, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 5, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 6, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 7, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 8, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 9, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 10, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 11, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 12, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908009151, 13, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 1, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 2, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 3, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 4, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 5, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 6, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 7, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 8, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 9, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720009152, 10, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 1, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 2, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 3, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 4, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 5, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 6, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223009153, 7, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 1, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 2, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 3, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 4, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 5, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 6, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 7, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 8, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 9, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 10, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 11, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 12, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 13, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 14, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009154, 15, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 1, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 2, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 3, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 4, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 5, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 6, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 7, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 8, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 9, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 10, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 11, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 12, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 13, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912009155, 14, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 1, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 2, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 3, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 4, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 6, 188, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 7, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 8, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 9, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 10, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 11, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 12, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306009156, 13, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215009157, 1, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215009157, 2, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000215009157, 3, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 1, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 2, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 3, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 4, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 5, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 6, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 7, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 8, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 9, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060715009158, 10, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 1, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 2, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 3, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 4, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 5, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 6, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 7, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 8, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 9, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 10, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 11, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727009511, 12, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 1, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 2, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 3, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 4, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 5, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 6, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 7, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 8, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 9, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 10, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 11, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 12, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080309009512, 13, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 1, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 2, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 3, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 4, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 5, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 6, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 7, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 8, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 9, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 10, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 11, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 12, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730009513, 13, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 1, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 2, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 3, 161, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 4, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 5, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 6, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 7, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 8, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 9, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 10, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 11, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 12, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 13, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 14, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 15, 171, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 16, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 17, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 18, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326009514, 19, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 1, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 2, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 3, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 4, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 5, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 6, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 7, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 8, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 9, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 10, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 11, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 12, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 13, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 14, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 15, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 16, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140313009515, 17, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910009516, 1, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910009516, 2, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910009516, 3, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910009516, 4, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910009516, 5, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 1, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 2, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 3, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 4, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 5, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 6, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 7, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 8, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 9, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 10, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 11, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 12, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006009517, 13, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 1, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 2, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 3, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 4, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 5, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 6, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 7, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060302009518, 8, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 1, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 2, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 3, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 4, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 5, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 6, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 7, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 8, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 9, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 10, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 11, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009519, 12, 49, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 1, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 2, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 3, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 4, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 5, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009520, 6, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225009521, 1, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225009521, 2, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225009521, 3, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 1, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 2, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 3, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 4, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 5, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115009522, 6, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 1, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 2, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 3, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 4, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 5, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 6, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 7, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 8, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 9, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 10, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 11, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 12, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 13, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 14, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 15, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 16, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 17, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 18, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311009523, 19, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 1, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 2, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 3, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 4, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 5, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010113009524, 6, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 1, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 2, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 3, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 4, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 5, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 6, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031202009525, 7, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 1, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 2, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 3, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 4, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 5, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 6, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 7, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 8, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 9, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 10, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 11, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806009526, 12, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 1, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 2, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 3, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 4, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 5, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 6, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 7, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 8, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 9, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 10, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 11, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115009527, 12, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 1, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 2, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 3, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 4, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 5, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822009528, 6, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 1, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 2, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 3, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 4, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 5, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 6, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 7, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 8, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029009529, 9, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802009530, 1, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802009530, 2, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802009530, 3, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802009530, 4, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802009530, 5, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 1, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 2, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 3, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 4, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 5, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 6, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 7, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 8, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 9, 55, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 10, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080424009531, 11, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 1, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 2, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 3, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 4, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 5, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 6, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722009532, 7, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513009533, 1, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513009533, 2, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513009533, 3, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513009533, 4, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 1, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 2, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 3, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 4, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 5, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 6, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 7, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 8, 105, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 9, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 10, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219009534, 11, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 1, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 2, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 8, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 9, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 10, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 11, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 12, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 1, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 2, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 3, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 4, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 5, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 6, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 7, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 8, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 9, 170, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 10, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 11, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009891, 12, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 1, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 2, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 3, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 4, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 5, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 6, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 7, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 8, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 9, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 10, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203009892, 11, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009893, 1, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009893, 2, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009893, 3, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009893, 4, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009893, 5, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507009894, 1, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507009894, 2, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507009894, 3, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507009894, 4, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 1, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 2, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 3, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 4, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 5, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 6, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 7, 59, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 8, 7, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 9, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 10, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 11, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 12, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 13, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 14, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 15, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 16, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304009895, 17, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 1, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 2, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 3, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 4, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 5, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 6, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 7, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 8, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 9, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110009896, 10, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 1, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 2, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 3, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 4, 48, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 5, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 6, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 7, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 8, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 9, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060927009897, 10, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 1, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 2, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 3, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 4, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 5, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 6, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 7, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 8, 140, 36, 11, 396);
commit;
prompt 88000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009898, 9, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 1, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 2, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 3, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 4, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 5, 85, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 6, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 7, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 8, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 9, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915009899, 10, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 1, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 2, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 3, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 4, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 5, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 6, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 7, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 8, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 9, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 10, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 11, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 12, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 13, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 14, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 15, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029009900, 16, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110009901, 1, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110009901, 2, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110009901, 3, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110009901, 4, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110009901, 5, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 1, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 2, 153, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 3, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 4, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 5, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 6, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 7, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 8, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 9, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 10, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 11, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 12, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 13, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 14, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009902, 15, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 1, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 2, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 3, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 4, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 5, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 6, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 7, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 8, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009903, 9, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 1, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 2, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 3, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 4, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 5, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 6, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009904, 7, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220009905, 1, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220009905, 2, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001220009905, 3, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 1, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 2, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 3, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 4, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 5, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 6, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 7, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 8, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 9, 175, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 10, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 11, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 12, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 13, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111009906, 14, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009907, 1, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009907, 2, 92, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009907, 3, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009907, 4, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009907, 5, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 1, 18, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 2, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 3, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 4, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 5, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 6, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 7, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 8, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 9, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 10, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 11, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 12, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009908, 13, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 1, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 2, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 3, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 4, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 5, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 6, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 7, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 8, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 9, 79, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 10, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 11, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 12, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 13, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009909, 14, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 1, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 2, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 3, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 4, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 5, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 6, 146, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 7, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 8, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 9, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 10, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818009910, 11, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 1, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 2, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 3, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 4, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 5, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 6, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 7, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 8, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 9, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 10, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 11, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 12, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 13, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 14, 72, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 15, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309009911, 16, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 1, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 2, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 3, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 4, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 5, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303009912, 6, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 1, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 2, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 3, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 4, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 5, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 6, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 7, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 8, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 9, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 10, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 11, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 12, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 13, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 1, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 2, 12, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 3, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 4, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 5, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 6, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 7, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 8, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 9, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 10, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 11, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 12, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 13, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 14, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723008758, 15, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 1, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 2, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 3, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 4, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 5, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 6, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 7, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 8, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 9, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 10, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 11, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 12, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 13, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 14, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 15, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923008759, 16, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223008760, 1, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223008760, 2, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223008760, 3, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223008760, 4, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 1, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 2, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 3, 168, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 4, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 5, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 6, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 7, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 8, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 9, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 10, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 11, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 12, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 13, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 14, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 15, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613008761, 16, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 1, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 2, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 3, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 4, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 5, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 6, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 7, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 8, 64, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 9, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 10, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 11, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 12, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 13, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 14, 170, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 15, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417008762, 16, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 1, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 2, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 3, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 4, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 5, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 6, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 7, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 8, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 9, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 10, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 11, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 12, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 13, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008763, 14, 93, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 1, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 2, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 3, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 4, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 5, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 6, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 7, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 8, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226008764, 9, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 1, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 2, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 3, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 4, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 5, 55, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 6, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 7, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 8, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 9, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080227008765, 10, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008766, 1, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008766, 2, 110, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008766, 3, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705008766, 4, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230008767, 1, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230008767, 2, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011230008767, 3, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 1, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 2, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 3, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 4, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 5, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 6, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 7, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 8, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 9, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 10, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 11, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 12, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 13, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 14, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019008768, 15, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 1, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 2, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 3, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 4, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 5, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 6, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 7, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 8, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 9, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 10, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 11, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 12, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 13, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 14, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 15, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 16, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 17, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 18, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328008769, 19, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 1, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 2, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 3, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 4, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 5, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 6, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 7, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 8, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 9, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 10, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 11, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 12, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 13, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 14, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 15, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 16, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 17, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 18, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203008770, 19, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 1, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 2, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 3, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 4, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 5, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 6, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 7, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 8, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 9, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 10, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 11, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 12, 172, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 13, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319008771, 14, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224008772, 1, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224008772, 2, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224008772, 3, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224008772, 4, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224008772, 5, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 1, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 2, 56, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 3, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 4, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 5, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 6, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 7, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 8, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 9, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050113008773, 10, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 1, 127, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 2, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 3, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 4, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 5, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 6, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 7, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 8, 182, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 9, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 10, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 11, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 12, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605008774, 13, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 1, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 2, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 3, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 4, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 5, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 6, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050806008775, 7, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706008776, 1, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706008776, 2, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706008776, 3, 47, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706008776, 4, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706008776, 5, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 1, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 2, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 3, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 4, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 5, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 6, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041207008777, 7, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806008778, 1, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806008778, 2, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806008778, 3, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 1, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 2, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 3, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 4, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 5, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 6, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 7, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 8, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 9, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124008779, 10, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 1, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 2, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 3, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 4, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 5, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 1, 143, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 2, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 3, 47, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 4, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 5, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 6, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 7, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 8, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 9, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 10, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 11, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 12, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 13, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009159, 14, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 1, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 2, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 3, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 4, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 5, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 6, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 7, 99, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 8, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107009160, 9, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 1, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 2, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 3, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 4, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 5, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 6, 13, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 7, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 8, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 9, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 10, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071223009161, 11, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503009162, 1, 175, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503009162, 2, 97, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503009162, 3, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503009162, 4, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 1, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 2, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 3, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 4, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 5, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503009163, 6, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 1, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 2, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 3, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 4, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 5, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 6, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 7, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 8, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 9, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070813009164, 10, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 1, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 2, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 3, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 4, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 5, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112009165, 6, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 1, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 2, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 3, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 4, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 5, 192, 34, 18, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 6, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 7, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 8, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 9, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 10, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 11, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 12, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 13, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 14, 144, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 15, 164, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009166, 16, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 1, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 2, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 3, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 4, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 5, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 6, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 7, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 8, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 9, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 10, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 11, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 12, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009167, 13, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 1, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 2, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 3, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 4, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 5, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 6, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 7, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 8, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 9, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 10, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 11, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 12, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 13, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614009168, 14, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 1, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 2, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 3, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 4, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 5, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 6, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 7, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008009169, 8, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 1, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 2, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 3, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 4, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 5, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 6, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 7, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 8, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 9, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 10, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208009170, 11, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 1, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 2, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 3, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 4, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 5, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 6, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 7, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 8, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 9, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 10, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003009171, 11, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 1, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 2, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 3, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 4, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 5, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 6, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 7, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 8, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 9, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 10, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 11, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 12, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 13, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 14, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 15, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009172, 16, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001009173, 1, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001009173, 2, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001009173, 3, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001009173, 4, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001009173, 5, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 1, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 2, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 3, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 4, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 5, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 6, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 7, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101009174, 8, 125, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 1, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 2, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 3, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 4, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 5, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 6, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 7, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009175, 8, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 1, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 2, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 3, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 4, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 5, 122, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 6, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 7, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 8, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 9, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 10, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 11, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 12, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 13, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 14, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100401009176, 15, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 1, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 2, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 3, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 4, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 5, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 6, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 7, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 8, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 9, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 10, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 11, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 12, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 13, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 14, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 15, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109009177, 16, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 1, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 2, 177, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 3, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 4, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 5, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 6, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 7, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 8, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 9, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061126009178, 10, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 1, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 2, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 3, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 4, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 5, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 6, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 7, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 8, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 9, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080506009179, 10, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 1, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 2, 26, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 3, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 4, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 5, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 6, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 7, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 8, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 9, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 10, 64, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 11, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 12, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 13, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 14, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 15, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 16, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711009180, 17, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 1, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 3, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 4, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 5, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 6, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 7, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 8, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 9, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 10, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 11, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 12, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 13, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 14, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 15, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216009535, 16, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 1, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 2, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 3, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 4, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 5, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 6, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 7, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 8, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724009536, 9, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119009537, 1, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119009537, 2, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119009537, 3, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 1, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 2, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 3, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 4, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 5, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 6, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 7, 147, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 8, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 9, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 10, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328009538, 11, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 1, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 2, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 4, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 5, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 6, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 7, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 8, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 9, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 10, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 11, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 12, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 13, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009539, 14, 127, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 1, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 2, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 3, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 4, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 5, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623009540, 6, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701009541, 1, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701009541, 2, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701009541, 3, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020701009541, 4, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 1, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 2, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 3, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 4, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 5, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 6, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 7, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 8, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 9, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 10, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061130009542, 11, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 1, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 2, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 3, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 4, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 5, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 6, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 7, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 8, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 9, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 10, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 11, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 12, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 13, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 14, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327009543, 15, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 1, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 2, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 3, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 4, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 5, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 6, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 7, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009544, 8, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 1, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 2, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 3, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 4, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 5, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 6, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 7, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 8, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 9, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 10, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 11, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 12, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 13, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 14, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129009545, 15, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 1, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 2, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 3, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 4, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 5, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 6, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 7, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 8, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 9, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 10, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 11, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090126009546, 12, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 1, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 2, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 3, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 4, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 5, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 6, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 7, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 8, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 9, 44, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 10, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 11, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 12, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 13, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 14, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801009547, 15, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208009548, 1, 103, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208009548, 2, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208009548, 3, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208009548, 4, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208009548, 5, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 1, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 2, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 3, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 4, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 5, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 6, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 7, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 8, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060501009549, 9, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 1, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 2, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 3, 144, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 4, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 5, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 6, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 7, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 8, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 9, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 10, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 11, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119009550, 12, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 1, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 2, 16, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 3, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 4, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 5, 128, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 6, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 7, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 8, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 9, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 10, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 11, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 12, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 13, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 14, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 15, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116009551, 16, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401009552, 1, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401009552, 2, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401009552, 3, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401009552, 4, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401009552, 5, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 1, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 2, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 3, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 4, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 5, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 6, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 7, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 8, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 9, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009553, 10, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 1, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 2, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 3, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 4, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 5, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 6, 1, 91, 3, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 7, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 8, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 9, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331009554, 10, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001210009555, 1, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001210009555, 2, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001210009555, 3, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 1, 6, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 2, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 3, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 4, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 5, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 6, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 7, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 8, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 9, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317009556, 10, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 1, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 2, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 3, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 4, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 5, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009557, 6, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 1, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 2, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 3, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 4, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 5, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 6, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 7, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 8, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830009558, 9, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 1, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 2, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 3, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 4, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 5, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 6, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 7, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 14, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120321009913, 15, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 1, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 2, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 3, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 4, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 5, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 6, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 7, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 8, 69, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223009914, 9, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 1, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 2, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 3, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 4, 115, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 5, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 6, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 7, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 8, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 9, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 10, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 11, 121, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009915, 12, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 1, 145, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 2, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 3, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 4, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 5, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 6, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 7, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 8, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 9, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 10, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 11, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 12, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 13, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 14, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 15, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009916, 16, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 1, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 2, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 3, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 4, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 5, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 6, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 7, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 8, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 9, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408009917, 10, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 1, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 2, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 3, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 4, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 5, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 6, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 7, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 8, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 9, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 10, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 11, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 12, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 13, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 14, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 15, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106009918, 16, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 1, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 2, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 3, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 4, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 5, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 6, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 7, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 8, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 9, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 10, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 11, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 12, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 13, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 14, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208009919, 15, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 1, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 2, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 3, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 4, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 5, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 6, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 7, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 8, 153, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 9, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 10, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 11, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 12, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125009920, 13, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 1, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 2, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 3, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 4, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 5, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 6, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 7, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 8, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 9, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 10, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 11, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 12, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 13, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009921, 14, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 1, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 2, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 3, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 4, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 5, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 6, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810009922, 7, 76, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 1, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 2, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 3, 104, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 4, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 5, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 6, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 7, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 8, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 9, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 10, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070802009923, 11, 166, 50, 13, 650);
commit;
prompt 89000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 1, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 2, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 3, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 4, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 5, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 6, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 7, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 8, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 9, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 10, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 11, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 12, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 13, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 14, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 15, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 16, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805009924, 17, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 1, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 2, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 3, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 4, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 5, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505009925, 6, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 1, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 2, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 3, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 4, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 5, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 6, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 7, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 8, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 9, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 10, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 11, 176, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 12, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 13, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 14, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100601009926, 15, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 1, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 2, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 3, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 4, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 5, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 6, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 7, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 8, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 9, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 10, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 11, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 12, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 13, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 14, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 15, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901009927, 16, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 1, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 2, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 3, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 4, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 5, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 6, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 7, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 8, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101009928, 9, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 1, 50, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 2, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 3, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 4, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 5, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 6, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 7, 192, 6, 18, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 8, 108, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 9, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 10, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 11, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 12, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 13, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 14, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 15, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 16, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625009929, 17, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 1, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 2, 73, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 3, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 4, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 5, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 6, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 7, 69, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 8, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717009930, 9, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 1, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 2, 62, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 3, 89, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 4, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 5, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 6, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 7, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 8, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 9, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 10, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 11, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 12, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 13, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 14, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 15, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 16, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307009931, 17, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 1, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 2, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 3, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 4, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 5, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 6, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 7, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 6, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 7, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 8, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 9, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 10, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 11, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 12, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 13, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090805008780, 14, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008781, 1, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008781, 2, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008781, 3, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008781, 4, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 1, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 2, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 3, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 4, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 5, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 6, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 7, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 8, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 9, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 10, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 11, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 12, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 13, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 14, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 15, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 16, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 17, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131116008782, 18, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 1, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 2, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 3, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 4, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 5, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 6, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 7, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 8, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 9, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 10, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 11, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 12, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008008783, 13, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 1, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 2, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 3, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 4, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 5, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 6, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827008784, 7, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 1, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 2, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 3, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 4, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 5, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 6, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 7, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 8, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 9, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 10, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 11, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 12, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 13, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 14, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 15, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131101008785, 16, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 1, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 2, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 3, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 4, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 5, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 6, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 7, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 8, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 9, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 10, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008786, 11, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 1, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 2, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 3, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 4, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 5, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 6, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 7, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041003008787, 8, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 1, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 2, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 3, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 4, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 5, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020208008788, 6, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 1, 103, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 2, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 3, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 4, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 5, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 6, 20, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 7, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 8, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 9, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 10, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 11, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 12, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 13, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 14, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206008789, 15, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 1, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 2, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 3, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 4, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 5, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 6, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 7, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227008790, 8, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 1, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 2, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 3, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 4, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 5, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 6, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124008791, 7, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 1, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 2, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 3, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 4, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 5, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 6, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 7, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 8, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 9, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 10, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 11, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 12, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 13, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 14, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 15, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414008792, 16, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008793, 1, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008793, 2, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111008793, 3, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 1, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 2, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 3, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 4, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 5, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 6, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 7, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 8, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 9, 63, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 10, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 11, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 12, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 13, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 14, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 15, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702008794, 16, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 1, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 2, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 3, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 4, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 5, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 6, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 7, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 8, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 9, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327008795, 10, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 1, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 2, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 3, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 4, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 5, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 6, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 7, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 8, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 9, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 10, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 11, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 12, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 13, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 14, 120, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 15, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008796, 16, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 1, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 2, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 3, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 4, 93, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 5, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613008797, 6, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 1, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 2, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 3, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 4, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 5, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 6, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 7, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041102008798, 8, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624008799, 1, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624008799, 2, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624008799, 3, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624008799, 4, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624008799, 5, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008800, 1, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000810008800, 2, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 1, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 2, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 3, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 4, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 5, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 6, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 7, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 8, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 9, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 10, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 11, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 12, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 13, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121008801, 14, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 1, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 2, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 3, 124, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 4, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 5, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 6, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 7, 98, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 8, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 9, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 10, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 11, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 12, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427008802, 13, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 1, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 2, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 3, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 4, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 5, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924008803, 6, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 1, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 2, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 3, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 4, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 5, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 6, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 7, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 8, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 9, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 10, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 11, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 12, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 13, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723009181, 14, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 1, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 2, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 3, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 4, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 5, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 6, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 7, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 8, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 9, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 10, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 11, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 12, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 13, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203009182, 14, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 1, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 2, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 3, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 4, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 5, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 6, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 7, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 8, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 9, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 10, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 11, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 12, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 13, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 14, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 15, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428009183, 16, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 1, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 2, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 3, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 4, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 5, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 6, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 7, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210009184, 8, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 1, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 2, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 3, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 4, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 5, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009185, 6, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 1, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 2, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 3, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 4, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 5, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 6, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 7, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 8, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 9, 63, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424009186, 10, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001009187, 1, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001009187, 2, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001009187, 3, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001009187, 4, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001009187, 5, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 1, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 2, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 3, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 4, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 5, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219009188, 6, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 1, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 2, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 3, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 4, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 5, 46, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 6, 1, 89, 3, 267);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 7, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 8, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 9, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119009189, 10, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 1, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 2, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 3, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 4, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 5, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 6, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 7, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 8, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 9, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 10, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527009190, 11, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 1, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 2, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 3, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 4, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 5, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 6, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 7, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 8, 180, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 9, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401009191, 10, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 1, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 2, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 3, 40, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 4, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 5, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 6, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 7, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 8, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 9, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 10, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 11, 71, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 12, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 13, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 14, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117009192, 15, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 1, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 2, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 3, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 4, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 5, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 6, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 7, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 8, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 9, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 10, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 11, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 12, 34, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 13, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 14, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 15, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009193, 16, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 1, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 2, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 3, 120, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 4, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 5, 31, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 6, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 7, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 8, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 9, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 10, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 11, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 12, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 13, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 14, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 15, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219009194, 16, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 1, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 2, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 3, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 4, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 5, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 6, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 7, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 8, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 9, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 10, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 11, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 12, 184, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 13, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 14, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113009195, 15, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 1, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 2, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 3, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 4, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 5, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 6, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 7, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 8, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 9, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 10, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 11, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 12, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 13, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101221009196, 14, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 1, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 2, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 3, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 4, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 5, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211009197, 6, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219009198, 1, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219009198, 2, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219009198, 3, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000219009198, 4, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 1, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 2, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 3, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 4, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 5, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 6, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 7, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 8, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009199, 9, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 1, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 2, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 3, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 4, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 5, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 6, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 7, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 8, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 9, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 10, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 11, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411009200, 12, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029009201, 1, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029009201, 2, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029009201, 3, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029009201, 4, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029009201, 5, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 1, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 2, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 3, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 4, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 5, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 6, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 7, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 8, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 9, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 10, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 11, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 12, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 13, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303009202, 14, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 1, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 2, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 3, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 4, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 8, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 9, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 10, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 11, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009559, 12, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 1, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 2, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 3, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 4, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 5, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 6, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 7, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 8, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 9, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 10, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 11, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920009560, 12, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 1, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 2, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 3, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 4, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 5, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 6, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 7, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 8, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 9, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 10, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 11, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 12, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 13, 171, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 14, 152, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921009561, 15, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 1, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 2, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 3, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 4, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 5, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 6, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 7, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 8, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 9, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 10, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 11, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 12, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009562, 13, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 1, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 2, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 3, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 4, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 5, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 6, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 7, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 8, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 9, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 10, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209009563, 11, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 1, 92, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 2, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 3, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 4, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 5, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 6, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 7, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 8, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 9, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 10, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 11, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 12, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 13, 47, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 14, 189, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 15, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 16, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222009564, 17, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 1, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 2, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 3, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 4, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 5, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 6, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 7, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 8, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219009565, 9, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 1, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 2, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 3, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 4, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 5, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 6, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 7, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 8, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 9, 134, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 10, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511009566, 11, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016009567, 1, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016009567, 2, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016009567, 3, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016009567, 4, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016009567, 5, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 1, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 2, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 3, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 4, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 5, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 6, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 7, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 8, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 9, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 10, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 11, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 12, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 13, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 14, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131209009568, 15, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027009569, 1, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027009569, 2, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027009569, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 1, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 2, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 3, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 4, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 5, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 6, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 7, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 8, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 9, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 10, 149, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324009570, 11, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 1, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 2, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 3, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 4, 14, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 5, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 6, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130009571, 7, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 1, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 2, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 3, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 4, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 5, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 6, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 7, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 8, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 9, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 10, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080727009572, 11, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 1, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 2, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 3, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 4, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 5, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 6, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 7, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 8, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 9, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 10, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 11, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 12, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 13, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 14, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 15, 146, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007009573, 16, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 1, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 2, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 3, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 4, 48, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 5, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 6, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 7, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 8, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 9, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 10, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 11, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703009574, 12, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 1, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 2, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 3, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 4, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 5, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 6, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 7, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606009575, 8, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126009576, 1, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126009576, 2, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126009576, 3, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 1, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 2, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 3, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 4, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 5, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 6, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 7, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 8, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 9, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 10, 78, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 11, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 12, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 13, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 14, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111029009577, 15, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914009578, 1, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914009578, 2, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 1, 77, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 2, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 3, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 4, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 5, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 6, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 7, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 8, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 9, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 10, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 11, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 12, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 13, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111018009579, 14, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 1, 93, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 2, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 3, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 4, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 5, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 6, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 7, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 8, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 9, 1, 92, 3, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 10, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 11, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218009580, 12, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009581, 1, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009581, 2, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009581, 3, 168, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009581, 4, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 1, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 2, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 3, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 4, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 5, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 6, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 7, 87, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 8, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 8, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009932, 9, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 1, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 2, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 3, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 4, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 5, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 6, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 7, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 8, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 9, 83, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 10, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 11, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 12, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 13, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 14, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 15, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510009933, 16, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 1, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 2, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 3, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 4, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 5, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 6, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 7, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 8, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 9, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 10, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 11, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 12, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 13, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 14, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 15, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427009934, 16, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 1, 96, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 2, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 3, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 4, 21, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 5, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 6, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 7, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 8, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 9, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 10, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 11, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009935, 12, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 1, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 2, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 3, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 4, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 5, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 6, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009936, 7, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 1, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 2, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 3, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 4, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 5, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 6, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 7, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 8, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 9, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 10, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 11, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 12, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 13, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 14, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421009937, 15, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 1, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 2, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 3, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 4, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 5, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 6, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 7, 3, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 8, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 9, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 10, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 11, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 12, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 13, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228009938, 14, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 1, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 2, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 3, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 4, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 5, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 6, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 7, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 8, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 9, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 10, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 11, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211009939, 12, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 1, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 2, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 3, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 4, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 5, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 6, 107, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 7, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 8, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 9, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 10, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 11, 71, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 12, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018009940, 13, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 1, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 2, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 3, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 4, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 5, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 6, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030106009941, 7, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 1, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 2, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 3, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 4, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 5, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 6, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 7, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 8, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112009942, 9, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211009943, 1, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211009943, 2, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211009943, 3, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211009943, 4, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 1, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 2, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 3, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 4, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 5, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 6, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 7, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 8, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 9, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 10, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 11, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 12, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 13, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 14, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 15, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120210009944, 16, 23, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 1, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 2, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 3, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 4, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 5, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 6, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 7, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 8, 154, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 9, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 10, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 11, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 12, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 13, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 14, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 15, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 16, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 17, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028009945, 18, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 1, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 2, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 3, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 4, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 5, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 6, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 7, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 8, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 9, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020009946, 10, 146, 87, 10, 870);
commit;
prompt 90000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 1, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 2, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 3, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 4, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 5, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 6, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 7, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 8, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 9, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 10, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 11, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 12, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 13, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830009947, 14, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 1, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 2, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 3, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 4, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 5, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131009948, 6, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 1, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 2, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 3, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 4, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 5, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 6, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 7, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 8, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 9, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 10, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 11, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725009949, 12, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 1, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 2, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 3, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 4, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 5, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 6, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 7, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 8, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 9, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 10, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 11, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 12, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 13, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030009950, 14, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 1, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 2, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 3, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 4, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 5, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 6, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 7, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009951, 8, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920009952, 1, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920009952, 2, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010920009952, 3, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 1, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 2, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 3, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 4, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 5, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 6, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 7, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 8, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 9, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 10, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 11, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 2, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 3, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 4, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 5, 177, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 6, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 7, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 8, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 9, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 10, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 11, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 12, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 13, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 14, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527008804, 15, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 1, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 2, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 3, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 4, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 5, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 6, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 7, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 8, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050501008805, 9, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 1, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 2, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 3, 88, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 4, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 5, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 6, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 7, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 8, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 9, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 10, 26, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 11, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080612008806, 12, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 1, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 2, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 3, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 4, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 5, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 6, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 7, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 8, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 9, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 10, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 11, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090809008807, 12, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 1, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 2, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 3, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 4, 179, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 5, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 6, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 7, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 8, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 9, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070209008808, 10, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 1, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 2, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 3, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 4, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 5, 67, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 6, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 7, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123008809, 8, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 1, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 2, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 3, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 4, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 5, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 6, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 7, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 8, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131008810, 9, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 1, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 2, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 3, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 4, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 5, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 6, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 7, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 8, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 9, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 10, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 11, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 12, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 13, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 14, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 15, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 16, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 17, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 18, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408008811, 19, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 1, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 2, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 3, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 4, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 5, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 6, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 7, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 8, 118, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 9, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 10, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926008812, 11, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 1, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 2, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 3, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 4, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 5, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 6, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 7, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 8, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060712008813, 9, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 1, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 2, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 3, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 4, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 5, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 6, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 7, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 8, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 9, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 10, 107, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090504008814, 11, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 1, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 2, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 3, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 4, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 5, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 6, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 7, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 8, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 9, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 10, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 11, 190, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 12, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 13, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 14, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 15, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 16, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 17, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519008815, 18, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013008816, 1, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001013008816, 2, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 1, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 2, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 3, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 4, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 5, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 6, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 7, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 8, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 9, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 10, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 11, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 12, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 13, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 14, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 15, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 16, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130411008817, 17, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823008818, 1, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823008818, 2, 192, 86, 18, 1548);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823008818, 3, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823008818, 4, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823008818, 5, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 1, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 2, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 3, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 4, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 5, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 6, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 7, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 8, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 9, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 10, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 11, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 12, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 13, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829008819, 14, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 1, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 2, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 3, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 4, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 5, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 6, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 7, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 8, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 9, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 10, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 11, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 12, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 13, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 14, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 15, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 16, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 17, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008820, 18, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009008821, 1, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009008821, 2, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009008821, 3, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009008821, 4, 41, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011009008821, 5, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 1, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 2, 129, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 3, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 4, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 5, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 6, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 7, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 8, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505008822, 9, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 1, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 2, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 3, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 4, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 5, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 6, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 7, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 8, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 9, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 10, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 11, 85, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008823, 12, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 1, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 2, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 3, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 4, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 5, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 6, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 7, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 8, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 9, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 10, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 11, 76, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 12, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 13, 27, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 14, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008824, 15, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 5, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 6, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 7, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009203, 8, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913009204, 1, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913009204, 2, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913009204, 3, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913009204, 4, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 1, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 2, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 3, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 4, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 5, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 6, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 7, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 8, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 9, 10, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 10, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 11, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 12, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 13, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 14, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 15, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203009205, 16, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 1, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 2, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 3, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 4, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 5, 149, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 6, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 7, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 8, 15, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 9, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009206, 10, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 1, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 2, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 3, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 4, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 5, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 6, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 7, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 8, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 9, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 10, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 11, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 12, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 13, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 14, 55, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009207, 15, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004009208, 1, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004009208, 2, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004009208, 3, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004009208, 4, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004009208, 5, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 1, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 2, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 3, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 4, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 5, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 6, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 7, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 8, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 9, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508009209, 10, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 1, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 2, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 3, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 4, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 5, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 6, 180, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 7, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 8, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 9, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 10, 191, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 11, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 12, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 13, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 14, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 15, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 16, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140217009210, 17, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 1, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 2, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 3, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 4, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 5, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 6, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 7, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 8, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 9, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216009211, 10, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 1, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 3, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 4, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 5, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 6, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 7, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 8, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 9, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 10, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 11, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 12, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 13, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 14, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 15, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303009212, 16, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 1, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 2, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 3, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 4, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 5, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 6, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 7, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 8, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 9, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 10, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 11, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 12, 90, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 13, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 14, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009213, 15, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 1, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 2, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 3, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 4, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 5, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813009214, 6, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117009215, 1, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117009215, 2, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117009215, 3, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117009215, 4, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117009215, 5, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 1, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 2, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 3, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 4, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 5, 192, 17, 18, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 6, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 7, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 8, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 9, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 10, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 11, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 12, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 13, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 14, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 15, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009216, 16, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 1, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 2, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 3, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 4, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 5, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020009217, 6, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 1, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 2, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 3, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 4, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 5, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 6, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 7, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314009218, 8, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 1, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 2, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 3, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 4, 16, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 5, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726009219, 6, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 1, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 2, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 3, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 4, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 5, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 6, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 7, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 8, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 9, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 10, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 11, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406009220, 12, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 1, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 2, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 3, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 4, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 5, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 6, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303009221, 7, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 1, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 2, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 3, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 4, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 5, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 6, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 7, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 8, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 9, 23, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 10, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 11, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423009222, 12, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 1, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 2, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 3, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 4, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 5, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906009223, 6, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 1, 192, 14, 18, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 2, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 3, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 4, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 5, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 6, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 7, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 8, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 9, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 10, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 11, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215009224, 12, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 1, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 2, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 3, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 4, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 5, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 6, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714009225, 7, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213009226, 1, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213009226, 2, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213009226, 3, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213009226, 4, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213009226, 5, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 1, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 2, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 3, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 4, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 5, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009227, 6, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 1, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 2, 30, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 3, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 4, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 9, 60, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 10, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 11, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 12, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 13, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904009582, 14, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 1, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 2, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 3, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 4, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 5, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 6, 92, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 7, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206009583, 8, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 1, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 2, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 3, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 4, 104, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 5, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 6, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 7, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 8, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 9, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 10, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 11, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 12, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214009584, 13, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 1, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 2, 179, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 3, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 4, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 5, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 6, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 7, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 8, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 9, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 10, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 11, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090606009585, 12, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 1, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 2, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 3, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 4, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 5, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 6, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 7, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 8, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601009586, 9, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 1, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 2, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 3, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 4, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 5, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 6, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 7, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 8, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 9, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 10, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 11, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 12, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 13, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 14, 107, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 15, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316009587, 16, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 1, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 2, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 3, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 4, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 5, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 6, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302009588, 7, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 1, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 2, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 3, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 4, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 5, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 6, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 7, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 8, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 9, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 10, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 11, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 12, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 13, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 14, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 15, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 16, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009589, 17, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114009590, 1, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114009590, 2, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114009590, 3, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 1, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 2, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 3, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 4, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 5, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 6, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 7, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 8, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723009591, 9, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 1, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 2, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 3, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 4, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 5, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 6, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 7, 3, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 8, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 9, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227009592, 10, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 1, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 2, 150, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 3, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 4, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 5, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 6, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 7, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 8, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201009593, 9, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 1, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 2, 84, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 3, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 4, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 5, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 6, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 7, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 8, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 9, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 10, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 11, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 12, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009594, 13, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 1, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 2, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 3, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 4, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 5, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 6, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 7, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 8, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 9, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 10, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071004009595, 11, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 1, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 2, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 3, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 4, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 5, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 6, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 7, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 8, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070113009596, 9, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 1, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 2, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 3, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 4, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 5, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 6, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 7, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040316009597, 8, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 1, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 2, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 3, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 4, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 5, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 6, 167, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 7, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 8, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 9, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070716009598, 10, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 1, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 2, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 3, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 4, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 5, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 6, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 7, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 8, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 9, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 10, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071114009599, 11, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 1, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 2, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 3, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 4, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 5, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 6, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 7, 69, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 8, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 9, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 10, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 11, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 12, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 13, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 14, 41, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113009600, 15, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 1, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 2, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 3, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 4, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 5, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 6, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 7, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 8, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 9, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327009601, 10, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 1, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 2, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 3, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 4, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 5, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 6, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 7, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 8, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727009602, 9, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 1, 63, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 2, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 3, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 4, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 5, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 6, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 7, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 8, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 9, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 10, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 11, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 12, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111130009603, 13, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 1, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 2, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 3, 145, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 4, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 5, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 6, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 7, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 8, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 9, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 10, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 11, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 12, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 13, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 14, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009953, 15, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 1, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 2, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 3, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 4, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 5, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 6, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 7, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 8, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 9, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 10, 100, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 11, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 12, 97, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100615009954, 13, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 1, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 2, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 3, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 4, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 5, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 6, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 7, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 8, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 9, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 10, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215009955, 11, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 1, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 2, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 3, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 4, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 5, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 6, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 7, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 8, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 9, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 10, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 11, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 12, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301009956, 13, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 1, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 2, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 3, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 4, 89, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 5, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 6, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 7, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 8, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 9, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501009957, 10, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 1, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 2, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 3, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 4, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 5, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219009958, 6, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 1, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 2, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 3, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 4, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 5, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 6, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 8, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 9, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129009959, 10, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 1, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 2, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 3, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 4, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 5, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 6, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419009960, 7, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 1, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 2, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 3, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 4, 114, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 5, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 6, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 7, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 8, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 9, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 10, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 11, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 12, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 13, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022009961, 14, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 1, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 2, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 3, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 4, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 5, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 6, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 7, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 8, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 9, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919009962, 10, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 1, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 2, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 3, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 4, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 5, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 6, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 7, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 8, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 9, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 10, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 11, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 12, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100621009963, 13, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 1, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 2, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 3, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 4, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 5, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 6, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 7, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025009964, 8, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 1, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 2, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 3, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 4, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 5, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 6, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 7, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214009965, 8, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 1, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 2, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 3, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 4, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 5, 112, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 6, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107009966, 7, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 1, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 2, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 3, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 4, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 5, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 6, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 7, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 8, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 9, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 10, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 11, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 12, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910009967, 13, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 1, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 2, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 3, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 4, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 5, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 6, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 7, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 8, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 9, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 10, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 11, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 12, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110915009968, 13, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 1, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 2, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 3, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 4, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 5, 97, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 6, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 7, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 8, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 9, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 10, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 11, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 12, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 13, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714009969, 14, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 1, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 2, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 3, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 4, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 5, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 6, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 7, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 8, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222009970, 9, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 1, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 2, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 3, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 4, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 5, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 6, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 7, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 8, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 9, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 10, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 11, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 12, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 13, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929009971, 14, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204009972, 1, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204009972, 2, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204009972, 3, 71, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204009972, 4, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204009972, 5, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 1, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 2, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 3, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 4, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 5, 57, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 6, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 7, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 8, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 9, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 10, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 11, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 12, 41, 4, 5, 20);
commit;
prompt 91000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106009973, 13, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911009974, 1, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911009974, 2, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911009974, 3, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911009974, 4, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 1, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 2, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 3, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 4, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 5, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 6, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 7, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 8, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 9, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 10, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 11, 44, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 12, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 13, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 14, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 15, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009975, 16, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 1, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 2, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 3, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 4, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 1, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 2, 18, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 3, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 4, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 5, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 6, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129008825, 7, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 1, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 2, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 3, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 4, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 5, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 6, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008826, 7, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 1, 53, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 2, 113, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 3, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 4, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 5, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 6, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 7, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 8, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 9, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 10, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 11, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 12, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 13, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 14, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120731008827, 15, 106, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 1, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 2, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 3, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 4, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 5, 9, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 6, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 7, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013008828, 8, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 1, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 2, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 3, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 4, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 5, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 6, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104008829, 7, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 1, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 2, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 3, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 4, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 5, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 6, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 7, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 8, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 9, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 10, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 11, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 12, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 13, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111028008830, 14, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 1, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 2, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 3, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 4, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 5, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 6, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 7, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 8, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 9, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 10, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 11, 67, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 12, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 13, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 14, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510008831, 15, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 1, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 2, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 3, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 4, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 5, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 6, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 7, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 8, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 9, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 10, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 11, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 12, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509008832, 13, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 1, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 2, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 3, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 4, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 5, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 6, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 7, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 8, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 9, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223008833, 10, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218008834, 1, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218008834, 2, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 1, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 2, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 3, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 4, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 5, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705008835, 6, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 1, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 2, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 3, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 4, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 5, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 6, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 7, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 8, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314008836, 9, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 1, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 2, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 3, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 4, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 5, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 6, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 7, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 8, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 9, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 10, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 11, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 12, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 13, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 14, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 15, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 16, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525008837, 17, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 1, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 2, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 3, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 4, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 5, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 6, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 7, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 8, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 9, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 10, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 11, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 12, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 13, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 14, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 15, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 16, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121028008838, 17, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 1, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 2, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 3, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 4, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 5, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119008839, 6, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 1, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 2, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 3, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 4, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 5, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 6, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 7, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 8, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 9, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 10, 164, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 11, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 12, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 13, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 14, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 15, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 16, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 17, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710008840, 18, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 1, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 2, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 3, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 4, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 5, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 6, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 7, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121008841, 8, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008842, 1, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008842, 2, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008842, 3, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008842, 4, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008842, 5, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 1, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 2, 127, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 3, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 4, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 5, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 6, 143, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 7, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 8, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 9, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 10, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 11, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006008843, 12, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 1, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 2, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 3, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 4, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 5, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 6, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 7, 54, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 8, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 9, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 10, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 11, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 12, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517008844, 13, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 1, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 2, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 3, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 4, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 5, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 6, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 7, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 8, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 9, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 10, 76, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 11, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 12, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522008845, 13, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 1, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 2, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 3, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 4, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 5, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 6, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 7, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 8, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 9, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 10, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020008846, 11, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 1, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 2, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 3, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 4, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 5, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 5, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 6, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 7, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 8, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 9, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 10, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 11, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 12, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 13, 30, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 14, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 15, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518009228, 16, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 1, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 2, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 3, 3, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 4, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 5, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 6, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 7, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 8, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 9, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 10, 76, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 11, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 12, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 13, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 14, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 15, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 16, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305009229, 17, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429009230, 1, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429009230, 2, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429009230, 3, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429009230, 4, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429009230, 5, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 1, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 2, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 3, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 4, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 5, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 6, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 7, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 8, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 9, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 10, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 11, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 12, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091118009231, 13, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 1, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 2, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 3, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 4, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 5, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 6, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 7, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040422009232, 8, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 1, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 2, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 3, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 4, 163, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 5, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 6, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 7, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 8, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 9, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 10, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 11, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124009233, 12, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 1, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 2, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 3, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 4, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 5, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 6, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 7, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 8, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 9, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 10, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 11, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 12, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 13, 147, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 14, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125009234, 15, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 1, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 2, 122, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 3, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 4, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 5, 72, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 6, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 7, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 8, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 9, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 10, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 11, 135, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 12, 75, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031009235, 13, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 1, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 2, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 3, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 4, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 5, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 6, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 7, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 8, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 9, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 10, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 11, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 12, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 13, 65, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 14, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 15, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 16, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823009236, 17, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929009237, 1, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929009237, 2, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929009237, 3, 85, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929009237, 4, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929009237, 5, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 1, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 2, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 3, 32, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 4, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 5, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 6, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 7, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 8, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 9, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 10, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 11, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722009238, 12, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 1, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 2, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 3, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 4, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 5, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716009239, 6, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127009240, 1, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127009240, 2, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127009240, 3, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011127009240, 4, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 1, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 2, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 3, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 4, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 5, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 6, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 7, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 8, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 9, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 10, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 11, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 12, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 13, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100411009241, 14, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 1, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 2, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 3, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 4, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 5, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308009242, 6, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 1, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 2, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 3, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 4, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 5, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 6, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 7, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 8, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060929009243, 9, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818009244, 1, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818009244, 2, 171, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818009244, 3, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010818009244, 4, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 1, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 2, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 3, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 4, 132, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 5, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 6, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 7, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 8, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009245, 9, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 1, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 2, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 3, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 4, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 5, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 6, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 7, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 8, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 9, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 10, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 11, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 12, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 13, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109009246, 14, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 1, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 2, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 3, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 4, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 5, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 6, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 7, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 8, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 9, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 10, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 11, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111009247, 12, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 1, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 2, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 3, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 4, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 5, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 6, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 7, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 8, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 9, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 10, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 11, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 12, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 13, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105009248, 14, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 1, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 2, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 3, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 4, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 5, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 6, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 7, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 8, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009249, 9, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 1, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 2, 159, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 3, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 4, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 5, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 6, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 7, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613009250, 8, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302009251, 1, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 12, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 13, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618009604, 14, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 1, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 2, 62, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 3, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 4, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 5, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 6, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 7, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 8, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 9, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 10, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081223009605, 11, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 1, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 2, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 3, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 4, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 5, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 6, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703009606, 7, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 1, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 2, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 3, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 4, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 5, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 6, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 7, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 8, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 9, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 10, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 11, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 12, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 13, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611009607, 14, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 1, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 2, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 3, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 4, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 5, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 6, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 7, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 8, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 9, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 10, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725009608, 11, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 1, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 2, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 3, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 4, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 5, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 6, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 7, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 8, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 9, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511009609, 10, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 1, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 2, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 3, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 4, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 5, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901009610, 6, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 1, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 2, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 3, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 4, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 5, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713009611, 6, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 1, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 2, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 3, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 4, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 5, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 6, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 7, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 8, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 9, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 10, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711009612, 11, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 1, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 2, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 3, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 4, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 5, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 6, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 7, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 8, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 9, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 10, 139, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 11, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009613, 12, 47, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000625009614, 1, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000625009614, 2, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000625009614, 3, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000625009614, 4, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 1, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 2, 76, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 3, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 4, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 5, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 6, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 7, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 8, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 9, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 10, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 11, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 12, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 13, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 14, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927009615, 15, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009616, 1, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009616, 2, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009616, 3, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009616, 4, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009616, 5, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 1, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 2, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 3, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 4, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 5, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720009617, 6, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 1, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 2, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 3, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 4, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 5, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 6, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 7, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 8, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 9, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 10, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 11, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 12, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415009618, 13, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 1, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 2, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 3, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 4, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 5, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 6, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 7, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 8, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 9, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 10, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 11, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 12, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310009619, 13, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 1, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 2, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 3, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 4, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 5, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 6, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 7, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 8, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 9, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 10, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 11, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 12, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 13, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 14, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 15, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802009620, 16, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 1, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 2, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 3, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 4, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 5, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 6, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 7, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 8, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 9, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401009621, 10, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 1, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 2, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 3, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 4, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 5, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 6, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622009622, 7, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 1, 189, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 2, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 3, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 4, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 5, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 6, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 7, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 8, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 9, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 10, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 11, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 12, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 13, 158, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 14, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 15, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117009623, 16, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 1, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 2, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 3, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 4, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 5, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 6, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 7, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009624, 8, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 1, 192, 100, 18, 1800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 2, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 3, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 4, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 5, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 6, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 7, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 8, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 9, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 10, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 11, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080825009625, 12, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 1, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 2, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 3, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 4, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 5, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 6, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 7, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 8, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 9, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 10, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 11, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 12, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 13, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 14, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 15, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517009626, 16, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 1, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 2, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 3, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 4, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 5, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 6, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 7, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 16, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 17, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 18, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 19, 27, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 1, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 2, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 3, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 4, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 5, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 6, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 7, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 8, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 9, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 10, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 11, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 12, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 13, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 14, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 15, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 16, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 17, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506010068, 18, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 1, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 2, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 3, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 4, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 5, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 6, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 7, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 8, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 9, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 10, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 11, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 12, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 13, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 14, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720010069, 15, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 1, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 2, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 3, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 4, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 5, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 6, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 7, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 8, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010070, 9, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 1, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 2, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 3, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 4, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 5, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 6, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 7, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 8, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 9, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 10, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 11, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 12, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 13, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 14, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 15, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106010071, 16, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 1, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 2, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 3, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 4, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 5, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 6, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010072, 7, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 1, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 2, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 3, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 4, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 5, 149, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 6, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 7, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 8, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 9, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 10, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 11, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 12, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407010073, 13, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 1, 132, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 2, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 3, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 4, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 5, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 6, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 7, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 8, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 9, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 10, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 11, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 12, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917010074, 13, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905010075, 1, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905010075, 2, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905010075, 3, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905010075, 4, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 1, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 2, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 3, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 4, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 5, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 6, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 7, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 8, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 9, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 10, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823010076, 11, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 1, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 2, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 3, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 4, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 5, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 6, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 7, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 8, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 9, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060818010077, 10, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 1, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 2, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 3, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 4, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 5, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 6, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 7, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 8, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424010078, 9, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018010079, 1, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018010079, 2, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018010079, 3, 79, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001018010079, 4, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201010080, 1, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201010080, 2, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201010080, 3, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 1, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 2, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 3, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 4, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 5, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 6, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 7, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 8, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 9, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 10, 157, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 11, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 12, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 13, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 14, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 15, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 16, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805010081, 17, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 1, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 2, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 3, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 4, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 5, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 6, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 7, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 8, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 9, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 10, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 11, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 12, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702010082, 13, 83, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 1, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 2, 108, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 3, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 4, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 5, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 6, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 7, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 8, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 9, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 10, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 11, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 12, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 13, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 14, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 15, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310010083, 16, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010817010084, 1, 154, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010817010084, 2, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010817010084, 3, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010817010084, 4, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010817010084, 5, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 1, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 2, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 3, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 4, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 5, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 6, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 7, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 8, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 9, 152, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 10, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 11, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 12, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 13, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 14, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 15, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 16, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220010085, 17, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010086, 1, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010086, 2, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010086, 3, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224010087, 1, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224010087, 2, 165, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224010087, 3, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021224010087, 4, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407010088, 1, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407010088, 2, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407010088, 3, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407010088, 4, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 1, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 2, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 3, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 4, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 5, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 6, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 7, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 8, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 9, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 10, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 11, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 12, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 13, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 14, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 15, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 16, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822010089, 17, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 1, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 2, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 3, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 4, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 5, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 6, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 6, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 7, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 8, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402008847, 9, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 1, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 2, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 3, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 4, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 5, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 6, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 7, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 8, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 9, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 10, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 11, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 12, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 13, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 14, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 15, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 16, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 17, 42, 20, 6, 120);
commit;
prompt 92000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 18, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118008848, 19, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008849, 1, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008849, 2, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008849, 3, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008849, 4, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020305008850, 1, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020305008850, 2, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020305008850, 3, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020305008850, 4, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020305008850, 5, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 1, 146, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 2, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 3, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 4, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 5, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 6, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 7, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824008851, 8, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 1, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 2, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 3, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 4, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 5, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 6, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 7, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729008852, 8, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 1, 21, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 2, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 3, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 4, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 5, 88, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 6, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040703008853, 7, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 1, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 2, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 3, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 4, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 5, 143, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 6, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 7, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 8, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 9, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 10, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 11, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 12, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 13, 89, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313008854, 14, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 1, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 2, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 3, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 4, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 5, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 6, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 7, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222008855, 8, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 1, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 2, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 3, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 4, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 5, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 6, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 7, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 8, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 9, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 10, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 11, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070712008856, 12, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417008857, 1, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417008857, 2, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417008857, 3, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417008857, 4, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417008857, 5, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 1, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 2, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 3, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 4, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 5, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 6, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 7, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 8, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 9, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 10, 80, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 11, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606008858, 12, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 1, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 2, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 3, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 4, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 5, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 6, 64, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 7, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 8, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051021008859, 9, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 1, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 2, 17, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 3, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 4, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 5, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218008860, 6, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 1, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 2, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 3, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 4, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 5, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 6, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 7, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 8, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 9, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 10, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525008861, 11, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 1, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 2, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 3, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 4, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 5, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 6, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 7, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529008862, 8, 149, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 1, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 2, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 3, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 4, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 5, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 6, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 7, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 8, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 9, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 10, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703008863, 11, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 1, 106, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 2, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 3, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 4, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 5, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 6, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 7, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 8, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 9, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060309008864, 10, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 1, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 2, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 3, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 4, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 5, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 6, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 7, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 8, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 9, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 10, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 11, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 12, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 13, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 14, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414008865, 15, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 1, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 2, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 3, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 4, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 5, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 6, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125008866, 7, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 1, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 2, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 3, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 4, 116, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 5, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 6, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 7, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 8, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 9, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 10, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 11, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218008867, 12, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 1, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 2, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 3, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 4, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 5, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 6, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 7, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 8, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 9, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 10, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 11, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080129008868, 12, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 1, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 2, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 3, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 4, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 5, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 6, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 7, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 8, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 9, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 10, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 11, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 12, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 13, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100516008869, 14, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 1, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 2, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 3, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 4, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 5, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 6, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 7, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 8, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 9, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 10, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 11, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 12, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 13, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 14, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 15, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 16, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930008870, 17, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 1, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302009251, 2, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302009251, 3, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302009251, 4, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302009251, 5, 8, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 1, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 2, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 3, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 4, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 5, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 6, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415009252, 7, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 1, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 2, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 3, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 4, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 5, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 6, 158, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 7, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 8, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 9, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007009253, 10, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 1, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 2, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 3, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 4, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 5, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 6, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 7, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 8, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 9, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 10, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 11, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 12, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 13, 191, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 14, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 15, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131001009254, 16, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 1, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 2, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 3, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 4, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 5, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 6, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 7, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 8, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 9, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 10, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 11, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009255, 12, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009256, 1, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009256, 2, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009256, 3, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009256, 4, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009256, 5, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 1, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 2, 90, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 3, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 4, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 5, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 6, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 7, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917009257, 8, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 1, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 2, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 3, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 4, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 5, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 6, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 7, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 8, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 9, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 10, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 11, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 12, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 13, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 14, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520009258, 15, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 1, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 2, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 3, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 4, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 5, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 6, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 7, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 8, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 9, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 10, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 11, 109, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 12, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 13, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 14, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 15, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 16, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 17, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 18, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104009259, 19, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 1, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 2, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 3, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 4, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 5, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 6, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 7, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 8, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 9, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 10, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 11, 192, 64, 18, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 12, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081124009260, 13, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 1, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 2, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 3, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 4, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 5, 8, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 6, 141, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 7, 182, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 8, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 9, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060720009261, 10, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 1, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 2, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 3, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 4, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 5, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 6, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 7, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 8, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040731009262, 9, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 1, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 2, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 3, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 4, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 5, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 6, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 7, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 8, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403009263, 9, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028009264, 1, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028009264, 2, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028009264, 3, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028009264, 4, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031028009264, 5, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913009265, 1, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913009265, 2, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913009265, 3, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913009265, 4, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913009265, 5, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 1, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 2, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 3, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 4, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 5, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 6, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 7, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 8, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 9, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 10, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 11, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 12, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 13, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 14, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228009266, 15, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 1, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 2, 41, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 3, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 4, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 5, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 6, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 7, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 8, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 9, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009267, 10, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929009268, 1, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929009268, 2, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929009268, 3, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929009268, 4, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929009268, 5, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 1, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 2, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 3, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 4, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 5, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413009269, 6, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 1, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 2, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 3, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 4, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 5, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 6, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224009270, 7, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 1, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 2, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 3, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 4, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 5, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 6, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 7, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 8, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 9, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 10, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 11, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 12, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101019009271, 13, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115009272, 1, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115009272, 2, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011115009272, 3, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 1, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 2, 84, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 3, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 4, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 5, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 6, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821009273, 7, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 1, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 2, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 3, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 4, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 5, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 6, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827009274, 7, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010919009275, 1, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010919009275, 2, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010919009275, 3, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010919009275, 4, 143, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 1, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 2, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 3, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 4, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 5, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 6, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 7, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 8, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 9, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 10, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 11, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 12, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 13, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 14, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 15, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 8, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 9, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 10, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 11, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 12, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 13, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223009627, 14, 160, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922009628, 1, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922009628, 2, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922009628, 3, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922009628, 4, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010922009628, 5, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 1, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 2, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 3, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 4, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 5, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508009629, 6, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 1, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 2, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 3, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 4, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 5, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 6, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 7, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 8, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 9, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 10, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 11, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 12, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 13, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 14, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 15, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221009630, 16, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 1, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 2, 186, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 3, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 4, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 5, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 6, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 7, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 8, 180, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 9, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 10, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 11, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009631, 12, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103009632, 1, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103009632, 2, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103009632, 3, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103009632, 4, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 1, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 2, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 3, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 4, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 5, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 6, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 7, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 8, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 9, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 10, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710009633, 11, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 1, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 2, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 3, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 4, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 5, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 6, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 7, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 8, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 9, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 10, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 11, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 12, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 13, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 14, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 15, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303009634, 16, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 1, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 2, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 3, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 4, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 5, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 6, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 7, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 8, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 9, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 10, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 11, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 12, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 13, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 14, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 15, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 16, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105009635, 17, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 1, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 2, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 3, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 4, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 5, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 6, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 7, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 8, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 9, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 10, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 11, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 12, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 13, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 14, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130928009636, 15, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 1, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 2, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 3, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 4, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 5, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 6, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423009637, 7, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 1, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 2, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 3, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 4, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 5, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 6, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 7, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 8, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 9, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 10, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 11, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 12, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 13, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 14, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 15, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 16, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119009638, 17, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 1, 96, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 2, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 3, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 4, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 5, 178, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 6, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 7, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 8, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 9, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 10, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 11, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 12, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 13, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 14, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223009639, 15, 124, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 1, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 2, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 3, 37, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 4, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 5, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 6, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 7, 61, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 8, 66, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 9, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 10, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 11, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 12, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 13, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 14, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 15, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 16, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 17, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301009640, 18, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 1, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 2, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 3, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 4, 98, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 5, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 6, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 7, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 8, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 9, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 10, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 11, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 12, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215009641, 13, 163, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414009642, 1, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414009642, 2, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414009642, 3, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414009642, 4, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 1, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 2, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 3, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 4, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 5, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 6, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 7, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 8, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 9, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819009643, 10, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 1, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 2, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 3, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 4, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 5, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003009644, 6, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 1, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 2, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 3, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 4, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 5, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 6, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 7, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 8, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 9, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 10, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 11, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 12, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 13, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020009645, 14, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 1, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 2, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 3, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 4, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 5, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 6, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 7, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 8, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502009646, 9, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422009647, 1, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422009647, 2, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000422009647, 3, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 1, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 2, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 3, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 4, 101, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 5, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 6, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 7, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030009648, 8, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 1, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 2, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 3, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 4, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 5, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 5, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 6, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 7, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 8, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 9, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 10, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907009976, 11, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 1, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 2, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 3, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 4, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 5, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 6, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 7, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 8, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 9, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 10, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 11, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 12, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 13, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 14, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 15, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307009977, 16, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 1, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 2, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 3, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 4, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 5, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 6, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 7, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 8, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 9, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128009978, 10, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 1, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 2, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 3, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 4, 100, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 5, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 6, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 7, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 8, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 9, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 10, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 11, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 12, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223009979, 13, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 1, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 2, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 3, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 4, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 5, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 6, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 7, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 8, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 9, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 10, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 11, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 12, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 13, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 14, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 15, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211009980, 16, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827009981, 1, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827009981, 2, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827009981, 3, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827009981, 4, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827009981, 5, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001009982, 1, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001009982, 2, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 1, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 2, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 3, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 4, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 5, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 6, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 7, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 8, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 9, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 10, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 11, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 12, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 13, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228009983, 14, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 1, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 2, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 3, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 4, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 5, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 6, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 7, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 8, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 9, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 10, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 11, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 12, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 13, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209009984, 14, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 1, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 2, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 3, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 4, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 5, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 6, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 7, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 8, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 9, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 10, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 11, 33, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 12, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 13, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228009985, 14, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 1, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 2, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 3, 156, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 4, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 5, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 6, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 7, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 8, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 9, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 10, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 11, 156, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 12, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 13, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 14, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 15, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 16, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 17, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201009986, 18, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 1, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 2, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 3, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 4, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 5, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 6, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 7, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 8, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 9, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 10, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 11, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 12, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 13, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 14, 123, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 15, 189, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 16, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131016009987, 17, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 1, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 2, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 3, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 4, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 5, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 6, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 7, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 8, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 9, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709009988, 10, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 1, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 2, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 3, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 4, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 5, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 6, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 7, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 8, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 9, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 10, 170, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 11, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 12, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623009989, 13, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221009990, 1, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221009990, 2, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221009990, 3, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221009990, 4, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221009990, 5, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 1, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 2, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 4, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 5, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 6, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 7, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 8, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 9, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215009991, 10, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 1, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 2, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 3, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 4, 179, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 5, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 6, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 7, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 8, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 9, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 10, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316009992, 11, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 1, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 2, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 3, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 4, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 5, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 6, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 7, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221009993, 8, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 1, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 2, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 3, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 4, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 5, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 6, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 7, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 8, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 9, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 10, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 11, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 12, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621009994, 13, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 1, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 2, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 3, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 4, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 5, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 6, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 7, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 8, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 9, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 10, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 11, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 12, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 13, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 14, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014009995, 15, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 1, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 2, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 3, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 4, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 5, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 6, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925009996, 7, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 2, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 3, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 4, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 5, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 6, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 7, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 8, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 9, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 10, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 11, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 12, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 13, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525008871, 14, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 1, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 2, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 3, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 4, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 5, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131008872, 6, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 1, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 2, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 3, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 4, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 5, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 6, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008873, 7, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008874, 1, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008874, 2, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008874, 3, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008874, 4, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002008874, 5, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 1, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 2, 145, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 3, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 4, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 5, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 6, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 7, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 8, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 9, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 10, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 11, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 12, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 13, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 14, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 15, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113008875, 16, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 1, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 2, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 3, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 4, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 5, 1, 2, 3, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 6, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 7, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 8, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 9, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 10, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 11, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008876, 12, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 1, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 2, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 3, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 4, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 5, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 6, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 7, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 8, 50, 56, 7, 392);
commit;
prompt 93000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 9, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 10, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 11, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 12, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 13, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 14, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424008877, 15, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 1, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 2, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 3, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 4, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 5, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305008878, 6, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008879, 1, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008879, 2, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008879, 3, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008879, 4, 178, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008879, 5, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 1, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 2, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 3, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 4, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 5, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 6, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041020008880, 7, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 1, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 2, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 3, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 4, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 5, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 6, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416008881, 7, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 1, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 2, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 3, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 4, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 5, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 6, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 7, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 8, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 9, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 10, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 11, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 12, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 13, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011008882, 14, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 1, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 2, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 3, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 4, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 5, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 6, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 7, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 8, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 9, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 10, 66, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 11, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616008883, 12, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 1, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 2, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 3, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 4, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 5, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 6, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 7, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030831008884, 8, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229008885, 1, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229008885, 2, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229008885, 3, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229008885, 4, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229008885, 5, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 1, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 2, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 3, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 4, 57, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 5, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 6, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 7, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 8, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 9, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 10, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080522008886, 11, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214008887, 1, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214008887, 2, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214008887, 3, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214008887, 4, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214008887, 5, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124008888, 1, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124008888, 2, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124008888, 3, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124008888, 4, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 1, 103, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 2, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 3, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 4, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 5, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 6, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 7, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 8, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 9, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 10, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 11, 86, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 12, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416008889, 13, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 1, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 2, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 3, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 4, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 5, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 6, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 7, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 8, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 9, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 10, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 11, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 12, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 13, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 14, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100826008890, 15, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 1, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 2, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 3, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 4, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 5, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 6, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 7, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 8, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 9, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 10, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 11, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 12, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 13, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 14, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009008891, 15, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008892, 1, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008892, 2, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008892, 3, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108008892, 4, 135, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 1, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 2, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 3, 112, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 4, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 5, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 6, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 7, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 8, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 9, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 10, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 11, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 12, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 13, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 14, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 15, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 16, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 17, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 18, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209008893, 19, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 1, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 2, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 3, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 4, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 5, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 6, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 7, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060831008894, 8, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008895, 1, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008895, 2, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008895, 3, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008895, 4, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020511008895, 5, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713008896, 1, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713008896, 2, 110, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226009276, 16, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 1, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 2, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 3, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 4, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 5, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 6, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 7, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 8, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 9, 44, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 10, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 11, 156, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805009277, 12, 144, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 1, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 2, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 3, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 4, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 5, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009278, 6, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 1, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 2, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 3, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 4, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 5, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 6, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 7, 100, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040808009279, 8, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 1, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 2, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 3, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 4, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 5, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 6, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 7, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 8, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 9, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 10, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217009280, 11, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 1, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 2, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 3, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 4, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 5, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 6, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 7, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 8, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 9, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 10, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 11, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 12, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 13, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 14, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111009281, 15, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 1, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 2, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 3, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 4, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 5, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 6, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040206009282, 7, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 1, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 2, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 3, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 4, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 5, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 6, 1, 88, 3, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 7, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 8, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 9, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 10, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925009283, 11, 92, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 1, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 2, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 3, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 4, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 5, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 6, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 7, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 8, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 9, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 10, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614009284, 11, 187, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 1, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 2, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 3, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 4, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 5, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 6, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 7, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 8, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 9, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 10, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 11, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 12, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 13, 46, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 14, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 15, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203009285, 16, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921009286, 1, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921009286, 2, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921009286, 3, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 1, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 2, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 3, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 4, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 5, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011120009287, 6, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 1, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 2, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 3, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 4, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 5, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 6, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 7, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 8, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 9, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 10, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 11, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 12, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 13, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 14, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 15, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 16, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131025009288, 17, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807009289, 1, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807009289, 2, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807009289, 3, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010807009289, 4, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 1, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 2, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 3, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 4, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 5, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 6, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 7, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 8, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 9, 82, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 10, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402009290, 11, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 1, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 2, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 3, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 4, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 5, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 6, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 7, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124009291, 8, 182, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 1, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 2, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 3, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 4, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 5, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 6, 8, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 7, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 8, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 9, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 10, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 11, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 12, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 13, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 14, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 15, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909009292, 16, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 1, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 2, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 3, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 4, 54, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 5, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 6, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 7, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 8, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 9, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 10, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 11, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070131009293, 12, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016009294, 1, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016009294, 2, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016009294, 3, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016009294, 4, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016009294, 5, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 1, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 2, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 3, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 4, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 5, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 6, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 7, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 8, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 9, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 10, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 11, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 12, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 13, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 14, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721009295, 15, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 1, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 2, 72, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 3, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 4, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 5, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020318009296, 6, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 1, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 2, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 3, 181, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 4, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 5, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014009297, 6, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 1, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 2, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 3, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 4, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 5, 28, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 6, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 7, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 8, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 9, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 10, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 11, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009298, 12, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 1, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 2, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 3, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 4, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 5, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 6, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 7, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 8, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 9, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 10, 70, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 11, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 12, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 13, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009299, 14, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 1, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 2, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 3, 56, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 4, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 5, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 6, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 6, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 7, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 8, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 9, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927009649, 10, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 1, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 2, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 3, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 4, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 5, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 6, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 7, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 8, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 9, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 10, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 11, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 12, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 13, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 14, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 15, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 16, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325009650, 17, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 1, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 2, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 3, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 4, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 5, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 6, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 7, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050825009651, 8, 165, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 1, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 2, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 3, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 4, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 5, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 6, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 7, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102009652, 8, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 1, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 2, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 3, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 4, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 5, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 6, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 7, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 8, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 9, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 10, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 11, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 12, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021009653, 13, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928009654, 1, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928009654, 2, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202009655, 1, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202009655, 2, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202009655, 3, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202009655, 4, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202009655, 5, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 1, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 2, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 3, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 4, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 5, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 6, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 7, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 8, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 9, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 10, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 11, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 12, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 13, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 14, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 15, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 16, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605009656, 17, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 1, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 2, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 3, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 4, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 5, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 6, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009657, 7, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 1, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 2, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 3, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 4, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 5, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 6, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 7, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 8, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 9, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 10, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 11, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 12, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 13, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705009658, 14, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 1, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 2, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 3, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 4, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 5, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 6, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 7, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 8, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 9, 59, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 10, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 11, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 12, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628009659, 13, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 1, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 2, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 3, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 4, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 5, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 6, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 7, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 8, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 9, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 10, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 11, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416009660, 12, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 1, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 2, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 3, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 4, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 5, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 6, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 7, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 8, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 9, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 10, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 11, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 12, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 13, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 14, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 15, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 16, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 17, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827009661, 18, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 1, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 2, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 3, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 4, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 5, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 6, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 7, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 8, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 9, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 10, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422009662, 11, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 1, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 2, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 3, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 4, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 5, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 6, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 7, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009663, 8, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 1, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 2, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 3, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 4, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 5, 87, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 6, 4, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 7, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 8, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 9, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070906009664, 10, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 1, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 2, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 3, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 4, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 5, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 6, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 7, 165, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 8, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024009665, 9, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826009666, 1, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826009666, 2, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826009666, 3, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826009666, 4, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826009666, 5, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 1, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 2, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 3, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 4, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 5, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 6, 148, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 7, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 8, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706009667, 9, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 1, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 2, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 3, 24, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 4, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 5, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 6, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 7, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 8, 98, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717009668, 9, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 1, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 2, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 3, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 4, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 5, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 6, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 7, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 8, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 9, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 10, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 11, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 12, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 13, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 14, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701009669, 15, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 1, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 2, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 3, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 4, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 5, 190, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009670, 6, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 1, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 2, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 3, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 4, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 5, 53, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 6, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 7, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 8, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 9, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 10, 19, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 11, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 12, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530009671, 13, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 1, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 2, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 3, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 4, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 5, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 7, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 8, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 9, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 10, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 11, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 12, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 13, 121, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 14, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 1, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 2, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 3, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 4, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 5, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 6, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 7, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060819010019, 8, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 1, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 2, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 3, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 4, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 5, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529010020, 6, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920010021, 1, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920010021, 2, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920010021, 3, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920010021, 4, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920010021, 5, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113010022, 1, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113010022, 2, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113010022, 3, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113010022, 4, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912010023, 1, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912010023, 2, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912010023, 3, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912010023, 4, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912010023, 5, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 1, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 2, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 3, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 4, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 5, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 6, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 7, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 8, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 9, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 10, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 11, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426010024, 12, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 1, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 2, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 3, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 4, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 5, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 6, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 7, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803010025, 8, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 1, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 2, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 3, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 4, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 5, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 6, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 7, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 8, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 9, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 10, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 11, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 12, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 13, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 14, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 15, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 16, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010026, 17, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 1, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 2, 136, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 3, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 4, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 5, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 6, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 7, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 8, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 9, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 10, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010027, 11, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 1, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 2, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 3, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 4, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 5, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 6, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 7, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 8, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 9, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 10, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 11, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 12, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 13, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 14, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004010028, 15, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010029, 1, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010029, 2, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010029, 3, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 1, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 2, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 3, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 4, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 5, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 6, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041208010030, 7, 192, 49, 18, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 1, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 2, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 3, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 4, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 5, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 6, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 7, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 8, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 9, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 10, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 11, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 12, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 13, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524010031, 14, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 1, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 2, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 3, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 4, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 5, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 6, 70, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 7, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 8, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 9, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 10, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 11, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 12, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 13, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110010032, 14, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 1, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 2, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 3, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 4, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 5, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 6, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 7, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 8, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828010033, 9, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603010034, 1, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603010034, 2, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603010034, 3, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603010034, 4, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228010035, 1, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228010035, 2, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228010035, 3, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228010035, 4, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228010035, 5, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 1, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 2, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 3, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 4, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 5, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 6, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 7, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218010036, 8, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 1, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 2, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 3, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 4, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 5, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 6, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 7, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 8, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 9, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 10, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 11, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 12, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 13, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 14, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 15, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010037, 16, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 1, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 2, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 3, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 4, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 5, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418010038, 6, 171, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 1, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 2, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 3, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 4, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 5, 132, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 6, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 7, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 8, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 9, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 10, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 11, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 12, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 13, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215010039, 14, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 1, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 2, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 3, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 4, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 5, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 6, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 7, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 8, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 9, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 10, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081230010040, 11, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 1, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 2, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 3, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 4, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 5, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 6, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 7, 91, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 8, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 9, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 10, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 11, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 12, 126, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925010041, 13, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 1, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 2, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 3, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 4, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 5, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 6, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 7, 71, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 8, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 9, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224010042, 10, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 1, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 2, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 3, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 4, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 5, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713008896, 3, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713008896, 4, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 1, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 2, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 3, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 4, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 5, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 6, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 7, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 8, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 9, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 10, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 11, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 12, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 13, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 14, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720008897, 15, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 1, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 2, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 3, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 4, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 5, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 6, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 7, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 8, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 9, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 10, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 11, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 12, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 13, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 14, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 15, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 16, 1, 68, 3, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118008898, 17, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 1, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 2, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 3, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 4, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 5, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 6, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 7, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 8, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 9, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 10, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 11, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 12, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009008899, 13, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 1, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 2, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 3, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 4, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 5, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 6, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 7, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 8, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 9, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 10, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 11, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 12, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813008900, 13, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 1, 37, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 2, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 3, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 4, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 5, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 6, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030812008901, 7, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331008902, 1, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331008902, 2, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331008902, 3, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001008903, 1, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001008903, 2, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001008903, 3, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 1, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 2, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 3, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 4, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 5, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 6, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 7, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 8, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 9, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 10, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 11, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205008904, 12, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922008905, 1, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922008905, 2, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922008905, 3, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922008905, 4, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 1, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 2, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 3, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 4, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 5, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 6, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 7, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 8, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 9, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 10, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 11, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 12, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 13, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413008906, 14, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 1, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 2, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 3, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 4, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 5, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 6, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 7, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 8, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 9, 152, 24, 16, 384);
commit;
prompt 94000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 10, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 11, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 12, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509008907, 13, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519008908, 1, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519008908, 2, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519008908, 3, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519008908, 4, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519008908, 5, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 1, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 2, 24, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 3, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 4, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 5, 68, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 6, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 7, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 8, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 9, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530008909, 10, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 1, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 2, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 3, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 4, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 5, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 6, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 7, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 8, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 9, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 10, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 11, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080610008910, 12, 122, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 1, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 2, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 3, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 4, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 5, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 6, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 7, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050115008911, 8, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114008912, 1, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114008912, 2, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114008912, 3, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 1, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 2, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 3, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 4, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 5, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 6, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 7, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 8, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919008913, 9, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 1, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 2, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 3, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 4, 122, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 5, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 6, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 7, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 8, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 9, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 10, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 11, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 12, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100926008914, 13, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 1, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 2, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 3, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 4, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 5, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 6, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 7, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 8, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 9, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 10, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 11, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 12, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110624008915, 13, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 1, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 2, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 3, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 4, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 5, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 6, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 7, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 8, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 9, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 10, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 11, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103008916, 12, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 1, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 2, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 3, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 4, 189, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 5, 51, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 6, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 7, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 8, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 9, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 10, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 11, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 12, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080216008917, 13, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 1, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 2, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 3, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 4, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 5, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 6, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 7, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 8, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 9, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 10, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 11, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 12, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 13, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 14, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 15, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 16, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101008918, 17, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 1, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 2, 57, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 3, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 4, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 5, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 6, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 7, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231008919, 8, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 7, 84, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 8, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 9, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 10, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716009300, 11, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 1, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 2, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 3, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 4, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 5, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 6, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 7, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 8, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 9, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 10, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 11, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 12, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 13, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 14, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 15, 132, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 16, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421009301, 17, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 1, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 2, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 3, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 4, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 5, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 6, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 7, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826009302, 8, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401009303, 1, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401009303, 2, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401009303, 3, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000401009303, 4, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 1, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 2, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 3, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 4, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 5, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 6, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 7, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 8, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 9, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 10, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 11, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 12, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 13, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 14, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502009304, 15, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 1, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 2, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 3, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 4, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 5, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 6, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707009305, 7, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 1, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 2, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 3, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 4, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 5, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 6, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 7, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 8, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 9, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 10, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 11, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 12, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 13, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 14, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502009306, 15, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015009307, 1, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015009307, 2, 3, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015009307, 3, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015009307, 4, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015009307, 5, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213009308, 1, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213009308, 2, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213009308, 3, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213009308, 4, 68, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021213009308, 5, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 1, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 2, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 3, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 4, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 5, 59, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 6, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 7, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 8, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 9, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 10, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 11, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 12, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 13, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 14, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 15, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507009309, 16, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009310, 1, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009310, 2, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009310, 3, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009310, 4, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009310, 5, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 1, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 2, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 3, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 4, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 5, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 6, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 7, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 8, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 9, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 10, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 11, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 12, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 13, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 14, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008009311, 15, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 1, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 2, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 3, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 4, 24, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 5, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 6, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024009312, 7, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 1, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 2, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 3, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 4, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 5, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 6, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 7, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 8, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 9, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 10, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819009313, 11, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 1, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 2, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 3, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 4, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 5, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 6, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 7, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 8, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 9, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 10, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127009314, 11, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009315, 1, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009315, 2, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009315, 3, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009315, 4, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719009315, 5, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 1, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 2, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 3, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 4, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 5, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 6, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 7, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 8, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060320009316, 9, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916009317, 1, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916009317, 2, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916009317, 3, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916009317, 4, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916009317, 5, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 1, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 2, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 3, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 4, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 5, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 6, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324009318, 7, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 1, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 2, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 3, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 4, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 5, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 6, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 7, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 8, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 9, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 10, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 11, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 12, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706009319, 13, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 1, 91, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 2, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 3, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 4, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 5, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 6, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040605009320, 7, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 1, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 2, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 3, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 4, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 5, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 6, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 7, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 8, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009321, 9, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 1, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 2, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 3, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 4, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 5, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 6, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 7, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 8, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504009322, 9, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 1, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 2, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 3, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 4, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 5, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224009323, 6, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 1, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 2, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 3, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 4, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 5, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 6, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 7, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 8, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 9, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 10, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121009324, 11, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 1, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 2, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 3, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 4, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 5, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 6, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 7, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 8, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 9, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 10, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 11, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 12, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 6, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 7, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425009672, 8, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 1, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 2, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 3, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 4, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 5, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 6, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 7, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 8, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923009673, 9, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 1, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 2, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 3, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 4, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 5, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 6, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 7, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 8, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009674, 9, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 1, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 2, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 3, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 4, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 5, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 6, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 7, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 8, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 9, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123009675, 10, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 1, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 2, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 3, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 4, 19, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 5, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 6, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 7, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 8, 142, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 9, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 10, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 11, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 12, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 13, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121212009676, 14, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009677, 1, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009677, 2, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009677, 3, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009677, 4, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 1, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 2, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 3, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 4, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 5, 134, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 6, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 7, 61, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 8, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 9, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 10, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 11, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 12, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 13, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 14, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 15, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512009678, 16, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 1, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 2, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 3, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 4, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 5, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 6, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 7, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 8, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 9, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 10, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 11, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 12, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 13, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 14, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 15, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 16, 104, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113009679, 17, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 1, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 2, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 3, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 4, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 5, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 6, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 7, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 8, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329009680, 9, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 1, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 2, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 3, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 4, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 5, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 6, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416009681, 7, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 1, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 2, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 3, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 4, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 5, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 6, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 7, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 8, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 9, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 10, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 11, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210009682, 12, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 1, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 2, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 3, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 4, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 5, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 6, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 7, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 8, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 9, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323009683, 10, 58, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 1, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 2, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 3, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 4, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 5, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 6, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 8, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 9, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 10, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 11, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 12, 191, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 13, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 14, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 15, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331009684, 16, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 1, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 2, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 3, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 4, 57, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 5, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 6, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 7, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 8, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 9, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 10, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 11, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 12, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 13, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009685, 14, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 1, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 2, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 3, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 4, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 5, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 6, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 7, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 8, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 9, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009686, 10, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 1, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 2, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 3, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 4, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 5, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 6, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009687, 7, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009688, 1, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426009688, 2, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708009689, 1, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708009689, 2, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708009689, 3, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708009689, 4, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 1, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 2, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 3, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 4, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 5, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311009690, 6, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 1, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 2, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 3, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 4, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 5, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 6, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 7, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 8, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 9, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 10, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 11, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 12, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711009691, 13, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 1, 100, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 2, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 3, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 4, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 5, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 6, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 7, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 8, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928009692, 9, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223009693, 1, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223009693, 2, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223009693, 3, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223009693, 4, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223009693, 5, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208009694, 1, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208009694, 2, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208009694, 3, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208009694, 4, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208009694, 5, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 1, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 2, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 3, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 4, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 5, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 6, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 7, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 8, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 9, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 10, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 11, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 12, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323009695, 13, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 1, 142, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 2, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 3, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 4, 38, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 5, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 6, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 7, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 8, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230009696, 9, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 1, 128, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 2, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 3, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 4, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 5, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 6, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 7, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 8, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 9, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 10, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 11, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 12, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820010090, 13, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725010091, 1, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725010091, 2, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725010091, 3, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725010091, 4, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 1, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 2, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 3, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 4, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 5, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 6, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 7, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628010092, 8, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 1, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 2, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 3, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 4, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 5, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 6, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 7, 135, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 8, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 9, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 10, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 11, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 12, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 13, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010093, 14, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 1, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 2, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 3, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 4, 51, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 5, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 6, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 7, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 8, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 9, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 10, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 11, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 12, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 13, 31, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 14, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 15, 87, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 16, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 17, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 18, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508010094, 19, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 1, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 2, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 3, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 4, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 5, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 6, 111, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 7, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 8, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826010095, 9, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 1, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 2, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 3, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 4, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 5, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 6, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 7, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 8, 99, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 9, 192, 79, 18, 1422);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 10, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 11, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 12, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 13, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 14, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 15, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914010096, 16, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313010097, 1, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313010097, 2, 103, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313010097, 3, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313010097, 4, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 1, 179, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 2, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 3, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 4, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 5, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 6, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 7, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 8, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 9, 182, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 10, 145, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321010098, 11, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210010099, 1, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210010099, 2, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210010099, 3, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210010099, 4, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 1, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 2, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 3, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 4, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 5, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 6, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 7, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 8, 192, 35, 18, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 9, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 10, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 11, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605010100, 12, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 1, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 2, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 3, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 4, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 5, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 6, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 7, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230010101, 8, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 1, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 2, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 3, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 4, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 5, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030314010102, 6, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 1, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 2, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 3, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 4, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 5, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 6, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 7, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 8, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 9, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403010103, 10, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 1, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 2, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 3, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 4, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 5, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 6, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 7, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 8, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 9, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 10, 103, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 11, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 12, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080903010104, 13, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702010105, 1, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702010105, 2, 37, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702010105, 3, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702010105, 4, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702010105, 5, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 1, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 2, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 3, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 4, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 5, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 6, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 7, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 8, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 9, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 10, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 11, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 12, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 13, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815010106, 14, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 1, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 2, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 3, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 4, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 5, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 6, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 7, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 8, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 9, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 10, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222010107, 11, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 1, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 2, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 3, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 4, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 5, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 6, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 7, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060118010108, 8, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 1, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 2, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 3, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 4, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 5, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 6, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 7, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 8, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 9, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 10, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080807010109, 11, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 1, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 2, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 3, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 4, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 5, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 6, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 7, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 8, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 9, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 10, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 11, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 12, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 13, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 14, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 15, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026010110, 16, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613010111, 1, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613010111, 2, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613010111, 3, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613010111, 4, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 1, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 2, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 3, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 4, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 5, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 6, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 7, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 8, 180, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010112, 9, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220010113, 1, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220010113, 2, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220010113, 3, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220010113, 4, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 1, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 2, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 3, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 4, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 5, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 6, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 7, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315010114, 8, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 1, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 2, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 3, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 4, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 1, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 2, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 3, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 4, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 5, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 6, 109, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 7, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 8, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 9, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 10, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831008920, 11, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 1, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 2, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 3, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 4, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 5, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 6, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 7, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 8, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 9, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921008921, 10, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 1, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 2, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 3, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 4, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 5, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 6, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 7, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321008922, 8, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 1, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 2, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 3, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 4, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 5, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 6, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 7, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 8, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 9, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 10, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 11, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 12, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 13, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119008923, 14, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 1, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 2, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 3, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 4, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 5, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 6, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 7, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 8, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 9, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 10, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 11, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 12, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030008924, 13, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 1, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 2, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 3, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 4, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 5, 174, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 6, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 7, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 8, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 9, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 10, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 11, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 12, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 13, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 14, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 15, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 16, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 17, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024008925, 18, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317008926, 1, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317008926, 2, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317008926, 3, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317008926, 4, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 1, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 2, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 3, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 4, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 5, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 6, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 7, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 8, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 9, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109008927, 10, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530008928, 1, 153, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530008928, 2, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016008929, 1, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016008929, 2, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016008929, 3, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016008929, 4, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 1, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 2, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 3, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 4, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 5, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513008930, 6, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 1, 149, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 2, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 3, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 4, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 5, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 6, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 7, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 8, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 9, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 10, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 11, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 12, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519008931, 13, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 1, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 2, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 3, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 4, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 5, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 6, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 7, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 8, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 9, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220008932, 10, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 1, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 2, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 3, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 4, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 5, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 6, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 7, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 8, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 9, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 10, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 11, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 12, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 13, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 14, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 15, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023008933, 16, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 1, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 2, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 3, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 4, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 5, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 6, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 7, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 8, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 9, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 10, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 11, 32, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 12, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 13, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 14, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 15, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121225008934, 16, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 1, 121, 71, 9, 639);
commit;
prompt 95000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 2, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 3, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 4, 90, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 5, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 6, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 7, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 8, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601008935, 9, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 1, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 2, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 3, 90, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 4, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 5, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 6, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 7, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 8, 180, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 9, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 10, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 11, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090506008936, 12, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 1, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 2, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 3, 70, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 4, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 5, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 6, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 7, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 8, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 9, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 10, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 11, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 12, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 13, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 14, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 15, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 16, 73, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503008937, 17, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 1, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 2, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 3, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 4, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 5, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 6, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 7, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 8, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 9, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 10, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 11, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 12, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 13, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 14, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418008938, 15, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 1, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 2, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 3, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 4, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 5, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 6, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 7, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 8, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 9, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 10, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105008939, 11, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 1, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 2, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 3, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 4, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 5, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 6, 125, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 7, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 8, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 9, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 10, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 11, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 12, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220008940, 13, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 1, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 2, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 3, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 4, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 5, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 6, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 7, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 13, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 14, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110715009325, 15, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 1, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 2, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 3, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 4, 166, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 5, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 6, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 7, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 8, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 9, 177, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 10, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 11, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 12, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 13, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009326, 14, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 1, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 2, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 3, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 4, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 5, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 6, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 7, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 8, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 9, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 10, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 11, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 12, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 13, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 14, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 15, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 16, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 17, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140118009327, 18, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 1, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 2, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 3, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 4, 154, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 5, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 6, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 7, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 8, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051016009328, 9, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809009329, 1, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809009329, 2, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809009329, 3, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809009329, 4, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809009329, 5, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 1, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 2, 105, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 3, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 4, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 5, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 6, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 7, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 8, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 9, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 10, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080814009330, 11, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 1, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 2, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 3, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 4, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 5, 30, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 6, 146, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 7, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 8, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 9, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 10, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 11, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 12, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 13, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009331, 14, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 1, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 2, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 3, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 4, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 5, 139, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 6, 44, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 7, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 8, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 9, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 10, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 11, 78, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 12, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521009332, 13, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009333, 1, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009333, 2, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009333, 3, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009333, 4, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009333, 5, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509009334, 1, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509009334, 2, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509009334, 3, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509009334, 4, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509009334, 5, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 1, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 2, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 3, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 4, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 5, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 6, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 7, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 8, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 9, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 10, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 11, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 12, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 13, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 14, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 15, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920009335, 16, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 1, 168, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 2, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 3, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 4, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 5, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 6, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 7, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 8, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 9, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060529009336, 10, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 1, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 2, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 3, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 4, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 5, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 6, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 7, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 8, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 9, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806009337, 10, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 1, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 2, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 3, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 4, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 5, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 6, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 7, 123, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 8, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 9, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 10, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 11, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 12, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112009338, 13, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 1, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 2, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 3, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 4, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 5, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 6, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 7, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 8, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 9, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 10, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021009339, 11, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 1, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 2, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 3, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 4, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 5, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 6, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 7, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 8, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 9, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 10, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 11, 168, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 12, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110709009340, 13, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 1, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 2, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 3, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 4, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 5, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 6, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 7, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 8, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 9, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 10, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 11, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 12, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 13, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806009341, 14, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 1, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 2, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 3, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 4, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 5, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 6, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 7, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 8, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 9, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 10, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 11, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 12, 179, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 13, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 14, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305009342, 15, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 1, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 2, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 3, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 4, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 5, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 6, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 7, 155, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 8, 166, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 9, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 10, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 11, 138, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 12, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081228009343, 13, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 1, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 2, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 3, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 4, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 5, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 6, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 7, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 8, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 9, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 10, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 11, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 12, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 13, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812009344, 14, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109009345, 1, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109009345, 2, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109009345, 3, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109009345, 4, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109009345, 5, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 1, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 2, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 3, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 4, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 5, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 6, 54, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 7, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 8, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 7, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 8, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 9, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 10, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 11, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 12, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 13, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 14, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409009697, 15, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 1, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 2, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 3, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 4, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 5, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 6, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 7, 39, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 8, 181, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040427009698, 9, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000713009699, 1, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000713009699, 2, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 1, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 2, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 3, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 4, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 5, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 6, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 7, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 8, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 9, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 10, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 11, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 12, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 13, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 14, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100128009700, 15, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 1, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 2, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 3, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 4, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 5, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 6, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 7, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 8, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 9, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 10, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119009701, 11, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628009702, 1, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628009702, 2, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628009702, 3, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628009702, 4, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628009702, 5, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 1, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 2, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 3, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 4, 3, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 5, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 6, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 7, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 8, 183, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 9, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 10, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 11, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 12, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 13, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 14, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 15, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120503009703, 16, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 1, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 2, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 3, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 4, 76, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 5, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 6, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 7, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 8, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 9, 112, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 10, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090205009704, 11, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123009705, 1, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123009705, 2, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123009705, 3, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123009705, 4, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 1, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 2, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 3, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 4, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 5, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 6, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 7, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 8, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 9, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 10, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 11, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 12, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 13, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 14, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 15, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009706, 16, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 1, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 2, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 3, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 4, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 5, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 6, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 7, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 8, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 9, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 10, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 11, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114009707, 12, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 1, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 2, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 3, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 4, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 5, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 6, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 7, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 8, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060615009708, 9, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 1, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 2, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 3, 34, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 4, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 5, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 6, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 7, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 8, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026009709, 9, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 1, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 2, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 3, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 4, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 5, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 6, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 7, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913009710, 8, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 1, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 2, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 3, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 4, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 5, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 6, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 7, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 8, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 9, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 10, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 11, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 12, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 13, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 14, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 15, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425009711, 16, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511009712, 1, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511009712, 2, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511009712, 3, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511009712, 4, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511009712, 5, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 1, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 2, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 3, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 4, 129, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 5, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 6, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 7, 188, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 8, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 9, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 10, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208009713, 11, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 1, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 2, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 3, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 4, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 5, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 6, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 7, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050220009714, 8, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 1, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 2, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 3, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 4, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 5, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 6, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 7, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 8, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 9, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 10, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 11, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 12, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 13, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 14, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 15, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 16, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120320009715, 17, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 1, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 2, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 3, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 4, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 5, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040212009716, 6, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 1, 141, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 2, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 3, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 4, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 5, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 6, 153, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 7, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 8, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 9, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 10, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 11, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 12, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104009717, 13, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 1, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 2, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 3, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 4, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 5, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 6, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 7, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 8, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 9, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 10, 147, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207009718, 11, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 1, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 2, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 3, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 4, 25, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 5, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 6, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 7, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209009719, 8, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528009720, 1, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528009720, 2, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528009720, 3, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528009720, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010528009720, 5, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 1, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 2, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 3, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 1, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 2, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 3, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 4, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 5, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 6, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 7, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 8, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 9, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 10, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 11, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919009997, 12, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 1, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 2, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 3, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 4, 185, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 5, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 6, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 7, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 8, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 9, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 10, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 11, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 12, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 13, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 14, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 15, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 16, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 17, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130101009998, 18, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 1, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 2, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 3, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 4, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 5, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 6, 51, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 7, 146, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030121009999, 8, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 1, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 2, 167, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 3, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 4, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 5, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 6, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 7, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 8, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 9, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 10, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 11, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 12, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 13, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 14, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 15, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620010000, 16, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 1, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 2, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 3, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 4, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 5, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 6, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 7, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 8, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 9, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 10, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 11, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 12, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 13, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 14, 134, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 15, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120010001, 16, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 1, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 2, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 3, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 4, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 5, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 6, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325010002, 7, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 1, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 2, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 3, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 4, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 5, 166, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 6, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 7, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 8, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 9, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 10, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 11, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 12, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 13, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 14, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513010003, 15, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 1, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 2, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 3, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 4, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 5, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 6, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 7, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 8, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 9, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 10, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 11, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 12, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 13, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 14, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 15, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222010004, 16, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010005, 1, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010005, 2, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010005, 3, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010005, 4, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010005, 5, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 1, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 2, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 3, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 4, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 5, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 6, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 7, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 8, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 9, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 10, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 11, 122, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 12, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 13, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 14, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010006, 15, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206010007, 1, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206010007, 2, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001206010007, 3, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 1, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 2, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 3, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 4, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 5, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 6, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 7, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 8, 26, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126010008, 9, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 2, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 3, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 4, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 5, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 6, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 7, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 8, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 9, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 10, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 11, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010009, 12, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 1, 70, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 2, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 3, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 4, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 5, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020317010010, 6, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 1, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 2, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 3, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 4, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 5, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 6, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 7, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 8, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 9, 115, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 10, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917010011, 11, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 1, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 2, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 3, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 4, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 5, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 6, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 7, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 8, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 9, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 10, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 11, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 12, 134, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 13, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 14, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 15, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 16, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 17, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140312010012, 18, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 1, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 2, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 3, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 4, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 5, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 6, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 7, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 8, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 9, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 10, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 11, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 12, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522010013, 13, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 1, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 2, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 3, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 4, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 5, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 6, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 7, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 8, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103010014, 9, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 1, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 2, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 3, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 4, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 5, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 6, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 7, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 8, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071122010015, 9, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 1, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 2, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 3, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 4, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 5, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010016, 6, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 1, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 2, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 3, 110, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 4, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 5, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 6, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 7, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 8, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 9, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515010017, 10, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 1, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 2, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 3, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 4, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 5, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221010018, 6, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 8, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 9, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 10, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 11, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 12, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 13, 31, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 14, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618008941, 15, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 1, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 2, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 3, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 4, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 5, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 6, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 7, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 8, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 9, 5, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008942, 10, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 1, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 2, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 3, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 4, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 5, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 6, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115008943, 7, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 1, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 2, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 3, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 4, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 5, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 6, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 7, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 8, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 9, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 10, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 11, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 12, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 13, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008944, 14, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 1, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 2, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 3, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 4, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 5, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910008945, 6, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 1, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 2, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 3, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 4, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 5, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 6, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 7, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 8, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 9, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028008946, 10, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008947, 1, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008947, 2, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008947, 3, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930008947, 4, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 1, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 2, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 3, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 4, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 5, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 6, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 7, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 8, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 9, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 10, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 11, 145, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 12, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 13, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 14, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 15, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 16, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 17, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130327008948, 18, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 1, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 2, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 3, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 4, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 5, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 6, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 7, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 8, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220008949, 9, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 1, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 2, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 3, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 4, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 5, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 6, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 7, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 8, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 9, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 10, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405008950, 11, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 1, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 2, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 3, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 4, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 5, 159, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 6, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 7, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 8, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 9, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 10, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091224008951, 11, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 1, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 2, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 3, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 4, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 5, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630008952, 6, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008953, 1, 154, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008953, 2, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008953, 3, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008953, 4, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020425008953, 5, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 1, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 2, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 3, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 4, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 5, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 6, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 7, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929008954, 8, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 1, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 2, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 3, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 4, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 5, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 6, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 7, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 8, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 9, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 10, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 11, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 12, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913008955, 13, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 1, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 2, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 3, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 4, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 5, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 6, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 7, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 8, 8, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 9, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 10, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 11, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622008956, 12, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215008957, 1, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215008957, 2, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001215008957, 3, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 1, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 2, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 3, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 4, 192, 22, 18, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 5, 1, 53, 3, 159);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 6, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620008958, 7, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 1, 149, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 2, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 3, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 4, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 5, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 6, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 7, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 8, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 9, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 10, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 11, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406008959, 12, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 1, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 2, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 3, 64, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 4, 32, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 5, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 6, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 7, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 8, 56, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 9, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312008960, 10, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825008961, 1, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825008961, 2, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825008961, 3, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825008961, 4, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 1, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 2, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 3, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 4, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 5, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 6, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008962, 7, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 1, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 2, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 3, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 4, 122, 40, 10, 400);
commit;
prompt 96000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 5, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 6, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522008963, 7, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 1, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 2, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 3, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 4, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 5, 30, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 6, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 7, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060822008964, 8, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 1, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 2, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 3, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 4, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 5, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 6, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126008965, 7, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 1, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 2, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 3, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 4, 181, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 5, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 6, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 7, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 8, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 9, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 10, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205008966, 11, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 1, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 2, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 3, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 4, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 5, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 6, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 7, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 8, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307008967, 9, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 1, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 2, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603009346, 9, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 1, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 2, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 3, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 4, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 5, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 6, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 7, 48, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 8, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 9, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 10, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 11, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 12, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 13, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009347, 14, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 1, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 2, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 3, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 4, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 5, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 6, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 7, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 8, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 9, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 10, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 11, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 12, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 13, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 14, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721009348, 15, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 1, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 2, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 3, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 4, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 5, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 6, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 7, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 8, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 9, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 10, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009349, 11, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009350, 1, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009350, 2, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009350, 3, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 1, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 2, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 3, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 4, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 5, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 6, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 7, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 8, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 9, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 10, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 11, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 12, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 13, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 14, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608009351, 15, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 1, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 2, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 3, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 4, 137, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 5, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 6, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 7, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 8, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 9, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 10, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 11, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 12, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 13, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 14, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 15, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 16, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127009352, 17, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 1, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 2, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 3, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 4, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 5, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 6, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 7, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 8, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 9, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 10, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 11, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 12, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 13, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127009353, 14, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 1, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 2, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 3, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 4, 192, 16, 18, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 5, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 6, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 7, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 8, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 9, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 10, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908009354, 11, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 1, 38, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 2, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 3, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 4, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 5, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 6, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 7, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 8, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 9, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 10, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 11, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 12, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204009355, 13, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 1, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 2, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 3, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 4, 145, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 5, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 6, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 7, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 8, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 9, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 10, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 11, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 12, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917009356, 13, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 1, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 2, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 3, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 4, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 5, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 6, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 7, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821009357, 8, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 1, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 2, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 3, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 4, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 5, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 6, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 7, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 8, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 9, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 10, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 11, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 12, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 13, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 14, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 15, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723009358, 16, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 1, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 2, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 3, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 4, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 5, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 6, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 7, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 8, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 9, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 10, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 11, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 12, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 13, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112009359, 14, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 1, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 2, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 3, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 4, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 5, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 6, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 7, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 8, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 9, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 10, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 11, 139, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 12, 95, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090313009360, 13, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 1, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 2, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 3, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 4, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 5, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 6, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 7, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 8, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904009361, 9, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 1, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 2, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 3, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 4, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 5, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 6, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 7, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 8, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 9, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 10, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 11, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 12, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 13, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 14, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 15, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 16, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209009362, 17, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 1, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 2, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 3, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 4, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 5, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 6, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 7, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 8, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 9, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 10, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215009363, 11, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527009364, 1, 182, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527009364, 2, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527009364, 3, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020527009364, 4, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 1, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 2, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 3, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 4, 122, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 5, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 6, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 7, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 8, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 9, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 10, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 11, 34, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 12, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 13, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 14, 192, 56, 18, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 15, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009365, 16, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 1, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 2, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 3, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 4, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 4, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 5, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 6, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 7, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 8, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 9, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 10, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 11, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 12, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111009721, 13, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 1, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 2, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 3, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 4, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 5, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 6, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 7, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 8, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 9, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503009722, 10, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 1, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 2, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 3, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 4, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 5, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 6, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 7, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 8, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 9, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 10, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 11, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080526009723, 12, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 1, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 2, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 3, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 4, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 5, 170, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 6, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 7, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 8, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 9, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130009724, 10, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 1, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 2, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 3, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 4, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 5, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 6, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 7, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 8, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 9, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 10, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 11, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 12, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221009725, 13, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 1, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 2, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 3, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 4, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 5, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105009726, 6, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 1, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 2, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 3, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 4, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 5, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224009727, 6, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 1, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 2, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 3, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 4, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 5, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 6, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609009728, 7, 184, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306009729, 1, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306009729, 2, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306009729, 3, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306009729, 4, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306009729, 5, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 1, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 2, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 3, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 4, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 5, 94, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 6, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 7, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 8, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 9, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 10, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 11, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 12, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 13, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105009730, 14, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 1, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 2, 192, 95, 18, 1710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 3, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 4, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 5, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021107009731, 6, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 1, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 2, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 3, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 4, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 5, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 6, 186, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009732, 7, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421009733, 1, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421009733, 2, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421009733, 3, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421009733, 4, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 1, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 2, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 3, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 4, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 5, 22, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 6, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 7, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 8, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 9, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 10, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 11, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 12, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 13, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 14, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121004009734, 15, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 1, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 2, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 3, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 4, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 5, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214009735, 6, 138, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 1, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 2, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 3, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 4, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 5, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 6, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 7, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 8, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 9, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 10, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 11, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028009736, 12, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 1, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 2, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 4, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 5, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 6, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 7, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 8, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 9, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 10, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 11, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 12, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 13, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 14, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 15, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816009737, 16, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907009738, 1, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907009738, 2, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907009738, 3, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907009738, 4, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108009739, 1, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108009739, 2, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108009739, 3, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108009739, 4, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212009740, 1, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212009740, 2, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212009740, 3, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212009740, 4, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212009740, 5, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 1, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 2, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 3, 173, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 4, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 5, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104009741, 6, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 1, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 2, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 3, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 4, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 5, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 6, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 7, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 8, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 9, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 10, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 11, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 12, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 13, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 14, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131127009742, 15, 41, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 1, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 2, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 3, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 4, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 5, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 6, 163, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 7, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 8, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702009743, 9, 73, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 1, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 2, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 3, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 4, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 5, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 6, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 7, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 8, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 9, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 10, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 11, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823009744, 12, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 1, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 2, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 3, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 4, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 5, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 6, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 7, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 8, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 9, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 10, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 11, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 12, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 13, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 14, 63, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 15, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120418009745, 16, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 1, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 2, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 3, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 4, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 5, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 6, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 7, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 8, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 9, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 6, 178, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 7, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 8, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010043, 9, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919010044, 1, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919010044, 2, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919010044, 3, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919010044, 4, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601010045, 1, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601010045, 2, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601010045, 3, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601010045, 4, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002010046, 1, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002010046, 2, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002010046, 3, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001002010046, 4, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 1, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 2, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 3, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 4, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 5, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 6, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 7, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 8, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 9, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 10, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 11, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 12, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 13, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 14, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702010047, 15, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 1, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 2, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 3, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 4, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 5, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 6, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 7, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 8, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 9, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 10, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 11, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 12, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 13, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 14, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 15, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 16, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 17, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404010048, 18, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 1, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 2, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 3, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 4, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 5, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 6, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 7, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 8, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 9, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 10, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 11, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 12, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 13, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100915010049, 14, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010050, 1, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010050, 2, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010050, 3, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010050, 4, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010050, 5, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731010051, 1, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731010051, 2, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731010051, 3, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731010051, 4, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 1, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 2, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 3, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 4, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 5, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 6, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 7, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 8, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 9, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205010052, 10, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 1, 55, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 2, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 3, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 4, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 5, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 6, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 7, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 8, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 9, 93, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 10, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010053, 11, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 1, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 2, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 3, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 4, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 5, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 6, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 7, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 8, 69, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 9, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 10, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010054, 11, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506010055, 1, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506010055, 2, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506010055, 3, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506010055, 4, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506010055, 5, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 1, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 2, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 3, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 4, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 5, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 6, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 7, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 8, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 9, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 10, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 11, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 12, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 13, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 14, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417010056, 15, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 1, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 2, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 3, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 4, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 5, 192, 76, 18, 1368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 6, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 7, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 8, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 9, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 10, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 11, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 12, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 13, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 14, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 15, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010057, 16, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 1, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 2, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 3, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 4, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 5, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 6, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320010058, 7, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 1, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 2, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 3, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 4, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 5, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 6, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 7, 9, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 8, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904010059, 9, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 1, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 2, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 3, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 4, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 5, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 6, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 7, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918010060, 8, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 1, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 2, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 3, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 4, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 5, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 6, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 7, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 8, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 9, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 10, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 11, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 12, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205010061, 13, 67, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 1, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 2, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 3, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 4, 119, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 5, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 6, 109, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 7, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 8, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 9, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 10, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 11, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 12, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 13, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 14, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 15, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010062, 16, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922010063, 1, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922010063, 2, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922010063, 3, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922010063, 4, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000922010063, 5, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 1, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 2, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 3, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 4, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 5, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 6, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416010064, 7, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 1, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 2, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 3, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 4, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 5, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 6, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 7, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 8, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 9, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 10, 187, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 11, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 12, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020010065, 13, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010066, 1, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010066, 2, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010066, 3, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010066, 4, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010066, 5, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 1, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 2, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 3, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 4, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 5, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 6, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 7, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 8, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 9, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 10, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 11, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 12, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 13, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 14, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204010067, 15, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 3, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 4, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 5, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 6, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 7, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 8, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 9, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 10, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 11, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 12, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 13, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 14, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506008968, 15, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 1, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 2, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 3, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 4, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 5, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 6, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 7, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 8, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 9, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 10, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329008969, 11, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 1, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 2, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 3, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 4, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 5, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 6, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 7, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 8, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 9, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 10, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110008970, 11, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 1, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 2, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 3, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 4, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 5, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 6, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 7, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 8, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 9, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 10, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 11, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 12, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 13, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 14, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721008971, 15, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 1, 138, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 2, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 3, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 4, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 5, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 6, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 7, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 8, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 9, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 10, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110008972, 11, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 1, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 2, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 3, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 4, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 5, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208008973, 6, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008974, 1, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008974, 2, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008974, 3, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115008974, 4, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 1, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 2, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 3, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 4, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 5, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 6, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 7, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 8, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 9, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409008975, 10, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320008976, 1, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320008976, 2, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320008976, 3, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320008976, 4, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 1, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 2, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 3, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 4, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 5, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 6, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 7, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 8, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 9, 139, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 10, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 11, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 12, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 13, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 14, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 15, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 16, 101, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 17, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103008977, 18, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428008978, 1, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428008978, 2, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428008978, 3, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428008978, 4, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708008979, 1, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708008979, 2, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708008979, 3, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020708008979, 4, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 1, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 2, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 3, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 4, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 5, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 6, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 7, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 8, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 9, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 10, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206008980, 11, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 1, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 2, 58, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 3, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 4, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 5, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 6, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 7, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 8, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 9, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618008981, 10, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 1, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 2, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 4, 34, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 5, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 6, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508008982, 7, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 1, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 2, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 3, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 4, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 5, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801008983, 6, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 1, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 2, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 3, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 4, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 5, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 6, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 7, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 8, 77, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 9, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 10, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 11, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 12, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121008984, 13, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 1, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 2, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 3, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 4, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 5, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 6, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 7, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 8, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324008985, 9, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 1, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 2, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 3, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 4, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 5, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009008986, 6, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 1, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 2, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 3, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 4, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 5, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 6, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 7, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 8, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 9, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 10, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 11, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 12, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 13, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 14, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 15, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 16, 130, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008987, 17, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 1, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 2, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 3, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 4, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 5, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 6, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309008988, 7, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 1, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 2, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 3, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 4, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 5, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 6, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 7, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 8, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 9, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070719008989, 10, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 1, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 2, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 3, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 4, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 5, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 6, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 7, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 8, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 9, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 10, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 11, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 12, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 13, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 14, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 15, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 16, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 17, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904008990, 18, 111, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 1, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 2, 81, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 3, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 4, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 5, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 6, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925008991, 7, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 1, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 2, 59, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 3, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 4, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 5, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 6, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 7, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 5, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 6, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607009366, 7, 182, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 1, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 2, 93, 2, 12, 24);
commit;
prompt 97000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 3, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 4, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 5, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 6, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 7, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 8, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 9, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 10, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 11, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 12, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 13, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 14, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 15, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 16, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421009367, 17, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 1, 56, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 2, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 3, 168, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 4, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 5, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 6, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 7, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122009368, 8, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008009369, 1, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008009369, 2, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008009369, 3, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008009369, 4, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008009369, 5, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 1, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 2, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 3, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 4, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 5, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009370, 6, 71, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 1, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 2, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 3, 31, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 4, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 5, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 6, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 7, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 8, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 9, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 10, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 11, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 12, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 13, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 14, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102009371, 15, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 1, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 2, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 3, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 4, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 5, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 6, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 7, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 8, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 9, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913009372, 10, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 1, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 2, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 3, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 4, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 5, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 6, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 7, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 8, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 9, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 10, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 11, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214009373, 12, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 1, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 2, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 3, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 4, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 5, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 6, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 7, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 8, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 9, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 10, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 11, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 12, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015009374, 13, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 1, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 2, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 3, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 4, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 5, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 6, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 7, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 8, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 9, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 10, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 11, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 12, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831009375, 13, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 1, 167, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 2, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 3, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 4, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 5, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 6, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614009376, 7, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 1, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 2, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 3, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 4, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 5, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 6, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920009377, 7, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 1, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 2, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 3, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 4, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 5, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 6, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 7, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 8, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 9, 19, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 10, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 11, 153, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 12, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422009378, 13, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 1, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 2, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 3, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 4, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 5, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 6, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 7, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 8, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 9, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 10, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 11, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 12, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091121009379, 13, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 1, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 2, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 3, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 4, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 5, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 6, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 7, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 8, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 9, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 10, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 11, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 12, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 13, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 14, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100919009380, 15, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 1, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 2, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 3, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 4, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 5, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 6, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 7, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 8, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 9, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 10, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 11, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 12, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 13, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111125009381, 14, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 1, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 2, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 3, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 4, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 5, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 6, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 7, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119009382, 8, 176, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 1, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 2, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 3, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 4, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 5, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 6, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 7, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 8, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331009383, 9, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 1, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 2, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 3, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 4, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 5, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 6, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 7, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 8, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 9, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 10, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 11, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 12, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 13, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413009384, 14, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 1, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 2, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 3, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 4, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 5, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 6, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 7, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 8, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 9, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 10, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002009385, 11, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727009386, 1, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727009386, 2, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727009386, 3, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727009386, 4, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 1, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 2, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 3, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 4, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 5, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 6, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225009387, 7, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 1, 44, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 2, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 3, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 4, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 5, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 6, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 7, 82, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 8, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 9, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 10, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 11, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 12, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 13, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 14, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 15, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 10, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 11, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009746, 12, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303009747, 1, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303009747, 2, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 1, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 2, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 3, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 4, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 5, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 6, 23, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 7, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 8, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 9, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 10, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 11, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 12, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 13, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 14, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100805009748, 15, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 1, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 2, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 3, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 4, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 5, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 6, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 7, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 8, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222009749, 9, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 1, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 2, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 3, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 4, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 5, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 6, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 7, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 8, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 9, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 10, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 11, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130009750, 12, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 1, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 2, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 3, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 4, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 5, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 6, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 7, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 8, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 9, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 10, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 11, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 12, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 13, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010009751, 14, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 1, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 2, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 3, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 4, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 5, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 6, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 7, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 8, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 9, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 10, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124009752, 11, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 1, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 2, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 3, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 4, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 5, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 6, 88, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 7, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 8, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 9, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 10, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 11, 192, 14, 18, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 12, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 13, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 14, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620009753, 15, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708009754, 1, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708009754, 2, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708009754, 3, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 1, 27, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 2, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 3, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 4, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 5, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 6, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 7, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 8, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 9, 74, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 10, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 11, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 12, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 13, 95, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 14, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 15, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 16, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 17, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023009755, 18, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 1, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 2, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 3, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 4, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 5, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 6, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 7, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 8, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060401009756, 9, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 1, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 2, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 3, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 4, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 5, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 6, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 7, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 8, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 9, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 10, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 11, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 12, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 13, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 14, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 15, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 16, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131223009757, 17, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 1, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 2, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 3, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 4, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 5, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 6, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 7, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 8, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 9, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 10, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 11, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 12, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 13, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 14, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 15, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 16, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 17, 134, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127009758, 18, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 1, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 3, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 4, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 5, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 6, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 7, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 8, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 9, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 10, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 11, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 12, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 13, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101005009759, 14, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 1, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 2, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 3, 46, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 4, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 5, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 6, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 7, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 8, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 9, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 10, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 11, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 12, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103009760, 13, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 1, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 2, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 3, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 4, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 5, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009761, 6, 171, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 1, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 2, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 3, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 4, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 5, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 6, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 7, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 8, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051020009762, 9, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 1, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 2, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 3, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 4, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 5, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 6, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 7, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 8, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 9, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103009763, 10, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 1, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 2, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 3, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 4, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 5, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 6, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 7, 60, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 8, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 9, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 10, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 11, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 12, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 13, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312009764, 14, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 1, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 2, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 3, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 4, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 5, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 6, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 7, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702009765, 8, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 1, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 2, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 3, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 4, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 5, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 6, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 7, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050202009766, 8, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 1, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 2, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 3, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 4, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 5, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 6, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 7, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009767, 8, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520009768, 1, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520009768, 2, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520009768, 3, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 12, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 13, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 14, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 15, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 16, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821008620, 17, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 1, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 2, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 3, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 4, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 5, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 6, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 7, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 8, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 9, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080101008621, 10, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 1, 59, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 2, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 3, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 4, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 5, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 6, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 7, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 8, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 9, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 10, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530008622, 11, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213008623, 1, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213008623, 2, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213008623, 3, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213008623, 4, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008624, 1, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008624, 2, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901008624, 3, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 1, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 2, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 3, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 4, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 5, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 6, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 7, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 8, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 9, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 10, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 11, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 12, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 13, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 14, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 15, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 16, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 17, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120008625, 18, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 1, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 2, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 3, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 4, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 5, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 6, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 7, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 8, 76, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 9, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 10, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 11, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 12, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 13, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 14, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 15, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510008626, 16, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 1, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 2, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 3, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 4, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 5, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 6, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 7, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 8, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 9, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 10, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618008627, 11, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 1, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 2, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 3, 14, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 4, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 5, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 6, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 7, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 8, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 9, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 10, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 11, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 12, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 13, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 14, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 15, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 16, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120920008628, 17, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008629, 1, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008629, 2, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008629, 3, 15, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416008629, 4, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 1, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 2, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 3, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 4, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 5, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 6, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 7, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 8, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 9, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 10, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404008630, 11, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 1, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 2, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 3, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 4, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 5, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 6, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 7, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 8, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 9, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101008631, 10, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 1, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 2, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 3, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 4, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 5, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 6, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 7, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 8, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 9, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 10, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 11, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 12, 1, 18, 3, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 13, 1, 98, 3, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 14, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 15, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 16, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 17, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140116008632, 18, 107, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 1, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 2, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 3, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 4, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 5, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 6, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 7, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 8, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 9, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 10, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 11, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 12, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 13, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 14, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 15, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503008633, 16, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 1, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 2, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 3, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 4, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 5, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 6, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 7, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 8, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 9, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 10, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 11, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 12, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 13, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 14, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 15, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 16, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 17, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130814008634, 18, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722008635, 1, 47, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722008635, 2, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722008635, 3, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722008635, 4, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 1, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 2, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 3, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 4, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 5, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 6, 188, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 7, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 8, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 9, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 10, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 11, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207008636, 12, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 1, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 2, 32, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 3, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 4, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 5, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 6, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 7, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 8, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 9, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126008637, 10, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 1, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 2, 134, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 3, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 4, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 5, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 6, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 7, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 8, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061104008638, 9, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 1, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 2, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 3, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 4, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 5, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 6, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 7, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 8, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 9, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 10, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 11, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 12, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 13, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002008639, 14, 144, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 1, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 2, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 3, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 4, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 5, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 6, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 7, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 8, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 9, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 10, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218008640, 11, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030618008641, 1, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030618008641, 2, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030618008641, 3, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030618008641, 4, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030618008641, 5, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822008642, 1, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 8, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 9, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 10, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 11, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 12, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 13, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 14, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 15, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121008992, 16, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512008993, 1, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512008993, 2, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512008993, 3, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512008993, 4, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 1, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 2, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 3, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 4, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 5, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 6, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 7, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008994, 8, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 1, 192, 78, 18, 1404);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 2, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 3, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 4, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 5, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 6, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 7, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205008995, 8, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 1, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 2, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 3, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 4, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 5, 159, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 6, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 7, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 8, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 9, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 10, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 11, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 12, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 13, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 14, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406008996, 15, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 1, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 2, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 3, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 4, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 5, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 6, 179, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 7, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 8, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 9, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 10, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 11, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226008997, 12, 1, 49, 3, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 1, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 2, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 3, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 4, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 5, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 6, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 7, 147, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 8, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 9, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 10, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 11, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 12, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817008998, 13, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 1, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 2, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 3, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 4, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 5, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 6, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 7, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 8, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 9, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 10, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 11, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 12, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 13, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 14, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 15, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 16, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321008999, 17, 84, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 1, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 2, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 3, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 4, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 5, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 6, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 7, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 8, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 9, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 10, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 11, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 12, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 13, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 14, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120202009000, 15, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320009001, 1, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320009001, 2, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320009001, 3, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320009001, 4, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320009001, 5, 77, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 1, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 2, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 3, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 4, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 5, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 6, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 7, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 8, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 9, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 10, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 11, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519009002, 12, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 1, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 2, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 3, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 4, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 5, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 6, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 7, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417009003, 8, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603009004, 1, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603009004, 2, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603009004, 3, 189, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 1, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 2, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 3, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 4, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 5, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727009005, 6, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 1, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 2, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 3, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 4, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 5, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 6, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 7, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 8, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 9, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 10, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 11, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 12, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 13, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 14, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718009006, 15, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 1, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 2, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 3, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 4, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 5, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 6, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 7, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 8, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 9, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 10, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 11, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 12, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 13, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 14, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 15, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 16, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525009007, 17, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 1, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 2, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 3, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 4, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 5, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 6, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 7, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 8, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 9, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 10, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 11, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730009008, 12, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 1, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 2, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 3, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 4, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 5, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 6, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 7, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 8, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 9, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602009009, 10, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 1, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 2, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 3, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 4, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 5, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 6, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603009010, 7, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 1, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 2, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 3, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 4, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 5, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211009011, 6, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 1, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 2, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 3, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 4, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 5, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 6, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 7, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 8, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 9, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 10, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 11, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 12, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 13, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 14, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 15, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 16, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 17, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703009012, 18, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 1, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 2, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 3, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 4, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 5, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 6, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 7, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920009013, 8, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 1, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 2, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 3, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 4, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 5, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 6, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 7, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 8, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 9, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 10, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 11, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 12, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 16, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103009388, 17, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 1, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 2, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 3, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 4, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 5, 117, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 6, 189, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 7, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117009389, 8, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 1, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 2, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 3, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 4, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 5, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815009390, 6, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 1, 101, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 2, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 3, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 4, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 5, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 6, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 7, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 8, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 9, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 10, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302009391, 11, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 1, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 2, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 3, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 4, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 5, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 6, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 7, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 8, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 9, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717009392, 10, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 1, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 2, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 3, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 4, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 5, 31, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 6, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 7, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 8, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009393, 9, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012009394, 1, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012009394, 2, 73, 14, 6, 84);
commit;
prompt 98000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012009394, 3, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012009394, 4, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021012009394, 5, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 1, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 2, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 3, 91, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 4, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 5, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 6, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 7, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 8, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061004009395, 9, 11, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009396, 1, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009396, 2, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009396, 3, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009396, 4, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009396, 5, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 1, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 2, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 3, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 4, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 5, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 6, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 7, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 8, 127, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 9, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 10, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 11, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 12, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 13, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 14, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 15, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130610009397, 16, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 1, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 2, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 3, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 4, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 5, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 6, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 7, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 8, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 9, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620009398, 10, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 1, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 2, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 3, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 4, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 5, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 6, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 7, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 8, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 9, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121009399, 10, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 1, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 2, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 3, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 4, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 5, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 6, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719009400, 7, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 1, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 2, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 3, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 4, 1, 85, 3, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 5, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109009401, 6, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613009402, 1, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613009402, 2, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613009402, 3, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613009402, 4, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 1, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 2, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 3, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 4, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 5, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 6, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 7, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 8, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 9, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 10, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 11, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 12, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 13, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 14, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 15, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 16, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430009403, 17, 171, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 1, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 2, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 3, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 4, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 5, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 6, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 7, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 8, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827009404, 9, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204009405, 1, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204009405, 2, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204009405, 3, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204009405, 4, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204009405, 5, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 1, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 2, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 3, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 4, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 5, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111009406, 6, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 1, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 2, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 3, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 4, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 5, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 6, 56, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 7, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 8, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 9, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 10, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 11, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 12, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 13, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 14, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 15, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 16, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508009407, 17, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 1, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 2, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 3, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 4, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 5, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 6, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 7, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 8, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 9, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 10, 55, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117009408, 11, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703009409, 1, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703009409, 2, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703009409, 3, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 1, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 2, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 3, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 4, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 5, 78, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 6, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 7, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 8, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060221009410, 9, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110009411, 1, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110009411, 2, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110009411, 3, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110009411, 4, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110009411, 5, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009412, 1, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009412, 2, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009412, 3, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 1, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 2, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 3, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 4, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 5, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 6, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 7, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 8, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 9, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009413, 10, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 1, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 2, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 3, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 4, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 5, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 6, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 7, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 8, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 9, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 10, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 11, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 12, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 13, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 14, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 15, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 16, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 17, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 18, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140202009414, 19, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 1, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 2, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 3, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 4, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 5, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 6, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 7, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520009768, 4, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 1, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 2, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 3, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 4, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 5, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 6, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 7, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 8, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201009769, 9, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 1, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 2, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 3, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 4, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 5, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 6, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 7, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061228009770, 8, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715009771, 1, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715009771, 2, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715009771, 3, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715009771, 4, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 1, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 2, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 3, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 4, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 5, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 6, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 7, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 8, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 9, 117, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 10, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 11, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090110009772, 12, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 1, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 2, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 3, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 4, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 5, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 6, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 7, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 8, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 9, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 10, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 11, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 12, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225009773, 13, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531009774, 1, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531009774, 2, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531009774, 3, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531009774, 4, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531009774, 5, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 1, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 2, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 3, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 4, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 5, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 6, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 7, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 8, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 9, 114, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 10, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 11, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 12, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020009775, 13, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609009776, 1, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609009776, 2, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609009776, 3, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 1, 51, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 2, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 3, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 4, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 5, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 6, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 7, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 8, 6, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 9, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 10, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 11, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 12, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 13, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 14, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 15, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121208009777, 16, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 1, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 2, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 3, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 4, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 5, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 6, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 7, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 8, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 9, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 10, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 11, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 12, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 13, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616009778, 14, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 1, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 2, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 3, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 4, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 5, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 6, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 7, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 8, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 9, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 10, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 11, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 12, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 13, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 14, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 15, 138, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 16, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018009779, 17, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715009780, 1, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715009780, 2, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715009780, 3, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715009780, 4, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218009781, 1, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218009781, 2, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218009781, 3, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 1, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 2, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 3, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 4, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 5, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030310009782, 6, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 1, 99, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 2, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 3, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 4, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 5, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 6, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 7, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 8, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 9, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 10, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 11, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 12, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 13, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009783, 14, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 1, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 2, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 3, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 4, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 5, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 6, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 7, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 8, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 9, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 10, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 11, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 12, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123009784, 13, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 1, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 2, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 3, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 4, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 5, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 6, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009785, 7, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 1, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 2, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 3, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 4, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 5, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 6, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 7, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 8, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 9, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060607009786, 10, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 1, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 2, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 3, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 4, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 5, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 6, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 7, 30, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 8, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 9, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017009787, 10, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 1, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 2, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 3, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 4, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 5, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 6, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 7, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 8, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 9, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 10, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 11, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 12, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 13, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013009788, 14, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 1, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 2, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 3, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 4, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 5, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 6, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 7, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 8, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 9, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 10, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 11, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 12, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304009789, 13, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010318009790, 1, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010318009790, 2, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010318009790, 3, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 1, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 2, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 3, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 4, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 5, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 6, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 7, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 8, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 9, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 10, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 11, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 12, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716009791, 13, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 1, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 2, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 3, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 4, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 5, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 6, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 7, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 8, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 9, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 10, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 11, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 12, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 13, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 14, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822008642, 2, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822008642, 3, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822008642, 4, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822008642, 5, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 1, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 2, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 3, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 4, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 5, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 6, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 7, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 8, 12, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 9, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506008643, 10, 42, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 1, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 2, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 3, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 4, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 5, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 6, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 7, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226008644, 8, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 1, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 2, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 3, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 4, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 5, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 6, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 7, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 8, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 9, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 10, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 11, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328008645, 12, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 1, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 2, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 3, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 4, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 5, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 6, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 7, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 8, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 9, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070524008646, 10, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 1, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 2, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 3, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 4, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 5, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013008647, 6, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 1, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 2, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 3, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 4, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 5, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 6, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 7, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 8, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 9, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 10, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707008648, 11, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 1, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 2, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 3, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 4, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 5, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 6, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 7, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 8, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 9, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 10, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 11, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 12, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 13, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 14, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 15, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608008649, 16, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 1, 148, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 2, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 3, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 4, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 5, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 6, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 7, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 8, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 9, 56, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 10, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 11, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 12, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 13, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 14, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317008650, 15, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221008651, 1, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221008651, 2, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221008651, 3, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221008651, 4, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221008651, 5, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710008652, 1, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000710008652, 2, 116, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 1, 153, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 2, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 3, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 4, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 5, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 6, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020206008653, 7, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 1, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 2, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 3, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 4, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 5, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 6, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 7, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 8, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 9, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 10, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301008654, 11, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 1, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 2, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 3, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 4, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 5, 1, 6, 3, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 6, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 7, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 8, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 9, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 10, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 11, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 12, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 13, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 14, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 15, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 16, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806008655, 17, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 1, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 2, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 3, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 4, 18, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 5, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 6, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 7, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 8, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608008656, 9, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008657, 1, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008657, 2, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008657, 3, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008657, 4, 142, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107008657, 5, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 1, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 2, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 3, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 4, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 5, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 6, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 7, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 8, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 9, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208008658, 10, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111008659, 1, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111008659, 2, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111008659, 3, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111008659, 4, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111008659, 5, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 1, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 2, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 3, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 4, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 5, 51, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 6, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 7, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 8, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 9, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 10, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 11, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080217008660, 12, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 1, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 2, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 3, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 4, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 5, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 6, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 7, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 8, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 9, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 10, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 11, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626008661, 12, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000317008662, 1, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000317008662, 2, 160, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000317008662, 3, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408008663, 1, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408008663, 2, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408008663, 3, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408008663, 4, 177, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408008663, 5, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 1, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 2, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 3, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 4, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 5, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 6, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 7, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 8, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 9, 35, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 10, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 11, 59, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 12, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228008664, 13, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001008665, 1, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001008665, 2, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001008665, 3, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001008665, 4, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 1, 156, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 2, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 3, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 4, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 5, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 6, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 7, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 8, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040403008666, 9, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 1, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 2, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 3, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 4, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 5, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 6, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616008667, 7, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 1, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 2, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 3, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 4, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 5, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 6, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 7, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 8, 128, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 9, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 10, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929008668, 11, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 13, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 14, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218009014, 15, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 1, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 2, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 3, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 4, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 5, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 6, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 7, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 8, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 9, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 10, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 11, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070902009015, 12, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009016, 1, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009016, 2, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009016, 3, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009016, 4, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 1, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 2, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 3, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 4, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 5, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 6, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 7, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 8, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 9, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071216009017, 10, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 1, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 2, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 3, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 4, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 5, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 6, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 7, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 8, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 9, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704009018, 10, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 1, 32, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 2, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 3, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 4, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 5, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 6, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 7, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 8, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 9, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 10, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080627009019, 11, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 1, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 2, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 3, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 4, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 5, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 6, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 7, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 8, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 9, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 10, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 11, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 12, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130009020, 13, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 1, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 2, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 3, 49, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 4, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 5, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 6, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 7, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625009021, 8, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 1, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 2, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 3, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 4, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 5, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111009022, 6, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 1, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 2, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 3, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 4, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 5, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231009023, 6, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 1, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 2, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 3, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 4, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 5, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 6, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 7, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 8, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 9, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 10, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 11, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 12, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110411009024, 13, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418009025, 1, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418009025, 2, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418009025, 3, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418009025, 4, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418009025, 5, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 1, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 2, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 3, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 4, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 5, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 6, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 7, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 8, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 9, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 10, 68, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 11, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 12, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 13, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 14, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 15, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009026, 16, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 1, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 2, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 3, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 4, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 5, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212009027, 6, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 1, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 2, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 3, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 4, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 5, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 6, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 7, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306009028, 8, 44, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 1, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 2, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 3, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 4, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 5, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 6, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 7, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 8, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 9, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 10, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 11, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 12, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 13, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100820009029, 14, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 1, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 2, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 3, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 4, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 5, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 6, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 7, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 8, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 9, 27, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 10, 21, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 11, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 12, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 13, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505009030, 14, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 1, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 2, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 3, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 4, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 5, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 6, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 7, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 8, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 9, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 10, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 11, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080415009031, 12, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908009032, 1, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908009032, 2, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908009032, 3, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908009032, 4, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908009032, 5, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 1, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 2, 157, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 3, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 4, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 5, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020412009033, 6, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009034, 1, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009034, 2, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531009034, 3, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 1, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 2, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 3, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 4, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 5, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 6, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 7, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 8, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 9, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 10, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 11, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 12, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 13, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 14, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130009035, 15, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 1, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 2, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 3, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 4, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 5, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 6, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 7, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 8, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 9, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 10, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 11, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 12, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 13, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 14, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725009036, 15, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 1, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 2, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 3, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 4, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 5, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217009037, 6, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 1, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 2, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 3, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 4, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 5, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 6, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 7, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009038, 8, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 1, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 2, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 3, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 4, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 5, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 6, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 7, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 8, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 9, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 10, 137, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 8, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 9, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 10, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 11, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 12, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 13, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 14, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 15, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 16, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 17, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418009415, 18, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 1, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 2, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 3, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 4, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 5, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 6, 97, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 7, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 8, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 9, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 10, 16, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 11, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 12, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 13, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 14, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101009416, 15, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 1, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 2, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 3, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 4, 110, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 5, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 6, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 7, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 8, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 9, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 10, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 11, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 12, 130, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129009417, 13, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 1, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 2, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 3, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 4, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 5, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 6, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 7, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 8, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 9, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 10, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 11, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 12, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 13, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 14, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404009418, 15, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000509009419, 1, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000509009419, 2, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000509009419, 3, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 1, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 2, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 3, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 4, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 5, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 6, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 7, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 8, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 9, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 10, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 11, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 12, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102009420, 13, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 1, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 2, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 3, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 4, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 5, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 6, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 7, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 8, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 9, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 10, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709009421, 11, 7, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 1, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 2, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 3, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 4, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 5, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 6, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 7, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 8, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 9, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 10, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 11, 58, 19, 8, 152);
commit;
prompt 99000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 12, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 13, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 14, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220009422, 15, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 1, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 2, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 3, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 4, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 5, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 6, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 7, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 8, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 9, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 10, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070311009423, 11, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 1, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 2, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 3, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 4, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 5, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 6, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 7, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 8, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 9, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 10, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 11, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 12, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907009424, 13, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 1, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 2, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 3, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 4, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 5, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 6, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 7, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 8, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 9, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 10, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 11, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 12, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 13, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 14, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 15, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 16, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220009425, 17, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 1, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 2, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 3, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 4, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 5, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 6, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 7, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 8, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 9, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 10, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 11, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 12, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 13, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 14, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 15, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218009426, 16, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 1, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 2, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 3, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 4, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 5, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 6, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 7, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 8, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 9, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 10, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 11, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 12, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 13, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 14, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130208009427, 15, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 1, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 2, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 3, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 4, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 5, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 6, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 7, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 8, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 9, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070729009428, 10, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 1, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 2, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 3, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 4, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 5, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401009429, 6, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821009430, 1, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821009430, 2, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821009430, 3, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821009430, 4, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 1, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 2, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 3, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 4, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 5, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105009431, 6, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 1, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 2, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 3, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 4, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 5, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 6, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 7, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 8, 33, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 9, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009432, 10, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 1, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 2, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 3, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 4, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 5, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 6, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 7, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 8, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 9, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 10, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 11, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 12, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 13, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 14, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117009433, 15, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923009434, 1, 103, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923009434, 2, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923009434, 3, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923009434, 4, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009435, 1, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009435, 2, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009435, 3, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009435, 4, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009435, 5, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 1, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 2, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 3, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 4, 132, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 5, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 6, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 7, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502009436, 8, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427009437, 1, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427009437, 2, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427009437, 3, 187, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 15, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 16, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 17, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430009792, 18, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 1, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 2, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 3, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 4, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 5, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 6, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 7, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 8, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 9, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 10, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 11, 126, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 12, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 13, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 14, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 15, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220009793, 16, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 1, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 2, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 3, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 4, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 5, 60, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 6, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210009794, 7, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009795, 1, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009795, 2, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009795, 3, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009795, 4, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421009795, 5, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114009796, 1, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114009796, 2, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114009796, 3, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114009796, 4, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502009797, 1, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502009797, 2, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502009797, 3, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 1, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 2, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 3, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 4, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 5, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 6, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 7, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 8, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 9, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 10, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409009798, 11, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221009799, 1, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221009799, 2, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221009799, 3, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221009799, 4, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021221009799, 5, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 1, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 2, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 3, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 4, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 5, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 6, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 7, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 8, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 9, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714009800, 10, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 1, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 2, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 3, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 4, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 5, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 6, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 7, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 8, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 9, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 10, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 11, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 12, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 13, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 14, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 15, 85, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 16, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 17, 155, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624009801, 18, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 1, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 2, 21, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 3, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 4, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 5, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 6, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 7, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 8, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630009802, 9, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 1, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 2, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 3, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 4, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 5, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 6, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 7, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 8, 141, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 9, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051221009803, 10, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 1, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 2, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 3, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 4, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 5, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 6, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 7, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 8, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 9, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 10, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 11, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 12, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 13, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 14, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426009804, 15, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111009805, 1, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111009805, 2, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111009805, 3, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111009805, 4, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009806, 1, 7, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009806, 2, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009806, 3, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724009806, 4, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830009807, 1, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830009807, 2, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830009807, 3, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830009807, 4, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830009807, 5, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 1, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 2, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 3, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 4, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 5, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 6, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 7, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 8, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811009808, 9, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 1, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 2, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 3, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 4, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 5, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 6, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 7, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130009809, 8, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026009810, 1, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026009810, 2, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 1, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 2, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 3, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 4, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 5, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 6, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 7, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 8, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 9, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 10, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 11, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 12, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 13, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222009811, 14, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 1, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 2, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 3, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 4, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 5, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 6, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 7, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060604009812, 8, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 1, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 2, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 3, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 4, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 5, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 6, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 7, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 8, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 9, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 10, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 11, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 12, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 13, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120203009813, 14, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 1, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 2, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 3, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 4, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 5, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 6, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 7, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 8, 75, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 9, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 10, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 11, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 12, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917009814, 13, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 1, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 2, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 3, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 4, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 5, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 6, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 7, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 8, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022009815, 9, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 1, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 2, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 3, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 4, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 5, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 6, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 7, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915009816, 8, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 1, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 2, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 3, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 4, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 5, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 6, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 7, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 8, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 9, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 10, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313009817, 11, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 1, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 2, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 3, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 4, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 5, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 6, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 7, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 8, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 9, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 10, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 11, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 12, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 13, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 1, 76, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 2, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 3, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 4, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 5, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 6, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 7, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 8, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126008669, 9, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 1, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 2, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 3, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 4, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 5, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 6, 175, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 7, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104008670, 8, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 1, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 2, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 3, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 4, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 5, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 6, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 7, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 8, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 9, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 10, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 11, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 12, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 13, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313008671, 14, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 1, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 2, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 3, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 4, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 5, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 6, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 7, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 8, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 9, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 10, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 11, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 12, 181, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 13, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406008672, 14, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726008673, 1, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726008673, 2, 8, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726008673, 3, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 1, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 2, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 3, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 4, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 5, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 6, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 7, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 8, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 9, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 10, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 11, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911008674, 12, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 1, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 2, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 3, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 4, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 5, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 6, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 7, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 8, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 9, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 10, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 11, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 12, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 13, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 14, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 15, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513008675, 16, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 1, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 2, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 3, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 4, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 5, 169, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 6, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527008676, 7, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 1, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 2, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 3, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 4, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 5, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 6, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 7, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 8, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 9, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 10, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 11, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813008677, 12, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127008678, 1, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127008678, 2, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127008678, 3, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127008678, 4, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127008678, 5, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 1, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 2, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 3, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 4, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 5, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929008679, 6, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 1, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 2, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 3, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 4, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 5, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 6, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 7, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926008680, 8, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 1, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 2, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 3, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 4, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 5, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 6, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 7, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 8, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 9, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 10, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070629008681, 11, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 1, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 2, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 3, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 4, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 5, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 6, 109, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 7, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 8, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 9, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 10, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 11, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 12, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 13, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 14, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 15, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 16, 60, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212008682, 17, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 1, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 2, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 3, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 4, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 5, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 6, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 7, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 8, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 9, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 10, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 11, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 12, 134, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090823008683, 13, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529008684, 1, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529008684, 2, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529008684, 3, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529008684, 4, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529008684, 5, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 1, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 2, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 3, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 4, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 5, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 6, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 7, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 8, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 9, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 10, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 11, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 12, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 13, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 14, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 15, 13, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 16, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402008685, 17, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 1, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 2, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 3, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 4, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 5, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 6, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 7, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 8, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 9, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 10, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 11, 103, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 12, 65, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 13, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100102008686, 14, 104, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 1, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 2, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 3, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 4, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 5, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 6, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 7, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 8, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 9, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 10, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 11, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 12, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 13, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711008687, 14, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 1, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 2, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 3, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 4, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 5, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 6, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 7, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621008688, 8, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 1, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 2, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 3, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 4, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 5, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 6, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 7, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 8, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 9, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 10, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 11, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 12, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420008689, 13, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416008690, 1, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416008690, 2, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416008690, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416008690, 4, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416008690, 5, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 1, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 2, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 3, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 4, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 5, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 6, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 7, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 8, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 11, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224009039, 12, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 1, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 2, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 3, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 4, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 5, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 6, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 7, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 8, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 9, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 10, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 11, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 12, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204009040, 13, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 1, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 2, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 3, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 4, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 5, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 6, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416009041, 7, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 1, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 2, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 3, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 4, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 5, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 6, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020502009042, 7, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 1, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 2, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 3, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 4, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 5, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 6, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 7, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 8, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 9, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 10, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 11, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 12, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 13, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 14, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 15, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 16, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130714009043, 17, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 1, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 2, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 3, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 4, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 5, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 6, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 7, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 8, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 9, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 10, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 11, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211009044, 12, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028009045, 1, 14, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028009045, 2, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028009045, 3, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 1, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 2, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 3, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 4, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 5, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 6, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 7, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 8, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 9, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 10, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 11, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 12, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 13, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 14, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 15, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213009046, 16, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 1, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 2, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 3, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 4, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 5, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 6, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 7, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 8, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126009047, 9, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 1, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 2, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 3, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 4, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 5, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 6, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 7, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 8, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 9, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 10, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208009048, 11, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 1, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 2, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 3, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 4, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 5, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 6, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 7, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 8, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 9, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 10, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 11, 147, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 12, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 13, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 14, 20, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 15, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630009049, 16, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 1, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 2, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 3, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 4, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 5, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 6, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 7, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 8, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 9, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 10, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 11, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 12, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 13, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 14, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 15, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 16, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926009050, 17, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 1, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 2, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 3, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 4, 35, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 5, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 6, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 7, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 8, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 9, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 10, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 11, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 12, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 13, 12, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 14, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 15, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 16, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014009051, 17, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 1, 99, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 2, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 3, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 4, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 5, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 6, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 7, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051108009052, 8, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 1, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 2, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 3, 99, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 4, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 5, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 6, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 7, 134, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 8, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 9, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 10, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 11, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 12, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 13, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 14, 129, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 15, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 16, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128009053, 17, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106009054, 1, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106009054, 2, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106009054, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 1, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 2, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 3, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 4, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 5, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 6, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 7, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 8, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 9, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 10, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 11, 125, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 12, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 13, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 14, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412009055, 15, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 1, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 2, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 3, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 4, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 5, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 6, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 7, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 8, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 9, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 10, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 11, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 12, 151, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404009056, 13, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130009057, 1, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130009057, 2, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130009057, 3, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 1, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 2, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 3, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 4, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 5, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 6, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 7, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 8, 154, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 9, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 10, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070308009058, 11, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 1, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 2, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 3, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 4, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 5, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 6, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 7, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 8, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 9, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 10, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 11, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 12, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117009059, 13, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 1, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 2, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 3, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 4, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 5, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 6, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 7, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 8, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427009437, 4, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427009437, 5, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 1, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 2, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 3, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 4, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 5, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 6, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 7, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 8, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 9, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 10, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315009438, 11, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 1, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 2, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 3, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 4, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 5, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 6, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 7, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 8, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 9, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 10, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 11, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 12, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 13, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 14, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108009439, 15, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 1, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 2, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 3, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 4, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 5, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 6, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 7, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 8, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 9, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 10, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 11, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 12, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 13, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 14, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 15, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120516009440, 16, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 1, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 2, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 3, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 4, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 5, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 6, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 7, 173, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 8, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 9, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 10, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 11, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607009441, 12, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 1, 69, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 2, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 3, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 4, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 5, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 6, 182, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 7, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 8, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 9, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 10, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 11, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 12, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004009442, 13, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 1, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 2, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 3, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 5, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 6, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 7, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 8, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 9, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 10, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 11, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071207009443, 12, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 1, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 2, 117, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 3, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 4, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 5, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021008009444, 6, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 1, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 2, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 3, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 4, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 5, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 6, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 7, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 8, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 9, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 10, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060729009445, 11, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 1, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 2, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 3, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 4, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 5, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 6, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 7, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 8, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 9, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 10, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 11, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 12, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906009446, 13, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 1, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 2, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 3, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 4, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 5, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 6, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 7, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 8, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 9, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 10, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 11, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 12, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626009447, 13, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 1, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 2, 137, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 3, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 4, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 5, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 6, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901009448, 7, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611009449, 1, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611009449, 2, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611009449, 3, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 1, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 2, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 3, 141, 13, 12, 156);
commit;
prompt 100000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 4, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 5, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 6, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 7, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 8, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 9, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 10, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 11, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 12, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 13, 138, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 14, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219009450, 15, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 1, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 2, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 3, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 4, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 5, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 6, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 7, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 8, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 9, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 10, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 11, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080221009451, 12, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104009452, 1, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104009452, 2, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104009452, 3, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104009452, 4, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010104009452, 5, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 1, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 2, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 3, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 4, 115, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 5, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 6, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 7, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303009453, 8, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 1, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 2, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 3, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 4, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 5, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 6, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 7, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 8, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 9, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 10, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 11, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 12, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205009454, 13, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 1, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 2, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 3, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 4, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 5, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 6, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 7, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 8, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 9, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 10, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 11, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 12, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 13, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701009455, 14, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 1, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 2, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 3, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 4, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 5, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 6, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030603009456, 7, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121009457, 1, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121009457, 2, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 1, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 2, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 3, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 4, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 5, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 6, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 7, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 8, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604009458, 9, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 1, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 2, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 3, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 4, 107, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 5, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 6, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 7, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 8, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 9, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 10, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 11, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 12, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 13, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 14, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202009459, 15, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 1, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 2, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 3, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 4, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 5, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 14, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925009818, 15, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 1, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 2, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 3, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 4, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 5, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 6, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 7, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 8, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 9, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720009819, 10, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 1, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 2, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 3, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 4, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 5, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301009820, 6, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 1, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 2, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 3, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 4, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 5, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 6, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 7, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 8, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 9, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 10, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 11, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104009821, 12, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 1, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 2, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 3, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 4, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 5, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 6, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 7, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 8, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 9, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 10, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 11, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 12, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 13, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 14, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 15, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729009822, 16, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 1, 119, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 2, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 3, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 4, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 5, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 6, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 7, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031120009823, 8, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826009824, 1, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826009824, 2, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826009824, 3, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 1, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 2, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 3, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 4, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 5, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 6, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131009825, 7, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 1, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 2, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 3, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 4, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 5, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 6, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 7, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 8, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 9, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 10, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023009826, 11, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 1, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 2, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 3, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 4, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 5, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 6, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 7, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 8, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 9, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808009827, 10, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 1, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 2, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 3, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 4, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 5, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 6, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 7, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 8, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 9, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 10, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 11, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 12, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 13, 163, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 14, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 15, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824009828, 16, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 1, 31, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 2, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 3, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 4, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 5, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 6, 99, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 7, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 8, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 9, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418009829, 10, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 1, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 2, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 3, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 4, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 5, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 6, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 7, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 8, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 9, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211009830, 10, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 1, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 2, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 3, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 4, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 5, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 6, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411009831, 7, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 1, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 2, 137, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 3, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 4, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 5, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 6, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 7, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 8, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060315009832, 9, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 1, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 2, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 3, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 4, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 5, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 6, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 7, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 8, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 9, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 10, 24, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070107009833, 11, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 1, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 2, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 3, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 4, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 5, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 6, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 7, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 8, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 9, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 10, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 11, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 12, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419009834, 13, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 1, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 2, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 3, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 4, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 5, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 6, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 7, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 8, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 9, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 10, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 11, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324009835, 12, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 1, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 2, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 3, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 4, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 5, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 6, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 7, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 8, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 9, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 10, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009836, 11, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 1, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 2, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 3, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 4, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 5, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 6, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 7, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 8, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 9, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 10, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 11, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 12, 22, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202009837, 13, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 1, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 2, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 3, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 4, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 5, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 6, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 7, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 8, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 9, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 10, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 11, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 12, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 13, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 14, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 15, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714009838, 16, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 1, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 2, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 3, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 4, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 5, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 6, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 7, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 8, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 9, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 10, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091228009839, 11, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 2, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 3, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 4, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 5, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 6, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 7, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 8, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 9, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 10, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 11, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 12, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104009840, 13, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804009841, 1, 69, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804009841, 2, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 9, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 10, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 11, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 12, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 13, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 14, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125008691, 15, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 1, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 2, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 3, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 4, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 5, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 6, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 7, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 8, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 9, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 10, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 11, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626008692, 12, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 1, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 2, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 3, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 4, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 5, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 6, 137, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 7, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 8, 14, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 9, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 10, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 11, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 12, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 13, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 14, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606008693, 15, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 1, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 2, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 3, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 4, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 5, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 6, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 7, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 8, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 9, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 10, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 11, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 12, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502008694, 13, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 1, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 2, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 3, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 4, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 5, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 6, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 7, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 8, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 9, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 10, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725008695, 11, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 1, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 2, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 3, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 4, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 5, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 6, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 7, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 8, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 9, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 10, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 11, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 12, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 13, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 14, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 15, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027008696, 16, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 1, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 2, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 3, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 4, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 5, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 6, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 7, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 8, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 9, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 10, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 11, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 12, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 13, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 14, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225008697, 15, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401008698, 1, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401008698, 2, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401008698, 3, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401008698, 4, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 1, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 2, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 3, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 4, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 5, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 6, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 7, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 8, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 9, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 10, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225008699, 11, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 1, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 2, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 3, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 4, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 5, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 6, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 7, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 8, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 9, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 10, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 11, 155, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101226008700, 12, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 1, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 2, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 3, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 4, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 5, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 6, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 7, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 8, 155, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 9, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 10, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 11, 129, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 12, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 13, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 14, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130008701, 15, 50, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 1, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 2, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 3, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 4, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 5, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 6, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 7, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 8, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 9, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 10, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 11, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 12, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 13, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 14, 84, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101008702, 15, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 1, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 2, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 3, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 4, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 5, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 6, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 7, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 8, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105008703, 9, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 1, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 2, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 3, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 4, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 5, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711008704, 6, 76, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 1, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 2, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 3, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 4, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 5, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 6, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 7, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 8, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 9, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051119008705, 10, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 1, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 2, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 3, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 4, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 5, 125, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 6, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 7, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603008706, 8, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 1, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 2, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 3, 155, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 4, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 5, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 6, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 7, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 8, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 9, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 10, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 11, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 12, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 13, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 14, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728008707, 15, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 1, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 2, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 3, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 4, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 5, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 6, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 7, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728008708, 8, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 1, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 2, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 3, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 4, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 5, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 6, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 7, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 8, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 9, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 10, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717008709, 11, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 1, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 2, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 3, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 4, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 5, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 6, 110, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 7, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 8, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 9, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 10, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 11, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 12, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 13, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902008710, 14, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804008711, 1, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804008711, 2, 44, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804008711, 3, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804008711, 4, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804008711, 5, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 1, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 2, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 3, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 4, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 5, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 6, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 7, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 9, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 10, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 11, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 12, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 13, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 14, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 15, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 16, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627009060, 17, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 1, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 2, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 3, 171, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 4, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 5, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 6, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 7, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 8, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 9, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 10, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 11, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 12, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 13, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 14, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703009061, 15, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513009062, 1, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513009062, 2, 31, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513009062, 3, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513009062, 4, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 1, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 2, 69, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 3, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 4, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 5, 141, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 6, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 7, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 8, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 9, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 10, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 11, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 12, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508009063, 13, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 1, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 2, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 3, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 4, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 5, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919009064, 6, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 1, 69, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 2, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 3, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 4, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 5, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 6, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 7, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 8, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 9, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 10, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230009065, 11, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 1, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 2, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 3, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 4, 7, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 5, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 6, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811009066, 7, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 1, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 2, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 3, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 4, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 5, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 6, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 7, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 8, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523009067, 9, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 1, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 2, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 3, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 4, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 5, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 6, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 7, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 8, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 9, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 10, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 11, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 12, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612009068, 13, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 1, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 2, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 3, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 4, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 5, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 6, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 7, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 8, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915009069, 9, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 1, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 3, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 4, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 5, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 6, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 7, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 8, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 9, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 10, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 11, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 12, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 13, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 14, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 15, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229009070, 16, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 1, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 2, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 3, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 4, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 5, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210009071, 6, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 1, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 2, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 3, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 4, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 5, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 6, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 7, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 8, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 9, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 10, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 11, 155, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430009072, 12, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 1, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 2, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 3, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 4, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 5, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020327009073, 6, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 1, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 2, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 3, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 4, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 5, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 6, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 7, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 8, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 9, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 10, 61, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 11, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208009074, 12, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009075, 1, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009075, 2, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009075, 3, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010713009075, 4, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 1, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 2, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 3, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 4, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 5, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 6, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 7, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 8, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 9, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 10, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305009076, 11, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 1, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 2, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 3, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 4, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 5, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729009077, 6, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 1, 70, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 2, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 3, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 4, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 5, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 6, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 7, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 8, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 9, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 10, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 11, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 12, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 13, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 14, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 15, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 16, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017009078, 17, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 1, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 2, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 3, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 4, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 5, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 6, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 7, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521009079, 8, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 1, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 2, 152, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 3, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 4, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 5, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813009080, 6, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 1, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 2, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 3, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 4, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 5, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 6, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 7, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 8, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 9, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 10, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 11, 1, 72, 3, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 12, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 13, 132, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 14, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 15, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 16, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230009081, 17, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 1, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 2, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 3, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 4, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 5, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 6, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030926009082, 7, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307009083, 1, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307009083, 2, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307009083, 3, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307009083, 4, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307009083, 5, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 1, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 2, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 3, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 4, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 5, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 6, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 7, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 8, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 9, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 10, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 6, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 7, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 8, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 9, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319009460, 10, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 1, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 2, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 3, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 4, 93, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 5, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 6, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 7, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127009461, 8, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 1, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 2, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 3, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 4, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 5, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 6, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 7, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 8, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 9, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 10, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 11, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 12, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 13, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 14, 44, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 15, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919009462, 16, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 1, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 2, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 3, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 4, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 5, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 6, 191, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218009463, 7, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 1, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 2, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 3, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 4, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 5, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 6, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 7, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 8, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 9, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070509009464, 10, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009465, 1, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009465, 2, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429009465, 3, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728009466, 1, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728009466, 2, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728009466, 3, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728009466, 4, 33, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728009466, 5, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 1, 103, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 2, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 3, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 4, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 5, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 6, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 7, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 8, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 9, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227009467, 10, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 1, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 2, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 3, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 4, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 5, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 6, 181, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 7, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 8, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 9, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519009468, 10, 19, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009469, 1, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009469, 2, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106009469, 3, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 1, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 2, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 3, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 4, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 5, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 6, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 7, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 8, 108, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226009470, 9, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 1, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 2, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 3, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 4, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 5, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 6, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 7, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 8, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 9, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 10, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 11, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121009471, 12, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 1, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 2, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 3, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 4, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 5, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 6, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 7, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 8, 77, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 9, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 10, 161, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 11, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 12, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430009472, 13, 52, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 1, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 2, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 3, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 4, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 5, 13, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 6, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 7, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 8, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 9, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 10, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 11, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420009473, 12, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 1, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 2, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 3, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 4, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 5, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 6, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 7, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 8, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 9, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018009474, 10, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 1, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 2, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 3, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 4, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 5, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814009475, 6, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 1, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 2, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 3, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 4, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 5, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 6, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 7, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 8, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419009476, 9, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 1, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 2, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 3, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 4, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 5, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 6, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 7, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 8, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 9, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 10, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 11, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 12, 125, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 13, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 14, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 15, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012009477, 16, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 1, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 2, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 3, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 4, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 5, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 6, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627009478, 7, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 1, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 2, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 3, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 4, 79, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 5, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 6, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 7, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 8, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115009479, 9, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 1, 123, 59, 11, 649);
commit;
prompt 101000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 2, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 3, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 4, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 5, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 6, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 7, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 8, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 9, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 10, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 11, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 12, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407009480, 13, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 1, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 2, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 3, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 4, 14, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 5, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 6, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 7, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 8, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 9, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 10, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307009481, 11, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 1, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 2, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 3, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 4, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 5, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 6, 110, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 7, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118009482, 8, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 1, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 2, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 3, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 4, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 5, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 6, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 7, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 8, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 9, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 10, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 11, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 12, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 13, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 14, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222009483, 15, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 1, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 2, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 3, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 4, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 5, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 6, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 7, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 8, 131, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 9, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 10, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 11, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 12, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804009841, 3, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804009841, 4, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010804009841, 5, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 1, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 2, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 3, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 4, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 5, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 6, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 7, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 8, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 9, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 10, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 11, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 12, 186, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 13, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 14, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 15, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410009842, 16, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 1, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 2, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 3, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 4, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 5, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 6, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 7, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 8, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 9, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 10, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 11, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 12, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 13, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510009843, 14, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 1, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 2, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 3, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 4, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 5, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 6, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 7, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 8, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 9, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 10, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 11, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305009844, 12, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 1, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 2, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 3, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 4, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 5, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 6, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 7, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 8, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 9, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111009845, 10, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 1, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 2, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 3, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 4, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 5, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 6, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 7, 144, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 8, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 9, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 10, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 11, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 12, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100113009846, 13, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 1, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 2, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 3, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 4, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 5, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 6, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 7, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 8, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 9, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 10, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 11, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 12, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 13, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 14, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 15, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 16, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 17, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414009847, 18, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 1, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 2, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 3, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 4, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 5, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 6, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 7, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 8, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 9, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 10, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 11, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070528009848, 12, 59, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 1, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 2, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 3, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 4, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 5, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 6, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 7, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 8, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050224009849, 9, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021207009850, 1, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021207009850, 2, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021207009850, 3, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021207009850, 4, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 1, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 2, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 3, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 4, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 5, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 6, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 7, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 8, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 9, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 10, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 11, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 12, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 13, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 14, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 15, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525009851, 16, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 1, 123, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 2, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 3, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 4, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 5, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 6, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 7, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 8, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 9, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 10, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 11, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 12, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609009852, 13, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 1, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 2, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 3, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 4, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 5, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 6, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031205009853, 7, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009854, 1, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009854, 2, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009854, 3, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628009854, 4, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 1, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 2, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 3, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 4, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 5, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 6, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 7, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031031009855, 8, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 1, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 2, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 3, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 4, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 5, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 6, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513009856, 7, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501009857, 1, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501009857, 2, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501009857, 3, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501009857, 4, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 1, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 2, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 3, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 4, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 5, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 6, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 7, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 8, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 9, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 10, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 11, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 12, 67, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202009858, 13, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 1, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 2, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 3, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 4, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 5, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 6, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 7, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 8, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 9, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 10, 180, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 11, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 12, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 13, 173, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100624009859, 14, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009860, 1, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009860, 2, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009860, 3, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009860, 4, 88, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230009860, 5, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 1, 106, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 2, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 3, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 4, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 5, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 6, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 7, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 8, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 9, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208009861, 10, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 1, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 2, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 3, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 4, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 5, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 6, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 7, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 8, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 9, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 10, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 11, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 12, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100118009862, 13, 95, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726009863, 1, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726009863, 2, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726009863, 3, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730009864, 1, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730009864, 2, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730009864, 3, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730009864, 4, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030730009864, 5, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 1, 145, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 2, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 3, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 4, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 5, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 8, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515008712, 9, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 1, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 2, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 3, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 4, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 5, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 6, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 7, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 8, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 9, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 10, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 11, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 12, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 13, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917008713, 14, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 1, 40, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 2, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 3, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 4, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 5, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 6, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 7, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 8, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 9, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060310008714, 10, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 1, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 2, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 3, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 4, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 5, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 6, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 7, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 8, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 9, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 10, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 11, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 12, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 13, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 14, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 15, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 16, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 17, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140213008715, 18, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 1, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 2, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 3, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 4, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 5, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 6, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 7, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 8, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 9, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 10, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 11, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 12, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 13, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511008716, 14, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 1, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 2, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 3, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 4, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 5, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 6, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 7, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 8, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 9, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 10, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 11, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 12, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110124008717, 13, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 1, 94, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 2, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 3, 145, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 4, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 5, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 6, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016008718, 7, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816008719, 1, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816008719, 2, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816008719, 3, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816008719, 4, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 1, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 2, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 3, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 4, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 5, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610008720, 6, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 1, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 2, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 3, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 4, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 5, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015008721, 6, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 1, 65, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 2, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 3, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 4, 57, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 5, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 6, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 7, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 8, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 9, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 10, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 11, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 12, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 13, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 14, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 15, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 16, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 17, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822008722, 18, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 1, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 2, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 3, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 4, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 5, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 6, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531008723, 7, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 1, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 2, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 3, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 4, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 5, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213008724, 6, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 1, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 2, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 3, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 4, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 5, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 6, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 7, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 8, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 9, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 10, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 11, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 12, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 13, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 14, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321008725, 15, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 1, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 2, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 3, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 4, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 5, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 6, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 7, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 8, 169, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 9, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 10, 144, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924008726, 11, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 1, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 2, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 3, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 4, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 5, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026008727, 6, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 1, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 2, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 3, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 4, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 5, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 6, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 7, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 8, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 9, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 10, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 11, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702008728, 12, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 1, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 2, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 3, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 4, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 5, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 6, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 7, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 8, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 9, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 10, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 11, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 12, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 13, 171, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 14, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303008729, 15, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 1, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 2, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 3, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 4, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 5, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 6, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 7, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 8, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 9, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 10, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 11, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 12, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917008730, 13, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 1, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 2, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 3, 33, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 4, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 5, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 6, 24, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 7, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 8, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 9, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 10, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 11, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 12, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 13, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 14, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 15, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108008731, 16, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 1, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 2, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 3, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 4, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 5, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 6, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 7, 48, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 8, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 9, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 10, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 11, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222008732, 12, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 1, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 2, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 3, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 4, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 5, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 6, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 7, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 8, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329008733, 9, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 1, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 2, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 3, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 4, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 5, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 11, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 12, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 13, 72, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 14, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 15, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 16, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024009084, 17, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 1, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 2, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 3, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 4, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 5, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 6, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 7, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830009085, 8, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 1, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 2, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 3, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 4, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 5, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 6, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 7, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 8, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 9, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 10, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 11, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090410009086, 12, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 1, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 2, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 3, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 4, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 5, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 6, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 7, 171, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207009087, 8, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 1, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 2, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 3, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 4, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 5, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 6, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 7, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 8, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 9, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 10, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303009088, 11, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217009089, 1, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217009089, 2, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217009089, 3, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217009089, 4, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 1, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 2, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 3, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 4, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 5, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 6, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 7, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050327009090, 8, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 1, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 2, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 3, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 4, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 5, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 6, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 7, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 8, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 9, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 10, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 11, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 12, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 13, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209009091, 14, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 1, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 2, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 3, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 4, 111, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 5, 22, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 6, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 7, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 8, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 9, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 10, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 11, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 12, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 13, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 14, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 15, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 16, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009009092, 17, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 1, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 2, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 3, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 4, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 5, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 6, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 7, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 8, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 9, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 10, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 11, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 12, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 13, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100320009093, 14, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 1, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 2, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 3, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 4, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 5, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 6, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 7, 175, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 8, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 9, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509009094, 10, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 1, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 2, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 3, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 4, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 5, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 6, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 7, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031009095, 8, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 1, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 2, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 3, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 4, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 5, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 6, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 7, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 8, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 9, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 10, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090502009096, 11, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 1, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 2, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 3, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 4, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 5, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 6, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 7, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 8, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 9, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 10, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 11, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417009097, 12, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009098, 1, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009098, 2, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009098, 3, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712009098, 4, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 1, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 2, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 3, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 4, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 5, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 6, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 7, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 8, 41, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 9, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 10, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 11, 7, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928009099, 12, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 1, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 2, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 3, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 4, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 5, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 6, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 7, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 8, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 9, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060731009100, 10, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 1, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 2, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 3, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 4, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 5, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 6, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 7, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 8, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 9, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 10, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329009101, 11, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 1, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 2, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 3, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 4, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 5, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 6, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 7, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 8, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226009102, 9, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 1, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 2, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 3, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 4, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 5, 22, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 6, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 7, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 8, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 9, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 10, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 11, 179, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 12, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 13, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 14, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 15, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 16, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219009103, 17, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 1, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 2, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 3, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 4, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 5, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 6, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 7, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805009104, 8, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 1, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 2, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 3, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 4, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 5, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 6, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 7, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 8, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060724009105, 9, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210009106, 1, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210009106, 2, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210009106, 3, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210009106, 4, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 1, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 2, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 3, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 4, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 5, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 6, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 7, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 8, 33, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 9, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 10, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 11, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 13, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 14, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 15, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 16, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140509009484, 17, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 1, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 2, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 3, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 4, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 5, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323009485, 6, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 1, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 2, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 3, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 4, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 5, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 6, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 7, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 8, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 9, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505009486, 10, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 1, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 2, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 3, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 4, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 5, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 6, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 7, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 8, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 9, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 10, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 11, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 12, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 13, 31, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 14, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110319009487, 15, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 1, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 2, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 3, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 4, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 5, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 6, 127, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 7, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 8, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 9, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 10, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 11, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211009488, 12, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 1, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 2, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 3, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 4, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 5, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906009489, 6, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 1, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 2, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 3, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 4, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 5, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 6, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 7, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 8, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 9, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 10, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 11, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 12, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 13, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 14, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 15, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 16, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 17, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207009490, 18, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 1, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 2, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 3, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 4, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 5, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 6, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 7, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205009491, 8, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 1, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 2, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 3, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 4, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 5, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 6, 1, 71, 3, 213);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 7, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 8, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 9, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424009492, 10, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 1, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 2, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 3, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 4, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 5, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102009493, 6, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723009494, 1, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723009494, 2, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723009494, 3, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723009494, 4, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723009494, 5, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 1, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 2, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 3, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 4, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 5, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 6, 83, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 7, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 8, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201009495, 9, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 1, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 2, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 3, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 4, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 5, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 6, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 7, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 8, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 9, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 10, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 11, 32, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 12, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 13, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 14, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724009496, 15, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 1, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 2, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 3, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 4, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 5, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 6, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909009497, 7, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 1, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 2, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 3, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 4, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 5, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 6, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 7, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 8, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 9, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 10, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 11, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 12, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 13, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 14, 151, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 15, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630009498, 16, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 1, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 2, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 3, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 4, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 5, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 6, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 7, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 8, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 9, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 10, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080521009499, 11, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409009500, 1, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409009500, 2, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409009500, 3, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000409009500, 4, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 1, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 2, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 3, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 4, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 5, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 6, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231009501, 7, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 1, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 2, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 3, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 4, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 5, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913009502, 6, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209009503, 1, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209009503, 2, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209009503, 3, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 1, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 2, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 3, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 4, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 5, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 6, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 7, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 8, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 9, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 10, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 11, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 12, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910009504, 13, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615009505, 1, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615009505, 2, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615009505, 3, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615009505, 4, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615009505, 5, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 1, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 2, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 3, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 4, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 5, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 6, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829009506, 7, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 1, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 2, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 3, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 4, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 5, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 6, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 7, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 8, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 9, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 10, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 11, 33, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707009507, 12, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 1, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 2, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 3, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 4, 51, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 5, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 6, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 7, 122, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 8, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 9, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 10, 26, 17, 7, 119);
commit;
prompt 102000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 11, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 12, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 13, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722009508, 14, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 1, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 2, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 3, 18, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 4, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 5, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119009509, 6, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419009510, 1, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419009510, 2, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419009510, 3, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020517009865, 6, 104, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 1, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 2, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 3, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 4, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 5, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 6, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 7, 182, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 8, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 9, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 10, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 11, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 12, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 13, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 14, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 15, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 16, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928009866, 17, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 1, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 2, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 3, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 4, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 5, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 6, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 7, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 8, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 9, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 10, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 11, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314009867, 12, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 1, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 2, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 3, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 4, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 5, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 6, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 7, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 8, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 9, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 10, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 11, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 12, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 13, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 14, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 15, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121121009868, 16, 59, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527009869, 1, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527009869, 2, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527009869, 3, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527009869, 4, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 1, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 2, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 3, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 4, 9, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 5, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 6, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 7, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 8, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 9, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 10, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 11, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 12, 132, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 13, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129009870, 14, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 1, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 2, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 3, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 4, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 5, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 6, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 7, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 8, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524009871, 9, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 1, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 2, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 3, 10, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 4, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 5, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 6, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213009872, 7, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 1, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 2, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 3, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 4, 176, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 5, 66, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 6, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 7, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 8, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 9, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 10, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 11, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108009873, 12, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 1, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 2, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 3, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 4, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 5, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 6, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 7, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 8, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 9, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 10, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 11, 126, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 12, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 13, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 14, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 15, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 16, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106009874, 17, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 1, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 2, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 3, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 4, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 5, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 6, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 7, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517009875, 8, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605009876, 1, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605009876, 2, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605009876, 3, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605009876, 4, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 1, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 2, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 3, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 4, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 5, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020426009877, 6, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 1, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 2, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 3, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 4, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 5, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 6, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 7, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051209009878, 8, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 1, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 2, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 3, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 4, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 5, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 6, 136, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 7, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 8, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 9, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 10, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 11, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 12, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 13, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825009879, 14, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 1, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 2, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 3, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 4, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 5, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120009880, 6, 93, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 1, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 2, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 3, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 4, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 5, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 6, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 7, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 8, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 9, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 10, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 11, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 12, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 13, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 14, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 15, 59, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 16, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130120009881, 17, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 1, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 2, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 3, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 4, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 5, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 6, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115009882, 7, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 1, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 2, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 3, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 4, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 5, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 6, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 7, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217009883, 8, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 1, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 2, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 3, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 4, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 5, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 6, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 7, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 8, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 9, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050102009884, 10, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 1, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 2, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 3, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 4, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 5, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 6, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516009885, 7, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 1, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 2, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 3, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 4, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 5, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 6, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815009886, 7, 96, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 1, 78, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 2, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 3, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 4, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 5, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 6, 1, 60, 3, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 7, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 8, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318009887, 9, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017009888, 1, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017009888, 2, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017009888, 3, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017009888, 4, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021017009888, 5, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 1, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 2, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 3, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 4, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 5, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 6, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922009889, 7, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 1, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 2, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 3, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 4, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 5, 70, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 6, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830009890, 7, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 6, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 7, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 8, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 9, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 10, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 11, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091029008734, 12, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 1, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 2, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 3, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 4, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 5, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 6, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 7, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 8, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 9, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 10, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 11, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 12, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226008735, 13, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203008736, 1, 1, 77, 3, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203008736, 2, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 1, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 2, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 3, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 4, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 5, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 6, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 7, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105008737, 8, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 1, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 2, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 3, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 4, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 5, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 6, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050620008738, 7, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 1, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 2, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 3, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 4, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 5, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 6, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 7, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 8, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 9, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 10, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 11, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 12, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512008739, 13, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 1, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 2, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 3, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 4, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 5, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 6, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 7, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 8, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 9, 180, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 10, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 11, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 12, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 13, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 14, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 15, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121016008740, 16, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 1, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 2, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 3, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 4, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 5, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 6, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 7, 19, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 8, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 9, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 10, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 11, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 12, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 13, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 14, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615008741, 15, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 1, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 2, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 3, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 4, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 5, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 6, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 7, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 8, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 9, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 10, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 11, 52, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 12, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 13, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110518008742, 14, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008743, 1, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008743, 2, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008743, 3, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008743, 4, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125008743, 5, 65, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 1, 25, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 2, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 3, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 4, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 5, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010415008744, 6, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 1, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 2, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 3, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 4, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 5, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 6, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 7, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 8, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 9, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 10, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 11, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 12, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 13, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 14, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123008745, 15, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 1, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 2, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 3, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 4, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 5, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 6, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 7, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 8, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 9, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 10, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 11, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 12, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 13, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 14, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115008746, 15, 64, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 1, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 2, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 3, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 4, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 5, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012008747, 6, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 1, 180, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 2, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 3, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 4, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 5, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 6, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 7, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 8, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 9, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 10, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 11, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 12, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714008748, 13, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230008749, 1, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230008749, 2, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230008749, 3, 1, 27, 3, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 1, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 2, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 3, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 4, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 5, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 6, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 7, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 8, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 9, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 10, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 11, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 12, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 13, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 14, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029008750, 15, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 1, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 2, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 3, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 4, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 5, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 6, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 7, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 8, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613008751, 9, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602008752, 1, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602008752, 2, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602008752, 3, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 1, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 2, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 3, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 4, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 5, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 6, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 7, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 8, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 9, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 10, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 11, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 12, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 13, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 14, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 15, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130217008753, 16, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 1, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 2, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 3, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 4, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 5, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 6, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 7, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 8, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 9, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 10, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 11, 150, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 12, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 13, 111, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 14, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104008754, 15, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 1, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 2, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 3, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 4, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 5, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 6, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 7, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 8, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 9, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 10, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417008755, 11, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 1, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 2, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 3, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 5, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524008756, 6, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 1, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 2, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 3, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 4, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 5, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227008757, 6, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 12, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 13, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 14, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 15, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 16, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304009107, 17, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009108, 1, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009108, 2, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009108, 3, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009108, 4, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226009108, 5, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 1, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 2, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 3, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 4, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 5, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 6, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 7, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 8, 146, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 9, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 10, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 11, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080212009109, 12, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 1, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 2, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 3, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 4, 49, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 5, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 6, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 7, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 8, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 9, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 10, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 11, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 12, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 13, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 14, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 15, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109009110, 16, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 1, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 2, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 3, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 4, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 5, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217009111, 6, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009112, 1, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009112, 2, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009112, 3, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009112, 4, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515009112, 5, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 1, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 2, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 3, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 4, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 5, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 6, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 7, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 8, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 9, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 10, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 11, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 12, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 13, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 14, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 15, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120629009113, 16, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506009114, 1, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506009114, 2, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 1, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 2, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 3, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 4, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 5, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 6, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 7, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 8, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 9, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416009115, 10, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 1, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 3, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 4, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 5, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 6, 191, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 7, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 8, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 9, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 10, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 11, 161, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 12, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 13, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117009116, 14, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801009117, 1, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801009117, 2, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801009117, 3, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801009117, 4, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801009117, 5, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 1, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 2, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 3, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 4, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 5, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 6, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 7, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218009118, 8, 1, 40, 3, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709009119, 1, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709009119, 2, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000709009119, 3, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 1, 42, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 2, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 3, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 4, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 5, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 6, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 7, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004009120, 8, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329009121, 1, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329009121, 2, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329009121, 3, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329009121, 4, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329009121, 5, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508009122, 1, 150, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508009122, 2, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 1, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 2, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 3, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 4, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 5, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 6, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 7, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 8, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129009123, 9, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013009124, 1, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013009124, 2, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013009124, 3, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013009124, 4, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310009125, 1, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310009125, 2, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310009125, 3, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310009125, 4, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128009126, 1, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128009126, 2, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128009126, 3, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128009126, 4, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128009126, 5, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221009127, 1, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221009127, 2, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221009127, 3, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221009127, 4, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 1, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 2, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 3, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 4, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 5, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 6, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 8, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310009128, 9, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 1, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 2, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 3, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 4, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 5, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 6, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 7, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505009129, 8, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514009130, 1, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514009130, 2, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514009130, 3, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 1, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 2, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 3, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 4, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 5, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 6, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 7, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 8, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 9, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 10, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 11, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 12, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 13, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 14, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 15, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 16, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513009131, 17, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723009132, 1, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723009132, 2, 89, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723009132, 3, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723009132, 4, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723009132, 5, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 1, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 2, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 3, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 4, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 5, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 6, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 7, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050225009133, 8, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 1, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 2, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 3, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 4, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 5, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 6, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 7, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 8, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 9, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 10, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 11, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 12, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102009134, 13, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 1, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 2, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 3, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 4, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 5, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 6, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 7, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 8, 12, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 9, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 10, 157, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 11, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 12, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 13, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 14, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 15, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120515009135, 16, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 1, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 2, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 3, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 4, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 5, 174, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 6, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 7, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 8, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 9, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 10, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315009136, 11, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 15, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 1, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 2, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 3, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 4, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 5, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 6, 19, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 7, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 8, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 9, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 10, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 11, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 12, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 13, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010640, 14, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 1, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 2, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 3, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 4, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 5, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 6, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 7, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 8, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 9, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060726010641, 10, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010642, 1, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010642, 2, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010642, 3, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010642, 4, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010642, 5, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 1, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 2, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 3, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 4, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 5, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 6, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 7, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 8, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 9, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 10, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920010643, 11, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 1, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 2, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 3, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 4, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 5, 29, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 6, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 7, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 8, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 9, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 10, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 11, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 12, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 13, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 14, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 15, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 16, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 17, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010644, 18, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 1, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 2, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 3, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 4, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 5, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 6, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 7, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 8, 192, 19, 18, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 9, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 10, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070103010645, 11, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 1, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 2, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 3, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 4, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 5, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 6, 109, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 7, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 8, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 9, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 10, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919010646, 11, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 1, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 2, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 3, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 4, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 5, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 6, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 7, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 8, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 9, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 10, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 11, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 12, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 13, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714010647, 14, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 1, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 2, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 3, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 4, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 5, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 6, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 7, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010648, 8, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 1, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 2, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 3, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 4, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 5, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 6, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 7, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 8, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 9, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 10, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 11, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 12, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010649, 13, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905010650, 1, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905010650, 2, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905010650, 3, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905010650, 4, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905010650, 5, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 1, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 2, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 3, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 4, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 5, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 6, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 7, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 8, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 9, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 10, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010651, 11, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 1, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 2, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 3, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 4, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 5, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 6, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 7, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 8, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 9, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 10, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 11, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 12, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 13, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 14, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 15, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 16, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412010652, 17, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 1, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 2, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 3, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 4, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 5, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 6, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 7, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 8, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 9, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 10, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 11, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 12, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 13, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 14, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 15, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010653, 16, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 1, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 2, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 3, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 4, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 5, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 6, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 7, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 8, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 9, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 10, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 11, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 12, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 13, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120331010654, 14, 107, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 1, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 2, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 3, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 4, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 5, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 6, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 7, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 8, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 9, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 10, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 11, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602010655, 12, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821010656, 1, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821010656, 2, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821010656, 3, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821010656, 4, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 1, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 2, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 3, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 4, 74, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 5, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 6, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 7, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 8, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 9, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831010657, 10, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 1, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 2, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 3, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 4, 37, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 5, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 6, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 7, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 8, 138, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 9, 192, 35, 18, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 10, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 11, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010658, 12, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010659, 1, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010659, 2, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010659, 3, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010659, 4, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010659, 5, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 1, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 2, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 3, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 4, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 5, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 6, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417010660, 7, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 1, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 2, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 3, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 4, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 5, 185, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 6, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 7, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 8, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 9, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 10, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 3, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 4, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 5, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 6, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 7, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 8, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 9, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 10, 90, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 11, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 12, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 13, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 14, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 15, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 16, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010997, 1, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010997, 2, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010997, 3, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816010997, 4, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 1, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 2, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 3, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 4, 16, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 5, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 6, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 7, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 8, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404010998, 9, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319010999, 1, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319010999, 2, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319010999, 3, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319010999, 4, 51, 20, 8, 160);
commit;
prompt 103000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 1, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 2, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 3, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 4, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 5, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 6, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 7, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 8, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 9, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 10, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 11, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 12, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100527011000, 13, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 1, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 2, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 3, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 4, 52, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 5, 46, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 6, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 7, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701011001, 8, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 1, 108, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 2, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 3, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 4, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 5, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 6, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 7, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 8, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 9, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406011002, 10, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 1, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 2, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 3, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 4, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 5, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 6, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 7, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 8, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 9, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 10, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216011003, 11, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 1, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 2, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 3, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 4, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 5, 84, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514011004, 6, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821011005, 1, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821011005, 2, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821011005, 3, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821011005, 4, 48, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 1, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 2, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 3, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 4, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 5, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 6, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 7, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 8, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 9, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 10, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 11, 103, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 12, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 13, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 14, 148, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 15, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 16, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 17, 148, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825011006, 18, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 1, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 2, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 3, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 4, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 5, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 6, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 7, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 8, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 9, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 10, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 11, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 12, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 13, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 14, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 15, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428011007, 16, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 1, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 2, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 3, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 4, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 5, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725011008, 6, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 1, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 2, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 3, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 4, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 5, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 6, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 7, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 8, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 9, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 10, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 11, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 12, 74, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909011009, 13, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114011010, 1, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114011010, 2, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114011010, 3, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114011010, 4, 42, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114011010, 5, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 1, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 2, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 3, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 4, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 5, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 6, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 7, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 8, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 9, 121, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 10, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 11, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 12, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 13, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 14, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 15, 144, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 16, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819011011, 17, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 1, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 2, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 3, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 4, 65, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 5, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 6, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 7, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060305011012, 8, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511011013, 1, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511011013, 2, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511011013, 3, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511011013, 4, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511011013, 5, 100, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 1, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 2, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 3, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 4, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 5, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 6, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 7, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 8, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 9, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 10, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 11, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827011014, 12, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 1, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 2, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 3, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 4, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 5, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019011015, 6, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 1, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 2, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 3, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 4, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 5, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 6, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 7, 88, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327011016, 8, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 1, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 2, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 3, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 4, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 5, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 6, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 7, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 8, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 9, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 10, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 11, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 12, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 13, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 14, 154, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120701011017, 15, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 1, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 2, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 3, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 4, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 5, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 6, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 7, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 8, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 9, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 10, 15, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 11, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 12, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 13, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 14, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925011018, 15, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 1, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 2, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 3, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 4, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 5, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 6, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 7, 10, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 8, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 9, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 10, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 11, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 12, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 2, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 3, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 4, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 5, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 6, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 7, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 8, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 9, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 10, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 11, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309011371, 1, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309011371, 2, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309011371, 3, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309011371, 4, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020309011371, 5, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 1, 78, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 2, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 3, 65, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 4, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 5, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 6, 56, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 7, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 8, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 9, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 10, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091125011372, 11, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 1, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 2, 157, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 3, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 4, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 5, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 6, 77, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 7, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 8, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 9, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 10, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 11, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 12, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 13, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011373, 14, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 1, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 2, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 3, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 4, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 5, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 6, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520011374, 7, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 1, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 2, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 3, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 4, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 5, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 6, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 7, 29, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 8, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 9, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 10, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 11, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 12, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 13, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 14, 96, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019011375, 15, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 1, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 2, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 3, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 4, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 5, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401011376, 6, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211011377, 1, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211011377, 2, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211011377, 3, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211011377, 4, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010211011377, 5, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 1, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 2, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 3, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 4, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 5, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 6, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 7, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 8, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 9, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 10, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213011378, 11, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 1, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 2, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 3, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 4, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 5, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 6, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 7, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 8, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 9, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 10, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 11, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 12, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 13, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 14, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 15, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011379, 16, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 1, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 2, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 3, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 4, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 5, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 6, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 7, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051009011380, 8, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023011381, 1, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001023011381, 2, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 1, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 2, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 3, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 4, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 5, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208011382, 6, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 1, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 2, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 3, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 4, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 5, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 6, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 7, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 8, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 9, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 10, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 11, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 12, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 13, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 14, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011383, 15, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 1, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 2, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 3, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 4, 45, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 5, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 6, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 7, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 8, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 9, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 10, 127, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 11, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 12, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080624011384, 13, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 1, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 2, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 3, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 4, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 5, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 6, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 7, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220011385, 8, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 1, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 2, 72, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 3, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 4, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 5, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 6, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 7, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 8, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 9, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 10, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720011386, 11, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031011387, 1, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031011387, 2, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031011387, 3, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 1, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 2, 86, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 3, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 4, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 5, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 6, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303011388, 7, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303011389, 1, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303011389, 2, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303011389, 3, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303011389, 4, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303011389, 5, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 1, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 3, 95, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 4, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 5, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 6, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 7, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 8, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 9, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 10, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 11, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 12, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 13, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 14, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011390, 15, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 1, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 2, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 3, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 4, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 5, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 6, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 7, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 8, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060828011391, 9, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 1, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 2, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 3, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 4, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 5, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 6, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 7, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 8, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 9, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071212011392, 10, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 1, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 2, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 3, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 4, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 5, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 6, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 7, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124011393, 8, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224011394, 1, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224011394, 2, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224011394, 3, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224011394, 4, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 1, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 2, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 3, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 4, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 5, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 6, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 7, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 8, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 9, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116011395, 10, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 1, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 2, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 3, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 4, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 5, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 2, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 3, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 4, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 5, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 6, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 7, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 8, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 9, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 10, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 11, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 1, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 2, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 3, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 4, 64, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 5, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 6, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 7, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 8, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 9, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 10, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 11, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 12, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 13, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 14, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225010266, 15, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 1, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 2, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 3, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 4, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 5, 153, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 6, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 7, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 8, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 9, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 10, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 11, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 12, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 13, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 14, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 15, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110113010267, 16, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219010268, 1, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219010268, 2, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001219010268, 3, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 1, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 2, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 3, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 4, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 5, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 6, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 7, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 8, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 9, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 10, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 11, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 12, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011010269, 13, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 1, 21, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 2, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 3, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 4, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 5, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010270, 6, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 1, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 2, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 3, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 4, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 5, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 6, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611010271, 7, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 1, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 2, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 3, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 4, 5, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 5, 124, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 6, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 7, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 8, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 9, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 10, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 11, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 12, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 13, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 14, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 15, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526010272, 16, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 1, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 2, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 3, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 4, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 5, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 6, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 7, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 8, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 9, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 10, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311010273, 11, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 1, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 2, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 3, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 4, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 5, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 6, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 7, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 8, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 9, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 10, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 11, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 12, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 13, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 14, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123010274, 15, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 1, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 2, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 3, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 4, 85, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 5, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 6, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111010275, 7, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120010276, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120010276, 2, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120010276, 3, 99, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 1, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 2, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 3, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 4, 154, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 5, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 6, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 7, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 8, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050717010277, 9, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 1, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 2, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 3, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 4, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 5, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 6, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 7, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 8, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 9, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 10, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802010278, 11, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010279, 1, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010279, 2, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010279, 3, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118010280, 1, 25, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118010280, 2, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118010280, 3, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118010280, 4, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118010280, 5, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 1, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 2, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 3, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 4, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 5, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 6, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 7, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 8, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 9, 54, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 10, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 11, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 12, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 13, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 14, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 15, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325010281, 16, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 1, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 2, 125, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 3, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 4, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 5, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 6, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 7, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 8, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 9, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 10, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 11, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 12, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010282, 13, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 1, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 2, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 3, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 4, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 5, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 6, 180, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 7, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040102010283, 8, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 1, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 2, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 3, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 4, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 5, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 6, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 7, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 8, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331010284, 9, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122010285, 1, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122010285, 2, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122010285, 3, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122010285, 4, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122010285, 5, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 1, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 2, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 3, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 4, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 5, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 6, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 7, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 8, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010286, 9, 73, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 1, 65, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 2, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 3, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 4, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 5, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 6, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 7, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127010287, 8, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 1, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 2, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 3, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 4, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 5, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 6, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 7, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 8, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 9, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 10, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 11, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 12, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 13, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 14, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 15, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 16, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 17, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220010288, 18, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410010289, 1, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410010289, 2, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410010289, 3, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 11, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 12, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608010661, 13, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 1, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 2, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 3, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 4, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 5, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 6, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 7, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 8, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 9, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 10, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 11, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 12, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 13, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 14, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024010662, 15, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010663, 1, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010663, 2, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010663, 3, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010663, 4, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010663, 5, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 1, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 2, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 3, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 4, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 5, 125, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 6, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 7, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 8, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 9, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 10, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090118010664, 11, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 1, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 2, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 3, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 4, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 5, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 6, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 7, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 8, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010665, 9, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 1, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 2, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 3, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 4, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 5, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 6, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 7, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131010666, 8, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226010667, 1, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226010667, 2, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226010667, 3, 89, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226010667, 4, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 1, 1, 22, 3, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 2, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 3, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 4, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 5, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 6, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 7, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 8, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422010668, 9, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 1, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 2, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 3, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 4, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 5, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 6, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 7, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 8, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 9, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 10, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 11, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 12, 108, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 13, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617010669, 14, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 1, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 2, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 3, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 4, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 5, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 6, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 7, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 8, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 9, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 10, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 11, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 12, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 13, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 14, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 15, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 16, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 17, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505010670, 18, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 1, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 2, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 3, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 4, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 5, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 6, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 7, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010671, 8, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 1, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 2, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 3, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 4, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 5, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 6, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 7, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 8, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 9, 148, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 10, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 11, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 12, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 13, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 14, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329010672, 15, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 1, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 2, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 3, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 4, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 5, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 6, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 7, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 8, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 9, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 10, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 11, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 12, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 13, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010673, 14, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 1, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 2, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 3, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 4, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 5, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 6, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 7, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 8, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 9, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 10, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 11, 33, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105010674, 12, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 1, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 2, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 3, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 4, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 5, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 6, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 7, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 8, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126010675, 9, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 1, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 2, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 3, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 4, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 5, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 6, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 7, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 8, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 9, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 10, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 11, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009010676, 12, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217010677, 1, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217010677, 2, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217010677, 3, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001217010677, 4, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 1, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 2, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 3, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 4, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 5, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 6, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 7, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 8, 154, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 9, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 10, 124, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 11, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 12, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121010678, 13, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010502010679, 1, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010502010679, 2, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010502010679, 3, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010502010679, 4, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 1, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 2, 144, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 3, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 4, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 5, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 6, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 7, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 8, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060531010680, 9, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 1, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 2, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 3, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 4, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 5, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 6, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 7, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 8, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 9, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 10, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 11, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 12, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 13, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010681, 14, 9, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 1, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 2, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 3, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 4, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 5, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 6, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 7, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 8, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 9, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 10, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 11, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 12, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 13, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 14, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708010682, 15, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 1, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 2, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 3, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 4, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 5, 163, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 6, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 7, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 8, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 9, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 10, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129010683, 11, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 1, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 2, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 3, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 13, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091120011019, 14, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 1, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 2, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 3, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 4, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 5, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 6, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 7, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011020, 8, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 1, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 2, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 3, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 4, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 5, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 6, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 7, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 8, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 9, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 10, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 11, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 12, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 13, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 14, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 15, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209011021, 16, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 1, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 2, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 3, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 4, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 5, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 6, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 7, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 8, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 9, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 10, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 11, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 12, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824011022, 13, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 1, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 2, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 3, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 4, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 5, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 6, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 7, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 8, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 9, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 10, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 11, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 12, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 13, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 14, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 15, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310011023, 16, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 1, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 2, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 3, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 4, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 5, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 6, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 7, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 8, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 9, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 10, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011024, 11, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202011025, 1, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202011025, 2, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202011025, 3, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202011025, 4, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202011025, 5, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 1, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 2, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 3, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 4, 78, 91, 11, 1001);
commit;
prompt 104000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 5, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 6, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 7, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 8, 110, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 9, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 10, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 11, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 12, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118011026, 13, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 1, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 2, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 3, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 4, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 5, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 6, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 7, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 8, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 9, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 10, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 11, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 12, 71, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 13, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508011027, 14, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 1, 173, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 2, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 3, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 4, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 5, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 6, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 7, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 8, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 9, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 10, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117011028, 11, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 1, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 2, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 3, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 4, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 5, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 6, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 7, 71, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 8, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 9, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 10, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 11, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 12, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 13, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 14, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100909011029, 15, 167, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 1, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 2, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 3, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 4, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 5, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 6, 108, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 7, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 8, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 9, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 10, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 11, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 12, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 13, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 14, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011030, 15, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 1, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 2, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 3, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 4, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 5, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 6, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 7, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 8, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 9, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 10, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 11, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091024011031, 12, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 1, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 2, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 3, 145, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 4, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 5, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 6, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 7, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 8, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 9, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 10, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080606011032, 11, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 1, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 2, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 3, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 4, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 5, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 6, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706011033, 7, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 1, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 2, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 3, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 4, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 5, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 6, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 7, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011034, 8, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 1, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 2, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 3, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 4, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 5, 192, 64, 18, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020107011035, 6, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 1, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 2, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 3, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 4, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 5, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 6, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 7, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 8, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 9, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 10, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829011036, 11, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 1, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 2, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 3, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 4, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 5, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 6, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 7, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 8, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 9, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 10, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 11, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 12, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 13, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 14, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601011037, 15, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 1, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 2, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 3, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 4, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 5, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 6, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 7, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 8, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 9, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310011038, 10, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 1, 132, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 2, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 3, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 4, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 5, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011015011039, 6, 154, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 1, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 2, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 3, 88, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 4, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 5, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 6, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 7, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 8, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 9, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 10, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 11, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 12, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 13, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 14, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 6, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 7, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 8, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 9, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 10, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 11, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 12, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 13, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 14, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716011396, 15, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 1, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 2, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 3, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 4, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 5, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 6, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 7, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 8, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050311011397, 9, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215011398, 1, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215011398, 2, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215011398, 3, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215011398, 4, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215011398, 5, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118011399, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118011399, 2, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118011399, 3, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118011399, 4, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118011399, 5, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 1, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 2, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 3, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 4, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 5, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 6, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 7, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 8, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 9, 3, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 10, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813011400, 11, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010215011401, 1, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010215011401, 2, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010215011401, 3, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010215011401, 4, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 1, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 2, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 3, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 4, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 5, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 6, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 7, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 8, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 9, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 10, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 11, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 12, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 13, 150, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 14, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 15, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704011402, 16, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 1, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 2, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 3, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 4, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 5, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 6, 180, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024011403, 7, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 1, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 2, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 3, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 4, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 5, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 6, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 7, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 8, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 9, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 10, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070411011404, 11, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 1, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 2, 189, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 3, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 4, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 5, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 6, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 7, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 8, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 9, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011405, 10, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427011406, 1, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427011406, 2, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427011406, 3, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427011406, 4, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427011406, 5, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 1, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 2, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 3, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 4, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 5, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 6, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 7, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 8, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 9, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 10, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 11, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 12, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090417011407, 13, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 1, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 2, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 3, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 4, 15, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 5, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 6, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 7, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 8, 109, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 9, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 10, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060123011408, 11, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913011409, 1, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913011409, 2, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913011409, 3, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913011409, 4, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913011409, 5, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 1, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 2, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 3, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 4, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 5, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 6, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051112011410, 7, 182, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 1, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 2, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 3, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 4, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 5, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 6, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 7, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 8, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 9, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 10, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 11, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 12, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 13, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201011411, 14, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 1, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 2, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 3, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 4, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 5, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 6, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 7, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 8, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 9, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 10, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213011412, 11, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 1, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 2, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 3, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 4, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 5, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 6, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 7, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 8, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 9, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 10, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071208011413, 11, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 1, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 2, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 3, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 4, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 5, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 6, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 7, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 8, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 9, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 10, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623011414, 11, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 1, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 2, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 3, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 4, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 5, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 6, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 7, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 8, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071109011415, 9, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 1, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 2, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 3, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 4, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 5, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 6, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 7, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 8, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 9, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 10, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 11, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 12, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313011416, 13, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 1, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 2, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 3, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 4, 30, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 5, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 6, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423011417, 7, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 1, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 2, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 3, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 4, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 5, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 6, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 7, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 8, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 9, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 10, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 11, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 12, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 13, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 14, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 15, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808011418, 16, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 1, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 2, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 3, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 4, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 5, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 6, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 7, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 8, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 9, 146, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 10, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 11, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112011419, 12, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 1, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 2, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 3, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 4, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 5, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 6, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410010289, 4, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020410010289, 5, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 1, 94, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 2, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 3, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 4, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 5, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 6, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 7, 102, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 8, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 9, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 10, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 11, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 12, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 13, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 14, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 15, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010290, 16, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 1, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 2, 20, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 3, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 4, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 5, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 6, 36, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 7, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 8, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 9, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 10, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 11, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100723010291, 12, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128010292, 1, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128010292, 2, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128010292, 3, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128010292, 4, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001128010292, 5, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 1, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 2, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 3, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 4, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 5, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 6, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 7, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 8, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 9, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 10, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 11, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 12, 28, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 13, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 14, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131010293, 15, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223010294, 1, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223010294, 2, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 1, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 2, 27, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 3, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 4, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 5, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 6, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 7, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 8, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 9, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 10, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 11, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 12, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 13, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 14, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529010295, 15, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222010296, 1, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222010296, 2, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222010296, 3, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 1, 75, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 2, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 3, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 4, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 5, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 6, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823010297, 7, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 1, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 2, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 3, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 4, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 5, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 6, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 7, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 8, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 9, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 10, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 11, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 12, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 13, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 14, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 15, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 16, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331010298, 17, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 1, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 2, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 3, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 4, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 5, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 6, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 7, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 8, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 9, 132, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 10, 109, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 11, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080810010299, 12, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 1, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 2, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 3, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 4, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 5, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 6, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201010300, 7, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 1, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 2, 163, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 3, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 4, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 5, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 6, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 7, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 8, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 9, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 10, 24, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 11, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029010301, 12, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 1, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 2, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 3, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 4, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 5, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 6, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 7, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 8, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 9, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 10, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220010302, 11, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 1, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 2, 19, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 3, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 4, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 5, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010303, 6, 104, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 1, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 2, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 3, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 4, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 5, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 6, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 7, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 8, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120010304, 9, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 1, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 2, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 3, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 4, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 5, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 6, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 7, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 8, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 9, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 10, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 11, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 12, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 13, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 14, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105010305, 15, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 1, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 2, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 3, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 4, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 5, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 6, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 7, 90, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 8, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 9, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 10, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306010306, 11, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 1, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 2, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 3, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 4, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 5, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 6, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 7, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 8, 134, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 9, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 10, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 11, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 12, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029010307, 13, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 1, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 2, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 3, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 4, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 5, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 6, 16, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221010308, 7, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 1, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 2, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 3, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 4, 25, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 5, 146, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 6, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 7, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010309, 8, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 1, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 2, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 3, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 4, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 5, 97, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 6, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 7, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 8, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 9, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 10, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 11, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 12, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 13, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 14, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 15, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 16, 78, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111010310, 17, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 1, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 2, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 3, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 4, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 5, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 6, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030219010311, 7, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 1, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 2, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 3, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 4, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 5, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 6, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 7, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 8, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 9, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 10, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 4, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 5, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 6, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 7, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 8, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 9, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 10, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070830010684, 11, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 1, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 2, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 3, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 4, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 5, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 6, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 7, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 8, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 9, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 10, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 11, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 12, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 13, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 14, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120830010685, 15, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 1, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 2, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 3, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 4, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 5, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 6, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 7, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 8, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 9, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 10, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 11, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424010686, 12, 114, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 1, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 2, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 3, 128, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 4, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 5, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 6, 91, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 7, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 8, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 9, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 10, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 11, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 12, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 13, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 14, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 15, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 16, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140310010687, 17, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 1, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 2, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 3, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 4, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 5, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 6, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 7, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 8, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 9, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 10, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 11, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 12, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 13, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 14, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120825010688, 15, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 1, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 2, 44, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 3, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 4, 180, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 5, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 6, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 7, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 8, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 9, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 10, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 11, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620010689, 12, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 1, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 2, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 3, 19, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 4, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 5, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 6, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 7, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 8, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 9, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070615010690, 10, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 1, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 2, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 3, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 4, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 5, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 6, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 7, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018010691, 8, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 1, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 2, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 3, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 4, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 5, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 6, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 7, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 8, 157, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 9, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 10, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 11, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 12, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122010692, 13, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 1, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 2, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 3, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 4, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 5, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 6, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 7, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 8, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 9, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 10, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 11, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 12, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 13, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 14, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 15, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 16, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306010693, 17, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 1, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 2, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 3, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 4, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 5, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 6, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 7, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 8, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203010694, 9, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109010695, 1, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109010695, 2, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109010695, 3, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109010695, 4, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011109010695, 5, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 1, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 2, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 3, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 4, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 5, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 6, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 7, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121010696, 8, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 1, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 2, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 3, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 4, 159, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 5, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 6, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 7, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 8, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 9, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223010697, 10, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 1, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 2, 177, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 3, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 4, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 5, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 6, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 7, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 8, 65, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 9, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081229010698, 10, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 1, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 2, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 3, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 4, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 5, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 6, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 7, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 8, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 9, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 10, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010699, 11, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 1, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 2, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 3, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 4, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 5, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 6, 87, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 7, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 8, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 9, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 10, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 11, 151, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010700, 12, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 1, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 2, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 3, 23, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 4, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 5, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 6, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 7, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 8, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 9, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 10, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 11, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 12, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 13, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223010701, 14, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 1, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 2, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 3, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 4, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 5, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 6, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020809010702, 7, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 1, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 2, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 3, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 4, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 5, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 6, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 7, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 8, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 9, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 10, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 11, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 12, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 13, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 14, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508010703, 15, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 1, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 2, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 3, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 4, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 5, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 6, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 7, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 8, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 9, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 10, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 11, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 15, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 16, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 17, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602011040, 18, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 1, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 2, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 3, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 4, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 5, 136, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 6, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 7, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 8, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 9, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 10, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 11, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 12, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 13, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023011041, 14, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 1, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 2, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 3, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 4, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 5, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 6, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 7, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 8, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 9, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 10, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917011042, 11, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 1, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 2, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 3, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 4, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 5, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 6, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 7, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 8, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 9, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 10, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 11, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 12, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 13, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 14, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 15, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 16, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526011043, 17, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519011044, 1, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519011044, 2, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519011044, 3, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 1, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 2, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 3, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 4, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 5, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 6, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 7, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 8, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 9, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 10, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 11, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 12, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 13, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 14, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 15, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 16, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523011045, 17, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726011046, 1, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726011046, 2, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726011046, 3, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726011046, 4, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010726011046, 5, 132, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 1, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 2, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 3, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 4, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 5, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 6, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 7, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 8, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 9, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 10, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 11, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 12, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091028011047, 13, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 1, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 2, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 3, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 4, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 5, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 6, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 7, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 8, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 9, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 10, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 11, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 12, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110611011048, 13, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 1, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 2, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 3, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 4, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 5, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 6, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 7, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 8, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 9, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 10, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 11, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 12, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 13, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 14, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 15, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 16, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011049, 17, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 1, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 2, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 3, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 4, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 5, 72, 98, 12, 1176);
commit;
prompt 105000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 6, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 7, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 8, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 9, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 10, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 11, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 12, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011050, 13, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 1, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 2, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 3, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 4, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 5, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005011051, 6, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822011052, 1, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822011052, 2, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822011052, 3, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822011052, 4, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822011052, 5, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129011053, 1, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129011053, 2, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129011053, 3, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001129011053, 4, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 1, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 2, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 3, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 4, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 5, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 6, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 7, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 8, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 9, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912011054, 10, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 1, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 2, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 3, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 4, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 5, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 6, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011055, 7, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725011056, 1, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725011056, 2, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725011056, 3, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725011056, 4, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725011056, 5, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 1, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 2, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 3, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 4, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 5, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 6, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 7, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225011057, 8, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 1, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 2, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 3, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 4, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 5, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 6, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328011058, 7, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 1, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 2, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 3, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 4, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 5, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 6, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 7, 50, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 8, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 9, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 10, 137, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312011059, 11, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 1, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 2, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 3, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 4, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 5, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 6, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 7, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 8, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 9, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 10, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 11, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 12, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 13, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 14, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 15, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 16, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011060, 17, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 1, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 2, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 3, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 4, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 5, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 6, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 7, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 8, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 9, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 10, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 11, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011061, 12, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 1, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 2, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 3, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 4, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 5, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 6, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 7, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 8, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 9, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 10, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 11, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011062, 12, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 1, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 2, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 3, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 4, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 5, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 6, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 7, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040628011063, 8, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 7, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 8, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 9, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218011420, 10, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 1, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 2, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 3, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 4, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 5, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 6, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 7, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 8, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 9, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 10, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 11, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070128011421, 12, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118011422, 1, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118011422, 2, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118011422, 3, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118011422, 4, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 1, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 2, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 3, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 4, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 5, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 6, 181, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 7, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 8, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009011423, 9, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 1, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 2, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 3, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 4, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 5, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522011424, 6, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 1, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 2, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 3, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 4, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 5, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031011425, 6, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 1, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 2, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 3, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 4, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 5, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 6, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 7, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201011426, 8, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 1, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 2, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 3, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 4, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 5, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 6, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 7, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 8, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060103011427, 9, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 1, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 2, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 3, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 4, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 5, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 6, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 7, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 8, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 9, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321011428, 10, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 1, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 2, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 3, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 4, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 5, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 6, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 7, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 8, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071222011429, 9, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 1, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 2, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 3, 69, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 4, 163, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 5, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 6, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 7, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 8, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011430, 9, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 1, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 2, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 3, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 4, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 5, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 6, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 7, 128, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 8, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 9, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 10, 165, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 11, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 12, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 13, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 14, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 15, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 16, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510011431, 17, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 1, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 2, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 3, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 4, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 5, 42, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 6, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 7, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 8, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 9, 134, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 10, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 11, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 12, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 13, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 14, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 15, 183, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204011432, 16, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 1, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 2, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 3, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 4, 140, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 5, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 6, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 7, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 8, 160, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 9, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 10, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 11, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024011433, 12, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 1, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 2, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 3, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 4, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 5, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 6, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 7, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 8, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 9, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 10, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 11, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 12, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710011434, 13, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016011435, 1, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016011435, 2, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016011435, 3, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016011435, 4, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 1, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 2, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 3, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 4, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 5, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 6, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 7, 161, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 8, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 9, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 10, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 11, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 12, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011436, 13, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 1, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 2, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 3, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 4, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 5, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 6, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 7, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011437, 8, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 1, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 2, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 3, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 4, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 5, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 6, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 7, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011438, 8, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 1, 53, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 2, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 3, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 4, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 5, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 6, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 7, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229011439, 8, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 1, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 2, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 3, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 4, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 5, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 6, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 7, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 8, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 9, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 10, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 11, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 12, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 13, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 14, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624011440, 15, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 1, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 2, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 3, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 4, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 5, 31, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 6, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 7, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 8, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 9, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070404011441, 10, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201011442, 1, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201011442, 2, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201011442, 3, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 1, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 2, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 3, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 4, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 5, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 6, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129011443, 7, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 1, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 2, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 3, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 4, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 5, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 6, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 7, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 8, 94, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 9, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 10, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 11, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 12, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615011444, 13, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 1, 142, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 2, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 3, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 4, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 5, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 6, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071007010312, 11, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 1, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 2, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 3, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 4, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 5, 148, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020404010313, 6, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608010314, 1, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608010314, 2, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 1, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 2, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 3, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 4, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 5, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030415010315, 6, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 1, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 2, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 3, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 4, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 5, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 6, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 7, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 8, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 9, 22, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 10, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 11, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 12, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 13, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 14, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010316, 15, 20, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 1, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 2, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 3, 126, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 4, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 5, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 6, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 7, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 8, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 9, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 10, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010317, 11, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 1, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 2, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 3, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 4, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 5, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 6, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 7, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 8, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 9, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 10, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 11, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 12, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 13, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 14, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 15, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806010318, 16, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 1, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 2, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 3, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 4, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 5, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 6, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 7, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 8, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 9, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318010319, 10, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 1, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 2, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 3, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 4, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 5, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 6, 99, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 7, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 8, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 9, 108, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 10, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 11, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326010320, 12, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 1, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 2, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 3, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 4, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 5, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 6, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 7, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 8, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 9, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702010321, 10, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 1, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 2, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 3, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 4, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 5, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 6, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 7, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 8, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 9, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 10, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 11, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 12, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 13, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 14, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 15, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 16, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 17, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 18, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140511010322, 19, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 1, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 2, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 3, 108, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 4, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 5, 157, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 6, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 7, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010323, 8, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 1, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 2, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 3, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 4, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 5, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 6, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 7, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 8, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 9, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 10, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 11, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 12, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 13, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 14, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 15, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 16, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401010324, 17, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010325, 1, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010325, 2, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010325, 3, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010325, 4, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 1, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 2, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 3, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 4, 178, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 5, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 6, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 7, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 8, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 9, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107010326, 10, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 1, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 2, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 3, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 4, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 5, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 6, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 7, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 8, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 9, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 10, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 11, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 12, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 13, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 14, 119, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 15, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111024010327, 16, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618010328, 1, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618010328, 2, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618010328, 3, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618010328, 4, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 1, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 2, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 3, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 4, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 5, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 6, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 7, 66, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 8, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 9, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 10, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 11, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 12, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 13, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100810010329, 14, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 1, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 2, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 3, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 4, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 5, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 6, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 7, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 8, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 9, 139, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081026010330, 10, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 1, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 2, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 3, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 4, 137, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 5, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 6, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 7, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 8, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 9, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010331, 10, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 1, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 2, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 3, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 4, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 5, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 6, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 7, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024010332, 8, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 1, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 2, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 3, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 4, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 5, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 6, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 7, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 8, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 9, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 10, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 11, 16, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 12, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 13, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 14, 165, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529010333, 15, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 1, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 2, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 3, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 4, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 5, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 6, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 7, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050420010334, 8, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 1, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 2, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 3, 162, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 4, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 5, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 6, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 7, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 12, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317010704, 13, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 1, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 2, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 3, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 4, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 5, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 6, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 7, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 8, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 9, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 10, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525010705, 11, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010706, 1, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010706, 2, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010706, 3, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010706, 4, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010706, 5, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 1, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 2, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 3, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 4, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 5, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 6, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 7, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 8, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 9, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513010707, 10, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 1, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 2, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 3, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 4, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 5, 182, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 6, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 7, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010708, 8, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 1, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 2, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 3, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 4, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 5, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 6, 178, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 7, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 8, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 9, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 10, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 11, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 12, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 13, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 14, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110717010709, 15, 122, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 1, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 2, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 3, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 4, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 5, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 6, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 7, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 8, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 9, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 10, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 11, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 12, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 13, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 14, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010710, 15, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 1, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 2, 64, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 3, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 4, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 5, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 6, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 7, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 8, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 9, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 10, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 11, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 12, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129010711, 13, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 1, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 2, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 3, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 4, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 5, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 6, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 7, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 8, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 9, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 10, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 11, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 12, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 13, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100420010712, 14, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302010713, 1, 172, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302010713, 2, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302010713, 3, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 1, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 2, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 3, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 4, 1, 21, 3, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 5, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 6, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 7, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 8, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 9, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 10, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 11, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080716010714, 12, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 1, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 2, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 3, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 4, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 5, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 6, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 7, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 8, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 9, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 10, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 11, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 12, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518010715, 13, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904010716, 1, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904010716, 2, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000904010716, 3, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 1, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 2, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 3, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 4, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 5, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 6, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 7, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626010717, 8, 15, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 1, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 2, 120, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 3, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 4, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 5, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 6, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 7, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 8, 66, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108010718, 9, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 1, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 2, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 3, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 4, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 5, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 6, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 7, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 8, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 9, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301010719, 10, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 1, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 2, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 3, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 4, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 5, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 6, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204010720, 7, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 1, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 2, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 3, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 4, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 5, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 6, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 7, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041217010721, 8, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 1, 11, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 2, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 3, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 4, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 5, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 6, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 7, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 8, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 9, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 10, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 11, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 12, 18, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 13, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229010722, 14, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 1, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 2, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 3, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 4, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 5, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 6, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 7, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 8, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115010723, 9, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324010724, 1, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324010724, 2, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324010724, 3, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 1, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 2, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 3, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 4, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 5, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 6, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112010725, 7, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 1, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 2, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 3, 11, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 4, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 5, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 6, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 7, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 8, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 9, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 10, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 11, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 12, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 13, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091013010726, 14, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 1, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 2, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 3, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 4, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 5, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 6, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 7, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 8, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 9, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 10, 66, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 11, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 12, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 13, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811010727, 14, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 1, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 2, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 3, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 4, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 5, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 6, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 7, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 8, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 9, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120010728, 10, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 1, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 2, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 1, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 2, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 3, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 4, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 5, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 6, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 7, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 8, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 9, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 10, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 11, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004011064, 12, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 1, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 2, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 3, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 4, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 5, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 6, 70, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 7, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 8, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 9, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 10, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 11, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020011065, 12, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 1, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 2, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 3, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 4, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 5, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 6, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 7, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 8, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 9, 92, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 10, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080820011066, 11, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 1, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 2, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 3, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 4, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 5, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 6, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 7, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 8, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 9, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 10, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 11, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 12, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228011067, 13, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011068, 1, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011068, 2, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011068, 3, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011068, 4, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011068, 5, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 1, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 2, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 3, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 4, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 5, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 6, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 7, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629011069, 8, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 1, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 2, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 3, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 4, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 5, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 6, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 7, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 8, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 9, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 10, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 11, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 12, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 13, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 14, 105, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 15, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907011070, 16, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 1, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 2, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 3, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 4, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 5, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 6, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 7, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 8, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 9, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 10, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 11, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091025011071, 12, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 1, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 2, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 3, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 4, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 5, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 6, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 7, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 8, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 9, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 10, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 11, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 12, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330011072, 13, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522011073, 1, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522011073, 2, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522011073, 3, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 1, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 2, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 3, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 4, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 5, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210011074, 6, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 1, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 2, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 3, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 4, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 5, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 6, 29, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 7, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 8, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 9, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 10, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020011075, 11, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105011076, 1, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105011076, 2, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105011076, 3, 95, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105011076, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105011076, 5, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 1, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 2, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 3, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 4, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 5, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 6, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 7, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 8, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 9, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 10, 69, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 11, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 12, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 13, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 14, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 15, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120621011077, 16, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 1, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 2, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 3, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 4, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 5, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 6, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 7, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 8, 78, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060228011078, 9, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 1, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 2, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 3, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 4, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 5, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 6, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 7, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 8, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912011079, 9, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 1, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 2, 29, 36, 10, 360);
commit;
prompt 106000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 3, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 4, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 5, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 6, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 7, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 8, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 9, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 10, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 11, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 12, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 13, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 14, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813011080, 15, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 1, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 2, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 3, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 4, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 5, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 6, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 7, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 8, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 9, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419011081, 10, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 1, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 2, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 3, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 4, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 5, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 6, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 7, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 8, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 9, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 10, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416011082, 11, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 1, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 2, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 3, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 4, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 5, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 6, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 7, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 8, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 9, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 10, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 11, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 12, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 13, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012011083, 14, 50, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 1, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 2, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 3, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 4, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 5, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 6, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807011084, 7, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 1, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 2, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 3, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 4, 99, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 5, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 6, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 7, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 8, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 9, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 10, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 11, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 12, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100114011085, 13, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324011086, 1, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324011086, 2, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324011086, 3, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324011086, 4, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011087, 1, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011087, 2, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011087, 3, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011087, 4, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030114011445, 7, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 1, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 2, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 3, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 4, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 5, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 6, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 7, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 8, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 9, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913011446, 10, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 1, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 2, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 3, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 4, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 5, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 6, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 7, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 8, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 9, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 10, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 11, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 12, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 13, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 14, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121021011447, 15, 21, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 1, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 2, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 3, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 4, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 5, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 6, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 7, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 8, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 9, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 10, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 11, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 12, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516011448, 13, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 1, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 2, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 3, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 4, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 5, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 6, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 7, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 8, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 9, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 10, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 11, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 12, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 13, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210011449, 14, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 1, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 2, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 3, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 4, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 5, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 6, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 7, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 8, 160, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 9, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 10, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 11, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218011450, 12, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 1, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 2, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 3, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 4, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 5, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 6, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 7, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 8, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207011451, 9, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 1, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 2, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 3, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 4, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 5, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 6, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 7, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 8, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405011452, 9, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 1, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 2, 51, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 3, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 4, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 5, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 6, 115, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 7, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 8, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 9, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 10, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 11, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926011453, 12, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 1, 85, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 2, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 3, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 4, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 5, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 6, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 7, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 8, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040619011454, 9, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 1, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 2, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 3, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 4, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 5, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 6, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424011455, 7, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 1, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 2, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 3, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 4, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 5, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 6, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 7, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 8, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 9, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 10, 146, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617011456, 11, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 1, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 2, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 3, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 4, 190, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 5, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 6, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421011457, 7, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 1, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 2, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 3, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 4, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 5, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 6, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 7, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 8, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 9, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 10, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 11, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 12, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 13, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 14, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 15, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140120011458, 16, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 1, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 2, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 3, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 4, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 5, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 6, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020516011459, 7, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 1, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 2, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 3, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 4, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 5, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 6, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 7, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 8, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 9, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513011460, 10, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 1, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 2, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 3, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 4, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 5, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030611011461, 6, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 1, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 2, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 3, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 4, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 5, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 6, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 7, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 8, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 9, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 10, 39, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 11, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 12, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 13, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 14, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 15, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140228011462, 16, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 1, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 2, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 3, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 4, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 5, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 6, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 7, 39, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 8, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 9, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 10, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 11, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605011463, 12, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 1, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 2, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 3, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 4, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 5, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 6, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 7, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 8, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 9, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 10, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 11, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 12, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 13, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229011464, 14, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 1, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 2, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 3, 168, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 4, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 5, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 6, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 7, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 8, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 9, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 10, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 11, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101117011465, 12, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 1, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 2, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 3, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 4, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 5, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 6, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 7, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 8, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 9, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 10, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208011466, 11, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 1, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 2, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 3, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 4, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 5, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 8, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 9, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 10, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 11, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 12, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 13, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717010335, 14, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 1, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 2, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 3, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 4, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 5, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514010336, 6, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819010337, 1, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819010337, 2, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819010337, 3, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819010337, 4, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 1, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 2, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 3, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 4, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 5, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 6, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 7, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 8, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 9, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 10, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 11, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 12, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 13, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 14, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203010338, 15, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 1, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 2, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 3, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 4, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 5, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 6, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 7, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 8, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 9, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 10, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 11, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 12, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 13, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818010339, 14, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 1, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 2, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 3, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 4, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 5, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 6, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 7, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 8, 21, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719010340, 9, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026010341, 1, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026010341, 2, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026010341, 3, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 1, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 2, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 3, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 4, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 5, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 6, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 7, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 8, 116, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 9, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 10, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 11, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 12, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 13, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 14, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121002010342, 15, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 1, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 2, 177, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 3, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 4, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 5, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 6, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 7, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 8, 31, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 9, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 10, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 11, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 12, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 13, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 14, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 15, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 16, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327010343, 17, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 1, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 2, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 3, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 4, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 5, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010344, 6, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 1, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 2, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 3, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 4, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 5, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 6, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 7, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 8, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 9, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 10, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 11, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 12, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 13, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 14, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901010345, 15, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 1, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 2, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 3, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 4, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 5, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 6, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 7, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 8, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 9, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 10, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 11, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070228010346, 12, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 1, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 2, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 3, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 4, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 5, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 6, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 7, 94, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 8, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 9, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818010347, 10, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227010348, 1, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227010348, 2, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227010348, 3, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227010348, 4, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227010348, 5, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 1, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 2, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 3, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 4, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 5, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 6, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 7, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 8, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 9, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 10, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 11, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070122010349, 12, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 1, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 2, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 3, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 4, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 5, 112, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 6, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 7, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 8, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 9, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 10, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 11, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 12, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 13, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 14, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111222010350, 15, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 1, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 2, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 3, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 4, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 5, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 6, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 7, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 8, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010351, 9, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 1, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 2, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 3, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 4, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 5, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812010352, 6, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010353, 1, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010353, 2, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010353, 3, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010353, 4, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010353, 5, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 1, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 2, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 3, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 4, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 5, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 6, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 7, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 8, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 9, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612010354, 10, 8, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 1, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 2, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 3, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 4, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 5, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 6, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 7, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 8, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 9, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 10, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 11, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 12, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 13, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 14, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 15, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 16, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 17, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730010355, 18, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 1, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 2, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 3, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 4, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 5, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 6, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 7, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 8, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 9, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 10, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 11, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070530010356, 12, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320010357, 1, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320010357, 2, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320010357, 3, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010320010357, 4, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 1, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 2, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 3, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 4, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 5, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 6, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 7, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 8, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 9, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070307010358, 10, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 3, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 4, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 5, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 6, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 7, 57, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 8, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 9, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 10, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 11, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 12, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 13, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 14, 98, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 15, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 16, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412010729, 17, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 1, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 2, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 3, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 4, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 5, 40, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 6, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 7, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 8, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 9, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 10, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 11, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 12, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100929010730, 13, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 1, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 2, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 3, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 4, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 5, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 6, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 7, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 8, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 9, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 10, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 11, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 12, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 13, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 14, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 15, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 16, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107010731, 17, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126010732, 1, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126010732, 2, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126010732, 3, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126010732, 4, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126010732, 5, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 1, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 2, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 3, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 4, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 5, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 6, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 7, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 8, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 9, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070218010733, 10, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 1, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 2, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 3, 176, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 4, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 5, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 6, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 7, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205010734, 8, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 1, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 2, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 3, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 4, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 5, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 6, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 7, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 8, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 9, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 10, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 11, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 12, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 13, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 14, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 15, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 16, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 17, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010735, 18, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 1, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 2, 100, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 3, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 4, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 5, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 6, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 7, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 8, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 9, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 10, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 11, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 12, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 13, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 14, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 15, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 16, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 17, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625010736, 18, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 1, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 2, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 3, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 4, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 5, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 6, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 7, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 8, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 9, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 10, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 11, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 12, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 13, 57, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 14, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 15, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 16, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 17, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601010737, 18, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 1, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 2, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 3, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 4, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 5, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 6, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 7, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 8, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 9, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 10, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 11, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 12, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010738, 13, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 1, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 2, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 3, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 4, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 5, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 6, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930010739, 7, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 1, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 2, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 3, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 4, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 5, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 6, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 7, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 8, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 9, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 10, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 11, 175, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 12, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 13, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 14, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 15, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 16, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121216010740, 17, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 1, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 2, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 3, 29, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 4, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 5, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 6, 97, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 7, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122010741, 8, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 1, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 2, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 3, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 4, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 5, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 6, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 7, 148, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 8, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 9, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 10, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 11, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021010742, 12, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 1, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 2, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 3, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 4, 178, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 5, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 6, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 7, 161, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 8, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 9, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 10, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 11, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 12, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010743, 13, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 1, 137, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 2, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 3, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 4, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 5, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 6, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 7, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 8, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 9, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070531010744, 10, 65, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 1, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 2, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 3, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 4, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128010745, 6, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902010746, 1, 145, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902010746, 2, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902010746, 3, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 1, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 2, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 3, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 4, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 5, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 6, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905010747, 7, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 1, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 2, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 3, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 4, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 5, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 6, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 7, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 8, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 9, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 10, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 11, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823010748, 12, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 1, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 2, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 3, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 4, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 5, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 6, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 7, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 8, 166, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 9, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011087, 5, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 1, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 2, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 3, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 4, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 5, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 6, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 7, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 8, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 9, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 10, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 11, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 12, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226011088, 13, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 1, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 2, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 3, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 4, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 5, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 6, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 7, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 8, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 9, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 10, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 11, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011089, 12, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 1, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 2, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 3, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 4, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 5, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 6, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901011090, 7, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711011091, 1, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711011091, 2, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711011091, 3, 57, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711011091, 4, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711011091, 5, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 1, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 2, 100, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 3, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 4, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 5, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 6, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815011092, 7, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 1, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 2, 122, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 3, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 4, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 5, 167, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 6, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 7, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 8, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 9, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050803011093, 10, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 1, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 2, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 3, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 4, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 5, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 6, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 7, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 8, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 9, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 10, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 11, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 12, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 13, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 14, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 15, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 16, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 17, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130117011094, 18, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 1, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 2, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 3, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 4, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 5, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 6, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 7, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 8, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 9, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 10, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 11, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 12, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111011095, 13, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 1, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 2, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 3, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 4, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 5, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026011096, 6, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125011097, 1, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125011097, 2, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125011097, 3, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125011097, 4, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 1, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 2, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 3, 60, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 4, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 5, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 6, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031213011098, 7, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 1, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 2, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 3, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 4, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 5, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 6, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 7, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 8, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 9, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 10, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 11, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 12, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 13, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416011099, 14, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 1, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 2, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 3, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 4, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 5, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 6, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 7, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 8, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 9, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 10, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011100, 11, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505011101, 1, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505011101, 2, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505011101, 3, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505011101, 4, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505011101, 5, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 1, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 2, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 3, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 4, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 5, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 6, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 7, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212011102, 8, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 1, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 2, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 3, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 4, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 5, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 6, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 7, 15, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 8, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 9, 12, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 10, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 11, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 12, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 13, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 14, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011103, 15, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 1, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 2, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 3, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 4, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 5, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217011104, 6, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 1, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 2, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 3, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 4, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 5, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 6, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219011105, 7, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 1, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 2, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 3, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 4, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 5, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 6, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 7, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 8, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 9, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 10, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 11, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 12, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 13, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 14, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 15, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312011106, 16, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 1, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 2, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 3, 79, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 4, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 5, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 6, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 7, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 8, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 9, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 10, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 11, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 12, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 13, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 14, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 15, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 16, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204011107, 17, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 1, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 2, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 3, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 4, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 5, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 6, 63, 60, 13, 780);
commit;
prompt 107000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 7, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 8, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 9, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 10, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 11, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 12, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 13, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 14, 117, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121011108, 15, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 1, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 2, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 3, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 4, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 5, 10, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 6, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 7, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 8, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 9, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 10, 15, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 11, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 12, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010011109, 13, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 1, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 2, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 3, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 4, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 5, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 6, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 7, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 8, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 9, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 12, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216011561, 1, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216011561, 2, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216011561, 3, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021216011561, 4, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 1, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 2, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 3, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 4, 4, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 5, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 6, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 7, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 8, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 9, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 10, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 11, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 12, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207011562, 13, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 1, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 2, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 3, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 4, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 5, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 6, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 7, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 8, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 9, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 10, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 11, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 12, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 13, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100901011563, 14, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 1, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 2, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 3, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 4, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 5, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 6, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 7, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 8, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 9, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011564, 10, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 1, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 2, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 3, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 4, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 5, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 6, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 7, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 8, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 9, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080924011565, 10, 51, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 1, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 2, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 3, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 4, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 5, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 6, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 7, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201011566, 8, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930011567, 1, 148, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930011567, 2, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930011567, 3, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930011567, 4, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930011567, 5, 56, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818011568, 1, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818011568, 2, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818011568, 3, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818011568, 4, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818011568, 5, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 1, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 2, 50, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 3, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 4, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 5, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 6, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 7, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 8, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 9, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 10, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 11, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 12, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 13, 64, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 14, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 15, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 16, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 17, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325011569, 18, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 1, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 2, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 3, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 4, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 5, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 6, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 7, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040125011570, 8, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006011571, 1, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006011571, 2, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006011571, 3, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006011571, 4, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021006011571, 5, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 1, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 2, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 3, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 4, 1, 31, 3, 93);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 5, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 6, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 7, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 8, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 9, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 10, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 11, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 12, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 13, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 14, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 15, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 16, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227011572, 17, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527011573, 1, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527011573, 2, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527011573, 3, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527011573, 4, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 1, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 2, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 3, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 4, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 5, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 6, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 7, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 8, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 9, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503011574, 10, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 1, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 2, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 3, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 4, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 5, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 6, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 7, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119011575, 8, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 1, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 2, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 3, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 4, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 5, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 6, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 7, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 8, 81, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 9, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222011576, 10, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 1, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 2, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 3, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 4, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 5, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 6, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 7, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 8, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 9, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 10, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 11, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090803011577, 12, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 1, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 2, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 3, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 4, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 5, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 6, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 7, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 8, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 9, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 10, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 11, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 12, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 13, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 14, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 15, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 16, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111011578, 17, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 1, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 2, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 3, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 4, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 5, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 6, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 7, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 8, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 9, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 10, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 11, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 12, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 13, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 14, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 15, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 16, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908011579, 17, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011580, 1, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011580, 2, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011580, 3, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011580, 4, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011580, 5, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 1, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 2, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 3, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 4, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 5, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 6, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 7, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 8, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101011581, 9, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 1, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 2, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 3, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 4, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 5, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 6, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 7, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 8, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 9, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 10, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 11, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 12, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 13, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 14, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 15, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709011582, 16, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 1, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 2, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 3, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 4, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 5, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 6, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 7, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 8, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 9, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 10, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 11, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830011583, 12, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 1, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 1, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 2, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 3, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 4, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 5, 33, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 6, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 7, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 8, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 9, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 10, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 11, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 12, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 13, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 14, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 15, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421010359, 16, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014010360, 1, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014010360, 2, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014010360, 3, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021014010360, 4, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 1, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 2, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 3, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 4, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 5, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 6, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 7, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 8, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 9, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 10, 188, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 11, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070206010361, 12, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 1, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 2, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 3, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 4, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 5, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 6, 2, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 7, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 8, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 9, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 10, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 11, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 12, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 13, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010362, 14, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523010363, 1, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523010363, 2, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523010363, 3, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523010363, 4, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523010363, 5, 168, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010364, 1, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010364, 2, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010364, 3, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010364, 4, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010364, 5, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 1, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 2, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 3, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 4, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 5, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 6, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 7, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 8, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 9, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 10, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 11, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 12, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 13, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100630010365, 14, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010366, 1, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010366, 2, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010366, 3, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010366, 4, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 1, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 2, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 3, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 4, 182, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 5, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 6, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 7, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 8, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 9, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 10, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 11, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080503010367, 12, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 1, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 2, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 3, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 4, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 5, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 6, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 7, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 8, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 9, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010368, 10, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 1, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 2, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 3, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 4, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 5, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 6, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910010369, 7, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519010370, 1, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519010370, 2, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519010370, 3, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519010370, 4, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519010370, 5, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 1, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 2, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 3, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 4, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 5, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 6, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 7, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 8, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 9, 78, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 10, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 11, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108010371, 12, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 1, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 2, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 3, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 4, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 5, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 6, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 7, 137, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 8, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 9, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 10, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 11, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010372, 12, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 1, 154, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 2, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 3, 192, 48, 18, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 4, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 5, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 6, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118010373, 7, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 1, 27, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 2, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 3, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 4, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 5, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731010374, 6, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 1, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 2, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 3, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 4, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 5, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 6, 98, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 7, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 8, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 9, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 10, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 11, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010375, 12, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 1, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 2, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 3, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 4, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 5, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 6, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 7, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 8, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 9, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 10, 95, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 11, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307010376, 12, 55, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 1, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 2, 152, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 3, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 4, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 5, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 6, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 7, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 8, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 9, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 10, 122, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 11, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 12, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080701010377, 13, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 1, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 2, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 3, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 4, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 5, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 6, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 7, 147, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061110010378, 8, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221010379, 1, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221010379, 2, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221010379, 3, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207010380, 1, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207010380, 2, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207010380, 3, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 1, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 2, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 3, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 4, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 5, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 6, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 7, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 8, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 9, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 10, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 11, 15, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090612010381, 12, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 1, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 2, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 3, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 4, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 5, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 6, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 7, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 8, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060213010382, 9, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 1, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 2, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 3, 90, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 4, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 5, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 6, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 7, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014010383, 8, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 1, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 2, 185, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 3, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 4, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 5, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 6, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 7, 163, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 8, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 9, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 10, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 11, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 12, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 13, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 14, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 10, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 11, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 12, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 13, 30, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 14, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115010749, 15, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 1, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 2, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 3, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 4, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 5, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 6, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 7, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 8, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 9, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 10, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 11, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 12, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 13, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219010750, 14, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224010751, 1, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224010751, 2, 171, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224010751, 3, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 1, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 2, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 3, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 4, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 5, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 6, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 7, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 8, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060619010752, 9, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 1, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 2, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 3, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 4, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 5, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 6, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 7, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 8, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 9, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 10, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 11, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 12, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618010753, 13, 83, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515010754, 1, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515010754, 2, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515010754, 3, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515010754, 4, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 1, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 2, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 3, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 4, 1, 30, 3, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 5, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031224010755, 6, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 1, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 2, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 3, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 4, 12, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 5, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 6, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 7, 104, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 8, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 9, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 10, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 11, 14, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 12, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 13, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 14, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 15, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416010756, 16, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 1, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 2, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 3, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 4, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 5, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 6, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 7, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 8, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 9, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 10, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 11, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 12, 189, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 13, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 14, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019010757, 15, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 1, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 2, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 3, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 4, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 5, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 6, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 7, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 8, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 9, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 10, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061008010758, 11, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 1, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 2, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 3, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 4, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 5, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 6, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 7, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727010759, 8, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 1, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 2, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 3, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 4, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 5, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 6, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 7, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 8, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 9, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 10, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 11, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 12, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100627010760, 13, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 1, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 2, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 3, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 4, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 5, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 6, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 7, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 8, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 9, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 10, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 11, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 12, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 13, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 14, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 15, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 16, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128010761, 17, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 1, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 2, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 3, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 4, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 5, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 6, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316010762, 7, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 1, 107, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 2, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 3, 150, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 4, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 5, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 6, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 7, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 8, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 9, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 10, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 11, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 12, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411010763, 13, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 1, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 2, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 3, 138, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 4, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 5, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 6, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 7, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 8, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 9, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 10, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 11, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 12, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 13, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 14, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 15, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 16, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 17, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111010764, 18, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 1, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 2, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 3, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 4, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 5, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 6, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 7, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 8, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 9, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 10, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 11, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 12, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 13, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 14, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 15, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 16, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620010765, 17, 111, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 1, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 2, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 3, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 4, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 5, 33, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 6, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031123010766, 7, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020215010767, 1, 44, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020215010767, 2, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020215010767, 3, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020215010767, 4, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020215010767, 5, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 1, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 2, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 3, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 4, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 5, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 6, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 7, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 8, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 9, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 10, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212010768, 11, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 1, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 2, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 3, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 4, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 5, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 6, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 7, 192, 51, 18, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060618010769, 8, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708010770, 1, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708010770, 2, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 1, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 2, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 3, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 4, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 5, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 6, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 7, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 8, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713010771, 9, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 1, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 2, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 3, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 4, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 5, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 6, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 7, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323011110, 10, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 1, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 2, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 3, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 4, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 5, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 6, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 7, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 8, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 9, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613011111, 10, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515011112, 1, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515011112, 2, 183, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515011112, 3, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515011112, 4, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515011112, 5, 6, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 1, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 2, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 3, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 4, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 5, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 6, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 7, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 8, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 9, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 10, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 11, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 12, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 13, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 14, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909011113, 15, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 1, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 2, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 3, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 4, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 5, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 6, 1, 18, 3, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 7, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 8, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 9, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 10, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 11, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 12, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 13, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603011114, 14, 65, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 1, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 2, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 3, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 4, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 5, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 6, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724011115, 7, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 1, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 2, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 3, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 4, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 5, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 6, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 7, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051118011116, 8, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 1, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 2, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 3, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 4, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 5, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 6, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 7, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 8, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 9, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 10, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 11, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 12, 86, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 13, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 14, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 15, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 16, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 17, 155, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140108011117, 18, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 1, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 2, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 3, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 4, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 5, 20, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 6, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 7, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 8, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 9, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 10, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011118, 11, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 1, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 2, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 3, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 4, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 5, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 6, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011119, 7, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 1, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 2, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 3, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 4, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 5, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 6, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 7, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 8, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 9, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 10, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 11, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 12, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 13, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 14, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725011120, 15, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 1, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 2, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 3, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 4, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 5, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 6, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029011121, 7, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 1, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 2, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 3, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 4, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 5, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 6, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 7, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 8, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 9, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 10, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409011122, 11, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313011123, 1, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313011123, 2, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313011123, 3, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313011123, 4, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 1, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 2, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 3, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 4, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 5, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 6, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 7, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 8, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 9, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 10, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 11, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 12, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 13, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100925011124, 14, 28, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005011125, 1, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005011125, 2, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005011125, 3, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 1, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 2, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 3, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 4, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 5, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 6, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 7, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 8, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 9, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 10, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 11, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 12, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 13, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 14, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 15, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 16, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011126, 17, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 1, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 2, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 3, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 4, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 5, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 6, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 7, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 8, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 9, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 10, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 11, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 12, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824011127, 13, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 1, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 2, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 3, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 4, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 5, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 6, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 7, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 8, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 9, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011128, 10, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 1, 157, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 2, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 3, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 4, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 5, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 6, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 7, 15, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 8, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 9, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 10, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 11, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 12, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 13, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 14, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 15, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130309011129, 16, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 1, 171, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 2, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 3, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 4, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 5, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 6, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 7, 55, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 8, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 9, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 10, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 11, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225011130, 12, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 1, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 2, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 3, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 4, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 5, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 6, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 7, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 8, 68, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 9, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 10, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 11, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091130011131, 12, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 1, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 2, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 3, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 4, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 5, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 6, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 7, 64, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 8, 99, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 6, 58, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 7, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 8, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 9, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 10, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 11, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217011467, 12, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 1, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 2, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 3, 171, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 4, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 5, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 6, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 7, 59, 88, 9, 792);
commit;
prompt 108000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708011468, 8, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512011469, 1, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512011469, 2, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512011469, 3, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 1, 157, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 2, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 3, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 4, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 5, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 6, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 7, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 8, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 9, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 10, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 11, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 12, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 13, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 14, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 15, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 16, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328011470, 17, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 1, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 2, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 3, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 4, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 5, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 6, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 7, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 8, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210011471, 9, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011472, 1, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011472, 2, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011472, 3, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011472, 4, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011472, 5, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 1, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 2, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 3, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 4, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 5, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 6, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 7, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 8, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 9, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 10, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 11, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112011473, 12, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 1, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 2, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 3, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 4, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 5, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 6, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 7, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 8, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 9, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 10, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 11, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 12, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 13, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 14, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100220011474, 15, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 1, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 2, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 3, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 4, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 5, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303011475, 6, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 1, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 2, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 3, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 4, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 5, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 6, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 7, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 8, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 9, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 10, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 11, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 12, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 13, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090509011476, 14, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 1, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 2, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 3, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 4, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 5, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 6, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 7, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 8, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 9, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 10, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 11, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 12, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100409011477, 13, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 1, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 2, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 3, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 4, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 5, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 6, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 7, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 8, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 9, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 10, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 11, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 12, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 13, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 14, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 15, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427011478, 16, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 1, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 2, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 3, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 4, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 5, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 6, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 7, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 8, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 9, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116011479, 10, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 1, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 2, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 3, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 4, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 5, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 6, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 7, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 8, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 9, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830011480, 10, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 1, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 2, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 3, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 4, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 5, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 6, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 7, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 8, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 9, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 10, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117011481, 11, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 1, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 2, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 3, 93, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 4, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 5, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 6, 159, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 7, 95, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 8, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 9, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 10, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 11, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 12, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080125011482, 13, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 1, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 2, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 3, 19, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 4, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 5, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 6, 33, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512011483, 7, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 1, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 2, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 3, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 4, 16, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 5, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 6, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 7, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041224011484, 8, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 1, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 2, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 3, 97, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 4, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 5, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 6, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 7, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 8, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 9, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071023011485, 10, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 1, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 2, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 3, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 4, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 5, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 6, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 7, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 8, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 9, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 10, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 11, 153, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011486, 12, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 1, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 2, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 3, 183, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 4, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 5, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 6, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 7, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 8, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 9, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 10, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081110011487, 11, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 1, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 2, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 3, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 4, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 5, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 6, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226011488, 7, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 1, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 2, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 3, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 4, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 5, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 6, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 7, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 8, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 9, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 10, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090807011489, 11, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 1, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 2, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 3, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 4, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102010384, 15, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 1, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 2, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 3, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 4, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 5, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 6, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 7, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 8, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 9, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 10, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 11, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 12, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 13, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 14, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 15, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 16, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 17, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628010385, 18, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 1, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 2, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 3, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 4, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 5, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 6, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 7, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 8, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709010386, 9, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 1, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 2, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 3, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 4, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 5, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 6, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 7, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 8, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 9, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 10, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 11, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 12, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100412010387, 13, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 1, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 2, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 3, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 4, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 5, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 6, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 7, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 8, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 9, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 10, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 11, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 12, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010388, 13, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 1, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 2, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 3, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 4, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 5, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 6, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 7, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010389, 8, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 1, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 2, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 3, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 4, 135, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 5, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 6, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 7, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 8, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 9, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 10, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 11, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103010390, 12, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 1, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 2, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 3, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 4, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 5, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 6, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 7, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 8, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 9, 28, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 10, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 11, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 12, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 13, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 14, 128, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 15, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222010391, 16, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 1, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 2, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 3, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 4, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 5, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 6, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 7, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 8, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 9, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 10, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 11, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 12, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 13, 24, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208010392, 14, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 1, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 2, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 3, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 4, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 5, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918010393, 6, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203010394, 1, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203010394, 2, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203010394, 3, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203010394, 4, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010203010394, 5, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 1, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 2, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 3, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 4, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 5, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 6, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 7, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 8, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 9, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 10, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 11, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 12, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 13, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 14, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010395, 15, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 1, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 2, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 3, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 4, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 5, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 6, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 7, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 8, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 9, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 10, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 11, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 12, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 13, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111221010396, 14, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001205010397, 1, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001205010397, 2, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001205010397, 3, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 1, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 2, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 3, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 4, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 5, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 6, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 7, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 8, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 9, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 10, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080720010398, 11, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 1, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 2, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 3, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 4, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 5, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 6, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 7, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 8, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 9, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 10, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 11, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 12, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 13, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 14, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 15, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140107010399, 16, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 1, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 2, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 3, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 4, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 5, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 6, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 7, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 8, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 9, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 10, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 11, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 12, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913010400, 13, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 1, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 2, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 3, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 4, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 5, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 6, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010401, 7, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 1, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 2, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 3, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 4, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 5, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 6, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 7, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 8, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 9, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 10, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 11, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817010402, 12, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 1, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 2, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 3, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 4, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 5, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 6, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 7, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 8, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 9, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814010403, 10, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 1, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 2, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 3, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 4, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 5, 182, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 6, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 7, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 8, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 9, 156, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 10, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 11, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 12, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 13, 166, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 14, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 15, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130313010404, 16, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 1, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 2, 179, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 3, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 4, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 5, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 6, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 7, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 8, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 9, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 10, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 11, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 12, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 13, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 14, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 15, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610010772, 16, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 1, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 2, 162, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 3, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 4, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 5, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 6, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 7, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 8, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 9, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 10, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 11, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 12, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 13, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507010773, 14, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620010774, 1, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620010774, 2, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620010774, 3, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620010774, 4, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620010774, 5, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717010775, 1, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717010775, 2, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717010775, 3, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717010775, 4, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717010775, 5, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 1, 123, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 2, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 3, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 4, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 5, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 6, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 7, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 8, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 9, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 10, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 11, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 12, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 13, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 14, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 15, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112010776, 16, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 1, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 2, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 3, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 4, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 5, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 6, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 7, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 8, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 9, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 10, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 11, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 12, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 13, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 14, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 15, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 16, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 17, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130427010777, 18, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 1, 147, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 2, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 3, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 4, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 5, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 6, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 7, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010778, 8, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 1, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 2, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 3, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 4, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 5, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919010779, 6, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 1, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 2, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 3, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 4, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 5, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 6, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 7, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 8, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 9, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 10, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 11, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 12, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 13, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 14, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 15, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527010780, 16, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 1, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 2, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 3, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 4, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 5, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 6, 157, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 7, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 8, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 9, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 10, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 11, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 12, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 13, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 14, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 15, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010781, 16, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 1, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 2, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 3, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 4, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 5, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 6, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 7, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 8, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 9, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010782, 10, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 1, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 2, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 3, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 4, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 5, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 6, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 7, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 8, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 9, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 10, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 11, 100, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 12, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 13, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 14, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 15, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825010783, 16, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 1, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 2, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 3, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 4, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 5, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 6, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 7, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 8, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 9, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 10, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 11, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226010784, 12, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128010785, 1, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128010785, 2, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128010785, 3, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128010785, 4, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010128010785, 5, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 1, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 2, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 3, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 4, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 5, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 6, 59, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041111010786, 7, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804010787, 1, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804010787, 2, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804010787, 3, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000804010787, 4, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 1, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 2, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 3, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 4, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 5, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 6, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 7, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029010788, 8, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 1, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 2, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 3, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 4, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 5, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 6, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 7, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 8, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 9, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 10, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 11, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 12, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 13, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 14, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121015010789, 15, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 1, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 2, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 3, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 4, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 5, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 6, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 7, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 8, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 9, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329010790, 10, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 1, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 2, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 3, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 4, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 5, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 6, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 7, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 8, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 9, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 10, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 11, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821010791, 12, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 1, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 2, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 3, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 4, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 5, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 6, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 7, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 8, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 9, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 10, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 11, 56, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 12, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080417010792, 13, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 1, 186, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 2, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 3, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 4, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 5, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 6, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 7, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 8, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 9, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127010793, 10, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 1, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 2, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 3, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 4, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 9, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 10, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070119011132, 11, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 1, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 2, 88, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 3, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 4, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 5, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 6, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050726011133, 7, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111011134, 1, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111011134, 2, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111011134, 3, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111011134, 4, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 1, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 2, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 3, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 4, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 5, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 6, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 7, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011135, 8, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 1, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 2, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 3, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 4, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 5, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 6, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 7, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 8, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830011136, 9, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 1, 47, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 2, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 3, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 4, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 5, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 6, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 7, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 8, 119, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 9, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 10, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 11, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011137, 12, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 1, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 2, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 3, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 4, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 5, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 6, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 7, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 8, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 9, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 10, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 11, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 12, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 13, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011138, 14, 8, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 1, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 2, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 3, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 4, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 5, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 6, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 7, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 8, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 9, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 10, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 11, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 12, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 13, 44, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 14, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 15, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107011139, 16, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129011140, 1, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129011140, 2, 115, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129011140, 3, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129011140, 4, 170, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129011140, 5, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 1, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 2, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 3, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 4, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 5, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 6, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 7, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 8, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 9, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 10, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 11, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 12, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 13, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 14, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 15, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 16, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805011141, 17, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 1, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 2, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 3, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 4, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 5, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804011142, 6, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430011143, 1, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430011143, 2, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000430011143, 3, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 1, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 2, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 3, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 4, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 5, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 6, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 7, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 8, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 9, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 10, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 11, 136, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215011144, 12, 134, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 1, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 2, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 3, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 4, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 5, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 6, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 7, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 8, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 9, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 10, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 11, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 12, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 13, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011145, 14, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 1, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 2, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 3, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 4, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 5, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 6, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 7, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 8, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 9, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 10, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913011146, 11, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 1, 112, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 2, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 3, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 4, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 5, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 6, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 7, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 8, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 9, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 10, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 11, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 12, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 13, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 14, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 15, 17, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 16, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120223011147, 17, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 1, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 2, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 3, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 4, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 5, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 6, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 7, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 8, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 9, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 10, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 11, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 12, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714011148, 13, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 1, 17, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 2, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 3, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 4, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 5, 133, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 6, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 7, 76, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624011149, 8, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 1, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 2, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 3, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 4, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 5, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 6, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 7, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050624011150, 8, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 1, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 2, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 3, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 4, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 5, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 6, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 7, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 8, 44, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 9, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 10, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 11, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 12, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 13, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 14, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011151, 15, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 1, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 2, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 3, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 4, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 5, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 6, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 7, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 8, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 9, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 10, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 11, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405011152, 12, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 1, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 2, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 3, 112, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 4, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 5, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 6, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 7, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 8, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 9, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 10, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 11, 167, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 12, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722011153, 13, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 1, 53, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 2, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 3, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 4, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 5, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 6, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 7, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 8, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 9, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 10, 116, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060506011154, 11, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921011155, 1, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 11, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 12, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 13, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 1, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 2, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 3, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 4, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 5, 177, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 6, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 7, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 8, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 9, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 10, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 11, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505011513, 12, 104, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 1, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 2, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 3, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 4, 52, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 5, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 6, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020315011514, 7, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 1, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 2, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 3, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 4, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 5, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 6, 53, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 7, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 8, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 9, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 10, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 11, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 12, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 13, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011515, 14, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 1, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 2, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 3, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 4, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 5, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 6, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123011516, 7, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 1, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 2, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 3, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 4, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 5, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 6, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 7, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 8, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 9, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 10, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 11, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 12, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 13, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 14, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 15, 107, 31, 9, 279);
commit;
prompt 109000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110610011517, 16, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 1, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 2, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 3, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 4, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 5, 103, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 6, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220011518, 7, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203011519, 1, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203011519, 2, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203011519, 3, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 1, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 2, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 3, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 4, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 5, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 6, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331011520, 7, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 1, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 2, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 3, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 4, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 5, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 6, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 7, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 8, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 9, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 10, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090306011521, 11, 59, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 1, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 2, 119, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 3, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 4, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 5, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 6, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 7, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 8, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627011522, 9, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 1, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 2, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 3, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 4, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 5, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 6, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811011523, 7, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 1, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 2, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 3, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 4, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 5, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 6, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 7, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 8, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 9, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 10, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 11, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 12, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129011524, 13, 158, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 1, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 2, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 3, 129, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 4, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 5, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 6, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 7, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413011525, 8, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 1, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 2, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 3, 67, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 4, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 5, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010312011526, 6, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 1, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 2, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 3, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 4, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 5, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 6, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 7, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 8, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 9, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 10, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 11, 192, 12, 18, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090203011527, 12, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 1, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 2, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 3, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 4, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 5, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 6, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 7, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 8, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 9, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 10, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 11, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 12, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 13, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 14, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011528, 15, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 1, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 2, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 3, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 4, 71, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 5, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 6, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 7, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425011529, 8, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 1, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 2, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 3, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 4, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 5, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 6, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 7, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 8, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 9, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104011530, 10, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 1, 89, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 2, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 3, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 4, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 5, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 6, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 7, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 8, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 9, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 10, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 11, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 12, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 13, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100117011531, 14, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 1, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 2, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 3, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 4, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 5, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 6, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 7, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040611011532, 8, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330011533, 1, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330011533, 2, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330011533, 3, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330011533, 4, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000330011533, 5, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 1, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 2, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 3, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 4, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 5, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 6, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 7, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 8, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 9, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 10, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 11, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 12, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319011534, 13, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 1, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 2, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 3, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 4, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 5, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 6, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 7, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 8, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 9, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 10, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 11, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022011535, 12, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 1, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 2, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 3, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 4, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 5, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 6, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 7, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 8, 1, 21, 3, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 9, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 10, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 11, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100501011536, 12, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 8, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 9, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 10, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 11, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 12, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 13, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010405, 14, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 1, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 2, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 3, 172, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 4, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 5, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 6, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 7, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 8, 43, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 9, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 10, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 11, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 12, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 13, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 14, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 15, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 16, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219010406, 17, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 1, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 2, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 3, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 4, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 5, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 6, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 7, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 8, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 9, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 10, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 11, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090720010407, 12, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 1, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 2, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 3, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 4, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 5, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031014010408, 6, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 1, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 2, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 3, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 4, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 5, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 6, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 7, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 8, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 9, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 10, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 11, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 12, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 13, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 14, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204010409, 15, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 1, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 2, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 3, 85, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 4, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 5, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 6, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 7, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 8, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 9, 11, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 10, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 11, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713010410, 12, 95, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 1, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 2, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 3, 80, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 4, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 5, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 6, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 7, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 8, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 9, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 10, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 11, 180, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 12, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 13, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 14, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 15, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 16, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401010411, 17, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 1, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 2, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 3, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 4, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 5, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 6, 146, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 7, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 8, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 9, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 10, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 11, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 12, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 13, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 14, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010412, 15, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 1, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 2, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 3, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 4, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 5, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 6, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 7, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 8, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 9, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028010413, 10, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 1, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 2, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 3, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 4, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 5, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 6, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 7, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 8, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 9, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 10, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 11, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 12, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 13, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 14, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120726010414, 15, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 1, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 2, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 3, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 4, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 5, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 6, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 7, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 8, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 9, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 10, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 11, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010415, 12, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 1, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 2, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 3, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 4, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 5, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 6, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 7, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 8, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 9, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 10, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 11, 182, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 12, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713010416, 13, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 1, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 2, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 3, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 4, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 5, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 6, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 7, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 8, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 9, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 10, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 11, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903010417, 12, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519010418, 1, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519010418, 2, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519010418, 3, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020519010418, 4, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 1, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 2, 75, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 3, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 4, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 5, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 6, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 7, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 8, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 9, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 10, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 11, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517010419, 12, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 1, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 2, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 3, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 4, 84, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 5, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 6, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 7, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 8, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 9, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 10, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 11, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 12, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 13, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 14, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 15, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 16, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 17, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130105010420, 18, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 1, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 2, 139, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 3, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 4, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 5, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 6, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 7, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 8, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 9, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 10, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 11, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 12, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 13, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110314010421, 14, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 1, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 2, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 3, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 4, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 5, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 6, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029010422, 7, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 1, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 2, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 3, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 4, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 5, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 6, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 7, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 8, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 9, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 10, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 11, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 12, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620010423, 13, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 1, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 2, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 3, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 4, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 5, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617010424, 6, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 1, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 2, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 5, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 6, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 7, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 8, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 9, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 10, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090930010794, 11, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218010795, 1, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218010795, 2, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218010795, 3, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218010795, 4, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 1, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 2, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 3, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 4, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 5, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 6, 183, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 7, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118010796, 8, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 1, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 2, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 3, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 4, 67, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 5, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 6, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710010797, 7, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 1, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 2, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 3, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 4, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 5, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 6, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 7, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041030010798, 8, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 1, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 2, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 3, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 4, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 5, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 6, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 7, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 8, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 9, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 10, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 11, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 12, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 13, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 14, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310010799, 15, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 1, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 2, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 3, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 4, 110, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 5, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612010800, 6, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 1, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 2, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 3, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 4, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 5, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 6, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625010801, 7, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 1, 123, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 2, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 3, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 4, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 5, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 6, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040228010802, 7, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 1, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 2, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 3, 166, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 4, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 5, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 6, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 7, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 8, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 9, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 10, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 11, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516010803, 12, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 1, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 2, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 3, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 4, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 5, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 6, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 7, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 8, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 9, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070506010804, 10, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 1, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 2, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 3, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 4, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 5, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 6, 97, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 7, 119, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 8, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 9, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 10, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 11, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 12, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010805, 13, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028010806, 1, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028010806, 2, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028010806, 3, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028010806, 4, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 1, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 2, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 3, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 4, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 5, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 6, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 7, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 8, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 9, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614010807, 10, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820010808, 1, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820010808, 2, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820010808, 3, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 1, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 2, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 3, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 4, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 5, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 6, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 7, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 8, 46, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 9, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 10, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 11, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 12, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 13, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 14, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010809, 15, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 1, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 2, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 3, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 4, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 5, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 6, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 7, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 8, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 9, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 10, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 11, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 12, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 13, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207010810, 14, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 1, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 2, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 3, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 4, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 5, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 6, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 7, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 8, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 9, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 10, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 11, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 12, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 13, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 14, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 15, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 16, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 17, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010811, 18, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916010812, 1, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916010812, 2, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 1, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 2, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 3, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 4, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 5, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 6, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 7, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 8, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 9, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 10, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 11, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 12, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802010813, 13, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 1, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 2, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 3, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 4, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 5, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 6, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 7, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 8, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 9, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 10, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 11, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 12, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 13, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 14, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 15, 117, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911010814, 16, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 1, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 2, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 3, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 4, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 5, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 6, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 7, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 8, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 9, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 10, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926010815, 11, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 1, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 2, 187, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 3, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 4, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 5, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 6, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 7, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 8, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 9, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 10, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 11, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 12, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010816, 13, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 1, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 2, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 3, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 4, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 5, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 6, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 7, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 8, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 9, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 10, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 11, 124, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 12, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 13, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 14, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 15, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110406010817, 16, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921011155, 2, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000921011155, 3, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 1, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 2, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 3, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 4, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 5, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 6, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 7, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 8, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 9, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 10, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 11, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 12, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011156, 13, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 1, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 2, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 3, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 4, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 5, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 6, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 7, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 8, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 9, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 10, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 11, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 12, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 13, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 14, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210011157, 15, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 1, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 2, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 3, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 5, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 6, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 7, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 8, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 9, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 10, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 11, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 12, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 13, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 14, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 15, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 16, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207011158, 17, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 1, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 2, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 3, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 4, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 5, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 6, 82, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 7, 29, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 8, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 9, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 10, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 11, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 12, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 13, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 14, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 15, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130926011159, 16, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 1, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 2, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 3, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 4, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 5, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 6, 1, 63, 3, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710011160, 7, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 1, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 2, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 3, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 4, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 5, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 6, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 7, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 8, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 9, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 10, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 11, 47, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 12, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 13, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 14, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320011161, 15, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 1, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 2, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 3, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 4, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 5, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 6, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 7, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 8, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 9, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 10, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 11, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 12, 192, 16, 18, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 13, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 14, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 15, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 16, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 17, 10, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011162, 18, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526011163, 1, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526011163, 2, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526011163, 3, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 1, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 2, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 3, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 4, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 5, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 6, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 7, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 8, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 9, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 10, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 11, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 12, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 13, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211011164, 14, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 1, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 2, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 3, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 4, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 5, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 6, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 7, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 8, 170, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 9, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 10, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 11, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 12, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 13, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 14, 1, 75, 3, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 15, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 16, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308011165, 17, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 1, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 2, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 3, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 4, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 5, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 6, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 7, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 8, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 9, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 10, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 11, 120, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 12, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502011166, 13, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 1, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 2, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 3, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 4, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 5, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712011167, 6, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 1, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 2, 73, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 3, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 4, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 5, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602011168, 6, 21, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 1, 146, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 2, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 3, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 4, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 5, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 6, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 7, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 8, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 9, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 10, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 11, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 12, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 13, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504011169, 14, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 1, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 2, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 3, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 4, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 5, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 6, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301011170, 7, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 1, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 2, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 3, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 4, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 5, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 6, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 7, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 8, 167, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 9, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 10, 25, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 11, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 12, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 13, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 14, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020011171, 15, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 1, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 2, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 3, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 4, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 5, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 6, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 7, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 8, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 9, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 10, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 11, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 12, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 13, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100415011172, 14, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907011173, 1, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907011173, 2, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907011173, 3, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 1, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 2, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 3, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 4, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 5, 137, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 6, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 7, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 8, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 9, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 10, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 11, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 12, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 13, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105011174, 14, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 1, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 2, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 3, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 4, 160, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 5, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 6, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 7, 177, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 8, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120011175, 9, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 1, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 2, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 3, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 4, 91, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 5, 1, 71, 3, 213);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 6, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 7, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 8, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 9, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 10, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 11, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 12, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 13, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111011584, 14, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 1, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 2, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 3, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 4, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 5, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 6, 1, 44, 3, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 7, 174, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 8, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 9, 15, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 10, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 11, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 12, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 13, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 14, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 15, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 16, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115011585, 17, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 1, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 2, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 3, 103, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 4, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 5, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113011586, 6, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 1, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 2, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 3, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 4, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 5, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 6, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 7, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 8, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 9, 192, 20, 18, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 10, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 11, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 12, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310011587, 13, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 1, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 2, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 3, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 4, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 5, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 6, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230011588, 7, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 1, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 2, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 3, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 4, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 5, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 6, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 7, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 8, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011589, 9, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725011590, 1, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725011590, 2, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725011590, 3, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725011590, 4, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725011590, 5, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 1, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 2, 107, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 3, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 4, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 5, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 6, 123, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 7, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 8, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 9, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 10, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 11, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 12, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 13, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218011591, 14, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 1, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 2, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 3, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 4, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 5, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 6, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 7, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 8, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 9, 76, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014011592, 10, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825011593, 1, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825011593, 2, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825011593, 3, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 1, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 2, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 3, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 4, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 5, 146, 44, 10, 440);
commit;
prompt 110000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 6, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020403011594, 7, 138, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 1, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 2, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 3, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 4, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 5, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001011595, 6, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324011596, 1, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324011596, 2, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324011596, 3, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324011596, 4, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324011596, 5, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 1, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 2, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 3, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 4, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 5, 125, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 6, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 7, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203011597, 8, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207011598, 1, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207011598, 2, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207011598, 3, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207011598, 4, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 1, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 2, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 3, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 4, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 5, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 6, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 7, 14, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 8, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 9, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080528011599, 10, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 1, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 2, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 3, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 4, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 5, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 6, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 7, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 8, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 9, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 10, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 11, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 12, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 13, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 14, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508011600, 15, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513011601, 1, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513011601, 2, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513011601, 3, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513011601, 4, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020513011601, 5, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 1, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 2, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 3, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 4, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 5, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 6, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 7, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 8, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 9, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 10, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 11, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102011602, 12, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 1, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 2, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 3, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 4, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 5, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 6, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 7, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 8, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 9, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 10, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 11, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111011603, 12, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 1, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 2, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 3, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 4, 154, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 5, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630011604, 6, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 1, 45, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 2, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 3, 179, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 4, 168, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 5, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 6, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 7, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 8, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 9, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 10, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 11, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 12, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 13, 153, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 14, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424011605, 15, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 1, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 2, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 3, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 4, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 5, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306011606, 6, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 1, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 2, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 3, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 4, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 5, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 6, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 7, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 8, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 9, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820011607, 10, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 1, 3, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 2, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 3, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 4, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 5, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218011608, 6, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 1, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 2, 71, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 3, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 4, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 5, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 6, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 7, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 8, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 9, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 10, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129011609, 11, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 1, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 2, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 3, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 4, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 3, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 4, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 5, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 6, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119010425, 7, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 1, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 2, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 3, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 4, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 5, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031121010426, 6, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 1, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 2, 177, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 3, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 4, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 5, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 6, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 7, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 8, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 9, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 10, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 11, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 12, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 13, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 14, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 15, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214010427, 16, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 1, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 2, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 3, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 4, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 5, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 6, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 7, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 8, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 9, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 10, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 11, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 12, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 13, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 14, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 15, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703010428, 16, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 1, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 2, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 3, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 4, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 5, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 6, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 7, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 8, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 9, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 10, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 11, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 12, 181, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 13, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 14, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 15, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226010429, 16, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 1, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 2, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 3, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 4, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 5, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 6, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 7, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 8, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 9, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 10, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 11, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 12, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 13, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 14, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010430, 15, 79, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 1, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 2, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 3, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 4, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 5, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 6, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326010431, 7, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 1, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 2, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 3, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 4, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 5, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 6, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 7, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 8, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 9, 177, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 10, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 11, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 12, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 13, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 14, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120614010432, 15, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 1, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 2, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 3, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 4, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 5, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818010433, 6, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 1, 27, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 2, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 3, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 4, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 5, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 6, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 7, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 8, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 9, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 10, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 11, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 12, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 13, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713010434, 14, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 1, 183, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 2, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 3, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 4, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 5, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 6, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531010435, 7, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 1, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 2, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 3, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 4, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 5, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 6, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 7, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 8, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 9, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 10, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 11, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 12, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 13, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 14, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 15, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928010436, 16, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 1, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 2, 150, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 3, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 4, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 5, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 6, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 7, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 8, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 9, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328010437, 10, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 1, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 2, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 3, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 4, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 5, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111010438, 6, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 1, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 2, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 3, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 4, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 5, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 6, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 7, 134, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 8, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 9, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 10, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 11, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 12, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 13, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 14, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121228010439, 15, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 1, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 2, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 3, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 4, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 5, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 6, 112, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 7, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 8, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041215010440, 9, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 1, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 2, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 3, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 4, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 5, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 6, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 7, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 8, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 9, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 10, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 11, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 12, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 13, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308010441, 14, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624010442, 1, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624010442, 2, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624010442, 3, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010624010442, 4, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010443, 1, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010443, 2, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621010443, 3, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 1, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 2, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 3, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 4, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 5, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 6, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121010444, 7, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 1, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 2, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 3, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 4, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 5, 59, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 6, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408010445, 7, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 1, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 2, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 3, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 4, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 5, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 6, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 7, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519010446, 8, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 1, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 2, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 3, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 4, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 5, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 6, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 7, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 8, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 9, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 10, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 11, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 12, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 13, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100216010447, 14, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 1, 121, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 2, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 3, 57, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 1, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 2, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 3, 17, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 4, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 5, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703010818, 6, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 1, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 2, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 3, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 4, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 5, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 6, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 7, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 8, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 9, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 10, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 11, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 12, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 13, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 14, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120405010819, 15, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 1, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 2, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 3, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 4, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 5, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 6, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 7, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 8, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 9, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 10, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 11, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 12, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 13, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120510010820, 14, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 1, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 2, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 3, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 4, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 5, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 6, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 7, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 8, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060329010821, 9, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 1, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 2, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 3, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 4, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 5, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 6, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 7, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 8, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 9, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 10, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 11, 85, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 12, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091023010822, 13, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 1, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 2, 166, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 3, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 4, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 5, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 6, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 7, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 8, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 9, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010823, 10, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 1, 89, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 2, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 3, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 4, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 5, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 6, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 7, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 8, 10, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 9, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 10, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 11, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 12, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 13, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 14, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109010824, 15, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530010825, 1, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530010825, 2, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530010825, 3, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530010825, 4, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 1, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 2, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 3, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 4, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 5, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 6, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 7, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 8, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051207010826, 9, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722010827, 1, 4, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722010827, 2, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722010827, 3, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 1, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 2, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 3, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 4, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 5, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 6, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 7, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 8, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 9, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 10, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 11, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119010828, 12, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 1, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 2, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 3, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 4, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 5, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 6, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 7, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 8, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 9, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 10, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 11, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 12, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 13, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010829, 14, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 1, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 2, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 3, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 4, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 5, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 6, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 7, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 8, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515010830, 9, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 1, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 2, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 3, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 4, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 5, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 6, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807010831, 7, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 1, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 2, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 3, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 4, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 5, 61, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 6, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009010832, 7, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 1, 21, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 2, 144, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 3, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 4, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 5, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 6, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 7, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 8, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 9, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 10, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 11, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 12, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 13, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114010833, 14, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 1, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 2, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 3, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 4, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 5, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 6, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 7, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 8, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 9, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050204010834, 10, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 1, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 2, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 3, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 4, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 5, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 6, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 7, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 8, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 9, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 10, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 11, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 12, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 13, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101227010835, 14, 17, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420010836, 1, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420010836, 2, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420010836, 3, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420010836, 4, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420010836, 5, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 1, 177, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 2, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 3, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 4, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 5, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 6, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 7, 85, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 8, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 9, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 10, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 11, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 12, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 13, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 14, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 15, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504010837, 16, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 1, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 2, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 3, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 4, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 5, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 6, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 7, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 8, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 9, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 10, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080312010838, 11, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101010839, 1, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101010839, 2, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101010839, 3, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101010839, 4, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 1, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 2, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 3, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 4, 89, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 5, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 6, 1, 95, 3, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 7, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 8, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 9, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 10, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 11, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 12, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 13, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 14, 104, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 15, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 16, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 17, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 18, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 2, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 3, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 4, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 5, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 6, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 7, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 8, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 9, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 10, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 11, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081217011176, 12, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201011177, 1, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201011177, 2, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201011177, 3, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201011177, 4, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001201011177, 5, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114011178, 1, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114011178, 2, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114011178, 3, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411011179, 1, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411011179, 2, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411011179, 3, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411011179, 4, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411011179, 5, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011180, 1, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011180, 2, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011180, 3, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011180, 4, 4, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 1, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 2, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 3, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 4, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 5, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 6, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 7, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 8, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 9, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 10, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116011181, 11, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 1, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 2, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 3, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 4, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 5, 55, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030105011182, 6, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 1, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 2, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 3, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 4, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 5, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 6, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 7, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 8, 3, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713011183, 9, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 1, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 2, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 3, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 4, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 5, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 6, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 7, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 8, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 9, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 10, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 11, 140, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 12, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 13, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 14, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 15, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906011184, 16, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729011185, 1, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729011185, 2, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729011185, 3, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729011185, 4, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729011185, 5, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 1, 73, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 2, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 3, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 4, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 5, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 6, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 7, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 8, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 9, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 10, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 11, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 12, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 13, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110222011186, 14, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119011187, 1, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119011187, 2, 98, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119011187, 3, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119011187, 4, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119011187, 5, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 1, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 2, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 3, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 4, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 5, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 6, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 7, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060111011188, 8, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 1, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 2, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 3, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 4, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 5, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 6, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 7, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 8, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 9, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 10, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060807011189, 11, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 1, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 2, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 3, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 4, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 5, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 6, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 7, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 8, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 9, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312011190, 10, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 1, 151, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 2, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 3, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 4, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 5, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 6, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 7, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051127011191, 8, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 1, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 2, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 3, 156, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 4, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 5, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 6, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 7, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 8, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 9, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112011192, 10, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011193, 1, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011193, 2, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011193, 3, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011193, 4, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027011193, 5, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123011194, 1, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123011194, 2, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123011194, 3, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 1, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 2, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 3, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 4, 136, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 5, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 6, 65, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 7, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 8, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 9, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 10, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826011195, 11, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 1, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 2, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 3, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 4, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 5, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 6, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 7, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 8, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 9, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124011196, 10, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 1, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 2, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 3, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 4, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 5, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 6, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 7, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 8, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 9, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 10, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 11, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910011197, 12, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 1, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 2, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 3, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 4, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 5, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 6, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 7, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 8, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 9, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216011198, 10, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 1, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 2, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 3, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 4, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 5, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 6, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 7, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 8, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 9, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 10, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 11, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 12, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611011199, 13, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102011200, 1, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102011200, 2, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102011200, 3, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102011200, 4, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010102011200, 5, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 1, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 2, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 3, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 4, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 5, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 6, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 7, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 8, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212011201, 9, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 1, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 2, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 3, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 4, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 5, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 6, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 7, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 8, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 9, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 10, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 11, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 12, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 13, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 14, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 15, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 16, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118011202, 17, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 1, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 2, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 3, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 5, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 6, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 7, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 8, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 9, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 10, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 11, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 12, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 13, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011490, 14, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 1, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 2, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 3, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 4, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 5, 47, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 6, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 7, 60, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 8, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 9, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 10, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 11, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 12, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090709011491, 13, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 1, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 2, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 3, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 4, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 5, 97, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 6, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 7, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 8, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060629011492, 9, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928011493, 1, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928011493, 2, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928011493, 3, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928011493, 4, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 1, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 2, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 3, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 4, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 5, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 6, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 7, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 8, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516011494, 9, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 1, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 2, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 3, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 4, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 5, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 6, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 7, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 8, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 9, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 10, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011495, 11, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 1, 44, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 2, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 3, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 4, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 5, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 6, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912011496, 7, 61, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 1, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 2, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 3, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 4, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 5, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019011497, 6, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 1, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 2, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 3, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 4, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 5, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 6, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 7, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 8, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 9, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 10, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 11, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921011498, 12, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 1, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 2, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 3, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 4, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 5, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 6, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 7, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 8, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 9, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 10, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 11, 63, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 12, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 13, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 14, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 15, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 16, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318011499, 17, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 1, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 2, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 3, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 4, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 5, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 6, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 7, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 8, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 9, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 10, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 11, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 12, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112011500, 13, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 1, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 2, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 3, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 4, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 5, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 6, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 7, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 8, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 9, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 10, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 11, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 12, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 13, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811011501, 14, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 1, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 2, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 3, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 4, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 5, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 6, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528011502, 7, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 1, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 2, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 3, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 4, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 5, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 6, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 7, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 8, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 9, 20, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070812011503, 10, 79, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 1, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 2, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 3, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 4, 143, 26, 14, 364);
commit;
prompt 111000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 5, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 6, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 7, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321011504, 8, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 1, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 2, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 3, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 4, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 5, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207011505, 6, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 1, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 2, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 3, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 4, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 5, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 6, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 7, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 8, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050421011506, 9, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 1, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 2, 96, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 3, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 4, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 5, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 6, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 7, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 8, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 9, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 10, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015011507, 11, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 1, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 2, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 3, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 4, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 5, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 6, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 7, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 8, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 9, 61, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 10, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 11, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 12, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 13, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 14, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 15, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 16, 51, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722011508, 17, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 1, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 2, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 3, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 4, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 5, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 6, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 7, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 8, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 9, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 10, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 11, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 12, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 13, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 14, 89, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 15, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703011509, 16, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 1, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 2, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 3, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 4, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 5, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 6, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011510, 7, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 1, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 2, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 3, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 4, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 5, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 6, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 7, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 8, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 9, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 10, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 11, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 12, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107011511, 13, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 1, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 2, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 3, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 4, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 5, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 6, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 7, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 8, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 9, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103011512, 10, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 4, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 5, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 6, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 7, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 8, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523010448, 9, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 1, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 2, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 3, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 4, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 5, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 6, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 7, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 8, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 9, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010449, 10, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 1, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 2, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 3, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 4, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 5, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 6, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 7, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 8, 108, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128010450, 9, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 1, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 2, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 3, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 4, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 5, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 6, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 7, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205010451, 8, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 1, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 2, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 3, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 4, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 5, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 6, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 7, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 8, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 9, 48, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 10, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070106010452, 11, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 1, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 2, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 3, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 4, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 5, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 6, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 7, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 8, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 9, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 10, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 11, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 12, 32, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090508010453, 13, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620010454, 1, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620010454, 2, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000620010454, 3, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010455, 1, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010455, 2, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010455, 3, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010455, 4, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209010456, 1, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209010456, 2, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209010456, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021209010456, 4, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106010457, 1, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106010457, 2, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106010457, 3, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106010457, 4, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 1, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 2, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 3, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 4, 122, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 5, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 6, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 7, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 8, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071022010458, 9, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 1, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 2, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 3, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 4, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 5, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 6, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 7, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 8, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 9, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 10, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621010459, 11, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 1, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 2, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 3, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 4, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 5, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 6, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 7, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 8, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 9, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130010460, 10, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 1, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 2, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 3, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 4, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 5, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 6, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 7, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 8, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 9, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 10, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226010461, 11, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 1, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 2, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 3, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 4, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 5, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 6, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 7, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 8, 24, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406010462, 9, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 1, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 2, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 3, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 4, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 5, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 6, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 7, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 8, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 9, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 10, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 11, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125010463, 12, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 1, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 2, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 3, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 4, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 5, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010464, 6, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 1, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 2, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 3, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 4, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 5, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 6, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 7, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 8, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 9, 116, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 10, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117010465, 11, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 1, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 2, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 3, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 4, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 5, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 6, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 7, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 8, 56, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 9, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 10, 40, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 11, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 12, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 13, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 14, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 15, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 16, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403010466, 17, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 1, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 2, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 3, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 4, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 5, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 6, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 7, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 8, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 9, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 10, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 11, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 12, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010467, 13, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521010468, 1, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521010468, 2, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521010468, 3, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521010468, 4, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521010468, 5, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 1, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 2, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 3, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 4, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 5, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 6, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 7, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 8, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106010469, 9, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 1, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 2, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 3, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 4, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 5, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 6, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 7, 118, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 8, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 9, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 10, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804010470, 11, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 1, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 2, 144, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 3, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 4, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 5, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 6, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 7, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 8, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 9, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 10, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 11, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 12, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 13, 51, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 14, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 15, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218010471, 16, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 1, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 2, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 3, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 4, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 5, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 6, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 7, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 8, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 9, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 10, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 11, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825010472, 12, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 1, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 2, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 3, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 4, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 5, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140507010840, 19, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 1, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 2, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 3, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 4, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 5, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 6, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 7, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 8, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 9, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 10, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 11, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 12, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120010841, 13, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 1, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 2, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 3, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 4, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 5, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 6, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 7, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119010842, 8, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 1, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 2, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 3, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 4, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 5, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 6, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 7, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 8, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630010843, 9, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 1, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 2, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 3, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 4, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 5, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 6, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 7, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 8, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 9, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 10, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 11, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 12, 143, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 13, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 14, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 15, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111030010844, 16, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 1, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 2, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 3, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 4, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 5, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 6, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 7, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 8, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 9, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 10, 66, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 11, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 12, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 13, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010845, 14, 187, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 1, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 2, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 3, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 4, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 5, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 6, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 7, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 8, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 9, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 10, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 11, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010846, 12, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 1, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 2, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 3, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 4, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 5, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 6, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 7, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 8, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 9, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 10, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 11, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 12, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214010847, 13, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 1, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 2, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 3, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 4, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 5, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 6, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 7, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 8, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 9, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 10, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 11, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 12, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 13, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415010848, 14, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 1, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 2, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 3, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 4, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 5, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 6, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 7, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 8, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 9, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 10, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 11, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 12, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 13, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 14, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 15, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213010849, 16, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 1, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 2, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 3, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 4, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 5, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 6, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 7, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 8, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010850, 9, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 1, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 2, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 3, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 4, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 5, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 6, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 7, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 8, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 9, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 10, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 11, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 12, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 13, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 14, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 15, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 16, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209010851, 17, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219010852, 1, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219010852, 2, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219010852, 3, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219010852, 4, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 1, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 2, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 3, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 4, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 5, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 6, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 7, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 8, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 9, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 10, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 11, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 12, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 13, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 14, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 15, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 16, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303010853, 17, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809010854, 1, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809010854, 2, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809010854, 3, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809010854, 4, 99, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010809010854, 5, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 1, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 2, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 3, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 4, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 5, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 6, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 7, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 8, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 9, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 10, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 11, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 12, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 13, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 14, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110704010855, 15, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 1, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 2, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 3, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 4, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 5, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 6, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 7, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 8, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 9, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 10, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 11, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 12, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 13, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124010856, 14, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 1, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 2, 97, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 3, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 4, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 5, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 6, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927010857, 7, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 1, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 2, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 3, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 4, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 5, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 6, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010858, 7, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 1, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 2, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 3, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 4, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 5, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 6, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 7, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 8, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 9, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 10, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 11, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 12, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 13, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309010859, 14, 56, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010860, 1, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010860, 2, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602010860, 3, 105, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 1, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 2, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 3, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 4, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 5, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 6, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 7, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413010861, 8, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 1, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 2, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 3, 97, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 4, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 5, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 6, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 7, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 8, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011203, 9, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920011204, 1, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920011204, 2, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920011204, 3, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920011204, 4, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030920011204, 5, 86, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 1, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 2, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 3, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 4, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 5, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007011205, 6, 166, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020829011206, 1, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020829011206, 2, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020829011206, 3, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020829011206, 4, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020829011206, 5, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 1, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 2, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 3, 117, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 4, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 5, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 6, 2, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 7, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 8, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 9, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 10, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 11, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 12, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 13, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 14, 128, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 15, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 16, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110011207, 17, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 1, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 2, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 3, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 4, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 5, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 6, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 7, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 8, 98, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 9, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 10, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 11, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 12, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 13, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209011208, 14, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 1, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 2, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 3, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 4, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 5, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 6, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 7, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730011209, 8, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 1, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 2, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 3, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 4, 120, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 5, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 6, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 7, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 8, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 9, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119011210, 10, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 1, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 2, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 3, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 4, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 5, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 6, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 7, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 8, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 9, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 10, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 11, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 12, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 13, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 14, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525011211, 15, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 1, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 2, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 3, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 4, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 5, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 6, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 7, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 8, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 9, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 10, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 11, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 12, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 13, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 14, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 15, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224011212, 16, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 1, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 2, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 3, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 4, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 5, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 6, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 7, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 8, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 9, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 10, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 11, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 12, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 13, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 14, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 15, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 16, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 17, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140412011213, 18, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806011214, 1, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806011214, 2, 123, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806011214, 3, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806011214, 4, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806011214, 5, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 1, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 2, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 3, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 4, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 5, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 6, 103, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 7, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 8, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 9, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 10, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 11, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 12, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 13, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 14, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 15, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 16, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119011215, 17, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929011216, 1, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929011216, 2, 111, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 1, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 2, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 3, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 4, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 5, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 6, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 7, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 8, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 9, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 10, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 11, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 12, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 13, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 14, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 15, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620011217, 16, 171, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 1, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 2, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 3, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 4, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 5, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 6, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020601011218, 7, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 1, 46, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 2, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 3, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 4, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 5, 59, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 6, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 7, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 8, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 9, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 10, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 11, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 12, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 13, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 14, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 15, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130618011219, 16, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 1, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 2, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 3, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 4, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 5, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 6, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 7, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905011220, 8, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 1, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 2, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 3, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 4, 70, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 5, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011221, 6, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 1, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 2, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 3, 124, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 4, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 5, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 6, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930011222, 7, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 1, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 2, 29, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 3, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 4, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 5, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 6, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 7, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 8, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 9, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 10, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 11, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 12, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 13, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 14, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 15, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120909011223, 16, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 1, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 2, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 3, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 4, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 5, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 6, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 7, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 8, 192, 75, 18, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111011224, 9, 6, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 1, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 2, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 3, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 4, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 5, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 6, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 7, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 8, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050715011225, 9, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 1, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 1, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 2, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 3, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 4, 137, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 5, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 6, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 7, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114011537, 8, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 1, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 2, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 3, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 4, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 5, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 6, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 7, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 8, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 9, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 10, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011538, 11, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 1, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 2, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 3, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 4, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 5, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 6, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419011539, 7, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 1, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 2, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 3, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 4, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 5, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 6, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 7, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 8, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 9, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130011540, 10, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 1, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 2, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 3, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 4, 158, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 5, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 6, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 7, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 8, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 9, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 10, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 11, 5, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 12, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212011541, 13, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505011542, 1, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505011542, 2, 30, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505011542, 3, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505011542, 4, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030505011542, 5, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403011543, 1, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403011543, 2, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403011543, 3, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403011543, 4, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403011543, 5, 133, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028011544, 1, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028011544, 2, 72, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028011544, 3, 88, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 1, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 2, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 3, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 4, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 5, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121011545, 6, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 1, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 2, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 3, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 4, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 5, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 6, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011546, 7, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 1, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 2, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 3, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 4, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 5, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 6, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 7, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 8, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 9, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 10, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 11, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 12, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928011547, 13, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 1, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 2, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 3, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 4, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 5, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 6, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 7, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 8, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 9, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 10, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 11, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115011548, 12, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 1, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 3, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 4, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 5, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 6, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 7, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 8, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 9, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 10, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 11, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 12, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 13, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 14, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 15, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 16, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131225011549, 17, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 1, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 2, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 3, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 4, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 5, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 6, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 7, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 8, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 9, 39, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 10, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 11, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 12, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 13, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129011550, 14, 51, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 1, 53, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 2, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 3, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 4, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 5, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 6, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 7, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 8, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 9, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 10, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080816011551, 11, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 1, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 2, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 3, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 4, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 5, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 6, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 7, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 8, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 9, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 10, 85, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 11, 185, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514011552, 12, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 1, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 2, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 3, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 4, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 5, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 6, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 7, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 8, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 9, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 10, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 11, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224011553, 12, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 1, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 2, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 3, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 4, 47, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 5, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 6, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 7, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 8, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 9, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070711011554, 10, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 1, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 2, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 3, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 4, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 5, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 6, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 7, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 8, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 9, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 10, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 11, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 12, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 13, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 14, 40, 79, 11, 869);
commit;
prompt 112000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201011555, 15, 9, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 1, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 2, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 3, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 4, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 5, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 6, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 7, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 8, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 9, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 10, 23, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 11, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 12, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 13, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 14, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 15, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212011556, 16, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 1, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 2, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 3, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 4, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 5, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124011557, 6, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404011558, 1, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404011558, 2, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404011558, 3, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404011558, 4, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 1, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 2, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 3, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 4, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 5, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 6, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 7, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 8, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 9, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 10, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327011559, 11, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 1, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 2, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 3, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 4, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 5, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 6, 192, 36, 18, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 7, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 8, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 9, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 10, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011011560, 11, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 6, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 7, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 8, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 9, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 10, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 11, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 12, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428010473, 13, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 1, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 2, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 3, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 4, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 5, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 6, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 7, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 8, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 9, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 10, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 11, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321010474, 12, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 1, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 2, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 3, 70, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 4, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 5, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 6, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 7, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 8, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 9, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 10, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 11, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 12, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 13, 148, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 14, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 15, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 16, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 17, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131008010475, 18, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 1, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 2, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 3, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 4, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 5, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217010476, 6, 136, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228010477, 1, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228010477, 2, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 1, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 2, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 3, 156, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 4, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 5, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 6, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114010478, 7, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 1, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 2, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 3, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 4, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 5, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 6, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 7, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 8, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 9, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 10, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080621010479, 11, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 1, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 2, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 3, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 4, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 5, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 6, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 7, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 8, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 9, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 10, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 11, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609010480, 12, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 1, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 2, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 3, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 4, 168, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 5, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216010481, 6, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 1, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 2, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 3, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 4, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 5, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010482, 6, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414010483, 1, 109, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414010483, 2, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414010483, 3, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414010483, 4, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414010483, 5, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 1, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 2, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 3, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 4, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 5, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 6, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 7, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009010484, 8, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 1, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 2, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 3, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 4, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 5, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 6, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 7, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 8, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010485, 9, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 1, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 2, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 3, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 4, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 5, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 6, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 7, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 8, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 9, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 10, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 11, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 12, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 13, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090703010486, 14, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 1, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 2, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 3, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 4, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 5, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 6, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 7, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 8, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010487, 9, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218010488, 1, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218010488, 2, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218010488, 3, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218010488, 4, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218010488, 5, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010489, 1, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010489, 2, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010489, 3, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010489, 4, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 1, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 2, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 3, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 4, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 5, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 6, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 7, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106010490, 8, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010491, 1, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010491, 2, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121010491, 3, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 1, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 2, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 3, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 4, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 5, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 6, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 7, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 8, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 9, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629010492, 10, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 1, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 2, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 3, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 4, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 5, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 6, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 7, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 8, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 9, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 10, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 11, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 12, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 13, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128010493, 14, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517010494, 1, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517010494, 2, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517010494, 3, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 1, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 2, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 3, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 4, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 5, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 6, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 7, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 8, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 9, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111010495, 10, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 1, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 2, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 3, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 4, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 5, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 6, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 7, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 8, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 9, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 10, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 11, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 12, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 13, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 14, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 15, 50, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 16, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 17, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115010496, 18, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109010497, 1, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109010497, 2, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109010497, 3, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 1, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 2, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 3, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 4, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 5, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 6, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 7, 66, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 8, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 9, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 10, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 11, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 12, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 13, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 14, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110403010498, 15, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 1, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 2, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 3, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 4, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 5, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 6, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 7, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 8, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 9, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 10, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060613010499, 11, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 1, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 2, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 4, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 5, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 6, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 7, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 8, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050724010862, 9, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 1, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 2, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 3, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 4, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 5, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 6, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216010863, 7, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 1, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 2, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 3, 97, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 4, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 5, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 6, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 7, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 8, 22, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 9, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 10, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922010864, 11, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 1, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 2, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 3, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 4, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 5, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 6, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 7, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 8, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 9, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060816010865, 10, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 1, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 2, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 3, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 4, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 5, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 6, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 7, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 8, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 9, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 10, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229010866, 11, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 1, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 2, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 3, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 4, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 5, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 6, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203010867, 7, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 1, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 2, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 3, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 4, 134, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 5, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 6, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 7, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 8, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 9, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070104010868, 10, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 1, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 2, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 3, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 4, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 5, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 6, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 7, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210010869, 8, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 1, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 2, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 3, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 4, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 5, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 6, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 7, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 8, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 9, 99, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 10, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 11, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 12, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 13, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 14, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 15, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 16, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606010870, 17, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 1, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 2, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 3, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 4, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 5, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 6, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 7, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 8, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 9, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 10, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 11, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 12, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 13, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 14, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 15, 6, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130123010871, 16, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102010872, 1, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102010872, 2, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102010872, 3, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102010872, 4, 126, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102010872, 5, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 1, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 2, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 3, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 4, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 5, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 6, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 7, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 8, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 9, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 10, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 11, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 12, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 13, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 14, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 15, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140210010873, 16, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 1, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 2, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 3, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 4, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 5, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 6, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 7, 150, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 8, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 9, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 10, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 11, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 12, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 13, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 14, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 15, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 16, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 17, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130913010874, 18, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 1, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 2, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 3, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 4, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 5, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 6, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 7, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 8, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 9, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 10, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 11, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 12, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 13, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 14, 128, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815010875, 15, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 1, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 2, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 3, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 4, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 5, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 6, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 7, 149, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 8, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 9, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 10, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 11, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 12, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401010876, 13, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831010877, 1, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831010877, 2, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831010877, 3, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831010877, 4, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010831010877, 5, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 1, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 2, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 3, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 4, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 5, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 6, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 7, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 8, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 9, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 10, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 11, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 12, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 13, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 14, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 15, 65, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 16, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930010878, 17, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 1, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 2, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 3, 174, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 4, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 5, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 6, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 7, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 8, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 9, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 10, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430010879, 11, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 1, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 2, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 3, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 4, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 5, 192, 36, 18, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 6, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 7, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 8, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 9, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 10, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 11, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090215010880, 12, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 1, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 2, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 3, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 4, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 5, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 6, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 7, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 8, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 9, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 10, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 11, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 12, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 13, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116010881, 14, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 1, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 2, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 3, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 4, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 5, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 6, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220010882, 7, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 1, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 2, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 3, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 2, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 3, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 4, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 5, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010615011226, 6, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 1, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 2, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 3, 44, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 4, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 5, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 6, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 7, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 8, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 9, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 10, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080509011227, 11, 181, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 1, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 2, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 3, 98, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 4, 17, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 5, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 6, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 7, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 8, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 9, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 10, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 11, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 12, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090210011228, 13, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 1, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 2, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 3, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 4, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 5, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 6, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 7, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 8, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 9, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 10, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080122011229, 11, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326011230, 1, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326011230, 2, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326011230, 3, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326011230, 4, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 1, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 2, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 3, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 4, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 5, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 6, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419011231, 7, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 1, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 2, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 3, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 4, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 5, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 6, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 7, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 8, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 9, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 10, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 11, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314011232, 12, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 1, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 2, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 3, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 4, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 5, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 6, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 7, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 8, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 9, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 10, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 11, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 12, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011233, 13, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 1, 133, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 2, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 3, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 4, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 5, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 6, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 7, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 8, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 9, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 10, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 11, 116, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801011234, 12, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 1, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 2, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 3, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 4, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 5, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 6, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 7, 102, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 8, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 9, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 10, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011235, 11, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 1, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 2, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 3, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 4, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 5, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 6, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101011236, 7, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 1, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 2, 128, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 3, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 4, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 5, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 6, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 7, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 8, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 9, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 10, 165, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 11, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 12, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100910011237, 13, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 1, 36, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 2, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 3, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 4, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 5, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 6, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 7, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 8, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 9, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 10, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609011238, 11, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 1, 148, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 2, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 3, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 4, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 5, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223011239, 6, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 1, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 2, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 3, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 4, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 5, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 6, 182, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011240, 7, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 1, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 2, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 3, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 4, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 5, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 6, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 7, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 8, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 9, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 10, 113, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 11, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 12, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 13, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125011241, 14, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 1, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 2, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 3, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 4, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 5, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 6, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 7, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 8, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 9, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 10, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 11, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071118011242, 12, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 1, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 2, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 3, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 4, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 5, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 6, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 7, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 8, 1, 60, 3, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 9, 80, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 10, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 11, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011243, 12, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 1, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 2, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 3, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 4, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 5, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 6, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 7, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 8, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 9, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 10, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 11, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 12, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 13, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904011244, 14, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125011245, 1, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125011245, 2, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125011245, 3, 51, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125011245, 4, 67, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021125011245, 5, 151, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 1, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 2, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 3, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 4, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 5, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 6, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427011246, 7, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 1, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 2, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 3, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 4, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 5, 142, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128011247, 6, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 1, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 2, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 3, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 4, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 5, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 6, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040801011248, 7, 4, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105011249, 1, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105011249, 2, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105011249, 3, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018011250, 1, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018011250, 2, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018011250, 3, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018011250, 4, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018011250, 5, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 1, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 2, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 3, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 4, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 5, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 6, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 7, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 8, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 9, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 10, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 11, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 5, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 6, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 7, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010115, 8, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 1, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 2, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 3, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 4, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 5, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402010116, 6, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 1, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 2, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 3, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 4, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 5, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 6, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 7, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 8, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 9, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 10, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 11, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 12, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226010117, 13, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 1, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 2, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 3, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 4, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 5, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 6, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021128010118, 7, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 1, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 2, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 3, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 4, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 5, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 6, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 8, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 9, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 10, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 11, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080222010119, 12, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 1, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 2, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 3, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 4, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 5, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 6, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 7, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 8, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 9, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 10, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 11, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 12, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 13, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 14, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 15, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 16, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130502010120, 17, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 1, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 2, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 3, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 4, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 5, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 6, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 7, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 8, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 9, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527010121, 10, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 1, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 2, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 3, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 4, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 5, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 6, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 7, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 8, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 9, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 10, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 11, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 12, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826010122, 13, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 1, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 2, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 3, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 4, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 5, 191, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 6, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 7, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 8, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 9, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 10, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624010123, 11, 191, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 1, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 2, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 3, 66, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 4, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 5, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 6, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 7, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 8, 121, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121010124, 9, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010125, 1, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010125, 2, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010125, 3, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010125, 4, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301010125, 5, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 1, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 2, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 3, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 4, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 5, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 6, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 7, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 8, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 9, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 10, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 11, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 12, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 13, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 14, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128010126, 15, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 1, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 2, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 3, 69, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 4, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 5, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 6, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 7, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 8, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 9, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 10, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 11, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 12, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 13, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 14, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 15, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 16, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503010127, 17, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 1, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 2, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 3, 42, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 4, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 5, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 6, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302010128, 7, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 1, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 2, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 3, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 4, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 5, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 6, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 7, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 8, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 9, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 10, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 11, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 12, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 13, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120517010129, 14, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 1, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 2, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 3, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 4, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 5, 178, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 6, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 7, 120, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 8, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 9, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 10, 114, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 11, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 12, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 13, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 14, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105010130, 15, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 1, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 2, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 3, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 4, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 5, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 6, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 7, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 8, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 9, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901010131, 10, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 1, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 2, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 3, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 4, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 5, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 6, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 7, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 8, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025010132, 9, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415010133, 1, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415010133, 2, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415010133, 3, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415010133, 4, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000415010133, 5, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 1, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 2, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 3, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 4, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 5, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 6, 93, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 7, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201010134, 8, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 1, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 2, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 3, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 4, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 5, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 6, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 7, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 8, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103010135, 9, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 1, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 2, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 3, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 4, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 5, 81, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 6, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 7, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 8, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 9, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 10, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 11, 91, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080511010136, 12, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 1, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 2, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 3, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 4, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 5, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 6, 183, 30, 16, 480);
commit;
prompt 113000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 7, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 8, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 9, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 10, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 3, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 4, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 5, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 6, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 7, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 8, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 9, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 10, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 11, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 12, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 13, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090906010500, 14, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102010501, 1, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102010501, 2, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102010501, 3, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102010501, 4, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015010502, 1, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015010502, 2, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015010502, 3, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015010502, 4, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015010502, 5, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 1, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 2, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 3, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 4, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 5, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 6, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 7, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 8, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 9, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 10, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 11, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 12, 99, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 13, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 14, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 15, 121, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626010503, 16, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 1, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 2, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 3, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 4, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 5, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 6, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 7, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 8, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 9, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010504, 10, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 1, 90, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 2, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 3, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 4, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 5, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 6, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 7, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213010505, 8, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001112010506, 1, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001112010506, 2, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 1, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 2, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 3, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 4, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 5, 109, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921010507, 6, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010508, 1, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010508, 2, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010508, 3, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010508, 4, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010508, 5, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 1, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 2, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 3, 28, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 4, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 5, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 6, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 7, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119010509, 8, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 1, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 2, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 3, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 4, 187, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 5, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 6, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 7, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 8, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 9, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 10, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 11, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 12, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 13, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514010510, 14, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 1, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 2, 157, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 3, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 4, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 5, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 6, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 7, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 8, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 9, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 10, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 11, 28, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 12, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 13, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 14, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531010511, 15, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 1, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 2, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 3, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 4, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 5, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 6, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 7, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 8, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 9, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 10, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 11, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 12, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080703010512, 13, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 1, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 2, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 3, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 4, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 5, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 6, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 7, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 8, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 9, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 10, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 11, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 12, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 13, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318010513, 14, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 1, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 2, 96, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 3, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 4, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 5, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 6, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 7, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 8, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 9, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 10, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 11, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 12, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010514, 13, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 1, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 2, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 3, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 4, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 5, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 6, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 7, 31, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809010515, 8, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 1, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 2, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 3, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 4, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 5, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030912010516, 6, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 1, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 2, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 3, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 4, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 5, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 6, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 7, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 8, 54, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 9, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 10, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 11, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 12, 42, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 13, 165, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100616010517, 14, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 1, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 2, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 3, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 4, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 5, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 6, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 7, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 8, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 9, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 10, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 11, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 12, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828010518, 13, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 1, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 2, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 3, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 4, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 5, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 6, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 7, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 8, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 9, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 10, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201010519, 11, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 1, 113, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 2, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 3, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 4, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 5, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 6, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 7, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 8, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 9, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 10, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 11, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 12, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 13, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 14, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 15, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305010520, 16, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 1, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 2, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 3, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 4, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 5, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 6, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 7, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 8, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 9, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 10, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 11, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 12, 27, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 13, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907010521, 14, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 1, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 2, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 3, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 4, 59, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 5, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 6, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 7, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 8, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 9, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 10, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 11, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 12, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 4, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 5, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 6, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 7, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 8, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 9, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 10, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 11, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 12, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 13, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 14, 145, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 15, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140309010883, 16, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 1, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 2, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 3, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 4, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 5, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 6, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 7, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 8, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 9, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 10, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 11, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 12, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 13, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 14, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 15, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 16, 80, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 17, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915010884, 18, 97, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 1, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 2, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 3, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 4, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 5, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 6, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 7, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 8, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 9, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 10, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 11, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223010885, 12, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 1, 171, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 2, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 3, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 4, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 5, 191, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 6, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 7, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 8, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 9, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 10, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 11, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 12, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 13, 186, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 14, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110419010886, 15, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 1, 58, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 2, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 3, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 4, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 5, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040112010887, 6, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 1, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 2, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 3, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 4, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 5, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 6, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 7, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 8, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 9, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 10, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 11, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 12, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 13, 20, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 14, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 15, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917010888, 16, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 1, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 2, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 3, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 4, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 5, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 6, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421010889, 7, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 1, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 2, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 3, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 4, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 5, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 6, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 7, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 8, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215010890, 9, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 1, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 2, 106, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 3, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 4, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 5, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 6, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 7, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 8, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 9, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 10, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060208010891, 11, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520010892, 1, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520010892, 2, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520010892, 3, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520010892, 4, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520010892, 5, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 1, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 2, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 3, 104, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 4, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 5, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 6, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 7, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 8, 87, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 9, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 10, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 11, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 12, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726010893, 13, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 1, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 2, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 3, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 4, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 5, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 6, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 7, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041129010894, 8, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 1, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 2, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 3, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 4, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 5, 6, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803010895, 6, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 1, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 2, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 3, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 4, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 5, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 6, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 7, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 8, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 9, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105010896, 10, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 1, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 2, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 3, 130, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 4, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 5, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 6, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 7, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 8, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 9, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 10, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 11, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 12, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 13, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100521010897, 14, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 1, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 2, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 3, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 4, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 5, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 6, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 7, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 8, 58, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 9, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 10, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 11, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 12, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906010898, 13, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 1, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 2, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 3, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 4, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 5, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 6, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108010899, 7, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 1, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 2, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 3, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 4, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 5, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013010900, 6, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 1, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 2, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 3, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 4, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 5, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 6, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 7, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 8, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 9, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 10, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 11, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 12, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 13, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 14, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 15, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120319010901, 16, 61, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 1, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 2, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 3, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 4, 105, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 5, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907010902, 6, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 1, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 2, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 3, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 4, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 5, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 6, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 7, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 8, 107, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 9, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 10, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 11, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 12, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923010903, 13, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511010904, 1, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511010904, 2, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511010904, 3, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511010904, 4, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 1, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 2, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 3, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 4, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 5, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 6, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 7, 156, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 8, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 9, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 10, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 11, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 12, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 13, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 14, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104011251, 15, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 1, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 2, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 3, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 4, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 5, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 6, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 7, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 8, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 9, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 10, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 11, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 12, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820011252, 13, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 1, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 2, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 3, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 4, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 5, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 6, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 7, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 8, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021011253, 9, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 1, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 2, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 3, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 4, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 5, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 6, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 7, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 8, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 9, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215011254, 10, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 1, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 2, 99, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 3, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 4, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 5, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 6, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 7, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 8, 127, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 9, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 10, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 11, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 12, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 13, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 14, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 15, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 16, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903011255, 17, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 1, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 2, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 3, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 4, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 5, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 6, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 7, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 8, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 9, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 10, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 11, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 12, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 13, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 14, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 15, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 16, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404011256, 17, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 1, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 2, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 3, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 4, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 5, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 6, 90, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011257, 7, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011258, 1, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011258, 2, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011258, 3, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011258, 4, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030702011258, 5, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 1, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 2, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 3, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 4, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 5, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 6, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227011259, 7, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 1, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 2, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 3, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 4, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 5, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 6, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 7, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 8, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 9, 4, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 10, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 11, 98, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 12, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011260, 13, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 1, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 2, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 3, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 4, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 5, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 6, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 7, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 8, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 9, 160, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616011261, 10, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 1, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 2, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 3, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 4, 125, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 5, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 6, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 7, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710011262, 8, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801011263, 1, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801011263, 2, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801011263, 3, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801011263, 4, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030801011263, 5, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 1, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 2, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 3, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 4, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 5, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 6, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 7, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 8, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 9, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 10, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 11, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 12, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 13, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 14, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 15, 143, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 16, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 17, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924011264, 18, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906011265, 1, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906011265, 2, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906011265, 3, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010906011265, 4, 41, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 1, 14, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 2, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 3, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 4, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 5, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 6, 187, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 7, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 8, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 9, 171, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102011266, 10, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810011267, 1, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810011267, 2, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810011267, 3, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 1, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 2, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 3, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 4, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 5, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 6, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 7, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 8, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 9, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 10, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 11, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013011268, 12, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 1, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 2, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 3, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 4, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 5, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 6, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 7, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 8, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 9, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 10, 71, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 11, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 12, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 13, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091112011269, 14, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903011270, 1, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903011270, 2, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903011270, 3, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903011270, 4, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 1, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 2, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 3, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 4, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 5, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 6, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 7, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 8, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 9, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 10, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 11, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 12, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816011271, 13, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 1, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 2, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 3, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 4, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 5, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 6, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 7, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 8, 187, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 9, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 10, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 11, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 12, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 13, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 14, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110323011272, 15, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 1, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 2, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 3, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 4, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 5, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 6, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 7, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 8, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 9, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 10, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 11, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 12, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118011273, 13, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318011274, 1, 100, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318011274, 2, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318011274, 3, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318011274, 4, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318011274, 5, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 1, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 2, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 3, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 11, 124, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 12, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 13, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 14, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100819010137, 15, 142, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 1, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 2, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 3, 167, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 4, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 5, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 6, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 7, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729010138, 8, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 1, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 2, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 3, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 4, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 5, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 6, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 7, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627010139, 8, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 1, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 2, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 3, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 4, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 5, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 6, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 7, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 8, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 9, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 10, 171, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028010140, 11, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507010141, 1, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507010141, 2, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000507010141, 3, 188, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 1, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 2, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 3, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 4, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 5, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 6, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 7, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 8, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 9, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 10, 8, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 11, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 12, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423010142, 13, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 1, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 2, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 3, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 4, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 5, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 6, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 7, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 8, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 9, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 10, 4, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 11, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 12, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100531010143, 13, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228010144, 1, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228010144, 2, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228010144, 3, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 1, 117, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 2, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 3, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 4, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 5, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 6, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 7, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 8, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 9, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 10, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 11, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 12, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 13, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221010145, 14, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 1, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 2, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 3, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 4, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 5, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 6, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040107010146, 7, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 1, 80, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 2, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 3, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 4, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 5, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 6, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 7, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 8, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 9, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127010147, 10, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 1, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 2, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 3, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 4, 35, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 5, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 6, 112, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 7, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 8, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 9, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 10, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 11, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 12, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 13, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 14, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 15, 55, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811010148, 16, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013010149, 1, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013010149, 2, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013010149, 3, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013010149, 4, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013010149, 5, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000321010150, 1, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000321010150, 2, 169, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202010151, 1, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202010151, 2, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000202010151, 3, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 1, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 3, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 4, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 5, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 6, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 7, 110, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 8, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 9, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 10, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908010152, 11, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 1, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 2, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 3, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 4, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 5, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 6, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 7, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 8, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 9, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 10, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106010153, 11, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706010154, 1, 162, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706010154, 2, 41, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706010154, 3, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706010154, 4, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706010154, 5, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 1, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 2, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 3, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 4, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 5, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 6, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 7, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 8, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 9, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 10, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 11, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070815010155, 12, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 1, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 2, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 3, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 4, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 5, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 6, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 7, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 8, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 9, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 10, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325010156, 11, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 2, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 3, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 4, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 5, 1, 39, 3, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 6, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 7, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 8, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 9, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 10, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 11, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 12, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 13, 192, 49, 18, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 14, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 15, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 16, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 17, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140303010157, 18, 126, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 1, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 2, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 3, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 4, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 5, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 6, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 7, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 8, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 9, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423010158, 10, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 1, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 2, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 3, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 4, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 5, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 6, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 7, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 8, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 9, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 10, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 11, 60, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 12, 93, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 13, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 14, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 15, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130010159, 16, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 1, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 2, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 3, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 4, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 5, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 6, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 7, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 8, 174, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 9, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 10, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 11, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 12, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 13, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 14, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110523010160, 15, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 1, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 2, 59, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 3, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 4, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 5, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 6, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 7, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 8, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 9, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 13, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 14, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201010522, 15, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 1, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 2, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 3, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 4, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 5, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 6, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418010523, 7, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717010524, 1, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717010524, 2, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717010524, 3, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717010524, 4, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717010524, 5, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 1, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 2, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 3, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 4, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 5, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010525, 6, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 1, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 2, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 3, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 4, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 5, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 6, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 7, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 8, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 9, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 10, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 11, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 12, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 13, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111015010526, 14, 172, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 1, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 2, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 3, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 4, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 5, 165, 54, 12, 648);
commit;
prompt 114000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 6, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 7, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 8, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 9, 47, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 10, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 11, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 12, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 13, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 14, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910010527, 15, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 1, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 2, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 3, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 4, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 5, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 6, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 7, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 8, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 9, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 10, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 11, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080625010528, 12, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 1, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 2, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 3, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 4, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 5, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 6, 150, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 7, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 8, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 9, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 10, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 11, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 12, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110215010529, 13, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 1, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 2, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 3, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 4, 186, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 5, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 6, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 7, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 8, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 9, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 10, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 11, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 12, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 13, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 14, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 15, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 16, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 17, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 18, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140307010530, 19, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 1, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 2, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 3, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 4, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 5, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 6, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 7, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 8, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204010531, 9, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 1, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 2, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 3, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 4, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 5, 80, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 6, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 7, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 8, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 9, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 10, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 11, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 12, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 13, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 14, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805010532, 15, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 1, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 2, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 3, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 4, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 5, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 6, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 7, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 8, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 9, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 10, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 11, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 12, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 13, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 14, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 15, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229010533, 16, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 2, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 3, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 4, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 5, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 6, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 7, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 8, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 9, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 10, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010534, 11, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 1, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 2, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 3, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 4, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 5, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 6, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 7, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 8, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 9, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 10, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 11, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 12, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 13, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 14, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 15, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 16, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221010535, 17, 166, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 1, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 2, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 3, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 4, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 5, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 6, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 7, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 8, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 9, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 10, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 11, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 12, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101010536, 13, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 1, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 2, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 3, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 4, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 5, 144, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205010537, 6, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 1, 64, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 2, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 3, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 4, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 5, 175, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 6, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 7, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115010538, 8, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 1, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 2, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 3, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 4, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 5, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 6, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002010539, 7, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 1, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 2, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 3, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 4, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 5, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 6, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 7, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 8, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 9, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 10, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 11, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 12, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 13, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206010540, 14, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 1, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 2, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 3, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 4, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 5, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 6, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 7, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 8, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 9, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 10, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 11, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 12, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 13, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 14, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 15, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030010541, 16, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918010542, 1, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918010542, 2, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918010542, 3, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918010542, 4, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000918010542, 5, 94, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 1, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 2, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 3, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 4, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 5, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 6, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 7, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 8, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 12, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090724010905, 13, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 1, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 2, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 3, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 4, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 5, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 6, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228010906, 7, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119010907, 1, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119010907, 2, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119010907, 3, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119010907, 4, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 1, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 2, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 3, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 4, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 5, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 6, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 7, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 8, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 9, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 10, 139, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121010908, 11, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 1, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 2, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 3, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 4, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 5, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 6, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 7, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 8, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060708010909, 9, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 1, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 2, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 3, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 4, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 5, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 6, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 7, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 8, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 9, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 10, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 11, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 12, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 13, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 14, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 15, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 16, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 17, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803010910, 18, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 1, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 2, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 3, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 4, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 5, 24, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115010911, 6, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 1, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 2, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 3, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 4, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 5, 84, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 6, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 7, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 8, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 9, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 10, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 11, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 12, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 13, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129010912, 14, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 1, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 2, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 3, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 4, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 5, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 6, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104010913, 7, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 1, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 2, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 3, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 4, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 5, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 6, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 7, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 8, 55, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010914, 9, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 1, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 2, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 3, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 4, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 5, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 6, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 7, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 8, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 9, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 10, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 11, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106010915, 12, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 1, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 2, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 3, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 4, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 5, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 6, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 7, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 8, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 9, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 10, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 11, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 12, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222010916, 13, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 1, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 2, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 3, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 4, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 5, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 6, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 7, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 8, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 9, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 10, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080316010917, 11, 33, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 1, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 2, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 3, 164, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 4, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 5, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 6, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 7, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 8, 155, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 9, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 10, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 11, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 12, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 13, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104010918, 14, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 1, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 2, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 3, 153, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 4, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 5, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 6, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304010919, 7, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 1, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 2, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 3, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 4, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 5, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 6, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 7, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 8, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 9, 38, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 10, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 11, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 12, 98, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 13, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 14, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707010920, 15, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 1, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 2, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 3, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 4, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 5, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 6, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 7, 182, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 8, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 9, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 10, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 11, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 12, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 13, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 14, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318010921, 15, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 1, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 2, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 3, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 4, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 5, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 6, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030307010922, 7, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 1, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 2, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 3, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 4, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 5, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 6, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 7, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 8, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220010923, 9, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 1, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 2, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 3, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 4, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 5, 84, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010428010924, 6, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 1, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 2, 84, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 3, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 4, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 5, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 6, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 7, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 8, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205010925, 9, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 1, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 2, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 3, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 4, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 5, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 6, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 7, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 8, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 9, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 10, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 11, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 12, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 13, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 14, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213010926, 15, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 1, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 2, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 3, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 4, 131, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 5, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 6, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 7, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 8, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060608010927, 9, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727010928, 1, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727010928, 2, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727010928, 3, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 1, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 2, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 3, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 4, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 5, 143, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 6, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 7, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 4, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 5, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 6, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 7, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040802011275, 8, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 1, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 2, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 3, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 4, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 5, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 6, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 7, 86, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 8, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 9, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 10, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 11, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 12, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 13, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 14, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 15, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 16, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140113011276, 17, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 1, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 2, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 3, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 4, 65, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 5, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 6, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030515011277, 7, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 1, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 2, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 3, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 4, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 5, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 6, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 7, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 8, 74, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 9, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 10, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 11, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 12, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206011278, 13, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 1, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 2, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 3, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 4, 140, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 5, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 6, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416011279, 7, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 1, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 2, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 3, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 4, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 5, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 6, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 7, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 8, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060803011280, 9, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 1, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 2, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 3, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 4, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 5, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 6, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 7, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 8, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 9, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 10, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 11, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 12, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 13, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013011281, 14, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 1, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 2, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 3, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 4, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 5, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 6, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 7, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 8, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 9, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 10, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 11, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 12, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 13, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 14, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011282, 15, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 1, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 2, 91, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 3, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 4, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 5, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 6, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 7, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 8, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 9, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 10, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 11, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 12, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 13, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 14, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 15, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 16, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 17, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716011283, 18, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 1, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 2, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 3, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 4, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 5, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 6, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 7, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 8, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031011284, 9, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 1, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 2, 99, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 3, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 4, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 5, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 6, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 7, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723011285, 8, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 1, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 2, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 3, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 4, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 5, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 6, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 7, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 8, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 9, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 10, 177, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 11, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 12, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 13, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 14, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205011286, 15, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 1, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 2, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 3, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 4, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 5, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 6, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 7, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 8, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 9, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 10, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 11, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 12, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 13, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011287, 14, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817011288, 1, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817011288, 2, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817011288, 3, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817011288, 4, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817011288, 5, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 1, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 2, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 3, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 4, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 5, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 6, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 7, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 8, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 9, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 10, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 11, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 12, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609011289, 13, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 1, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 2, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 3, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 4, 31, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 5, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041119011290, 6, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 1, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 2, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 3, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 4, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 5, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 6, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 7, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 8, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 9, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 10, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 11, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 12, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 13, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 14, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630011291, 15, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 1, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 2, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 3, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 4, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 5, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 6, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 7, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 8, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 9, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 10, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061006011292, 11, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 1, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 2, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 3, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 4, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 5, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 6, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 7, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 8, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 9, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 10, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 11, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 12, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 13, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 14, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 15, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130209011293, 16, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 1, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 2, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 3, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 4, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 5, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 6, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 7, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 8, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 9, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 10, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070508011294, 11, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 1, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 2, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 3, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 4, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 5, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 6, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 7, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 8, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128011295, 9, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521011296, 1, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521011296, 2, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050911010161, 10, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117010162, 1, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117010162, 2, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001117010162, 3, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115010163, 1, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115010163, 2, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115010163, 3, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115010163, 4, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115010164, 1, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115010164, 2, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115010164, 3, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115010164, 4, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031115010164, 5, 64, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 1, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 2, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 3, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 4, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 5, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 6, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 7, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 8, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124010165, 9, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208010166, 1, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208010166, 2, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208010166, 3, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208010166, 4, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 1, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 2, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 3, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 4, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 5, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 6, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 7, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 8, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 9, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 10, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 11, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 12, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 13, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 14, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502010167, 15, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223010168, 1, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223010168, 2, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223010168, 3, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223010168, 4, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119010169, 1, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119010169, 2, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119010169, 3, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119010169, 4, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 1, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 2, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 3, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 4, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 5, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 6, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 7, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 8, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 9, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 10, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 11, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 12, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 13, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 14, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022010170, 15, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 1, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 2, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 3, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 4, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 5, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 6, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 7, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 8, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210010171, 9, 141, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 1, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 2, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 3, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 4, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 5, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 6, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 7, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 8, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 9, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 10, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 11, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010172, 12, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 1, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 2, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 3, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 4, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 5, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 6, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 7, 148, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 8, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 9, 71, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 10, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 11, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 12, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090330010173, 13, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 1, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 2, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 3, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 4, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 5, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 6, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 7, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 8, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 9, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 10, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 11, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804010174, 12, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 1, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 2, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 3, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 4, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 5, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 6, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 7, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 8, 127, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116010175, 9, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 1, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 2, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 3, 62, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 4, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 5, 79, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 6, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 7, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 8, 25, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 9, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 10, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 11, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 12, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222010176, 13, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 1, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 2, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 3, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 4, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 5, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226010177, 6, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 1, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 2, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 3, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 4, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 5, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 6, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 7, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 8, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 9, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 10, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 11, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 12, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 13, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 14, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 15, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829010178, 16, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230010179, 1, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230010179, 2, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230010179, 3, 56, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 1, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 2, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 3, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 4, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 5, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 6, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 7, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 8, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 9, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 10, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 11, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 12, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 13, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 14, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 15, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707010180, 16, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 1, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 2, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 3, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 4, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 5, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310010181, 6, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916010182, 1, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916010182, 2, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916010182, 3, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916010182, 4, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010916010182, 5, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 1, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 2, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 3, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 4, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 5, 84, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 6, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 7, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 8, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 9, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 10, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206010183, 11, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222010184, 1, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222010184, 2, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222010184, 3, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222010184, 4, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 1, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 2, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 3, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 4, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 5, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 6, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 7, 32, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 8, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609010185, 9, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 1, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 2, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 3, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 4, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 5, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 6, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120010186, 7, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 1, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 2, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 3, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 4, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 5, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 6, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 7, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231010187, 8, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 1, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 2, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 3, 174, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 4, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 5, 177, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707010188, 6, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 1, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 2, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 3, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 4, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 5, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 6, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 7, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 8, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 9, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 9, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 10, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 11, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015010543, 12, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 1, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 2, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 3, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 4, 128, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 5, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 6, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210010544, 7, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217010545, 1, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217010545, 2, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217010545, 3, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217010545, 4, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010217010545, 5, 69, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 1, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 2, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 3, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 4, 65, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 5, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 6, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 7, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 8, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 9, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 10, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 11, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 12, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 13, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 14, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110309010546, 15, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 1, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 2, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 3, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 4, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 5, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 6, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 7, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 8, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 9, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 10, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 11, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 12, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081011010547, 13, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 1, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 2, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 3, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 4, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 5, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 6, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 7, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 8, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 9, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 10, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 11, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 12, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 13, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 14, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723010548, 15, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 1, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 2, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 3, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 4, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 5, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 6, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 7, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 8, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 9, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 10, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 11, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 12, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 13, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208010549, 14, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 1, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 2, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 3, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 4, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 5, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 6, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 7, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 8, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 9, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 10, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 11, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 12, 44, 15, 8, 120);
commit;
prompt 115000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 13, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 14, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 15, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011010550, 16, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 1, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 2, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 3, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 4, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 5, 138, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 6, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 7, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212010551, 8, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 1, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 2, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 3, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 4, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 5, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 6, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 7, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 8, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 9, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 10, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 11, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 12, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 13, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 14, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 15, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 16, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130710010552, 17, 65, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929010553, 1, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929010553, 2, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929010553, 3, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 1, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 2, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 3, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 4, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 5, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 6, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 7, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 8, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809010554, 9, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 1, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 2, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 3, 7, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 4, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 5, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 6, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 7, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105010555, 8, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 1, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 2, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 3, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 4, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 5, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 6, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 7, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226010556, 8, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003010557, 1, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003010557, 2, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003010557, 3, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010010558, 1, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010010558, 2, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010010558, 3, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010010558, 4, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010010558, 5, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 1, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 2, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 3, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 4, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 5, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 6, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 7, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 8, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 9, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101010559, 10, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 1, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 2, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 3, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 4, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 5, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125010560, 6, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306010561, 1, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306010561, 2, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 1, 108, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 2, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 3, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 4, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 5, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 6, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 7, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 8, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 9, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 10, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070619010562, 11, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 1, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 2, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 3, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 4, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 5, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 6, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040827010563, 7, 179, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 1, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 2, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 3, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 4, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 5, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 6, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 7, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 8, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 9, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 10, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 11, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081128010564, 12, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115010565, 1, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115010565, 2, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115010565, 3, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115010565, 4, 54, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 1, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 2, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 3, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 4, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 5, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 6, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308010566, 7, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 1, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 2, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 3, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 4, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 5, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 6, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 7, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 8, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 9, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 10, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 11, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 12, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321010567, 13, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 1, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 2, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 3, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 4, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 5, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 6, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 7, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 8, 88, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 9, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 10, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 11, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 12, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 13, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 14, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 15, 183, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231010568, 16, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 1, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 8, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 9, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 10, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 11, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 12, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 13, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 14, 188, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 15, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131020010929, 16, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 1, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 2, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 3, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 4, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 5, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 6, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 7, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 8, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 9, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 10, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 11, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 12, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 13, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 14, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 15, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108010930, 16, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 1, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 2, 59, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 3, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 4, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 5, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 6, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 7, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 8, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 9, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 10, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 11, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 12, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 13, 171, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505010931, 14, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 1, 30, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 2, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 3, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 4, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 5, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 6, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 7, 177, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 8, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 9, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 10, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 11, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 12, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803010932, 13, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 1, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 2, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 3, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 4, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 5, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 6, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 7, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 8, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 9, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 10, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 11, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 12, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728010933, 13, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827010934, 1, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827010934, 2, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827010934, 3, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827010934, 4, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827010934, 5, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827010935, 1, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827010935, 2, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827010935, 3, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 1, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 2, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 3, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 4, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 5, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 6, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 7, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 8, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612010936, 9, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 1, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 2, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 3, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 4, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 5, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 6, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 7, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 8, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 9, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 10, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 11, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 12, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 13, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 14, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 15, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 16, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 17, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428010937, 18, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 1, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 2, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 3, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 4, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 5, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 6, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 7, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 8, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 9, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528010938, 10, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010939, 1, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010939, 2, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010939, 3, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010939, 4, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521010939, 5, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 1, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 2, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 3, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 4, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 5, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 6, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 7, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121010940, 8, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 1, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 2, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 3, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 4, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 5, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 6, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101010941, 7, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110010942, 1, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110010942, 2, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110010942, 3, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 1, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 2, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 3, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 4, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 5, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 6, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 7, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425010943, 8, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 1, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 2, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 3, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 4, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 5, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 6, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 7, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403010944, 8, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 1, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 2, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 3, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 4, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 5, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 6, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 7, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 8, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 9, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 10, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 11, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 12, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127010945, 13, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 1, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 2, 112, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 3, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 4, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 5, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 6, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 7, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 8, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 9, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 10, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 11, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 12, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 13, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 14, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428010946, 15, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 1, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 2, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 3, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 4, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 5, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 6, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 7, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 8, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 9, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010010947, 10, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606010948, 1, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606010948, 2, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606010948, 3, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606010948, 4, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606010948, 5, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 1, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 2, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 3, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 4, 114, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 5, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 6, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 7, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 8, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 9, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 10, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 11, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 12, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619010949, 13, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 1, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 2, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 3, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 4, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 5, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 6, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 7, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 8, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 9, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 10, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710010950, 11, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318010951, 1, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318010951, 2, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318010951, 3, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000318010951, 4, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 1, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 2, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 3, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 4, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 5, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 6, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050505010952, 7, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 1, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 2, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 3, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 4, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 5, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 6, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050514010953, 7, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 1, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 2, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 3, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 4, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521011296, 3, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521011296, 4, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010521011296, 5, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 1, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 2, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 3, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 4, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 5, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 6, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222011297, 7, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513011298, 1, 151, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513011298, 2, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513011298, 3, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513011298, 4, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513011298, 5, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 1, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 2, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 3, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 4, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 5, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 6, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 7, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 8, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428011299, 9, 56, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 1, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 2, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 3, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 4, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 5, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022011300, 6, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 1, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 2, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 3, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 4, 192, 38, 18, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 5, 35, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 6, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 7, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 8, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 9, 107, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 10, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 11, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 12, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 13, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602011301, 14, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 1, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 2, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 3, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 4, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 5, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 6, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 7, 1, 80, 3, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 8, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 9, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 10, 87, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 11, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 12, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 13, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 14, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 15, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 16, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522011302, 17, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 1, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 2, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 3, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 4, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 5, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 6, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302011303, 7, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 1, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 2, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 3, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 4, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 5, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 6, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 7, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 8, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423011304, 9, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 1, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 2, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 3, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 4, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 5, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 6, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 7, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704011305, 8, 27, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 1, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 2, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 3, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 4, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 5, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331011306, 6, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 1, 135, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 2, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 3, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 4, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 5, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 6, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 7, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 8, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 9, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 10, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080721011307, 11, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 1, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 2, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 3, 84, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 4, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 5, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 6, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 7, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 8, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 9, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 10, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060301011308, 11, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000528011309, 1, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000528011309, 2, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000528011309, 3, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704011310, 1, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704011310, 2, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704011310, 3, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704011310, 4, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704011310, 5, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208011311, 1, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208011311, 2, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208011311, 3, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208011311, 4, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 1, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 2, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 3, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 4, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 5, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 6, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 7, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 8, 108, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 9, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 10, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 11, 170, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 12, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 13, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 14, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217011312, 15, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 1, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 2, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 3, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 4, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 5, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 6, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 7, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 8, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 9, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 10, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 11, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 12, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 13, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 14, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 15, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 16, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011313, 17, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 1, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 2, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 3, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 4, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 5, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 6, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 7, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 8, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403011314, 9, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 1, 192, 51, 18, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 2, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 3, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 4, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 5, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 6, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 7, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 8, 101, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 9, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 10, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 11, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 12, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 13, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 14, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121215011315, 15, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 1, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 2, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 3, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 4, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 5, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 6, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129011316, 7, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 1, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 2, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 3, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 4, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 5, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 6, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 7, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 8, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 9, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 10, 81, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319011317, 11, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 1, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 2, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 3, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 4, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 5, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 6, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103011318, 7, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 1, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 2, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 3, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 4, 95, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 5, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 6, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112011319, 7, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716011320, 1, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716011320, 2, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716011320, 3, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716011320, 4, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010716011320, 5, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 1, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 2, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 3, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 4, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 5, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 6, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 7, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 8, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321011321, 9, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 1, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 2, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 3, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 4, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 5, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 6, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 7, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 8, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 9, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 10, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 11, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321011322, 12, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 10, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 11, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 12, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 13, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110702010189, 14, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010190, 1, 172, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010190, 2, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010190, 3, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628010190, 4, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513010191, 1, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513010191, 2, 167, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513010191, 3, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513010191, 4, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 1, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 2, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 3, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 4, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 5, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 6, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 7, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 8, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 9, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 10, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080501010192, 11, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 1, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 2, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 3, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 4, 122, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 5, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 6, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123010193, 7, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 1, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 2, 54, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 3, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 4, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 5, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 6, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224010194, 7, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 1, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 2, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 3, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 4, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 5, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 6, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 7, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 8, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 9, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070312010195, 10, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 1, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 2, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 3, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 4, 175, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 5, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 6, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 7, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809010196, 8, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 1, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 2, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 3, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 4, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 5, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 6, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 7, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 8, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 9, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 10, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 11, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 12, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 13, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 14, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 15, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120702010197, 16, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 1, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 2, 59, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 3, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 4, 192, 94, 18, 1692);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 5, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010198, 6, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 1, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 2, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 3, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 4, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 5, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 6, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 7, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 8, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 9, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 10, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 11, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 12, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 13, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103010199, 14, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 1, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 2, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 3, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 4, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 5, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 6, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 7, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301010200, 8, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 1, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 2, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 3, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 4, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 5, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 6, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 7, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 8, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 9, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 10, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 11, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 12, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101024010201, 13, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 1, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 2, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 3, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 4, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 5, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 6, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815010202, 7, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 1, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 2, 73, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 3, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 4, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 5, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 6, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 7, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 8, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624010203, 9, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 1, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 2, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 3, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 4, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 5, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 6, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 7, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 8, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 9, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 10, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 11, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 12, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031010204, 13, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 1, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 2, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 3, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 4, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 5, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 6, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 7, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 8, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 9, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 10, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 11, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 12, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 13, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 14, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 15, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227010205, 16, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618010206, 1, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618010206, 2, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618010206, 3, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618010206, 4, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020618010206, 5, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 1, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 2, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 3, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 4, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 5, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010207, 6, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 1, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 2, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 3, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 4, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 5, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 6, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 7, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 8, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 9, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 10, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 11, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 12, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 13, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 14, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 15, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120903010208, 16, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 1, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 2, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 3, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 4, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 5, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 6, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 7, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 8, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 9, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 10, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513010209, 11, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 1, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 2, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 3, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 4, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 5, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501010210, 6, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 1, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 2, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 3, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 4, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 5, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 6, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 7, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 8, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 9, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018010211, 10, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 1, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 2, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 3, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 4, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 5, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 6, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 7, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 8, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 9, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 10, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 11, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 12, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 13, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 14, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426010212, 15, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 1, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 2, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 3, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 4, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 5, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 6, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 7, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 8, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 9, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 10, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019010213, 11, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 1, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 2, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 3, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 4, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 5, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 6, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 7, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 8, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 9, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 10, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 11, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 12, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 13, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202010569, 14, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 1, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 2, 10, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 3, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 4, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 5, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 6, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 7, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 8, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 9, 43, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 10, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 11, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 12, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 13, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723010570, 14, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010571, 1, 20, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010571, 2, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605010571, 3, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 1, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 2, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 3, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 4, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 5, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 6, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 7, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 8, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 9, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 10, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 11, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813010572, 12, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414010573, 1, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414010573, 2, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 1, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 2, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 3, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 4, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 5, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 6, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 7, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 8, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 9, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 10, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 11, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 12, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 13, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 14, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705010574, 15, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 1, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 2, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 3, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 4, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 5, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 6, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 7, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 8, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 9, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 10, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 11, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 12, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 13, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091106010575, 14, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 1, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 2, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 3, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 4, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 5, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218010576, 6, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 1, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 2, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 3, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 4, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 5, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815010577, 6, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 1, 190, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 2, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 3, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 4, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 5, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 6, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 7, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 8, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 9, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 10, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 11, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 12, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 13, 185, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 14, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025010578, 15, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 1, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 2, 72, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 3, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 4, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 5, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 6, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 7, 157, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 8, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 9, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 10, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 11, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 12, 43, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 13, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108010579, 14, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 1, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 2, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 3, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 4, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 5, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 6, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 7, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 8, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 9, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 10, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 11, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207010580, 12, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 1, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 2, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 3, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 4, 25, 26, 6, 156);
commit;
prompt 116000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 5, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 6, 145, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 7, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 8, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 9, 126, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 10, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 11, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 12, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 13, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100215010581, 14, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 1, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 3, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 4, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 5, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 6, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 7, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 8, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 9, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 10, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 11, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 12, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 13, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 14, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 15, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120512010582, 16, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 1, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 2, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 3, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 4, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 5, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 6, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 7, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 8, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 9, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 10, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 11, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 12, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 13, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126010583, 14, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 1, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 2, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 3, 99, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 4, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 5, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 6, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 7, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 8, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 9, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 10, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 11, 1, 96, 3, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091231010584, 12, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 1, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 2, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 3, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 4, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 5, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 6, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 7, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 8, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 9, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 10, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 11, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 12, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 13, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 14, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 15, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218010585, 16, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 1, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 2, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 3, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 4, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 5, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 6, 39, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 7, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 8, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 9, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 10, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 11, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 12, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 13, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 14, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 15, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509010586, 16, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 1, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 2, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 3, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 4, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 5, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 6, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 7, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 8, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 9, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 10, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 11, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531010587, 12, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 1, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 2, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 3, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 4, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 5, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 6, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 7, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819010588, 8, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 1, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 2, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 3, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 4, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 5, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 5, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 6, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 7, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 8, 112, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 9, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 10, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 11, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 12, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 13, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 14, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 15, 181, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 16, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408010954, 17, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727010955, 1, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727010955, 2, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727010955, 3, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727010955, 4, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 1, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 2, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 3, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 4, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 5, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 6, 154, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 7, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 8, 41, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 9, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530010956, 10, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725010957, 1, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725010957, 2, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725010957, 3, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725010957, 4, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 1, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 2, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 3, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 4, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 5, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 6, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 7, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 8, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 9, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 10, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 11, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 12, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 13, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 14, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 15, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 16, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 17, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323010958, 18, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 1, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 2, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 3, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 4, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 5, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 6, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 7, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 8, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 9, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 10, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 11, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 12, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 13, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804010959, 14, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 1, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 2, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 3, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 4, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 5, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 6, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 7, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008010960, 8, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 1, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 2, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 3, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 4, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 5, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 6, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 7, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 8, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 9, 19, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 10, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 11, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 12, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 13, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 14, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 15, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 16, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 17, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131201010961, 18, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 1, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 2, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 3, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 4, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 5, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 6, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 7, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 8, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 9, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 10, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 11, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 12, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 13, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 14, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110010962, 15, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 1, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 2, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 3, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 4, 173, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 5, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 6, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 7, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 8, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 9, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 10, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 11, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 12, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 13, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110303010963, 14, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 1, 48, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 2, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 3, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 4, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 5, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 6, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 7, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 8, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 9, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 10, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 11, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 12, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520010964, 13, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729010965, 1, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729010965, 2, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729010965, 3, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729010965, 4, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020729010965, 5, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 1, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 2, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 3, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 4, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 5, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 6, 31, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016010966, 7, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 1, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 2, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 3, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 4, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 5, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 6, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 7, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 8, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 9, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 10, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 11, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 12, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 13, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091111010967, 14, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 1, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 2, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 3, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 4, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 5, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 6, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 7, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 8, 125, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 9, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 10, 141, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 11, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 12, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 13, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 14, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812010968, 15, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 1, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 2, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 3, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 4, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 5, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 6, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 7, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 8, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 9, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 10, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 11, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 12, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 13, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 14, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105010969, 15, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 1, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 2, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 3, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 4, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 5, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 6, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 7, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 8, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 9, 56, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 10, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 11, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 12, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 13, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 14, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110103010970, 15, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 1, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 2, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 3, 126, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 4, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 5, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 6, 119, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 7, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 8, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 9, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 10, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 11, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 12, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231010971, 13, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 1, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 2, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 3, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 4, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 5, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 6, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 7, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 8, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 9, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 10, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 11, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 12, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 13, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 14, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 15, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430010972, 16, 144, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010973, 1, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010973, 2, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004010973, 3, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 1, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 2, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 3, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 4, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 5, 22, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026011323, 1, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026011323, 2, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026011323, 3, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026011323, 4, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 1, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 2, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 3, 91, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 4, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 5, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 6, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 7, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 8, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 9, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 10, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011324, 11, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 1, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 2, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 3, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 4, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 5, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 6, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 7, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 8, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 9, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 10, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 11, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 12, 108, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710011325, 13, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 1, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 2, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 3, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 4, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 5, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 6, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 7, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 8, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120011326, 9, 98, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 1, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 2, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 3, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 4, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 5, 47, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 6, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 7, 177, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 8, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 9, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 10, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 11, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 12, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 13, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100419011327, 14, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 1, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 2, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 3, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 4, 185, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 5, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 6, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 7, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 8, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 9, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 10, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 11, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 12, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 13, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 14, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 15, 88, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120915011328, 16, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115011329, 1, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115011329, 2, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115011329, 3, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000115011329, 4, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 1, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 2, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 3, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 4, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 5, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 6, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 7, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 8, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 9, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 10, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 11, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 12, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 13, 98, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 14, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 15, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 16, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011330, 17, 161, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 1, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 2, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 3, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 4, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 5, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 6, 172, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 7, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 8, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 9, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 10, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 11, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 12, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 13, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 14, 71, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 15, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131107011331, 16, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110011332, 1, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110011332, 2, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110011332, 3, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110011332, 4, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110011332, 5, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000427011333, 1, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000427011333, 2, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130011334, 1, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130011334, 2, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130011334, 3, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 1, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 2, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 3, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 4, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 5, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 6, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 7, 124, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 8, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 9, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 10, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526011335, 11, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011336, 1, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011336, 2, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011336, 3, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011336, 4, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214011337, 1, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214011337, 2, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214011337, 3, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214011337, 4, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 1, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 2, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 3, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 4, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 5, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 6, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 7, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 8, 115, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 9, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060227011338, 10, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 1, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 2, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 3, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 4, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 5, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 6, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 7, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 8, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 9, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 10, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 11, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 12, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 13, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 14, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111006011339, 15, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 1, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 2, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 3, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 4, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 5, 4, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 6, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 7, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 8, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 9, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 10, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 11, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 12, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 13, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 14, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 15, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130011340, 16, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 1, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 2, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 3, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 4, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 5, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 6, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 7, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 8, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 9, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324011341, 10, 113, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 1, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 2, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 3, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 4, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 5, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 6, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 7, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 8, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 9, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 10, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 11, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 12, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 13, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 14, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916011342, 15, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 1, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 2, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 3, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 4, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 5, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 6, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 7, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 8, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 9, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 10, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 11, 14, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 12, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 13, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 14, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 15, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203011343, 16, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 1, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 2, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 3, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 4, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 5, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 6, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 7, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 8, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 9, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 10, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 11, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 12, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210011344, 13, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 1, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 2, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 3, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 4, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 5, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809011345, 6, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 1, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 2, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 3, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 4, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 5, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 2, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 3, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 4, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 5, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 6, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 7, 126, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 8, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 9, 1, 6, 3, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 10, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 11, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 12, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 13, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 14, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 15, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 16, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024010214, 17, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 1, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 2, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 3, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 4, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 5, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 6, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 7, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 8, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 9, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 10, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 11, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006010215, 12, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 1, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 2, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 3, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 4, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 5, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 6, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 7, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 8, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 9, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 10, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 11, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 12, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 13, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 14, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 15, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 16, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120226010216, 17, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010217, 1, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010217, 2, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010217, 3, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214010217, 4, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 1, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 2, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 3, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 4, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 5, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 6, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 7, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 8, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 9, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 10, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 11, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 12, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 13, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120010218, 14, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527010219, 1, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527010219, 2, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527010219, 3, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116010220, 1, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116010220, 2, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116010220, 3, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 1, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 2, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 3, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 4, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 5, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 6, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 7, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 8, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 9, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 10, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 11, 14, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 12, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404010221, 13, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 1, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 2, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 3, 135, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 4, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 5, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 6, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 7, 189, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 8, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 9, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 10, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 11, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 12, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 13, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 14, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 15, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 16, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 17, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131029010222, 18, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 1, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 2, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 3, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 4, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 5, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 6, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 7, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 8, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 9, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 10, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 11, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 12, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 13, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 14, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312010223, 15, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 1, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 2, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 3, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 4, 67, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 5, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430010224, 6, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 1, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 2, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 3, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 4, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 5, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 6, 146, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040418010225, 7, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 1, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 2, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 3, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 4, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 5, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 6, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 7, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 8, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 9, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 10, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070730010226, 11, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 1, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 2, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 3, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 4, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 5, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 6, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 7, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030329010227, 8, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 1, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 2, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 3, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 4, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 5, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 6, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 7, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 8, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 9, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 10, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 11, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 12, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 13, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128010228, 14, 180, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 1, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 2, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 3, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 4, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 5, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 6, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 7, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 8, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 9, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 10, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 11, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 12, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 13, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 14, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130116010229, 15, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 1, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 2, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 3, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 4, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 5, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 6, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 7, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 8, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 9, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 10, 110, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 11, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080713010230, 12, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 1, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 2, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 3, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 4, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 5, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 6, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 7, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 8, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 9, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707010231, 10, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001104010232, 1, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001104010232, 2, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621010233, 1, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621010233, 2, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621010233, 3, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 1, 63, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 2, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 3, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 4, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 5, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 6, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040620010234, 7, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 1, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 2, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 3, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 4, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 5, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 6, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313010235, 7, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 1, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 2, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 3, 135, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 4, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 5, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 6, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 7, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 8, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 9, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 10, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 11, 111, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003010236, 12, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627010237, 1, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627010237, 2, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627010237, 3, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627010237, 4, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627010237, 5, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 1, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 2, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 3, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 4, 169, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 5, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 6, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 7, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806010589, 8, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125010590, 1, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125010590, 2, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125010590, 3, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125010590, 4, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 1, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 2, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 3, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 4, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 5, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 6, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 7, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 8, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 9, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 10, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 11, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 12, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 13, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 14, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 15, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 16, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140223010591, 17, 1, 31, 3, 93);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 1, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 2, 72, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 3, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 4, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 5, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 6, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 7, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 8, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 9, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 10, 120, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 11, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 12, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706010592, 13, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 1, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 2, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 3, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 4, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 5, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 6, 30, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 7, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 8, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 9, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 10, 177, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204010593, 11, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 1, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 2, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 3, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 4, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 5, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 6, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 7, 155, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605010594, 8, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 1, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 2, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 3, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 4, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 5, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 6, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 7, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060428010595, 8, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 1, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 2, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 3, 180, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 4, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 5, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 6, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 7, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 8, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 9, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 10, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218010596, 11, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 1, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 2, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 3, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 4, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 5, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 6, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 7, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 8, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 9, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 10, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 11, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 12, 48, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 13, 136, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 14, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620010597, 15, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130010598, 1, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130010598, 2, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130010598, 3, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 1, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 2, 137, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 3, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 4, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 5, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 6, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 7, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 8, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 9, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 10, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 11, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 12, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111010599, 13, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 1, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 2, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 3, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 4, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 5, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 6, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 7, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 8, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 9, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 10, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 11, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 12, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 13, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 14, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 15, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 16, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131030010600, 17, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 1, 65, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 2, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 3, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 4, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 5, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 6, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 7, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 8, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823010601, 9, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411010602, 1, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411010602, 2, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411010602, 3, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411010602, 4, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 1, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 2, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 3, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 4, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 5, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 6, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020720010603, 7, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 1, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 2, 5, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 3, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 4, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 5, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 6, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 7, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 8, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 9, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601010604, 10, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514010605, 1, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514010605, 2, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 1, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 2, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 3, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 4, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 5, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219010606, 6, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 1, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 2, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 3, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 4, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 5, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 6, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 7, 84, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 8, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 9, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 10, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 11, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 12, 15, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 13, 61, 44, 11, 484);
commit;
prompt 117000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 14, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 15, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 16, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317010607, 17, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822010608, 1, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822010608, 2, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822010608, 3, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 1, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 2, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 3, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 4, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 5, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 6, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 7, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 8, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 9, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 10, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 11, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 12, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010010609, 13, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106010610, 1, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106010610, 2, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106010610, 3, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106010610, 4, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106010610, 5, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 1, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 2, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 3, 192, 57, 18, 1026);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 4, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 5, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 6, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 7, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 8, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 9, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 10, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 11, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205010611, 12, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 1, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 2, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 3, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 4, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 5, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 6, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 7, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 8, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820010612, 9, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 1, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 2, 79, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 3, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 4, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 5, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 6, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 7, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 8, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 9, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 10, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 11, 177, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 12, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090416010613, 13, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 1, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 2, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 3, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 4, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 5, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031113010614, 6, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010615, 1, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 6, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 7, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 8, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 9, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 10, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 11, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 12, 140, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430010974, 13, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 1, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 2, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 3, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 4, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 5, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 6, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 7, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 8, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 9, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 10, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 11, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519010975, 12, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 1, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 2, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 3, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 4, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 5, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 6, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 7, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 8, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 9, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 10, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 11, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 12, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 13, 44, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 14, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 15, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329010976, 16, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 1, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 2, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 3, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 4, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 5, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 6, 170, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 7, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 8, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 9, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 10, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 11, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 12, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 13, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 14, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422010977, 15, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 1, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 2, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 3, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 4, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 5, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 6, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 7, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 8, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 9, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 10, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090206010978, 11, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 1, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 2, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 3, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 4, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 5, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030303010979, 6, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 1, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 2, 101, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 3, 190, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 4, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 5, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 6, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 7, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 8, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 9, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 10, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 11, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 12, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 13, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 14, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 15, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 16, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230010980, 17, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 1, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 2, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 3, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 4, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 5, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 6, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 7, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 8, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 9, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 10, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 11, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221010981, 12, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 1, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 2, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 3, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 4, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 5, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 6, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 7, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 8, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 9, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 10, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 11, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 12, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 13, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 14, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 15, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 16, 81, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 17, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725010982, 18, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 1, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 2, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 3, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 4, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 5, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 6, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 7, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 8, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 9, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 10, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 11, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 12, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 13, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 14, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904010983, 15, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 1, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 2, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 3, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 4, 30, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 5, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 6, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 7, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 8, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 9, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 10, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 11, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 12, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 13, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111102010984, 14, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 1, 65, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 2, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 3, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 4, 28, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 5, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 6, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 7, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313010985, 8, 108, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 1, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 2, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 3, 134, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 4, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 5, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 6, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 7, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 8, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 9, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 10, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 11, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 12, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 13, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091216010986, 14, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 1, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 2, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 3, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 4, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 5, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 6, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 7, 187, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 8, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 9, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070518010987, 10, 171, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 1, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 2, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 3, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 4, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 5, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 6, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 7, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 8, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 9, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 10, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 11, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 12, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 13, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 14, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 15, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131105010988, 16, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023010989, 1, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023010989, 2, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023010989, 3, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023010989, 4, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023010989, 5, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 1, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 2, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 3, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 4, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 5, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 6, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 7, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 8, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 9, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 10, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 11, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 12, 45, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601010990, 13, 51, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 1, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 2, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 3, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 4, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 5, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020911010991, 6, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 1, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 2, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 3, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 4, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 5, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020010992, 6, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010993, 1, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010993, 2, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010993, 3, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119010993, 4, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711010994, 1, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711010994, 2, 63, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711010994, 3, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711010994, 4, 166, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020711010994, 5, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 1, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 2, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 3, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 4, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 5, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120010995, 6, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 1, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217010996, 2, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 6, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 7, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 8, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926011346, 9, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 1, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 2, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 3, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 4, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 5, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805011347, 6, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 1, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 2, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 3, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 4, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 5, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 6, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 7, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821011348, 8, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913011349, 1, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913011349, 2, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913011349, 3, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913011349, 4, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 1, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 2, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 3, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 4, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 5, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 6, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 7, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 8, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 9, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 10, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 11, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 12, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 13, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 14, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829011350, 15, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 1, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 2, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 3, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 4, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 5, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 6, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 7, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903011351, 8, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 1, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 2, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 3, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 4, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 5, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 6, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 7, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 8, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 9, 168, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 10, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070430011352, 11, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 1, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 2, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 3, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 4, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 5, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 6, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 7, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 8, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 9, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 10, 64, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 11, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 12, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 13, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 14, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 15, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130505011353, 16, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 1, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 2, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 3, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 4, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 5, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227011354, 6, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 1, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 2, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 3, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 4, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 5, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 6, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 7, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 8, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 9, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011355, 10, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 1, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 2, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 3, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 4, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 5, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 6, 178, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 7, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 8, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 9, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 10, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 11, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 12, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 13, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 14, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 15, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424011356, 16, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 1, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 2, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 3, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 4, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 5, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 6, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 7, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 8, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071210011357, 9, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 1, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 2, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 3, 108, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 4, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 5, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 6, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 7, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 8, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 9, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 10, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 11, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 12, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100214011358, 13, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 1, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 2, 38, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 3, 122, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 4, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 5, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 6, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 7, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 8, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 9, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 10, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 11, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507011359, 12, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 1, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 2, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 3, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 4, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 5, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 6, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 7, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 8, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 9, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011011360, 10, 174, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 1, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 2, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 3, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 4, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 5, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 6, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 7, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 8, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612011361, 9, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 1, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 2, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 3, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 4, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 5, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 6, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 7, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 8, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702011362, 9, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223011363, 1, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223011363, 2, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223011363, 3, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223011363, 4, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001223011363, 5, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 1, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 2, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 3, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 4, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 5, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 6, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 7, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 8, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411011364, 9, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 1, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 2, 82, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 3, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 4, 87, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 5, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 6, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 7, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 8, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 9, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 10, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 11, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 12, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 13, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 14, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 15, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412011365, 16, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317011366, 1, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317011366, 2, 120, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317011366, 3, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317011366, 4, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317011366, 5, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 1, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 2, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 3, 24, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 4, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 5, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 6, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 7, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 8, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 9, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 10, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 11, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 12, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 13, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 14, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406011367, 15, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 1, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 2, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 3, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 4, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 5, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 6, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 7, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060317011368, 8, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 1, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 2, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 3, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 4, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 5, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 6, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 7, 109, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 8, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 9, 175, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 10, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 11, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 12, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 13, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531011369, 14, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060920011370, 1, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 6, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 7, 109, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 8, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 9, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 10, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 11, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 12, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 13, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 14, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 15, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 16, 169, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 17, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 18, 115, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318010238, 19, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 1, 35, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 2, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 3, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 4, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 5, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 6, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 7, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 8, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219010239, 9, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 1, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 2, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 3, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 4, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 5, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 6, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 7, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 8, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 9, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 10, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 11, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 12, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 13, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 14, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120010240, 15, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 1, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 2, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 3, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 4, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 5, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902010241, 6, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705010242, 1, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705010242, 2, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705010242, 3, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705010242, 4, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020705010242, 5, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 1, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 2, 189, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 3, 189, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 4, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 5, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 6, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 7, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 8, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 9, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511010243, 10, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225010244, 1, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225010244, 2, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225010244, 3, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225010244, 4, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225010244, 5, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 1, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 2, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 3, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 4, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 5, 86, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 6, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 7, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 8, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 9, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 10, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 11, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301010245, 12, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 1, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 2, 92, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 3, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 4, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 5, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 6, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 7, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 8, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 9, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003010246, 10, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 1, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 2, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 3, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 4, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 5, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 6, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 7, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825010247, 8, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 1, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 2, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 3, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 4, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 5, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 6, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926010248, 7, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010249, 1, 191, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010249, 2, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010249, 3, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011225010249, 4, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 1, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 2, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 3, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 4, 30, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 5, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112010250, 6, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 1, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 2, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 3, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 4, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 5, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010127010251, 6, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913010252, 1, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913010252, 2, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913010252, 3, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913010252, 4, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 1, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 2, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 3, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 4, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 5, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 6, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322010253, 7, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911010254, 1, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911010254, 2, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911010254, 3, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 1, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 2, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 3, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 4, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 5, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 6, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501010255, 7, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 1, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 2, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 3, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 4, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 5, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 6, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 7, 154, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 8, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915010256, 9, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 1, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 2, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 3, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 4, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 5, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 6, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 7, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 8, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 9, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 10, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 11, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 12, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090521010257, 13, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 1, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 2, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 3, 132, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 4, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 5, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 6, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 7, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 8, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 9, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 10, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 11, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 12, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 13, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 14, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929010258, 15, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201010259, 1, 48, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201010259, 2, 187, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201010259, 3, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201010259, 4, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 1, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 2, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 3, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 4, 149, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 5, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 6, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413010260, 7, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 1, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 2, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 3, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 4, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 5, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 6, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 7, 189, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 8, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 9, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 10, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 11, 110, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 12, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 13, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 14, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 15, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 16, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 17, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 18, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140405010261, 19, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009010262, 1, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009010262, 2, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009010262, 3, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009010262, 4, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009010262, 5, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 1, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 2, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 3, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 4, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 5, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 6, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 7, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 8, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 9, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 10, 147, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 11, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 12, 27, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 13, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 14, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 15, 171, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131113010263, 16, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 1, 60, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 2, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 3, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 4, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 5, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 6, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 7, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 8, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 9, 165, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 10, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 11, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090208010264, 12, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025010265, 1, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010615, 2, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010615, 3, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010615, 4, 107, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617010615, 5, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 1, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 2, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 3, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 4, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 5, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 6, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 7, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 8, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 9, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 10, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 11, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004010616, 12, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 1, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 2, 15, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 3, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 4, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 5, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 6, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 7, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 8, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 9, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907010617, 10, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 1, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 2, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 3, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 4, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 5, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 6, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 7, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 8, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 9, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 10, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 11, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708010618, 12, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126010619, 1, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126010619, 2, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126010619, 3, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001126010619, 4, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 1, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 2, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 3, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 4, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 5, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 6, 47, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 7, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 8, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 9, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 10, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103010620, 11, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103010621, 1, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103010621, 2, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103010621, 3, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 1, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 2, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 3, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 4, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 5, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 6, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 7, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 8, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 9, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 10, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 11, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 12, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 13, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 14, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 15, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802010622, 16, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 1, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 2, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 3, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 4, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 5, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825010623, 6, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001010624, 1, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001010624, 2, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923010625, 1, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923010625, 2, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923010625, 3, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010923010625, 4, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 1, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 2, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 3, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 4, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 5, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 6, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 7, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 8, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 9, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050906010626, 10, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304010627, 1, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304010627, 2, 72, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304010627, 3, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 1, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 2, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 3, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 4, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 5, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 6, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 7, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 8, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 9, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 10, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 11, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 12, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100209010628, 13, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 1, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 2, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 3, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 4, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 5, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413010629, 6, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 1, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 2, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 3, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 4, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 5, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 6, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 7, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 8, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 9, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 10, 8, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 11, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 12, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 13, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 14, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627010630, 15, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 1, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 2, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 3, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 4, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 5, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 6, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127010631, 7, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 1, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 2, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 3, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 4, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 5, 44, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 6, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 7, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 8, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 9, 144, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 10, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301010632, 11, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323010633, 1, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323010633, 2, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323010633, 3, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323010633, 4, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030323010633, 5, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 1, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 2, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 3, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 4, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 5, 9, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030511010634, 6, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 1, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 2, 91, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 3, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 4, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 5, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 6, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 7, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 8, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 9, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 10, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 11, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 12, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 13, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 14, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408010635, 15, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 1, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 2, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 3, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 4, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 5, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 6, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 7, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 8, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 9, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 10, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 11, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 12, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 13, 100, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 14, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 15, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 16, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 17, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131228010636, 18, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 1, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 2, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 3, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 4, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 5, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 6, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 7, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 8, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 9, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 10, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 11, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 12, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 13, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 14, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 15, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130528010637, 16, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 1, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 2, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 3, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 4, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 5, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 6, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 7, 191, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 8, 144, 33, 15, 495);
commit;
prompt 118000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 9, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 10, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 11, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 12, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 13, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 14, 101, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 15, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303010638, 16, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 1, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 2, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 3, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 4, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 5, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 6, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 7, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 8, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 9, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 10, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 11, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 12, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 13, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426010639, 14, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 2, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 3, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 4, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 5, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 6, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 7, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 8, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 9, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 10, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 11, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 12, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 13, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 14, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 15, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 16, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 17, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120012138, 1, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120012138, 2, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120012138, 3, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120012138, 4, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120012138, 5, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520012139, 1, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520012139, 2, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520012139, 3, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520012139, 4, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 1, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 2, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 3, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 4, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 5, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 6, 190, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 7, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 8, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 9, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 10, 145, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 11, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 12, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 13, 108, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 14, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 15, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504012140, 16, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230012141, 1, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230012141, 2, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230012141, 3, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230012141, 4, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230012141, 5, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 1, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 2, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 3, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 4, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 5, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 6, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 7, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 8, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609012142, 9, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 1, 185, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 2, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 3, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 4, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 5, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 6, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 7, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 8, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 9, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 10, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 11, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 12, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 13, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 14, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 15, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012143, 16, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 1, 15, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 2, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 3, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 4, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 5, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 6, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 7, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926012144, 8, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607012145, 1, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607012145, 2, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607012145, 3, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607012145, 4, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607012145, 5, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 1, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 2, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 3, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 4, 129, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 5, 163, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 6, 167, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 7, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218012146, 8, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 1, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 2, 77, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 3, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 4, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 5, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 6, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 7, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 8, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 9, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012147, 10, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 1, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 2, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 3, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 4, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 5, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 6, 192, 55, 18, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 7, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727012148, 8, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 1, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 2, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 3, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 4, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 5, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 6, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 7, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 8, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 9, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 10, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 11, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 12, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 13, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 14, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 15, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 16, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007012149, 17, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 1, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 2, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 3, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 4, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 5, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 6, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 7, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 8, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 9, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 10, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 11, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 12, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 13, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209012150, 14, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 1, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 2, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 3, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 4, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 5, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 6, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 7, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 8, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 9, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 10, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 11, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 12, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 13, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110221012151, 14, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 1, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 2, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 3, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 4, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 5, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 6, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 7, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 8, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 9, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 10, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 11, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012152, 12, 119, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 1, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 2, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 3, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 4, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 5, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 6, 76, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 7, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 8, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 9, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 10, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 11, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 12, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923012153, 13, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 1, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 2, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 3, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 4, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 5, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 6, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 7, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 8, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 9, 51, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 10, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 11, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 12, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 13, 2, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 14, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 15, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 16, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130509012154, 17, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 1, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 2, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 3, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 4, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 5, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 6, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 7, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 8, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 9, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 10, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 11, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 12, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 13, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117012155, 14, 105, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 1, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 2, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 3, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 4, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 5, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 6, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 7, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 8, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 9, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 10, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 11, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091206012156, 12, 38, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 1, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 2, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 3, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 4, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 5, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 6, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 7, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 8, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 9, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 10, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 11, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070403012157, 12, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012158, 1, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012158, 2, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012158, 3, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 1, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 3, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 4, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 5, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 6, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 7, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 8, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 9, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 10, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 11, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 12, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 13, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 14, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012504, 1, 27, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012504, 2, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012504, 3, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012504, 4, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 1, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 2, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 3, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 4, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 5, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012505, 6, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 1, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 2, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 3, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 4, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 5, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 6, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 7, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 8, 91, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 9, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 10, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 11, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 12, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 13, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620012506, 14, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 1, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 2, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 3, 66, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 4, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 5, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 6, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012507, 7, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 1, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 2, 109, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 3, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 4, 71, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 5, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 6, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 7, 18, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 8, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 9, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 10, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 11, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 12, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 13, 3, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329012508, 14, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 1, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 2, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 3, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 4, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 5, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 6, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 7, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 8, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 9, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 10, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 11, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 12, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 13, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201012509, 14, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 1, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 2, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 3, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 4, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 5, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 6, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 7, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015012510, 8, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 1, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 2, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 3, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 4, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 5, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 6, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040130012511, 7, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 1, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 2, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 3, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 4, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 5, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 6, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 7, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 8, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 9, 97, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 10, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 11, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 12, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725012512, 13, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 1, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 2, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 3, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 4, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 5, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 6, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 7, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 8, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 9, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 10, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 11, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 12, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003012513, 13, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 1, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 2, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 3, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 4, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 5, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 6, 128, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 7, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 8, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922012514, 9, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 1, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 2, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 3, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 4, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 5, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 6, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129012515, 7, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 1, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 2, 46, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 3, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 4, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 5, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 6, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040807012516, 7, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 1, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 2, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 3, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 4, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 5, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 6, 183, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 7, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 8, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 9, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 10, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 11, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 12, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 13, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 14, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121231012517, 15, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 1, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 2, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 3, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 4, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 5, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 6, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 7, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 8, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 9, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 10, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 11, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 12, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 13, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808012518, 14, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 1, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 2, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 3, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 4, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 5, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 6, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 7, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 8, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 9, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 10, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 11, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 12, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308012519, 13, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 1, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 2, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 3, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 4, 64, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 5, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 6, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 7, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 8, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 9, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 10, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 11, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 12, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104012520, 13, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 1, 185, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 2, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 3, 131, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 4, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 5, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 6, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 7, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 8, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 9, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 10, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 11, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 12, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 13, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 14, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 15, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 16, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131203012521, 17, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 1, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 2, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 3, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 4, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 5, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 6, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 7, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 8, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 9, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 10, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 11, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 12, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 13, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110110012522, 14, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 1, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 2, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 3, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 4, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 5, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218012523, 6, 122, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 1, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 2, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 3, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 4, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 5, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 6, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 7, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 8, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 9, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 10, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 11, 101, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 12, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 7, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 8, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 9, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 10, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 11, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 12, 88, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 1, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 2, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 3, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 4, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 5, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 6, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529012876, 7, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 1, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 2, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 3, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 4, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 5, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 6, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 7, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 8, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 9, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 10, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070409012877, 11, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 2, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 3, 192, 20, 18, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 4, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 5, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 6, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508012878, 7, 162, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 1, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 2, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 3, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 4, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 5, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 6, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 7, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815012879, 8, 10, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219012880, 1, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219012880, 2, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219012880, 3, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219012880, 4, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219012880, 5, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 1, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 2, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 3, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 4, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 5, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 6, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 7, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 8, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 9, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 10, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 11, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 12, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126012881, 13, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 1, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 2, 153, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 3, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 4, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 5, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 6, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 7, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 8, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 9, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071230012882, 10, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 1, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 2, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 3, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 4, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 5, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 6, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 7, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 8, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 9, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070717012883, 10, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 1, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 2, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 3, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 4, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 5, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 6, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 7, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 8, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 9, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 10, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070401012884, 11, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 1, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 2, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 3, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 4, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 5, 102, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 6, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 7, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 8, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 9, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 10, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304012885, 11, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 1, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 2, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 3, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 4, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 5, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 6, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 7, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012886, 8, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926012887, 1, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926012887, 2, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926012887, 3, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012888, 1, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012888, 2, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012888, 3, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 1, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 2, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 3, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 4, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 5, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 6, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 7, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 8, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 9, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 10, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 11, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 12, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 13, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 14, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 15, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204012889, 16, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 1, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 2, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 3, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 4, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 5, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 6, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 7, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 8, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 9, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 10, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630012890, 11, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 1, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 2, 1, 44, 3, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 3, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 4, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 5, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505012891, 6, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 1, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 2, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 3, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 4, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 5, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 6, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 7, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061009012892, 8, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203012893, 1, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203012893, 2, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203012893, 3, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203012893, 4, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 1, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 2, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 3, 105, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 4, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 5, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 6, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 7, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 8, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 9, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012894, 10, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 1, 80, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 2, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 3, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 4, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 5, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 6, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 7, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 8, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050823012895, 9, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510012896, 1, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510012896, 2, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510012896, 3, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510012896, 4, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 1, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 2, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 3, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 4, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 5, 59, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 6, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 7, 171, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 8, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 9, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 10, 135, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 11, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 12, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 13, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 14, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 15, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615012897, 16, 101, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 1, 67, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 2, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 3, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 4, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 5, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 6, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 7, 165, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 8, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 9, 3, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 10, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 11, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 12, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 13, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 14, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906012898, 15, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 1, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 2, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 3, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 4, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 5, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 6, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 7, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 8, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 9, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 10, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 11, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 12, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 13, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 14, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 15, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130917012899, 16, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 1, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 2, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 3, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 4, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 5, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 6, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 7, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 8, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 9, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 10, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 11, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 12, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 7, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 8, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 9, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 10, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 11, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 12, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 13, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 14, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 15, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 1, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 2, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 3, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 4, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 5, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 6, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 7, 153, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 8, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 9, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 10, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 11, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 12, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 13, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 14, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 15, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108011759, 16, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 1, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 2, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 3, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 4, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 5, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 6, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 7, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 8, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040118011760, 9, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 1, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 2, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 3, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 4, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 5, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 6, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 7, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 8, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 9, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 10, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 11, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 12, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226011761, 13, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 1, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 2, 10, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 3, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 4, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 5, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011762, 6, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 1, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 2, 94, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 3, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 4, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 5, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 6, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 7, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 8, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 9, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 10, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 11, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 12, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 13, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 14, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 15, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 16, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 17, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121011763, 18, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 1, 97, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 2, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 3, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 4, 169, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 5, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 6, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 7, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 8, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 9, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 10, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 11, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 12, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 13, 189, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 14, 44, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 15, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 16, 97, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 17, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122011764, 18, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 1, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 2, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 3, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 4, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 5, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 6, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 7, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 8, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 9, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 10, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 11, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 12, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011765, 13, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 1, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 2, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 3, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 4, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 5, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 6, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 7, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 8, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 9, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 10, 178, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 11, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 12, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 13, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 14, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111226011766, 15, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005011767, 1, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005011767, 2, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005011767, 3, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005011767, 4, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001005011767, 5, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 1, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 2, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 3, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 4, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 5, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 6, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 7, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040705011768, 8, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403011769, 1, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403011769, 2, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403011769, 3, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403011769, 4, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 1, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 2, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 3, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 4, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 5, 165, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021026011770, 6, 109, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222011771, 1, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222011771, 2, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222011771, 3, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222011771, 4, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 1, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 2, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 4, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 5, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 6, 175, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 7, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 8, 23, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 9, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 10, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 11, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 12, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 13, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 14, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115011772, 15, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 1, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 2, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 3, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 4, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 5, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 6, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 7, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 8, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 9, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 10, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 11, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 12, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811011773, 13, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 1, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 2, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 3, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 4, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 5, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 6, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 7, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 8, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 9, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 10, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 11, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 12, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 13, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100611011774, 14, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 1, 132, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 2, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 3, 88, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 4, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 5, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 6, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 7, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 8, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050228011775, 9, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011776, 1, 181, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011776, 2, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011776, 3, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011776, 4, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117011777, 1, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117011777, 2, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117011777, 3, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000117011777, 4, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 1, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 2, 44, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 3, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 4, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 5, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 6, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 7, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 8, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 9, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 10, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 11, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 12, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 13, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229011778, 14, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 1, 179, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 2, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 3, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 4, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 5, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 6, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 7, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925011779, 8, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501011780, 1, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501011780, 2, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501011780, 3, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501011780, 4, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030501011780, 5, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 1, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 2, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 3, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 4, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 5, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 6, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 7, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 8, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 9, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 2, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 3, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 4, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 5, 125, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 6, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 7, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 8, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 9, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 10, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 11, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 12, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808012159, 13, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 1, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 2, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 3, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 4, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 5, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 6, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 7, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 8, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520012160, 9, 73, 39, 6, 234);
commit;
prompt 119000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 1, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 2, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 3, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 4, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 5, 20, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 6, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 7, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030115012161, 8, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 1, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 2, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 3, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 4, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 5, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 6, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 7, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 8, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 9, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 10, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914012162, 11, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629012163, 1, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629012163, 2, 146, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629012163, 3, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629012163, 4, 47, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629012163, 5, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 1, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 2, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 3, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 4, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 5, 190, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 6, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 7, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 8, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 9, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080805012164, 10, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 1, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 2, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 3, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 4, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 5, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 6, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 7, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 8, 37, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 9, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 10, 117, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 11, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 12, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 13, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 14, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012165, 15, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 1, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 2, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 3, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 4, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 5, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901012166, 6, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722012167, 1, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722012167, 2, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722012167, 3, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 1, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 2, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 3, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 4, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 5, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 6, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 7, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 8, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 9, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 10, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 11, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211012168, 12, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 1, 1, 97, 3, 291);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 2, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 3, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 4, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 5, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 6, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 7, 138, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 8, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504012169, 9, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 1, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 2, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 3, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 4, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 5, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 6, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 7, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 8, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 9, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 10, 29, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070424012170, 11, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 1, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 2, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 3, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 4, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 5, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 6, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 7, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 8, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040923012171, 9, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 1, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 2, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 3, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 4, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 5, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 6, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 7, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 8, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 9, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129012172, 10, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 1, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 2, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 3, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 4, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 5, 167, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 6, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 7, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 8, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 9, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061128012173, 10, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 1, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 2, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 3, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 4, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 5, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 6, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 7, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 8, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 9, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080202012174, 10, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 1, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 2, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 3, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 4, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 5, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905012175, 6, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 1, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 2, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 3, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 4, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 5, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 6, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 7, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 8, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 9, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 10, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 11, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 12, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 13, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 14, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 15, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110628012176, 16, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 1, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 2, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 3, 181, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 4, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 5, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 6, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040717012177, 7, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 1, 73, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 2, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 3, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 4, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 5, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 6, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 7, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 8, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 9, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 10, 74, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 11, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 12, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207012178, 13, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 1, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 2, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 3, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 4, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 5, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 6, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 7, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 8, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012179, 9, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 1, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 2, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 3, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 4, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 5, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 6, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629012180, 7, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 1, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 2, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 3, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 4, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 5, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 6, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 7, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 8, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 9, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 10, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 11, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 12, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 13, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 14, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 15, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 16, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403012181, 17, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 1, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 2, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 3, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 4, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 5, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 6, 3, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524012182, 7, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 1, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 2, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 3, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 4, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 5, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 6, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050530012183, 7, 42, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702012524, 13, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 1, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 2, 186, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 3, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 4, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 5, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610012525, 6, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 1, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 2, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 3, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 4, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 5, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 6, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 7, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 8, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218012526, 9, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 1, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 2, 87, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 3, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 4, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 5, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 6, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 7, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040729012527, 8, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 1, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 2, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 3, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 4, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 5, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 6, 58, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 7, 129, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 8, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012528, 9, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006012529, 1, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006012529, 2, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006012529, 3, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006012529, 4, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 1, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 2, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 3, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 4, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 5, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 6, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 7, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 8, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 9, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 10, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 11, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 12, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 13, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 14, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 15, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625012530, 16, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 1, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 2, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 3, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 4, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 5, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 6, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012531, 7, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 1, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 2, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 3, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 4, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 5, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 6, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 7, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118012532, 8, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 1, 109, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 2, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 3, 1, 44, 3, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 4, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 5, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 6, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 7, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 8, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 9, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 10, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 11, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 12, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302012533, 13, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704012534, 1, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704012534, 2, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704012534, 3, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704012534, 4, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704012534, 5, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 1, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 2, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 3, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 4, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 5, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 6, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 7, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831012535, 8, 57, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 1, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 2, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 3, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 4, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 5, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012536, 6, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 1, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 2, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 3, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 4, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 5, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 6, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 7, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 8, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 9, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 10, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 11, 150, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 12, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 13, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 14, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 15, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120514012537, 16, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 1, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 2, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 3, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 4, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 5, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 6, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 7, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 8, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 9, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731012538, 10, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 1, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 2, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 3, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 4, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 5, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 6, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 7, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 8, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 9, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 10, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 11, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310012539, 12, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 1, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 2, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 3, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 4, 51, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 5, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 6, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 7, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 8, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 9, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 10, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 11, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 12, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530012540, 13, 99, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 1, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 2, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 3, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 4, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 5, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 6, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 7, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 8, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 9, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 10, 88, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 11, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 12, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 13, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 14, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 15, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120205012541, 16, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 1, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 2, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 3, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 4, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 5, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008012542, 6, 149, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 1, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 2, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 3, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 4, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 5, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 6, 58, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 7, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 8, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 9, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 10, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 11, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 12, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 13, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 14, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 15, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 16, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121007012543, 17, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 1, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 2, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 3, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 4, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 5, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 6, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 7, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012544, 8, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 1, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 2, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 3, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 4, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 5, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 6, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 7, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 8, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 9, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 10, 186, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 11, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 12, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 13, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 14, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012545, 15, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 1, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 2, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 3, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 4, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 5, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 6, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 7, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 8, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 9, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 10, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 11, 34, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706012546, 12, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 1, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 3, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 4, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 5, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 6, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 7, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212012547, 8, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 1, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 2, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 3, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 4, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 5, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 13, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 14, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 15, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111201012900, 16, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 1, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 2, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 3, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 4, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 5, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 6, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 7, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 8, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 9, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 10, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 11, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 12, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 13, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 14, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 15, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107012901, 16, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 1, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 2, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 3, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 4, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 5, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 6, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 7, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 8, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 9, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061112012902, 10, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110012903, 1, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110012903, 2, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 1, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 2, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 3, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 4, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 5, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 6, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 7, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 8, 149, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 9, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 10, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070801012904, 11, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 1, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 2, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 3, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 4, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 5, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 6, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627012905, 7, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 1, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 2, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 3, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 4, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 5, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 6, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 7, 103, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040309012906, 8, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 1, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 2, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 3, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 4, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 5, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 6, 17, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 7, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012907, 8, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 1, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 2, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 3, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 4, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 5, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 6, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 7, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 8, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 9, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 10, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 11, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 12, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 13, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104012908, 14, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 1, 44, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 2, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 3, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 4, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 5, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 6, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 7, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 8, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 9, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 10, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 11, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 12, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 13, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 14, 181, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 15, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 16, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130925012909, 17, 108, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 1, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 2, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 3, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 4, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 5, 166, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 6, 71, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 7, 54, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 8, 82, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 9, 96, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 10, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 11, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 12, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 13, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 14, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 15, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 16, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 17, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140131012910, 18, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 1, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 2, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 3, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 4, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 5, 190, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 6, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 7, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 8, 182, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 9, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 10, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 11, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101102012911, 12, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 1, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 2, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 3, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 4, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 5, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 6, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 7, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 8, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 9, 136, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819012912, 10, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 1, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 2, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 3, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 4, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 5, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 6, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 7, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 8, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 9, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 10, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 11, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 12, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 13, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 14, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609012913, 15, 50, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 1, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 2, 170, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 3, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 4, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 5, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 6, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 7, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041127012914, 8, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 1, 152, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 2, 171, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 3, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 4, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 5, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 6, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 7, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 8, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 9, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 10, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 11, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 12, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 13, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 14, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 15, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 16, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 17, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 18, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140403012915, 19, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 1, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 2, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 3, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 4, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 5, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 6, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 7, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 8, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 9, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 10, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 11, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 12, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 13, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 14, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128012916, 15, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 1, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 2, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 3, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 4, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 5, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 6, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 7, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 8, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060908012917, 9, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907012918, 1, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907012918, 2, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000907012918, 3, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 1, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 2, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 3, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 4, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 5, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129012919, 6, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 1, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 2, 125, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 3, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 4, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 5, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 6, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 7, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012920, 8, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 1, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 2, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 3, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 4, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 5, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 6, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 7, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 8, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 9, 121, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 10, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 11, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 12, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116012921, 13, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 1, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 2, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 3, 155, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 4, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 5, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 6, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 10, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121011781, 11, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 1, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 2, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 3, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 5, 16, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 6, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 7, 97, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 8, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 9, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 10, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 11, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 12, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 13, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 14, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923011782, 15, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920011783, 1, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920011783, 2, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000920011783, 3, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 1, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 2, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 3, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 4, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 5, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412011784, 6, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 1, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 2, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 3, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 4, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 5, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901011785, 6, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 1, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 2, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 3, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 4, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 5, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 6, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 7, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 8, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 9, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 10, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 11, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 12, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 13, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 14, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 15, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712011786, 16, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 1, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 2, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 3, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 4, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 5, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020101011787, 6, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 1, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 2, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 3, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 4, 124, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 5, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 6, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 7, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 8, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 9, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 10, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 11, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 12, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 13, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 14, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 15, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 16, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011788, 17, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 1, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 2, 128, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 3, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 4, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 5, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 6, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030305011789, 7, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 1, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 2, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 3, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 4, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 5, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 6, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 7, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 8, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 9, 184, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 10, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 11, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 12, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 13, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 14, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011790, 15, 182, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 1, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 2, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 3, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 4, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 5, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 6, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 7, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 8, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 9, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 10, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 11, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 12, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608011791, 13, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 1, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 2, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 3, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 4, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 5, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 6, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 7, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 8, 99, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 9, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 10, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 11, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 12, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205011792, 13, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131011793, 1, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000131011793, 2, 129, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 1, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 2, 86, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 3, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 4, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 5, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 6, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 7, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 8, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 9, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 10, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 11, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 12, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512011794, 13, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 1, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 2, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 3, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 4, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 5, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 6, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726011795, 7, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 1, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 2, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 3, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 4, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 5, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 6, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 7, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 8, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 9, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510011796, 10, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 1, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 2, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 3, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 4, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 5, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 6, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 7, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 8, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 9, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 10, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 11, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315011797, 12, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 1, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 2, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 3, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 4, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 5, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 6, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 7, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 8, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 9, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 10, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 11, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 12, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 13, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 14, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 15, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120011798, 16, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 1, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 2, 136, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 3, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 4, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 5, 158, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 6, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 7, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 8, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 9, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 10, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 11, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327011799, 12, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011800, 1, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011800, 2, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501011800, 3, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 1, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 2, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 3, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 4, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 5, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 6, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 7, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 8, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 9, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 10, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110011801, 11, 124, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 1, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 2, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 3, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 4, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 5, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 6, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 7, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 8, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 9, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 10, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 11, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 12, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 13, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308011802, 14, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 1, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 2, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 3, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 4, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 5, 66, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 6, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 7, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 8, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 9, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 10, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618011803, 11, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 1, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 2, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 3, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 4, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 5, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 6, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 7, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208011804, 8, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 1, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 2, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 3, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 4, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 5, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 6, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 7, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 8, 27, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 9, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 10, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 11, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 12, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 13, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 14, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120530012184, 15, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 1, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 2, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 3, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 4, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 5, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 6, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 7, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 8, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 9, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 10, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325012185, 11, 21, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 1, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 2, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 3, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 4, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 5, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 6, 100, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 7, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108012186, 8, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025012187, 1, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025012187, 2, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025012187, 3, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025012187, 4, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021025012187, 5, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625012188, 1, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625012188, 2, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625012188, 3, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625012188, 4, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625012188, 5, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 1, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 2, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 3, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 4, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 5, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 6, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 7, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 8, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 9, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 10, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 11, 83, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 12, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 13, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 14, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 15, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 16, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140417012189, 17, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 1, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 2, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 3, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 4, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 5, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 6, 185, 86, 11, 946);
commit;
prompt 120000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 7, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924012190, 8, 186, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 1, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 2, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 3, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 4, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 5, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 6, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 7, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 8, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 9, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 10, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 11, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 12, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 13, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 14, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 15, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 16, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 17, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 18, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411012191, 19, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 1, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 2, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 3, 99, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 4, 103, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 5, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 6, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 7, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 8, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 9, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 10, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 11, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 12, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 13, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 14, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 15, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 16, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308012192, 17, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 1, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 2, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 3, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 4, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 5, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 6, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 7, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 8, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 9, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 10, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 11, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 12, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 13, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 14, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120130012193, 15, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 1, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 2, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 3, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 4, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 5, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 6, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210012194, 7, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 1, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 2, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 3, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 4, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 5, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 6, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 7, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 8, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 9, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 10, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071020012195, 11, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 1, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 2, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 3, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 4, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 5, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 6, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 7, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 8, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 9, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 10, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 11, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 12, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918012196, 13, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 1, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 2, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 3, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 4, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 5, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 6, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 7, 81, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 8, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007012197, 9, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 1, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 2, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 3, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 4, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 5, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 6, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 7, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 8, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012198, 9, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 1, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 2, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 3, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 4, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 5, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 6, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 7, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 8, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 9, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 10, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 11, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 12, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 13, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120930012199, 14, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 1, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 2, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 3, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 4, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 5, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 6, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 7, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 8, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 9, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 10, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102012200, 11, 161, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 1, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 2, 83, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 3, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 4, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 5, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 6, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 7, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 8, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 9, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 10, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 11, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 12, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 13, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012201, 14, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 1, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 2, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 3, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 4, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 5, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 6, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 7, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 8, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070929012202, 9, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 1, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 2, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 3, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 4, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 5, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012203, 6, 106, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 1, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 2, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 3, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 4, 146, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 5, 132, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 6, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 7, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 8, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 9, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 10, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111012204, 11, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 1, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 2, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 3, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 4, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 5, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 6, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228012548, 7, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 1, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 2, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 3, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 4, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 5, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 6, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 7, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 8, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 9, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 10, 117, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 11, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 12, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 13, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 14, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728012549, 15, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 1, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 2, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 3, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 4, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 5, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 6, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 7, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 8, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 9, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 10, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404012550, 11, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 1, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 2, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 3, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 4, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 5, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 6, 11, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 7, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040310012551, 8, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 1, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 2, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 3, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 4, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 5, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 6, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 7, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 8, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 9, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 10, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 11, 89, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 12, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 13, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012552, 14, 10, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 1, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 2, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 3, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 4, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 5, 107, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623012553, 6, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525012554, 1, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525012554, 2, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525012554, 3, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525012554, 4, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525012554, 5, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 1, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 2, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 3, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 4, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 5, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 6, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 7, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027012555, 8, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227012556, 1, 122, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227012556, 2, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227012556, 3, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011227012556, 4, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 1, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 2, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 3, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 4, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 5, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 6, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 7, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 8, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 9, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 10, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 11, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 12, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 13, 136, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 14, 43, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018012557, 15, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 1, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 2, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 3, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 4, 76, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 5, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022012558, 6, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 1, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 2, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 3, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 4, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 5, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 6, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 7, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 8, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 9, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 10, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 11, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 12, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 13, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 14, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120610012559, 15, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 1, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 2, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 3, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 4, 166, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 5, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 6, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909012560, 7, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 1, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 2, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 3, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 4, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 5, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 6, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 7, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 8, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 9, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 10, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 11, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 12, 89, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 13, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 14, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 15, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120817012561, 16, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 1, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 2, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 3, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 4, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 5, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 6, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 7, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 8, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 9, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 10, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 11, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101222012562, 12, 128, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 1, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 2, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 3, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 4, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 5, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 6, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 7, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012563, 8, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929012564, 1, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929012564, 2, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929012564, 3, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929012564, 4, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929012564, 5, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 1, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 2, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 3, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 4, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 5, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 6, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 7, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 8, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 9, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 10, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 11, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130012565, 12, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 1, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 2, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 3, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 4, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 5, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 6, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 7, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 8, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 9, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 10, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 11, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 12, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 13, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 14, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110904012566, 15, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 1, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 2, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 3, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 4, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 5, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 6, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 8, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 9, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 10, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 11, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 12, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 13, 126, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 14, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 15, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 16, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206012567, 17, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 1, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 2, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 3, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 4, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 5, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 6, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 7, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 8, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 9, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 10, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 11, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 12, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 13, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 14, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130902012568, 15, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228012569, 1, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228012569, 2, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228012569, 3, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 1, 131, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 2, 79, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 3, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 4, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 5, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 6, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 7, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 8, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 9, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922012570, 10, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 1, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 2, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 3, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 4, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 5, 48, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 6, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 7, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 8, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 9, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 7, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 8, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 9, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 10, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 11, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 12, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090611012922, 13, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 1, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 2, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 3, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 4, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 5, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 6, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 7, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 8, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 9, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 10, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 11, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 12, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 13, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 14, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 15, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929012923, 16, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 1, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 2, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 3, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 4, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 5, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 6, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 7, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 8, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 9, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 10, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 11, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 12, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 13, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 14, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504012924, 15, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 1, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 2, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 3, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 4, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 5, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 6, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030621012925, 7, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 1, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 2, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 3, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 4, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 5, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 6, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031126012926, 7, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 1, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 2, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 3, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 4, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 5, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 6, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 7, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 8, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 9, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 10, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 11, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218012927, 12, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 1, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 2, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 3, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 4, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 5, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 6, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 7, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 8, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 9, 70, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 10, 121, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 11, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 12, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 13, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124012928, 14, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 1, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 2, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 3, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 4, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 5, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 6, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 7, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 8, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 9, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117012929, 10, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 1, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 2, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 3, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 4, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 5, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 6, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 7, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 8, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 9, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 10, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 11, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 12, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 13, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107012930, 14, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 1, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 2, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 3, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 4, 89, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 5, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 6, 35, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 7, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 8, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 9, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 10, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515012931, 11, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 1, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 2, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 3, 9, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 4, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 5, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 6, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308012932, 7, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 1, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 2, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 3, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 4, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 5, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 6, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 7, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 8, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 9, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 10, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 11, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 12, 122, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 13, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 14, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 15, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 16, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131211012933, 17, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 1, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 2, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 3, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 4, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 5, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 6, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 7, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 8, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 9, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125012934, 10, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 1, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 2, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 3, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 4, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 5, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 6, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 7, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 8, 21, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 9, 88, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 10, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 11, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 12, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 13, 138, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 14, 70, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 15, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 16, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623012935, 17, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919012936, 1, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919012936, 2, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000919012936, 3, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 1, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 2, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 3, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 4, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 5, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 6, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 7, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 8, 32, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 9, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 10, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530012937, 11, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 1, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 2, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 3, 97, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 4, 58, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 5, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 6, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 7, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 8, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 9, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 10, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 11, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 12, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 13, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 14, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223012938, 15, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 1, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 2, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 3, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 4, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 5, 28, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 6, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 7, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 8, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 9, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 10, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217012939, 11, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 1, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 2, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 3, 35, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 4, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 5, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 6, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020421012940, 7, 15, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902012941, 1, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902012941, 2, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902012941, 3, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902012941, 4, 174, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303012942, 1, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303012942, 2, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303012942, 3, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010303012942, 4, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 1, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 2, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 3, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 4, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 5, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 6, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 7, 81, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 8, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 9, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 10, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 11, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 12, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 13, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 14, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121109012943, 15, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107012944, 1, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107012944, 2, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107012944, 3, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107012944, 4, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107012944, 5, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 1, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 2, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 3, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 4, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 5, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 6, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 7, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 8, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 9, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 10, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 11, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 12, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 13, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 14, 93, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 15, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 16, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 17, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123011805, 18, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 1, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 2, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 3, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 4, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 5, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501011806, 6, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 1, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 2, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 3, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 4, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 5, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 6, 182, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 7, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 8, 132, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 9, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 10, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 11, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 12, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 13, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 14, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011807, 15, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 1, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 2, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 3, 53, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 4, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 5, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 6, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 7, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 8, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 9, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229011808, 10, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 1, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 2, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 3, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 4, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 5, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 6, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 7, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 8, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 9, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 10, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 11, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 12, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 13, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 14, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 15, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926011809, 16, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 1, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 2, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 3, 96, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 4, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 5, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 6, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 7, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 8, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 9, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060121011810, 10, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 1, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 2, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 3, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 4, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 5, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 6, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 7, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 8, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 9, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 10, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 11, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090113011811, 12, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 1, 119, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 2, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 3, 117, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 4, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 5, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 6, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 7, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 8, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 9, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 10, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 11, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 12, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 13, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110604011812, 14, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 1, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 2, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 3, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 4, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 5, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 6, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 7, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 8, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 9, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 10, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 11, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 12, 57, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 13, 68, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 14, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110328011813, 15, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 1, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 2, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 3, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 4, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 5, 153, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 6, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 7, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 8, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 9, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 10, 2, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 11, 20, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 12, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 13, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 14, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 15, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011814, 16, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 1, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 2, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 3, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 4, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 5, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 6, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 7, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 8, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 9, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 10, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 11, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 12, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 13, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 14, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 15, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 16, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525011815, 17, 182, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 1, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 2, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 3, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 4, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 5, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 6, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 7, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 8, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 9, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 10, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 11, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 12, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 13, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 14, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110011816, 15, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 1, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 2, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 3, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 4, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 5, 182, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307011817, 6, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 1, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 2, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 3, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 4, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 5, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 6, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 7, 56, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 8, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 9, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 10, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 11, 8, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 12, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 13, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524011818, 14, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 1, 9, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 2, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 3, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 4, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 5, 192, 84, 18, 1512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 6, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 7, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 8, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213011819, 9, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 1, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 2, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 3, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 4, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 5, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 6, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 7, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 8, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 9, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 10, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 11, 64, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 12, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 13, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 14, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911011820, 15, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 1, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 2, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 3, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 4, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 5, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 6, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 7, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 8, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 9, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 10, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 11, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 12, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 13, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 14, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 15, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914011821, 16, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 1, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 2, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 3, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 4, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 5, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 6, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 7, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 8, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040127011822, 9, 1, 22, 3, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 1, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 2, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 3, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 4, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 5, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 6, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 6, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041115012205, 7, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805012206, 1, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805012206, 2, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 1, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 2, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 3, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 4, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 5, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 6, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 7, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 8, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 9, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 10, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510012207, 11, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 1, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 2, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 3, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 4, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 5, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 6, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 7, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 8, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 9, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 10, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 11, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 12, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 13, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 14, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 15, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829012208, 16, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 1, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 2, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 3, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 4, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 5, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 6, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 7, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 8, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 9, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 10, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 11, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307012209, 12, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 1, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 2, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 3, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 4, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 5, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 6, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 7, 176, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504012210, 8, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 1, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 2, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 3, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 4, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 5, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 6, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 7, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 8, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 9, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 10, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 11, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 12, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 13, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 14, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 15, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307012211, 16, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 1, 79, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 2, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 3, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 4, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 5, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 6, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 7, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 8, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050407012212, 9, 97, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 1, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 2, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 3, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 4, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 5, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 6, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 7, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 8, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 9, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081030012213, 10, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411012214, 1, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411012214, 2, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411012214, 3, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411012214, 4, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020411012214, 5, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 1, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 2, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 3, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 4, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 5, 106, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 6, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 7, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 8, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 9, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 10, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 11, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 12, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 13, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313012215, 14, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 1, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 2, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 3, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 4, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 5, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 6, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 7, 52, 52, 9, 468);
commit;
prompt 121000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 8, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 9, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 10, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 11, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 12, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 13, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 14, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 15, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 16, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 17, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203012216, 18, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 1, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 2, 36, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 3, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 4, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 5, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 6, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012217, 7, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 1, 98, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 2, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 3, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 4, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 5, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 6, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 7, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 8, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 9, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051030012218, 10, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 1, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 2, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 3, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 4, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 5, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 6, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 7, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 8, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 9, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 10, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 11, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 12, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 13, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 14, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 15, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012219, 16, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 1, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 2, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 3, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 4, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 5, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 6, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 7, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 8, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 9, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 10, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 11, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 12, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 13, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 14, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 15, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110108012220, 16, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 1, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 2, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 3, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 4, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 5, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 6, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 7, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 8, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 9, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 10, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 11, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 12, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 13, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505012221, 14, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 1, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 2, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 3, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 4, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 5, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 6, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 7, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 8, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 9, 112, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 10, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 11, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810012222, 12, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000629012223, 1, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000629012223, 2, 124, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000629012223, 3, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000629012223, 4, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 1, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 2, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 3, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 4, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 6, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 7, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 8, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 9, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080215012224, 10, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 1, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 2, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 3, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 4, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 5, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 6, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 7, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 8, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 9, 181, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 10, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 11, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 12, 44, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 13, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 14, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 15, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223012225, 16, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 1, 110, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 2, 44, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 3, 32, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 4, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 5, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 6, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 7, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 8, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 9, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012226, 10, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 1, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 10, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524012571, 11, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017012572, 1, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017012572, 2, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017012572, 3, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017012572, 4, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017012572, 5, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 1, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 2, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 3, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 4, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 5, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 6, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 7, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 8, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 9, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 10, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070526012573, 11, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 1, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 2, 62, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 3, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 4, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 5, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 6, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 7, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012574, 8, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 1, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 2, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 3, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 4, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 5, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 6, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 7, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 8, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 9, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 10, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 11, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 12, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 13, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090624012575, 14, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 1, 6, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 2, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 3, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 4, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 5, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 6, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 7, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 8, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 9, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406012576, 10, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 1, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 2, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 3, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 4, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 5, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 6, 4, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 7, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 8, 50, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 9, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 10, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 11, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100626012577, 12, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 1, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 2, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 3, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 4, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 5, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 6, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 7, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 8, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825012578, 9, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031017012579, 1, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031017012579, 2, 20, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031017012579, 3, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031017012579, 4, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031017012579, 5, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 1, 44, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 2, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 3, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 4, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 5, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 6, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 7, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 8, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 9, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 10, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 11, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 12, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 13, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090103012580, 14, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 1, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 2, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 3, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 4, 51, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 5, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 6, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 7, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 8, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810012581, 9, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605012582, 1, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605012582, 2, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605012582, 3, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 1, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 2, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 3, 192, 20, 18, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 4, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 5, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 6, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 7, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 8, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 9, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 10, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 11, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 12, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 13, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 14, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801012583, 15, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602012584, 1, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602012584, 2, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 1, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 2, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 3, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 4, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 5, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 6, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 7, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 8, 110, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 9, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 10, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 11, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 12, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 13, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 14, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 15, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 16, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 17, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012585, 18, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 1, 26, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 2, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 3, 156, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 4, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 5, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 6, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 7, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 8, 143, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725012586, 9, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 1, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 2, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 3, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 4, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 5, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419012587, 6, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127012588, 1, 192, 80, 18, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127012588, 2, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127012588, 3, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127012588, 4, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127012588, 5, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 1, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 2, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 3, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 4, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 5, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 6, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 7, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 8, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 9, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 10, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 11, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 12, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012589, 13, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 1, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 2, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 3, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 4, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 5, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 6, 92, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 7, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 8, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 9, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 10, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 11, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114012590, 12, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614012591, 1, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614012591, 2, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614012591, 3, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614012591, 4, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614012591, 5, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 1, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 2, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 3, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 4, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 5, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 6, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 7, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 8, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111012592, 9, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 1, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 2, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 3, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 4, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 5, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 6, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 7, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 8, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 9, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 10, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 11, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 12, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 13, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101017012593, 14, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 1, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 2, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 3, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 4, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 5, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020812012594, 6, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 1, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 2, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 3, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 4, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 5, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 6, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 7, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 8, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 9, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 10, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 11, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 12, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 13, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 14, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 15, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 16, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318012595, 17, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 1, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 2, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 3, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 4, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 5, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 6, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 1, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 2, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 3, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 4, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 5, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 6, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 7, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 8, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 9, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080929012945, 10, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012946, 1, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012946, 2, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012946, 3, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012946, 4, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013012946, 5, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000808012947, 1, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000808012947, 2, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000808012947, 3, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000808012947, 4, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000808012947, 5, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 1, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 2, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 3, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 4, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 5, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 6, 137, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 7, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 8, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040706012948, 9, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 1, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 2, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 3, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 4, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 5, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 6, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 7, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 8, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 9, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060918012949, 10, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 1, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 2, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 3, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 4, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 5, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 6, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 7, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 8, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 9, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925012950, 10, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 1, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 2, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 3, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 4, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 5, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 6, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 7, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 8, 56, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505012951, 9, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 1, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 2, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 3, 170, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 4, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 5, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 6, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 7, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 8, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224012952, 9, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 1, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 2, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 3, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 4, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 5, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 6, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 7, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051007012953, 8, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 1, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 2, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 3, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 4, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 5, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 6, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 7, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 8, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012954, 9, 109, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725012955, 1, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725012955, 2, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725012955, 3, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725012955, 4, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725012955, 5, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 1, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 2, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 3, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 4, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 5, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 6, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 7, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 8, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 9, 165, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060829012956, 10, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 1, 88, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 2, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 3, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 4, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 5, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 6, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910012957, 7, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310012958, 1, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310012958, 2, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310012958, 3, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310012958, 4, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310012958, 5, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 1, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 2, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 3, 48, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 4, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 5, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 6, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 7, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 8, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618012959, 9, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 1, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 2, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 3, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 4, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 5, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229012960, 6, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 1, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 2, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 3, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 4, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 5, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 6, 73, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 7, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 8, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 9, 93, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 10, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 11, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228012961, 12, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 1, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 2, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 3, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 4, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 5, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010805012962, 6, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 1, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 2, 192, 80, 18, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 3, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 4, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 5, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 6, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 7, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321012963, 8, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012964, 1, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012964, 2, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 1, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 2, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 3, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 4, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 5, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 6, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 7, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 8, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 9, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 10, 65, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614012965, 11, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 1, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 2, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 3, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 4, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 5, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 6, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 7, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 8, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 9, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 10, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 11, 86, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 12, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 13, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 14, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 15, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130312012966, 16, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029012967, 1, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029012967, 2, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029012967, 3, 73, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029012967, 4, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 1, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 2, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 3, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 4, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 5, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 6, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 7, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 8, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 9, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 10, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 11, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 12, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 13, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 14, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825012968, 15, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 1, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 2, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 3, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 4, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 5, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607012969, 6, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 1, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 2, 66, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 3, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 4, 5, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 5, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 6, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 7, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 8, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 9, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070203012970, 10, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 1, 91, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 2, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 3, 21, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 4, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 5, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 6, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012971, 7, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 1, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 2, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 3, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 4, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 5, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 6, 69, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 7, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 8, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 9, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 10, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 11, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117012972, 12, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 1, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 2, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 3, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 7, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 8, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 9, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 10, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 11, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 12, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 13, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115011823, 14, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 1, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 2, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 3, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 4, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 5, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 6, 3, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 7, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 8, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 9, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 10, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 11, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 12, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 13, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 14, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 15, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 16, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804011824, 17, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 1, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 2, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 3, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 4, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 5, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011219011825, 6, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 1, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 2, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 3, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 4, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 5, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 6, 29, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 7, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 8, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 9, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 10, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 11, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 12, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 13, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111209011826, 14, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 1, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 2, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 3, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 4, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 5, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 6, 118, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 7, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 8, 87, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060311011827, 9, 171, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 1, 184, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 2, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 3, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 4, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 5, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 6, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 7, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 8, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 9, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 10, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 11, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 12, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111104011828, 13, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 1, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 2, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 3, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 4, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 5, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 6, 164, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 7, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 8, 155, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061106011829, 9, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 1, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 2, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 3, 146, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 4, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 5, 48, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022011830, 6, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112011831, 1, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112011831, 2, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112011831, 3, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112011831, 4, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112011831, 5, 120, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 1, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 2, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 3, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 4, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 5, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 6, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 7, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 8, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 9, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 10, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 11, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 12, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 13, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 14, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225011832, 15, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 1, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 2, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 3, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 4, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 5, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 6, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 7, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 8, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 9, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 10, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 11, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 12, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110102011833, 13, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103011834, 1, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103011834, 2, 161, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001103011834, 3, 38, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 1, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 2, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 3, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 4, 53, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 5, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 6, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 7, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124011835, 8, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 1, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 2, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 3, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 4, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 5, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919011836, 6, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 1, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 2, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 3, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 4, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 5, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 6, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 7, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 8, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 9, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 10, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 11, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070607011837, 12, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 1, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 2, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 3, 132, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 4, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 5, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 6, 25, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 7, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410011838, 8, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 1, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 2, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 3, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 4, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 5, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 6, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 7, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 8, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802011839, 9, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 1, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 2, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 3, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 4, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 5, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 6, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040711011840, 7, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 1, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 2, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 3, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 4, 46, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 5, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 6, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 7, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 8, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 9, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 10, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 11, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 12, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018011841, 13, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 1, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 2, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 3, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 4, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 5, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 6, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 7, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 8, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 9, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 10, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 11, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 12, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 13, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 14, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412011842, 15, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 1, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 2, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 3, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 4, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 5, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 6, 127, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 7, 84, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 8, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 9, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 10, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 11, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 12, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 13, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121110011843, 14, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 1, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 2, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 3, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 4, 160, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 5, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 6, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 7, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 8, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 9, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 10, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 11, 85, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 12, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 13, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 14, 56, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 15, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 16, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 17, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129011844, 18, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 1, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 2, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 3, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 4, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 5, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 6, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041023011845, 7, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 1, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 2, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 3, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 2, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 3, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 4, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 5, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 6, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 7, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 8, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 9, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 10, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 11, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 12, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 13, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 14, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 15, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120413012227, 16, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 1, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 2, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 3, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 4, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 5, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 6, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 8, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 9, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 10, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 11, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 12, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128012228, 13, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 1, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 2, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 3, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 4, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 5, 37, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012229, 6, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 1, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 2, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 3, 162, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 4, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 5, 59, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 6, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 7, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306012230, 8, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 1, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 2, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 3, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 4, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 5, 105, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 6, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 7, 144, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 8, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 9, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 10, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 11, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 12, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 13, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 14, 177, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012231, 15, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 1, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 2, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 3, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 4, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 5, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 6, 69, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 7, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 8, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 9, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 10, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711012232, 11, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 1, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 2, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 3, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 4, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 5, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 6, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 7, 15, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 8, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 9, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 10, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 11, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 12, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 13, 82, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402012233, 14, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907012234, 1, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907012234, 2, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907012234, 3, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907012234, 4, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 1, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 2, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 3, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 4, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 5, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111012235, 6, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 1, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 2, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 3, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 4, 49, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 5, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 6, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 7, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 8, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 9, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 10, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 11, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 12, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 13, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 14, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 15, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 16, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217012236, 17, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 1, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 2, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 3, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 4, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 5, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 6, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 7, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 8, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 9, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 10, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 11, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 12, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 13, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 14, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613012237, 15, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 1, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 2, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 3, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 4, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 5, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 6, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 7, 176, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050305012238, 8, 128, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012239, 1, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012239, 2, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012239, 3, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012239, 4, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012239, 5, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 1, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 2, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 3, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 4, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 5, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031021012240, 6, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 1, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 2, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 3, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 4, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 5, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 6, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 7, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 8, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 9, 51, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 10, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 11, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 12, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080317012241, 13, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 1, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 2, 136, 69, 14, 966);
commit;
prompt 122000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 3, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 4, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 5, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 6, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 7, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050814012242, 8, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 1, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 2, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 3, 61, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 4, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 5, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 6, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 7, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 8, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071012012243, 9, 162, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 1, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 2, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 3, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 4, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 5, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 6, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 7, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 8, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 9, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 10, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 11, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 12, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 13, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 14, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 15, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120801012244, 16, 118, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 1, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 2, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 3, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 4, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 5, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 6, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 7, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 8, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 9, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 10, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 11, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 12, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 13, 159, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090825012245, 14, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516012246, 1, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516012246, 2, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516012246, 3, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 1, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 2, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 3, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 4, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 5, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 6, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 7, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 8, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 9, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 10, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 11, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 12, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 13, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 14, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 15, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 16, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140130012247, 17, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830012248, 1, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830012248, 2, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830012248, 3, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830012248, 4, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830012248, 5, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 1, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 2, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 3, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 4, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 5, 154, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 6, 17, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 7, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 8, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 9, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 10, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 11, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 7, 155, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 8, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 9, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 10, 57, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126012596, 11, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 1, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 2, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 3, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 4, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 5, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 6, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 7, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 8, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 9, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 10, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 11, 116, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 12, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 13, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 14, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 15, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 16, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012597, 17, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 1, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 2, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 3, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 4, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 5, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012598, 6, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 1, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 2, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 3, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 4, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 5, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 6, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040417012599, 7, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 1, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 2, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 3, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 4, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 5, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 6, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 7, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 8, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 9, 104, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 10, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 11, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 12, 19, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407012600, 13, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 1, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 2, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 3, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 4, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 5, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919012601, 6, 134, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 1, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 2, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 3, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 4, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 5, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212012602, 6, 32, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 1, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 2, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 3, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 4, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 5, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 6, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 7, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 8, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 9, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 10, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 11, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 12, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 13, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 14, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 15, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120430012603, 16, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 1, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 2, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 3, 54, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 4, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 5, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 6, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 7, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 8, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 9, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 10, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012604, 11, 165, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212012605, 1, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212012605, 2, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212012605, 3, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212012605, 4, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011212012605, 5, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 1, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 2, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 3, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 4, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 5, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 6, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118012606, 7, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012607, 1, 1, 99, 3, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012607, 2, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012607, 3, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 1, 50, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 2, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 3, 15, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 4, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 5, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 6, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 7, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802012608, 8, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 1, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 2, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 3, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 4, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 5, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123012609, 6, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 1, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 2, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 3, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 4, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 5, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 6, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 7, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 8, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 9, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 10, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 11, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 12, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 13, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830012610, 14, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 1, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 2, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 3, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 4, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 5, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 6, 175, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 7, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 8, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713012611, 9, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 1, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 2, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 3, 3, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 4, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 5, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 6, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 7, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 8, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060420012612, 9, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120012613, 1, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120012613, 2, 42, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120012613, 3, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120012613, 4, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120012613, 5, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 1, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 2, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 3, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 4, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 5, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020730012614, 6, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 1, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 2, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 3, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 4, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 5, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 6, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 7, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 8, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 9, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012615, 10, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 1, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 2, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 3, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 4, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 5, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 6, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 7, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 8, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 9, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 10, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 11, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080803012616, 12, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 1, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 2, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 3, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 4, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 5, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 6, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 7, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 8, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 9, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 10, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 11, 174, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 12, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 13, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 14, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110220012617, 15, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 1, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 2, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 3, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 4, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 5, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 6, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 7, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 8, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 9, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 10, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325012618, 11, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 1, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 2, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 3, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 4, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 5, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 6, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 7, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 8, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 9, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 10, 73, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 11, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405012619, 12, 82, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 1, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 2, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 3, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 4, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 5, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 6, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 7, 16, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 8, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 9, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 10, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 11, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 12, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080613012620, 13, 137, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 1, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 2, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 3, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 4, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 5, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 6, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 7, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 14, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 1, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 2, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 3, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 4, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 5, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 6, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 7, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050524013069, 8, 191, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013070, 1, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013070, 2, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013070, 3, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013070, 4, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 1, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 2, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 3, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 4, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 5, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 6, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 7, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 8, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 9, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013071, 10, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 1, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 2, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 3, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 4, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 5, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 6, 139, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041124013072, 7, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813013073, 1, 109, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813013073, 2, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813013073, 3, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813013073, 4, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 1, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 2, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 3, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 4, 32, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 5, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 6, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031029013074, 7, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 1, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 2, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 3, 143, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 4, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 5, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 6, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 7, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 8, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 9, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 10, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 11, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090401013075, 12, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 1, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 2, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 3, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 4, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 5, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 6, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 7, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 8, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 9, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 10, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 11, 123, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112013076, 12, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 1, 159, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 2, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 3, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 4, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 5, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309013077, 6, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 1, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 2, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 3, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 4, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 5, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 6, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 7, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 8, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 9, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 10, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 11, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 12, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 13, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111205013078, 14, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 1, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 2, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 3, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 4, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 5, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 6, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 7, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 8, 65, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 9, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 10, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 11, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 12, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 13, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 14, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210013079, 15, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821013080, 1, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821013080, 2, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821013080, 3, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020821013080, 4, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 1, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 2, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 3, 3, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 4, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 5, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 6, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 7, 175, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 8, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 9, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102013081, 10, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 1, 79, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 2, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 3, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 4, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 5, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 6, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 7, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 8, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 9, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 10, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 11, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 12, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 13, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 14, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120416013082, 15, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302013083, 1, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302013083, 2, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302013083, 3, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302013083, 4, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714013084, 1, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714013084, 2, 162, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714013084, 3, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714013084, 4, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020714013084, 5, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 1, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 2, 162, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 3, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 4, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 5, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 6, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 7, 4, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 8, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 9, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 10, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 11, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 12, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 13, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 14, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 15, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 16, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 17, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 18, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013085, 19, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 1, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 2, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 3, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 4, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 5, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 6, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 7, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 8, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 9, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 10, 28, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 11, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 12, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 13, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 14, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 15, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 16, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222013086, 17, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 1, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 2, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 3, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 4, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 5, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 6, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 7, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030529013087, 8, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 1, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 2, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 3, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 4, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 5, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 6, 156, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 7, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 8, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 9, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022013088, 10, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 1, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 2, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 3, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 4, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 5, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 6, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013089, 7, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915013090, 1, 186, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915013090, 2, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915013090, 3, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915013090, 4, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 1, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 2, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 3, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 4, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 5, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 6, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 7, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 8, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 9, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 10, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 11, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081114013091, 12, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 1, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 2, 103, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 3, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 4, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 5, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 6, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 7, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 8, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 9, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 10, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707013092, 11, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 1, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 2, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 3, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 4, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 5, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 6, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 7, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041029013093, 8, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 1, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 2, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 3, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 4, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 4, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 5, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 6, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 7, 79, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050226011846, 8, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 1, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 2, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 3, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 4, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 5, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 6, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 7, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 8, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 9, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 10, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327011847, 11, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 1, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 2, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 3, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 4, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 5, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 6, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 7, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 8, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105011848, 9, 149, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016011849, 1, 183, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016011849, 2, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016011849, 3, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016011849, 4, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016011849, 5, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 1, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 2, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 3, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 4, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 5, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 6, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 7, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 8, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 9, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 10, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 11, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 12, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 13, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007011850, 14, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114011851, 1, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114011851, 2, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114011851, 3, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114011851, 4, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114011851, 5, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414011852, 1, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414011852, 2, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414011852, 3, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418011853, 1, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418011853, 2, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418011853, 3, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418011853, 4, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 1, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 2, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 3, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 4, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 5, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 6, 28, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 7, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040814011854, 8, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 1, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 2, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 3, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 4, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 5, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 6, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 7, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 8, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 9, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 10, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 11, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081220011855, 12, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 1, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 2, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 3, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 4, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 5, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 6, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 7, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 8, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 9, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 10, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 11, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 12, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090726011856, 13, 155, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 1, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 2, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 3, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 4, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 5, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 6, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 7, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 8, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 9, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 10, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 11, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 12, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 13, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110131011857, 14, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 1, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 2, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 3, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 4, 143, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 5, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 6, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 7, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 8, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 9, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 10, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120011858, 11, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 1, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 2, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 3, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 4, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 5, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 6, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 7, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 8, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 9, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 10, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 11, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 12, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 13, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 14, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110310011859, 15, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 1, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 2, 26, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 3, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 4, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 5, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 6, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 7, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 8, 86, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 9, 154, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 10, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 11, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 12, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006011860, 13, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 1, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 2, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 3, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 4, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 5, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 6, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 7, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 8, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 9, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 10, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 11, 4, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 12, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 13, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 14, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 15, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519011861, 16, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 1, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 2, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 3, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 4, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 5, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 6, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 7, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060614011862, 8, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 1, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 2, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 3, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 4, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 5, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 6, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 7, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 8, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 9, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 10, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 11, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100126011863, 12, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 1, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 2, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 3, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 4, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 5, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 6, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 7, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 8, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 9, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 10, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 11, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 12, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 13, 113, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 14, 75, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 15, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125011864, 16, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 1, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 2, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 3, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 4, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 5, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 6, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 7, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 8, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728011865, 9, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708011866, 1, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708011866, 2, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 1, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 2, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 3, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 4, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 5, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 6, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 7, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 8, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 9, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 10, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 11, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 12, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 13, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414011867, 14, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 1, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 2, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 3, 119, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 4, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 5, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 6, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 7, 37, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 8, 170, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 9, 189, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 10, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 11, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 12, 44, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823011868, 13, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 1, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 2, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 3, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 4, 78, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 5, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 6, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 7, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 12, 96, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004012249, 13, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 1, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 2, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 3, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 4, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 5, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 6, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 7, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 8, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 9, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 10, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 11, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 12, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 13, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 14, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 15, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401012250, 16, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 1, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 2, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 3, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 4, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 5, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 6, 159, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 7, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 8, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 9, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 10, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007012251, 11, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 1, 136, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 2, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 3, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 4, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 5, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030119012252, 6, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228012253, 1, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228012253, 2, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228012253, 3, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 1, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 2, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 3, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 4, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 5, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 6, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 7, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 8, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 9, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427012254, 10, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 1, 177, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 2, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 3, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 4, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 5, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 6, 169, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 7, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 8, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 9, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 10, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019012255, 11, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222012256, 1, 162, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222012256, 2, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222012256, 3, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222012256, 4, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000222012256, 5, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 1, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 2, 145, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 3, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 4, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 5, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 6, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 7, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 8, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 9, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302012257, 10, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 1, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 2, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 3, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 4, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 5, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 6, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 7, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 8, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 9, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 10, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 11, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 12, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 13, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 14, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 15, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002012258, 16, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 1, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 2, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 3, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 4, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 5, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 6, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 7, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022012259, 8, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 1, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 2, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 3, 167, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 4, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 5, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 6, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512012260, 7, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 1, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 2, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 3, 49, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 4, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 5, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 6, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 7, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 8, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 9, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 10, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 11, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 12, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 13, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 14, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 15, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121011012261, 16, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 1, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 2, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 3, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 4, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 5, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 6, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 7, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 8, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 9, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 10, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 11, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 12, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613012262, 13, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 1, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 2, 162, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 3, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 4, 105, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 5, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 6, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 7, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 8, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 9, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 10, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 11, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313012263, 12, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 1, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 2, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 3, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 4, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 5, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 6, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 7, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 8, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 9, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 10, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 11, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708012264, 12, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 1, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 2, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 3, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 4, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 5, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 6, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 7, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 8, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 9, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 10, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 11, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 12, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 13, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 14, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 15, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 16, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130822012265, 17, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303012266, 1, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303012266, 2, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303012266, 3, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303012266, 4, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020303012266, 5, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 1, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 2, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 3, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 4, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 5, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 6, 106, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 7, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 8, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 9, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 10, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 11, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 12, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012267, 13, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 1, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 2, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 3, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 4, 127, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 5, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 6, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 7, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711012268, 8, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 1, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 2, 192, 76, 18, 1368);
commit;
prompt 123000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 3, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 4, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 5, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 6, 140, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 7, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040414012269, 8, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 1, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 2, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 3, 1, 74, 3, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 4, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 5, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 6, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 7, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040317012270, 8, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108012271, 1, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108012271, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108012271, 3, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108012271, 4, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 1, 37, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 2, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 3, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 4, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 5, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 6, 171, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 7, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 8, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 9, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 10, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 11, 171, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 12, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 13, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 14, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 15, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 16, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409012272, 17, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 1, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 8, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 9, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 10, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 11, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 12, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 13, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 14, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110511012621, 15, 70, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422012622, 1, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422012622, 2, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422012622, 3, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422012622, 4, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422012622, 5, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 1, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 2, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 3, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 4, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 5, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 6, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 7, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 8, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 9, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012623, 10, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 1, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 2, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 3, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 4, 79, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 5, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 6, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 7, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 8, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 9, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 10, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090713012624, 11, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 1, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 2, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 3, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 4, 134, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 5, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 6, 169, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 7, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 8, 13, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 9, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 10, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 11, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 12, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 13, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 14, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 15, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120314012625, 16, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 1, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 2, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 3, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 4, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 5, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 6, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 7, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 8, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 9, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 10, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 11, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 12, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 13, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 14, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813012626, 15, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 1, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 2, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 3, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 4, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 5, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 6, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 7, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 8, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 9, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 10, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 11, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 12, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 13, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 14, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 15, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621012627, 16, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 1, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 2, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 3, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 4, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 5, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 6, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 7, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 8, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 9, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 10, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 11, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 12, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 13, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 14, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110312012628, 15, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 1, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 2, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 3, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 4, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 5, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 6, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 7, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 8, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 9, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 10, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 11, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 12, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 13, 124, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 14, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 15, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428012629, 16, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 1, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 2, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 3, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 4, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 5, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 6, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 7, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 8, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 9, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 10, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 11, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 12, 1, 63, 3, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 13, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 14, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608012630, 15, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 1, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 2, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 3, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 4, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 5, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 6, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 7, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 8, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051103012631, 9, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 1, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 2, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 3, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 4, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 5, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 6, 90, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 7, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006012632, 8, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 1, 127, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 2, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 3, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 4, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 6, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 7, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 8, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 9, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423012633, 10, 135, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 1, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 2, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 3, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 4, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 5, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 6, 103, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 7, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 8, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012634, 9, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 1, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 2, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 3, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 4, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 5, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 6, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 7, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 8, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 9, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 10, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 11, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 12, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 13, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101025012635, 14, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 1, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 2, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 3, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 4, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 5, 95, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 6, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 7, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 8, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207012636, 9, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 1, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 2, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 3, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 4, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 5, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 6, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 7, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 8, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 9, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 10, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 11, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 12, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 13, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705012637, 14, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 1, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 2, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 3, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 4, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 5, 151, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 6, 99, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 7, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 8, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 9, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 10, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 11, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 12, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 13, 139, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 14, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 15, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024012638, 16, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 1, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 2, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 3, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 4, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 5, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 6, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 7, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030924012639, 8, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 1, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 2, 66, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 3, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 4, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 5, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 6, 129, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 7, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 8, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 9, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 10, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 11, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 12, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 13, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 14, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 15, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 4, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 6, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 7, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 8, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 9, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 10, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 11, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 12, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100625012973, 13, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 1, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 2, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 3, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 4, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 5, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 6, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204012974, 7, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415012975, 1, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415012975, 2, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415012975, 3, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415012975, 4, 187, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 1, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 2, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 3, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 4, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 5, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 6, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 7, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 8, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 9, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 10, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 11, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 12, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418012976, 13, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 1, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 2, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 3, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 4, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 5, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 6, 145, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030929012977, 7, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 1, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 2, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 3, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 4, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 5, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 6, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 7, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 8, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 9, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 10, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 11, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 12, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 13, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 14, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 15, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 16, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707012978, 17, 189, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 1, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 2, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 3, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 4, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 5, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 6, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 7, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 8, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 9, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012979, 10, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 1, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 2, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 3, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 4, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 5, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 6, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 7, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 8, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 9, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060119012980, 10, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206012981, 1, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206012981, 2, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206012981, 3, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010206012981, 4, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 1, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 2, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 3, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 4, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 5, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 6, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 7, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 8, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 9, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 10, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 11, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 12, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100327012982, 13, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 1, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 2, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 3, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 4, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 5, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 6, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 7, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 8, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 9, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 10, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 11, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 12, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 13, 66, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110115012983, 14, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 1, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 2, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 3, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 4, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 5, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 6, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 7, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 8, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 9, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 10, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 11, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712012984, 12, 97, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 1, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 2, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 3, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 4, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 5, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 6, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 7, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 8, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 9, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 10, 7, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 11, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 12, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 13, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 14, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 15, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012985, 16, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930012986, 1, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930012986, 2, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 1, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 2, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 3, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 4, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 5, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 6, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 7, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051215012987, 8, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824012988, 1, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824012988, 2, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000824012988, 3, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 1, 143, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 2, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 3, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 4, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 5, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 6, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 7, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 8, 90, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 9, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 10, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 11, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 12, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 13, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111207012989, 14, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 1, 81, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 2, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 3, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 4, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 5, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 6, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012990, 7, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414012991, 1, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414012991, 2, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414012991, 3, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414012991, 4, 133, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020414012991, 5, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 1, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 2, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 3, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 4, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 5, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 6, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 7, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 8, 26, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 9, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081203012992, 10, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012993, 1, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012993, 2, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329012993, 3, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 1, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 2, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 3, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 4, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 5, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 6, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 7, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 8, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 9, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 10, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 11, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625012994, 12, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 1, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 2, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 3, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 4, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 5, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 6, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 7, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 8, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 9, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 10, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 11, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 12, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 13, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 14, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 15, 84, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 16, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131213012995, 17, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 1, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 2, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 3, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 4, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 5, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 6, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 7, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 8, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 9, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 10, 28, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 11, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 12, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 13, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 14, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 15, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 16, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109012996, 17, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 1, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 2, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 3, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 4, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 8, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 9, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 10, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 11, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 12, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921011869, 13, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 1, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 2, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 3, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 4, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 5, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 6, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 7, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 8, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 9, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 10, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 11, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 12, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081127011870, 13, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 1, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 2, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 3, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 4, 82, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 5, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204011871, 6, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 1, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 2, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 3, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 4, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 5, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 6, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 7, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 8, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 9, 176, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 10, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 11, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 12, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 13, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619011872, 14, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626011873, 1, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626011873, 2, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626011873, 3, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626011873, 4, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626011873, 5, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 1, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 2, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 3, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 4, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 5, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 6, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 7, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 8, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 9, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 10, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 11, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 12, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317011874, 13, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 1, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 2, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 3, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 4, 166, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 5, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 6, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 7, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 8, 135, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 9, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 10, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 11, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 12, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513011875, 13, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 1, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 2, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 3, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 4, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 5, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 6, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 7, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 8, 35, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 9, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 10, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070811011876, 11, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 1, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 2, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 3, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 4, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 5, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020728011877, 6, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 1, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 2, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 3, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 4, 162, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 5, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 6, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 7, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 8, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 9, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025011878, 10, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 1, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 2, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 3, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 4, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 5, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 6, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 7, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 8, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 9, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 10, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 11, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 12, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 13, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 14, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 15, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 16, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 17, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723011879, 18, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 1, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 2, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 3, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 4, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 5, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 6, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 7, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 8, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 9, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 10, 172, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 11, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 12, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 13, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 14, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 15, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731011880, 16, 170, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 1, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 2, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 3, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 4, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 5, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 6, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 7, 67, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 8, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 9, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 10, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 11, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 12, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100323011881, 13, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 1, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 2, 172, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 3, 29, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 4, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 5, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 6, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 7, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 8, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050509011882, 9, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723011883, 1, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723011883, 2, 41, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723011883, 3, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723011883, 4, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830011884, 1, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830011884, 2, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305011885, 1, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305011885, 2, 148, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305011885, 3, 177, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305011885, 4, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 1, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 2, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 3, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 4, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 5, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 6, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 7, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 8, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 9, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318011886, 10, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826011887, 1, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826011887, 2, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826011887, 3, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 1, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 2, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 3, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 4, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 5, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 6, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 7, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 8, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 9, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 10, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 11, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 12, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 13, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 14, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 15, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 16, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 17, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102011888, 18, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 1, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 2, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 3, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 4, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 5, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 6, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 7, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 8, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 9, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 10, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 11, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 12, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 13, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 14, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 15, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 16, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 17, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408011889, 18, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 1, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 2, 166, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 3, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 4, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 5, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 6, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 7, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 8, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 9, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 10, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 11, 121, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 12, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 13, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 14, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217011890, 15, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 1, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 2, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 3, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 4, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 5, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 6, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 7, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 8, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 9, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 10, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 11, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517011891, 12, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 2, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 3, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 4, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 5, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 6, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 7, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 8, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 9, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 10, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 11, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 12, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102012273, 13, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 1, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 2, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 3, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 4, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 5, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 6, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 7, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 8, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 9, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 10, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331012274, 11, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001012275, 1, 60, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001012275, 2, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001012275, 3, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001012275, 4, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001012275, 5, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 1, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 2, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 4, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 5, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 6, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 7, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 8, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 9, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 10, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 11, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 12, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 13, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105012276, 14, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 1, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 2, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 3, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 4, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 5, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 6, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 7, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 8, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 9, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 10, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 11, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530012277, 12, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 1, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 2, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 3, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 4, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 5, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 6, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 7, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 8, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 9, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081125012278, 10, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 1, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 2, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 3, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 4, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 5, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 6, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 7, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 8, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 9, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 10, 72, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 11, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 12, 157, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080107012279, 13, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 1, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 2, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 3, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 4, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 5, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031203012280, 6, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 1, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 2, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 3, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 4, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 5, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 6, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 7, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 8, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 9, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 10, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 11, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 12, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 13, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 14, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 15, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120723012281, 16, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 1, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 2, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 3, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 4, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 5, 48, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 6, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 7, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112012282, 8, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 1, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 2, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 3, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 4, 191, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 5, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 6, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 7, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 8, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 9, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 10, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 11, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 12, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 13, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 14, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 15, 132, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 16, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802012283, 17, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 1, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 2, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 3, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 4, 168, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 5, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 6, 54, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 7, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 8, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913012284, 9, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 1, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 2, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 3, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 4, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 5, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 6, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 7, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 8, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 9, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 10, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 11, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 12, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 13, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 14, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 15, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028012285, 16, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 1, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 2, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 3, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 4, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 5, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 6, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 7, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 8, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 9, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 10, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 11, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 12, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 13, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 14, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 15, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 16, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120507012286, 17, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 1, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 2, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 3, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 4, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 5, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 6, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030518012287, 7, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 1, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 2, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 3, 108, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 4, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 5, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 6, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 7, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 8, 150, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 9, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 10, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 11, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 12, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402012288, 13, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 1, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 2, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 3, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 4, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 5, 26, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 6, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 7, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 8, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 9, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 10, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 11, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 12, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 13, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 14, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111105012289, 15, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 1, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 2, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 3, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 4, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 5, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 6, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 7, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 8, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 9, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 10, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110012290, 11, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 1, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 2, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 3, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 4, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 5, 15, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 6, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 7, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 8, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820012291, 9, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 1, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 2, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 3, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 4, 49, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 5, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 6, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 7, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 8, 158, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 9, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 10, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 11, 158, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 12, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 13, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529012292, 14, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 1, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 2, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 3, 171, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 4, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 16, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 17, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012640, 18, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 1, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 2, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 3, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 4, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 5, 143, 2, 14, 28);
commit;
prompt 124000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 6, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 7, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618012641, 8, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 1, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 2, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 3, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 4, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 5, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 6, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 7, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 8, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 9, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 10, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 11, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 12, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 13, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 14, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 15, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518012642, 16, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 1, 166, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 2, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 3, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 4, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 5, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 6, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 7, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 8, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 9, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060414012643, 10, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 1, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 2, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 3, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 4, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 5, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 6, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 7, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 8, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 9, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 10, 164, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 11, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 12, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 13, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 14, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 15, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 16, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129012644, 17, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 1, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 2, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 3, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 4, 22, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 5, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 6, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040506012645, 7, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 1, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 2, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 3, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 4, 163, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 5, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 6, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 7, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 8, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 9, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 10, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 11, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 12, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 13, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309012646, 14, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 1, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 2, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 3, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 4, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 5, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 6, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 7, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 8, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 9, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 10, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 11, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091110012647, 12, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 1, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 2, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 3, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 4, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 5, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 6, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 7, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 8, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109012648, 9, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 1, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 2, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 3, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 4, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 5, 48, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 6, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 7, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210012649, 8, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 1, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 2, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 3, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 4, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 5, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 6, 155, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304012650, 7, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 1, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 2, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 3, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 4, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 5, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 6, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 7, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706012651, 8, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 1, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 2, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 3, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 4, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 5, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 6, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 7, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 8, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 9, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 10, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 11, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 12, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 13, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 14, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 15, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 16, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 17, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 18, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516012652, 19, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 1, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 2, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 3, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 4, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 5, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 6, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012653, 7, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 1, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 2, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 3, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 4, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 5, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 6, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 7, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 8, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 9, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922012654, 10, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830012655, 1, 139, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830012655, 2, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830012655, 3, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830012655, 4, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010830012655, 5, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 1, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 2, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 3, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 4, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 5, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 6, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 7, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 8, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 9, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119012656, 10, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 1, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 2, 98, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 3, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 4, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 5, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 6, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 7, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 8, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 9, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 10, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 11, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 12, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 13, 23, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 14, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 15, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530012657, 16, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 1, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 2, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 3, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 4, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 5, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 6, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 7, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 8, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 9, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 10, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 11, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 12, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614012658, 13, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 1, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 2, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 3, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 4, 90, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 5, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 6, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 7, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 8, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812012659, 9, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 1, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 2, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 3, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 4, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 5, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 6, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 7, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 8, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 9, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 10, 112, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 11, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 12, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 13, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 14, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 15, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 16, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130729012660, 17, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 1, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 2, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 3, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 4, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 5, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 6, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 7, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209012661, 8, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 1, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 2, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 3, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 4, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 5, 94, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 6, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 7, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 8, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 9, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 10, 10, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 11, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 1, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 2, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 3, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 4, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 5, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 6, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 7, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 8, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 9, 92, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 10, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 11, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 12, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 13, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 14, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 15, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130824013019, 16, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 1, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 2, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 3, 74, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 4, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 5, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 6, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 7, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 8, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 9, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061220013020, 10, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 1, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 2, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 3, 12, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 4, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 5, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 6, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031104013021, 7, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 1, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 2, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 3, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 4, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 5, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 6, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 7, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304013022, 8, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 1, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 2, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 3, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 4, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 5, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 6, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 7, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 8, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 9, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 10, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 11, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 12, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 13, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 14, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 15, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223013023, 16, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 1, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 2, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 3, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 4, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 5, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 6, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 7, 109, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040510013024, 8, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813013025, 1, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813013025, 2, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813013025, 3, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813013025, 4, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813013025, 5, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 1, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 2, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 3, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 4, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 5, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 6, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 7, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 8, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 9, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 10, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 11, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 12, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 13, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 14, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 15, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 16, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 17, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013026, 18, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 1, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 2, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 3, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 4, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 5, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 6, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 7, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 8, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 9, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 10, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 11, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 12, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 13, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201013027, 14, 18, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422013028, 1, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422013028, 2, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422013028, 3, 126, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010422013028, 4, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 1, 132, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 2, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 3, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 4, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 5, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 6, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 7, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 8, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070112013029, 9, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013030, 1, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013030, 2, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013030, 3, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306013031, 1, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306013031, 2, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306013031, 3, 43, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306013031, 4, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 1, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 2, 159, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 3, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 4, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 5, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 6, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 7, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 8, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 9, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 10, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 11, 68, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 12, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 13, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013032, 14, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020321013033, 1, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020321013033, 2, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020321013033, 3, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020321013033, 4, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020321013033, 5, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 1, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 2, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 3, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 4, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 5, 1, 99, 3, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 6, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 7, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 8, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 9, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 10, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 11, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 12, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 13, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 14, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202013034, 15, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 1, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 2, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 3, 1, 47, 3, 141);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 4, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 5, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 6, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 7, 91, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013035, 8, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801013036, 1, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801013036, 2, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801013036, 3, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801013036, 4, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801013036, 5, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 1, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 2, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 3, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 4, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 5, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 6, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 7, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 8, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 9, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 10, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 11, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 12, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102013037, 13, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 1, 119, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 2, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 3, 24, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 4, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 5, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 6, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 7, 49, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 8, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 9, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 10, 130, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 11, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 12, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522013038, 13, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701013039, 1, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701013039, 2, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701013039, 3, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701013039, 4, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423013040, 1, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423013040, 2, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423013040, 3, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423013040, 4, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030423013040, 5, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 1, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 2, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 3, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 4, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 5, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 6, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051228013041, 7, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 1, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 2, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 3, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 4, 16, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 5, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 6, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 7, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 8, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 9, 126, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 10, 128, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430013042, 11, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 1, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 2, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 3, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 4, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 5, 113, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 6, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 7, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 8, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429013043, 9, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 1, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 2, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 3, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 1, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 2, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 3, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 4, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 5, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 6, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 7, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 8, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 9, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 10, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 11, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 12, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080218011892, 13, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217011893, 1, 182, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217011893, 2, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217011893, 3, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217011893, 4, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217011893, 5, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 1, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 2, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 3, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 4, 50, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 5, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 6, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 7, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 8, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 9, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 10, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 11, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224011894, 12, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 1, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 2, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 3, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 4, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 5, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 6, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 7, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 8, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 9, 104, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 10, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 11, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 12, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 13, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 14, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816011895, 15, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 1, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 2, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 3, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 4, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 5, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 6, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 7, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 8, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 9, 164, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 10, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 11, 65, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 12, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 13, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 14, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 15, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 16, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609011896, 17, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016011897, 1, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016011897, 2, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016011897, 3, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016011897, 4, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016011897, 5, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 1, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 2, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 3, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 4, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 5, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 6, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 7, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 8, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 9, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 10, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 11, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 12, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 13, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 14, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 15, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220011898, 16, 178, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 1, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 2, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 3, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 4, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 5, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 6, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 7, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 8, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 9, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 10, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 11, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 12, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 13, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 14, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 15, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830011899, 16, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 1, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 2, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 3, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 4, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 5, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 6, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 7, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 8, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 9, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 10, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 11, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090204011900, 12, 166, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203011901, 1, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203011901, 2, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203011901, 3, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203011901, 4, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203011901, 5, 12, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 1, 187, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 2, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 3, 137, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 4, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 5, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 6, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 7, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 8, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 9, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 10, 192, 83, 18, 1494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 11, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817011902, 12, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 1, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 2, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 3, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 4, 180, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 5, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 6, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 7, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 8, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 9, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 10, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 11, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 12, 83, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 13, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110723011903, 14, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 1, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 2, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 3, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 4, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 5, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 6, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 7, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 8, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 9, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 10, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 11, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 12, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101225011904, 13, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011905, 1, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011905, 2, 40, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011905, 3, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011905, 4, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011905, 5, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 1, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 2, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 3, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 4, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 5, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 6, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 7, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 8, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 9, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 10, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 11, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 12, 13, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 13, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090626011906, 14, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 1, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 2, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 3, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 4, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 5, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 6, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 7, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 8, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923011907, 9, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 1, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 2, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 3, 121, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 4, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 5, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 6, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 7, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050905011908, 8, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204011909, 1, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204011909, 2, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204011909, 3, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204011909, 4, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031204011909, 5, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 1, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 2, 114, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 3, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 4, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 5, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 6, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 7, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 8, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 9, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 10, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 11, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 12, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721011910, 13, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610011911, 1, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610011911, 2, 136, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610011911, 3, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610011911, 4, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 1, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 2, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 3, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 4, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 5, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 6, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 7, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 8, 109, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 9, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 10, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 11, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 12, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 13, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316011912, 14, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 1, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 2, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 3, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 4, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 5, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 6, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 7, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 8, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218011913, 9, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 1, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 2, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 3, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 5, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 6, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 7, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313012293, 8, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 1, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 2, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 3, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 4, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 5, 99, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 6, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 7, 192, 89, 18, 1602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223012294, 8, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916012295, 1, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000916012295, 2, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130012296, 1, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130012296, 2, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000130012296, 3, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 1, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 2, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 3, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 4, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 5, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 6, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 7, 114, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 8, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 9, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 10, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 11, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 12, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 13, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 14, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 15, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130611012297, 16, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 1, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 2, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 3, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 4, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 5, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426012298, 6, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121012299, 1, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121012299, 2, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121012299, 3, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121012299, 4, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 1, 1, 71, 3, 213);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 2, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 3, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 4, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 5, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 6, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 7, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 8, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 9, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 10, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 11, 107, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 12, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 13, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012300, 14, 125, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 1, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 2, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 3, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 4, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 5, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 6, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 7, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 8, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 9, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 10, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 11, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 12, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 13, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 14, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417012301, 15, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012302, 1, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012302, 2, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 1, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 2, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 3, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 4, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 5, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 6, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 7, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 8, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 9, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 10, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 11, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 12, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091031012303, 13, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 1, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 2, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 3, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 4, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 5, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 6, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 7, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 8, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 9, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 10, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 11, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 12, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 13, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 14, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 15, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012304, 16, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111012305, 1, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111012305, 2, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111012305, 3, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111012305, 4, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 1, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 2, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 3, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 4, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 5, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 6, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 7, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 8, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 9, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 10, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226012306, 11, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 1, 43, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 2, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 3, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 4, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 5, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 6, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 7, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 8, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 9, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 10, 192, 58, 18, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 11, 69, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 12, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 13, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 14, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 15, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 16, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222012307, 17, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 1, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 2, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 3, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 4, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 5, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 6, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 7, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 8, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012308, 9, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 1, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 3, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 4, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 5, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 6, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 7, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 8, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 9, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 10, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 11, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 12, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 13, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 14, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 15, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127012309, 16, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 1, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 2, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 3, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 4, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 5, 65, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 6, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 7, 158, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 8, 190, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 9, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 10, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 11, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 12, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 13, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 14, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 15, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 16, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224012310, 17, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 1, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 2, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 3, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 4, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 5, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 6, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 7, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 8, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 9, 50, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 10, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 11, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 12, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 13, 29, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 14, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 15, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524012311, 16, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 1, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 2, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 3, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 4, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 5, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 6, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 7, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 8, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 9, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 10, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 11, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 12, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626012312, 13, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 1, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 2, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 3, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 4, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 5, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 6, 43, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 7, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 8, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 9, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 10, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 11, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923012313, 12, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 1, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 2, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 3, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 4, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 5, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 6, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 7, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 8, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 9, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 10, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 11, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 12, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218012314, 13, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 1, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 2, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 3, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 4, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 5, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 6, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 7, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 8, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115012662, 7, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 1, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 2, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 3, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 4, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 5, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 6, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030614012663, 7, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 1, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 2, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 3, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 4, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 5, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 6, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 7, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 8, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 9, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 10, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 11, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100414012664, 12, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 1, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 2, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 3, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 4, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 5, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 6, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 7, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 8, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410012665, 9, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 1, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 2, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 3, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 4, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 5, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 6, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 7, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 8, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050503012666, 9, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012667, 1, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012667, 2, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012667, 3, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012667, 4, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012667, 5, 93, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 1, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 2, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 3, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 4, 171, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 5, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 6, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 7, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 8, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 9, 51, 85, 8, 680);
commit;
prompt 125000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 10, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080422012668, 11, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 1, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 2, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 3, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 4, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 5, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 6, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 7, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120012669, 8, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 1, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 2, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 3, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 4, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 5, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 6, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 7, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 8, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 9, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 10, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 11, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 12, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922012670, 13, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 1, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 2, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 3, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 4, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 5, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040126012671, 6, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306012672, 1, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306012672, 2, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010306012672, 3, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 1, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 2, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 3, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 4, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 5, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 6, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127012673, 7, 145, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317012674, 1, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317012674, 2, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317012674, 3, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317012674, 4, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010317012674, 5, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 1, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 2, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 3, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 4, 109, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 5, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 6, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 7, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 8, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 9, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 10, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 11, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 12, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 13, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 14, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709012675, 15, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 1, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 2, 122, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 3, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 4, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 5, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 6, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 7, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 8, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214012676, 9, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 1, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 2, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 3, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 4, 167, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 5, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 6, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 7, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 8, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 9, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 10, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 11, 105, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 12, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 13, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100509012677, 14, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 1, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 2, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 3, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 4, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 5, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226012678, 6, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 1, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 2, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 3, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 4, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 5, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 6, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 7, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220012679, 8, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 1, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 2, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 3, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 4, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 5, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 6, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 7, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 8, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 9, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 10, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 11, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 12, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 13, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 14, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 15, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 16, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 17, 94, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128012680, 18, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 1, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 2, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 3, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 4, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 5, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 6, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 7, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050414012681, 8, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 1, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 2, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 3, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 4, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 5, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 6, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 7, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 8, 116, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 9, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 10, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 11, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 12, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 13, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110722012682, 14, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031012683, 1, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031012683, 2, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031012683, 3, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031012683, 4, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 1, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 2, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 3, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 4, 32, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 5, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 6, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050827012684, 7, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 1, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 2, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 3, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 4, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 5, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 6, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 7, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 8, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 9, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050602012685, 10, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 1, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 2, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 3, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 4, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 5, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 6, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 7, 61, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 8, 75, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 9, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 10, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 11, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 12, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 13, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 14, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 15, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 16, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120730012686, 17, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 1, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 2, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 3, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 4, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 5, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 6, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 7, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 8, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 9, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202012687, 10, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 1, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 2, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 5, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 6, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 7, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 8, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 9, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 10, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 11, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 12, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090625013094, 13, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 1, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 2, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 3, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 4, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 5, 30, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 6, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 7, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 8, 47, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 9, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 10, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 11, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 12, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021013095, 13, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 1, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 2, 22, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 3, 170, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 4, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 5, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 6, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 7, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 8, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816013096, 9, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 1, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 2, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 3, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 4, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 5, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 6, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 7, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 8, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426013097, 9, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 1, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 2, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 3, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 4, 113, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 5, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 6, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 7, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 8, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 9, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 10, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 11, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 12, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 13, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 14, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121201013098, 15, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427013099, 1, 94, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427013099, 2, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427013099, 3, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427013099, 4, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010427013099, 5, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 1, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 2, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 3, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 4, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 5, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 6, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 7, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 8, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307013100, 9, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 1, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 2, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 3, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 4, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 5, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 6, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 7, 158, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 8, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 9, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 10, 150, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 11, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 12, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 13, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 14, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 15, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 16, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 17, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 18, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226013101, 19, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 1, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 2, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 3, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 4, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 5, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 6, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 7, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 8, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 9, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 10, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 11, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 12, 180, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 13, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 14, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120013102, 15, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 1, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 2, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 3, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 4, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 5, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 6, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 7, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 8, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 9, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208013103, 10, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 1, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 2, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 3, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 4, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 5, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 6, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 7, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030616013104, 8, 167, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119013105, 1, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119013105, 2, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000119013105, 3, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 1, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 2, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 3, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 4, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 5, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 6, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 7, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 8, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 9, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 10, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 11, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503013106, 12, 169, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 1, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 2, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 3, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 4, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 5, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 6, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020914013107, 7, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 1, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 2, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 3, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 4, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 5, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 6, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 7, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907013108, 8, 185, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 1, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 2, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 3, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 4, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 5, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 6, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040925013109, 7, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 1, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 2, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 3, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 4, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 5, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 6, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 7, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 8, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 9, 39, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 10, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070412013110, 11, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 1, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 2, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 3, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 4, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 5, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 6, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 7, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 8, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 9, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 10, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327013111, 11, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 1, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 2, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 3, 99, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 4, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 5, 159, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 6, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 7, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401013112, 8, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 1, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 2, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 3, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 4, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 5, 125, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 6, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 7, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 8, 57, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418013113, 9, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 1, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 2, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 3, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 4, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 5, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 6, 185, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 7, 50, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 8, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 9, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 10, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 11, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 12, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 13, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 14, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305013114, 15, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 1, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 2, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 3, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 4, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 5, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 6, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 7, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122013115, 8, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 1, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 2, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 3, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 4, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 5, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 6, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 7, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101013116, 8, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 1, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 2, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 3, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 4, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 5, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030430013117, 6, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 1, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 2, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 3, 59, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 4, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 5, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 4, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 5, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 6, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 7, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 8, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060815011914, 9, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 1, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 2, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 3, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 5, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 6, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 7, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 8, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011915, 9, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605011916, 1, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605011916, 2, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605011916, 3, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605011916, 4, 144, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 1, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 2, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 3, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 4, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 5, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 6, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 7, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 8, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 9, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 10, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 11, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 12, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 13, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 14, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820011917, 15, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 1, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 2, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 3, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 4, 104, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 5, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 6, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 7, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 8, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 9, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 10, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808011918, 11, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 1, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 2, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 3, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 4, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 5, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 6, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 7, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 8, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 9, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 10, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090731011919, 11, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 1, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 2, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 3, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 4, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 5, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 6, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 7, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 8, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 9, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 10, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 11, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 12, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 13, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201011920, 14, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 1, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 2, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 3, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 4, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 5, 108, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 6, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 7, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 8, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 9, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070208011921, 10, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321011922, 1, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321011922, 2, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321011922, 3, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321011922, 4, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010321011922, 5, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125011923, 1, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125011923, 2, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125011923, 3, 108, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 1, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 2, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 3, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 4, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 5, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 6, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 7, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 8, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 9, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 10, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 11, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 12, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 13, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 14, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 15, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 16, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140305011924, 17, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 1, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 2, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 3, 99, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 4, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 5, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 6, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 7, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 8, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 9, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007011925, 10, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608011926, 1, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608011926, 2, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000608011926, 3, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 1, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 2, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 3, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 4, 131, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 5, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 6, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 7, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 8, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 9, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011927, 10, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020011928, 1, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020011928, 2, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020011928, 3, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020011928, 4, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719011929, 1, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719011929, 2, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719011929, 3, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 1, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 2, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 3, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 4, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 5, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 6, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031212011930, 7, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619011931, 1, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619011931, 2, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619011931, 3, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619011931, 4, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619011931, 5, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 1, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 2, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 3, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 4, 171, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 5, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 6, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 7, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 8, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 9, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 10, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 11, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 12, 74, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 13, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 14, 171, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 15, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117011932, 16, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000225011933, 1, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000225011933, 2, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 1, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 2, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 3, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 4, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 5, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 6, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 7, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107011934, 8, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 1, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 2, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 3, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 4, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 5, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 6, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 7, 148, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912011935, 8, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011936, 1, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011936, 2, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011936, 3, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011936, 4, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011936, 5, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907011937, 1, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907011937, 2, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907011937, 3, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907011937, 4, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907011937, 5, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 1, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 2, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 3, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 4, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 5, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 6, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 7, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 8, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 9, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 10, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 11, 9, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 12, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090516011938, 13, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011939, 1, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011939, 2, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015011939, 3, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 1, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 2, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 3, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 5, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 6, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 7, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 8, 172, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 9, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 10, 10, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 11, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 12, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 13, 81, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 14, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322011940, 15, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117011941, 1, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117011941, 2, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117011941, 3, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117011941, 4, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010117011941, 5, 107, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 1, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 2, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 3, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 4, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 5, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 6, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514011942, 7, 49, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 1, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 2, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 3, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 4, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 5, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 9, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 10, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 11, 104, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 12, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104012315, 13, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927012316, 1, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927012316, 2, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927012316, 3, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 1, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 2, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 3, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 4, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 5, 41, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 6, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 7, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012317, 8, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 1, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 2, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 3, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 4, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 5, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 6, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020420012318, 7, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 1, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 2, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 3, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 4, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 5, 180, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 6, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 7, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 8, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 9, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 10, 164, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211012319, 11, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208012320, 1, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208012320, 2, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208012320, 3, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208012320, 4, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030208012320, 5, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 1, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 2, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 3, 1, 8, 3, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 4, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 5, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 6, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 7, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 8, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 9, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 10, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 11, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 12, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012321, 13, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 1, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 2, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 3, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 4, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 5, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 6, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 7, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 8, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 9, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 10, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 11, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081004012322, 12, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 1, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 2, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 3, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 4, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 5, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 6, 118, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 7, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 8, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 9, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 10, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 11, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 12, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 13, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 14, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111012323, 15, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 1, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 2, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 3, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 4, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 5, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 6, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 7, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 8, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 9, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 10, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 11, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 12, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 13, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120323012324, 14, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 1, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 2, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 3, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 4, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 5, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 6, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 7, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 8, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725012325, 9, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 1, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 2, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 3, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 4, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 5, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 6, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 7, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 8, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 9, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 10, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 11, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725012326, 12, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 1, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 2, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 3, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 4, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 5, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 6, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 7, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 8, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 9, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050613012327, 10, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 1, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 2, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 3, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 4, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 5, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 6, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 7, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 8, 173, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 9, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 10, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 11, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 12, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318012328, 13, 111, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 1, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 2, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 3, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 4, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 5, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 6, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 7, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 8, 146, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 9, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 10, 22, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 11, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 12, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 13, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 14, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 15, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908012329, 16, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 1, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 2, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 3, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 4, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 5, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 6, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 7, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 8, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 9, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 10, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 11, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 12, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 13, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 14, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 15, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221012330, 16, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 1, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 2, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 3, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 4, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 5, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 6, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 7, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226012331, 8, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 1, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 2, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 3, 39, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 4, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 5, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 6, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 7, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 8, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 9, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 10, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 11, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714012332, 12, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 1, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 2, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 3, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 4, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 5, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 6, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 7, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 8, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 9, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 10, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012333, 11, 185, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 1, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 2, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 3, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 4, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 5, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 6, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 7, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 8, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105012334, 9, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 1, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 2, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 3, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 4, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 5, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 6, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 7, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 8, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722012335, 9, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 1, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 2, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 3, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 4, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 5, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 6, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 7, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 8, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 9, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 10, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 11, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 12, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 13, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 14, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 15, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121108012336, 16, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 1, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 2, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 3, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 4, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 5, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 3, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 4, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 5, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 6, 177, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 7, 143, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 8, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 9, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 10, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 11, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329012688, 12, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 1, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 2, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 3, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 4, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 5, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 6, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 7, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 8, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 9, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 10, 96, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 11, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021012689, 12, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 1, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 2, 183, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 3, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 4, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 5, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 6, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 7, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041104012690, 8, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 1, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 2, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 3, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 4, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 5, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 6, 83, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 7, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 8, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 9, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 10, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515012691, 11, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 1, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 2, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 3, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 4, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 5, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 6, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 7, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050512012692, 8, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 1, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 2, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 3, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 4, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 5, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802012693, 6, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 1, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 2, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 3, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 4, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 6, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 7, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 8, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 9, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 10, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 11, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314012694, 12, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 1, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 2, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 3, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 4, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 5, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 6, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 7, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 8, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 9, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 10, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 11, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722012695, 12, 2, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 1, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 2, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 3, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 4, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 5, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 6, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 7, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 8, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 9, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 10, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 11, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 12, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 13, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 14, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012696, 15, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 1, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 2, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 3, 74, 73, 7, 511);
commit;
prompt 126000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 4, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 5, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 6, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 7, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 8, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 9, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 10, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 11, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505012697, 12, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 1, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 2, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 3, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 4, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 5, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 6, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 7, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 8, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 9, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 10, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 11, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 12, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 13, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 14, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 15, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 16, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915012698, 17, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 1, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 2, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 3, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 4, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 5, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 6, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 7, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 8, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012699, 9, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 1, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 2, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 3, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 4, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 5, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 6, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 7, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 8, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 9, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 10, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901012700, 11, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 1, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 2, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 3, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 4, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 5, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 6, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 7, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 8, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 9, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 10, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 11, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 12, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 13, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 14, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121107012701, 15, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 1, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 2, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 3, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 4, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 5, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 6, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 7, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 8, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 9, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 10, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 11, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 12, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 13, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 14, 178, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 15, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 16, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 17, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619012702, 18, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 1, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 2, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 3, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 4, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 5, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 6, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 7, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 8, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 9, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908012703, 10, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 1, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 2, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 3, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 4, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 5, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 6, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 7, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 8, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 9, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 10, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 11, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 12, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091116012704, 13, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010310012705, 1, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010310012705, 2, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010310012705, 3, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010310012705, 4, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010310012705, 5, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 1, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 2, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 3, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 4, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 5, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 6, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 7, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 8, 138, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 9, 55, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 10, 117, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214012706, 11, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 1, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 2, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 3, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 4, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 5, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 6, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040101012707, 7, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429012708, 1, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429012708, 2, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429012708, 3, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020429012708, 4, 2, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 1, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 2, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 3, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 4, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 5, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 6, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 7, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 8, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 9, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 10, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 11, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 12, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 13, 155, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 5, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 6, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 7, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 8, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 9, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 10, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 11, 167, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 12, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 13, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 14, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531012997, 15, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 1, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 2, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 3, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 4, 187, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 5, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 6, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 7, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 8, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 9, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 10, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 11, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 12, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 13, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 14, 112, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 15, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009012998, 16, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 1, 124, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 2, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 3, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 4, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 5, 139, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 6, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 7, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 8, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 9, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050112012999, 10, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 1, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 2, 3, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 3, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 4, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 5, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 6, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 7, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 8, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 9, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 10, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 11, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 12, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 13, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110401013000, 14, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 1, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 2, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 3, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 4, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 5, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 6, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 7, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 8, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 9, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 10, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 11, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 12, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 13, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 14, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 15, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230013001, 16, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 1, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 2, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 3, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 4, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 5, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 6, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 7, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 8, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 9, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 10, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060728013002, 11, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907013003, 1, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907013003, 2, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907013003, 3, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907013003, 4, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 1, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 2, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 3, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 4, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 5, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 6, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 7, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 8, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 9, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060905013004, 10, 168, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 1, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 2, 80, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 3, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 4, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 5, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 6, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 7, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030418013005, 8, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 1, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 2, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 3, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 4, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 5, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 6, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 7, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 8, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 9, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 10, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 11, 36, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 12, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 13, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 14, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 15, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 16, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424013006, 17, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 1, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 2, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 3, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 4, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 5, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 6, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 7, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 8, 116, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 9, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 10, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 11, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515013007, 12, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 1, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 2, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 3, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 4, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 5, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 6, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 7, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050214013008, 8, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 1, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 2, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 3, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 4, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 5, 22, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 6, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 7, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 8, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 9, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 10, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 11, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 12, 30, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 13, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111013009, 14, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 1, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 2, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 3, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 4, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 5, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010819013010, 6, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 1, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 2, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 3, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 4, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 5, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 6, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 7, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 8, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 9, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 10, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 11, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 12, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 13, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 14, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 15, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140304013011, 16, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123013012, 1, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123013012, 2, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123013012, 3, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123013012, 4, 192, 81, 18, 1458);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 1, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 2, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 3, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 4, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 5, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 6, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 7, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 8, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 9, 103, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 10, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 11, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 12, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205013013, 13, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613013014, 1, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613013014, 2, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613013014, 3, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613013014, 4, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613013014, 5, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 1, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 2, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 3, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 4, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 5, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 6, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 7, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 8, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 9, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 10, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 11, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 12, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 13, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 14, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013015, 15, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 1, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 2, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 3, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 4, 185, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 5, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 6, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 7, 38, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 8, 23, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 9, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 10, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 11, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714013016, 12, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 1, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 2, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 3, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 4, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 5, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 6, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 7, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 8, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 9, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 10, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013017, 11, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 1, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 2, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 3, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 4, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 5, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090921013018, 6, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 6, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 7, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 8, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 9, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 10, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090917011943, 11, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 1, 165, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 2, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 3, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 4, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 5, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 6, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 7, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 8, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 9, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 10, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 11, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 12, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 13, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802011944, 14, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 1, 181, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 2, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 3, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 4, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 6, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 7, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 8, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 9, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 10, 33, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 11, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 12, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 13, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 14, 182, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 15, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 16, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 17, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 18, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106011945, 19, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 1, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 2, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 3, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 4, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 5, 82, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 6, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 7, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 8, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 9, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 10, 6, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 11, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 12, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 13, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120306011946, 14, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 1, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 2, 168, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 3, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 4, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 5, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 6, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 7, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 8, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061031011947, 9, 94, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414011948, 1, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414011948, 2, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000414011948, 3, 157, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 1, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 2, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 3, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 4, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 5, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 6, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 7, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 8, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 9, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317011949, 10, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811011950, 1, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811011950, 2, 77, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811011950, 3, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 1, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 2, 49, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 3, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 4, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 5, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 6, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 7, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 8, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 9, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 10, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080917011951, 11, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 1, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 2, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 3, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 4, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 5, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 6, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121011952, 7, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617011953, 1, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617011953, 2, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617011953, 3, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617011953, 4, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617011953, 5, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614011954, 1, 33, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614011954, 2, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614011954, 3, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614011954, 4, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020614011954, 5, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 1, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 2, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 3, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 4, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 5, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010721011955, 6, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 1, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 2, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 3, 80, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 4, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 5, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 6, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 7, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 8, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 9, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 10, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 11, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 12, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823011956, 13, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 1, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 2, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 3, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 4, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 5, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 6, 65, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 7, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 8, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 9, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 10, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060214011957, 11, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 1, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 2, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 3, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 4, 90, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 5, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 6, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 7, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 8, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 9, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070609011958, 10, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 1, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 2, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 3, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 4, 1, 29, 3, 87);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 5, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 6, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702011959, 7, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 1, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 2, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 3, 56, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 4, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 5, 148, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 6, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 7, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 8, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 9, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 10, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 11, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 12, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 13, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100213011960, 14, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 1, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 2, 168, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 3, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 4, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 5, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 6, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 7, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 8, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 9, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 10, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 11, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 12, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 13, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 14, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 15, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615011961, 16, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 1, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 2, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 3, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 4, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 5, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 6, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 7, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 8, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050805011962, 9, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 1, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 2, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 3, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 4, 192, 48, 18, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 5, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 6, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 7, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 8, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 9, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 10, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 11, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 12, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 13, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 14, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 15, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707011963, 16, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 1, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 2, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 3, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 4, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 5, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 6, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 7, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 8, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 9, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 10, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003011964, 11, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 1, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 2, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 3, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 4, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 5, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 6, 168, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 7, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 8, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 9, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 10, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011965, 11, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 1, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 2, 191, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 3, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 4, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 5, 121, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 6, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 7, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 8, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 9, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040129012337, 6, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 1, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 2, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 3, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 4, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 5, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 6, 167, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 7, 182, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 8, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 9, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 10, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 11, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 12, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 13, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 14, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 15, 180, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 16, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 17, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012338, 18, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 1, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 2, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 3, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 4, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 5, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 6, 2, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 7, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 8, 104, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 9, 188, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 10, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 11, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 12, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408012339, 13, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 1, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 2, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 3, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 4, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 5, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 6, 144, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 7, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 8, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 9, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710012340, 10, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 1, 133, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 2, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 3, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 4, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 5, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 6, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 7, 69, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 8, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 9, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 10, 111, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 11, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 12, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 13, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 14, 107, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 15, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 16, 160, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331012341, 17, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 1, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 2, 15, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 3, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 4, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 5, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 6, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 7, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 8, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 9, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 10, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 11, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804012342, 12, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 1, 53, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 2, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 3, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 4, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 5, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 6, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 7, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 8, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 9, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 10, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 11, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081201012343, 12, 151, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517012344, 1, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000517012344, 2, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 1, 125, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 2, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 3, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 4, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 5, 36, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211012345, 6, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 1, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 2, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 3, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 4, 52, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 5, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 6, 90, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 7, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 8, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 9, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 10, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 11, 71, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 12, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 13, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 14, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 15, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 16, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130012346, 17, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 1, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 2, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 3, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 4, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 5, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 6, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 7, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 8, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060113012347, 9, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012348, 1, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012348, 2, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012348, 3, 187, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012348, 4, 125, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012348, 5, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 1, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 2, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 3, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 4, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 5, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 6, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527012349, 7, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 1, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 2, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 3, 135, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 4, 84, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 5, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 6, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 7, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 8, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 9, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 10, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 11, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 12, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 13, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 14, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 15, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318012350, 16, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 1, 4, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 2, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 3, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 4, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 5, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 6, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 7, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 8, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 9, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 10, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 11, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 12, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 13, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213012351, 14, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 1, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 2, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 3, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 4, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 5, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 6, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 7, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 8, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 9, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 10, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 11, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121012352, 12, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 1, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 2, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 3, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 4, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 5, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 6, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 7, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060126012353, 8, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012354, 1, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012354, 2, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012354, 3, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012354, 4, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012354, 5, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 1, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 2, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 3, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 4, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 5, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 6, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 7, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 8, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050502012355, 9, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 1, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 2, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 3, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 4, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 5, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010012356, 6, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401012357, 1, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401012357, 2, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401012357, 3, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401012357, 4, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401012357, 5, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 1, 66, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 2, 42, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 3, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 4, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 5, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 6, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 7, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 8, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 9, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060517012358, 10, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 1, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 2, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 3, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 4, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 5, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 6, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 7, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 8, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 9, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 10, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 11, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 12, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 13, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 14, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 15, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928012359, 16, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012360, 1, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012360, 2, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012360, 3, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012361, 1, 136, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012361, 2, 30, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012361, 3, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012361, 4, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227012361, 5, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000712012362, 1, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 14, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314012709, 15, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 1, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 2, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 3, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 4, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 5, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 6, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 7, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 8, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 9, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 10, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 11, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 12, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 13, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 14, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 15, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 16, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 17, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 18, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140314012710, 19, 142, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 1, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 2, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 3, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 4, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 5, 6, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 6, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 7, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 8, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050929012711, 9, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 1, 64, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 2, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 3, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 4, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 5, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 6, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 7, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 8, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 9, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 10, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 11, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 12, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 13, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703012712, 14, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329012713, 1, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329012713, 2, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329012713, 3, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000329012713, 4, 143, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 1, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 2, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 3, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 4, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 5, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 6, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 7, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 8, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 9, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080907012714, 10, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214012715, 1, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214012715, 2, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214012715, 3, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214012715, 4, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214012715, 5, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 1, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 2, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 3, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 4, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 5, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 6, 100, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 7, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 8, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050601012716, 9, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 1, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 2, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 3, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 4, 139, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 5, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 6, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 7, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 8, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 9, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 10, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 11, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 12, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 13, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 14, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 15, 79, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 16, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120406012717, 17, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 1, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 2, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 3, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 4, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 5, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 6, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 7, 152, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030408012718, 8, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 1, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 2, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 3, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 4, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 5, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 6, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030331012719, 7, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 1, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 2, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 3, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 4, 23, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 5, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 6, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030610012720, 7, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 1, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 2, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 3, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 4, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 5, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 6, 84, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 7, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 8, 36, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 9, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 10, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 11, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 12, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 13, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 14, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 15, 88, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012721, 16, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 1, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 2, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 3, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 4, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 5, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 6, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 7, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 8, 64, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 9, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 10, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012722, 11, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 1, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 2, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 3, 19, 97, 7, 679);
commit;
prompt 127000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 4, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 5, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 6, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 7, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 8, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926012723, 9, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 1, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 2, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 3, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 4, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 5, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 6, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 7, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060830012724, 8, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 1, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 2, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 3, 43, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 4, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 5, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 6, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 7, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 8, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 9, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 10, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 11, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 12, 103, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105012725, 13, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 1, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 2, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 3, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 4, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 5, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 6, 15, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 7, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 8, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 9, 151, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 10, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 11, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 12, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 13, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 14, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 15, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713012726, 16, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 1, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 2, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 3, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 4, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 5, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 6, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131012727, 7, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 1, 59, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 2, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 3, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 4, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 5, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 6, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 7, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040902012728, 8, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802012729, 1, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802012729, 2, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802012729, 3, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802012729, 4, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 1, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 2, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 3, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 4, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 5, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 6, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 7, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 8, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 9, 141, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 10, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 11, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 12, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 13, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 14, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618012730, 15, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 1, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 2, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 3, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 4, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 5, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 6, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 7, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 8, 144, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 9, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 10, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 11, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100523012731, 12, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 1, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 2, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 3, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 4, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 5, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 6, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 7, 156, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314012732, 8, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 1, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 4, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 5, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 6, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 7, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 8, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 9, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 10, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525013044, 11, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 1, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 2, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 3, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 4, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 5, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 6, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 7, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 8, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 9, 49, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 10, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 11, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 12, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710013045, 13, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 1, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 2, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 3, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 4, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 5, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 6, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013046, 7, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 1, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 2, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 3, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 4, 77, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 5, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 6, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 7, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 8, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719013047, 9, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 1, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 2, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 3, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 4, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 5, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 6, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 7, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 8, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 9, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 10, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 11, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 12, 60, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101013048, 13, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 1, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 2, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 3, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 4, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 5, 168, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 6, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 7, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 8, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 9, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 10, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 11, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 12, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002013049, 13, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 1, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 2, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 3, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 4, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 5, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 6, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 7, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 8, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 9, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702013050, 10, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013051, 1, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013051, 2, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013051, 3, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013051, 4, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 1, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 2, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 3, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 4, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 5, 70, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 6, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428013052, 7, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 1, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 2, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 3, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 4, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 5, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 6, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 7, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 8, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 9, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 10, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 11, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 12, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100129013053, 13, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 1, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 2, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 3, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 4, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 5, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 6, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 7, 3, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 8, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 9, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 10, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 11, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 12, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 13, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 14, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 15, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 16, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422013054, 17, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 1, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 2, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 3, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 4, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 5, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 6, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 7, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 8, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 9, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127013055, 10, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 1, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 2, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 3, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 4, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 5, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 6, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030816013056, 7, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 1, 46, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 2, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 3, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 4, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 5, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013057, 6, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 1, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 2, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 3, 70, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 4, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 5, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 6, 162, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040226013058, 7, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 1, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 2, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 3, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 4, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 5, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 6, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 7, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061225013059, 8, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013060, 1, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013060, 2, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013060, 3, 27, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013060, 4, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622013061, 1, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622013061, 2, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622013061, 3, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622013061, 4, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010622013061, 5, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 1, 27, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 2, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 3, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 4, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 5, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 6, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 7, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 8, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 9, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 10, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 11, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 12, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609013062, 13, 159, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 1, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 2, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 3, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 4, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 5, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 6, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 7, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 8, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 9, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 10, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 11, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109013063, 12, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 1, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 2, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 3, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 4, 28, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 5, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 6, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 7, 14, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 8, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 9, 81, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 10, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 11, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 12, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013064, 13, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 1, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 2, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 3, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 4, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 5, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 6, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 7, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 8, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 9, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 10, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 11, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 12, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 13, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009013065, 14, 152, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315013066, 1, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315013066, 2, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000315013066, 3, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 1, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 2, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 3, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 4, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 5, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 6, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 7, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 8, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 9, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220013067, 10, 57, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 1, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 2, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 3, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 4, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 5, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 6, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 7, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 8, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 9, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 10, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 11, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 12, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091207013068, 13, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 10, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 11, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 12, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 13, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 14, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906011966, 15, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 1, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 2, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 3, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 4, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 5, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 6, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 7, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 8, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 9, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 10, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 11, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620011967, 12, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 1, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 2, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 3, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 4, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 5, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 6, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 7, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 8, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 9, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060217011968, 10, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 1, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 2, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 3, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 4, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 5, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 6, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 7, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 8, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 9, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 10, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 11, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403011969, 12, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 1, 138, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 2, 8, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 3, 108, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 4, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 5, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 6, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 7, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 8, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040924011970, 9, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216011971, 1, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216011971, 2, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216011971, 3, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 1, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 2, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 3, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 4, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 5, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 6, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 7, 192, 43, 18, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 8, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 9, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080104011972, 10, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006011973, 1, 173, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006011973, 2, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006011973, 3, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011006011973, 4, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 1, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 2, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 3, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 4, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 5, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 6, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 7, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 8, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 9, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 10, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525011974, 11, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 1, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 2, 109, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 3, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 4, 1, 49, 3, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 5, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 6, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040103011975, 7, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 1, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 2, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 3, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 4, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 5, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 6, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 7, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 8, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 9, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 10, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 11, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819011976, 12, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217011977, 1, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217011977, 2, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217011977, 3, 15, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000217011977, 4, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 1, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 2, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 3, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 4, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 5, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 6, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031110011978, 7, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 1, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 2, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 3, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 4, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 5, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 6, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 7, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 8, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714011979, 9, 103, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 1, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 2, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 3, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 4, 76, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 5, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 6, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 7, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 8, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 9, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 10, 108, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 11, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 12, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 13, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 14, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 15, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 16, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323011980, 17, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319011981, 1, 187, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319011981, 2, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319011981, 3, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 1, 41, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 2, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 3, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 4, 46, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 5, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 6, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 7, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 8, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 9, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 10, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 11, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 12, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 13, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 14, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 15, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324011982, 16, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 1, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 2, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 3, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 4, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 5, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 6, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 7, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 8, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 9, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070704011983, 10, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 1, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 2, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 3, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 4, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 5, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 6, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 7, 128, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031108011984, 8, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 1, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 2, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 3, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 4, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 5, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 6, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 7, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 8, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 9, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 10, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 11, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 12, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 13, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 14, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131229011985, 15, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 1, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 2, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 3, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 4, 131, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 5, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 6, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 7, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 8, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 9, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 10, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 11, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 12, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 13, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 14, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725011986, 15, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508011987, 1, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508011987, 2, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508011987, 3, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508011987, 4, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010508011987, 5, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 1, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 2, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 3, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 4, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 5, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 6, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 7, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 8, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 9, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 10, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 11, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 12, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 13, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 14, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100207011988, 15, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 1, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 2, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 3, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 4, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 5, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 6, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 7, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 8, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 9, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916011989, 10, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 1, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 2, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 3, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 4, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 5, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 6, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 7, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 8, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 9, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000712012362, 2, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 1, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 2, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 3, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 4, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 5, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204012363, 6, 54, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 1, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 2, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 3, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 4, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 5, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 6, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 7, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 8, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 9, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 10, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 11, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 12, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018012364, 13, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 1, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 2, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 3, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 4, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 5, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 6, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 7, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 8, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 9, 54, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 10, 23, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 11, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 12, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 13, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 14, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729012365, 15, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 1, 53, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 2, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 3, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 4, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 5, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 6, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 7, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 8, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 9, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 10, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071031012366, 11, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 1, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 2, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 3, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 4, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 5, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 6, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 7, 174, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 8, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 9, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060124012367, 10, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 1, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 2, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 3, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 4, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 5, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 6, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 7, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 8, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 9, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 10, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817012368, 11, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121012369, 1, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121012369, 2, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 1, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 2, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 3, 44, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 4, 74, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 5, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 6, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 7, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040820012370, 8, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 1, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 2, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 3, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 4, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 5, 90, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 6, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 7, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 8, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 9, 4, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 10, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 11, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 12, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508012371, 13, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 1, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 2, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 3, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 4, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 5, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 6, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 7, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 8, 18, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 9, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 10, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 11, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 12, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 13, 145, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100716012372, 14, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 1, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 2, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 3, 156, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 4, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 5, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 6, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 7, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613012373, 8, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 1, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 2, 100, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 3, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 4, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 5, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 6, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 7, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 8, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 9, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 10, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070814012374, 11, 63, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 1, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 2, 95, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 3, 51, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 4, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 5, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 6, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 7, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 8, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515012375, 9, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 1, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 2, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 3, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 4, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 5, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 6, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 7, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 8, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 9, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606012376, 10, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 1, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 2, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 3, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 4, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 5, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 6, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 7, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406012377, 8, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 1, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 2, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 3, 58, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 4, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 5, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 6, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 7, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 8, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 9, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080910012378, 10, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 1, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 2, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 3, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 4, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 5, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 6, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 7, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014012379, 8, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923012380, 1, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000923012380, 2, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 1, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 2, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 3, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 4, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 5, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 6, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 7, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 8, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 9, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 10, 192, 43, 18, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080508012381, 11, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 1, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 2, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 3, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 4, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 5, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712012382, 6, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 1, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 2, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 3, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 4, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 5, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 6, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 7, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 8, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 9, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 10, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 11, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 12, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 13, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 14, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 15, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 16, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230012383, 17, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 1, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 2, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 3, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 4, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 5, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 6, 187, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 7, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 8, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208012384, 9, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 1, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 2, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 3, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 4, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 5, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 6, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 7, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 8, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 9, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 10, 103, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 11, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 12, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 13, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 14, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012385, 15, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 1, 1, 76, 3, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 2, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 3, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 4, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 5, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 6, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 7, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 8, 51, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 9, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 10, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 11, 142, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 2, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 3, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 4, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 5, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 6, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 7, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 8, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 9, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 10, 43, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 11, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 12, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 13, 162, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 14, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 15, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 16, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130605012733, 17, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 1, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 2, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 3, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 4, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 5, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 6, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 7, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 8, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129012734, 9, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 1, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 2, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 3, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 4, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 5, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 6, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 7, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 8, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 9, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 10, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 11, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 12, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 13, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120214012735, 14, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012736, 1, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012736, 2, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012736, 3, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012736, 4, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 1, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 2, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 3, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 4, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 5, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205012737, 6, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721012738, 1, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721012738, 2, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721012738, 3, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721012738, 4, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 1, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 2, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 3, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 4, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 5, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 6, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 7, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 8, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050821012739, 9, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 1, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 2, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 3, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 4, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 5, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 6, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 7, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 8, 123, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 9, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 10, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 11, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 12, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 13, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120102012740, 14, 50, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 1, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 2, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 3, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 4, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 5, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 6, 134, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 7, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 8, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 9, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 10, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 11, 172, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100427012741, 12, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 1, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 2, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 3, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 4, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 5, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 6, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 7, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 8, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025012742, 9, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 1, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 2, 141, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 3, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 4, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 5, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 6, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 7, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 8, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 9, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 10, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 11, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 12, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 13, 99, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 14, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111009012743, 15, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 1, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 2, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 3, 121, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 4, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 5, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 6, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 7, 49, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 8, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 9, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 10, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070408012744, 11, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 1, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 2, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 3, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 4, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 5, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 6, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 7, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808012745, 8, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 1, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 2, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 3, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 4, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 5, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 6, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 7, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 8, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 9, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 10, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 11, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 12, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100513012746, 13, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 1, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 2, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 3, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 4, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 5, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 6, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 7, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 8, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 9, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 10, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708012747, 11, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 1, 118, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 2, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 3, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 4, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 5, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 6, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 7, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040625012748, 8, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 1, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 2, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 3, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 4, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 5, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 6, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 7, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 8, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 9, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 10, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012749, 11, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 1, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 2, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 3, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 4, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 5, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 6, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 7, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 8, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 9, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 10, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 11, 26, 42, 7, 294);
commit;
prompt 128000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014012750, 12, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 1, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 2, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 3, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 4, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 5, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 6, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 7, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703012751, 8, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 1, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 2, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 3, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 4, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 5, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 6, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 7, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 8, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 9, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 10, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005012752, 11, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 1, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 2, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 3, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 4, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 5, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113012753, 6, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126012754, 1, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126012754, 2, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126012754, 3, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011126012754, 4, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 1, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 2, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 3, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 4, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 5, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 6, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 7, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 8, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 9, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 10, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 11, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 12, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 13, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 14, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 15, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 16, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 17, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140512012755, 18, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 1, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 2, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 3, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 4, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 5, 108, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 6, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 5, 13, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 6, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 7, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 8, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 9, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 10, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 11, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 12, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 13, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100607011610, 14, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903011611, 1, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903011611, 2, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903011611, 3, 91, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903011611, 4, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 1, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 2, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 3, 165, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 4, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 5, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 6, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 7, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 8, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 9, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 10, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125011612, 11, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301011613, 1, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301011613, 2, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301011613, 3, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301011613, 4, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813011614, 1, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813011614, 2, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813011614, 3, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813011614, 4, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 1, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 2, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 3, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 4, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 5, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 6, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 7, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015011615, 8, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 1, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 2, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 3, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 4, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 5, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020616011616, 6, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 1, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 2, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 3, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 4, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 5, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 6, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 7, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 8, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 9, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 10, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 11, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 12, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 13, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 14, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 15, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130513011617, 16, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 1, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 2, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 3, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 4, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 5, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 6, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020530011618, 7, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 1, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 2, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 3, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 4, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 5, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040513011619, 6, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 1, 91, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 2, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 3, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 4, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 5, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 6, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 7, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 8, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 9, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 10, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915011620, 11, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 1, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 2, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 3, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 4, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 5, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 6, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 7, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 8, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 9, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 10, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 11, 100, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 12, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 13, 29, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 14, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 15, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 16, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527011621, 17, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109011622, 1, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109011622, 2, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109011622, 3, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109011622, 4, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030109011622, 5, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402011623, 1, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402011623, 2, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402011623, 3, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402011623, 4, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 1, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 2, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 3, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 4, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 5, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 6, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 7, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 8, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 9, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 10, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 11, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 12, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 13, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110505011624, 14, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 1, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 2, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 3, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 4, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 5, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 6, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 7, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 8, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 9, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 10, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 11, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 12, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528011625, 13, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 1, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 2, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 3, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 4, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 5, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 6, 51, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 7, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 8, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 9, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 10, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 11, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 12, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 13, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811011626, 14, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 1, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 2, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 3, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 4, 86, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 5, 77, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 6, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 7, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 8, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 9, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 10, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 11, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 12, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 13, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100112011627, 14, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 1, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 2, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 3, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 4, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 5, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 6, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 7, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051204011628, 8, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 1, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 2, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 3, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 4, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 5, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 6, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915011629, 7, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 1, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 2, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 3, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 4, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 5, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 6, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 7, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 8, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 9, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070322011630, 10, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220011631, 1, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220011631, 2, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220011631, 3, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220011631, 4, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220011631, 5, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 1, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 2, 68, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 3, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 4, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 5, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210011632, 6, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 1, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 2, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 3, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 4, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 5, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 6, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 7, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 8, 121, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 9, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 10, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081216011633, 11, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930011634, 1, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930011634, 2, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930011634, 3, 34, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023011635, 1, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023011635, 2, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023011635, 3, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023011635, 4, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023011635, 5, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 1, 31, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 2, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 3, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 4, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 5, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 6, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 7, 32, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 8, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 9, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 10, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 11, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 12, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 13, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 14, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 15, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818011636, 16, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 10, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 11, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 12, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 13, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 14, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 15, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131218011990, 16, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 1, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 2, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 3, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 4, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 5, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 6, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 7, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 8, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 9, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 10, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 11, 176, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 12, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 13, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 14, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 15, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 16, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305011991, 17, 159, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 1, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 2, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 3, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 4, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 5, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 6, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 7, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 8, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 9, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 10, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 11, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 12, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 13, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 14, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 15, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 16, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 17, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131017011992, 18, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 1, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 2, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 3, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 4, 123, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 5, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 6, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 7, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 8, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 9, 49, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 10, 43, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 11, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 12, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 13, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 14, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 15, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 16, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403011993, 17, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429011994, 1, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429011994, 2, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429011994, 3, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010429011994, 4, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 1, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 2, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 3, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 4, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 5, 23, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 6, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 7, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 8, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 9, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 10, 112, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 11, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 12, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 13, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326011995, 14, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 1, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 2, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 3, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 4, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 5, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 6, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 7, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 8, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 9, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 10, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 11, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705011996, 12, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 1, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 2, 161, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 3, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 4, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 5, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 6, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 7, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 8, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 9, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 10, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 11, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 12, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 13, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 14, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 15, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612011997, 16, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618011998, 1, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618011998, 2, 59, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618011998, 3, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618011998, 4, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618011998, 5, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 1, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 2, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 3, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 4, 117, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 5, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 6, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 7, 104, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 8, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 9, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 10, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060426011999, 11, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 1, 173, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 2, 110, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 3, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 4, 30, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 5, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 6, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 7, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130012000, 8, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 1, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 2, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 3, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 4, 53, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 5, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 6, 104, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519012001, 7, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 1, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 2, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 3, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 4, 192, 82, 18, 1476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 5, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 6, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 7, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 8, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 9, 40, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 10, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 11, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070715012002, 12, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 1, 67, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 2, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 3, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 4, 77, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 5, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 6, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 7, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 8, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041101012003, 9, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 1, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 2, 153, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 3, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 4, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 5, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 6, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521012004, 7, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 1, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 2, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 3, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 4, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 5, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 6, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 7, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 8, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 9, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 10, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 11, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 12, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412012005, 13, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 1, 126, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 2, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 3, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 4, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 6, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012006, 7, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928012007, 1, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928012007, 2, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928012007, 3, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928012007, 4, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928012007, 5, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 1, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 2, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 3, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 4, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 5, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 6, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 7, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 8, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 9, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 10, 14, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 11, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 12, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 13, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812012008, 14, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 1, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 2, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 3, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 4, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 5, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 6, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 7, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 8, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 9, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 10, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 11, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 12, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 13, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101110012009, 14, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 1, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 2, 90, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 3, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 4, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 5, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 6, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 7, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 8, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 9, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 10, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 11, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 12, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 13, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101023012010, 14, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 1, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 2, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 3, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 4, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 5, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 6, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 7, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 8, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 12, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 13, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 14, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 15, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325012386, 16, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 1, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 2, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 3, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 4, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 5, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 6, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 7, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 8, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 9, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 10, 186, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 11, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 12, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 13, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 14, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 15, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 16, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 17, 184, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131009012387, 18, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 1, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 2, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 3, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 4, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 5, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 6, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 7, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 8, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 9, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 10, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 11, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912012388, 12, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 1, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 2, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 3, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 4, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 5, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 6, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 7, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205012389, 8, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 1, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 2, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 3, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 4, 38, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 5, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 6, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 7, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 8, 183, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 9, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 10, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 11, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 12, 9, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 13, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029012390, 14, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 1, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 2, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 3, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 4, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 5, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 6, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 7, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 8, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 9, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060813012391, 10, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 1, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 2, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 3, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 4, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 5, 104, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 6, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 7, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 8, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 9, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 10, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 11, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 12, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110313012392, 13, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 1, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 2, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 3, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 4, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 5, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 6, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012393, 7, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 1, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 2, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 3, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 4, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 5, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 6, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 7, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 8, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 9, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 10, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 11, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 12, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 13, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090309012394, 14, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302012395, 1, 136, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302012395, 2, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302012395, 3, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302012395, 4, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302012395, 5, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 1, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 2, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 3, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 4, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 5, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 6, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 7, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 8, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 9, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 10, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 11, 189, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 12, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 13, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212012396, 14, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 1, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 2, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 3, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 4, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 5, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 6, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 7, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 8, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 9, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912012397, 10, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 1, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 2, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 3, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 4, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 5, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806012398, 6, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 1, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 2, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 3, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 4, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 5, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 6, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 7, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 8, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 9, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 10, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 11, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 12, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 13, 7, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 14, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120012399, 15, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014012400, 1, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014012400, 2, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014012400, 3, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014012400, 4, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011014012400, 5, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 1, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 2, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 3, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 4, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 5, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 6, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 7, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 8, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040919012401, 9, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 1, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 2, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 3, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 4, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 5, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 6, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 7, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 8, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 9, 120, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 10, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 11, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 12, 159, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 13, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 14, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 15, 108, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 16, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310012402, 17, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 1, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 2, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 3, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 4, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 5, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 6, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605012403, 7, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001109012404, 1, 99, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001109012404, 2, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001109012404, 3, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001109012404, 4, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001109012404, 5, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 1, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 2, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 3, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 4, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 5, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 6, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 7, 87, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 8, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060307012405, 9, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501012406, 1, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501012406, 2, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501012406, 3, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010501012406, 4, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 1, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 2, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 3, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 4, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 5, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 6, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 7, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 8, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 9, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 10, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 11, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601012407, 12, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 1, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 2, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 3, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 4, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 5, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 6, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 7, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 8, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 9, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 10, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 11, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 12, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 13, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 14, 80, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 15, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110427012408, 16, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 2, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 3, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 7, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 8, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040716012756, 9, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 1, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 2, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 3, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 4, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 5, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 6, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 7, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 8, 88, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 9, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 10, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517012757, 11, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 1, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 2, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 3, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 4, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 5, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 6, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 7, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 8, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 9, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051006012758, 10, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 1, 18, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 2, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 3, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 4, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 5, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 6, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 7, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 8, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 9, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 10, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519012759, 11, 74, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 1, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 2, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 3, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 4, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 5, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 6, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 7, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 8, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 9, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 10, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 11, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 12, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 13, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 14, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 15, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106012760, 16, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 1, 137, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 2, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 3, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 4, 25, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 5, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 6, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 7, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 8, 100, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 9, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 10, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 11, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 12, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 13, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 14, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525012761, 15, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405012762, 1, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405012762, 2, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405012762, 3, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000405012762, 4, 94, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 1, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 2, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 3, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 4, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 5, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 6, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 7, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 8, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 9, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 10, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 11, 97, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 12, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 13, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214012763, 14, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 1, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 2, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 3, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 4, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 5, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 6, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031111012764, 7, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 1, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 2, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 3, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 4, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 5, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 6, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 7, 47, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 8, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 9, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051218012765, 10, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120012766, 1, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120012766, 2, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120012766, 3, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120012766, 4, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120012766, 5, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 1, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 2, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 3, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 4, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 5, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 6, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 7, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 8, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322012767, 9, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 1, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 2, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 3, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 4, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 5, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 6, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 7, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050920012768, 8, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230012769, 1, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230012769, 2, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001230012769, 3, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 1, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 2, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 3, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 4, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 5, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 6, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 7, 91, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 8, 118, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 9, 147, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 10, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 11, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918012770, 12, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120012771, 1, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120012771, 2, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120012771, 3, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120012771, 4, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010120012771, 5, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 1, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 2, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 3, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 4, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 5, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 6, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 7, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 8, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 9, 3, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 10, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 11, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 12, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 13, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 14, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 15, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120412012772, 16, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 1, 87, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 2, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 3, 168, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 4, 107, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 5, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 6, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 7, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 8, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050302012773, 9, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 1, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 2, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 3, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 4, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 5, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 6, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 7, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 8, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 9, 171, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 10, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 11, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070624012774, 12, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 1, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 2, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 3, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 4, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 5, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 6, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 7, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 8, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 9, 155, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 10, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 11, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 12, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 13, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 14, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 15, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014012775, 16, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705012776, 1, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705012776, 2, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705012776, 3, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705012776, 4, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010705012776, 5, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 1, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 2, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 3, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 4, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 5, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 6, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 7, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 8, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 9, 174, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327012777, 10, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012778, 1, 159, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012778, 2, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012778, 3, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717012778, 4, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 1, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 2, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 3, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 4, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 5, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 6, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 7, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828012779, 8, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 1, 174, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 2, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 3, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 4, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 5, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 6, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 7, 108, 79, 10, 790);
commit;
prompt 129000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 8, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 9, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 10, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 11, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 12, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 13, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 14, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110908012780, 15, 85, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 1, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 1, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 2, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 3, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 4, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 5, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 6, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 7, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 8, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 9, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 10, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 11, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519011637, 12, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 1, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 2, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 3, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 4, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 5, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 6, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 7, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 8, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 9, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 10, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 11, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080729011638, 12, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 1, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 2, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 3, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 4, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 5, 18, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 6, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 7, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 8, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 9, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011639, 10, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 1, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 2, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 3, 32, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 4, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 5, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620011640, 6, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 1, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 2, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 3, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 4, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 5, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 6, 105, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 7, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 8, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 9, 27, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 10, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 11, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 12, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 13, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 14, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 15, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517011641, 16, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 1, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 2, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 3, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 4, 128, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 5, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 6, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 7, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 8, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127011642, 9, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 1, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 2, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 3, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 4, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 5, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 6, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013011643, 7, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 1, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 2, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 3, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 4, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 5, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 6, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 7, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 8, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 9, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 10, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 11, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 12, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809011644, 13, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 1, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 2, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 3, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 4, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 5, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 6, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 7, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 8, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 9, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 10, 80, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 11, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 12, 93, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 13, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 14, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120816011645, 15, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 1, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 2, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 3, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 4, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 5, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 6, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 7, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 8, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012011646, 9, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 1, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 2, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 3, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 4, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 5, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 6, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 7, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 8, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 9, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 10, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080731011647, 11, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 1, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 2, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 3, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 4, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 5, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216011648, 6, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802011649, 1, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802011649, 2, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802011649, 3, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802011649, 4, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802011649, 5, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312011650, 1, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312011650, 2, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312011650, 3, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000312011650, 4, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 1, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 2, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 3, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 4, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 5, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 6, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 7, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 8, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 9, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 10, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 11, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 12, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 13, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 14, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110502011651, 15, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011652, 1, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011652, 2, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 1, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 2, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 3, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 4, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 5, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 6, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 7, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 8, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061222011653, 9, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 1, 59, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 2, 36, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 3, 29, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 4, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 5, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010418011654, 6, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 1, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 2, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 3, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 4, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 5, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 6, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 7, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 8, 4, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 9, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 10, 190, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 11, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 12, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 13, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016011655, 14, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 1, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 2, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 3, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 4, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 5, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 6, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 7, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 8, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 9, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204011656, 10, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 1, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 2, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 3, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 4, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 5, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 6, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 7, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 8, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 9, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 10, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 11, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 12, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 13, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803011657, 14, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202011658, 1, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202011658, 2, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202011658, 3, 33, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202011658, 4, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 1, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 2, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 3, 94, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 4, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 5, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 6, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 7, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 8, 113, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 9, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 10, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918011659, 11, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 1, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 2, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 3, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 4, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 5, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 6, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 7, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 8, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 9, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 10, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 11, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 12, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 13, 59, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 14, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110205011660, 15, 143, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 1, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 2, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 3, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 4, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 9, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 10, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 11, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 12, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 13, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 14, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 15, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012011, 16, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 1, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 2, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 3, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 4, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 5, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 6, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041106012012, 7, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 1, 50, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 2, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 3, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 4, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 5, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 6, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 7, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 8, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 9, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313012013, 10, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 1, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 2, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 3, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 4, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 5, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 6, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 7, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 8, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 9, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 10, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 11, 131, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 12, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 13, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 14, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 15, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 16, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121023012014, 17, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 1, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 2, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 3, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 4, 117, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 5, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217012015, 6, 169, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 1, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 2, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 3, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 4, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 5, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020514012016, 6, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717012017, 1, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717012017, 2, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717012017, 3, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717012017, 4, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717012017, 5, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 1, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 2, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 3, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 4, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 5, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 6, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 7, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 8, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 9, 181, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626012018, 10, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105012019, 1, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105012019, 2, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105012019, 3, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105012019, 4, 173, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 1, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 2, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 3, 90, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 4, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 5, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 6, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 7, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707012020, 8, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012021, 1, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012021, 2, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012021, 3, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000126012021, 4, 37, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 1, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 2, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 3, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 4, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 5, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 6, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 7, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 8, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910012022, 9, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 1, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 2, 53, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 3, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 4, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 5, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 6, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 7, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 8, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 9, 113, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 10, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 11, 92, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 12, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 13, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 14, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 15, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 16, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130706012023, 17, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404012024, 1, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404012024, 2, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404012024, 3, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000404012024, 4, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304012025, 1, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304012025, 2, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304012025, 3, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304012025, 4, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304012025, 5, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718012026, 1, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718012026, 2, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718012026, 3, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718012026, 4, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010718012026, 5, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202012027, 1, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202012027, 2, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202012027, 3, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202012027, 4, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202012027, 5, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 1, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 2, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 3, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 4, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 5, 109, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 6, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 7, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 8, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 9, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051212012028, 10, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 1, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 2, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 3, 3, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 4, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 5, 111, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 6, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 7, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 8, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 9, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 10, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 11, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 12, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 13, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917012029, 14, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 1, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 2, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 3, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 4, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 5, 171, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 6, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 7, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 8, 104, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 9, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 10, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 11, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 12, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 13, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 14, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 15, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 16, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624012030, 17, 110, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 1, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 2, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 3, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 4, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 5, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 6, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 7, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 8, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 9, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 10, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 11, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 12, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 13, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603012031, 14, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 1, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 2, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 3, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 4, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 5, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 6, 24, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 7, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 8, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 9, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 10, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 11, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 12, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 13, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106012032, 14, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719012033, 1, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719012033, 2, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719012033, 3, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719012033, 4, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020719012033, 5, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 1, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 2, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 3, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 4, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 5, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 6, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 7, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 8, 46, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 9, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 10, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 11, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 12, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 13, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 14, 163, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711012034, 15, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 1, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 2, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 3, 109, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 4, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 5, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003012035, 6, 151, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 1, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 2, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 3, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 4, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 5, 18, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 6, 180, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 7, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 8, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 9, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 10, 10, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 11, 174, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817012036, 12, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 1, 139, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 4, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 5, 88, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 6, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 7, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 8, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 9, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 10, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714012409, 11, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 1, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 2, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 3, 116, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 4, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 5, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 6, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 7, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 8, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 9, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 10, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 11, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 12, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 13, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 14, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607012410, 15, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 1, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 2, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 3, 124, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 4, 171, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 5, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 6, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 7, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 8, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 9, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 10, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 11, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511012411, 12, 19, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 1, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 2, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 3, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 4, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 5, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 6, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 7, 73, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 8, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060612012412, 9, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 1, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 2, 80, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 3, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 4, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 5, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 6, 176, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 7, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 8, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 9, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 10, 180, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 11, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 12, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 13, 127, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 14, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 15, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012413, 16, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 1, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 2, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 3, 3, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 4, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 5, 82, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 6, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 7, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104012414, 8, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 1, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 2, 120, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 3, 180, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 4, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 5, 15, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 6, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 7, 84, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 8, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 9, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 10, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 11, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 12, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 13, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910012415, 14, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 1, 160, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 2, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 3, 179, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 4, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 5, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 6, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 7, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 8, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 9, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 10, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 11, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 12, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 13, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120720012416, 14, 152, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 1, 39, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 2, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 3, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 4, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 5, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 6, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012417, 8, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 1, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 2, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 3, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 4, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 5, 177, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 6, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 7, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 8, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 9, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070523012418, 10, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 1, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 2, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 3, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 4, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 5, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 6, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 7, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 8, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 9, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 10, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 11, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 12, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 13, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 14, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 15, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131012012419, 16, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 1, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 2, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 3, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 4, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 5, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218012420, 6, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 1, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 2, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 3, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 4, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 5, 17, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 6, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 7, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 8, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 9, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 10, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 11, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 12, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 13, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 14, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 15, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221012421, 16, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406012422, 1, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406012422, 2, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406012422, 3, 178, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 1, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 2, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 3, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 4, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 5, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 6, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 7, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 8, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 9, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 10, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 11, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 12, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 13, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 14, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 15, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 16, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121126012423, 17, 49, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 1, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 2, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 3, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 4, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 5, 182, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 6, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 7, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 8, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 9, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 10, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 11, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 12, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 13, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 14, 104, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 15, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113012424, 16, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128012425, 1, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128012425, 2, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128012425, 3, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128012425, 4, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020128012425, 5, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715012426, 1, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715012426, 2, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715012426, 3, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 1, 18, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 2, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 3, 134, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 4, 20, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 5, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118012427, 6, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 1, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 2, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 3, 191, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 4, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 5, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 6, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 7, 32, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 8, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 9, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 10, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 11, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 12, 169, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 13, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423012428, 14, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412012429, 1, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412012429, 2, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412012429, 3, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412012429, 4, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030412012429, 5, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 1, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 2, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 3, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 4, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 5, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 6, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 7, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 8, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 9, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 10, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 11, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 12, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 13, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 14, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 15, 164, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 16, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506012430, 17, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 1, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 2, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 3, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 4, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 5, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 6, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428012781, 7, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 1, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 2, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 3, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 4, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 5, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 6, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 7, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 8, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 9, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701012782, 10, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 1, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 2, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 3, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 4, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 5, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 6, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 7, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 8, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 9, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 10, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 11, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 12, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 13, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 14, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 15, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120709012783, 16, 69, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 1, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 2, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 3, 181, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 4, 78, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 5, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 6, 69, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323012784, 7, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112012785, 1, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112012785, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112012785, 3, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112012785, 4, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112012785, 5, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 1, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 2, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 3, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 4, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 5, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 6, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119012786, 7, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 1, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 2, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 3, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 4, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 5, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 6, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128012787, 7, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012788, 1, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012788, 2, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012788, 3, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012788, 4, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607012788, 5, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 1, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 2, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 3, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 4, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 5, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 6, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 7, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 8, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 9, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 10, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 11, 123, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 12, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 13, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819012789, 14, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 1, 174, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 2, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 3, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 4, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 5, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 6, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 7, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616012790, 8, 143, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211012791, 1, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211012791, 2, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211012791, 3, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211012791, 4, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020211012791, 5, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222012792, 1, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222012792, 2, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222012792, 3, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222012792, 4, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222012792, 5, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 1, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 2, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 3, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 4, 25, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 5, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 6, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031231012793, 7, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 1, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 2, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 3, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 4, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 5, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 6, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 7, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 8, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 9, 109, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 10, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 11, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 12, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 13, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925012794, 14, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 1, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 2, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 3, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 4, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 5, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 6, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 7, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 8, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 9, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 10, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 11, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070120012795, 12, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 1, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 2, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 3, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 4, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 5, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 6, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 7, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 8, 30, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 9, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012796, 10, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012797, 1, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012797, 2, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012797, 3, 80, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012797, 4, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101012797, 5, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 1, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 2, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 3, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 4, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 5, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 6, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 7, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 8, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 9, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 10, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 11, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 12, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 13, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012798, 14, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 1, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 2, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 3, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 4, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 5, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015012799, 6, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 1, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 2, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 3, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 4, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 5, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 6, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 7, 16, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 8, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 9, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 10, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 11, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 12, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 13, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 14, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 15, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620012800, 16, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 1, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 2, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 3, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 4, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 5, 29, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 6, 149, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122012801, 7, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 1, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 2, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 3, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 4, 141, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 5, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 6, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 7, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 8, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 9, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 10, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402012802, 11, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 1, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 2, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 3, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 4, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 5, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 6, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222012803, 7, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 1, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 2, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 3, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 4, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 5, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 6, 179, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 7, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 8, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 9, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 10, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 11, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 12, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 13, 167, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 14, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 15, 163, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120111012804, 16, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 1, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 2, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 3, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 4, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 5, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 6, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 7, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 8, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 9, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070709012805, 10, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 1, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 2, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 3, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 4, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 5, 80, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 6, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 7, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 8, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 9, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 5, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020629011661, 6, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 1, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 2, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 3, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 4, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 5, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405011662, 6, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 1, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 2, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 3, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 4, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 5, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 6, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 7, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 8, 105, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 9, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 10, 182, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 11, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 12, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 13, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 14, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717011663, 15, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 1, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 2, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 3, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 4, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 5, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 6, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 7, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 8, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 9, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 10, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 11, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 12, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 13, 178, 68, 11, 748);
commit;
prompt 130000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 14, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101209011664, 15, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 1, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 2, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 3, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 4, 176, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 5, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 6, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 7, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 8, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728011665, 9, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 1, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 2, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 3, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 4, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 5, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 6, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 7, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 8, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060827011666, 9, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 1, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 2, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 3, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 4, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 5, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 6, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 7, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 8, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 9, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 10, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 11, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108011667, 12, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 1, 104, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 2, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 3, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 4, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 5, 49, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 6, 180, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 7, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 8, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 9, 8, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 10, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 11, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 12, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100918011668, 13, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 1, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 2, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 3, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 4, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 5, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 6, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 7, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 8, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 9, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 10, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 11, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 12, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 13, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 14, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 15, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 16, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417011669, 17, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 1, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 2, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 3, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 4, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 5, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 6, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 7, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522011670, 8, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305011671, 1, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305011671, 2, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305011671, 3, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 1, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 2, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 3, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 4, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 5, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 6, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 7, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 8, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 9, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 10, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823011672, 11, 17, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 1, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 2, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 3, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 4, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 5, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020818011673, 6, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 1, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 2, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 3, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 4, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 5, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 6, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 7, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 8, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 9, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 10, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 11, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 12, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 13, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211011674, 14, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 1, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 2, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 3, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 4, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 5, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 6, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 7, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 8, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 9, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 10, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 11, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 12, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 13, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127011675, 14, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 1, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 2, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 3, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 4, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 5, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 6, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 7, 118, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 8, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 9, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060723011676, 10, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 1, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 2, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 3, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 4, 77, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 5, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 6, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 7, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 8, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050720011677, 9, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 1, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 2, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 3, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 4, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 5, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 6, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 7, 142, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 8, 53, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 9, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 10, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 11, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 12, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 13, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 14, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110206011678, 15, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 1, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 2, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 3, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 4, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 5, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 6, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 7, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 8, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 9, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 10, 49, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 11, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 12, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 13, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 14, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 15, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129011679, 16, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 1, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 2, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 3, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 4, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 5, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 6, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 7, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 8, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 9, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 10, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 11, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 12, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 13, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 14, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 15, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 16, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226011680, 17, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 1, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 2, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 3, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 4, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 5, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423011681, 6, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 1, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 2, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 3, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 4, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 5, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 6, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 7, 30, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 8, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 9, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 10, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 11, 170, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919011682, 12, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 2, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 3, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 4, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 5, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 6, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425012037, 7, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 1, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 2, 32, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 3, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 4, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 5, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 6, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 7, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 8, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 9, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 10, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 11, 10, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 12, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 13, 131, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 14, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211012038, 15, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 1, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 2, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 3, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 4, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 5, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 6, 42, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 7, 9, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 8, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 9, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425012039, 10, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 1, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 2, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 3, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 4, 54, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 5, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 6, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 7, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 8, 192, 18, 18, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006012040, 9, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 1, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 2, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 3, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 4, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 5, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 6, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 7, 143, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 8, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 9, 40, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 10, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070211012041, 11, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 1, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 2, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 3, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 4, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 5, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 6, 159, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 7, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 8, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 9, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 10, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 11, 40, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 12, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 13, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100715012042, 14, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 1, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 2, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 3, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 4, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 5, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 6, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 7, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 8, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 9, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 10, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 11, 1, 49, 3, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 12, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 13, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 14, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 15, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717012043, 16, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 1, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 2, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 3, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 4, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 5, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 6, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 7, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 8, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 9, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 10, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 11, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 12, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 13, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210012044, 14, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 1, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 2, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 3, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 4, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 5, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 6, 48, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 7, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 8, 111, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 9, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 10, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 11, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 12, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 13, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802012045, 14, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 1, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 2, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 3, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 4, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 5, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 6, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 7, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 8, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 9, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 10, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 11, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 12, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 13, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 14, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 15, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 16, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131006012046, 17, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227012047, 1, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227012047, 2, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227012047, 3, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227012047, 4, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227012047, 5, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 1, 159, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 2, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 3, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 4, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 5, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 6, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 7, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 8, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 9, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 10, 101, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 11, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 12, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 13, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 14, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805012048, 15, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317012049, 1, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317012049, 2, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317012049, 3, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317012049, 4, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317012049, 5, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 1, 173, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 2, 72, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 3, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 4, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 5, 101, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 6, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 7, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040916012050, 8, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 1, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 2, 189, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 3, 150, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 4, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 5, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 6, 95, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 7, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 8, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 9, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 10, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 11, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 12, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 13, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 14, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100827012051, 15, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 1, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 2, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 3, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 4, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 5, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 6, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 7, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 8, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 9, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 10, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 11, 34, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 12, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 13, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 14, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 15, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 16, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120101012052, 17, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 1, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 2, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 3, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 4, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 5, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 6, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 7, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 8, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 9, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 10, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 11, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 12, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 13, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 14, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 15, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 16, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723012053, 17, 163, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 1, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 2, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 3, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 4, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 5, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 6, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 7, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 8, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 9, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 10, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930012054, 11, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 1, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 2, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 3, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 4, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 5, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 6, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020807012055, 7, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 1, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 2, 109, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 3, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 4, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 5, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030822012056, 6, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 1, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 2, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 3, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 4, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 5, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 6, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 7, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 2, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 3, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 4, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 5, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 6, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 7, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 8, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 9, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 10, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 11, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 12, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 13, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 14, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 15, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130317012431, 16, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 1, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 2, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 3, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 4, 72, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 5, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 6, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 7, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 8, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 9, 121, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 10, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 11, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 12, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 13, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 14, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 15, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117012432, 16, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628012433, 1, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628012433, 2, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628012433, 3, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628012433, 4, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628012433, 5, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 1, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 2, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 3, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 4, 72, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 5, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 6, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 7, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 8, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 9, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 10, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 11, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 12, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603012434, 13, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103012435, 1, 106, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103012435, 2, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103012435, 3, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 1, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 2, 15, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 3, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 4, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 5, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 6, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507012436, 7, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 1, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 2, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 3, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 4, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 5, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 6, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 7, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 8, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 9, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 10, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 11, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 12, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 13, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 14, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 15, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622012437, 16, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 1, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 2, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 3, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 4, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 5, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 6, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 7, 101, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 8, 146, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 9, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 10, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011012438, 11, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001112012439, 1, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001112012439, 2, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 1, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 2, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 3, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 4, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 5, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 6, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 7, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 8, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 9, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 10, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 11, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 12, 127, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 13, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 14, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129012440, 15, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 1, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 2, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 3, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 4, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 5, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 6, 167, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 7, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060709012441, 8, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 1, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 2, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 3, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 4, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 5, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 6, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 7, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 8, 61, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 9, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 10, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 11, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 12, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 13, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 14, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917012442, 15, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 1, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 2, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 3, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 4, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 5, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 6, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 7, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 8, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 9, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 10, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 11, 139, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 12, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 13, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 14, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 15, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501012443, 16, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911012444, 1, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911012444, 2, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911012444, 3, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911012444, 4, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 1, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 2, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 3, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 4, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 5, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 6, 57, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 7, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416012445, 8, 147, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 1, 30, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 2, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 3, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 4, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 5, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 6, 187, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 7, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010012446, 8, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012447, 1, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012447, 2, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012447, 3, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012447, 4, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 1, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 2, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 3, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 4, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 5, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 6, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 7, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 8, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 9, 16, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 10, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070505012448, 11, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012449, 1, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429012449, 2, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 1, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 2, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 3, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 4, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 5, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 6, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 7, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 8, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406012450, 9, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 1, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 2, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 3, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 4, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 5, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 6, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 7, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 8, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 9, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 10, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 11, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090824012451, 12, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116012452, 1, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116012452, 2, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010116012452, 3, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 1, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 2, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 3, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 4, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 5, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 6, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 7, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 8, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 9, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 10, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 11, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 12, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 13, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 14, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 15, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 16, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712012453, 17, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322012454, 1, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322012454, 2, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322012454, 3, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322012454, 4, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322012454, 5, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 1, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 2, 6, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 3, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 4, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 5, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 6, 125, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 7, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 8, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 9, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 10, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 11, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 12, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 13, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 14, 36, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061125012806, 10, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 1, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 2, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 3, 36, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 4, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 5, 94, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 6, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 7, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 8, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 9, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070703012807, 10, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 1, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 2, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 3, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 4, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 5, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 6, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 7, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 8, 151, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 9, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 10, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 11, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 12, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 13, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 14, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120605012808, 15, 83, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 1, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 2, 131, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 3, 65, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 4, 27, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 5, 192, 48, 18, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 6, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 7, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 8, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 9, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 10, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 11, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 12, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 13, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 14, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 15, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402012809, 16, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 1, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 2, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 3, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 4, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 5, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 6, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 7, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 8, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 9, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 10, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 11, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 12, 1, 7, 3, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 13, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 14, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 15, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 16, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 17, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323012810, 18, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125012811, 1, 179, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125012811, 2, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125012811, 3, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125012811, 4, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 1, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 2, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 3, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 4, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 5, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 6, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 7, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 8, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 9, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 10, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 11, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 12, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 13, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 14, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 15, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 16, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012812, 17, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 1, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 2, 111, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 3, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 4, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 5, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 6, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 7, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430012813, 8, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 1, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 2, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 3, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 4, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 5, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 6, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 7, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 8, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 9, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 10, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 11, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602012814, 12, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031012815, 1, 146, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031012815, 2, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 1, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 2, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 3, 9, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 4, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 5, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 6, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 7, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 8, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 9, 136, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 10, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 11, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 12, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090325012816, 13, 116, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 1, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 2, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 3, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 4, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 5, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 6, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 7, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 8, 50, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518012817, 9, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907012818, 1, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907012818, 2, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907012818, 3, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907012818, 4, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030907012818, 5, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 1, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 2, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 3, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 4, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 5, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 6, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 7, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 8, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 9, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 10, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 11, 58, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 12, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 13, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 14, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 15, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 16, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114012819, 17, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 1, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 2, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 3, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 4, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 5, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 6, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 7, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 8, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 9, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 10, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 11, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 12, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 13, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 14, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 15, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823012820, 16, 157, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 1, 69, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 2, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 3, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 4, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 5, 79, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 6, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 7, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 8, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070630012821, 9, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 1, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 2, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 3, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 4, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 5, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 6, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 7, 46, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 8, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 9, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 10, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405012822, 11, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 1, 1, 80, 3, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 2, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 3, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 4, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 5, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 6, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826012823, 7, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 1, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 2, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 3, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 4, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 5, 135, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 6, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 7, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 8, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 9, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 10, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 11, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 12, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 13, 189, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 14, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 15, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 16, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 17, 88, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 18, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514012824, 19, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 1, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 2, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 3, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 4, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 5, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902012825, 6, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 1, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 2, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 3, 30, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 4, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 5, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 6, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229012826, 7, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 1, 89, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 2, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 3, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 4, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 5, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 6, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 7, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130012827, 8, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 1, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 2, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 3, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 4, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 5, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 6, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 7, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 8, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 9, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 1, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 2, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 3, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 4, 53, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 5, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 6, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 7, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 8, 24, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 9, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 10, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090331011683, 11, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 1, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 2, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 3, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 4, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 5, 186, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 6, 166, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 7, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 8, 152, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 9, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 10, 50, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 11, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 12, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 13, 90, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 14, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 15, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014011684, 16, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 1, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 2, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 3, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 4, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 5, 1, 4, 3, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 6, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 7, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409011685, 8, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 1, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 2, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 3, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 4, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 5, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108011686, 6, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 1, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 2, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 3, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 4, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 5, 96, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 6, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821011687, 7, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 1, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 2, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 3, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 4, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 5, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 6, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 7, 34, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 8, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 9, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 10, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 11, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 12, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 13, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 14, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 15, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705011688, 16, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 1, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 2, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 3, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 4, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 5, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 6, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 7, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 8, 123, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 9, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 10, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 11, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 12, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 13, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 14, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 15, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109011689, 16, 158, 18, 15, 270);
commit;
prompt 131000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 1, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 2, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 3, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 4, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 5, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 6, 27, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 7, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040920011690, 8, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 1, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 2, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 3, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 4, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 5, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 6, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 7, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 8, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 9, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 10, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070928011691, 11, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 1, 29, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 2, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 3, 13, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 4, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 5, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 6, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 7, 183, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 8, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 9, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 10, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 11, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090609011692, 12, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222011693, 1, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222011693, 2, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222011693, 3, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011222011693, 4, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 1, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 2, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 3, 124, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 4, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 5, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608011694, 6, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209011695, 1, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209011695, 2, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209011695, 3, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209011695, 4, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209011695, 5, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 1, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 2, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 3, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 4, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 5, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 6, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 7, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 8, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 9, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429011696, 10, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 1, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 2, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 3, 55, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 4, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 5, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 6, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 7, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210011697, 8, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322011698, 1, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322011698, 2, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322011698, 3, 55, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322011698, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 1, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 2, 140, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 3, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 4, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 5, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 6, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605011699, 7, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 1, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 2, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 3, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 4, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 5, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 6, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 7, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 8, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 9, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 10, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 11, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 12, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 13, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 14, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 15, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 16, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140318011700, 17, 110, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 1, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 2, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 3, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 4, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 5, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 6, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 7, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 8, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 9, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 10, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 11, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 12, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 13, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 14, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128011701, 15, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 1, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 2, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 3, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 4, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 5, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 6, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 7, 58, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 8, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 9, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 10, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 11, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 12, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100205011702, 13, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207011703, 1, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000207011703, 2, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011704, 1, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011704, 2, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011704, 3, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605011704, 4, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 1, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 2, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 3, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 4, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 5, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 6, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 7, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228011705, 8, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625011706, 1, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625011706, 2, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625011706, 3, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625011706, 4, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625011706, 5, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018011707, 1, 174, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018011707, 2, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018011707, 3, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018011707, 4, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018011707, 5, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717011708, 1, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717011708, 2, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717011708, 3, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010717011708, 4, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525011709, 1, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000525011709, 2, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 1, 109, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 2, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 3, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 4, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 5, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 6, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 7, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 8, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 9, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 8, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 9, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 10, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 11, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 12, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 13, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 14, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 15, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 16, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130601012057, 17, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 1, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 2, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 3, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 4, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 5, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 6, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 7, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 8, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 9, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 10, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 11, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 12, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 13, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 14, 179, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 15, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 16, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 17, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131104012058, 18, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 1, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 2, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 3, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 4, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 5, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 6, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 7, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 8, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 9, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 10, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 11, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 12, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 13, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111101012059, 14, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 1, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 2, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 3, 34, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 4, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 5, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 6, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 7, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 8, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012060, 9, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 1, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 2, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 3, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 4, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 5, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 6, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 7, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040603012061, 8, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 1, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 2, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 3, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 4, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 5, 89, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 6, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 7, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 8, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 9, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 10, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 11, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 12, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 13, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 14, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513012062, 15, 83, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615012063, 1, 78, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615012063, 2, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000615012063, 3, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 1, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 2, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 3, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 4, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 5, 185, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 6, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 7, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 8, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 9, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 10, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 11, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 12, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615012064, 13, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 1, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 2, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 3, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 4, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 5, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 6, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 7, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 8, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 9, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070610012065, 10, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 1, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 2, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 3, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 4, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 5, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 6, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 7, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 8, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 9, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 10, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090512012066, 11, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619012067, 1, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619012067, 2, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619012067, 3, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 1, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 2, 37, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 3, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 4, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 5, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 6, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 7, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050317012068, 8, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 1, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 2, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 3, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 4, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 5, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 6, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521012069, 7, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 1, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 2, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 3, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 4, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 5, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 6, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 7, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 8, 25, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 9, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 10, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 11, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 12, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 13, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512012070, 14, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 1, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 2, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 3, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 4, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 5, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 6, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 7, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 8, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 9, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 10, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 11, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 12, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 13, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 14, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 15, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 16, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731012071, 17, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 1, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 2, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 3, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 4, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 5, 53, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 6, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 7, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 8, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 9, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 10, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 11, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 12, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328012072, 13, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 1, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 2, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 3, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 4, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 5, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 6, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 7, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 8, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 9, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 10, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213012073, 11, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 1, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 2, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 3, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 4, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 5, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 6, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 7, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 8, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 9, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015012074, 10, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 1, 5, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 2, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 3, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 4, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 5, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 6, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 7, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 8, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203012075, 9, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 1, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 2, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 3, 33, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 4, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 5, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 6, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 7, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 8, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 9, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 10, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080906012076, 11, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 1, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 2, 174, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 3, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 4, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 5, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 6, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 7, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 8, 57, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 9, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 10, 103, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 11, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 12, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 13, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 14, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 15, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722012077, 16, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125012078, 1, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125012078, 2, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 1, 172, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 2, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 3, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 4, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 5, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522012079, 6, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 1, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100718012455, 15, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 1, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 2, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 3, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 4, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 5, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 6, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 7, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 8, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 9, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 10, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430012456, 11, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 1, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 2, 32, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 3, 79, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 4, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 5, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 6, 52, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126012457, 7, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 1, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 2, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 3, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 4, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 5, 50, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 6, 41, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 7, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 8, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 9, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205012458, 10, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 1, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 2, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 3, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 4, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 5, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020715012459, 6, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 1, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 2, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 3, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 4, 166, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 5, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 6, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 7, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 8, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 9, 125, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 10, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 11, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 12, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 13, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 14, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 15, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609012460, 16, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 1, 118, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 2, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 3, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 4, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 5, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 6, 163, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 7, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 8, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114012461, 9, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 1, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 2, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 3, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 4, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 5, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 6, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 7, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 8, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 9, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 10, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 11, 22, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 12, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816012462, 13, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 1, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 2, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 3, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 4, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 5, 11, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 6, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 7, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 8, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 9, 56, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 10, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 11, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 12, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 13, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 14, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 15, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 16, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910012463, 17, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012464, 1, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012464, 2, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012464, 3, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012464, 4, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030214012464, 5, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 1, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 2, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 3, 107, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 4, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 5, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 6, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 7, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 8, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 9, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 10, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 11, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011012465, 12, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 1, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 2, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 3, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 4, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 5, 148, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 6, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 7, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 8, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101012466, 9, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 1, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 2, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 3, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 4, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 5, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 6, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 7, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 8, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 9, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 10, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 11, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 12, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 13, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 14, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 15, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 16, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011012467, 17, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 1, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 2, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 3, 17, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 4, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 5, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 6, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 7, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 8, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 9, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206012468, 10, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 1, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 2, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 3, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 4, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 5, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 6, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040730012469, 7, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120012470, 1, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120012470, 2, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120012470, 3, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 1, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 2, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 3, 132, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 4, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 5, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 6, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 7, 8, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 8, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 9, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 10, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 11, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 12, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710012471, 13, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 1, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 2, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 3, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 4, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 5, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 6, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 7, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 8, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 9, 117, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 10, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 11, 35, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 12, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 13, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 14, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111023012472, 15, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 1, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 2, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 3, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 4, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 5, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 6, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 7, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 8, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 9, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 10, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 11, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 12, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615012473, 13, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622012474, 1, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622012474, 2, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622012474, 3, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622012474, 4, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 1, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 2, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 3, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 4, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 5, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 6, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 7, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 8, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 9, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081018012475, 10, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 1, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 2, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 3, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 4, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 5, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 6, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 7, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 8, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 9, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 10, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 11, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 12, 19, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202012476, 13, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411012477, 1, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411012477, 2, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411012477, 3, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 1, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 2, 137, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 3, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 4, 160, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 5, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 6, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 7, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 8, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 9, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 10, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 11, 169, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 12, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 13, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 14, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111120012478, 15, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 10, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 11, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 12, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 13, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090914012828, 14, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 1, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 2, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 3, 103, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 4, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 5, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 6, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 7, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 8, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 9, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050721012829, 10, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 1, 122, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 2, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 3, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 4, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 5, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 6, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 7, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 8, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 9, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 10, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 11, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 12, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 13, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 14, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 15, 154, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 16, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123012830, 17, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 1, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 2, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 3, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 4, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 5, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 6, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031012012831, 7, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 1, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 2, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 3, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 4, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 5, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 6, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 7, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 8, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 9, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 10, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 11, 177, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 12, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 13, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 14, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 15, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924012832, 16, 115, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 1, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 2, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 3, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 4, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 5, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 6, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503012833, 7, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 1, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 2, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 3, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 4, 39, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 5, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 6, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 7, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 8, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 9, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 10, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071111012834, 11, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621012835, 1, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621012835, 2, 63, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621012835, 3, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621012835, 4, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621012835, 5, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108012836, 1, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108012836, 2, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108012836, 3, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021108012836, 4, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 1, 181, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 2, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 3, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 4, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 5, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 6, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 7, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 8, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 9, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 10, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 11, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 12, 77, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100219012837, 13, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 1, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 2, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 3, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 4, 19, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 5, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 6, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 7, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 8, 182, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 9, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 10, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 11, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 12, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 13, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 14, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 15, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110318012838, 16, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827012839, 1, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827012839, 2, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827012839, 3, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827012839, 4, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 1, 58, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 2, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 3, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 4, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 5, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 6, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031130012840, 7, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 1, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 2, 132, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 3, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 4, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 5, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 6, 145, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 7, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050316012841, 8, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 1, 180, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 2, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 3, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 4, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 5, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 6, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 7, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 8, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 9, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 10, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060324012842, 11, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 1, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 2, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 3, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 4, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 5, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 6, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 7, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 8, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 9, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 10, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 11, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 12, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 13, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 14, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 15, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511012843, 16, 24, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 1, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 2, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 3, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 4, 127, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 5, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 6, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 7, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 8, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 9, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 10, 167, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 11, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 12, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110507012844, 13, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 1, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 2, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 3, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 4, 131, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 5, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 6, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617012845, 7, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 1, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 2, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 3, 78, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 4, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 5, 20, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 6, 18, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 7, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 8, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 9, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927012846, 10, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 1, 76, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 2, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 3, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 4, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 5, 116, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 6, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 7, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 8, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060222012847, 9, 11, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 1, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 2, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 3, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 4, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 5, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 6, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805012848, 7, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 1, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 2, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 3, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 4, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 5, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 6, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 7, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 8, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 9, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051226012849, 10, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 1, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 2, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 3, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 4, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 5, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 6, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 7, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129012850, 8, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 1, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 2, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 3, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 4, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 5, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 6, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 7, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 8, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 9, 36, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 10, 88, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 11, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 12, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 13, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 14, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 15, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 16, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310012851, 17, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026012852, 1, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 10, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 11, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 12, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 13, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604011710, 14, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 1, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 2, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 3, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 4, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 5, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 6, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 7, 160, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 8, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 9, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 10, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226011711, 11, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702011712, 1, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702011712, 2, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702011712, 3, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702011712, 4, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702011712, 5, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 1, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 2, 45, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 3, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 4, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 5, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 6, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 7, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830011713, 8, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 1, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 2, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 3, 132, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 4, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 5, 25, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 6, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 7, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 8, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 9, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 10, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070328011714, 11, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 1, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 2, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 3, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 4, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 5, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 6, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 7, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 8, 166, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061223011715, 9, 134, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 1, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 2, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 3, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 4, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 5, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 6, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 7, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 8, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 9, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 10, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 11, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 12, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 13, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 14, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 15, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918011716, 16, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 1, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 2, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 3, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 4, 101, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 5, 91, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 6, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 7, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 8, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109011717, 9, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011718, 1, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011718, 2, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011718, 3, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011718, 4, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001029011718, 5, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 1, 40, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 2, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 3, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 4, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 5, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519011719, 6, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 1, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 2, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 3, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 4, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 5, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 6, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 7, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 8, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011720, 9, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 1, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 2, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 3, 99, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 4, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 5, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 6, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 7, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 8, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 9, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 10, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 11, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 12, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 13, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 14, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 15, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 16, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 17, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124011721, 18, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 1, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 2, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 3, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 4, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 5, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 6, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 7, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 8, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050607011722, 9, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011723, 1, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011723, 2, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011723, 3, 77, 34, 10, 340);
commit;
prompt 132000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 1, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 2, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 3, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 4, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 5, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 6, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 7, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 8, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 9, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 10, 187, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808011724, 11, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 1, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 2, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 3, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 4, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 5, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 6, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 7, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040912011725, 8, 154, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 1, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 2, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 3, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 4, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 5, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822011726, 6, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 1, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 2, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 3, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 4, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 5, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 6, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 7, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 8, 16, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 9, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 10, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 11, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 12, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 13, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 14, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 15, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928011727, 16, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 1, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 2, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 3, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 4, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 5, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 6, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 7, 71, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 8, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519011728, 9, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 1, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 2, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 3, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 4, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 5, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 6, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 7, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219011729, 8, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 1, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 2, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 3, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 4, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 5, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 6, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 7, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 8, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 9, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309011730, 10, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 1, 110, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 2, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 3, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 4, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 5, 24, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 6, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 7, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 8, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 9, 166, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 10, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 11, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 12, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 13, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917011731, 14, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 1, 39, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 2, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 3, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 4, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 5, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 6, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 7, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 8, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 9, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 10, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223011732, 11, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011733, 1, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011733, 2, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000110011733, 3, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 1, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 2, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 3, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 4, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 5, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311011734, 6, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 1, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 2, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 3, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 4, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 5, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111011735, 6, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 1, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 2, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 3, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 4, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 5, 143, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 6, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041118011736, 7, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 2, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 3, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 4, 31, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 5, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710012080, 6, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011012081, 1, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011012081, 2, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011012081, 3, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011012081, 4, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012082, 1, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012082, 2, 9, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012082, 3, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012082, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511012082, 5, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206012083, 1, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206012083, 2, 49, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206012083, 3, 119, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206012083, 4, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206012083, 5, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 1, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 2, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 3, 189, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 4, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 5, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 6, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 7, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 8, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 9, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 10, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 11, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 12, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 13, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 14, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 15, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 16, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 17, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408012084, 18, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206012085, 1, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206012085, 2, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206012085, 3, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206012085, 4, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910012086, 1, 14, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910012086, 2, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910012086, 3, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910012086, 4, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 1, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 2, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 3, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 4, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 5, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 6, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 7, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029012087, 8, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 1, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 2, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 3, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 4, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 5, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 6, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 7, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 8, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 9, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101012088, 10, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 1, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 2, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 3, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 4, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 6, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116012089, 7, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 1, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 2, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 3, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 4, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 5, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 6, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 7, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 8, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 9, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 10, 111, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 11, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 12, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104012090, 13, 76, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711012091, 1, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711012091, 2, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010711012091, 3, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427012092, 1, 93, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427012092, 2, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427012092, 3, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427012092, 4, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427012092, 5, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107012093, 1, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107012093, 2, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107012093, 3, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107012093, 4, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 1, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 2, 86, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 3, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 4, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 5, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 6, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 7, 108, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223012094, 8, 116, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531012095, 1, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531012095, 2, 192, 95, 18, 1710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010531012095, 3, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 1, 81, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 2, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 3, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 4, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 5, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 6, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 7, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 8, 151, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 9, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 10, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 11, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 12, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 13, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 14, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803012096, 15, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 1, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 2, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 3, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 4, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 5, 143, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010115012097, 6, 50, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 1, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 2, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 3, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 4, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 5, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 6, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 7, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031119012098, 8, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 1, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 2, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 3, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 4, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 5, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 6, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 7, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 8, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 9, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 10, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 11, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 12, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 13, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 14, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 15, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 16, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130226012099, 17, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612012100, 1, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612012100, 2, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612012100, 3, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612012100, 4, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012101, 1, 152, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012101, 2, 117, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012101, 3, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012101, 4, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012101, 5, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 1, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 2, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 3, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 4, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 5, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 6, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 7, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 8, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116012102, 9, 44, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 1, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 2, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 3, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 4, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 5, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 6, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424012103, 7, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 1, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 2, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 3, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 4, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 5, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 6, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 7, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 8, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 9, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 10, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 11, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 12, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 13, 60, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100815012104, 14, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 1, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 2, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 3, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 4, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 6, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 7, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 8, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 9, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604012105, 10, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 1, 168, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 2, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 3, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 4, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 5, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 6, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 7, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 8, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 9, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 10, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 11, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821012106, 12, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 1, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 2, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 3, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 5, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 6, 58, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627012107, 7, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205012108, 1, 115, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205012108, 2, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205012108, 3, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205012108, 4, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 1, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 2, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 3, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 4, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 5, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 6, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 7, 100, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 8, 113, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 9, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070620012109, 10, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 1, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 2, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 3, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 4, 90, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 5, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 1, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 2, 69, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 3, 190, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 4, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 5, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 6, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 7, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 8, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040821012479, 9, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 1, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 2, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 3, 31, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 4, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 5, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 6, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 7, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 8, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050510012480, 9, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126012481, 1, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126012481, 2, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126012481, 3, 3, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126012481, 4, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126012481, 5, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012482, 1, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012482, 2, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012482, 3, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012482, 4, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030609012482, 5, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 1, 140, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 2, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 3, 151, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 4, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 5, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 6, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021226012483, 7, 174, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 1, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 2, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 3, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 4, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 5, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 6, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 7, 129, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 8, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 9, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 10, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 11, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 12, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 13, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111119012484, 14, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 1, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 2, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 3, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 4, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 5, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 6, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 7, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 8, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227012485, 9, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 1, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 2, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 3, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 4, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 5, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 6, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 7, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 8, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 9, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 10, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 11, 65, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090628012486, 12, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 1, 189, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 2, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 3, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 4, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 5, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 6, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 7, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809012487, 8, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 1, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 2, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 3, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 4, 9, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 5, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 6, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 7, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 8, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 9, 105, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 10, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 11, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 12, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 13, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905012488, 14, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 2, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 3, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 4, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 5, 174, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 6, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 7, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 8, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 9, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 10, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 11, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 12, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100503012489, 13, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 1, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 2, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 3, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 4, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 5, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030512012490, 6, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 1, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 2, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 3, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 4, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 5, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 6, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 7, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 8, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 9, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 10, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101012491, 11, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 1, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 2, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 3, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 4, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 5, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 6, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 7, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 8, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 9, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 10, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 11, 135, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 12, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 13, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 14, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122012492, 15, 185, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 1, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 2, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 3, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 4, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 5, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 6, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 7, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 8, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 9, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 10, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 11, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 12, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 13, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 14, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901012493, 15, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214012494, 1, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214012494, 2, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214012494, 3, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214012494, 4, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214012494, 5, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 1, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 2, 1, 56, 3, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 3, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 4, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 5, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521012495, 6, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 1, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 2, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 3, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 4, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 5, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 6, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 7, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 8, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040305012496, 9, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 1, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 2, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 3, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 4, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 5, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 6, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 7, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 8, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 9, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012497, 10, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 1, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 2, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 3, 96, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 4, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 5, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 6, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 7, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 8, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 9, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 10, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 11, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 12, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617012498, 13, 111, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 1, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 2, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 3, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 4, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 5, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 6, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 7, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 8, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 9, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 10, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 11, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 12, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100710012499, 13, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 1, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 2, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 3, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 4, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 5, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 6, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 7, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 8, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 9, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 10, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 11, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 12, 109, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 13, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 14, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 15, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 16, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716012500, 17, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 1, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 2, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 3, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 4, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 5, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010714012501, 6, 6, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 1, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 2, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 3, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 4, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 5, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226012502, 6, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 1, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820012503, 2, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026012852, 2, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026012852, 3, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011026012852, 4, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 1, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 2, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 3, 64, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 4, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 5, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 6, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 7, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 8, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 9, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 10, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081118012853, 11, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 1, 76, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 2, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 3, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 4, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 5, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 6, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 7, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 8, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303012854, 9, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118012855, 1, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118012855, 2, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118012855, 3, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118012855, 4, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012856, 1, 33, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012856, 2, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012856, 3, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620012856, 4, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 1, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 2, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 3, 167, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 4, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 5, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 6, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 7, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 8, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 9, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 10, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 11, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 12, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 13, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 14, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 15, 130, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126012857, 16, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 1, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 2, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 3, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 4, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 5, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040211012858, 6, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 1, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 2, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 3, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 4, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 5, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 6, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 7, 24, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 8, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 9, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 10, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 11, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 12, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 13, 90, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321012859, 14, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 1, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 2, 157, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 3, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 4, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 5, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 6, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 7, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 8, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 9, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 10, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 11, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 12, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 13, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 14, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 15, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 16, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114012860, 17, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 1, 14, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 2, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 3, 118, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 4, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 5, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 6, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 7, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 8, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 9, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 10, 89, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 11, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 12, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 13, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 14, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 15, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212012861, 16, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 1, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 2, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 3, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 4, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 5, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 6, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 7, 172, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 8, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 9, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102012862, 10, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 1, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 2, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 3, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 4, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 5, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 6, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 7, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 8, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 9, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 10, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 11, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 12, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 13, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 14, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 15, 143, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 16, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 17, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812012863, 18, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 1, 175, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 2, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 3, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 4, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 5, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 6, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 7, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427012864, 8, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610012865, 1, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610012865, 2, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610012865, 3, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610012865, 4, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 1, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 2, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 3, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 4, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 5, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 6, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 7, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 8, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 9, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 10, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801012866, 11, 72, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813012867, 1, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813012867, 2, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813012867, 3, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813012867, 4, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010813012867, 5, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 1, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 2, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 3, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 4, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 5, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 6, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 7, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 8, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 9, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 10, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 11, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 12, 112, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 13, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 14, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110606012868, 15, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 1, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 2, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 3, 92, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 4, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 5, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 6, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 7, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051028012869, 8, 117, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 1, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 2, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 3, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 4, 76, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 5, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 6, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223012870, 7, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 1, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 2, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 3, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 4, 17, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 5, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 6, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 7, 71, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 8, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 9, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 10, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 11, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 12, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 13, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 14, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 15, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110616012871, 16, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319012872, 1, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319012872, 2, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319012872, 3, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319012872, 4, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319012872, 5, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 1, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 2, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 3, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 4, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 5, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 6, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 7, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 8, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 9, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 10, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 11, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 12, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108012873, 13, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 1, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 2, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 3, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 4, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 5, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 6, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 7, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 8, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 9, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 10, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 11, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 12, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110601012874, 13, 19, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 1, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 2, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 3, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 4, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 5, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511012875, 6, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 1, 108, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 2, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 3, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 4, 96, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 5, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 6, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 7, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 8, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 9, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 10, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 11, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 12, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 13, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 14, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 15, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131210011737, 16, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 1, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 2, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 3, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 4, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 5, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 6, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 7, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 8, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 9, 185, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 10, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 11, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 12, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 13, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 14, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 15, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806011738, 16, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 1, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 2, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 3, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 4, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 5, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006011739, 6, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 1, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 2, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 3, 113, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 4, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 5, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 6, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 7, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 8, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 9, 131, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 10, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 11, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 12, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 13, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 14, 59, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 15, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430011740, 16, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 1, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 2, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 3, 168, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 4, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 5, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 6, 178, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 7, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 8, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 9, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 10, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 11, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 12, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 13, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100522011741, 14, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 1, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 2, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 3, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 4, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 5, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810011742, 6, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310011743, 1, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310011743, 2, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310011743, 3, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310011743, 4, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 1, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 2, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 3, 150, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 4, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 5, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 6, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 7, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 8, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 9, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 10, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 11, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080421011744, 12, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 1, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 2, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 3, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 4, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 5, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 6, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 7, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 8, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 9, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 10, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 11, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 12, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 13, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 14, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 15, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130821011745, 16, 13, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 1, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 2, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 3, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 4, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 5, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 6, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 7, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819011746, 8, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 1, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 2, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 3, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 4, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 5, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 6, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 7, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 8, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 9, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110011747, 10, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 1, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 2, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 3, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 4, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 5, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 6, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 7, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 8, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 9, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 10, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 11, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 12, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 13, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121211011748, 14, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 1, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 2, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 3, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 4, 92, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 5, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 6, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 7, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 8, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 9, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227011749, 10, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 1, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 2, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 3, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 4, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 5, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 6, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 7, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 8, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926011750, 9, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011751, 1, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011751, 2, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011751, 3, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011751, 4, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021218011751, 5, 139, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 1, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 2, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 3, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 4, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 5, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 6, 121, 11, 9, 99);
commit;
prompt 133000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625011752, 7, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011753, 1, 144, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011753, 2, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011753, 3, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805011753, 4, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 1, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 2, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 3, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 4, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 5, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 6, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 7, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 8, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 9, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 10, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 11, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 12, 90, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 13, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 14, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 15, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021011754, 16, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 1, 87, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 2, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 3, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 4, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 5, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 6, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 7, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 8, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 9, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 10, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 11, 65, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 12, 159, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 13, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 14, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307011755, 15, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 1, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 2, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 3, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 4, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 5, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 6, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 7, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 8, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 9, 190, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315011756, 10, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 1, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 2, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 3, 20, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 4, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 5, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 6, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 7, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 8, 181, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 9, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 10, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 11, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 12, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 13, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 14, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 15, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 16, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 17, 164, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130311011757, 18, 133, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 1, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 2, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 3, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 4, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 5, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110828011758, 6, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 6, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 7, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 8, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901012110, 9, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 1, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 2, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 3, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 4, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 5, 192, 6, 18, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 6, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 7, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 8, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061012012111, 9, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 1, 97, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 2, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 3, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 4, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 5, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 6, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 7, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 8, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 9, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 10, 33, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 11, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826012112, 12, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 1, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 2, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 3, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 4, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 5, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210012113, 6, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 1, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 2, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 3, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 4, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 5, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 6, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 7, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 8, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 9, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 10, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 11, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 12, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 13, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 14, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 15, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620012114, 16, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 1, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 2, 141, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 3, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 4, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 5, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 6, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040123012115, 7, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000309012116, 1, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000309012116, 2, 178, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000309012116, 3, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000309012116, 4, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707012117, 1, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707012117, 2, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707012117, 3, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707012117, 4, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905012118, 1, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905012118, 2, 101, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905012118, 3, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905012118, 4, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905012118, 5, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 1, 159, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 2, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 3, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 4, 170, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 5, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 6, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826012119, 7, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 1, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 2, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 3, 115, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 4, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 5, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 6, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 7, 31, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 8, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 9, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 10, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514012120, 11, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 1, 133, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 2, 42, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 3, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 4, 93, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 5, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 6, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 7, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 8, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 9, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 10, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 11, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 12, 173, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 13, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 14, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 15, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 16, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 17, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222012121, 18, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012122, 1, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012122, 2, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012122, 3, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004012122, 4, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 1, 84, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 2, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 3, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 4, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 5, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 6, 83, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 7, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 8, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 9, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 10, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 11, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612012123, 12, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 1, 122, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 2, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 3, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 4, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 5, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 6, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 7, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 8, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 9, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 10, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 11, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 12, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730012124, 13, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 1, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 2, 5, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 3, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 4, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 5, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 6, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 7, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 8, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 9, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 10, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 11, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 12, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 13, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 14, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 15, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130414012125, 16, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 1, 78, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 2, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 3, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 4, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 5, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 6, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 7, 177, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 8, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 9, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060625012126, 10, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208012127, 1, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208012127, 2, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208012127, 3, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208012127, 4, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208012127, 5, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 1, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 2, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 3, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 4, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 5, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 6, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 7, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 8, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 9, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 10, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 11, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012128, 12, 150, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 1, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 2, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 3, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 4, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 5, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 6, 69, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 7, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 8, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 9, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070110012129, 10, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 1, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 2, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 3, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 4, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 5, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 6, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902012130, 7, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506012131, 1, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506012131, 2, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506012131, 3, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 1, 183, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 2, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 3, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 4, 147, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 5, 175, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 6, 103, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 7, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 8, 168, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 9, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 10, 171, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 11, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 12, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100928012132, 13, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 1, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 2, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 3, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 4, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 5, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 6, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 7, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 8, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 9, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080504012133, 10, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 1, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 2, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 3, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 4, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 5, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 6, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 7, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315012134, 8, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012135, 1, 152, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012135, 2, 178, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012135, 3, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012135, 4, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020531012135, 5, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 1, 59, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 2, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 3, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 4, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 5, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 6, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030420012136, 7, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430012137, 1, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 5, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 6, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 7, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 8, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 9, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 10, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010424013638, 1, 118, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010424013638, 2, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010424013638, 3, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010424013638, 4, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010424013638, 5, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 1, 134, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 2, 114, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 3, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 4, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 5, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030103013639, 6, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 1, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 2, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 3, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 4, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 5, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020213013640, 6, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 1, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 2, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 3, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 4, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 5, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 6, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806013641, 7, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 1, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 2, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 3, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 4, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 5, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 6, 25, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 7, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 8, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 9, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013642, 10, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 1, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 2, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 3, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 4, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 5, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 6, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 7, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 8, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 9, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013643, 10, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 1, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 2, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 3, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 4, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 5, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 6, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 7, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 8, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 9, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 10, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 11, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090318013644, 12, 192, 60, 18, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506013645, 1, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506013645, 2, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506013645, 3, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506013645, 4, 169, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020506013645, 5, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 1, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 2, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 3, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 4, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 5, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 6, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 7, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 8, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 9, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 10, 61, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 11, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 12, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 13, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 14, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 15, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012013646, 16, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 1, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 2, 28, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 3, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 4, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 5, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 6, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 7, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 8, 43, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 9, 44, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 10, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 11, 126, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 12, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 13, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 14, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226013647, 15, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 1, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 2, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 3, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 4, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 5, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020712013648, 6, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 1, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 2, 139, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 3, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 4, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 5, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 6, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 7, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 8, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 9, 48, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 10, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013649, 11, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 1, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 2, 86, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 3, 178, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 4, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 5, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 6, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 7, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 8, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 9, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 10, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 11, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 12, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080416013650, 13, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 1, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 2, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 3, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 4, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 5, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 6, 101, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 7, 9, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 8, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 9, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 10, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 11, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 12, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 13, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 14, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130725013651, 15, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513013652, 1, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513013652, 2, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513013652, 3, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513013652, 4, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010513013652, 5, 12, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 1, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 2, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 3, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 4, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 5, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 6, 120, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 7, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 8, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 9, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 10, 27, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707013653, 11, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 1, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 2, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 3, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 4, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 5, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 6, 105, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 7, 139, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 8, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 9, 89, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 10, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 11, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 12, 185, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 13, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100604013654, 14, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 1, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 2, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 3, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 4, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 5, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 6, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 7, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 8, 77, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 9, 136, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 10, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 11, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 12, 176, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 13, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 14, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 15, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 16, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602013655, 17, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 1, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 2, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 3, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 4, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 5, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 6, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 7, 23, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 8, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 9, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 10, 93, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 11, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 12, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 13, 43, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 14, 190, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 15, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 16, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120318013656, 17, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 1, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 2, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 3, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 4, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 5, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 6, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 7, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 8, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050529013657, 9, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 1, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 2, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 3, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 4, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 5, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 6, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050227013658, 7, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 1, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 2, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 3, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 4, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 5, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827013659, 6, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 1, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 2, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 3, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 4, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 5, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 6, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 7, 4, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 8, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 9, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 10, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 14, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 15, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 16, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 17, 22, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 1, 56, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 2, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 3, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 4, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 5, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 6, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830014017, 7, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 1, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 2, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 3, 136, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 4, 142, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 5, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 6, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 7, 180, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 8, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 9, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 10, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081224014018, 11, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014019, 1, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014019, 2, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 1, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 2, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 3, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 4, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 5, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 6, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 7, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 8, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 9, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 10, 91, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 11, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090507014020, 12, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 1, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 2, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 3, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 4, 20, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 5, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 6, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 7, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014021, 8, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 1, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 2, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 3, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 4, 104, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 5, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 6, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 7, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607014022, 8, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 1, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 2, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 3, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 4, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 5, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 6, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 7, 143, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041112014023, 8, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 1, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 2, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 3, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 4, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 5, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 6, 34, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 7, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 8, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 9, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 10, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 11, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014024, 12, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 1, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 2, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 3, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 4, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 5, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 6, 190, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 7, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014025, 8, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 1, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 2, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 3, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 4, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 5, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 6, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 7, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 8, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 9, 51, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 10, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 11, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 12, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 13, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 14, 70, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 15, 180, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 16, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628014026, 17, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 1, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 2, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 3, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 4, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 5, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 6, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 7, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 8, 9, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 9, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 10, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 11, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 12, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 13, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 14, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014027, 15, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 1, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 2, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 3, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 4, 28, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 5, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 6, 120, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 7, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 8, 30, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 9, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 10, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 11, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 12, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 13, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213014028, 14, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 1, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 2, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 3, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 4, 36, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 5, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513014029, 6, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 1, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 2, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 3, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 4, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 5, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 6, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 7, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 8, 121, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 9, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 10, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 11, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 12, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111230014030, 13, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014031, 1, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014031, 2, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014031, 3, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014031, 4, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 1, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 2, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 3, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 4, 24, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 5, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 6, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324014032, 7, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 1, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 2, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 3, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 4, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 5, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 6, 167, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040104014033, 7, 188, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 1, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 2, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 3, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 4, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 5, 182, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020826014034, 6, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 1, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 2, 95, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 3, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 4, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 5, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 6, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 7, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 8, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 9, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050910014035, 10, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 1, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 2, 31, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 3, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 4, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 5, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 6, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 7, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 8, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 9, 20, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 10, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081102014036, 11, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 1, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 2, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 3, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 4, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 5, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 6, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 7, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 8, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 9, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 10, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 11, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 12, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 13, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 14, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 15, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 16, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 17, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014037, 18, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 1, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 2, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 3, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 4, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 5, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 6, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 7, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 8, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 9, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 10, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 11, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 12, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 13, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 14, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 15, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 16, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 17, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014038, 18, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 1, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 2, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 3, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 4, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 5, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 6, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 7, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 8, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 9, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 10, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 11, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 12, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 13, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 4, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 5, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 6, 71, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 1, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 2, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 3, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 4, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 5, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 6, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 7, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130014380, 8, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 1, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 2, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 3, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 4, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 5, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 6, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 7, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 8, 82, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 9, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050525014381, 10, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 1, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 2, 1, 99, 3, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 3, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 4, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 5, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628014382, 6, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 1, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 2, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 3, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 4, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 5, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 6, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 7, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 8, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 9, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 10, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 11, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 12, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520014383, 13, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 1, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 2, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 3, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 4, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 5, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 6, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 7, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 8, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810014384, 9, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 1, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 2, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 3, 120, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 4, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 5, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 6, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 7, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 8, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 9, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 10, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 11, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 12, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 13, 27, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 14, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 15, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110223014385, 16, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 1, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 2, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 3, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 4, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 5, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 6, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 7, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 8, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051129014386, 9, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 1, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 2, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 3, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 4, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 5, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 6, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050923014387, 7, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 1, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 2, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 3, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 4, 121, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 5, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 6, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 7, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 8, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 9, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 10, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 11, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722014388, 12, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014389, 1, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014389, 2, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014389, 3, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014389, 4, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014389, 5, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 1, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 2, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 3, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 4, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 5, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 6, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051010014390, 7, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 1, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 2, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 3, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 4, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 5, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 6, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 7, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 8, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 9, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 10, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 11, 24, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220014391, 12, 165, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819014392, 1, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000819014392, 2, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000328014393, 1, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000328014393, 2, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 1, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 2, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 3, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 4, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 5, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 6, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 7, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 8, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 9, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 10, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 11, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 12, 177, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 13, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 14, 185, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 15, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 16, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 17, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514014394, 18, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 1, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 2, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 3, 121, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 4, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 5, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 6, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 7, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 8, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060416014395, 9, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701014396, 1, 162, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701014396, 2, 148, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701014396, 3, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701014396, 4, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010701014396, 5, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 1, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 2, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 3, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 4, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 5, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 6, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 7, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 8, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 9, 74, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 10, 111, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218014397, 11, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 1, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 2, 167, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 3, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 4, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 5, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 6, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 7, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 8, 10, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 9, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 10, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 11, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091027014398, 12, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 1, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 2, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 3, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 4, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 5, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 6, 125, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 7, 145, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014014399, 8, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 1, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 2, 85, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 3, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 4, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 5, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 6, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 7, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 8, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 9, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 10, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 11, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 12, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 13, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 14, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 15, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 16, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 17, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140114014400, 18, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 1, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 2, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 3, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 4, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 5, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 6, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 7, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923014401, 8, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 1, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 2, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 3, 128, 79, 16, 1264);
commit;
prompt 134000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 4, 37, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 5, 120, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014402, 6, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 1, 103, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 2, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 3, 3, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 4, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 5, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 6, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 7, 42, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 8, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 9, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 10, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 11, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 12, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 13, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619014403, 14, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 1, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 2, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 3, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 4, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 5, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 6, 1, 47, 3, 141);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 7, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 8, 56, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 9, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 11, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 12, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 13, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 1, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 2, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 3, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 4, 145, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 5, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106013255, 6, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 1, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 2, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 3, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 4, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 5, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 6, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 7, 177, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 8, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 9, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 10, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 11, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 12, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013256, 13, 148, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013257, 1, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013257, 2, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013257, 3, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022013258, 1, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022013258, 2, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022013258, 3, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022013258, 4, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 1, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 2, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 3, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 4, 128, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 5, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 6, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 7, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040131013259, 8, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 1, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 2, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 3, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 4, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 5, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 6, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 7, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 8, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 9, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 10, 116, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 11, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 12, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 13, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 14, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618013260, 15, 134, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 1, 27, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 2, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 3, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 4, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 5, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 6, 103, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 7, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 8, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 9, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 10, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 11, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 12, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 13, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324013261, 14, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020920013262, 1, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020920013262, 2, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020920013262, 3, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020920013262, 4, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 1, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 2, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 3, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 4, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 5, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 6, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 7, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 8, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 9, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 10, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080409013263, 11, 192, 46, 18, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 1, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 2, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 3, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 4, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 5, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 6, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 7, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050427013264, 8, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013265, 1, 125, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013265, 2, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013265, 3, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515013266, 1, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515013266, 2, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515013266, 3, 55, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515013266, 4, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 1, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 2, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 3, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 4, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 5, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 6, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 7, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 8, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 9, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 10, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 11, 119, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 12, 23, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 13, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100407013267, 14, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 1, 179, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 2, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 3, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 4, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 5, 102, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 6, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 7, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 8, 133, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 9, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 10, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 11, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 12, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 13, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 14, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120506013268, 15, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911013269, 1, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911013269, 2, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000911013269, 3, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 1, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 2, 50, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 3, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 4, 191, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 5, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607013270, 6, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 1, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 2, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 3, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 4, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 5, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 6, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 7, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 8, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013271, 9, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 1, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 2, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 3, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 4, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 5, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004013272, 6, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 1, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 2, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 3, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 4, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 5, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 6, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 7, 8, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 8, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 9, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 10, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 11, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 12, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 13, 168, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090104013273, 14, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 1, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 2, 98, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 3, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 4, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 5, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 6, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 7, 94, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 8, 150, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 9, 27, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 10, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 11, 164, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 12, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 13, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 14, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120309013274, 15, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 1, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 2, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 3, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 4, 137, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 5, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 6, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 7, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 8, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 9, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 10, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 11, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 12, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 13, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013275, 14, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 1, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 2, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 3, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 4, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 5, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 6, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007013276, 7, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 1, 142, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 2, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 3, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 4, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 5, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 6, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 7, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 8, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 9, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 10, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 11, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 12, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 13, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 14, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402013277, 15, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 1, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 2, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 3, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 4, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 5, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 6, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 7, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 8, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 9, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 10, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 11, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 12, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 13, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 14, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 15, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120428013278, 16, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 1, 11, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 2, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 3, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 4, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 5, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 6, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 7, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 8, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 9, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 11, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 12, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 13, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121103013660, 14, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 1, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 2, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 3, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 4, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 5, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 6, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 7, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 8, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 9, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 10, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 11, 48, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 12, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 13, 49, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 14, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 15, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 16, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130326013661, 17, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 1, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 2, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 3, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 4, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 5, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013662, 6, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 1, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 2, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 3, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 4, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 5, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 6, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 7, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 8, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 9, 126, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 10, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 11, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 12, 59, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 13, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013663, 14, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 1, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 2, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 3, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 4, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 5, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 6, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 7, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 8, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 9, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 10, 82, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 11, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 12, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 13, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 14, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110301013664, 15, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 1, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 2, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 3, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 4, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 5, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 6, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706013665, 7, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 1, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 2, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 3, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 4, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 5, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 6, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 7, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 8, 41, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 9, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 10, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 11, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 12, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 13, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111013666, 14, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 1, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 2, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 3, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 4, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 5, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013667, 6, 2, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 1, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 2, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 3, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 4, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 5, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 6, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 7, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 8, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 9, 111, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 10, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918013668, 11, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 1, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 2, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 3, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 4, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 5, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329013669, 6, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 1, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 2, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 3, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 4, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 5, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 6, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 7, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 8, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 9, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 10, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 11, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100218013670, 12, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 1, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 2, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 3, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 4, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 5, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013671, 6, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 1, 89, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 2, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 3, 146, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 4, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 5, 58, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 6, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 7, 184, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 8, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 9, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 10, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 11, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 12, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091212013672, 13, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 1, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 2, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 3, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 4, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 5, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 6, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 7, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 8, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 9, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061011013673, 10, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 1, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 2, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 3, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 4, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 5, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 6, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 7, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 8, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 9, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 10, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 11, 70, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 12, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 13, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100120013674, 14, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816013675, 1, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816013675, 2, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816013675, 3, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816013675, 4, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816013675, 5, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 1, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 2, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 3, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 4, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 5, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 6, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 7, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 8, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 9, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 10, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 11, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 12, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 13, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 14, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100602013676, 15, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 1, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 2, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 3, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 4, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 5, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 6, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 7, 49, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 8, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 9, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 10, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 11, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 12, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 13, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 14, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 15, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 16, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130903013677, 17, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 1, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 2, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 3, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 4, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 5, 143, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 6, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040826013678, 7, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 1, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 2, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 3, 44, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 4, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 5, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 6, 163, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 7, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 8, 13, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 9, 152, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013679, 10, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 1, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 2, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 3, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 4, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 5, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 6, 40, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 7, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 8, 20, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 9, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 10, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 11, 96, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 12, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080914013680, 13, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207013681, 1, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207013681, 2, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207013681, 3, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207013681, 4, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010207013681, 5, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 1, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 2, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 3, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 4, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 5, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 6, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 7, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 8, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 9, 86, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 10, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 11, 107, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 12, 154, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 14, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 15, 1, 27, 3, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217014039, 16, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 1, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 2, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 3, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 4, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 5, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 6, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 7, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 8, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 9, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070219014040, 10, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 1, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 2, 2, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 3, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 4, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 5, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 6, 51, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 7, 162, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 8, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 9, 156, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 10, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513014041, 11, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 1, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 2, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 3, 152, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 4, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 5, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 6, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 7, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 8, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040910014042, 9, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 1, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 2, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 3, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 4, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 5, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 6, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 7, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 8, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 9, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 10, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081003014043, 11, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 1, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 2, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 3, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 4, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 5, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 6, 83, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 7, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 8, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 9, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 10, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 11, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070920014044, 12, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 1, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 2, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 3, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 4, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 5, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 6, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 7, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 8, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 9, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 10, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 11, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 12, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 13, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101126014045, 14, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 1, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 2, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 3, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 4, 85, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 5, 102, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 6, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 7, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 8, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060330014046, 9, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 1, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 2, 81, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 3, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 4, 18, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 5, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 6, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 7, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 8, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 9, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 10, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 11, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 12, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 13, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 14, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 15, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 16, 57, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220014047, 17, 157, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 1, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 2, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 3, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 4, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 5, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 6, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 7, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 8, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 9, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 10, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 11, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 12, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328014048, 13, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014049, 1, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014049, 2, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014049, 3, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 1, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 2, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 3, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 4, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 5, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 6, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 7, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 8, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 9, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 10, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 11, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 12, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 13, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 14, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 15, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 16, 85, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014050, 17, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 1, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 2, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 3, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 4, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 5, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 6, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721014051, 7, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 1, 72, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 2, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 3, 189, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 4, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 5, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 6, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 7, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 8, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 9, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 10, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 11, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081120014052, 12, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 1, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 2, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 3, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 4, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 5, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 6, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 7, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 8, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 9, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 10, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 11, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114014053, 12, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 1, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 2, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 3, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 4, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 5, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 6, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 7, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 8, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040927014054, 9, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 1, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 2, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 3, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 4, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 5, 176, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 6, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 7, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 8, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105014055, 9, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113014056, 1, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113014056, 2, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113014056, 3, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001113014056, 4, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 1, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 2, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 3, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 4, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 5, 79, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 6, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 7, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 8, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 9, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 10, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115014057, 11, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308014058, 1, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308014058, 2, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308014058, 3, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308014058, 4, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020308014058, 5, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 1, 35, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 2, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 3, 140, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 4, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 5, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 6, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 7, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 8, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 9, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014059, 10, 64, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 1, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 2, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 3, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 4, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 5, 26, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 6, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 7, 182, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 8, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 9, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 10, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060701014060, 11, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901014061, 1, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901014061, 2, 96, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901014061, 3, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020901014061, 4, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 1, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 2, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 3, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 4, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 5, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 6, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 7, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 8, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 9, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 10, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 11, 181, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 12, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 13, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 14, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 15, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130401014062, 16, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 10, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 11, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 12, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 13, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 14, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 15, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409014404, 16, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516014405, 1, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516014405, 2, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516014405, 3, 107, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516014405, 4, 139, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516014405, 5, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813014406, 1, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813014406, 2, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813014406, 3, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813014406, 4, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 1, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 2, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 3, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 4, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 5, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 6, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 7, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 8, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 9, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 10, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 11, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 12, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116014407, 13, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 1, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 2, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 3, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 4, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 5, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 6, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203014408, 7, 32, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 1, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 2, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 3, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 4, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 5, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 6, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915014409, 7, 178, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 1, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 2, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 3, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 4, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 5, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 6, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 7, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 8, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 9, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080418014410, 10, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 1, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 2, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 3, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 4, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 5, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 6, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 7, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 8, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 9, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 10, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 11, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 12, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 13, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 14, 121, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 15, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 16, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 17, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014411, 18, 73, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014412, 1, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014412, 2, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014412, 3, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014412, 4, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014412, 5, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604014413, 1, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604014413, 2, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604014413, 3, 156, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604014413, 4, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604014413, 5, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 1, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 2, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 3, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 4, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 5, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 6, 118, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804014414, 7, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 1, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 2, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 3, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 4, 26, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 5, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 6, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014415, 7, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014416, 1, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014416, 2, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014416, 3, 165, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014416, 4, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014416, 5, 37, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014417, 1, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014417, 2, 125, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014417, 3, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014417, 4, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 1, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 2, 157, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 3, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 4, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 5, 178, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 6, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 7, 67, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031210014418, 8, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 1, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 2, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 3, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 4, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 5, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 6, 127, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 7, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 8, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 9, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 10, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090519014419, 11, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 1, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 2, 167, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 3, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 4, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 5, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 6, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 7, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 8, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 9, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211014420, 10, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 1, 122, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 2, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 3, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 4, 10, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 5, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 6, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021105014421, 7, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 1, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 2, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 3, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 4, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 5, 2, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214014422, 6, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 1, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 2, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 3, 47, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 4, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 5, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 6, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 7, 149, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 8, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 9, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618014423, 10, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 1, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 2, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 3, 183, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 4, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 5, 42, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 6, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 7, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 8, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 9, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060406014424, 10, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 1, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 2, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 3, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 4, 13, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 5, 192, 29, 18, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 6, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 7, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 8, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 9, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 10, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 11, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 12, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 13, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 14, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 15, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 16, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 17, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 18, 16, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140411014425, 19, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 1, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 2, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 3, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 4, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 5, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 6, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 7, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 8, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051123014426, 9, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 1, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 2, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 3, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 4, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 5, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321014427, 6, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 1, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 2, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 3, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 4, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 5, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 6, 174, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 7, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 8, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 9, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 10, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 11, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 12, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 13, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 14, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 15, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 16, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 17, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140508014428, 18, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 1, 180, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 2, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 3, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 4, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 5, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 6, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 7, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 8, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 9, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 10, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 11, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708014429, 12, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 1, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 2, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 3, 60, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 4, 113, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 5, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 6, 16, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 7, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 8, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 9, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 10, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 11, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 12, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 13, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 14, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 15, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 16, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214013279, 17, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 1, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 2, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 3, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 4, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 5, 135, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919013280, 6, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 1, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 2, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 3, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 4, 6, 2, 8, 16);
commit;
prompt 135000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 5, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 6, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 7, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 8, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 9, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 10, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 11, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211013281, 12, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101013282, 1, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101013282, 2, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101013282, 3, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001101013282, 4, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 1, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 2, 165, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 3, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 4, 58, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 5, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013283, 6, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 1, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 2, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 3, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 4, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 5, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 6, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 7, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 8, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013284, 9, 54, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 1, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 2, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 3, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 4, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 5, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 6, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 7, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 8, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 9, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 10, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 11, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 12, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 13, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 14, 52, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121013013285, 15, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 1, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 2, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 3, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 4, 126, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 5, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421013286, 6, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 1, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 2, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 3, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 4, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 5, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 6, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 7, 15, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 8, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 9, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 10, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 11, 86, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013287, 12, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013288, 1, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013288, 2, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013288, 3, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013288, 4, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013288, 5, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 1, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 2, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 3, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 4, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 5, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 6, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 7, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 8, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 9, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 10, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405013289, 11, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 1, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 2, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 3, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 4, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 5, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 6, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 7, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 8, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 9, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050824013290, 10, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 1, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 2, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 3, 61, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 4, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 5, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 6, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 7, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 8, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 9, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 10, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 11, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081111013291, 12, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 1, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 2, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 3, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 4, 38, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 5, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 6, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 7, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421013292, 8, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 1, 171, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 2, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 3, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 4, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 5, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 6, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 7, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 8, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 9, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 10, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 11, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 12, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 13, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 14, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409013293, 15, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 1, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 2, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 3, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 4, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 5, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 6, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 7, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 8, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 9, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 10, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 11, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 12, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 13, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100528013294, 14, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 1, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 2, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 3, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 4, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 5, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 6, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 7, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060601013295, 8, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 1, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 2, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 3, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 4, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 5, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 6, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 7, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 8, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 9, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 10, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 11, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319013296, 12, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630013297, 1, 7, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630013297, 2, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630013297, 3, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630013297, 4, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 1, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 2, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 3, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 4, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 5, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 6, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 7, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 8, 96, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 9, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 10, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904013298, 11, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 1, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 2, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 3, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 4, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 5, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122013299, 6, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 1, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 2, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 3, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 4, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 5, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 6, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 7, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 8, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 9, 157, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 10, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 11, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 12, 113, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 13, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 14, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100830013300, 15, 1, 38, 3, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 1, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 2, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 3, 129, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 4, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 5, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 6, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 7, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 8, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 9, 106, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 10, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 11, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091208013301, 12, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 1, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 2, 26, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 3, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 4, 97, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 5, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 6, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 7, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 8, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 9, 155, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 10, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 11, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 12, 127, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 13, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716013302, 14, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 1, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 2, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 3, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 4, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101215013682, 13, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 1, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 2, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 3, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 4, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 5, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 6, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 7, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 8, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013683, 9, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 1, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 2, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 3, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 4, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 5, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 6, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 7, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013684, 8, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626013685, 1, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626013685, 2, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626013685, 3, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626013685, 4, 26, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024013686, 1, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024013686, 2, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 1, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 2, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 3, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 4, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 5, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 6, 89, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 7, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 8, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 9, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 10, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 11, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 12, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091018013687, 13, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 1, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 2, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 3, 3, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 4, 111, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 5, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 6, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 7, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 8, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 9, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 10, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 11, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 12, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080306013688, 13, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 1, 137, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 2, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 3, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 4, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 5, 164, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 6, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 7, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 8, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 9, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 10, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504013689, 11, 192, 100, 18, 1800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 1, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 2, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 3, 172, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 4, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 5, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 6, 122, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 7, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 8, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 9, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 10, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 11, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616013690, 12, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 1, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 2, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 3, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 4, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 5, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 6, 150, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 7, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 8, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 9, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 10, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 11, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 12, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 13, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 14, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130914013691, 15, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 1, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 2, 163, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 3, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 4, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 5, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 6, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 7, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 8, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 9, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701013692, 10, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 1, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 2, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 3, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 4, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 5, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 6, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 7, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 8, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 9, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 10, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 11, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 12, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 13, 40, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 14, 50, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116013693, 15, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 1, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 2, 14, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 3, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 4, 75, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 5, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 6, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 7, 25, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316013694, 8, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 1, 158, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 2, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 3, 172, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 4, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 5, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 6, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 7, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 8, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 9, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 10, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 11, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 12, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 13, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 14, 27, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 15, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120912013695, 16, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617013696, 1, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617013696, 2, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010617013696, 3, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 1, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 2, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 3, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 4, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 5, 39, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 6, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 7, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 8, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 9, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 10, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 11, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901013697, 12, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 1, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 2, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 3, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 4, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 5, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 6, 58, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624013698, 7, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 1, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 2, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 3, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 4, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 5, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328013699, 6, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 1, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 2, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 3, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 4, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 5, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 6, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 7, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 8, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 9, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 10, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 11, 66, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 12, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 13, 74, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 14, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 15, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103013700, 16, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 1, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 2, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 3, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 4, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 5, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 6, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 7, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 8, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 9, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 10, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 11, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 12, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 13, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118013701, 14, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 1, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 2, 162, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 3, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 4, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 5, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 6, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030416013702, 7, 167, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 1, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 2, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 3, 57, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 4, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 5, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 6, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 7, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 8, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 9, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 10, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 11, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 12, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 13, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 14, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 15, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108013703, 16, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 1, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 2, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 3, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 4, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 5, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 6, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 7, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 8, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 9, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 10, 131, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 11, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 12, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109013704, 13, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 1, 130, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 2, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 3, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 4, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 5, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 6, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 7, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 8, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 9, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 1, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 2, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 3, 119, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 4, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 5, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 6, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 7, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 8, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 9, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 10, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306014063, 11, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 1, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 2, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 3, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 4, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 5, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 6, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 7, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 8, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 9, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050915014064, 10, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 1, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 2, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 3, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 4, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 5, 128, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 6, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 7, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 8, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 9, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 10, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 11, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 12, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 13, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 14, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 15, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120419014065, 16, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527014066, 1, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000527014066, 2, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 1, 119, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 2, 157, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 3, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 4, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 5, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 6, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 7, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 8, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 9, 117, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 10, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 11, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 12, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100306014067, 13, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 1, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 2, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 3, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 4, 141, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 5, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 6, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 7, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 8, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 9, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 10, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222014068, 11, 45, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 1, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 2, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 3, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 4, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 5, 185, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 6, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 7, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 8, 190, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 9, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 10, 94, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 11, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 12, 28, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 13, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 14, 1, 74, 3, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 15, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120304014069, 16, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 1, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 2, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 3, 56, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 4, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 5, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020822014070, 6, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 1, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 2, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 3, 158, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 4, 121, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 5, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 6, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624014071, 7, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 1, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 2, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 3, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 4, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 5, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 6, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041109014072, 7, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 1, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 2, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 3, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 4, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 5, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 6, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 7, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 8, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 9, 192, 50, 18, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 10, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 11, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080806014073, 12, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 1, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 2, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 3, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 4, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 5, 159, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 6, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 7, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 8, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 9, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208014074, 10, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 1, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 2, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 3, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 4, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 5, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 6, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 7, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 8, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 9, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 10, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 11, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 12, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 13, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110217014075, 14, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 1, 63, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 2, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 3, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 4, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 5, 53, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 6, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 7, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 8, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 9, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 10, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 11, 17, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 12, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 13, 150, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 14, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306014076, 15, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 1, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 2, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 3, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 4, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 5, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 6, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 7, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 8, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 9, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051029014077, 10, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628014078, 1, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628014078, 2, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628014078, 3, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010628014078, 4, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 1, 184, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 2, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 3, 9, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 4, 50, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 5, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 6, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 7, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 8, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 9, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 10, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 11, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 12, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 13, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022014079, 14, 128, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 1, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 2, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 3, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 4, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 5, 79, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 6, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 7, 175, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 8, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 9, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 10, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 11, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 12, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 13, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 14, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 15, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 16, 66, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407014080, 17, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 1, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 2, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 3, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 4, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 5, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 6, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 7, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 8, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 9, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 10, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 11, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 12, 1, 29, 3, 87);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 13, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 14, 143, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613014081, 15, 137, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 1, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 2, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 3, 134, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 4, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 5, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 6, 79, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 7, 183, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 8, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 9, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 10, 149, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 11, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 12, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 13, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 14, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 15, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121014014082, 16, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 1, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 2, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 3, 183, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 4, 45, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 5, 134, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 6, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 7, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 8, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041113014083, 9, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 1, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 2, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 3, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 4, 41, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 10, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 11, 141, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091004014430, 12, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 1, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 2, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 3, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 4, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 5, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 6, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 7, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 8, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 9, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 10, 19, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 11, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730014431, 12, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 1, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 2, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 3, 148, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 4, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 5, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 6, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 7, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 8, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 9, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 10, 121, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 11, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106014432, 12, 108, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 1, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 2, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 3, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 4, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 5, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031022014433, 6, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 1, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 2, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 3, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 4, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 5, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 6, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 7, 116, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 8, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 9, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 10, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 11, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014434, 12, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 1, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 2, 38, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 3, 102, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 4, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 5, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 6, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 7, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 8, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 9, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 10, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 11, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 12, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101018014435, 13, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 1, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 2, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 3, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 4, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 5, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 6, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 7, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 8, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630014436, 9, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 1, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 2, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 3, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 4, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 5, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 6, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 7, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 8, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 9, 192, 1, 18, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 10, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 11, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 12, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090918014437, 13, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 1, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 2, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 3, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 4, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 5, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 6, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 7, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 8, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 9, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 10, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 11, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 12, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 13, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 14, 139, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 15, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014438, 16, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 1, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 2, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 3, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 4, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 5, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 6, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 7, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 8, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 9, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 10, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 11, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 12, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 13, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 14, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014439, 15, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 1, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 2, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 3, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 4, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 5, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 6, 93, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 7, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 8, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040704014440, 9, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 1, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 2, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 3, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 4, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 5, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 6, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 7, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 8, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 9, 79, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 10, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 11, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 12, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111211014441, 13, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 1, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 2, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 3, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 4, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 5, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 6, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 7, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 8, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 9, 180, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 10, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 11, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 12, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412014442, 13, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 1, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 2, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 3, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 4, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 5, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 6, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 7, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 8, 166, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 9, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 10, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 11, 173, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 12, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 13, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 14, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 15, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205014443, 16, 192, 38, 18, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705014444, 1, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705014444, 2, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705014444, 3, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000705014444, 4, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 1, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 2, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 3, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 4, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 5, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 6, 66, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 7, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 8, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 9, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 10, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 11, 116, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 12, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 13, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120501014445, 14, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 1, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 2, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 3, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 4, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 5, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826014446, 6, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 1, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 2, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 3, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 4, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 5, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 6, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 7, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 8, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 9, 67, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 10, 112, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 11, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 12, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 13, 48, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100413014447, 14, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 1, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 2, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 3, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 4, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 5, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 6, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 7, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 8, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 9, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050321014448, 10, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 1, 61, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 2, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 3, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 4, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 5, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 6, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 7, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 8, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 9, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 10, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 11, 125, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 12, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091008014449, 13, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 1, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 2, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 3, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 4, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 5, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 6, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 7, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 8, 178, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 9, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 10, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 11, 63, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 12, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110404014450, 13, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 1, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 2, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 3, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 5, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 6, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 7, 118, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 8, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 9, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 10, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 11, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 12, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021013303, 13, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 1, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 2, 32, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 3, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 4, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 5, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116013304, 6, 81, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 1, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 2, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 3, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 4, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 5, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 6, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020013305, 7, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 1, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 2, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 3, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 4, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 5, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 6, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 7, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 8, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013306, 9, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 1, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 2, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 3, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 4, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 5, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 6, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 7, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 8, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 9, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 10, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 11, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 12, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 13, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120819013307, 14, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816013308, 1, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000816013308, 2, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 1, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 2, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 3, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 4, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 5, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 6, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 7, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 8, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 9, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 10, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 11, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706013309, 12, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 1, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 2, 122, 2, 10, 20);
commit;
prompt 136000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 3, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 4, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 5, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 6, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 7, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 8, 120, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 9, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 10, 132, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 11, 178, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 12, 108, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 13, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 14, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 15, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 16, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131219013310, 17, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 1, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 2, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 3, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 4, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 5, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 6, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 7, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 8, 180, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 9, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 10, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 11, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 12, 183, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 13, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013311, 14, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322013312, 1, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322013312, 2, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322013312, 3, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322013312, 4, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 1, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 2, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 3, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 4, 131, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 5, 30, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 6, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 7, 142, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 8, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106013313, 9, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 1, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 2, 90, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 3, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 4, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 5, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 6, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 7, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013314, 8, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 1, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 2, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 3, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 4, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 5, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020512013315, 6, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 1, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 2, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 3, 110, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 4, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 5, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 6, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 7, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 8, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 9, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 10, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 11, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 12, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 13, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013316, 14, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 1, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 2, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 3, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 4, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 5, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 6, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 7, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 8, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 9, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 10, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 11, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 12, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 13, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 14, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 15, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 16, 164, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209013317, 17, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013318, 1, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013318, 2, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013318, 3, 51, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013318, 4, 82, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727013319, 1, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727013319, 2, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727013319, 3, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727013319, 4, 55, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727013319, 5, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 1, 79, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 2, 98, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 3, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 4, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 5, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419013320, 6, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 1, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 2, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 3, 69, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 4, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 5, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 6, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020407013321, 7, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 1, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 2, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 3, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 4, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 5, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 6, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 7, 33, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 8, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 9, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 10, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 11, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 12, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 13, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090902013322, 14, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 1, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 2, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 3, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 4, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 5, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 6, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 7, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 8, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 9, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 10, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 11, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 12, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026013323, 13, 90, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 1, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 2, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 3, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 4, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 5, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 6, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 7, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 8, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 9, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 10, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 11, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 12, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 13, 183, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 14, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 15, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130612013324, 16, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223013325, 1, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223013325, 2, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223013325, 3, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223013325, 4, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314013326, 1, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314013326, 2, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314013326, 3, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000314013326, 4, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 1, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 2, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 3, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 4, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 5, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 6, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902013327, 7, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 1, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 2, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 3, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 4, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 5, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 6, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 7, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 8, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013328, 9, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 1, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 2, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 10, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 11, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 12, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 13, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110425013705, 14, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 1, 121, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 2, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 3, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 4, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 5, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 6, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 7, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 8, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 9, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 10, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 11, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 12, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 13, 3, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 14, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013706, 15, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 1, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 2, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 3, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 4, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 5, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 6, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 7, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 8, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 9, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 10, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070511013707, 11, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 1, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 2, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 3, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 4, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 5, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 6, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 7, 10, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 8, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 9, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 10, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 11, 120, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 12, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 13, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 14, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 15, 121, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110807013708, 16, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013709, 1, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013709, 2, 8, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 1, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 2, 54, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 3, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 4, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 5, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 6, 151, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 7, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 8, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 9, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 10, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 11, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 12, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 13, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 14, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 15, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121005013710, 16, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 1, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 2, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 3, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 4, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 5, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 6, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 7, 37, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 8, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 9, 153, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 10, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015013711, 11, 155, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009013712, 1, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009013712, 2, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009013712, 3, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009013712, 4, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 1, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 2, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 3, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 4, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 5, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 6, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 7, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 8, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 9, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 10, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 11, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 12, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 13, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 14, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407013713, 15, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018013714, 1, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018013714, 2, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018013714, 3, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018013714, 4, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 1, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 2, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 3, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 4, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 5, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 6, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 7, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 8, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 9, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 10, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 11, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 12, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612013715, 13, 155, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 1, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 2, 56, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 3, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 4, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 5, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 6, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 7, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 8, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203013716, 9, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 1, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 2, 140, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 3, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 4, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 5, 5, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 6, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 7, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 8, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 9, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 10, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 11, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090308013717, 12, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 1, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 2, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 3, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 4, 152, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 5, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 6, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 7, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 8, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 9, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 10, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 11, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 12, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 13, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513013718, 14, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 1, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 2, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 3, 41, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 4, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 5, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 6, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 7, 140, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 8, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 9, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 10, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 11, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 12, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 13, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705013719, 14, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 1, 116, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 2, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 3, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 4, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 5, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 6, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117013720, 7, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 1, 14, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 2, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 3, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 4, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 5, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 6, 42, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 7, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 8, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 9, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 10, 190, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 11, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 12, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 13, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829013721, 14, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 1, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 2, 82, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 3, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 4, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 5, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 6, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 7, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 8, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013722, 9, 60, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 1, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 2, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 3, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 4, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 5, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 6, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 7, 180, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013723, 8, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 1, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 2, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 3, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 4, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 5, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521013724, 6, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 1, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 2, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 3, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 4, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 5, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 6, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 7, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 8, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070201013725, 9, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 1, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 2, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 3, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 4, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 5, 68, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 6, 124, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 7, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 8, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 9, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 10, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080303013726, 11, 85, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 1, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 2, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 3, 155, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 4, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 5, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 6, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 7, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 8, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 9, 17, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 10, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527013727, 11, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602013728, 1, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602013728, 2, 93, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602013728, 3, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 5, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 6, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 7, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 8, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 9, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 10, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 11, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 12, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 13, 173, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 14, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014084, 15, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 1, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 2, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 3, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 4, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 5, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 6, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 7, 160, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 8, 27, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 9, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 10, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 11, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 12, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 13, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 14, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110219014085, 15, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 1, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 2, 22, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 3, 38, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 4, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 5, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 6, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 7, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 8, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 9, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 10, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 11, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 12, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 13, 127, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 14, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110414014086, 15, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 1, 175, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 2, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 3, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 4, 18, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 5, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 6, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 7, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 8, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 9, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 10, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 11, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 12, 136, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014087, 13, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530014088, 1, 175, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530014088, 2, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530014088, 3, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530014088, 4, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 1, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 2, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 3, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 4, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 5, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 6, 96, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 7, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 8, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 9, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 10, 157, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 11, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 12, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 13, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 14, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 15, 133, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120227014089, 16, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 1, 171, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 2, 183, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 3, 188, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 4, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 5, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 6, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 7, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 8, 192, 18, 18, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 9, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 10, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070918014090, 11, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 1, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 2, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 3, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 4, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 5, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 6, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 7, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 8, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214014091, 9, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 1, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 2, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 3, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 4, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 5, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 6, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 7, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 8, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 9, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 10, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 11, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211014092, 12, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013014093, 1, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013014093, 2, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013014093, 3, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013014093, 4, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013014093, 5, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 1, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 2, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 3, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 4, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 5, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 6, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 7, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 8, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 9, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 10, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 11, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 12, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 13, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 14, 68, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210014094, 15, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 1, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 2, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 3, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 4, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 5, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 6, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 7, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060216014095, 8, 68, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 1, 140, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 2, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 3, 158, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 4, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 5, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014096, 6, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 1, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 2, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 3, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 4, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 5, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 6, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 7, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 8, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 9, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 10, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 11, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 12, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 13, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 14, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 15, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 16, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131226014097, 17, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 1, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 2, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 3, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 4, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 5, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 6, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 7, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 8, 88, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 9, 129, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 10, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 11, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 12, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 13, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 14, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 15, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 16, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014098, 17, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014099, 1, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014099, 2, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014099, 3, 151, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014099, 4, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 1, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 2, 149, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 3, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 4, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 5, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 6, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 7, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 8, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 9, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 10, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 11, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 12, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 13, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 14, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 15, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130328014100, 16, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208014101, 1, 107, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208014101, 2, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208014101, 3, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 1, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 2, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 3, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 4, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 5, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 6, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 7, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120014102, 8, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 1, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 2, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 3, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 4, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 5, 117, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 6, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 7, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 8, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 9, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 10, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 11, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 12, 80, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 13, 192, 1, 18, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 14, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130130014103, 15, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416014104, 1, 26, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416014104, 2, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416014104, 3, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416014104, 4, 122, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010416014104, 5, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 1, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 2, 137, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 3, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 4, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 5, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041018014105, 6, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 1, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 2, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 3, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 4, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 5, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 6, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 7, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 8, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 4, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 5, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 6, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 7, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 8, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 9, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 10, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 11, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 12, 141, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090226014451, 13, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 1, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 2, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 3, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 4, 99, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 5, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 6, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 7, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 8, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 9, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 10, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 11, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 12, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 13, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 14, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 15, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 16, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 17, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014452, 18, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510014453, 1, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510014453, 2, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510014453, 3, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510014453, 4, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 1, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 2, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 3, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 4, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 5, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 6, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 7, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 8, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 9, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 10, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 11, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080515014454, 12, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 1, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 2, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 3, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 4, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 5, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 6, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030617014455, 7, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 1, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 2, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 3, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 4, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 5, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 6, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 7, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 8, 76, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 9, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818014456, 10, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 1, 188, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 2, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 3, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 4, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 5, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 6, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 7, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 8, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 9, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 10, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 11, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 12, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 13, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 14, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308014457, 15, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 1, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 2, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 3, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 4, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 5, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 6, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 7, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 8, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 9, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 10, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 11, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 12, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090111014458, 13, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 1, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 2, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 3, 143, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 4, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 5, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 6, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 7, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 8, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325014459, 9, 189, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 1, 55, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 2, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 3, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 4, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 5, 51, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 6, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 7, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 8, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 9, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 10, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080714014460, 11, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 1, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 2, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 3, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 4, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 5, 91, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 6, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 7, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 8, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 9, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 10, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 11, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 12, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081212014461, 13, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 1, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 2, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 3, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 4, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 5, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 6, 171, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 7, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 8, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060421014462, 9, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 1, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 2, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 3, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 4, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 5, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 6, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 7, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 8, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 9, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 10, 53, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 11, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326014463, 12, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124014464, 1, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124014464, 2, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124014464, 3, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124014464, 4, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021124014464, 5, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 1, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 2, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 3, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 4, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 5, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927014465, 6, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 1, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 2, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 3, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 4, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 5, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 6, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 7, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 8, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 9, 83, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 10, 97, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 11, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 12, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 13, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 14, 137, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810014466, 15, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 1, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 2, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 3, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 4, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 5, 126, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 6, 190, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 7, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 8, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 9, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 10, 115, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090616014467, 11, 69, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 1, 40, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 2, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 3, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 4, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 5, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 6, 91, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014468, 7, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 1, 96, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 2, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 3, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 4, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 5, 126, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 6, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 7, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 8, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 9, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 10, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 11, 66, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 12, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 13, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 14, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 15, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514014469, 16, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 1, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 2, 7, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 3, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 4, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 5, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031024014470, 6, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 1, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 2, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 3, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 4, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 5, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 6, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 7, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 8, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 9, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 10, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 11, 57, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 12, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 13, 100, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 14, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525014471, 15, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 1, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 2, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 3, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 4, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 5, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 6, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 7, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 8, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 9, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 10, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 11, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 12, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 13, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 14, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121229014472, 15, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 3, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 4, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 5, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 6, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041121013329, 7, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013330, 1, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013330, 2, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013330, 3, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013330, 4, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013330, 5, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 1, 35, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 2, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 3, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 4, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 5, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 6, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 7, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 8, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919013331, 9, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 1, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 2, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 3, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 4, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 5, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 6, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 7, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 8, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 9, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070116013332, 10, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 1, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 2, 85, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 3, 20, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 4, 2, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 5, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 6, 75, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 7, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 8, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 9, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 10, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 11, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 12, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 13, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 14, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 15, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013333, 16, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 1, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 2, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 3, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 4, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 5, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 6, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 7, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 8, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 9, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 10, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013334, 11, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522013335, 1, 110, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522013335, 2, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522013335, 3, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522013335, 4, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000522013335, 5, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 1, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 2, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 3, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 4, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 5, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 6, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 7, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402013336, 8, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 1, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 2, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 3, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 4, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 5, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030221013337, 6, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 1, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 2, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 3, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 4, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 5, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 6, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 7, 112, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 8, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 9, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 10, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 11, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 12, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 13, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 14, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 15, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 16, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 17, 88, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111013338, 18, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 1, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 2, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 3, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 4, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 5, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030517013339, 6, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412013340, 1, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412013340, 2, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412013340, 3, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 1, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 2, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 3, 129, 19, 7, 133);
commit;
prompt 137000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 4, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 5, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 6, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 7, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 8, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 9, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 10, 88, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 11, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 12, 61, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 13, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 14, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 15, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 16, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131230013341, 17, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 1, 169, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 2, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 3, 138, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 4, 96, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 5, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 6, 168, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 7, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613013342, 8, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 1, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 2, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 3, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 4, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 5, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 6, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 7, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 8, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 9, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 10, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 11, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 12, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422013343, 13, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 1, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 2, 47, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 3, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 4, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 5, 183, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 6, 92, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 7, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 8, 176, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 9, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 10, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 11, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930013344, 12, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115013345, 1, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115013345, 2, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 1, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 2, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 3, 164, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 4, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 5, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731013346, 6, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 1, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 2, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 3, 160, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 4, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 5, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 6, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 7, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 8, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 9, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424013347, 10, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 1, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 2, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 3, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 4, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 5, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 6, 143, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 7, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 8, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 9, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 10, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901013348, 11, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 1, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 2, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 3, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 4, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 5, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 6, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 7, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122013349, 8, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 1, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 2, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 3, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 4, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 5, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 6, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 7, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707013350, 8, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 1, 133, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 2, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 3, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 4, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 5, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021116013351, 6, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 1, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 2, 7, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 3, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 4, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 5, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020119013352, 6, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 1, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 2, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 3, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 4, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 5, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 6, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113013353, 7, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 1, 126, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 2, 22, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 3, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 4, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 5, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825013354, 6, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817013355, 1, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817013355, 2, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 1, 150, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 2, 10, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 3, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 4, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 5, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 6, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 7, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 8, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227013356, 9, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 1, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 2, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 3, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 4, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 5, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 6, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000602013728, 4, 187, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013729, 1, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013729, 2, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013729, 3, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 1, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 2, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 3, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 4, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 5, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 6, 79, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 7, 45, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 8, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 9, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 10, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 11, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731013730, 12, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 1, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 2, 103, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 3, 2, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 4, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 5, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 6, 57, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 7, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 8, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 9, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924013731, 10, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 1, 136, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 2, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 3, 30, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 4, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 5, 81, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 6, 91, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 7, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 8, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 9, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060823013732, 10, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 1, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 2, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 3, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 4, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 5, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 6, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614013733, 7, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 1, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 2, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 3, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 4, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 5, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 6, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 7, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013734, 8, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 1, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 2, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 3, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 4, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 5, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 6, 188, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 7, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 8, 158, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 9, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 10, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061117013735, 11, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 1, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 2, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 3, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 4, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 5, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 6, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 7, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726013736, 8, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528013737, 1, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528013737, 2, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528013737, 3, 118, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528013737, 4, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020528013737, 5, 130, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 1, 117, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 2, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 3, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 4, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 5, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 6, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 7, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 8, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 9, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 10, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 11, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 12, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090312013738, 13, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 1, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 2, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 3, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 4, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 5, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 6, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811013739, 7, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 1, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 2, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 3, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 4, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 5, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 6, 85, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 7, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 8, 72, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929013740, 9, 165, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 1, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 2, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 3, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 4, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 5, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 6, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 7, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 8, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 9, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 10, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071104013741, 11, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 1, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 2, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 3, 90, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 4, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 5, 91, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 6, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 7, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 8, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 9, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 10, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301013742, 11, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 1, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 2, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 3, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 4, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 5, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210013743, 6, 127, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716013744, 1, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716013744, 2, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716013744, 3, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716013744, 4, 96, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 1, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 2, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 3, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 4, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 5, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030725013745, 6, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 1, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 2, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 3, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 4, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 5, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 6, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 7, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 8, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 9, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 10, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 11, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 12, 47, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 13, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 14, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013746, 15, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201013747, 1, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201013747, 2, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000201013747, 3, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 1, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 2, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 3, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 4, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 5, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 6, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 7, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 8, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 9, 174, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 10, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 11, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 12, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 13, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 14, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 15, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013748, 16, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 1, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 2, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 3, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 4, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 5, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 6, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 7, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 8, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519013749, 9, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 1, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 2, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 3, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 4, 164, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 5, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 6, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 7, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 8, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314013750, 9, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 1, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 2, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 3, 181, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 4, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 5, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 6, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 7, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 8, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 9, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070930013751, 10, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306013752, 1, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306013752, 2, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306013752, 3, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306013752, 4, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 1, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 2, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 3, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 4, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 5, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 6, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 7, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 8, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 9, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 10, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 11, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 12, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 13, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090923013753, 14, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 1, 13, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 2, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 3, 159, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 4, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 5, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 6, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 7, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 8, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 9, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 10, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 11, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 12, 149, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 13, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 14, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 15, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215013754, 16, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 1, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 9, 157, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 10, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 11, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 12, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 13, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 14, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 15, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 16, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 17, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224014106, 18, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528014107, 1, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528014107, 2, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528014107, 3, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528014107, 4, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528014107, 5, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605014108, 1, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605014108, 2, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605014108, 3, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 1, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 2, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 3, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 4, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 5, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 6, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 7, 162, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 8, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318014109, 9, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 1, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 2, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 3, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 4, 24, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 5, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 6, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 7, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 8, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 9, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109014110, 10, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 1, 16, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 2, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 3, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 4, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 5, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 6, 83, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410014111, 7, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 1, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 2, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 3, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 4, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 5, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 6, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020106014112, 7, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 1, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 2, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 3, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 4, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 5, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 6, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 7, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 8, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 9, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 10, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 11, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 12, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 13, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100424014113, 14, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 1, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 2, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 3, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 4, 70, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 5, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021204014114, 6, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415014115, 1, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415014115, 2, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415014115, 3, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415014115, 4, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415014115, 5, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 1, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 2, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 3, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 4, 1, 90, 3, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 5, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 6, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 7, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 8, 177, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 9, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 10, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 11, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090411014116, 12, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 1, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 2, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 3, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 4, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 5, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 6, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 7, 47, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 8, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 9, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 10, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 11, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 12, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 13, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 14, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 15, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 16, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 17, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130408014117, 18, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 1, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 2, 54, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 3, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 4, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 5, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 6, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 7, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 8, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 9, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 10, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 11, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 12, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090605014118, 13, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 1, 131, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 2, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 3, 76, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 4, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 5, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 6, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 7, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 8, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 9, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 10, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 11, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 12, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 13, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 14, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121111014119, 15, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 1, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 2, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 3, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 4, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 5, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 6, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 7, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 8, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 9, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 10, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014120, 11, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 1, 155, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 2, 9, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 3, 150, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 4, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 5, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 6, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 7, 97, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 8, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 9, 67, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 10, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 11, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 12, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 13, 189, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 14, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 15, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 16, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 17, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407014121, 18, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 1, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 2, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 3, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 4, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 5, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 6, 35, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 7, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 8, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 9, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 10, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014122, 11, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031014123, 1, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031014123, 2, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031014123, 3, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011031014123, 4, 59, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 1, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 2, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 3, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 4, 43, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 5, 117, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 6, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210014124, 7, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 1, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 2, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 3, 158, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 4, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 5, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 6, 175, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 7, 17, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 8, 187, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 9, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 10, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014125, 11, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 1, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 2, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 3, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 4, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 5, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014126, 6, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 1, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 2, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 3, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 4, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 5, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 6, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 7, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 8, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 9, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 10, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 11, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 12, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080831014127, 13, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 1, 10, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 2, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 3, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 4, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 5, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 6, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 7, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 8, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 9, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 10, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 11, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 12, 95, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 13, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 14, 125, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 15, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 16, 79, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 17, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231014128, 18, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 1, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 2, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 3, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 4, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 5, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 6, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 6, 58, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 7, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 8, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 9, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 10, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 11, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 12, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 13, 12, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 14, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 1, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 2, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 3, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 4, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 5, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 6, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030905014569, 7, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 1, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 2, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 3, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 4, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 5, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 6, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 7, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 8, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 9, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 10, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 11, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523014570, 12, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917014571, 1, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917014571, 2, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917014571, 3, 83, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010917014571, 4, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 1, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 2, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 3, 50, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 4, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 5, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 6, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 7, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 8, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 9, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 10, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 11, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 12, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 13, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 14, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 15, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130812014572, 16, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014573, 1, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014573, 2, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014573, 3, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014573, 4, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 1, 152, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 2, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 3, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 4, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 5, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 6, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 7, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 8, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 9, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 10, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 11, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 12, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 13, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 14, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712014574, 15, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 1, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 2, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 3, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 4, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 5, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 6, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 7, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 8, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515014575, 9, 128, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 1, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 2, 162, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 3, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 4, 92, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 5, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 6, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 7, 45, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 8, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 9, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 10, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 11, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 12, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 13, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 14, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 15, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522014576, 16, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 1, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 2, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 3, 164, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 4, 132, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 5, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 6, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 7, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 8, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014577, 9, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 2, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 3, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 4, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 5, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 6, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 7, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 8, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 9, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 10, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 11, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 12, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 13, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 14, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 15, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118014578, 16, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 1, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 2, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 3, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 4, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 5, 176, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 6, 66, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 7, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 8, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 9, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 10, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 11, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 12, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 13, 114, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100816014579, 14, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 1, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 2, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 3, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 4, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 5, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 6, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 7, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 8, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 9, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 10, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 11, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 12, 34, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100726014580, 13, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 1, 60, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 2, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 3, 144, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 4, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 5, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 6, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 7, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 8, 104, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 9, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 10, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080208014581, 11, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511014582, 1, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511014582, 2, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511014582, 3, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511014582, 4, 13, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000511014582, 5, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 1, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 2, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 3, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 4, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 5, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 6, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 7, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 8, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 9, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 10, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 11, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021014583, 12, 129, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 1, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 2, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 3, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 4, 187, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 5, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 6, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 7, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 8, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 9, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 10, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 11, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 12, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014584, 13, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001014585, 1, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001014585, 2, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001014585, 3, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001014585, 4, 150, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001014585, 5, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014586, 1, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014586, 2, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014586, 3, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014586, 4, 74, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014586, 5, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 1, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 2, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 3, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 4, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 5, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020529014587, 6, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 1, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 2, 121, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 3, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 4, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 5, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 6, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 7, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 8, 39, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 9, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 10, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 11, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 12, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110913014588, 13, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 1, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 2, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 3, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 4, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 5, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 6, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 7, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 8, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 9, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 10, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 11, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 12, 96, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090927014589, 13, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 1, 164, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 2, 162, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 3, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 4, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 5, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 6, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 7, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 8, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040529014590, 9, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 1, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 2, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 3, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 7, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 8, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 9, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 10, 178, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 11, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 12, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 13, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110316013357, 14, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 1, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 2, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 3, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 4, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 5, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 6, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 7, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 8, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 9, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 10, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 11, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 12, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 13, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 14, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003013358, 15, 166, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 1, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 2, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 3, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 4, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 5, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 6, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 7, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 8, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 9, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 10, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 11, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 12, 24, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 13, 45, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 14, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 15, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 16, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130128013359, 17, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 1, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 2, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 3, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 4, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 5, 145, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 6, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 7, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040612013360, 8, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 1, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 2, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 3, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 4, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 5, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 6, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 7, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 8, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 9, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 10, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 11, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 12, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 13, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 14, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 15, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311013361, 16, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 1, 181, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 2, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 3, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 4, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 5, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 6, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 7, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 8, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 9, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 10, 73, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 11, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 12, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 13, 42, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 14, 77, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 15, 152, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404013362, 16, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 1, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 2, 2, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 3, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 4, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 5, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 6, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 7, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 8, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 9, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 10, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 11, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 12, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 13, 121, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 14, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 15, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 16, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013363, 17, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 1, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 2, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 3, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 4, 110, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 5, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 6, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 7, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013364, 8, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 1, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 2, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 3, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 4, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 5, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 6, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524013365, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 1, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 2, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 3, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 4, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 5, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 6, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 7, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 8, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 9, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 10, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 11, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 12, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013366, 13, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 1, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 2, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 3, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 4, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 5, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 6, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 7, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 8, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923013367, 9, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 1, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 2, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 3, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 4, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 5, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 6, 176, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 7, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 8, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 9, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 10, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 11, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 12, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 13, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016013368, 14, 53, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 1, 81, 7, 7, 49);
commit;
prompt 138000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 2, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 3, 50, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 4, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 5, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 6, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 7, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 8, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 9, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 10, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 11, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 12, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 13, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120927013369, 14, 177, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 1, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 2, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 3, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 4, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 5, 169, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010715013370, 6, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 1, 94, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 2, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 3, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 4, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 5, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906013371, 6, 71, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013372, 1, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013372, 2, 38, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013372, 3, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013372, 4, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013372, 5, 79, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 1, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 2, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 3, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 4, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 5, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 6, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 7, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 8, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 9, 161, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 10, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 11, 65, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081014013373, 12, 141, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 1, 60, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 2, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 3, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 4, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 5, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 6, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 7, 61, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 8, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 9, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 10, 3, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 11, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 12, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 13, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 14, 106, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 15, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725013374, 16, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130013375, 1, 27, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130013375, 2, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130013375, 3, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130013375, 4, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130013375, 5, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 1, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 2, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 3, 167, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 4, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 5, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 6, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 7, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 8, 106, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 9, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 10, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 11, 37, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 12, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 13, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 14, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110123013376, 15, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 1, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 2, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 3, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 4, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 5, 97, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 6, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013377, 7, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013378, 1, 135, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013378, 2, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013378, 3, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013378, 4, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010613013378, 5, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 2, 6, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 3, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 4, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 5, 92, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 6, 175, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 7, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 8, 114, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621013755, 9, 187, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 1, 42, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 2, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 3, 86, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 4, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 5, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 6, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 7, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 8, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 9, 45, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 10, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012013756, 11, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 1, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 2, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 3, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 4, 68, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 5, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 6, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 7, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 8, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 9, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 10, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 11, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 12, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090915013757, 13, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 1, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 2, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 3, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 4, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 5, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 6, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 7, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 8, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 9, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 10, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 11, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 12, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 13, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 14, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118013758, 15, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 1, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 2, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 3, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 4, 122, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 5, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 6, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 7, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 8, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 9, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 10, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 11, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 12, 163, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 13, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111108013759, 14, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 1, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 2, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 3, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 4, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 5, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 6, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 7, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 8, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 9, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 10, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 11, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514013760, 12, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 1, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 2, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 3, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 4, 77, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 5, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 6, 46, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 7, 120, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 8, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 9, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070916013761, 10, 186, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 1, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 2, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 3, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 4, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 5, 192, 81, 18, 1458);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 6, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 7, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 8, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 9, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404013762, 10, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 1, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 2, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 3, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 4, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 5, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 6, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 7, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 8, 186, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 9, 9, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 10, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 11, 86, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 12, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 13, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 14, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625013763, 15, 174, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 1, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 2, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 3, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 4, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 5, 184, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 6, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 7, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 8, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 9, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 10, 22, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423013764, 11, 162, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 1, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 2, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 3, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 4, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 5, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 6, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 7, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050606013765, 8, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 1, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 2, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 3, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 4, 56, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 5, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 6, 179, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 7, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 8, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801013766, 9, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 1, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 2, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 3, 32, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 4, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 5, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 6, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 7, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 8, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 9, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117013767, 10, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 1, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 2, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 3, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 4, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 5, 174, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 6, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040314013768, 7, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 1, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 2, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 3, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 4, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 5, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 6, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 7, 168, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 8, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 9, 48, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 10, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 11, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 12, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 13, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 14, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 15, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 16, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130720013769, 17, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 1, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 2, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 3, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 4, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 5, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 6, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 7, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 8, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 9, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 10, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 11, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 12, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 13, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 14, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013770, 15, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 1, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 2, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 3, 130, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 4, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 5, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 6, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 7, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 8, 60, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 9, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 10, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607013771, 11, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 1, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 2, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 3, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 4, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 5, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 6, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420013772, 7, 90, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 1, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 2, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 3, 71, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 4, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 5, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 6, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 7, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 8, 155, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 9, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812013773, 10, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 1, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 2, 160, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 3, 146, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 4, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 5, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 6, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 7, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 8, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 9, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 10, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013774, 11, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 1, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 2, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 3, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 4, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 5, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 6, 79, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 7, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 8, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 9, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070517013775, 10, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 1, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 2, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 3, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 4, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 7, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 8, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 9, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 10, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 11, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923014129, 12, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013014130, 1, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013014130, 2, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013014130, 3, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013014130, 4, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013014130, 5, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 1, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 2, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 3, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 4, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 5, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 6, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 7, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 8, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 9, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 10, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 11, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 12, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 13, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 14, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 15, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131018014131, 16, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 1, 170, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 2, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 3, 145, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 4, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 5, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 6, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 7, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 8, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 9, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 10, 60, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206014132, 11, 104, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 1, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 2, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 3, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 4, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 5, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 6, 119, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 7, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 8, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 9, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 10, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 11, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 12, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014133, 13, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 1, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 2, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 3, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 4, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 5, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 6, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 7, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712014134, 8, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014135, 1, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014135, 2, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014135, 3, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014135, 4, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 1, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 2, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 3, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 4, 184, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 5, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 6, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 7, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 8, 161, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041230014136, 9, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 1, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 2, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 3, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 4, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 5, 191, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020501014137, 6, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211014138, 1, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211014138, 2, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211014138, 3, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 1, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 2, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 3, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 4, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 5, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 6, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 7, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 8, 159, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 9, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 10, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 11, 32, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 12, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 13, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 14, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 15, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 16, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130617014139, 17, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 1, 106, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 2, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 3, 23, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 4, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 5, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 6, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 7, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 8, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 9, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 10, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 11, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 12, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 13, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 14, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 15, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014140, 16, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 1, 138, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 2, 185, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 3, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 4, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 5, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 6, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 7, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 8, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071026014141, 9, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 1, 69, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 2, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 3, 15, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 4, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 5, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 6, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 7, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 8, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 9, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 10, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 11, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 12, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 13, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 14, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 15, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121206014142, 16, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 1, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 2, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 3, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 4, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 5, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 6, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 7, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 8, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 9, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 10, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 11, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 12, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 13, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110711014143, 14, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 1, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 2, 160, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 3, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 4, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 5, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 6, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 7, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907014144, 8, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 1, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 2, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 3, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 4, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 5, 163, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 6, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 7, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 8, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 9, 123, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 10, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 11, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 12, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209014145, 13, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 1, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 2, 95, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 3, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 4, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 5, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 6, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 7, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 8, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 9, 149, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 10, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 11, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 12, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 13, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 14, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 15, 39, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014146, 16, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 1, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 2, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 3, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 4, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 5, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 6, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 7, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050930014147, 8, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 1, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 2, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 3, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 4, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 5, 66, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020319014148, 6, 172, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 1, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 2, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 3, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 4, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 5, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 6, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030605014149, 7, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 1, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 2, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 3, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 4, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 5, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 6, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 7, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 8, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 9, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014150, 10, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 1, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 2, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 3, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 4, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 5, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 6, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 7, 64, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 8, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127014151, 9, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 1, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 2, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 3, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 4, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 5, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 6, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 7, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616014152, 8, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 1, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 2, 55, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 3, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 4, 74, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 5, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 6, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 7, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 8, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 9, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 10, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827014473, 11, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 1, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 2, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 3, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 4, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 5, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 6, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 7, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 8, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 9, 93, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 10, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 11, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 12, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 13, 48, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 14, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110905014474, 15, 142, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 1, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 2, 32, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 3, 91, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 4, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 5, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 6, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 7, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 8, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 9, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 10, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 11, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 12, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 13, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 14, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 15, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 16, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014475, 17, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 1, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 2, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 3, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 4, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 5, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 6, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 7, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 8, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 9, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 10, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 11, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 12, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 13, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110327014476, 14, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 1, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 2, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 3, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 4, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 5, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 6, 146, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 7, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061219014477, 8, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 1, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 2, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 3, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 4, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 5, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 6, 11, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 7, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 8, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 9, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 10, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 11, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 12, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923014478, 13, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 1, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 2, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 3, 52, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 4, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 5, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 6, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 7, 141, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 8, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 9, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 10, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126014479, 11, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 1, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 2, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 3, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 4, 133, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 5, 75, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 6, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 7, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 8, 182, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 9, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 10, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 11, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 12, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 13, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 14, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 15, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014480, 16, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 1, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 2, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 3, 122, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 4, 104, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 5, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 6, 176, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 7, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 8, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 9, 150, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 10, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 11, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 12, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110107014481, 13, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328014482, 1, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328014482, 2, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328014482, 3, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020328014482, 4, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 1, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 2, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 3, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 4, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 5, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 6, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 7, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 8, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 9, 143, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 10, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 11, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 12, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 13, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 14, 188, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 15, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811014483, 16, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 1, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 2, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 3, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 4, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 5, 121, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 6, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 7, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 8, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 9, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 10, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 11, 59, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 12, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 13, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 14, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101210014484, 15, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 1, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 2, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 3, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 4, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 5, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 6, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 7, 179, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 8, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 9, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 10, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070808014485, 11, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 1, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 2, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 3, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 4, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 5, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 6, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 7, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 8, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 9, 144, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 10, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 11, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 12, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 13, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 14, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 15, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215014486, 16, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 1, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 2, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 3, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 4, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 5, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 6, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 7, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 8, 28, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 9, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 10, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 11, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 12, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 13, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 14, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 15, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 16, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140302014487, 17, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 1, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 2, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 3, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 4, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 5, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202014488, 6, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 1, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 2, 33, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 3, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 4, 13, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 5, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 6, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 7, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 8, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 9, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 10, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 11, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 12, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 13, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 14, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225014489, 15, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 1, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 2, 157, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 3, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 4, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 5, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 6, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 7, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 8, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061204014490, 9, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 1, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 2, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 3, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 4, 68, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 5, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 6, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 7, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 8, 59, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 9, 72, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 10, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060624014491, 11, 189, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 1, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 1, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 2, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 3, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 4, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 5, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 6, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020313013379, 7, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 2, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 3, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 4, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 5, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 6, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 7, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 8, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 9, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 10, 32, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 11, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 12, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100317013380, 13, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013381, 1, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013381, 2, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013381, 3, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 1, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 2, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 3, 128, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 4, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 5, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 6, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 7, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061224013382, 8, 170, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015013383, 1, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015013383, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015013383, 3, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015013383, 4, 40, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015013383, 5, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 1, 4, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 2, 59, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 3, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 4, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 5, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 6, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 7, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 8, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 9, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 10, 97, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 11, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 12, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 13, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 14, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 15, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 16, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 17, 101, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140212013384, 18, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 1, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 2, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 3, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 4, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 5, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 6, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 7, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 8, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 9, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 10, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 11, 40, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 12, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 13, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 14, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100614013385, 15, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 1, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 2, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 3, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 4, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 5, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 6, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 7, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 8, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 9, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 10, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 11, 150, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 12, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 13, 82, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013386, 14, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 1, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 2, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 3, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 4, 107, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 5, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 6, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 7, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050417013387, 8, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 1, 39, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 2, 97, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 3, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 4, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 5, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 6, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 7, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 8, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 9, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013388, 10, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 1, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 2, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 3, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 4, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 5, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 6, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 7, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 8, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 9, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814013389, 10, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 1, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 2, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 3, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 4, 134, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 5, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 6, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 7, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 8, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202013390, 9, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 1, 32, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 2, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 3, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 4, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 5, 29, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 6, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 7, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 8, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 9, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 10, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 11, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 12, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 13, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 14, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 15, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906013391, 16, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930013392, 1, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930013392, 2, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010930013392, 3, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 1, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 2, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 3, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 4, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 5, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 6, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 7, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 8, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 9, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 10, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 11, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 12, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 13, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 14, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 15, 166, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 16, 188, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 17, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130416013393, 18, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 2, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 3, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 4, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 5, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 6, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 7, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 8, 2, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 9, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 10, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 11, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 12, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 13, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 14, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 15, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126013394, 16, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926013395, 1, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926013395, 2, 108, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926013395, 3, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 1, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 2, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 3, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 4, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 5, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 6, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 7, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 8, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 9, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 10, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060129013396, 11, 85, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210013397, 1, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210013397, 2, 97, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210013397, 3, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210013397, 4, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011210013397, 5, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 1, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 2, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 3, 62, 28, 12, 336);
commit;
prompt 139000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 4, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 5, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 6, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 7, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 8, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213013398, 9, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 1, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 2, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 3, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 4, 90, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 5, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 6, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 7, 87, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 8, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 9, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 10, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623013399, 11, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 1, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 2, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 3, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 4, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 5, 84, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 6, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 7, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 8, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 9, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 10, 163, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 11, 34, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 12, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 13, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828013400, 14, 88, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 1, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 2, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 3, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 4, 80, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 5, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 6, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 7, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 8, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 9, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 10, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 11, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 12, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 13, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 5, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 6, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 7, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 8, 2, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 9, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 10, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080922013776, 11, 166, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 1, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 2, 166, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 3, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 4, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 5, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 6, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 7, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 8, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 9, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 10, 184, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 11, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 12, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 13, 119, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 14, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 15, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 16, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129013777, 17, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013778, 1, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013778, 2, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013778, 3, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013778, 4, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 1, 89, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 2, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 3, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 4, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 5, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 6, 58, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 7, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 8, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229013779, 9, 175, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 1, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 2, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 3, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 4, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 5, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 6, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 7, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 8, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 9, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 10, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 11, 11, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 12, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 13, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013780, 14, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209013781, 1, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209013781, 2, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209013781, 3, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209013781, 4, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031209013781, 5, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 1, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 2, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 3, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 4, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 5, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 6, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 7, 6, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 8, 155, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 9, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 10, 43, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 11, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 12, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 13, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 14, 109, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013782, 15, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 1, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 2, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 3, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 4, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 5, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 6, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 7, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 8, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 9, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 10, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 11, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 12, 8, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 13, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120225013783, 14, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 1, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 2, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 3, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 4, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 5, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 6, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 7, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 8, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 9, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 10, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 11, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 12, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 13, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 14, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 15, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 16, 94, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327013784, 17, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 1, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 2, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 3, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 4, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 5, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 6, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020302013785, 7, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013786, 1, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001110013786, 2, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708013787, 1, 83, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708013787, 2, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000708013787, 3, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 1, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 2, 62, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 3, 133, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 4, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 5, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 6, 125, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 7, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 8, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 9, 26, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 10, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 11, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 12, 155, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 13, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 14, 108, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 15, 187, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013788, 16, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 1, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 2, 128, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 3, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 4, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 5, 42, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 6, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 7, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 8, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 9, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 10, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 11, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 12, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 13, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091011013789, 14, 60, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 1, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 2, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 3, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 4, 190, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 5, 120, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 6, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 7, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 8, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 9, 125, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017013790, 10, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 1, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 2, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 3, 82, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 4, 14, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 5, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 6, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 7, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 8, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 9, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013791, 10, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 1, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 2, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 3, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 4, 163, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 5, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 6, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 7, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 8, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114013792, 9, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 1, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 2, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 3, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 4, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 5, 55, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801013793, 6, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 1, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 2, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 3, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 4, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 5, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 6, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 7, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 8, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 9, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 10, 92, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 11, 134, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 12, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108013794, 13, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 1, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 2, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 3, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 4, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 5, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 6, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013795, 7, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 1, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 2, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 3, 188, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 4, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 5, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 6, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 7, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 8, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050324013796, 9, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013797, 1, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013797, 2, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121013797, 3, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 1, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 2, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 3, 123, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 4, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 5, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 6, 165, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 7, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 8, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 9, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 10, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 11, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 12, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 13, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 14, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 15, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916013798, 16, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 1, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 2, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 3, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 4, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 5, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 6, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 7, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 8, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 9, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 10, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 11, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 1, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 2, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 3, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 4, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 5, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 6, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 7, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 8, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 9, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 10, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 11, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 12, 17, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924014153, 13, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 1, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 2, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 3, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 4, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 5, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 6, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 7, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 8, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 9, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 10, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070608014154, 11, 9, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911014155, 1, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911014155, 2, 188, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911014155, 3, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911014155, 4, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010911014155, 5, 170, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014156, 1, 163, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014156, 2, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014156, 3, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014156, 4, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014156, 5, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 1, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 2, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 3, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 4, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 5, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 6, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 7, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 8, 68, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 9, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 10, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 11, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 12, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 13, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104014157, 14, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 1, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 2, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 3, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 4, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 5, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 6, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 7, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 8, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 9, 2, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 10, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 11, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817014158, 12, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 1, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 2, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 3, 100, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 4, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 5, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 6, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 7, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 8, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 9, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 10, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 11, 35, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 12, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 13, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 14, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 15, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 16, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 17, 83, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130207014159, 18, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 1, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 2, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 3, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 4, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 5, 87, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 6, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 7, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 8, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 9, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 10, 129, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 11, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 12, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 13, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 14, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 15, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121129014160, 16, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 1, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 2, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 3, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 4, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 5, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 6, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 7, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 8, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115014161, 9, 135, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 1, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 2, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 3, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 4, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 5, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 6, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 7, 143, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 8, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 9, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 10, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 11, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 12, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 13, 91, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 14, 151, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 15, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 16, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130122014162, 17, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927014163, 1, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927014163, 2, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927014163, 3, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610014164, 1, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610014164, 2, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610014164, 3, 157, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 1, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 2, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 3, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 4, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 5, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 6, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 7, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 8, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 9, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 10, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 11, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 12, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 13, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100707014165, 14, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 1, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 2, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 3, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 4, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 5, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 6, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 7, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206014166, 8, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 1, 161, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 2, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 3, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 4, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 5, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 6, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 7, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 8, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 9, 23, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070828014167, 10, 87, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 1, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 2, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 3, 85, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 4, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 5, 15, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 6, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 7, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 8, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 9, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 10, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090321014168, 11, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 1, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 2, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 3, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 4, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 5, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 6, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 7, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 8, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 9, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 10, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 11, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 12, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 13, 12, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 14, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100629014169, 15, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 1, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 2, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 3, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 4, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 5, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 6, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 7, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 8, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 9, 78, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 10, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 11, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 12, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 13, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 14, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 15, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 16, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014170, 17, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 1, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 2, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 3, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 4, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 5, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 6, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 7, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 8, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 9, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 10, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 11, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 12, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229014171, 13, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 1, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 2, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 3, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 4, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 5, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 6, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 7, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 8, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 9, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 10, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 11, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 12, 99, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 13, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 14, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 15, 121, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014172, 16, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 1, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 2, 78, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 3, 171, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 4, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 5, 127, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 6, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 7, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 8, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 9, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918014520, 2, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918014520, 3, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918014520, 4, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 1, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 2, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 3, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 4, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 5, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 6, 29, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 7, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 8, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050108014521, 9, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 1, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 2, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 3, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 4, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 5, 77, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020907014522, 6, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 1, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 2, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 3, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 4, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 5, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 6, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 7, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 8, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 9, 80, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 10, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 11, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 12, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 13, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 14, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 15, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014523, 16, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 1, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 2, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 3, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 4, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 5, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 6, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 7, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 8, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 9, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 10, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 11, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 12, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 13, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706014524, 14, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 1, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 2, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 3, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 4, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 5, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 6, 106, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 7, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 8, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 9, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070823014525, 10, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 1, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 2, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 3, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 4, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 5, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 6, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021007014526, 7, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 1, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 2, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 3, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 4, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 5, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 6, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 7, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 8, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 9, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 10, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 11, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 12, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 13, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 14, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 15, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 16, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 17, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316014527, 18, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 1, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 2, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 3, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 4, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 5, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 6, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 7, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 8, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 9, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 10, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 11, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202014528, 12, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 1, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 2, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 3, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 4, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 5, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 6, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 7, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 8, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 9, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 10, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915014529, 11, 44, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 1, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 2, 169, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 3, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 4, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 5, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 6, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 7, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050422014530, 8, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 1, 114, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 2, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 3, 113, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 4, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 5, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 6, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 7, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 8, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 9, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 10, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 11, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 12, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110218014531, 13, 158, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 1, 152, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 2, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 3, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 4, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 5, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 6, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 7, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 8, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 9, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 10, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 11, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 12, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 13, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 14, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 15, 158, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014532, 16, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 1, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 2, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 3, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 4, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 5, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 6, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 7, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 8, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 9, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 10, 40, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 11, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 12, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 13, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091007014533, 14, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 1, 20, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 2, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 3, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 4, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 5, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 6, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 7, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020014534, 8, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 1, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 2, 24, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 3, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 4, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 5, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 6, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 8, 1, 92, 3, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 9, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 10, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 11, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 12, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 13, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014535, 14, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 1, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 2, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 3, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 4, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 5, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 6, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 7, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 8, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 9, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 10, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 11, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 12, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215014536, 13, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 1, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 2, 170, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 3, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 4, 110, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 5, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 6, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 7, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 8, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 9, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 10, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 11, 155, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 12, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 13, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 14, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 15, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 16, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 17, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130103014537, 18, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529014538, 1, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529014538, 2, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 1, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 2, 61, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 3, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 4, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 5, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020723014539, 6, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 1, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 2, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 3, 161, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 4, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 5, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 6, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 7, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 8, 68, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 9, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 10, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 11, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 12, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 13, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 14, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014540, 15, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717014541, 1, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717014541, 2, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717014541, 3, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000717014541, 4, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 1, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 2, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100318013401, 14, 191, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 1, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 2, 24, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 3, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 4, 115, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 5, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 6, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201013402, 7, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603013403, 1, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603013403, 2, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603013403, 3, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603013403, 4, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 1, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 2, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 3, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 4, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 5, 9, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 6, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 7, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040607013404, 8, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 1, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 2, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 3, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 4, 175, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 5, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 6, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 7, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 8, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 9, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 10, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 11, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013405, 12, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 1, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 2, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 3, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 4, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 5, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 6, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 7, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031114013406, 8, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 1, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 2, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 3, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 4, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 5, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 6, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 7, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 8, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 9, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231013407, 10, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 1, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 2, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 3, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 4, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 5, 187, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 6, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 7, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 8, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 9, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 10, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 11, 106, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 12, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110224013408, 13, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216013409, 1, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216013409, 2, 192, 28, 18, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216013409, 3, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011216013409, 4, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 1, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 2, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 3, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 4, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 5, 102, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 6, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 7, 53, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 8, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 9, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 10, 18, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 11, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224013410, 12, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 1, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 2, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 3, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 4, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 5, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 6, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 7, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 8, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 9, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 10, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 11, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 12, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 13, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 14, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110728013411, 15, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 1, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 2, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 3, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 4, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 5, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 6, 157, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 7, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 8, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 9, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081006013412, 10, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905013413, 1, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905013413, 2, 90, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905013413, 3, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905013413, 4, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 1, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 2, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 3, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 4, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 5, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 6, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 7, 107, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 8, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 9, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 10, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 11, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 12, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105013414, 13, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 1, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 2, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 3, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 4, 59, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 5, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806013415, 6, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 1, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 2, 18, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 3, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 4, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 5, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 6, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 7, 57, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 8, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 9, 103, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 10, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 11, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080414013416, 12, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 1, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 2, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 3, 47, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 4, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 5, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 6, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 7, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 8, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 9, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 10, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 11, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 12, 192, 85, 18, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 13, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 14, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130307013417, 15, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 1, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 2, 148, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 3, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 4, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 5, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 6, 116, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 7, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 8, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 9, 122, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 10, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070527013418, 11, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201013419, 1, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201013419, 2, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201013419, 3, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201013419, 4, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 1, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 2, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 3, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 4, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 5, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 6, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 7, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220013420, 8, 139, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 1, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 2, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 3, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 4, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 5, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 6, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 7, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 8, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 9, 51, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 10, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 11, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 12, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428013421, 13, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728013422, 1, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728013422, 2, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728013422, 3, 38, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010728013422, 4, 97, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 1, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 2, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 3, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 4, 144, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 5, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 6, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 7, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 8, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 9, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 10, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 11, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 12, 143, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 13, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 14, 82, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 15, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 16, 28, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013423, 17, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 1, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 2, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 3, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 4, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 5, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 6, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 7, 63, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 8, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013424, 9, 100, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823013425, 1, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823013425, 2, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823013425, 3, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010823013425, 4, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 1, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 2, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 3, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 4, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 5, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 6, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 7, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 8, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 9, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 10, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 11, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617013426, 12, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 1, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 2, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 3, 52, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 12, 33, 74, 4, 296);
commit;
prompt 140000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 13, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 14, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 15, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025013799, 16, 133, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 1, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 2, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 3, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 4, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 5, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104013800, 6, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 1, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 2, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 3, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 4, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 5, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 6, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 7, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 8, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 9, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 10, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 11, 18, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 12, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 13, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 14, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 15, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 16, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 17, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140316013801, 18, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 1, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 2, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 3, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 4, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 5, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 6, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 7, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 8, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708013802, 9, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 1, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 2, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 3, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 4, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 5, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 6, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 7, 52, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 8, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 9, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 10, 70, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 11, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 12, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 13, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110923013803, 14, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 1, 82, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 2, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 3, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 4, 152, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 5, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 6, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 7, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 8, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 9, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 10, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 11, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203013804, 12, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326013805, 1, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326013805, 2, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011114013806, 1, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011114013806, 2, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011114013806, 3, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011114013806, 4, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 1, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 2, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 3, 85, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 4, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 5, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 6, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 7, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 8, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 9, 123, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 10, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 11, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 12, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 13, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 14, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708013807, 15, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910013808, 1, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910013808, 2, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910013808, 3, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910013808, 4, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 1, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 2, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 3, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 4, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 5, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 6, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023013809, 7, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 1, 96, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 2, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 3, 3, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 4, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 5, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 6, 60, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209013810, 7, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525013811, 1, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525013811, 2, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525013811, 3, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525013811, 4, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525013811, 5, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411013812, 1, 101, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411013812, 2, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411013812, 3, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 1, 77, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 2, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 3, 121, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 4, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 5, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 6, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040804013813, 7, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 1, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 2, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 3, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 4, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 5, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 6, 78, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 7, 46, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 8, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 9, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 10, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 11, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 12, 67, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 13, 155, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 14, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 15, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130305013814, 16, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 1, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 2, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 3, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 4, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 5, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 6, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 7, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 8, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 9, 40, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 10, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 11, 22, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 12, 89, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 13, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 14, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 15, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121219013815, 16, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013816, 1, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013816, 2, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013816, 3, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013816, 4, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 1, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 2, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 3, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 4, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 5, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 6, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 7, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 8, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 9, 23, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070118013817, 10, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 1, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 2, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 3, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 4, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 5, 6, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021013013818, 6, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 1, 174, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 2, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 3, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 4, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 5, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 6, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917013819, 7, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 1, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 2, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 3, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 4, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 5, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 6, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013013820, 7, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029013821, 1, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029013821, 2, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029013821, 3, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011029013821, 4, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227013822, 1, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227013822, 2, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227013822, 3, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227013822, 4, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 1, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 2, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 3, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 4, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 5, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105013823, 6, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119013824, 1, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119013824, 2, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119013824, 3, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001119013824, 4, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 1, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 2, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 3, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 4, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 5, 85, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 6, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 7, 128, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 8, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 9, 68, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 10, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 11, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 12, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 13, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 14, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 15, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013825, 16, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130013826, 1, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130013826, 2, 191, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130013826, 3, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130013826, 4, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130013826, 5, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 1, 144, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 2, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 3, 144, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 4, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 5, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 6, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 7, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 8, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 9, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 10, 188, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 11, 166, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 12, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 13, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107013827, 14, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 1, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 2, 158, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 10, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 11, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218014173, 12, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 1, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 2, 15, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 3, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 4, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 5, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 6, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040312014174, 7, 157, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 1, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 2, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 3, 115, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 4, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 5, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 6, 111, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 7, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 8, 41, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 9, 137, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 10, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 11, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 12, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090804014175, 13, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618014176, 1, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000618014176, 2, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 1, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 2, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 3, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 4, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 5, 8, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 6, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104014177, 7, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 1, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 2, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 3, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 4, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 5, 149, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 6, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 7, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 8, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 9, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 10, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 11, 103, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 12, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 13, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 14, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 15, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111214014178, 16, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 1, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 2, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 3, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 4, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 5, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 6, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202014179, 7, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726014180, 1, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726014180, 2, 39, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726014180, 3, 37, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726014180, 4, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726014180, 5, 41, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 1, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 2, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 3, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 4, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 5, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026014181, 6, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 1, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 2, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 3, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 4, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 5, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 6, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 7, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 8, 93, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 9, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 10, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 11, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090627014182, 12, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 1, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 2, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 3, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 4, 162, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 5, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 6, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 7, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 8, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041210014183, 9, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 1, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 2, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 3, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 4, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 5, 99, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 6, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030317014184, 7, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 1, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 2, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 3, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 4, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 5, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 6, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 7, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 8, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 9, 175, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 10, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 11, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 12, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 13, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 14, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 15, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 16, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 17, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130223014185, 18, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 1, 36, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 2, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 3, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 4, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 5, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 6, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 7, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 8, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 9, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 10, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925014186, 11, 79, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 1, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 2, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 3, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 4, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 5, 23, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 6, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 7, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 8, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 9, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 10, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 11, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 12, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 13, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090529014187, 14, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728014188, 1, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728014188, 2, 74, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728014188, 3, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728014188, 4, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728014188, 5, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 1, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 2, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 3, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 4, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 5, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 6, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 7, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410014189, 8, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 1, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 2, 191, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 3, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 4, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 5, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 6, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 7, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 8, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323014190, 9, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 1, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 2, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 3, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 4, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 5, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 6, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 7, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 8, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 9, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 10, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 11, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 12, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090821014191, 13, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 1, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 2, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 3, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 4, 163, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 5, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 6, 74, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 7, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 8, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 9, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 10, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 11, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307014192, 12, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 1, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 2, 39, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 3, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 4, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 5, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 6, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 7, 17, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 8, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 9, 166, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 10, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 11, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 12, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 13, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 14, 91, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 15, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 16, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 17, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428014193, 18, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 1, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 2, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 3, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 4, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 5, 186, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 6, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 7, 189, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 8, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 9, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 10, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 11, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 12, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 13, 146, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120228014194, 14, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020828014195, 1, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020828014195, 2, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020828014195, 3, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020828014195, 4, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020828014195, 5, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 1, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 2, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 3, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 4, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 5, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 6, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 7, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 8, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 9, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 10, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 11, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 12, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 13, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111004014196, 14, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 1, 86, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 2, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 3, 146, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 4, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 5, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 6, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 7, 158, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 8, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 9, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 10, 146, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 11, 120, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911014591, 12, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 1, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 2, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 3, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 4, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 5, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 6, 57, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 7, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 8, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 9, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050322014592, 10, 104, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 1, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 2, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 3, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 4, 163, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 5, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815014593, 6, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 1, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 2, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 3, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 4, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 5, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030123014594, 6, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 1, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 2, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 3, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 4, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 5, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014595, 6, 76, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 1, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 2, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 3, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 4, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 5, 128, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 6, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 7, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 8, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 9, 23, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 10, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 11, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103014596, 12, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 1, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 2, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 3, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 4, 181, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 5, 192, 67, 18, 1206);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 6, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012014597, 7, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 1, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 2, 6, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 3, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 4, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 5, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 6, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 7, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 8, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 9, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 10, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 11, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 12, 154, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 13, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 14, 80, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 15, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 16, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014598, 17, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 1, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 2, 86, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 3, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 4, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 5, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 6, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030612014599, 8, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 1, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 2, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 3, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 4, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 5, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 6, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 7, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 8, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 9, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 10, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 11, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 12, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 13, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 14, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 15, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829014600, 16, 91, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 1, 183, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 2, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 3, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 4, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 5, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 6, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 7, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 8, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 9, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 10, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 11, 170, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 12, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 13, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014601, 14, 143, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 1, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 2, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 3, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 4, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 5, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 6, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 7, 7, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 8, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 9, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 10, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 11, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 12, 51, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105014602, 13, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 1, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 2, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 3, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 4, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 5, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 6, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 7, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 8, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 9, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 10, 181, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 11, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114014603, 12, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 1, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 2, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 3, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 4, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 5, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 6, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 7, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 8, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 9, 92, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 10, 94, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 11, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 12, 188, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907014604, 13, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519014605, 1, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519014605, 2, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519014605, 3, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010519014605, 4, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014606, 1, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014606, 2, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014606, 3, 85, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 1, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 2, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 3, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 4, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 5, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906014607, 6, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014608, 1, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014608, 2, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014608, 3, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014608, 4, 102, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014608, 5, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 1, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 2, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 3, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 4, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 5, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 6, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 7, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 8, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 9, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060419014609, 10, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 1, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 2, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 3, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 4, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 5, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 6, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020413014610, 7, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 1, 167, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 2, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 3, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 4, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 5, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 6, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 7, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 8, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 9, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 10, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 11, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 12, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 13, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 14, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 15, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927014611, 16, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 1, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 2, 15, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 3, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 4, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 5, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 6, 18, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 7, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 8, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 9, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 10, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 11, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 12, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 13, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 14, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014612, 15, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 1, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 2, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 3, 48, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 4, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 5, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 6, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 7, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801014613, 8, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 1, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 2, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 3, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 4, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 5, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 6, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 7, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 8, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 9, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 10, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 11, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 12, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 13, 183, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 14, 146, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 15, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708014614, 16, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 4, 181, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 5, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 6, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 7, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 8, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 9, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 10, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 11, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 12, 66, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 13, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609013427, 14, 32, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 1, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 2, 9, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 3, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 4, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 5, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705013428, 6, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211013429, 1, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211013429, 2, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211013429, 3, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211013429, 4, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011211013429, 5, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 1, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 2, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 3, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 4, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 5, 83, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 6, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 7, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 8, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 9, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514013430, 10, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 1, 179, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 2, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 3, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 4, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 5, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 6, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 7, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 8, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060204013431, 9, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 1, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 2, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 3, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 4, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 5, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 6, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 7, 154, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050215013432, 8, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 1, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 2, 167, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 3, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 4, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 5, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 6, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 7, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 8, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 9, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 10, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 11, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211013433, 12, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 1, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 2, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 3, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 4, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 5, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 6, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 7, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 8, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513013434, 9, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 1, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 2, 188, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 3, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 4, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 5, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 6, 177, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 7, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 8, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508013435, 9, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 1, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 2, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 3, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 4, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 5, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 6, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 7, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 8, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 9, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 10, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518013436, 11, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226013437, 1, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226013437, 2, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226013437, 3, 99, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 1, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 2, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 3, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 4, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 5, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 6, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 7, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 8, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 9, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 10, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 11, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013438, 12, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 1, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 2, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 3, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 4, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 5, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 6, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 7, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 8, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 9, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407013439, 10, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 1, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 2, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 3, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 4, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 5, 88, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 6, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 7, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411013440, 8, 130, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 1, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 2, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 3, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 4, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 5, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 6, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 7, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 8, 187, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 9, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 10, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 11, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 12, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 13, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 14, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 15, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130204013441, 16, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012013442, 1, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012013442, 2, 78, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012013442, 3, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011012013442, 4, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 1, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 2, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 3, 176, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 4, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 5, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 6, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 7, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 8, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 9, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 10, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 11, 72, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 12, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609013443, 13, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 1, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 2, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 3, 10, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 4, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 5, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 6, 183, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 7, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714013444, 8, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 1, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 2, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 3, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 4, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 5, 10, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 6, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 7, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 8, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013445, 9, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 1, 14, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 2, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 3, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 4, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 5, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 6, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 7, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 8, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060926013446, 9, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 1, 135, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 2, 178, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 3, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 4, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 5, 152, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 6, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 7, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 8, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 9, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 10, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 11, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 12, 118, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 13, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 14, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 15, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 16, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140105013447, 17, 55, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 1, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 2, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 3, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 4, 28, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 5, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 6, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 7, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 8, 114, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 9, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 10, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 11, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 12, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 13, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 14, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 15, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 16, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 17, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625013448, 18, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 1, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 2, 34, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 3, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 4, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 5, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 6, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 7, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 8, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003013449, 9, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 1, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 2, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 3, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 4, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 5, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 6, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 7, 186, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 8, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 9, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 10, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807013450, 11, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 1, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 2, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 3, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 4, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 5, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 6, 103, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 7, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 8, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 9, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 10, 145, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 11, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 12, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 13, 31, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 14, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623013828, 15, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 1, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 2, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 3, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 4, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 5, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 6, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 7, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 8, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 9, 70, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 10, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 11, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071120013829, 12, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 1, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 2, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 3, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 4, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 5, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 6, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 7, 50, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 8, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061003013830, 9, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 1, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 2, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 3, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 4, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 5, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 6, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 7, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 8, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 9, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 10, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 11, 123, 48, 11, 528);
commit;
prompt 141000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100714013831, 12, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 1, 33, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 2, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 3, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 4, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 5, 121, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 6, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 7, 192, 76, 18, 1368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061108013832, 8, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 1, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 2, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 3, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 4, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 5, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 6, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 7, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207013833, 8, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 1, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 2, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 3, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 4, 143, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 5, 114, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 6, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 7, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 8, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 9, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 10, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 11, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 12, 32, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517013834, 13, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 1, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 2, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 3, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 4, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 5, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 6, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 7, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 8, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 9, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 10, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 11, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 12, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 13, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 14, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 15, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802013835, 16, 5, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 1, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 2, 37, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 3, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 4, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 5, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 6, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 7, 145, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 8, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 9, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 10, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 11, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 12, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 13, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 14, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424013836, 15, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 1, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 2, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 3, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 4, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 5, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013837, 6, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 1, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 2, 73, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 3, 79, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 4, 188, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 5, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 6, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 7, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 8, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 9, 158, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 10, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060907013838, 11, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 1, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 2, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 3, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 4, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 5, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 6, 133, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 7, 133, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 8, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 9, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 10, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 11, 137, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 12, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 13, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 14, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 15, 155, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 16, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130716013839, 17, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825013840, 1, 150, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825013840, 2, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825013840, 3, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825013840, 4, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825013840, 5, 73, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 1, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 2, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 3, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 4, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 5, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 6, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 7, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 8, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 9, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 10, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 11, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081117013841, 12, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 1, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 2, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 3, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 5, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 6, 102, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 7, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 8, 154, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215013842, 9, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 1, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 2, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 3, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 4, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 5, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 6, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 7, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 8, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 9, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 10, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 11, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 12, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 13, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410013843, 14, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 1, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 2, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 3, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 4, 46, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 5, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 6, 149, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031009013844, 7, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 1, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 2, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 3, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 4, 25, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 5, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 6, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 7, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 8, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 9, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 10, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 11, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 12, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 13, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602013845, 14, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 1, 25, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 2, 186, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 3, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 4, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 5, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 6, 180, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 7, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 8, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214013846, 9, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 1, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 2, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 3, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 4, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 5, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 6, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 7, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 8, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070422013847, 9, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 1, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 2, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 3, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 4, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 5, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 6, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 7, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 8, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 9, 19, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 10, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 11, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530013848, 12, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 1, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 2, 186, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 3, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 4, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 5, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 6, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 7, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 5, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 6, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 7, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 8, 171, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 9, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 10, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 11, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111014197, 12, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 1, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 2, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 3, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 4, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 5, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020925014198, 6, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 1, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 2, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 3, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 4, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 5, 138, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 6, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 7, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 8, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 9, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 10, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 11, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 12, 51, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 13, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 14, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 15, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 16, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 17, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329014199, 18, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 1, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 2, 158, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 3, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 4, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 5, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 6, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 7, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 8, 109, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 9, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014200, 10, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 1, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 2, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 3, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 4, 153, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 5, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 6, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 7, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 8, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 9, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 10, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224014201, 11, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014202, 1, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014202, 2, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707014202, 3, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 1, 65, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 2, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 3, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 4, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 5, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 6, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 7, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 8, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 9, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 10, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 11, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090108014203, 12, 17, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 1, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 2, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 3, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 4, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 5, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 6, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051101014204, 7, 145, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 1, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 2, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 3, 150, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 4, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 5, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724014205, 6, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 1, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 2, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 3, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 4, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 5, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 6, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031128014206, 7, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014207, 1, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014207, 2, 158, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014207, 3, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000612014207, 4, 53, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 1, 131, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 2, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 3, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 4, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 5, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014208, 6, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 1, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 2, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 3, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 4, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 5, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020624014209, 6, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 1, 37, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 2, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 3, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 4, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 5, 31, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 6, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 7, 103, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 8, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 9, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 10, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 11, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090924014210, 12, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 1, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 2, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 3, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 4, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 5, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 6, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 7, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 8, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 9, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 10, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 11, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 12, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 13, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 14, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501014211, 15, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613014212, 1, 138, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613014212, 2, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613014212, 3, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613014212, 4, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030613014212, 5, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 1, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 2, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 3, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 4, 12, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 5, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 6, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 7, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 8, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 9, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060430014213, 10, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 1, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 2, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 3, 147, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 4, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 5, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030215014214, 6, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811014215, 1, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811014215, 2, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811014215, 3, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010811014215, 4, 167, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 1, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 2, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 3, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 4, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 5, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 6, 181, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 7, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 8, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 9, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 10, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080827014216, 11, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122014217, 1, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122014217, 2, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122014217, 3, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122014217, 4, 142, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 1, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 2, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 3, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 4, 51, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 5, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 6, 190, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 7, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 8, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 9, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 10, 129, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 11, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 12, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 13, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 14, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 15, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120509014218, 16, 84, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 1, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 2, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 3, 78, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 4, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 5, 175, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 6, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 7, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 8, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 9, 143, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 10, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070921014219, 11, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 1, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 2, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 3, 179, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 4, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 5, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020220014220, 6, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 1, 60, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 2, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 3, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 4, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 5, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 6, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 7, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 8, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 9, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 10, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 11, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 12, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 13, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 14, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 15, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 16, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 17, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905014221, 18, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 1, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 2, 172, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 3, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 4, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 5, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 6, 141, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 7, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 8, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 9, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 10, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 11, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 12, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 13, 173, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 14, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014222, 15, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 1, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 2, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 2, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 3, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 4, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 5, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 6, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 7, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014492, 8, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 1, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 2, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 3, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 4, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 5, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 6, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014493, 7, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 1, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 2, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 3, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 4, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 5, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 6, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 7, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 8, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 9, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808014494, 10, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 1, 147, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 2, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 3, 121, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 4, 132, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 5, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 6, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 7, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 8, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 9, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051026014495, 10, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808014496, 1, 52, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808014496, 2, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808014496, 3, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808014496, 4, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014497, 1, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014497, 2, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014497, 3, 101, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000411014497, 4, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 1, 104, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 2, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 3, 29, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 4, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 5, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 6, 89, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 7, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 8, 88, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 9, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 10, 133, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 11, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 12, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090407014498, 13, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 1, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 2, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 3, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 4, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 5, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 6, 87, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 7, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 8, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 9, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 10, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080905014499, 11, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 1, 45, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 2, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 3, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 4, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 5, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011107014500, 6, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222014501, 1, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222014501, 2, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222014501, 3, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222014501, 4, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222014501, 5, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 1, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 2, 54, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 3, 21, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 4, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 5, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 6, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614014502, 7, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 1, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 2, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 3, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 4, 21, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 5, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924014503, 6, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 1, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 2, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 3, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 4, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 5, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 6, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 7, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050612014504, 8, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 1, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 2, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 3, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 4, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 5, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 6, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 7, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014505, 8, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508014506, 1, 161, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000508014506, 2, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 1, 61, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 2, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 3, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 4, 32, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 5, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 6, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 7, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 8, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 9, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 10, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060215014507, 11, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 1, 17, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 2, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 3, 75, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 4, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 5, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 6, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 7, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 8, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 9, 106, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 10, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 11, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 12, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 13, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 14, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111014014508, 15, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 1, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 2, 189, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 3, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 4, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 5, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 6, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 7, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 8, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 9, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 10, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070725014509, 11, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 1, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 2, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 3, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 4, 44, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 5, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 6, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 7, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 8, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014510, 9, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 1, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 2, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 3, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 4, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 5, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 6, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322014511, 7, 2, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 1, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 2, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 3, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 4, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 5, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 6, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 7, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 8, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 9, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 10, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 11, 32, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091205014512, 12, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 1, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 2, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 3, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 4, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 5, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 6, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 7, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041218014513, 8, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 1, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 2, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 3, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 4, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 5, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 6, 12, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 7, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 8, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 9, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 10, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 11, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 12, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 13, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 14, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110928014514, 15, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 1, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 2, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 3, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 4, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 5, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 6, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031003014515, 7, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 1, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 2, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 3, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 4, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 5, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 6, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 7, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 8, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050909014516, 9, 181, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515014517, 1, 7, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515014517, 2, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515014517, 3, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515014517, 4, 74, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 1, 127, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 2, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 3, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 4, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 5, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 6, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 7, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 8, 83, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 9, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 10, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 11, 72, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 12, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 13, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 14, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 15, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 16, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014518, 17, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607014519, 1, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607014519, 2, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607014519, 3, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607014519, 4, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607014519, 5, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010918014520, 1, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 3, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 4, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 5, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 6, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 7, 154, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 8, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 9, 95, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 10, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 11, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 12, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 13, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 14, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130801013451, 15, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 1, 38, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 2, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 3, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 4, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 5, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 6, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040205013452, 7, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219013453, 1, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219013453, 2, 164, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219013453, 3, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219013453, 4, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020219013453, 5, 108, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 1, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 2, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 3, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 4, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 5, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 6, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 7, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 8, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 9, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 10, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 11, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 12, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 13, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120125013454, 14, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 1, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 2, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 3, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 4, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 5, 182, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 6, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 7, 186, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031105013455, 8, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 1, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 2, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 3, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 4, 153, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 5, 74, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 6, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021227013456, 7, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 1, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 2, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 3, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 4, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 5, 159, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 6, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 7, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 8, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 9, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 10, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071103013457, 11, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 1, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 2, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 3, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 4, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 5, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 6, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 7, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 8, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 9, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 10, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 11, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 12, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528013458, 13, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 1, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 2, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 3, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 4, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 5, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 6, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 7, 158, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 8, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 9, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 10, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091225013459, 11, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 1, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 2, 29, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 3, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 4, 122, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 5, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 6, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 7, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 8, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 9, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 10, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 11, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 12, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101106013460, 13, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 1, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 3, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 4, 106, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 5, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 6, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 7, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 8, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 9, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 10, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 11, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 12, 44, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 13, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 14, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 15, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 16, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140104013461, 17, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 1, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 2, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 3, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 4, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 5, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 6, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 7, 17, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 8, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 9, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 10, 66, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 11, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 12, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 13, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 14, 107, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 15, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317013462, 16, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 1, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 2, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 3, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 4, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 5, 192, 36, 18, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 6, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 7, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 8, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 9, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526013463, 10, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 1, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 2, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 3, 55, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 4, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 5, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 6, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 7, 43, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040411013464, 8, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 1, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 2, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 3, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 4, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 5, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 6, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 7, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 8, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050131013465, 9, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 1, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 2, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 3, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 4, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 5, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 6, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013466, 7, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 1, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 2, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 3, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 4, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 5, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 6, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 7, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 8, 56, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 9, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 10, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 11, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 12, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013467, 13, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 1, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 2, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 3, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 4, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 5, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 6, 5, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 7, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 8, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 9, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 10, 110, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 11, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 12, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 13, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 14, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 15, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013468, 16, 173, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 1, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 2, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 3, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 4, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 5, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129013469, 6, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110013470, 1, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110013470, 2, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110013470, 3, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110013470, 4, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021110013470, 5, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 1, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 2, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 3, 1, 50, 3, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 4, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 5, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 6, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 7, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 8, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 9, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 10, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 11, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 12, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 13, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 14, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 15, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120929013471, 16, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 1, 27, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 2, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 3, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 4, 187, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 5, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 6, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 7, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 8, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 9, 192, 95, 18, 1710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 10, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 11, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 12, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 13, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 8, 146, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 9, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 10, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 11, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 12, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100116013849, 13, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122013850, 1, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122013850, 2, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122013850, 3, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 1, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 2, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 3, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 4, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 5, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020120013851, 6, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117013852, 1, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117013852, 2, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117013852, 3, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117013852, 4, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020117013852, 5, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 1, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 2, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 3, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 4, 43, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 5, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 6, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 7, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 8, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 9, 177, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 10, 78, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 11, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 12, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 13, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121012013853, 14, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228013854, 1, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228013854, 2, 73, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228013854, 3, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228013854, 4, 94, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031228013854, 5, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 1, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 2, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 3, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 4, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 5, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 6, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 7, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 8, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 9, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 10, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 11, 111, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 12, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 13, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 14, 72, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 15, 55, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 16, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 17, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112013855, 18, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 1, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 2, 80, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 3, 10, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 4, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 5, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 6, 52, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 7, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 8, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 9, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 10, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 11, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203013856, 12, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 1, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 2, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 3, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 4, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 5, 30, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 6, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 7, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 8, 130, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213013857, 9, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 1, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 2, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 3, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 4, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 5, 95, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 6, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 7, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 8, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 9, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 10, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531013858, 11, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 1, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 2, 63, 34, 13, 442);
commit;
prompt 142000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 3, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 4, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 5, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 6, 61, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 7, 183, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 8, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040124013859, 9, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617013860, 1, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617013860, 2, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617013860, 3, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617013860, 4, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000617013860, 5, 89, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 1, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 2, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 3, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 4, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 5, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013861, 6, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 1, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 2, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 3, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 4, 135, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 5, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 6, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 7, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 8, 103, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 9, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 10, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 11, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 12, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 13, 27, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 14, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 15, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110724013862, 16, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 1, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 2, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 3, 185, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 4, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 5, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 6, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 7, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 8, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 9, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 10, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 11, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 12, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 13, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 14, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 15, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130730013863, 16, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 1, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 2, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 3, 130, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 4, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 5, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 6, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 7, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 8, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 9, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 10, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 11, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 12, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 13, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110105013864, 14, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 1, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 2, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 3, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 4, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 5, 98, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 6, 32, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 7, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 8, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 9, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 10, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081221013865, 11, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 1, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 2, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 3, 133, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 4, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 5, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 6, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 7, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 8, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 9, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 10, 157, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 11, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 12, 117, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 13, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 14, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 15, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 16, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 17, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 18, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140408013866, 19, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105013867, 1, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105013867, 2, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011105013867, 3, 45, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 1, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 2, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 3, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 4, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 5, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 6, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 7, 65, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 8, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 9, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 10, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 11, 96, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 12, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 13, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 14, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 15, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013868, 16, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 1, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 2, 137, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 3, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 4, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 5, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 6, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 7, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 8, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 9, 7, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 10, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 11, 168, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 12, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 13, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 14, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008013869, 15, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428013870, 1, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428013870, 2, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428013870, 3, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428013870, 4, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030428013870, 5, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 1, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 2, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 3, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 4, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 5, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 6, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 7, 2, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 8, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 9, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 10, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 11, 95, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 12, 4, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 13, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620013871, 14, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 1, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 3, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 4, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 5, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 6, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 7, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 8, 176, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 9, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 10, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 11, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 12, 43, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403014223, 13, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 1, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 2, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 3, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 4, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 5, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 6, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 7, 50, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 8, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 9, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 10, 121, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 11, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 12, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 13, 118, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 14, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 15, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121203014224, 16, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 1, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 2, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 3, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 4, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 5, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 6, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 7, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 8, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 9, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 10, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 11, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 12, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 13, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 14, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 15, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110420014225, 16, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 1, 52, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 2, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 3, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 4, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 5, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 6, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 7, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 8, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 9, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 10, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 11, 27, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105014226, 12, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 1, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 2, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 3, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 4, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 5, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 6, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 7, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 8, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060525014227, 9, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 1, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 2, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 3, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 4, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 5, 178, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 6, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 7, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 8, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 9, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 10, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 11, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 12, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 13, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 14, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 15, 131, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014228, 16, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 1, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 2, 102, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 3, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 4, 112, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 5, 134, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 6, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 7, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 8, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 9, 180, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 10, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 11, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 12, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 13, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 14, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 15, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130210014229, 16, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 1, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 2, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 3, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 4, 100, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 5, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 6, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 7, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 8, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 9, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 10, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 11, 68, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 12, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 13, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619014230, 14, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114014231, 1, 40, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114014231, 2, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114014231, 3, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114014231, 4, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010114014231, 5, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 1, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 2, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 3, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 4, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 5, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020716014232, 6, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 1, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 2, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 3, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 4, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 5, 169, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 6, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 7, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 8, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 9, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 10, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 11, 178, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117014233, 12, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503014234, 1, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503014234, 2, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503014234, 3, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 1, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 2, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 3, 97, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 4, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 5, 32, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 6, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 7, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 8, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 9, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 10, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 11, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 12, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 13, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 14, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 15, 69, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130314014235, 16, 62, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 1, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 2, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 3, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 4, 89, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 5, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 6, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 7, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 8, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 9, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 10, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 11, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 12, 186, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 13, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014236, 14, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 1, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 2, 184, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 3, 13, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 4, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 5, 18, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 6, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 7, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 8, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721014237, 9, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 1, 160, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 2, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 3, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 4, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 5, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 6, 101, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 7, 148, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 8, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 9, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 10, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 11, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100906014238, 12, 185, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 1, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 2, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 3, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 4, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 5, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 6, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113014239, 7, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 1, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 2, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 3, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 4, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 6, 35, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 7, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 8, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 9, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 10, 103, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 11, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100208014240, 12, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 1, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 2, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 3, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 4, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 5, 24, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 6, 34, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 7, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 8, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 9, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 10, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 11, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 12, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 13, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 14, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824014241, 15, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 1, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 2, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 3, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 4, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 5, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 6, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 7, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 8, 69, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603014242, 9, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 1, 187, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 2, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 3, 136, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 4, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 5, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 6, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 7, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 8, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 3, 34, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 4, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 5, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 6, 72, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 7, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 8, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 9, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 10, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 11, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 12, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080204014542, 13, 139, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014543, 1, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014543, 2, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518014543, 3, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701014544, 1, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701014544, 2, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701014544, 3, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701014544, 4, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 1, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 2, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 3, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 4, 48, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 5, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 6, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 7, 191, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 8, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 9, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 10, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 11, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 12, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 13, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 14, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 15, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120421014545, 16, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 1, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 2, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 3, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 4, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 5, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 6, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 7, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 8, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050902014546, 9, 141, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619014547, 1, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619014547, 2, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619014547, 3, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 1, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 2, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 3, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 4, 110, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 5, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 6, 96, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030626014548, 7, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 1, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 2, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 3, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 4, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 5, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926014549, 6, 77, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 1, 64, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 2, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 3, 91, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 4, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 5, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908014550, 6, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 1, 173, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 2, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 3, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 4, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 5, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 6, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 7, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 8, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 9, 4, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 10, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080926014551, 11, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 1, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 2, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 3, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 4, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 5, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 6, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802014552, 7, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 1, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 2, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 3, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 4, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 5, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 6, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 7, 93, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 8, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 9, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 10, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090427014553, 11, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 1, 78, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 2, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 3, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 4, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 5, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 6, 153, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 7, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 8, 176, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060327014554, 9, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 1, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 2, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 3, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 4, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 5, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 6, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 7, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 8, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 9, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 10, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 11, 191, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410014555, 12, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118014556, 1, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118014556, 2, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118014556, 3, 138, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118014556, 4, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201014557, 1, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201014557, 2, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201014557, 3, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201014557, 4, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201014557, 5, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 1, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 2, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 3, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 4, 166, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 5, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 6, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 7, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 8, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 9, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 10, 57, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 11, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 12, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 13, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315014558, 14, 159, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 1, 148, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 2, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 3, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 4, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 5, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 6, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 7, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 8, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 9, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 10, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 11, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 12, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 13, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828014559, 14, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 1, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 2, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 3, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 4, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 5, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 6, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 7, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 8, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 9, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 10, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 11, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 12, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 13, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 14, 119, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 15, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118014560, 16, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 1, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 2, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 3, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 4, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 5, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 6, 89, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 7, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 8, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306014561, 9, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 1, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 2, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 3, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 4, 112, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 5, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 6, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031005014562, 7, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 1, 114, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 2, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 3, 174, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 4, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 5, 44, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 6, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 7, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 8, 46, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 9, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 10, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107014563, 11, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004014564, 1, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004014564, 2, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 1, 45, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 2, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 3, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 4, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 5, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 6, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 7, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 8, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 9, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 10, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108014565, 11, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 1, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 2, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 3, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 4, 50, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 5, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 6, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 7, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 8, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 9, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 10, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 11, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709014566, 12, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 1, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 2, 92, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 3, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 4, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 5, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 6, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 7, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 8, 5, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 9, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 10, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 11, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 12, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 13, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110510014567, 14, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 1, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 2, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 3, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 4, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127014568, 5, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 14, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 15, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 16, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121018013472, 17, 41, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 1, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 2, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 3, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 4, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 5, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 6, 155, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 7, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 8, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 9, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329013473, 10, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 1, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 2, 78, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 3, 52, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 4, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 5, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 6, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 7, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 8, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 9, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 10, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 11, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 12, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 13, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 14, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112013474, 15, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011013475, 1, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011013475, 2, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011013475, 3, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 1, 85, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 2, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 3, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 4, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 5, 185, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 6, 129, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 7, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 8, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 9, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 10, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 11, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 12, 120, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 13, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 14, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329013476, 15, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 1, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 2, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 3, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 4, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 5, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 6, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 7, 107, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 8, 109, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 9, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630013477, 10, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 1, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 2, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 3, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 4, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 5, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 6, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 7, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 8, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203013478, 9, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 1, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 2, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 3, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 4, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 5, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 6, 153, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 7, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 8, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 9, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 10, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 11, 9, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 12, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 13, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716013479, 14, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 1, 134, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 2, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 3, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 4, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 5, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 6, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 7, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 8, 81, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 9, 109, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 10, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 11, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 12, 63, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 13, 176, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 14, 64, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 15, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 16, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 17, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140117013480, 18, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 1, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 2, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 3, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 4, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 5, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 6, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 7, 107, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 8, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040515013481, 9, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 1, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 2, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 3, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 4, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 5, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 6, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 7, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 8, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 9, 77, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060802013482, 10, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107013483, 1, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107013483, 2, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107013483, 3, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107013483, 4, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 1, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 2, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 3, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 4, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 5, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 6, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 7, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 8, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 9, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 10, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 11, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 12, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 13, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 14, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 15, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 16, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106013484, 17, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305013485, 1, 70, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305013485, 2, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305013485, 3, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622013486, 1, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622013486, 2, 156, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622013486, 3, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020622013486, 4, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 1, 66, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 2, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 3, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 4, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 5, 105, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 6, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 7, 180, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 8, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 9, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410013487, 10, 117, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901013488, 1, 164, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901013488, 2, 179, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901013488, 3, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901013488, 4, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901013488, 5, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 1, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 2, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 3, 11, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 4, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 5, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 6, 95, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 7, 68, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 8, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060804013489, 9, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 1, 171, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 2, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 3, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 4, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 5, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 6, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 7, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 8, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 9, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 10, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 11, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090922013490, 12, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 1, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 2, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 3, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 4, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 5, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 6, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 7, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 8, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 9, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 10, 12, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 11, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 12, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824013491, 13, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 1, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 2, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 3, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 4, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 5, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 6, 1, 19, 3, 57);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 7, 153, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 8, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 9, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 10, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 11, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 12, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 13, 40, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 14, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 15, 35, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 16, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819013492, 17, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 1, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 2, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 3, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 4, 51, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 5, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 6, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 7, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 8, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 9, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 10, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 11, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 12, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110911013493, 13, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 1, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 2, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 3, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 4, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 5, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 6, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 7, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 8, 32, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 9, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 10, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 11, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 12, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 13, 45, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 14, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920013494, 15, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 2, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 3, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 4, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 5, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 6, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 7, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 8, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 9, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 10, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 11, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 12, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 13, 136, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110311013872, 14, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 1, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 2, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 3, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 4, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 5, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 6, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 7, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 8, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 9, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 10, 46, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 11, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 12, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 13, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 14, 115, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121013873, 15, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 1, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 2, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 4, 84, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 5, 88, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 6, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040630013874, 7, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 1, 144, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 2, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 3, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 4, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 5, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 6, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 7, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 8, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 9, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002013875, 10, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 1, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 2, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 3, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 4, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 5, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 6, 134, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 7, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 8, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 9, 120, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 10, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 11, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 12, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 13, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620013876, 14, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 1, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 2, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 3, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 4, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 5, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 6, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 7, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 8, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 9, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 10, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090629013877, 11, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124013878, 1, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124013878, 2, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000124013878, 3, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 1, 112, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 2, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 3, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 4, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 5, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 6, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 7, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 8, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 9, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 10, 169, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 11, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 12, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203013879, 13, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 1, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 2, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 3, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 4, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 5, 4, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 6, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 7, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 8, 187, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 9, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 10, 103, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 11, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 12, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 13, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303013880, 14, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108013881, 1, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108013881, 2, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108013881, 3, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000108013881, 4, 5, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 1, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 2, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 3, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 4, 17, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 5, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 6, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 7, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 8, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 9, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 10, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 11, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 12, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 13, 172, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 14, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624013882, 15, 142, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 1, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 2, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 3, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 4, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 5, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 6, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 7, 41, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 8, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 9, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 10, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 11, 96, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 12, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 13, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 14, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 15, 145, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 16, 14, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 17, 13, 62, 8, 496);
commit;
prompt 143000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628013883, 18, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410013884, 1, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410013884, 2, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410013884, 3, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410013884, 4, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030410013884, 5, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 1, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 2, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 3, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 4, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 5, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 6, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 7, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 8, 19, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 9, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 10, 80, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429013885, 11, 46, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 1, 41, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 2, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 3, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 4, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 5, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 6, 24, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 7, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808013886, 8, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 1, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 2, 179, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 3, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 4, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 5, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 6, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 7, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 8, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 9, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 10, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 11, 13, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 12, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 13, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 14, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105013887, 15, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 1, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 2, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 3, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 4, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 5, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013888, 6, 92, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507013889, 1, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507013889, 2, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507013889, 3, 93, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507013889, 4, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507013889, 5, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 1, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 2, 30, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 3, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 4, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 5, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040712013890, 6, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 1, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 2, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 3, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 4, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 5, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031211013891, 6, 22, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 1, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 2, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 3, 152, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 4, 90, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 5, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 6, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 7, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 8, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005013892, 9, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402013893, 1, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402013893, 2, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402013893, 3, 42, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402013893, 4, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010402013893, 5, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819013894, 1, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819013894, 2, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819013894, 3, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819013894, 4, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819013894, 5, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522013895, 1, 112, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522013895, 2, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522013895, 3, 170, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522013895, 4, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522013895, 5, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 1, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 2, 144, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 3, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 4, 145, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 5, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 6, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 7, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 8, 52, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 9, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 10, 61, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013896, 11, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003013897, 1, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003013897, 2, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003013897, 3, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003013897, 4, 63, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003013897, 5, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 9, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 10, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 11, 164, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126014243, 12, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 1, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 2, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 3, 45, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 4, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 5, 188, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 6, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 7, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 8, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 9, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 10, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 11, 46, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 12, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 13, 154, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 14, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130711014244, 15, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514014245, 1, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514014245, 2, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514014245, 3, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514014245, 4, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514014245, 5, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 1, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 2, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 3, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 4, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 5, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906014246, 6, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 1, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 2, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 3, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 4, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 5, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 6, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 7, 134, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 8, 160, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 9, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 10, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 11, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 12, 22, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124014247, 13, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 1, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 2, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 3, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 4, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 5, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 6, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 7, 94, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 8, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 9, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 10, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 11, 142, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 12, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111219014248, 13, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 1, 159, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 2, 128, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 3, 137, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 4, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 5, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 6, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 7, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 8, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 9, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 10, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 11, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101004014249, 12, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 1, 99, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 2, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 3, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 4, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 5, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 6, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 7, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221014250, 8, 191, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221014251, 1, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221014251, 2, 121, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221014251, 3, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221014251, 4, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 1, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 2, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 3, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 4, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 5, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 6, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 7, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 8, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 9, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 10, 158, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523014252, 11, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 1, 171, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 2, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 3, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 4, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 5, 14, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 6, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 7, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 8, 105, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 9, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 10, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 11, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 12, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 13, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 14, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204014253, 15, 63, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 1, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 2, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 3, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 4, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 5, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 6, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 7, 113, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 8, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 9, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 10, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214014254, 11, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524014255, 1, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524014255, 2, 122, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524014255, 3, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524014255, 4, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 1, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 2, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 3, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 4, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 5, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 6, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124014256, 7, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 1, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 2, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 3, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 4, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 5, 87, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 6, 50, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 7, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 8, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 9, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 10, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325014257, 11, 14, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912014258, 1, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912014258, 2, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912014258, 3, 57, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 1, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 2, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 3, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 4, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 5, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 6, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 7, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 8, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 9, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 10, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 11, 1, 1, 3, 3);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 12, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 13, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 14, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 15, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 16, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 17, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301014259, 18, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 1, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 2, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 3, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 4, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 5, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 6, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 7, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050830014260, 8, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 1, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 2, 190, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 3, 24, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 4, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 5, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 6, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 7, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 8, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 9, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 10, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 11, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 12, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 13, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 14, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014261, 15, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 1, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 2, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 3, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 4, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 5, 183, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020221014262, 6, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 1, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 2, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 3, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 4, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 5, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 6, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 7, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409014263, 8, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 1, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 2, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 3, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 4, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 5, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 6, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 7, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 8, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 9, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 10, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 11, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 12, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 13, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 14, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 15, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817014264, 16, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131014265, 1, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131014265, 2, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131014265, 3, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131014265, 4, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131014265, 5, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130014266, 1, 174, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130014266, 2, 192, 31, 18, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130014266, 3, 149, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130014266, 4, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 1, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 2, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 3, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 4, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 5, 190, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 6, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 7, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 8, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 9, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918014267, 10, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 1, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 2, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 3, 94, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 4, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 5, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 6, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 7, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 6, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 7, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 8, 90, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 9, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 10, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 11, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 12, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 13, 61, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 14, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 15, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 16, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905013118, 17, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 1, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 2, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 3, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 4, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 5, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 6, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 7, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021013119, 8, 35, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 1, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 2, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 3, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 4, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 5, 71, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 6, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 7, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 8, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 9, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 10, 1, 11, 3, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 11, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 12, 71, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 13, 49, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 14, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 15, 134, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 16, 142, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 17, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140410013120, 18, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 1, 146, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 2, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 3, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 4, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 5, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 6, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 7, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 8, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 9, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 10, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 11, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 12, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 13, 41, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 14, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 15, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 16, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 17, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130218013121, 18, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 1, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 2, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 3, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 4, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 5, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 6, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 7, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 8, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070306013122, 9, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 1, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 2, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 3, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 4, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 5, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 6, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 7, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 8, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 9, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070912013123, 10, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 1, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 2, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 3, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 4, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 5, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 6, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 7, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050103013124, 8, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 1, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 2, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 3, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 4, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 5, 98, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 6, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 7, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 8, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 9, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 10, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 11, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013125, 12, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 1, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 2, 75, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 3, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 4, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 5, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 6, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 7, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916013126, 8, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 1, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 2, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 3, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 4, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 5, 150, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 6, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 7, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050323013127, 8, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 1, 6, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 2, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 3, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 4, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 5, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 6, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 7, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 8, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 9, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 10, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 11, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911013128, 12, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 1, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 2, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 3, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 4, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 5, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 6, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 7, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 8, 31, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 9, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 10, 181, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 11, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 12, 12, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100314013129, 13, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 1, 152, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 2, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 3, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 4, 178, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 5, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 6, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 7, 56, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 8, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 9, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 10, 110, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 11, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 12, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100721013130, 13, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 1, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 2, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 3, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 4, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 5, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030407013131, 6, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 1, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 2, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 3, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 4, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 5, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 6, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 7, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 8, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013132, 9, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 1, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 2, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 3, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 4, 133, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 5, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 6, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 7, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 8, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070723013133, 9, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203013134, 1, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203013134, 2, 14, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203013134, 3, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 1, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 2, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 3, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 4, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 5, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 6, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 7, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 8, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 9, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 10, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080302013135, 11, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 1, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 2, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 3, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 4, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 5, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 6, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 7, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 8, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 9, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 10, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 11, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 12, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 13, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 14, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 15, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 16, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 17, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 18, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140514013136, 19, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 1, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 2, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 3, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 4, 88, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 5, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 6, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 7, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 8, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 9, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 10, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 11, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 12, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 13, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 14, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120523013137, 15, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 1, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 2, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 3, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 4, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 5, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031201013138, 6, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 1, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 2, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 3, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 4, 146, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 5, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 6, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 7, 172, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 8, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 9, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 10, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 11, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 12, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514013495, 1, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514013495, 2, 40, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514013495, 3, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000514013495, 4, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006013496, 1, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006013496, 2, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006013496, 3, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 1, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 2, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 3, 81, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 4, 90, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 5, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 6, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 7, 47, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 8, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 9, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 10, 189, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080531013497, 11, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 1, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 2, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 3, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 4, 39, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 5, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 6, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 7, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 8, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 9, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 10, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 11, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 12, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 13, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 14, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 15, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519013498, 16, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 1, 156, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 2, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 3, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 4, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 5, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111013499, 6, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 1, 53, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 2, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 3, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 4, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 5, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041019013500, 6, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 1, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 2, 64, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 3, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 4, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 5, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 6, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 7, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 8, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 9, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 10, 50, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 11, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 12, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 13, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728013501, 14, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326013502, 1, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326013502, 2, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000326013502, 3, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 1, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 2, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 3, 66, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 4, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 5, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 6, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 7, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 8, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 9, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 10, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070622013503, 11, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 1, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 2, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 3, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 4, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 5, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 6, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 7, 63, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 8, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 9, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117013504, 10, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 1, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 2, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 3, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 4, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 5, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 6, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 7, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 8, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061213013505, 9, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 1, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 2, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 3, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 4, 159, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 5, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 6, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128013506, 7, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 1, 183, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 2, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 3, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 4, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 5, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 6, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 7, 133, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 8, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 9, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 10, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 11, 144, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 12, 11, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013507, 13, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 1, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 2, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 3, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 4, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 5, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 6, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 7, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 8, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325013508, 9, 154, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 1, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 2, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 3, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 4, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 5, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 6, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 7, 54, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 8, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 9, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 10, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 11, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 12, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100225013509, 13, 118, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 1, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 2, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 3, 127, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 4, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 5, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901013510, 6, 134, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829013511, 1, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829013511, 2, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829013511, 3, 94, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829013511, 4, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 1, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 2, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 3, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 4, 153, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 5, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 6, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 7, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 8, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 9, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 10, 16, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 11, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 12, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 13, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090324013512, 14, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 1, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 2, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 3, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 4, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 5, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 6, 45, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 7, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 8, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 9, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 10, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 11, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 12, 174, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 13, 8, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 14, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724013513, 15, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 1, 61, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 2, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 3, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 4, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 5, 188, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 6, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 7, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 8, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128013514, 9, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 1, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 2, 115, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 3, 118, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 4, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 5, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 6, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 7, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 8, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 9, 40, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 10, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 11, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 12, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 13, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 14, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117013515, 15, 131, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 1, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 2, 82, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 3, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 4, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 5, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627013516, 6, 7, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 1, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 2, 35, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 3, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 4, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 5, 44, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 6, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040419013517, 7, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 1, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 2, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 3, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 4, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 5, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 6, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 7, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 8, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 9, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826013518, 10, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 1, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 2, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 3, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 4, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 5, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 6, 18, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 7, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 8, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 9, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 10, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 11, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 12, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 13, 4, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110627013519, 14, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 1, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 2, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 3, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 4, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 5, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013898, 1, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013898, 2, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013898, 3, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804013898, 4, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 1, 172, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 2, 134, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 3, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 4, 153, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 5, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 6, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 7, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 8, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 9, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 10, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 11, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 12, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 13, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110508013899, 14, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 1, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 2, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 3, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 4, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 5, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 6, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 7, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 8, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 9, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 10, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 11, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 12, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 13, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121003013900, 14, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 1, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 2, 163, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 3, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 4, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 5, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 6, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 7, 32, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 8, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 9, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 10, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 11, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 12, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 13, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 14, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 15, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 16, 36, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130829013901, 17, 3, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111013902, 1, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111013902, 2, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111013902, 3, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111013902, 4, 97, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 1, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 2, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 3, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 4, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 5, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 6, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 7, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 8, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 9, 111, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 10, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 11, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 12, 39, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 13, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 14, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 15, 81, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302013903, 16, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 1, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 2, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 3, 113, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 4, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 5, 135, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 6, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 7, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 8, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 9, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 10, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 11, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 12, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090603013904, 13, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 1, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 2, 4, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 3, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 4, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 5, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 6, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 7, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 8, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 9, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 10, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 11, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 12, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 13, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111115013905, 14, 31, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 1, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 2, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 3, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 4, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 5, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 6, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 7, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 8, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 9, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 10, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 11, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 12, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 13, 34, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 14, 7, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120623013906, 15, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 1, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 2, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 3, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 4, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 5, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 6, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 7, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 8, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 9, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 10, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 11, 121, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 12, 153, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 13, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120924013907, 14, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 1, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 2, 175, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 3, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 4, 74, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 5, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 6, 93, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 7, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 8, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 9, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 10, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 11, 104, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 12, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 13, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 14, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 15, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121020013908, 16, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310013909, 1, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310013909, 2, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310013909, 3, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000310013909, 4, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 1, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 2, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 3, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 4, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 5, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 6, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 7, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 8, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 9, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 10, 91, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516013910, 11, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 1, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 2, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 3, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 4, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 5, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 6, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 7, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 8, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 9, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 10, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 11, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 12, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 13, 117, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 14, 41, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426013911, 15, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 1, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 2, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 3, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 4, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 5, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 6, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 7, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 8, 152, 46, 16, 736);
commit;
prompt 144000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 9, 78, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 10, 138, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 11, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 12, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100204013912, 13, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 1, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 2, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 3, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 4, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 5, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 6, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 7, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 8, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050801013913, 9, 128, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 1, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 2, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 3, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 4, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 5, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 6, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 7, 144, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 8, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 9, 175, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 10, 88, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 11, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 12, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 13, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 14, 8, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913013914, 15, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 1, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 2, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 3, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 4, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 5, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 6, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 7, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 8, 77, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 9, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 10, 13, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 11, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020013915, 12, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120013916, 1, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120013916, 2, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929013917, 1, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929013917, 2, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000929013917, 3, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 1, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 2, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 3, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 4, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 5, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 6, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 7, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 8, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 9, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 10, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 11, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 12, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 13, 36, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 14, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 8, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 9, 44, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 10, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 11, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 12, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 13, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090802014268, 14, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 1, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 2, 24, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 3, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 4, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 5, 138, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021126014269, 6, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725014270, 1, 82, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725014270, 2, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725014270, 3, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725014270, 4, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010725014270, 5, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 1, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 2, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 3, 165, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 4, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 5, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121014271, 6, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 1, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 2, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 3, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 4, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 5, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 6, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 7, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050217014272, 8, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 1, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 2, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 3, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 4, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 5, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 6, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 7, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 8, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 9, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 10, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 11, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221014273, 12, 9, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 1, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 2, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 3, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 4, 186, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 5, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 6, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 7, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 8, 96, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 9, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081115014274, 10, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 1, 52, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 2, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 3, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 4, 79, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 5, 167, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 6, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 7, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 8, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 9, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 10, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 11, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 12, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090610014275, 13, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025014276, 1, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025014276, 2, 3, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025014276, 3, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025014276, 4, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025014276, 5, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 1, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 2, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 3, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 4, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 5, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 6, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 7, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 8, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008014277, 9, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 1, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 2, 75, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 3, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 4, 71, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 5, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 6, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 7, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 8, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 9, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 10, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 11, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 12, 2, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 13, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 14, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 15, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 16, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 17, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014278, 18, 124, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 1, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 2, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 3, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 4, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 5, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 6, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 7, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 8, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 9, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 10, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 11, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 12, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 13, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 14, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 15, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110528014279, 16, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 1, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 2, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 3, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 4, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 5, 130, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 6, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 7, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 8, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070714014280, 9, 1, 72, 3, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302014281, 1, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302014281, 2, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302014281, 3, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 1, 51, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 2, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 3, 47, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 4, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 5, 98, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 6, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 7, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 8, 4, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 9, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 10, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 11, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510014282, 12, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 1, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 2, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 3, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 4, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 5, 7, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 6, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 7, 180, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 8, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 9, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 10, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 11, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 12, 73, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090405014283, 13, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 1, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 2, 161, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 3, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 4, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 5, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 6, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 7, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 8, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 9, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 10, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 11, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 12, 154, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 13, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 14, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 15, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102014284, 16, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222014285, 1, 87, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222014285, 2, 84, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222014285, 3, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001222014285, 4, 174, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 1, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 2, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 3, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 4, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 5, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 6, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 7, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 8, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 9, 179, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 10, 19, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060202014286, 11, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325014287, 1, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325014287, 2, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325014287, 3, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000325014287, 4, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 1, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 2, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 3, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 4, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 5, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 6, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523014288, 7, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014289, 1, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014289, 2, 130, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014289, 3, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014289, 4, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 1, 111, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 2, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 3, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 4, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 5, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 6, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 7, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 8, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 9, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 10, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091102014290, 11, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 1, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 2, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 3, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 4, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 5, 119, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 6, 12, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 7, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 8, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 9, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 10, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 11, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 12, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 13, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 14, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203014291, 15, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 1, 180, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 2, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 3, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 4, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 5, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 6, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 7, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 8, 121, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 9, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 10, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 11, 69, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 12, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 13, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 14, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403014292, 15, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 13, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512013139, 14, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 1, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 2, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 3, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 4, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 5, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 6, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 7, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 8, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 9, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 10, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 11, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 12, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 13, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 14, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 15, 107, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 16, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227013140, 17, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 1, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 2, 22, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 3, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 4, 139, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 5, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 6, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 7, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 8, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 9, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 10, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 11, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 12, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 13, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 14, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 15, 72, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 16, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013141, 17, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 1, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 2, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 3, 90, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 4, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 5, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 6, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 7, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 8, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 9, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 10, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 11, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 12, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 13, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 14, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100924013142, 15, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 1, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 2, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 3, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 4, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 5, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 6, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 7, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 8, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 9, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 10, 85, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 11, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 12, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 13, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 14, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605013143, 15, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 1, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 2, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 3, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 4, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 5, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 6, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 7, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 8, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 9, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 10, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826013144, 11, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 1, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 2, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 3, 11, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 4, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 5, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 6, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 7, 148, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 8, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 9, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050702013145, 10, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 1, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 2, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 3, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 4, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 5, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 6, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 7, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 8, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050917013146, 9, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 1, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 2, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 3, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 4, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 5, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 6, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020415013147, 7, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 1, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 2, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 3, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 4, 13, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 5, 156, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 6, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 7, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 8, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 9, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050120013148, 10, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118013149, 1, 57, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118013149, 2, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118013149, 3, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118013149, 4, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 1, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 2, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 3, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 4, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 5, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 6, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 7, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 8, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 9, 74, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 10, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 11, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 12, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 13, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 14, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 15, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123013150, 16, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322013151, 1, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322013151, 2, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000322013151, 3, 39, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 1, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 2, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 3, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 4, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 5, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 6, 179, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 7, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 8, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 9, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 10, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208013152, 11, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013153, 1, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013153, 2, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013153, 3, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013153, 4, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525013153, 5, 129, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 1, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 2, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 3, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 4, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 5, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 6, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 7, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 8, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 9, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 10, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 11, 172, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 12, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 13, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 14, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121207013154, 15, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225013155, 1, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225013155, 2, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225013155, 3, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225013155, 4, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 1, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 2, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 3, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 4, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 5, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 6, 49, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 7, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 8, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 9, 14, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 10, 55, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 11, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 12, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 13, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 14, 65, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 15, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013156, 16, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 1, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 2, 47, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 3, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 4, 119, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 5, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 6, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 7, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060511013157, 8, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 1, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 2, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 3, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 4, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 5, 14, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 6, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 7, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 8, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 9, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 10, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 11, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 12, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 13, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 14, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 15, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 16, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 17, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703013158, 18, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 1, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 2, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 3, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 4, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 5, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 6, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 7, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 8, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 9, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 10, 151, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 11, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 12, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 13, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707013159, 14, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 1, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 2, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 3, 108, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 4, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 5, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 6, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 7, 135, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 8, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 9, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 10, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 11, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 12, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 6, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 7, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 8, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 9, 155, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430013520, 10, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 1, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 2, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 3, 78, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 4, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 5, 92, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 6, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526013521, 7, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 1, 24, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 2, 122, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 3, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 4, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 5, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 6, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 7, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 8, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 9, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 10, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 11, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090525013522, 12, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 1, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 2, 21, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 3, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 4, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 5, 191, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 6, 33, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 7, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 8, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 9, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 10, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 11, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 12, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 13, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 14, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 15, 49, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121019013523, 16, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 1, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 2, 37, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 3, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 4, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 5, 65, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 6, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 7, 179, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 8, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 9, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 10, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 11, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 12, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 13, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 14, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110209013524, 15, 176, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 1, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 2, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 3, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 4, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 5, 29, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 6, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 7, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 8, 183, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 9, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 10, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 11, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 12, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 13, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 14, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 15, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 16, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140331013525, 17, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 1, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 2, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 3, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 4, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 5, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 6, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 7, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 8, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 9, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 10, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 11, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 12, 22, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 13, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 14, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921013526, 15, 182, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 1, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 2, 173, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 3, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 4, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 5, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 6, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 7, 35, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 8, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 9, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 10, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070602013527, 11, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 1, 27, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 2, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 3, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 4, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 5, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 6, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 7, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 8, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 9, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 10, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080529013528, 11, 119, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 1, 61, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 2, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 3, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 4, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 5, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 6, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030422013529, 7, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908013530, 1, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908013530, 2, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908013530, 3, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908013530, 4, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010908013530, 5, 49, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013531, 1, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013531, 2, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013531, 3, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013531, 4, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212013531, 5, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 1, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 2, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 3, 131, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 4, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 5, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 6, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 7, 183, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 8, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051001013532, 9, 190, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228013533, 1, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228013533, 2, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228013533, 3, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001228013533, 4, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 1, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 2, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 3, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 4, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 5, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 6, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 7, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 8, 137, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 9, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602013534, 10, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 1, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 2, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 3, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 4, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 5, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 6, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 7, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 8, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208013535, 9, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129013536, 1, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129013536, 2, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129013536, 3, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129013536, 4, 1, 99, 3, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129013536, 5, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213013537, 1, 156, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213013537, 2, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213013537, 3, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213013537, 4, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010213013537, 5, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 1, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 2, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 3, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 4, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 5, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 6, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 7, 25, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 8, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 9, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 10, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 11, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313013538, 12, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 1, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 2, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 3, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 4, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 5, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 6, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021114013539, 7, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 1, 84, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 2, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 3, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 4, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 5, 104, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 6, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312013540, 7, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 1, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 2, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 3, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 4, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 5, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011119013541, 6, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 1, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 2, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 3, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 4, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 5, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 6, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 7, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 8, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 9, 136, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 10, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 11, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 12, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090223013542, 13, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 1, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 2, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 3, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 4, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 5, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 6, 153, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 7, 102, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 8, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 9, 64, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 10, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 11, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 12, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 13, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223013543, 14, 99, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 1, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 2, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 3, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 4, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 5, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 6, 174, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 7, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 8, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 9, 8, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 10, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 11, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 12, 29, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 15, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013918, 16, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 1, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 2, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 3, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 4, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 5, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 6, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031229013919, 7, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 1, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 2, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 3, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 4, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 5, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 6, 188, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 7, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 8, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 9, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 10, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 11, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 12, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126013920, 13, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205013921, 1, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205013921, 2, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205013921, 3, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 1, 142, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 2, 90, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 3, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 4, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 5, 64, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 6, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 7, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 8, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 9, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 10, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 11, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019013922, 12, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 1, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 2, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 3, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 4, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 5, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030322013923, 6, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408013924, 1, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408013924, 2, 38, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408013924, 3, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 1, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 2, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 3, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 4, 168, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 5, 160, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 6, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 7, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 8, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 9, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 10, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 11, 157, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 12, 81, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 13, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 14, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 15, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712013925, 16, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 1, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 2, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 3, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 4, 116, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 5, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 6, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 7, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050604013926, 8, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 1, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 2, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 3, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 4, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 5, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 6, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050605013927, 7, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 1, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 2, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 3, 90, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 4, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 5, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 6, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 7, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 8, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041209013928, 9, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120013929, 1, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120013929, 2, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120013929, 3, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 1, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 2, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 3, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 5, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104013930, 6, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 1, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 2, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 3, 125, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 4, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 5, 16, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 6, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 7, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 8, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 9, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 10, 44, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 11, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 12, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 13, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 14, 130, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 15, 100, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 16, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 17, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 18, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140407013931, 19, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 1, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 2, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 3, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 4, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 5, 155, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 6, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 7, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 8, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 9, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 10, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 11, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 12, 163, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 13, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720013932, 14, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 1, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 2, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 3, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 4, 93, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 5, 78, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 6, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 7, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 8, 72, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 9, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 10, 170, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 11, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 12, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 13, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 14, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906013933, 15, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 1, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 2, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 3, 79, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 4, 139, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 5, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 6, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 7, 104, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 8, 109, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 9, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730013934, 10, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 1, 116, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 2, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 3, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 4, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 5, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 6, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 7, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 8, 18, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 9, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 10, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 11, 111, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 12, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 13, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111228013935, 14, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 1, 117, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 2, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 3, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 4, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 5, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 6, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 7, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 8, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 9, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002013936, 10, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 1, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 2, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 3, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 4, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 5, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 6, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 7, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 8, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 9, 8, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 10, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 11, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 12, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 13, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 14, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 15, 29, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130504013937, 16, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023013938, 1, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023013938, 2, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023013938, 3, 129, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 1, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 2, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 3, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 4, 157, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 5, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 6, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041015013939, 7, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 1, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 2, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 3, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 4, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 5, 135, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 6, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 7, 43, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 8, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927013940, 9, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 1, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 2, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 3, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 4, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 5, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031215013941, 6, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202013942, 1, 127, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202013942, 2, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202013942, 3, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202013942, 4, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202013942, 5, 137, 83, 8, 664);
commit;
prompt 145000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913013943, 1, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913013943, 2, 18, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913013943, 3, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913013943, 4, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010913013943, 5, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520013944, 1, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000520013944, 2, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 1, 49, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 2, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 3, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 4, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 5, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 6, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 7, 26, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 8, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 9, 62, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 1, 74, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 2, 30, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 3, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 4, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 5, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 6, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 7, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 8, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 9, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 10, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 11, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 12, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 13, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 14, 73, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110109014293, 15, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 1, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 2, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 3, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 4, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 5, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 6, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 7, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 8, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205014294, 9, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120014295, 1, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120014295, 2, 51, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001120014295, 3, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 1, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 2, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 3, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 4, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 5, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 6, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 7, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 8, 181, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 9, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 10, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 11, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 12, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 13, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711014296, 14, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 1, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 2, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 3, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 4, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 5, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 6, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 7, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 8, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 9, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 10, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 11, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 12, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091230014297, 13, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 1, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 2, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 3, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 4, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 5, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 6, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 7, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 8, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 9, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 10, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 11, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 12, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 13, 64, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 14, 9, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120804014298, 15, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 1, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 2, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 3, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 4, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 5, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 6, 59, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 7, 35, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 8, 139, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 9, 40, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 10, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 11, 3, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 12, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 13, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 14, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 15, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 16, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130803014299, 17, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 1, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 2, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 3, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 4, 11, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 6, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 7, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 8, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 9, 166, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 10, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 11, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 12, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 13, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 14, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009014300, 15, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 1, 118, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 2, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 3, 29, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 4, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 5, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 6, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 7, 119, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 8, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 9, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 10, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 11, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 12, 186, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110418014301, 13, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 1, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 2, 170, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 3, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 4, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 5, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 6, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 7, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 8, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 9, 32, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 10, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 11, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 12, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 13, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 14, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120117014302, 15, 97, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 1, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 2, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 3, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 4, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 5, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 6, 78, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 7, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 8, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 9, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 10, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 11, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131014303, 12, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 1, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 2, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 3, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 4, 182, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 5, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 6, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 7, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 8, 9, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 9, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 10, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 11, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 12, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 13, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 14, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101207014304, 15, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 1, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 2, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 3, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 4, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 5, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020608014305, 6, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014306, 1, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014306, 2, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014306, 3, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000323014306, 4, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 1, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 2, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 3, 185, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 4, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 5, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 6, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125014307, 7, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 1, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 2, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 3, 175, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 4, 131, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 5, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 6, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 7, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 8, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 9, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 10, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 11, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 12, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 13, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821014308, 14, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 1, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 2, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 3, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 4, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 5, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 6, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 7, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 8, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 9, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 10, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 11, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 12, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 13, 64, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110618014309, 14, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 1, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 2, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 3, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 4, 5, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 5, 70, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010820014310, 6, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 1, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 2, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 3, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 4, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 5, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 6, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 7, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 8, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 9, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 10, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 11, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 12, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 13, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 14, 68, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120224014311, 15, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 1, 1, 2, 3, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 2, 150, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 3, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 4, 126, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 5, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010406014312, 6, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 1, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 2, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 3, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 4, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 5, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 6, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 7, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 8, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 9, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 10, 155, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 11, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 12, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 13, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 14, 1, 6, 3, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120914013160, 15, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 1, 101, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 2, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 3, 71, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 4, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 5, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020906013161, 6, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 1, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 2, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 3, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 4, 68, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 5, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 6, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 7, 44, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 8, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129013162, 9, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 1, 93, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 2, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 3, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 4, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 5, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 6, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 7, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 8, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602013163, 9, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 1, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 2, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 3, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 4, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 5, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 6, 167, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 7, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030110013164, 8, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 1, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 2, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 3, 132, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 4, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 5, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 6, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 7, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 8, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 9, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 10, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090928013165, 11, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 1, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 2, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 3, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 4, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 5, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 6, 189, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 7, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 8, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 9, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 10, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 11, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 12, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 13, 177, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 14, 108, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131024013166, 15, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 1, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 2, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 3, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 4, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 5, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 6, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 7, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 8, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 9, 13, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 10, 187, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 11, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 12, 93, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 13, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324013167, 14, 111, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 1, 61, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 2, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 3, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 4, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 5, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 6, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 7, 26, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 8, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 9, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 10, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 11, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410013168, 12, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 1, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 2, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 3, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 4, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 5, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 6, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 7, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 8, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 9, 134, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 10, 65, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080927013169, 11, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 1, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 2, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 3, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 4, 133, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 5, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 6, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 7, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050714013170, 8, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 1, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 2, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 3, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 4, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 5, 29, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 6, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 7, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 8, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 9, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 10, 32, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 11, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 12, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 13, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 14, 163, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 15, 173, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120206013171, 16, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 1, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 2, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 3, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 4, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 5, 25, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 6, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 7, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 8, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 9, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 10, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 11, 56, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 12, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 13, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 14, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125013172, 15, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 1, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 2, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 3, 23, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 4, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 5, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718013173, 6, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 1, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 2, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 3, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 4, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 5, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 6, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 7, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 8, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 9, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 10, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 11, 10, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 12, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 13, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026013174, 14, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 1, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 2, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 3, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 5, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030711013175, 6, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 1, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 2, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 3, 124, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 4, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 5, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 6, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 7, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 8, 191, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824013176, 9, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 1, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 2, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 3, 98, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 4, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 5, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010915013177, 6, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 1, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 2, 9, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 3, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 4, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 5, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 6, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 7, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 8, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 9, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 10, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 11, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 12, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 13, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 14, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121017013178, 15, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 1, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 2, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 3, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 4, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 5, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 6, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 7, 121, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 8, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013179, 9, 17, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 1, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 2, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 3, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 4, 55, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 5, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 6, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041125013180, 7, 164, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 1, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 2, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 3, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 4, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 5, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 6, 2, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 7, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 8, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 9, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071010013181, 10, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 1, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 2, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 3, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 4, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 5, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 6, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 7, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 8, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 9, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 10, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 11, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 12, 139, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 13, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 14, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100725013182, 15, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 1, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 2, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 3, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 4, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 5, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 13, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 14, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919013544, 15, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 1, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 2, 118, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 3, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 4, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 5, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 6, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 7, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 8, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 9, 138, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 10, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 11, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 12, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511013545, 13, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 1, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 2, 155, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 3, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 4, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 5, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 6, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 7, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 8, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 9, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318013546, 10, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 1, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 2, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 3, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 4, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 5, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 6, 105, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 7, 69, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 8, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 9, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 10, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 11, 192, 47, 18, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 12, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128013547, 13, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 1, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 2, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 3, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 4, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 5, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 6, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 7, 70, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050619013548, 8, 70, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 1, 102, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 2, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 3, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 4, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 5, 144, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 6, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 7, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 8, 118, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 9, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 10, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 11, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 12, 34, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 13, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 14, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208013549, 15, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 1, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 2, 94, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 3, 50, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 4, 97, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 5, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 6, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 7, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 8, 92, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 9, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 10, 106, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 11, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 12, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 13, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 14, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121119013550, 15, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 1, 45, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 2, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 3, 8, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 4, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 5, 107, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 6, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 7, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 8, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 9, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 10, 130, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 11, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 12, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 13, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 14, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713013551, 15, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 1, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 2, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 3, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 4, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 5, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 6, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 7, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 8, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 9, 127, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 10, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 11, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 12, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 13, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 14, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 15, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008013552, 16, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 1, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 2, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 3, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 4, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 5, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 6, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 7, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 8, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 9, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 10, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 11, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224013553, 12, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 1, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 2, 112, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 3, 187, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 4, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 5, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 6, 50, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 7, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 8, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 9, 20, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 10, 97, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 11, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 12, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 13, 65, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 14, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 15, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 16, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130721013554, 17, 62, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902013555, 1, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902013555, 2, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000902013555, 3, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 1, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 2, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 3, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 4, 143, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 5, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 6, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 7, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 8, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 9, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 10, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 11, 129, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 12, 184, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 13, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 14, 178, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 15, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213013556, 16, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 1, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 2, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 3, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 4, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 5, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 6, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030302013557, 7, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 1, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 2, 168, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 3, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 4, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 5, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 6, 162, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 7, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 8, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 9, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 10, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080520013558, 11, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 1, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 2, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 3, 157, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 4, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 5, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 6, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 7, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 8, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 9, 81, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 10, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 11, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402013559, 12, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 1, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 2, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 3, 61, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 4, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 5, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 6, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 7, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013560, 8, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 1, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 2, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 3, 61, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 4, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 5, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 6, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 7, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 8, 156, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 9, 78, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 10, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 11, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 12, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 13, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 14, 168, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907013561, 15, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 1, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 2, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 3, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 4, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 5, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 6, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 7, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 8, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 9, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 10, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070625013562, 11, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 1, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 2, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 3, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 4, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 5, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 6, 19, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720013563, 7, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 1, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 2, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 3, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 4, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 5, 29, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030514013564, 6, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 1, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 2, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 3, 57, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 4, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 5, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 6, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 7, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 10, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 11, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 12, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 13, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 14, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131231013945, 15, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 1, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 2, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 3, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 4, 96, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 5, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 6, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 7, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 8, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 9, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061023013946, 10, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 1, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 2, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 3, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 4, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 5, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 6, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 7, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 8, 43, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050728013947, 9, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 1, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 2, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 3, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 4, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 5, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 6, 157, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 7, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916013948, 8, 180, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 1, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 2, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 3, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 4, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 5, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 6, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 7, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 8, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 9, 39, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 10, 6, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 11, 155, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 12, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 13, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100803013949, 14, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204013950, 1, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204013950, 2, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010204013950, 3, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218013951, 1, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218013951, 2, 19, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 1, 126, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 2, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 3, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 4, 66, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 5, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 6, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 7, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 8, 56, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 9, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 10, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 11, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 12, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 13, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 14, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430013952, 15, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 1, 28, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 2, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 3, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 4, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 5, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 6, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 7, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 8, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 9, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 10, 110, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 11, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 12, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 13, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 14, 59, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 15, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128013953, 16, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120013954, 1, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120013954, 2, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120013954, 3, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120013954, 4, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815013955, 1, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815013955, 2, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815013955, 3, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815013955, 4, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020815013955, 5, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 1, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 2, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 3, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 4, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 5, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 6, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 7, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 8, 3, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 9, 166, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 10, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 11, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 12, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 13, 118, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 14, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 15, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 16, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322013956, 17, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 1, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 2, 121, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 3, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 4, 173, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 5, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 6, 131, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 7, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 8, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 9, 162, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 10, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 11, 16, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 12, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 13, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 14, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 15, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 16, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 17, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129013957, 18, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 1, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 2, 152, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 3, 21, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 4, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 5, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 6, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013958, 7, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 1, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 2, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 3, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 4, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 5, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 6, 176, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020416013959, 7, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 1, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 2, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 3, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 4, 90, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 5, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 6, 15, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 7, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 8, 64, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 9, 99, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 10, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 11, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 12, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 13, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308013960, 14, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 1, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 2, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 3, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 4, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 5, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020325013961, 6, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 1, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 2, 142, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 3, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 4, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 5, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 6, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 7, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 8, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 9, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 10, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 11, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 12, 38, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 13, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 14, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010013962, 15, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013963, 1, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013963, 2, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110013963, 3, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 1, 167, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 2, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 3, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 4, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 5, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 6, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 7, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 8, 116, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 9, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060210013964, 10, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218013965, 1, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218013965, 2, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218013965, 3, 184, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218013965, 4, 7, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218013965, 5, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 1, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 2, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 3, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 4, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 5, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 6, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 7, 11, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 8, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202013966, 9, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016013967, 1, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016013967, 2, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016013967, 3, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016013967, 4, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021016013967, 5, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 1, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 2, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 3, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 4, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 5, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 6, 51, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 7, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 8, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 9, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 10, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 11, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 12, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 13, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924013968, 14, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 1, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 2, 105, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 3, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 4, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 5, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 6, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 7, 85, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 8, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 9, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 10, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 11, 6, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216013969, 12, 24, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 1, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 2, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 3, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 4, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 13, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 14, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101112014313, 15, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 1, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 2, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 3, 25, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 4, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 5, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 6, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 7, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404014314, 8, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 1, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 2, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 3, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 4, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 5, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 6, 77, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 7, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 8, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 9, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 10, 77, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 11, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 12, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 13, 118, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 14, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 15, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 16, 54, 50, 11, 550);
commit;
prompt 146000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 17, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808014315, 18, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 1, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 2, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 3, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 4, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 5, 106, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 6, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 7, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 8, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 9, 109, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 10, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 11, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 12, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 13, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 14, 172, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 15, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014316, 16, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 1, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 2, 157, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 3, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 4, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 5, 33, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 6, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 7, 116, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 8, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 9, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 10, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 11, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 12, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 13, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 14, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 15, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 16, 29, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 17, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326014317, 18, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819014318, 1, 67, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819014318, 2, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819014318, 3, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819014318, 4, 51, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030819014318, 5, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 1, 145, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 2, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 3, 89, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 4, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 5, 162, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 6, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 7, 164, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 8, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 9, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 10, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 11, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 12, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 13, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 14, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 15, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 16, 188, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 17, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130202014319, 18, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 1, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 2, 146, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 3, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 4, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 5, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 6, 32, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 7, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 8, 70, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 9, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 10, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080801014320, 11, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 1, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 2, 133, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 3, 190, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 4, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 5, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 6, 1, 91, 3, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 7, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 8, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 9, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 10, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 11, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 12, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 13, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117014321, 14, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 1, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 2, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 3, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 4, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 5, 133, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 6, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 7, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110014322, 8, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 1, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 2, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 3, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 4, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 5, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 6, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 7, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 8, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 9, 1, 33, 3, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070429014323, 10, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 1, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 2, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 3, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 4, 92, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 5, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 6, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 7, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 8, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 9, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 10, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 11, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 12, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 13, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818014324, 14, 35, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 1, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 2, 181, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 3, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 4, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 5, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 6, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014325, 7, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716014326, 1, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716014326, 2, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716014326, 3, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716014326, 4, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000716014326, 5, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 1, 1, 64, 3, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 2, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 3, 21, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 4, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 5, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 6, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 7, 177, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 8, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 9, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 10, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 11, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 12, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 13, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 14, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 15, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130524014327, 16, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 1, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 2, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 3, 189, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 4, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 5, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 6, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 7, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 8, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 9, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070606014328, 10, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 1, 22, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 2, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 3, 167, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 4, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 5, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 6, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 7, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 8, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 9, 177, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 10, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081012014329, 11, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 1, 25, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 2, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 3, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 4, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 5, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 6, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 7, 165, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 8, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014330, 9, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 1, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 2, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 3, 160, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 4, 47, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 5, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 6, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 7, 64, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 8, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 9, 30, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 10, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415014331, 11, 68, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 1, 171, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 2, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 3, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 4, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 5, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 6, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 7, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 8, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 9, 128, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 10, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 11, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 12, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903014332, 13, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 1, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 2, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 3, 64, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 4, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 5, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 6, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 7, 19, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 8, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 9, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 10, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090316014333, 11, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 1, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 2, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 3, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 6, 111, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 7, 176, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 8, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 9, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 10, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 11, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 12, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080928013183, 13, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 1, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 2, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 3, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 4, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 5, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 6, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 7, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 8, 105, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 9, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 10, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 11, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214013184, 12, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 1, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 2, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 3, 145, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 4, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 5, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 6, 29, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 7, 192, 7, 18, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 8, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 9, 184, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 10, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 11, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 12, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 13, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 14, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 15, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130310013185, 16, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 1, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 2, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 3, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 4, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 5, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 6, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 7, 189, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 8, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 9, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313013186, 10, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 1, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 2, 119, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 3, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 4, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 5, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 6, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113013187, 7, 29, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 1, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 2, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 3, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 4, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 5, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 6, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604013188, 7, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 1, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 2, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 3, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 4, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 5, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 6, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 7, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 8, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 9, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 10, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516013189, 11, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 1, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 2, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 3, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 4, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 5, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 6, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 7, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 8, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 9, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 10, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 11, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 12, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 13, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 14, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130722013190, 15, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 1, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 2, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 3, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 4, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 5, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 6, 151, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040913013191, 7, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 1, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 2, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 3, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 4, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 5, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 6, 184, 1, 17, 17);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 7, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 8, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 9, 112, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 10, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 11, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 12, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 13, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 14, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 15, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 16, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217013192, 17, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016013193, 1, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016013193, 2, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016013193, 3, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011016013193, 4, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 1, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 2, 181, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 3, 82, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 4, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 5, 60, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 6, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 7, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 8, 190, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050413013194, 9, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 1, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 2, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 3, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 4, 31, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 5, 40, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 6, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 7, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 8, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 9, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 10, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081211013195, 11, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 1, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 2, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 3, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 4, 174, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 5, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 6, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 7, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 8, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 9, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 10, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216013196, 11, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 1, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 2, 29, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 3, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 4, 154, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 5, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 6, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 7, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 8, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027013197, 9, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 1, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 2, 22, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 3, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 4, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 5, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 6, 192, 71, 18, 1278);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 7, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 8, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515013198, 9, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 1, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 2, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 3, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 4, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 5, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 6, 148, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 7, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 8, 128, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 9, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 10, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013199, 11, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 1, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 2, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 3, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 4, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 5, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 6, 142, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 7, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 8, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 9, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 10, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 11, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 12, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 13, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 14, 41, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 15, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802013200, 16, 70, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 1, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 2, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 3, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 4, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 5, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 6, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 7, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 8, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 9, 152, 100, 16, 1600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 10, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 11, 162, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 12, 37, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 13, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 14, 189, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110815013201, 15, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 1, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 2, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 3, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 4, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 5, 37, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 6, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 7, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 8, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 9, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 10, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823013202, 11, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 1, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 2, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 3, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 4, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 5, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 6, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 7, 88, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 8, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 9, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013203, 10, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004013204, 1, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004013204, 2, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004013204, 3, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004013204, 4, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004013204, 5, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 1, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 2, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 3, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 4, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 5, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 6, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 7, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016013205, 8, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 1, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 8, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 9, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080630013565, 10, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 1, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 2, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 3, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 4, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 5, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 6, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 7, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 8, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 9, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116013566, 10, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 1, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 2, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 3, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 4, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 5, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 6, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 7, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 8, 18, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 9, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 10, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 11, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 12, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 13, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304013567, 14, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 1, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 2, 96, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 3, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 4, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 5, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 6, 85, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 7, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060906013568, 8, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 1, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 2, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 3, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 4, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 5, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 6, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 7, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 8, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 9, 42, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060321013569, 10, 99, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706013570, 1, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706013570, 2, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706013570, 3, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706013570, 4, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010706013570, 5, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 1, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 2, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 3, 46, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 4, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 5, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 6, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 7, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 8, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 9, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 10, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 11, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 12, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110413013571, 13, 100, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 1, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 2, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 3, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 4, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 5, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 6, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 7, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 8, 185, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322013572, 9, 163, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 1, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 2, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 3, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 4, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 5, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 6, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 7, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 8, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 9, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 10, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 11, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 12, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 13, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 14, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 15, 50, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 16, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013573, 17, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 1, 190, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 2, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 3, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 4, 32, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 5, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121013574, 6, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 1, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 2, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 3, 69, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 4, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 5, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 6, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 7, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 8, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 9, 117, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 10, 91, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 11, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 12, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 13, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100221013575, 14, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 1, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 2, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 3, 110, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 4, 65, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 5, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 6, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 7, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 8, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 9, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 10, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090307013576, 11, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 1, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 2, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 3, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 4, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 5, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 6, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 7, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 8, 67, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 9, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 10, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 11, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 12, 33, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 13, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 14, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120608013577, 15, 96, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 1, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 2, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 3, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 4, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 5, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 6, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 7, 186, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 8, 161, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 9, 142, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 10, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090929013578, 11, 82, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 1, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 2, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 3, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 4, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 5, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 6, 71, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 7, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 8, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 9, 101, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 10, 134, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 11, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 12, 170, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712013579, 13, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 1, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 2, 126, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 3, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 4, 188, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 5, 4, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 6, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 7, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 8, 130, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 9, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 10, 14, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 11, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525013580, 12, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 1, 151, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 2, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 3, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 4, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 5, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 6, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 7, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 8, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 9, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 10, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 11, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 12, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 13, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 14, 162, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130807013581, 15, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 1, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 2, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 3, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 4, 19, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 5, 58, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 6, 169, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 7, 73, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 8, 46, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 9, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 10, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 11, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 12, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 13, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311013582, 14, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 1, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 2, 50, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 3, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 4, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 5, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 6, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 7, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 8, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 9, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 10, 62, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 11, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 12, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 13, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 14, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 15, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520013583, 16, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015013584, 1, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015013584, 2, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015013584, 3, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015013584, 4, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015013584, 5, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 1, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 2, 8, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 3, 58, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 4, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 5, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040521013585, 6, 5, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 1, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 2, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 3, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 4, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 5, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 6, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 7, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 8, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 9, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 10, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 11, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 5, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 6, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 7, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 8, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 9, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 10, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 11, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 12, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 13, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 14, 50, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 15, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304013970, 16, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 1, 192, 12, 18, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 2, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 3, 154, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 4, 180, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 5, 171, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119013971, 6, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 1, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 2, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 3, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 4, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 5, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 6, 137, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 7, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 8, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 9, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070123013972, 10, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719013973, 1, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719013973, 2, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719013973, 3, 10, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010719013973, 4, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 1, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 2, 157, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 3, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 4, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 5, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 6, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031025013974, 7, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 1, 60, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 2, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 3, 5, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 4, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 5, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 6, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 7, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 8, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 9, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 10, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 11, 4, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 12, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 13, 8, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 14, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120925013975, 15, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720013976, 1, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720013976, 2, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 1, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 2, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 3, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 4, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 5, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 6, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 7, 112, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 8, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 9, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 10, 46, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 11, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 12, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 13, 129, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111229013977, 14, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 1, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 2, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 3, 116, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 4, 142, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 5, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 6, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 7, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 8, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 9, 155, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 10, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 11, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 12, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 13, 156, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100125013978, 14, 6, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 1, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 2, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 3, 169, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 4, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 5, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 6, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 7, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 8, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 9, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 10, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 11, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 12, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 13, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229013979, 14, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 1, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 2, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 3, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 4, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 5, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 6, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040327013980, 7, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 1, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 2, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 3, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 4, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 5, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 6, 103, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113013981, 7, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 1, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 2, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 3, 11, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 4, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 5, 68, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 6, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 7, 175, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060924013982, 8, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226013983, 1, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226013983, 2, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226013983, 3, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226013983, 4, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 1, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 2, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 3, 131, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 4, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 5, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 6, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 7, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 8, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 9, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 10, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 11, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 12, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 13, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 14, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110731013984, 15, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 1, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 2, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 3, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 4, 52, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 5, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 6, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 7, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050329013985, 8, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 1, 69, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 2, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 3, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 4, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 5, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040519013986, 6, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 1, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 2, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 3, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 4, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 5, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 6, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 7, 122, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 8, 167, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 9, 27, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 10, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530013987, 11, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802013988, 1, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802013988, 2, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802013988, 3, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000802013988, 4, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 1, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 2, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 3, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 4, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 5, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 6, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 7, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 8, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 9, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 10, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 11, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 12, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 13, 136, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 14, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110013989, 15, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 1, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 2, 108, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 3, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 4, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 5, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 6, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 7, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 8, 90, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 9, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 10, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 11, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 12, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 13, 31, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729013990, 14, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 1, 131, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 2, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 3, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 4, 2, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 5, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 6, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 7, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 8, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 9, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 10, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 11, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100127013991, 12, 35, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 1, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 2, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 3, 82, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 4, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 5, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 6, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 7, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 8, 80, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 9, 160, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 10, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 11, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524013992, 12, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 1, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 2, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 3, 3, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 4, 138, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 5, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 6, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 7, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 8, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 9, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 10, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 11, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 12, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 13, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218013993, 14, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113013994, 1, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113013994, 2, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113013994, 3, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113013994, 4, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 4, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 5, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030928014334, 6, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 1, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 2, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 3, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 4, 118, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 5, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 6, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 7, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 8, 181, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 9, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 10, 64, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415014335, 11, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809014336, 1, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809014336, 2, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809014336, 3, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809014336, 4, 179, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030809014336, 5, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 1, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 2, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 3, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 4, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 5, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 6, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 7, 157, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 8, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 9, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 10, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 11, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 12, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 13, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111002014337, 14, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 1, 78, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 2, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 3, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 4, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 5, 151, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 6, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 7, 188, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 8, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 9, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 10, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 11, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 12, 184, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 13, 40, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 14, 33, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 15, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 16, 145, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130923014338, 17, 186, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 1, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 2, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 3, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 4, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 5, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 6, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 7, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 8, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 9, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070702014339, 10, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 1, 145, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 2, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 3, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 4, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 5, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 6, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 7, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 8, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 9, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 10, 29, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 11, 138, 51, 9, 459);
commit;
prompt 147000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 12, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 13, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 14, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 15, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 16, 128, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621014340, 17, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 1, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 2, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 3, 192, 68, 18, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 4, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 5, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 6, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 7, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410014341, 8, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024014342, 1, 128, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024014342, 2, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001024014342, 3, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 1, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 2, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 3, 29, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 4, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 5, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 6, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 7, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 8, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 9, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 10, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 11, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 12, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 13, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 14, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 15, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 16, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402014343, 17, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014344, 1, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014344, 2, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014344, 3, 176, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014344, 4, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014344, 5, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 1, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 2, 175, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 3, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 4, 72, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 5, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020718014345, 6, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 1, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 2, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 3, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 4, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 5, 79, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 6, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 7, 123, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 8, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 9, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 10, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 11, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 12, 119, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090617014346, 13, 28, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 1, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 2, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 3, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 4, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 5, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 6, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 7, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 8, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 9, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 10, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 11, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 12, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 13, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 14, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014347, 15, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 1, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 2, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 3, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 4, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 5, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 6, 8, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 7, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 8, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 9, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 10, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 11, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 12, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014348, 13, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 1, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 2, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 3, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 4, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 5, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 6, 76, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 7, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050110014349, 8, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 1, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 2, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 3, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 4, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 5, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 6, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030918014350, 7, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 1, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 2, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 3, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 4, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 5, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 6, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 7, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 8, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 9, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 10, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 11, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 12, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 13, 23, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120402014351, 14, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 1, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 2, 151, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 3, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 4, 97, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 5, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014352, 6, 129, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 1, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 2, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 3, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 4, 178, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 5, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 6, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 7, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 8, 6, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 9, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 10, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 11, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 12, 117, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801014353, 13, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 1, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 2, 44, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 3, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 4, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 5, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 6, 188, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 7, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 8, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 9, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 10, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 11, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 12, 179, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014354, 13, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 1, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 2, 145, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 3, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 4, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 5, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 6, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 7, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 8, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 9, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 10, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 11, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 12, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 13, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 14, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 15, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014355, 16, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 1, 37, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 2, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 3, 121, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 4, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 5, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 2, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 3, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 4, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 5, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 6, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 7, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230013206, 8, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 1, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 2, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 3, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 4, 30, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 5, 48, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 6, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 7, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 8, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 9, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 10, 90, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 11, 165, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 12, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 13, 160, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 14, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805013207, 15, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 1, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 2, 71, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 3, 57, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 4, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 5, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 6, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 7, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 8, 128, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 9, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 10, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 11, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 12, 164, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 13, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 14, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100728013208, 15, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 1, 138, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 2, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 3, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 4, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 5, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 6, 104, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 7, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130013209, 8, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 1, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 2, 113, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 3, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 4, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 5, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 6, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 7, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 8, 76, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 9, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080715013210, 10, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013211, 1, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013211, 2, 142, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013211, 3, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021228013211, 4, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 1, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 2, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 3, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 4, 90, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 5, 21, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 6, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 7, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 8, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 9, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 10, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 11, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 12, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110710013212, 13, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 1, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 2, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 3, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 4, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 5, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 6, 28, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 7, 171, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 8, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 9, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 10, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706013213, 11, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 1, 137, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 2, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 3, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 4, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 5, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 6, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041022013214, 7, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 1, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 2, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 3, 161, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 4, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 5, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 6, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908013215, 7, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506013216, 1, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506013216, 2, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506013216, 3, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506013216, 4, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013217, 1, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013217, 2, 142, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013217, 3, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001004013217, 4, 14, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 1, 27, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 2, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 3, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 4, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 5, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 6, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008013218, 7, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 1, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 2, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 3, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 4, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 5, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030206013219, 6, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 1, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 2, 47, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 3, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 4, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 5, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 6, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 7, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 8, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 9, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 10, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 11, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 12, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 13, 38, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 14, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 15, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503013220, 16, 25, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 1, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 2, 79, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 3, 60, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 4, 173, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 5, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 6, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 7, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 8, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 9, 114, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 10, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 11, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 12, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 13, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 14, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131118013221, 15, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 1, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 2, 39, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 3, 1, 59, 3, 177);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 4, 1, 88, 3, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 5, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 6, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 7, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 8, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114013222, 9, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 1, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 2, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 3, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 4, 57, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 5, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 6, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 7, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 8, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 9, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 10, 96, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 11, 115, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 12, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 13, 132, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110013223, 14, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 1, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 2, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 3, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 4, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 5, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 6, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 7, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050210013224, 8, 91, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 1, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 2, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 3, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 4, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 5, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 6, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 7, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 8, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 9, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 10, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 11, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090728013225, 12, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 1, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 2, 100, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 3, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 4, 182, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 5, 21, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 6, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330013226, 7, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 1, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 2, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 3, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 4, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 5, 158, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 6, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 7, 59, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030630013227, 8, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 1, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 2, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 3, 168, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 4, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 5, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 6, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 7, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 8, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 9, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 10, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 11, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721013228, 12, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 1, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 2, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 3, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 4, 17, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 5, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 6, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 7, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 8, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 9, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060914013229, 10, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 1, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 2, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 3, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 4, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 5, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 6, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020125013230, 7, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 1, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 2, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 3, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 12, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 13, 22, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 14, 63, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 15, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120529013586, 16, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 1, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 2, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 3, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 4, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 5, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011018013587, 6, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 1, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 2, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 3, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 4, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 5, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 6, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 7, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 8, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 9, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 10, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 11, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 12, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 13, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100211013588, 14, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 1, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 2, 181, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 3, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 4, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 5, 93, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 6, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 7, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 8, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 9, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 10, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 11, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 12, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 13, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 14, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 15, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 16, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121029013589, 17, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 1, 158, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 2, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 3, 77, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 4, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 5, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 6, 77, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 7, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313013590, 8, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 1, 183, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 2, 74, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 3, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 4, 54, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 5, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 6, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 7, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 8, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 9, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 10, 68, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 11, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 12, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100603013591, 13, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605013592, 1, 26, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605013592, 2, 54, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000605013592, 3, 121, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 1, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 2, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 3, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 4, 132, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 5, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011102013593, 6, 3, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 1, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 2, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 3, 179, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 4, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 5, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 6, 134, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 7, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 8, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050508013594, 9, 80, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 1, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 2, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 3, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 4, 132, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 5, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 6, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 7, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 8, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 9, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 10, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 11, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 12, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 13, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 14, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 15, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122013595, 16, 109, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319013596, 1, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319013596, 2, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319013596, 3, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806013597, 1, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806013597, 2, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806013597, 3, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806013597, 4, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010806013597, 5, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 1, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 2, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 3, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 4, 112, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 5, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 6, 83, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 7, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 8, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050701013598, 9, 150, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 1, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 2, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 3, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 4, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 5, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 6, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 7, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 8, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 9, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061205013599, 10, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527013600, 1, 181, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527013600, 2, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527013600, 3, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527013600, 4, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010527013600, 5, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 1, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 2, 117, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 3, 181, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 4, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 5, 166, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 6, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 7, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 8, 62, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 9, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 10, 173, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 11, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 12, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100210013601, 13, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 1, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 2, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 3, 8, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 4, 61, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 5, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 6, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 7, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 8, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 9, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 10, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 11, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 12, 69, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 13, 87, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 14, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814013602, 15, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524013603, 1, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524013603, 2, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524013603, 3, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524013603, 4, 132, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524013603, 5, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 1, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 2, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 3, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 4, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 5, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 6, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 7, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 8, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 9, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 10, 105, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 11, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090907013604, 12, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215013605, 1, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215013605, 2, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215013605, 3, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215013605, 4, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215013605, 5, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 1, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 2, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 3, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 4, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 5, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 6, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 7, 151, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320013606, 8, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228013607, 1, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228013607, 2, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228013607, 3, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228013607, 4, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 1, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 2, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 3, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 4, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 5, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 6, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 7, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 8, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 9, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 10, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218013608, 11, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 1, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 2, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 3, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 4, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 5, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 6, 23, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 7, 134, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 8, 170, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 9, 58, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 10, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 11, 29, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 12, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100729013609, 13, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 1, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 2, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 3, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 4, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 5, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 6, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 7, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 8, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605013610, 9, 80, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 1, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 2, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 3, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 4, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 5, 40, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 6, 171, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 7, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 8, 60, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 9, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 10, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 11, 53, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 12, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 13, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 14, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 15, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613013995, 1, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613013995, 2, 126, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613013995, 3, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000613013995, 4, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 1, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 2, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 3, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 4, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 5, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 6, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 7, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 8, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 9, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 10, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902013996, 11, 143, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 1, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 2, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 3, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 4, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 5, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 6, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 7, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 8, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 9, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 10, 186, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 11, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070611013997, 12, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 1, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 2, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 3, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 4, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 5, 64, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 6, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 7, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041229013998, 8, 24, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325013999, 1, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325013999, 2, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325013999, 3, 23, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325013999, 4, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010325013999, 5, 11, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 1, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 2, 53, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 3, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 4, 94, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 5, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 6, 13, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021002014000, 7, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 1, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 2, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 3, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 4, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 5, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 6, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 7, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 8, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 9, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 10, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081031014001, 11, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 1, 186, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 2, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 3, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 4, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 5, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 6, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 7, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 8, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 9, 148, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 10, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 11, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 12, 55, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 13, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 14, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 15, 175, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 16, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140109014002, 17, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 1, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 2, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 3, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 4, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 5, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 6, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 7, 42, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125014003, 8, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 1, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 2, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 3, 148, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 4, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 5, 191, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 6, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 7, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 8, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 9, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 10, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080611014004, 11, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 1, 98, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 2, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 3, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 4, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 5, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 6, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 7, 55, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 8, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 9, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 10, 49, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 11, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 12, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 13, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 14, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 15, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 16, 33, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130728014005, 17, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 1, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 2, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 3, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 4, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 5, 12, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 6, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 7, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 8, 63, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 9, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 10, 48, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 11, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 12, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 13, 190, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 14, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 15, 8, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 16, 5, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130227014006, 17, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 1, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 2, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 3, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 4, 34, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 5, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 6, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 7, 12, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 8, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 9, 16, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 10, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 11, 191, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 12, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 13, 52, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 14, 27, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 15, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 16, 137, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 17, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221014007, 18, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 1, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 2, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 3, 175, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 4, 45, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 5, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 6, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 7, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 8, 107, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 9, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 10, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071008014008, 11, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 1, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 2, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 3, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 4, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 5, 127, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 6, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 7, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 8, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 9, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 10, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 11, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 12, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 13, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 14, 30, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101228014009, 15, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922014010, 1, 127, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922014010, 2, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922014010, 3, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922014010, 4, 161, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030922014010, 5, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129014011, 1, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129014011, 2, 65, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129014011, 3, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 1, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 2, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 3, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 4, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 5, 153, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 6, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 7, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 8, 110, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 9, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 10, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 11, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 12, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 13, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 14, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 15, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130113014012, 16, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427014013, 1, 1, 84, 3, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427014013, 2, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427014013, 3, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427014013, 4, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 1, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 2, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 3, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 4, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 5, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 6, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 7, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505014014, 8, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 1, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 2, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 3, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 4, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 5, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 6, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 7, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 8, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 9, 78, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 10, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 11, 141, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 12, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 13, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 14, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 15, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 16, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 17, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802014015, 18, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 1, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 2, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 3, 42, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 4, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 5, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 6, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 7, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 8, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 9, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 10, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 11, 180, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 12, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014016, 13, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 6, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 7, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 8, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 9, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 10, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 11, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 12, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 13, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019014356, 14, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 1, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 2, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 3, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 4, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 5, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316014357, 6, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 1, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 2, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 3, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 4, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 5, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 6, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 7, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 8, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610014358, 9, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910014359, 1, 70, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910014359, 2, 74, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910014359, 3, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910014359, 4, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020910014359, 5, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 1, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 2, 4, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 3, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 4, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 5, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231014360, 6, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305014361, 1, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305014361, 2, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305014361, 3, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305014361, 4, 100, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010305014361, 5, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 1, 87, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 2, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 3, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 4, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 5, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 6, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020803014362, 7, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106014363, 1, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106014363, 2, 18, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106014363, 3, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106014363, 4, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021106014363, 5, 140, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 1, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 2, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 3, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 4, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 5, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 6, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 7, 79, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031208014364, 8, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 1, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 2, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 3, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 4, 177, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 5, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 6, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 7, 147, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 8, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 9, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 10, 141, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 11, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 12, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 13, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 14, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727014365, 15, 191, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 1, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 2, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 3, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 4, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 5, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 6, 126, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 7, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 8, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 9, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 10, 11, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 11, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 12, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 13, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 14, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 15, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 16, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120717014366, 17, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 1, 130, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 2, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 3, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 4, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 5, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 6, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 7, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 8, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060220014367, 9, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 1, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 2, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 3, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 4, 40, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 5, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 6, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 7, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 8, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 9, 68, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 10, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 11, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 12, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 13, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 14, 172, 84, 12, 1008);
commit;
prompt 148000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 15, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120310014368, 16, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 1, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 2, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 3, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 4, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 5, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 6, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 7, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 8, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050713014369, 9, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 1, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 2, 139, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 3, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 4, 95, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 5, 18, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 6, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 7, 134, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 8, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 9, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 10, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 11, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 12, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 13, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 14, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 15, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120926014370, 16, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 1, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 2, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 3, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 4, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 5, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 6, 160, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 7, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050507014371, 8, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 1, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 2, 67, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 3, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 4, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 5, 42, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 6, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 7, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 8, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 9, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 10, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 11, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 12, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 13, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213014372, 14, 119, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 1, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 2, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 3, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 4, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 5, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 6, 9, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 7, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 8, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 9, 104, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 10, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 11, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100505014373, 12, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 1, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 2, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 3, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 4, 50, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 5, 98, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 6, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 7, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 8, 139, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 9, 164, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 10, 74, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 11, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 12, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 13, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 14, 50, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 15, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 16, 161, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 17, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028014374, 18, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 1, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 2, 71, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 3, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 4, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 5, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 6, 40, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 7, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040328014375, 8, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 1, 19, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 2, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 3, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 4, 85, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 5, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 6, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 7, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 8, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 9, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 10, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701014376, 11, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 1, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 2, 19, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 3, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 4, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 5, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 6, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 7, 15, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 8, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 9, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 10, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 11, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 12, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 13, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 14, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 15, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 16, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 17, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014377, 18, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210014378, 1, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210014378, 2, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210014378, 3, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210014378, 4, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210014378, 5, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 1, 23, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 2, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020612014379, 3, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 4, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 5, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 6, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021217013231, 7, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 1, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 2, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 3, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 4, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 5, 95, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 6, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 7, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030126013232, 8, 87, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 1, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 2, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 3, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 4, 50, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 5, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 6, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 7, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 8, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 9, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 10, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 11, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 12, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 13, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008013233, 14, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 1, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 2, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 3, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 4, 156, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 5, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 6, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 7, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 8, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 9, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 10, 52, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 11, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 12, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 13, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108013234, 14, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 1, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 2, 99, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 3, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 4, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 5, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 6, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 7, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 8, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 9, 104, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060702013235, 10, 113, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 1, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 2, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 3, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 4, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 5, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 6, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 7, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 8, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 9, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 10, 81, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 11, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 12, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 13, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111206013236, 14, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 1, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 2, 67, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 3, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 4, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 5, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 6, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021211013237, 7, 86, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 1, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 2, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 3, 147, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 4, 111, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 5, 1, 42, 3, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 6, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 7, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060505013238, 8, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903013239, 1, 9, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903013239, 2, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903013239, 3, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228013240, 1, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228013240, 2, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228013240, 3, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228013240, 4, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228013240, 5, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 1, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 2, 120, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 3, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 4, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 5, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 6, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 7, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 8, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 9, 26, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 10, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081015013241, 11, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 1, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 2, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 3, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 4, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 5, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 6, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 7, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 8, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 9, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 10, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 11, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 12, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 13, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 14, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 15, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 16, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 17, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412013242, 18, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 1, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 2, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 3, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 4, 82, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 5, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 6, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 7, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 8, 99, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 9, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 10, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 11, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013243, 12, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 1, 79, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 2, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 3, 71, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 4, 184, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 5, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 6, 53, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 7, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 8, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 9, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060928013244, 10, 58, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 1, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 2, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 3, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 4, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 5, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 6, 68, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030716013245, 7, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 1, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 2, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 3, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 4, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 5, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 6, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 7, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 8, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 9, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 10, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 11, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 12, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 13, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 14, 142, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 15, 76, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222013246, 16, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 1, 175, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 2, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 3, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 4, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 5, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 6, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 7, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 8, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 9, 12, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 10, 114, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 11, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 12, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 13, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 14, 7, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530013247, 15, 177, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 1, 35, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 2, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 3, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 4, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 5, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 6, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 7, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 8, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813013248, 9, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 1, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 2, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 3, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 4, 85, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 5, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 6, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 7, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 8, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051005013249, 9, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 1, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 2, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 3, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 4, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 5, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 6, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 7, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 8, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 9, 78, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 10, 174, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210013250, 11, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 1, 35, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 2, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 3, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 4, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 5, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 6, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 7, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 8, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 9, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 10, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 11, 15, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217013251, 12, 183, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104013252, 1, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104013252, 2, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104013252, 3, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104013252, 4, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104013252, 5, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 1, 192, 70, 18, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 2, 91, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 3, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 4, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 5, 164, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 6, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040722013253, 7, 92, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 1, 186, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 2, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 3, 134, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 4, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 5, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 6, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 7, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 8, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 9, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080223013254, 10, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608013611, 16, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709013612, 1, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709013612, 2, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709013612, 3, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010709013612, 4, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 1, 27, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 2, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 3, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 4, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 5, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 6, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 7, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 8, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 9, 45, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 10, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 11, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071126013613, 12, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 1, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 2, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 3, 35, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 4, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 5, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 6, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 7, 165, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 8, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 9, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 10, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 11, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 12, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 13, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 14, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 15, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817013614, 16, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013615, 1, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013615, 2, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013615, 3, 107, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013615, 4, 70, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013615, 5, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 1, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 2, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 3, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 4, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 5, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 6, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 7, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 8, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 9, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050611013616, 10, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 1, 149, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 2, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 3, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 4, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 5, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 6, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041120013617, 7, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013618, 1, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013618, 2, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013618, 3, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013618, 4, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926013618, 5, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 1, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 2, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 3, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 4, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 5, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 6, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 7, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 8, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 9, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 10, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 11, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070616013619, 12, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 1, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 2, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 3, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 4, 68, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 5, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 6, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 7, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 8, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 9, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 10, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090714013620, 11, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 1, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 2, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 3, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 4, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 5, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 6, 19, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 7, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 8, 144, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 9, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231013621, 10, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 1, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 2, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 3, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 4, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 5, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 6, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 7, 32, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 8, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050219013622, 9, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 1, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 2, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 3, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 4, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 5, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 6, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 7, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 8, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 9, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 10, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061221013623, 11, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 1, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 2, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 3, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 4, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 5, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 6, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 7, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 8, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 9, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060225013624, 10, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426013625, 1, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426013625, 2, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426013625, 3, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426013625, 4, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 1, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 2, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 3, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 4, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 5, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 6, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 7, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 8, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 9, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070205013626, 10, 140, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 1, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 2, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 3, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 4, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 5, 108, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 6, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 7, 166, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 8, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 9, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 10, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090707013627, 11, 99, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731013628, 1, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731013628, 2, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731013628, 3, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731013628, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 1, 192, 57, 18, 1026);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 2, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 3, 106, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 4, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 5, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 6, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 7, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823013629, 8, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 1, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 2, 42, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 3, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 4, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 5, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417013630, 6, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 1, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 2, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 3, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 4, 104, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 5, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 6, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041220013631, 7, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013632, 1, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000530013632, 2, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 1, 85, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 2, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 3, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 4, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 5, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 6, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 7, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 8, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 9, 188, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 10, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 11, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 12, 12, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090925013633, 13, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 1, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 2, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 3, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 4, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 5, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 6, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 7, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 8, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 9, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 10, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604013634, 11, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 1, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 2, 169, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 3, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 4, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 5, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 6, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 7, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 8, 166, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 9, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 10, 28, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 11, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 12, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 13, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 14, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 15, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 16, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712013635, 17, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 1, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 2, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 3, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 4, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 5, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 6, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 7, 89, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 8, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 9, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 10, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 11, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 12, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 13, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 14, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 15, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 16, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 17, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140215013636, 18, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 1, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 2, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 3, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071001013637, 4, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 8, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 9, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 10, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 11, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 12, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 13, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 14, 79, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 15, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 16, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 1, 50, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 2, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 3, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 4, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 5, 6, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 6, 189, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030405015110, 7, 165, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 1, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 2, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 3, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 4, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 5, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 6, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906015111, 7, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 1, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 2, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 3, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 4, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 5, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 6, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 7, 94, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 8, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 9, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 10, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 11, 125, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 12, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 13, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 14, 173, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 15, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015112, 16, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 1, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 2, 184, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 3, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 4, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 5, 25, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 6, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 7, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 8, 12, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 9, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 10, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 11, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 12, 9, 23, 4, 92);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 13, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090812015113, 14, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629015114, 1, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629015114, 2, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629015114, 3, 145, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629015114, 4, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629015114, 5, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 1, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 2, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 3, 14, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 4, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 5, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 6, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 7, 75, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 8, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 9, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 10, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 11, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090211015115, 12, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 1, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 2, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 3, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 4, 34, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 5, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 6, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 7, 82, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 8, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 9, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 10, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 11, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 12, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 13, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 14, 139, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 15, 138, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 16, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 17, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808015116, 18, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901015117, 1, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901015117, 2, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901015117, 3, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 1, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 2, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 3, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 4, 70, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 5, 192, 21, 18, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 6, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308015118, 7, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208015119, 1, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208015119, 2, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208015119, 3, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208015119, 4, 33, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503015120, 1, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503015120, 2, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000503015120, 3, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 1, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 2, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 3, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 4, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 5, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 6, 13, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 7, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 8, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 9, 17, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 10, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 11, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 12, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 13, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717015121, 14, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 1, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 2, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 3, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 4, 158, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 5, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 6, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 7, 192, 20, 18, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 8, 180, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 9, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 10, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 11, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 12, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 13, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 14, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 15, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218015122, 16, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 1, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 2, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 3, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 4, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 5, 119, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 6, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 7, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 8, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 9, 12, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 10, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 11, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 12, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 13, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110429015123, 14, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 1, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 2, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 3, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 4, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 5, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 6, 79, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 7, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 8, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 9, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 10, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 11, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 12, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081231015124, 13, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 1, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 2, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 3, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 4, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 5, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 6, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 7, 54, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 8, 127, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 9, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120015125, 10, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 1, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 2, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 3, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 4, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 5, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 6, 174, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 7, 49, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 8, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 9, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 10, 22, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 11, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 12, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 13, 76, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 14, 1, 31, 3, 93);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 15, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 16, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140415015126, 17, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 1, 137, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 2, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 3, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 4, 150, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 5, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 6, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 7, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 8, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025015127, 9, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 1, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 2, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 3, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 4, 188, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 5, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 6, 77, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 7, 146, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 8, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 9, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 10, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061119015128, 11, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 1, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 2, 56, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 3, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 4, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 5, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 6, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 7, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 8, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 9, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 10, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 11, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 12, 103, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 13, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 14, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 15, 67, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110819015129, 16, 116, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130015130, 1, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130015130, 2, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130015130, 3, 173, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130015130, 4, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130015130, 5, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 1, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 2, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 3, 180, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 4, 151, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 5, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 6, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 7, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 8, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 9, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 7, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 8, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 9, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 10, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 11, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 12, 153, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 13, 47, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 14, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015501, 1, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015501, 2, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015501, 3, 191, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 1, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 2, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 3, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 4, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 5, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 6, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 7, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 8, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 9, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225015502, 10, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 1, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 2, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 3, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 4, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 5, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 6, 168, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 7, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 8, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 9, 86, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 10, 1, 41, 3, 123);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 11, 132, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 12, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 13, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 14, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 15, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120221015503, 16, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208015504, 1, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208015504, 2, 133, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208015504, 3, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021208015504, 4, 68, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 1, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 2, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 3, 91, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 4, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 5, 8, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 6, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 7, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 8, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015505, 9, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 1, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 2, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 3, 167, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 4, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 5, 144, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 6, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 7, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 8, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040323015506, 9, 37, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 1, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 2, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 3, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 4, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 5, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 6, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 7, 179, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 8, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 9, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 10, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 11, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 12, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 13, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 14, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726015507, 15, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 1, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 2, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 3, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 4, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 5, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 6, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 7, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 8, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060109015508, 9, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 1, 156, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 2, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 3, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 4, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 5, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 6, 3, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 7, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 8, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 9, 169, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 10, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926015509, 11, 95, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 1, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 2, 121, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 3, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 4, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 5, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 6, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 7, 158, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 8, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 9, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 10, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 11, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 12, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 13, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 14, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224015510, 15, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 1, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 2, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 3, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 4, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 5, 19, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 6, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 7, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 8, 155, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 9, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 10, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 11, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 12, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 13, 2, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 14, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100613015511, 15, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 1, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 2, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 3, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 4, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 5, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 6, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 7, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 8, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 9, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 10, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219015512, 11, 109, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 1, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 2, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 3, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 4, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 5, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 6, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 7, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 8, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 9, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015513, 10, 175, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 1, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 2, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 3, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 4, 76, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 5, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 6, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 7, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 8, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 9, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 10, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070708015514, 11, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 1, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 2, 84, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 3, 10, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 4, 155, 86, 12, 1032);
commit;
prompt 149000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 5, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 6, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 7, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 8, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 9, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 10, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 11, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202015515, 12, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 1, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 2, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 3, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 4, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 5, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 6, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050615015516, 7, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 1, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 2, 185, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 3, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 4, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 5, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 6, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 7, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 8, 146, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 9, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081112015517, 10, 49, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015518, 1, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015518, 2, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015518, 3, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015518, 4, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 1, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 2, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 3, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 4, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 5, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 6, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 7, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 8, 157, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 9, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 10, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 11, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 12, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 13, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110307015519, 14, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 1, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 2, 128, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 3, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 4, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 5, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 6, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 7, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060809015520, 8, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 1, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 2, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 3, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 4, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 5, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 6, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015521, 7, 62, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 1, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 2, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 3, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 4, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 5, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 6, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040713015522, 7, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221015523, 1, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221015523, 2, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001221015523, 3, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 1, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 2, 132, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 3, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 4, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 5, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 6, 164, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719015524, 7, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 1, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 2, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 3, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 4, 68, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 6, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 7, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 8, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 9, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 10, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 11, 181, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 1, 100, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 2, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 3, 6, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 4, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 5, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 6, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 7, 27, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 8, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211015876, 9, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 1, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 2, 28, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 3, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 4, 73, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 5, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 6, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 7, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 8, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 9, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 10, 50, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 11, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 12, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 13, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 14, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015877, 15, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 1, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 2, 191, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 3, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 4, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 5, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 6, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 7, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 8, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 9, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 10, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 11, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 12, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 13, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090315015878, 14, 96, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 1, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 2, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 3, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 4, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 5, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 6, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 7, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030128015879, 8, 97, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 1, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 2, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 3, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 4, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 5, 46, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 6, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 7, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 8, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 9, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070721015880, 10, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 1, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 2, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 3, 177, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 4, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 5, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010225015881, 6, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 1, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 2, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 3, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 4, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 5, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 6, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 7, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 8, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 9, 14, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 10, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015882, 11, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720015883, 1, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720015883, 2, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720015883, 3, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000720015883, 4, 132, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 1, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 2, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 3, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 4, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 5, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 6, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 7, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 8, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 9, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 10, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 11, 8, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090414015884, 12, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630015885, 1, 164, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630015885, 2, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630015885, 3, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630015885, 4, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020630015885, 5, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017015886, 1, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017015886, 2, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017015886, 3, 95, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017015886, 4, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001017015886, 5, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 1, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 2, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 3, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 4, 122, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 5, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 6, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 7, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 8, 95, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 9, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 10, 160, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 11, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 12, 157, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 13, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 14, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015887, 15, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 1, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 2, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 3, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 4, 184, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 5, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 6, 21, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 7, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 8, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 9, 192, 89, 18, 1602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 10, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 11, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 12, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 13, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 14, 91, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 15, 76, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201015888, 16, 163, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822015889, 1, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822015889, 2, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822015889, 3, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 1, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 2, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 3, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 4, 146, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 5, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 6, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 7, 191, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 8, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 9, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 10, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 11, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081208015890, 12, 177, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 1, 82, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 2, 44, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 3, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 4, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 5, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 6, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 7, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 8, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 9, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 10, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 11, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 12, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 13, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 14, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 15, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121030015891, 16, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 1, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 2, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 3, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 4, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 5, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 6, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 7, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015892, 8, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 1, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 2, 175, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 3, 148, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 4, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 5, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 6, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 7, 139, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 8, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 9, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 10, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206015893, 11, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 1, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 2, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 3, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 4, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 5, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 6, 115, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 7, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 8, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 9, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 10, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070510015894, 11, 7, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 1, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 2, 107, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 3, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 4, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 5, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 6, 22, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 7, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 8, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 9, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 10, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 11, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 12, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515015895, 13, 105, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212015896, 1, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212015896, 2, 136, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921015897, 1, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921015897, 2, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921015897, 3, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921015897, 4, 43, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030921015897, 5, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 1, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 2, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 3, 96, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 4, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 5, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011110015898, 6, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 1, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 2, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 3, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 4, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 5, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 6, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 7, 2, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 8, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 9, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 10, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 11, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 12, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100121015899, 13, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 1, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 2, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 3, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 11, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 12, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 13, 38, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 14, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 15, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 16, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 1, 111, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 2, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 3, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 4, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 5, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 6, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 7, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 8, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 9, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 10, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 11, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 12, 166, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 13, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014746, 14, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 1, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 2, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 3, 31, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 4, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 5, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 6, 32, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 7, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 8, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 9, 165, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226014747, 10, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 1, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 2, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 3, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 4, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 5, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 6, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 7, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 8, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 9, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 10, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 11, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830014748, 12, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 1, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 2, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 3, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 4, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 5, 129, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 6, 179, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 7, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 8, 156, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 9, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 10, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 11, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 12, 132, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 13, 148, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 14, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618014749, 15, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 1, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 2, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 3, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 4, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 5, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 6, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 7, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 8, 59, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315014750, 9, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 1, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 2, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 3, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 4, 93, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 5, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 6, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 7, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 8, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 9, 189, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 10, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 11, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 12, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 13, 88, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100428014751, 14, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 1, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 2, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 3, 68, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 4, 106, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 5, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 6, 150, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 7, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 8, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 9, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 10, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 11, 174, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 12, 133, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002014752, 13, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 1, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 2, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 3, 33, 17, 4, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 4, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 5, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 6, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 7, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030726014753, 8, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 1, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 2, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 3, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 4, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 5, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 6, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 7, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 8, 154, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410014754, 9, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 1, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 2, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 3, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 4, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 5, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 6, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 7, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 8, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 9, 19, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 10, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 11, 182, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 12, 28, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 13, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 14, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111212014755, 15, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 1, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 2, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 3, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 4, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 5, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 6, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 7, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 8, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 9, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 10, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 11, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100303014756, 12, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 1, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 2, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 3, 22, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 4, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 5, 107, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 6, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 7, 157, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 8, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 9, 136, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014757, 10, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 1, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 2, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 3, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 4, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 5, 173, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 6, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 7, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 8, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 9, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 10, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 11, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 12, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 13, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 14, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 15, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101014758, 16, 165, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 1, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 2, 54, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 3, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 4, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 5, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 6, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 7, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 8, 12, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 9, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 10, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 11, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 12, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 13, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 14, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 15, 65, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014759, 16, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 1, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 2, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 3, 108, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 4, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 5, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 6, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 7, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 8, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 9, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 10, 180, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513014760, 11, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308014761, 1, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308014761, 2, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308014761, 3, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308014761, 4, 28, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308014761, 5, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228014762, 1, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228014762, 2, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228014762, 3, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010228014762, 4, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 1, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 2, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 3, 144, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 4, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 5, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 6, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 7, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 8, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 9, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 10, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 11, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081104014763, 12, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 1, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 2, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 3, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 4, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 5, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 6, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 7, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 8, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 9, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 10, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 11, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 12, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 13, 74, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 14, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 15, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 16, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 17, 185, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 18, 163, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124014764, 19, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 1, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 2, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 3, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 4, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 5, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 6, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 7, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040401014765, 8, 33, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108014766, 1, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 10, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 11, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 12, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 13, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 14, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 15, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 16, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 17, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731015131, 18, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 1, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 2, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 3, 89, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 4, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 5, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 6, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 7, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040926015132, 8, 89, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 1, 23, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 2, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 3, 37, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 4, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 5, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 6, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 7, 99, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 8, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 9, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 10, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 11, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 12, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 13, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 14, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 15, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 16, 138, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121118015133, 17, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 1, 71, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 2, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 3, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 4, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 5, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 6, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 7, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 8, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 9, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 10, 187, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 11, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 12, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091014015134, 13, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 1, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 2, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 3, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 4, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 5, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 6, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040623015135, 7, 13, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 1, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 2, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 3, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 4, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 5, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 6, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 7, 157, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 8, 70, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 9, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 10, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 11, 155, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 12, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923015136, 13, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 1, 191, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 2, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 3, 191, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 4, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 5, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 6, 85, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050511015137, 7, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 1, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 2, 34, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 3, 107, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 4, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 5, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 6, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 7, 178, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 8, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918015138, 9, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821015139, 1, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821015139, 2, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821015139, 3, 30, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821015139, 4, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010821015139, 5, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 1, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 2, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 3, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 4, 21, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 5, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 6, 69, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 7, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 8, 179, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 9, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 10, 112, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 11, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015140, 12, 39, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 1, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 2, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 3, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 4, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 5, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 6, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 7, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 8, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 9, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 10, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 11, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 12, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 13, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015141, 14, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 1, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 2, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 3, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 4, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 5, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 6, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 7, 191, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 8, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901015142, 9, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 1, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 2, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 3, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 4, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 5, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 6, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 7, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 8, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 9, 186, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 10, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015143, 11, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 1, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 2, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 3, 62, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 4, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 5, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 6, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 7, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 8, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 9, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 10, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 11, 71, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 12, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 13, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100130015144, 14, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216015145, 1, 50, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216015145, 2, 145, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216015145, 3, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001216015145, 4, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 1, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 2, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 3, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 4, 64, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 5, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 6, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 7, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 8, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 9, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 10, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 11, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 12, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 13, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 14, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111210015146, 15, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 1, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 2, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 3, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 4, 20, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 5, 140, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 6, 27, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 7, 44, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 8, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 9, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 10, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080904015147, 11, 168, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531015148, 1, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531015148, 2, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531015148, 3, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531015148, 4, 99, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531015148, 5, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015149, 1, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015149, 2, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015149, 3, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015149, 4, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015149, 5, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412015150, 1, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412015150, 2, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412015150, 3, 108, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412015150, 4, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412015150, 5, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 1, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 2, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 3, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 4, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 5, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 6, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 7, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 8, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 9, 152, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 10, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 11, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 12, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 13, 70, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 14, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 15, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130412015151, 16, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 1, 26, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 2, 167, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 3, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 4, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 5, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 6, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 7, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 8, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 9, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 10, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080828015152, 11, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015153, 1, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015153, 2, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000418015153, 3, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 1, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 2, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 3, 97, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 4, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 5, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 6, 76, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 7, 62, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 8, 71, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 9, 80, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 10, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 11, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 12, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 13, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 14, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 15, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 16, 127, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 5, 2, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 6, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 7, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 8, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 9, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 10, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015525, 11, 65, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 1, 57, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 2, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 3, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 4, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 5, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 6, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 7, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 8, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 9, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050114015526, 10, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802015527, 1, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802015527, 2, 55, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802015527, 3, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802015527, 4, 86, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802015527, 5, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 1, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 2, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 3, 98, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 4, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 5, 97, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 6, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 7, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 8, 33, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 9, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060617015528, 10, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 1, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 2, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 3, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 4, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 5, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 6, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 7, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 8, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 9, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 10, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 11, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608015529, 12, 90, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 1, 71, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 2, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 3, 31, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 4, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 5, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 6, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 7, 87, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050630015530, 8, 114, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015531, 1, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015531, 2, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015531, 3, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015531, 4, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015531, 5, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 1, 111, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 2, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 3, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 4, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 5, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 6, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105015532, 7, 72, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 1, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 2, 17, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 3, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 4, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 5, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 6, 12, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 7, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061026015533, 8, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 1, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 2, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 3, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 4, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 5, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 6, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 7, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 8, 132, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 9, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 10, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 11, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 12, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 13, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090123015534, 14, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 1, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 2, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 3, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 4, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 5, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 6, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 7, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 8, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 9, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 10, 136, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 11, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 12, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 13, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090829015535, 14, 132, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 1, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 2, 145, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 3, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 4, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 5, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 6, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 7, 57, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 8, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 9, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 10, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080331015536, 11, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 1, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 2, 64, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 3, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 4, 99, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 5, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 6, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 7, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 8, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 9, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 10, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 11, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 12, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 13, 36, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 14, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 15, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 16, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 17, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140323015537, 18, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 1, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 2, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 3, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 4, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 5, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 6, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 7, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 8, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 9, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 10, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 11, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 12, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 13, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 14, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 15, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 16, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130715015538, 17, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 1, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 2, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 3, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 4, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 5, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 6, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 7, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050412015539, 8, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 1, 69, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 2, 153, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 3, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 4, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 5, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 6, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005015540, 7, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 1, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 2, 9, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 3, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 4, 91, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 5, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 6, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 7, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 8, 33, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 9, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 10, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 11, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 12, 25, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829015541, 13, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002015542, 1, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002015542, 2, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002015542, 3, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011002015542, 4, 159, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 1, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 2, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 3, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 4, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 5, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 6, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911015543, 7, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 1, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 2, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 3, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 4, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 5, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 6, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 7, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 8, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 9, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 10, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 11, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205015544, 12, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016015545, 1, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016015545, 2, 88, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016015545, 3, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016015545, 4, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016015545, 5, 97, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 1, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 2, 117, 71, 12, 852);
commit;
prompt 150000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 3, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 4, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 5, 28, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 6, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 7, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121015546, 8, 152, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 1, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 2, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 3, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 4, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 5, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 6, 5, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 7, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 8, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 9, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 10, 10, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 11, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 12, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 13, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091202015547, 14, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 1, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 2, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 3, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 4, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 5, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 6, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 7, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 8, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 9, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 10, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 11, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916015548, 12, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 1, 39, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 2, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 3, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 4, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 5, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 6, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 7, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 8, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 9, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 10, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 11, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090620015900, 12, 53, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 1, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 2, 169, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 3, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 5, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 6, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 7, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 8, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114015901, 9, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 1, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 2, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 3, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 4, 106, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 5, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 6, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 7, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 8, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 9, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 10, 5, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 11, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 12, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 13, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502015902, 14, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 1, 135, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 2, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 3, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 4, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 5, 62, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 6, 125, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 7, 55, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 8, 89, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 9, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 10, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015903, 11, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205015904, 1, 54, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205015904, 2, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205015904, 3, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205015904, 4, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011205015904, 5, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 1, 75, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 2, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 3, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 4, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 5, 33, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 6, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 7, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 8, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 9, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 10, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060603015905, 11, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 1, 30, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 2, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 3, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 4, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 5, 70, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 6, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 7, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 8, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 9, 70, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 10, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 11, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015906, 12, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 1, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 2, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 3, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 4, 123, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 5, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 6, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 7, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 8, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 9, 26, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 10, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 11, 173, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 12, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813015907, 13, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 1, 116, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 2, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 3, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 4, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 5, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 6, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 7, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 8, 142, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 9, 66, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 10, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070314015908, 11, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 1, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 2, 157, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 3, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 4, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 5, 3, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 6, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 7, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 8, 172, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 9, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 10, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061212015909, 11, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825015910, 1, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825015910, 2, 115, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825015910, 3, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825015910, 4, 69, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 1, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 2, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 3, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 4, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 5, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 6, 70, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 7, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 8, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 9, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050424015911, 10, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118015912, 1, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118015912, 2, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010118015912, 3, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 1, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 2, 42, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 3, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 4, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 5, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 6, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050711015913, 7, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 1, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 2, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 3, 178, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 4, 136, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 5, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 6, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 7, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 8, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 9, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 10, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 11, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 12, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090712015914, 13, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 1, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 2, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 3, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 4, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 5, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 6, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 7, 127, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 8, 23, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 9, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 10, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 11, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 12, 55, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 13, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 14, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110922015915, 15, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521015916, 1, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521015916, 2, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000521015916, 3, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 1, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 2, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 3, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 4, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 5, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 6, 166, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015917, 7, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118015918, 1, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118015918, 2, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118015918, 3, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818015919, 1, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818015919, 2, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818015919, 3, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504015920, 1, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504015920, 2, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504015920, 3, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015921, 1, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015921, 2, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015921, 3, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015921, 4, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015921, 5, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 1, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 2, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 3, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 4, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 5, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 6, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 7, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 8, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 9, 99, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 10, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080408015922, 11, 79, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 1, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 2, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 3, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 4, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 5, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 6, 41, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 7, 108, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 8, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 9, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 10, 2, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 11, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 12, 50, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 13, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 14, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 15, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 16, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130119015923, 17, 82, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 1, 23, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 2, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 3, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 4, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 5, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 6, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 7, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 8, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 9, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060423015924, 10, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 1, 70, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 2, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 3, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 4, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 5, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 6, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 7, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 8, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 9, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 10, 125, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 11, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 12, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 13, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 14, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110207015925, 15, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 1, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 2, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 3, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 4, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 5, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001108014766, 2, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 1, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 2, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 3, 188, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 4, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 5, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 6, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 7, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 8, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 9, 75, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 10, 80, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224014767, 11, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 1, 124, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 2, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 3, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 4, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 5, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 6, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 7, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 8, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040315014768, 9, 94, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 1, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 2, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 3, 182, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 4, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 5, 34, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 6, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 7, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 8, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 9, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071128014769, 10, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 1, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 2, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 3, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 4, 137, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 5, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 6, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 7, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 8, 27, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 9, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 10, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 11, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 12, 158, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719014770, 13, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 1, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 2, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 3, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 4, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 5, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 6, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318014771, 7, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 1, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 2, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 3, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 4, 134, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 5, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 6, 34, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 7, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 8, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 9, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 10, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 11, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 12, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090422014772, 13, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 1, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 2, 112, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 3, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 4, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 5, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 6, 188, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 7, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 8, 48, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060627014773, 9, 30, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 1, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 2, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 3, 116, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 4, 177, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 5, 122, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 6, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 7, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 8, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 9, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 10, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 11, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 12, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 13, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 14, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725014774, 15, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821014775, 1, 6, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821014775, 2, 57, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821014775, 3, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000821014775, 4, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 1, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 2, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 3, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 4, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 5, 79, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 6, 12, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 7, 120, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 8, 186, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 9, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912014776, 10, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 1, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 2, 135, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 3, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 4, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 5, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 6, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040803014777, 7, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 1, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 2, 51, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 3, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 4, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 5, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 6, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 7, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 8, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 9, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 10, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 11, 138, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 12, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 13, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 14, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 15, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616014778, 16, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 1, 142, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 2, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 3, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 4, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 5, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 6, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 7, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 8, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 9, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 10, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 11, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 12, 153, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 13, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110519014779, 14, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103014780, 1, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103014780, 2, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103014780, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103014780, 4, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 1, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 2, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 3, 62, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 4, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 5, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 6, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 7, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 8, 69, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 9, 116, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 10, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 11, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 12, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 13, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 14, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 15, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130922014781, 16, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 1, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 2, 45, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 3, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 4, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 5, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 6, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 7, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 8, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 9, 46, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 10, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070825014782, 11, 8, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 1, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 2, 184, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 3, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 4, 151, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 5, 165, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010014783, 6, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 1, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 2, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 3, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 4, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 5, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 6, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 7, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 8, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 9, 61, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 10, 99, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 11, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 12, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080916014784, 13, 99, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 1, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 2, 37, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 3, 130, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 4, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 5, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 6, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 7, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 8, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 9, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 10, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 11, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 12, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100608014785, 13, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 1, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 2, 53, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 3, 39, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 4, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 5, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 6, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 7, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 8, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 9, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 10, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 11, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 12, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 13, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100511014786, 14, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 1, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 2, 97, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 3, 139, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 4, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 5, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 6, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 7, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030304014787, 8, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206014788, 1, 144, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206014788, 2, 54, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206014788, 3, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011206014788, 4, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 1, 62, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 2, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 3, 69, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 4, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 5, 162, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129014789, 6, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 1, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 2, 192, 27, 18, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 3, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 4, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 5, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215015154, 17, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 1, 3, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 2, 164, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 3, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 4, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 5, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 6, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 7, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 8, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 9, 3, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 10, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 11, 65, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 12, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 13, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 14, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 15, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 16, 22, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410015155, 17, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 1, 123, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 2, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 3, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 4, 182, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 5, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 6, 176, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 7, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 8, 19, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 9, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 10, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 11, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 12, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 13, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 14, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100916015156, 15, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 1, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 2, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 3, 108, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 4, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 5, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 6, 39, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 7, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 8, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 9, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 10, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 11, 60, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018015157, 12, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 1, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 2, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 3, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 4, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 5, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 6, 82, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 7, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 8, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 9, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 10, 183, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080601015158, 11, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918015159, 1, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918015159, 2, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918015159, 3, 165, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020918015159, 4, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 1, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 2, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 3, 42, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 4, 184, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 5, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 6, 19, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 7, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 8, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 9, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 10, 7, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 11, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 12, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 13, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709015160, 14, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 1, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 2, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 3, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 4, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 5, 63, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 6, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 7, 50, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 8, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 9, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 10, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 11, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 12, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 13, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520015161, 14, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 1, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 2, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 3, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 4, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 5, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 6, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 7, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 8, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 9, 185, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 10, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 11, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 12, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 13, 34, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 14, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 15, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121022015162, 16, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 1, 3, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 2, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 3, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 4, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 5, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625015163, 6, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 1, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 2, 107, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 3, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 4, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 5, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 6, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 7, 110, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 8, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 9, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 10, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 11, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 12, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 13, 78, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 14, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 15, 90, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 16, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 17, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015164, 18, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 1, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 2, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 3, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 4, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 5, 55, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030520015165, 6, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 1, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 2, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 3, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 4, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 5, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 6, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 7, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 8, 60, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 9, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 10, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080404015166, 11, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 1, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 2, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 3, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 4, 58, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 5, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 6, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 7, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 8, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060424015167, 9, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 1, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 2, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 3, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 4, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 5, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 6, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 7, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 8, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061102015168, 9, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 1, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 2, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 3, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 4, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 5, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 6, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 7, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050504015169, 8, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515015170, 1, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515015170, 2, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010515015170, 3, 14, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 1, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 2, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 3, 123, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 4, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 5, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 6, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 7, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 8, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 9, 74, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 10, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 11, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 12, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 13, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 14, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 15, 78, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 16, 35, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130805015171, 17, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 1, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 2, 124, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 3, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 4, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 5, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 6, 127, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 7, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 8, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 9, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 10, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 11, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 12, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 13, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101124015172, 14, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 1, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 2, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 3, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 4, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 5, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 6, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 7, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 8, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 9, 37, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 10, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070105015173, 11, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 1, 111, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 2, 40, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 3, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 4, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 5, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 6, 121, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 7, 95, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 8, 100, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 9, 94, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 10, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 11, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 12, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 13, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 14, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 15, 26, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 16, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015174, 17, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 1, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 2, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 3, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 4, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 5, 84, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 6, 7, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 4, 164, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 5, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 6, 70, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 7, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 8, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 9, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 10, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 11, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 12, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 13, 173, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 14, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608015549, 15, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 1, 154, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 2, 76, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 3, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 4, 103, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 5, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 6, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 7, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 8, 100, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 9, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 10, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 11, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 12, 65, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 13, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 14, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110619015550, 15, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 1, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 2, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 3, 41, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 4, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 5, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 6, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 7, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212015551, 8, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 1, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 2, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 3, 7, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 4, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 5, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 6, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 7, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 8, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 9, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 10, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 11, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080628015552, 12, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 1, 35, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 2, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 3, 66, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 4, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 5, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 6, 38, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 7, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 8, 21, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 9, 111, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 10, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 11, 67, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 12, 191, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 13, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111126015553, 14, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 1, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 2, 186, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 3, 99, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 4, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 5, 68, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 6, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 7, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015554, 8, 185, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 1, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 2, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 3, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 4, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 5, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 6, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 7, 32, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 8, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 9, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 10, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 11, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 12, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 13, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 14, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713015555, 15, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 1, 9, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 2, 98, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 3, 14, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 4, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 5, 181, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 6, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 7, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 8, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829015556, 9, 113, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 1, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 2, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 3, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 4, 170, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 5, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 6, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 7, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 8, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050106015557, 9, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015558, 1, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015558, 2, 142, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015558, 3, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015558, 4, 41, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 1, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 2, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 3, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 4, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 5, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 6, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 7, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 8, 140, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 9, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 10, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 11, 64, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 12, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 13, 83, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 14, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 15, 6, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130924015559, 16, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 1, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 2, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 3, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 4, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 5, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 6, 141, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 7, 12, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 8, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 9, 160, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 10, 170, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 11, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 12, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 13, 9, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 14, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 15, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 16, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110015560, 17, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 1, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 2, 57, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 3, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 4, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 5, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 6, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 7, 42, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050404015561, 8, 7, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 1, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 2, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 3, 187, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 4, 20, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 5, 56, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 6, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 7, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 8, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 9, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 10, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 11, 146, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 12, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090430015562, 13, 5, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015563, 1, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015563, 2, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015563, 3, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015563, 4, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015563, 5, 165, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111015564, 1, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111015564, 2, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111015564, 3, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111015564, 4, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 1, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 2, 144, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 3, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 4, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 5, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 6, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 7, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 8, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 9, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 10, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 11, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 12, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 13, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110712015565, 14, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 1, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 2, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 3, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 4, 118, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 5, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 6, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 7, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 8, 27, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 9, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 10, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 11, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 12, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 13, 39, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110416015566, 14, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 1, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 2, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 3, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 4, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 5, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905015567, 6, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 1, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 2, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 3, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 4, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 5, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 6, 154, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 7, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 8, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015568, 9, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014015569, 1, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014015569, 2, 53, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001014015569, 3, 140, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 1, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 2, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 3, 177, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 4, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 5, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 6, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 7, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 8, 49, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050913015570, 9, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 1, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 2, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 3, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 4, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 5, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030622015571, 6, 22, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 1, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 2, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 3, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 4, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 5, 54, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 6, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 7, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 8, 32, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221015572, 9, 12, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 6, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 7, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207015926, 8, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309015927, 1, 126, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309015927, 2, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309015927, 3, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309015927, 4, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030309015927, 5, 71, 13, 11, 143);
commit;
prompt 151000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 1, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 2, 25, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 3, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 4, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 5, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 6, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 7, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 8, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 9, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 10, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 11, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 12, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110504015928, 13, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 1, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 2, 45, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 3, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 4, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 5, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 6, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 7, 57, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 8, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 9, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 10, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 11, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002015929, 12, 104, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 1, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 2, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 3, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 4, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 5, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 6, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 7, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 8, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 9, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 10, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 11, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071101015930, 12, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 1, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 2, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 3, 83, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 4, 177, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 5, 77, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 6, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 7, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 8, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 9, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 10, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 11, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 12, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 13, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 14, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015931, 15, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 1, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 2, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 3, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 4, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 5, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 6, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 7, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 8, 105, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 9, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 10, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 11, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 12, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 13, 187, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015932, 14, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 1, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 2, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 3, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 4, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 5, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 6, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 7, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 8, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 9, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 10, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 11, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526015933, 12, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 1, 160, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 2, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 3, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 4, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 5, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 6, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 7, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 8, 157, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 9, 57, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 10, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 11, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 12, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 13, 37, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120814015934, 14, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 1, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 2, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 3, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 4, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 5, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 6, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 7, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216015935, 8, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 1, 192, 17, 18, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 2, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 3, 40, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 4, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 5, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 6, 189, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 7, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 8, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 9, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 10, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 11, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 12, 22, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 13, 92, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 14, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120107015936, 15, 95, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 1, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 2, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 3, 131, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 4, 85, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 5, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 6, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 7, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 8, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 9, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126015937, 10, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 1, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 2, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 3, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 4, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 5, 128, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 6, 136, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 7, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 8, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061115015938, 9, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 1, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 2, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 3, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 4, 100, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 5, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 6, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 7, 86, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 8, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 9, 35, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 10, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 11, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 12, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 13, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 14, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 15, 101, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131221015939, 16, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226015940, 1, 141, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226015940, 2, 155, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226015940, 3, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226015940, 4, 99, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 1, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 2, 82, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 3, 177, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 4, 7, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 5, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 6, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 7, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 8, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 9, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080920015941, 10, 35, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 1, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 2, 35, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 3, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 4, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 5, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 6, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 7, 191, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 8, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 9, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 10, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 11, 192, 82, 18, 1476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416015942, 12, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 1, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 2, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 3, 126, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 4, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 5, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030530015943, 6, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010910015944, 1, 15, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010910015944, 2, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010910015944, 3, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 1, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 2, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 3, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 4, 102, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 5, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 6, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 7, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 8, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 9, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 10, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 11, 172, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 12, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 13, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 14, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100519015945, 15, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 1, 41, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 2, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 3, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 4, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 5, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010015946, 6, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 1, 169, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 2, 104, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 3, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 4, 187, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 5, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 6, 121, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011015947, 7, 120, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 1, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 2, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 3, 118, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 4, 45, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 5, 162, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227015948, 6, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 1, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 2, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 3, 5, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 4, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 5, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 6, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031019015949, 7, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 1, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 2, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 3, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 4, 81, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 5, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 6, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 7, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 8, 187, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 9, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 10, 77, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 11, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 12, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 13, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 14, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 15, 82, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 16, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404014790, 17, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 1, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 2, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 3, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 4, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 5, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 6, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 7, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017014791, 8, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 1, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 2, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 3, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 4, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 5, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 6, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 7, 88, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 8, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 9, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 10, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 11, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 12, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 13, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 14, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 15, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 16, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 17, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 18, 3, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140402014792, 19, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919014793, 1, 154, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919014793, 2, 140, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919014793, 3, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919014793, 4, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020919014793, 5, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 1, 176, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 2, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 3, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 4, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 5, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020717014794, 6, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 1, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 2, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 3, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 4, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 5, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 6, 83, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 7, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229014795, 8, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 1, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 2, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 3, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 4, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 5, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 6, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 7, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 8, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 9, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 10, 69, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 11, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 12, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090908014796, 13, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 1, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 2, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 3, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 4, 63, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 5, 55, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 6, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 7, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 8, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 9, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071228014797, 10, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 1, 151, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 2, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 3, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 4, 21, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 5, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 6, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 7, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041011014798, 8, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 1, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 2, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 3, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 4, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 5, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 6, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 7, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 8, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 9, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 10, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 11, 47, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100622014799, 12, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 1, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 2, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 3, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 4, 10, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 5, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 6, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 7, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 8, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 9, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609014800, 10, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 1, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 2, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 3, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 4, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 5, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 6, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 7, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 8, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 9, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928014801, 10, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 1, 8, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 2, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 3, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 4, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 5, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 6, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 7, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 8, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 9, 48, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 10, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080205014802, 11, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 1, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 2, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 3, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 4, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 5, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 6, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 7, 161, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 8, 131, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 9, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 10, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 11, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014803, 12, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 1, 75, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 2, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 3, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 4, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 5, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 6, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014804, 7, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 1, 143, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 2, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 3, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 4, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 5, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 6, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 7, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 8, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 9, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 10, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 11, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 12, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 13, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 14, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 15, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 16, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120613014805, 17, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802014806, 1, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802014806, 2, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802014806, 3, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010802014806, 4, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 1, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 2, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 3, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 4, 68, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 5, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 6, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 7, 4, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 8, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 9, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 10, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 11, 92, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 12, 59, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 13, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 14, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 15, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130126014807, 16, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 1, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 2, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 3, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 4, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 5, 141, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010520014808, 6, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014809, 1, 35, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014809, 2, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014809, 3, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014809, 4, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020419014809, 5, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 1, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 2, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 3, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 4, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 5, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 6, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 7, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 8, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 9, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 10, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 11, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 12, 157, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 13, 100, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 14, 74, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 15, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 16, 189, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 17, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327014810, 18, 168, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 1, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 2, 141, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 3, 73, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 4, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 5, 190, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 6, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 7, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 8, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 9, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 10, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 11, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 12, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110329014811, 13, 96, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 1, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 2, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 3, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 4, 79, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 5, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 6, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 7, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 8, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 9, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 7, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 8, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015175, 9, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 1, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 2, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 3, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 4, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 5, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 6, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 7, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 8, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 9, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 10, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 11, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 12, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 13, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 14, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031015176, 15, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319015177, 1, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319015177, 2, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319015177, 3, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010319015177, 4, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 1, 190, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 2, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 3, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 4, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 5, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 6, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040917015178, 7, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 1, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 2, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 3, 65, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 4, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 5, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 6, 65, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 7, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 8, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015179, 9, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 1, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 2, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 3, 169, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 4, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 5, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 6, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 7, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410015180, 8, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 1, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 2, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 3, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 4, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 5, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 6, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 7, 175, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 8, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 9, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 10, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 11, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 12, 129, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 13, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110210015181, 14, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 1, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 2, 72, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 3, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 4, 173, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 5, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 6, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 7, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 8, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 9, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 10, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 11, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 12, 156, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421015182, 13, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 1, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 2, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 3, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 4, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 5, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 6, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 7, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 8, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 9, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 10, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 11, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 12, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 13, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 14, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 15, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 16, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015183, 17, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210015184, 1, 8, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210015184, 2, 174, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010210015184, 3, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 1, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 2, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 3, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 4, 37, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 5, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 6, 156, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 7, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 8, 124, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 9, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318015185, 10, 54, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416015186, 1, 85, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416015186, 2, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000416015186, 3, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 1, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 2, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 3, 172, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 4, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 5, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 6, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 7, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 8, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415015187, 9, 101, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 1, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 2, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 3, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 4, 51, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 5, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 6, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 7, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 8, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 9, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 10, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091201015188, 11, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 1, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 2, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 3, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 4, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 5, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212015189, 6, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 1, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 2, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 3, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 4, 11, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 5, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 6, 182, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 7, 31, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 8, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 9, 163, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 10, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061210015190, 11, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 1, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 2, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 3, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 4, 150, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 5, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 6, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 7, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 8, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 9, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060412015191, 10, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428015192, 1, 187, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428015192, 2, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428015192, 3, 190, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428015192, 4, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428015192, 5, 6, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 1, 157, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 2, 105, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 3, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 4, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 5, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 6, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 7, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 8, 150, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 9, 15, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 10, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 11, 102, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 12, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 13, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 14, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120826015193, 15, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 1, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 2, 19, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 3, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 4, 67, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 5, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 6, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 7, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 8, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 9, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 10, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 11, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 12, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 13, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 14, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 15, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120624015194, 16, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 1, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 2, 72, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 3, 14, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 4, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 5, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 6, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 7, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 8, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 9, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 10, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 11, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 12, 173, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 13, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 14, 161, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 15, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227015195, 16, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 1, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 2, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 3, 35, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 4, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 5, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 6, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030320015196, 7, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 1, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 2, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 3, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 4, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 5, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 6, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 7, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 8, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 9, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 10, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 11, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 12, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 13, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 14, 72, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 15, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626015197, 16, 124, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 1, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 2, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 3, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 4, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 5, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 6, 87, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 7, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 8, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070722015198, 9, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 1, 126, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 2, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 1, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 2, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 3, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 4, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 5, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 6, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 7, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051012015573, 8, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 1, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 2, 75, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 3, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 4, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 5, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 6, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 7, 134, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 8, 88, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 9, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 10, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 11, 34, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 12, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 13, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 14, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120213015574, 15, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 1, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 2, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 3, 189, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 4, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 5, 115, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030503015575, 6, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 1, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 2, 118, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 3, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 4, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 5, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030424015576, 6, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 1, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 2, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 3, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 4, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 5, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 6, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 7, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 8, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 9, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070406015577, 10, 132, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 1, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 2, 131, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 3, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 4, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 5, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 6, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 7, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 8, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060730015578, 9, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 1, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 2, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 3, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 4, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 5, 147, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 6, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 7, 168, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 8, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 9, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 10, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 11, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 12, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 13, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906015579, 14, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 1, 14, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 2, 180, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 3, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 4, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 5, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 6, 26, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 7, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 8, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 9, 113, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 10, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 11, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 12, 33, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 13, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 14, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110927015580, 15, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 1, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 2, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 3, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 4, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 5, 130, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 6, 23, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 7, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 8, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 9, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 10, 46, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 11, 184, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 12, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091005015581, 13, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 1, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 2, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 3, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 4, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 5, 15, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 6, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 7, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 8, 54, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 9, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 10, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080530015582, 11, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 1, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 2, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 3, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 4, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 5, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 6, 14, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 7, 69, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 8, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 9, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 10, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 11, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 12, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 13, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 14, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 15, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 16, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 17, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130707015583, 18, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 1, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 2, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 3, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 4, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 5, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 6, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 7, 146, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 8, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 9, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 10, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 11, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 12, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 13, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 14, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110015584, 15, 10, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 1, 24, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 2, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 3, 187, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 4, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 5, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015585, 6, 70, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 1, 34, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 2, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 3, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 4, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 5, 111, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 6, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 7, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130015586, 8, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 1, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 2, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 3, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 4, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 5, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 6, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 7, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 8, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 9, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 10, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 11, 38, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 12, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108015587, 13, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 1, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 2, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 3, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 4, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 5, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 6, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 7, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 8, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 9, 180, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 10, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 11, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 12, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 13, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 14, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 15, 150, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 16, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015588, 17, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 1, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 2, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 3, 110, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 4, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 5, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 6, 25, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 7, 144, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 8, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 9, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 10, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 11, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 12, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 13, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110517015589, 14, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 1, 17, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 2, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 3, 98, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 4, 111, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 5, 182, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725015590, 6, 153, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 1, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 2, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 3, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 4, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 5, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 6, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 7, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 8, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 9, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 10, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 11, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 12, 92, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 13, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 14, 144, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 15, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 16, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015591, 17, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221015592, 1, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221015592, 2, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221015592, 3, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221015592, 4, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221015592, 5, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 1, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 2, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 3, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 4, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 5, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 6, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 7, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 8, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050314015593, 9, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 1, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 2, 48, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 3, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 4, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 6, 77, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030710015950, 7, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226015951, 1, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226015951, 2, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226015951, 3, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226015951, 4, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000226015951, 5, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 1, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 2, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 3, 176, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 4, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 5, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 6, 117, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 7, 22, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 8, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 9, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 10, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 11, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015952, 12, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 1, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 2, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 3, 12, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 4, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 5, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 6, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 7, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 8, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 9, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 10, 110, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 11, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070213015953, 12, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 1, 10, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 2, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 3, 60, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 4, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 5, 1, 26, 3, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 6, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 7, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 8, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 9, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 10, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070121015954, 11, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031015955, 1, 58, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031015955, 2, 25, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031015955, 3, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021031015955, 4, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 1, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 2, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 3, 14, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 4, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 5, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040830015956, 6, 158, 22, 15, 330);
commit;
prompt 152000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 1, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 2, 183, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 3, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 4, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 5, 152, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 6, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 7, 2, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 8, 1, 46, 3, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 9, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 10, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 11, 8, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 12, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 13, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921015957, 14, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 1, 54, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 2, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 3, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 4, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 5, 35, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 6, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 7, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 8, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 9, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 10, 150, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 11, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 12, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 13, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 14, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100821015958, 15, 10, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603015959, 1, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603015959, 2, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000603015959, 3, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 1, 173, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 2, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 3, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 4, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 5, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 6, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 7, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 8, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 9, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 10, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 11, 187, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 12, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 13, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 14, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 15, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 16, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 17, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830015960, 18, 184, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211015961, 1, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211015961, 2, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000211015961, 3, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 1, 89, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 2, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 3, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 4, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 5, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429015962, 6, 41, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825015963, 1, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825015963, 2, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825015963, 3, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825015963, 4, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825015963, 5, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 1, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 2, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 3, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 4, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 5, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 6, 125, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 7, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 8, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 9, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 10, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 11, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 12, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 13, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 14, 101, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 15, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120120015964, 16, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 1, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 2, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 3, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 4, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 5, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 6, 101, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 7, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 8, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 9, 173, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 10, 79, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 11, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815015965, 12, 174, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 1, 31, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 2, 137, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 3, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 4, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 5, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 6, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 7, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 8, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 9, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 10, 23, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 11, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 12, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 13, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 14, 46, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 15, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 16, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 17, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130930015966, 18, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 1, 143, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 2, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 3, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 4, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 5, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 6, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 7, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 8, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 9, 182, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 10, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 11, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 12, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015967, 13, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 1, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 2, 125, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 3, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 4, 135, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 5, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 6, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 7, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 8, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 9, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 10, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325015968, 11, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505015969, 1, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505015969, 2, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505015969, 3, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505015969, 4, 37, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010505015969, 5, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 1, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 2, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 3, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 4, 88, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 5, 99, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 6, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 7, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901015970, 8, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 1, 98, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 2, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 3, 53, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 4, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 5, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 6, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 7, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 8, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325015971, 9, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 1, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 2, 190, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 3, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 4, 28, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 5, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 6, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 7, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 8, 116, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 9, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 10, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 11, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090706015972, 12, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 1, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 2, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 3, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 4, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 5, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 6, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 7, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050201015973, 8, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 1, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 2, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 3, 121, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 4, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 5, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 6, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 7, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 8, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 9, 97, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 10, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 11, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 10, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 11, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 12, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101007014812, 13, 43, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 1, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 2, 87, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 3, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 4, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 5, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 6, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 7, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 8, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 9, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211014813, 10, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 1, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 2, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 3, 116, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 4, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 5, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 6, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 7, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030417014814, 8, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212014815, 1, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212014815, 2, 158, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000212014815, 3, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 1, 102, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 2, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 3, 145, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 4, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 5, 81, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 6, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 7, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 8, 86, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 9, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071201014816, 10, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 1, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 2, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 3, 179, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 4, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 5, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 6, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 7, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 8, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 9, 61, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 10, 131, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 11, 97, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 12, 90, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 13, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 14, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111021014817, 15, 138, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 1, 66, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 2, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 3, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 4, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 5, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 6, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 7, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 8, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 9, 16, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 10, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 11, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 12, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 13, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 14, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 15, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 16, 136, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131115014818, 17, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 2, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 3, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 4, 31, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 5, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 6, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 7, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 8, 185, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405014819, 9, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 1, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 2, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 3, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 4, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 5, 133, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 6, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 7, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 8, 1, 26, 3, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 9, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 10, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 11, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 12, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100321014820, 13, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 1, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 2, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 3, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 4, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 5, 163, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 6, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 7, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 8, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061107014821, 9, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 1, 57, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 2, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 3, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 4, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 5, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 6, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050124014822, 7, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 1, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 2, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 3, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 4, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 5, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 6, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 7, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 8, 107, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 9, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 10, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 11, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 12, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 13, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 14, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100201014823, 15, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014824, 1, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014824, 2, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014824, 3, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014824, 4, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014824, 5, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 1, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 2, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 3, 22, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 4, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 5, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 6, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 7, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 8, 63, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 9, 88, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 10, 39, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 11, 61, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 12, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 13, 156, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 14, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130510014825, 15, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 1, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 2, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 3, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 4, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 5, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 6, 37, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 7, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 8, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 9, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 10, 186, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 11, 174, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 12, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 13, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 14, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 15, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 16, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425014826, 17, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 1, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 2, 190, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 3, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 4, 159, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 5, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 6, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 7, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008014827, 8, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 1, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 2, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 3, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 4, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 5, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 6, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 7, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 8, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 9, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203014828, 10, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 1, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 2, 130, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 3, 59, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 4, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 5, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 6, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 7, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 8, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 9, 74, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 10, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 11, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 12, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 13, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 14, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010014829, 15, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014830, 1, 171, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014830, 2, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014830, 3, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608014830, 4, 46, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 1, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 2, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 3, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 4, 131, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 5, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 6, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 7, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 8, 82, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 9, 120, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 10, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 11, 109, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 12, 127, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 13, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 14, 169, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 15, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 16, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207014831, 17, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014832, 1, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014832, 2, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014832, 3, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014832, 4, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108014832, 5, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 1, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 2, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 3, 119, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 4, 29, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 5, 148, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 6, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 7, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 8, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 9, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 10, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 11, 174, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 12, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 13, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 14, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 15, 127, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130705014833, 16, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 1, 82, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 2, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 3, 148, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 4, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 5, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 6, 16, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 7, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 3, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 4, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 5, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 6, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 7, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 8, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 9, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015199, 10, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 1, 12, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 2, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 3, 57, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 4, 74, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 5, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 6, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 7, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 8, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 9, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 10, 53, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 11, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 12, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 13, 133, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100823015200, 14, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 1, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 2, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 3, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 4, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 5, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011108015201, 6, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 1, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 2, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 3, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 4, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 5, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 6, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040621015202, 7, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 1, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 2, 186, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 3, 77, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 4, 5, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 5, 189, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 6, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 7, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 8, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 9, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 10, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 11, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 12, 130, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 13, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 14, 27, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 15, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 16, 122, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409015203, 17, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 1, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 2, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 3, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 4, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 5, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 6, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 7, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050727015204, 8, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 1, 48, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 2, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 3, 89, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 4, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 5, 74, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 6, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 7, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 8, 174, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 9, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 10, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061207015205, 11, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 1, 101, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 2, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 3, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 4, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 5, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 6, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 7, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 8, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 9, 10, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520015206, 10, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 1, 176, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 2, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 3, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 4, 42, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 5, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 6, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 7, 82, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 8, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 9, 93, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 10, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 11, 190, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 12, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 13, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110527015207, 14, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118015208, 1, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118015208, 2, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001118015208, 3, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 1, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 2, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 3, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 4, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 5, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 6, 143, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 7, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 8, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 9, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117015209, 10, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 1, 23, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 2, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 3, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 4, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 5, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 6, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 7, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 8, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 9, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 10, 47, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 11, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080619015210, 12, 172, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 1, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 2, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 3, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 4, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 5, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 6, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 7, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041103015211, 8, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 1, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 2, 1, 63, 3, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 3, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 4, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 5, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 6, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 7, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 8, 62, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 9, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 10, 48, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070706015212, 11, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 1, 70, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 2, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 3, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 4, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 5, 161, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 6, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 7, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 8, 54, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 9, 179, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 10, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070329015213, 11, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 1, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 2, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 3, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 4, 169, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 5, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 6, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 7, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 8, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 9, 61, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 10, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 11, 160, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 12, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100609015214, 13, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 1, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 2, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 3, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 4, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 5, 10, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015215, 6, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 1, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 2, 187, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 3, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 4, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 5, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 6, 72, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 7, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 8, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 9, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 10, 5, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 11, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 12, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 13, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107015216, 14, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 1, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 2, 176, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 3, 9, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 4, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 5, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 6, 172, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 7, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 8, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 9, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 10, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116015217, 11, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 1, 163, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 2, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 3, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 4, 147, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 5, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 6, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 7, 172, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 8, 177, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040601015218, 9, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329015219, 1, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329015219, 2, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329015219, 3, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010329015219, 4, 107, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 1, 161, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 2, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 3, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 4, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 5, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 6, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 7, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 8, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 9, 106, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522015220, 10, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 1, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 2, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 3, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 4, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 5, 173, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 6, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 7, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 8, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 9, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720015221, 10, 76, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 1, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 2, 159, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 3, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 4, 26, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 5, 130, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 6, 91, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 7, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 8, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 9, 162, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 10, 126, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 11, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 12, 176, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 13, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 5, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 6, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 7, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040213015594, 8, 189, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 1, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 2, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 3, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 4, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 5, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 6, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030718015595, 7, 44, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 1, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 2, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 3, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 4, 121, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 5, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020605015596, 6, 92, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 1, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 2, 48, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 3, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 4, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 5, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 6, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 7, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 8, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 9, 116, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 10, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 11, 102, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 12, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 13, 140, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 14, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 15, 190, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 16, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 17, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140503015597, 18, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 1, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 2, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 3, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 4, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 5, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 6, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 7, 76, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040818015598, 8, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 1, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 2, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 3, 129, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 4, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 5, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 6, 16, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 7, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040604015599, 8, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 1, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 2, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 3, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 4, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 5, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 6, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 7, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 8, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 9, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 10, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 11, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091204015600, 12, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 1, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 2, 110, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 3, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 4, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 5, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 6, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 7, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115015601, 8, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 1, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 2, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 3, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 4, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 5, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 6, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 7, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 8, 144, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 9, 134, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 10, 113, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 11, 143, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 12, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 13, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 14, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120725015602, 15, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 1, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 2, 167, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 3, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 4, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 5, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 6, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 7, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 8, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 9, 119, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 10, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 11, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 12, 151, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 13, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120811015603, 14, 34, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 1, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 2, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 3, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 4, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 5, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 6, 180, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 7, 36, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 8, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 9, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 10, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 11, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 12, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227015604, 13, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 1, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 2, 62, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 3, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 4, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 5, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 6, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 7, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 8, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 9, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 10, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 11, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015605, 12, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720015606, 1, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720015606, 2, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720015606, 3, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720015606, 4, 162, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720015606, 5, 154, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 1, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 2, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 3, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 4, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 5, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 6, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 7, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 8, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 9, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 10, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 11, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090105015607, 12, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 1, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 2, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 3, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 4, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 5, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 6, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 7, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 8, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 9, 92, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 10, 31, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 11, 141, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090811015608, 12, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 1, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 2, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 3, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 4, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 5, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 6, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 7, 97, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 8, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 9, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060405015609, 10, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009015610, 1, 93, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009015610, 2, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009015610, 3, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009015610, 4, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021009015610, 5, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 1, 86, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 2, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 3, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 4, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 5, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 6, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 7, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 8, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 9, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 10, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 11, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 12, 160, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080307015611, 13, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 1, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 2, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 3, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 4, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 5, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 6, 18, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 7, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 8, 114, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 9, 158, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 10, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 11, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 12, 169, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 13, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 14, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120710015612, 15, 9, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 1, 74, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 2, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 3, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 4, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 5, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 6, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 7, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 8, 11, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 9, 58, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 10, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 11, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 12, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116015613, 13, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 1, 91, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 2, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 3, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 4, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 5, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 6, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 7, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 8, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 9, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 10, 87, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 11, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 12, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 13, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 14, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 15, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110514015614, 16, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025015615, 1, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025015615, 2, 1, 54, 3, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025015615, 3, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703015616, 1, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703015616, 2, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703015616, 3, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703015616, 4, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703015616, 5, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327015617, 1, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327015617, 2, 33, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 1, 40, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 2, 164, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 3, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 5, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 6, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016071, 1, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016071, 2, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016071, 3, 10, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016071, 4, 161, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 1, 98, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 2, 16, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 3, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 4, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 5, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 6, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 7, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 8, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 9, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 10, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 11, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 12, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029016072, 13, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 1, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 2, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 3, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 4, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 5, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 6, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 7, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 8, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 9, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 10, 189, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081226016073, 11, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 1, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 2, 92, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 3, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 4, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 5, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 6, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 7, 134, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 8, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 9, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 10, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016074, 11, 177, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 1, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 2, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 3, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 4, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 5, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 6, 175, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 7, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 8, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 9, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 10, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 11, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 12, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080305016075, 13, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 1, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 2, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 3, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 4, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 5, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 6, 152, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 7, 100, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 8, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 9, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 10, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 11, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 12, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 13, 124, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 14, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 15, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110615016076, 16, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 1, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 2, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 3, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 4, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 5, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 6, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 7, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050208016077, 8, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 1, 128, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 2, 154, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 3, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 4, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 5, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 6, 145, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030313016078, 7, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 2, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 3, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 4, 81, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 5, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 6, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 7, 140, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 8, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060205016079, 9, 175, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000420016080, 1, 130, 3, 8, 24);
commit;
prompt 153000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000420016080, 2, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000420016080, 3, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016081, 1, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016081, 2, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016081, 3, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016081, 4, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016081, 5, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 1, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 2, 80, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 3, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 4, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 5, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 6, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 7, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 8, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 9, 17, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 10, 140, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 11, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090530016082, 12, 64, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 1, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 2, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 3, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 4, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 5, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 6, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 7, 61, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 8, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 9, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 10, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 11, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 12, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 13, 160, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 14, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 15, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 16, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016083, 17, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 1, 158, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 2, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 3, 41, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 4, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 5, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 6, 104, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 7, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 8, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 9, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 10, 17, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 11, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 12, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 13, 99, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 14, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 15, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 16, 69, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 17, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318016084, 18, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 1, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 2, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 3, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 4, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 5, 55, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 6, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 7, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 8, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 9, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 10, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 11, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 12, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 13, 149, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 14, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 15, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130206016085, 16, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 1, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 2, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 3, 23, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 4, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 5, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 6, 102, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 7, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 8, 138, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 9, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 10, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 11, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 12, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090412016086, 13, 26, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 1, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 2, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 3, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 4, 15, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 5, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 6, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 7, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 8, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 9, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 10, 7, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 11, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 12, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 13, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 14, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016087, 15, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 1, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 2, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 3, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 4, 117, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 5, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 6, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 7, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 8, 170, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 9, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 10, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 11, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 12, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101008016088, 13, 166, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807016089, 1, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807016089, 2, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807016089, 3, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807016089, 4, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807016089, 5, 189, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 1, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 2, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 3, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 4, 20, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 5, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 6, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 7, 66, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 8, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 9, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 10, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 11, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016090, 12, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 1, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 2, 163, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 3, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 4, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 5, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 6, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 7, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 8, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 9, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 10, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090819016091, 11, 29, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127016092, 1, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127016092, 2, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127016092, 3, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001127016092, 4, 158, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 1, 105, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 8, 176, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 9, 14, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 10, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 11, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 12, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 13, 110, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 14, 45, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 15, 76, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 16, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 17, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140505014834, 18, 187, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 1, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 2, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 3, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 4, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 5, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 6, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 7, 15, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 8, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 9, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 10, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 11, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 12, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 13, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 14, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 15, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 16, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130121014835, 17, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 1, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 2, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 3, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 4, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 5, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 6, 174, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 7, 125, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 8, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 9, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 10, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 11, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 12, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 13, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 14, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 15, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140513014836, 16, 4, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 1, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 2, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 3, 184, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 4, 56, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 5, 96, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 6, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 7, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 8, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 9, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 10, 139, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 11, 24, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 12, 108, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120014837, 13, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 1, 43, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 2, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 3, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 4, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 5, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 6, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 7, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 8, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 9, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 10, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 11, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 12, 37, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628014838, 13, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 1, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 2, 53, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 3, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 4, 145, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 5, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 6, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 7, 70, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 8, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 9, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 10, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 11, 157, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 12, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100406014839, 13, 24, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 1, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 2, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 3, 60, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 4, 33, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 5, 143, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 6, 68, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 7, 49, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226014840, 8, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 1, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 2, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 3, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 4, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 5, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 6, 190, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 7, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 8, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 9, 102, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 10, 16, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 11, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 12, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090704014841, 13, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 1, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 2, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 3, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 4, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 5, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 6, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 7, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 8, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 9, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 10, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070220014842, 11, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 1, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 2, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 3, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 4, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 5, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114014843, 6, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 1, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 2, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 3, 120, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 4, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 5, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 6, 74, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 7, 131, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 8, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 9, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116014844, 10, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014845, 1, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014845, 2, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000807014845, 3, 84, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 1, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 2, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 3, 57, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 4, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 5, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 6, 64, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 7, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 8, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 9, 3, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 10, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090528014846, 11, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 1, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 2, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 3, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 4, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 5, 5, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 6, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 7, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 8, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 9, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 10, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 11, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 12, 163, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 13, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 14, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525014847, 15, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223014848, 1, 187, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223014848, 2, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223014848, 3, 168, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223014848, 4, 102, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010223014848, 5, 30, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 1, 69, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 2, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 3, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 4, 42, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 5, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 6, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 7, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 8, 90, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 9, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 10, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 11, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 12, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 13, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 14, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 15, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120609014849, 16, 91, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 1, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 2, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 3, 19, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 4, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 5, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 6, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 7, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 8, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 9, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 10, 154, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 11, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 12, 29, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 13, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 14, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110804014850, 15, 78, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014851, 1, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014851, 2, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014851, 3, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014851, 4, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506014851, 5, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 1, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 2, 188, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 3, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 4, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 5, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 6, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 7, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 8, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 9, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 10, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 11, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 12, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 13, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103014852, 14, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 1, 7, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 3, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 4, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 5, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 6, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 7, 140, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 8, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 9, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 10, 80, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 11, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070516014853, 12, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 1, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 2, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 3, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 4, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 5, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 6, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 7, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 8, 143, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 9, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 10, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 11, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 12, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 14, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 15, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 16, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428015222, 17, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 1, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 2, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 3, 36, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 4, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 5, 44, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041228015223, 6, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 1, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 2, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 3, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 4, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 5, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 6, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 7, 41, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 8, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 9, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 10, 95, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 11, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 12, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 13, 35, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090710015224, 14, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 1, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 2, 28, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 3, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 4, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 5, 80, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 6, 142, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 7, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 8, 124, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 9, 140, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 10, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120015225, 11, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 1, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 2, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 3, 44, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 4, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 5, 115, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 6, 97, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 7, 59, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 8, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 9, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 10, 100, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 11, 143, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 12, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 13, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 14, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 15, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 16, 117, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140425015226, 17, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 1, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 2, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 3, 164, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 4, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 5, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 6, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 7, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 8, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 9, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 10, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 11, 182, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 12, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 13, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111113015227, 14, 64, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 1, 157, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 2, 112, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 3, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 4, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 5, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 6, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 7, 177, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 8, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 9, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 10, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 11, 120, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080229015228, 12, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 1, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 2, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 3, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 4, 143, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 5, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 6, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 7, 72, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 8, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 9, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071214015229, 10, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015230, 1, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015230, 2, 74, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015230, 3, 155, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 1, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 2, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 3, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 4, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 5, 191, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 6, 18, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 7, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 8, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 9, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070816015231, 10, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 1, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 2, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 3, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 4, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 5, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 6, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 7, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 8, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 9, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819015232, 10, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020015233, 1, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020015233, 2, 66, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020015233, 3, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011020015233, 4, 8, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 1, 63, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 2, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 3, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 4, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 5, 180, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 6, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 7, 101, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 8, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 9, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 10, 15, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 11, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 12, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 13, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 14, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110202015234, 15, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 1, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 2, 175, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 3, 40, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 4, 12, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 5, 55, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 6, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 7, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 8, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 9, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 10, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 11, 113, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 12, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101027015235, 13, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 1, 92, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 2, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 3, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 4, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 5, 140, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 6, 160, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 7, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 8, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 9, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070917015236, 10, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225015237, 1, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225015237, 2, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225015237, 3, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225015237, 4, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225015237, 5, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 1, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 2, 109, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 3, 168, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 4, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 5, 5, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 6, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 7, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 8, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 9, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 10, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 11, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 12, 69, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 13, 143, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 14, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130628015238, 15, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 1, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 2, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 3, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 4, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 5, 63, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 6, 104, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 7, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629015239, 8, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829015240, 1, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829015240, 2, 143, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010829015240, 3, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722015241, 1, 51, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722015241, 2, 126, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722015241, 3, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722015241, 4, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722015241, 5, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 1, 57, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 2, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 3, 92, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 4, 89, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 5, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 6, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 7, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 8, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 9, 113, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061001015242, 10, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 1, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 2, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 3, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 4, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 5, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 6, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 7, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 8, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050129015243, 9, 130, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122015244, 1, 104, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122015244, 2, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122015244, 3, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122015244, 4, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030122015244, 5, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 1, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 2, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 3, 163, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 4, 59, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 5, 3, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 6, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 7, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 8, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 9, 133, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 10, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 11, 47, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 12, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 13, 182, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 14, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015245, 15, 48, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 1, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 2, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 3, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 4, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 5, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 6, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 7, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 8, 182, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 9, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 10, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 11, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 4, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 5, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 6, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 7, 26, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 8, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627015618, 9, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 1, 191, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 2, 106, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 3, 22, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 4, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 5, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 6, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 7, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 8, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 9, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121015619, 10, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 1, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 2, 87, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 3, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 4, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 5, 89, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 6, 128, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303015620, 7, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 1, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 2, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 3, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 4, 75, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 5, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 6, 25, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 7, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 8, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 9, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 10, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090131015621, 11, 114, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 1, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 2, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 3, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 4, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 5, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 6, 88, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 7, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 8, 138, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 9, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 10, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 11, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 12, 41, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100124015622, 13, 2, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 1, 12, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 2, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 3, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 4, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 5, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 6, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 7, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 8, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 9, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 10, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 11, 80, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 12, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 13, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 14, 84, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827015623, 15, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 1, 75, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 2, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 3, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 4, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 5, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 6, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 7, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 8, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 9, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 10, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 11, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100712015624, 12, 82, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 1, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 2, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 3, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 4, 15, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 5, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930015625, 6, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 1, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 2, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 3, 52, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 4, 112, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 5, 106, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 6, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 7, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 8, 109, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 9, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 10, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916015626, 11, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116015627, 1, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116015627, 2, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116015627, 3, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001116015627, 4, 156, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526015628, 1, 45, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526015628, 2, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526015628, 3, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526015628, 4, 176, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 1, 113, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 2, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 3, 87, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 4, 128, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 5, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015629, 6, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026015630, 1, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001026015630, 2, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 1, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 2, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 3, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 4, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 5, 70, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 6, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 7, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 8, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 9, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 10, 70, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 11, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 12, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 13, 136, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101107015631, 14, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 1, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 2, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 3, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 4, 96, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 5, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 6, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 7, 134, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050919015632, 8, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 1, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 2, 88, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 3, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 4, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 5, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 6, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 7, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 8, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 9, 176, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 10, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 11, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 12, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 13, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 14, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 15, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 16, 16, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131122015633, 17, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 1, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 2, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 3, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 4, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 5, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015634, 6, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 1, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 2, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 3, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 4, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 5, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 6, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 7, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 8, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 9, 119, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 10, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 11, 148, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 12, 108, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 13, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 14, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103015635, 15, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 1, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 2, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 3, 50, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 4, 67, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 5, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 6, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 7, 178, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 8, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 9, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 10, 129, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 11, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015636, 12, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 1, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 2, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 3, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 4, 142, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 5, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 6, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 7, 127, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 8, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 9, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 10, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 11, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 12, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 13, 9, 11, 4, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110620015637, 14, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 1, 53, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 2, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 3, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 4, 33, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 5, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 6, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 7, 82, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 8, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 9, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 10, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 11, 174, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070710015638, 12, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512015639, 1, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512015639, 2, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512015639, 3, 104, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000512015639, 4, 73, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 1, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 2, 7, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 3, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 4, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 5, 35, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 6, 178, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 7, 174, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 8, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 9, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 10, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 11, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818015640, 12, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 1, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 2, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 3, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 4, 30, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 5, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 6, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 7, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030525015641, 8, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129015642, 1, 121, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129015642, 2, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011129015642, 3, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 1, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 2, 6, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 3, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 4, 54, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 5, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 6, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040514015643, 7, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 12, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012015974, 13, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 1, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 2, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 3, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 4, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 5, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 6, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 7, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 8, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 9, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 10, 180, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 11, 117, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 12, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 13, 41, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 14, 149, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 15, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806015975, 16, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 1, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 2, 122, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 3, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 4, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 5, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 6, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 7, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 8, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 9, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 10, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 11, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 12, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 13, 99, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 14, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 15, 78, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 16, 52, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111015976, 17, 100, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803015977, 1, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803015977, 2, 134, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803015977, 3, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010803015977, 4, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 1, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 2, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 3, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 4, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 5, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 6, 67, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040624015978, 7, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 1, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 2, 20, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 3, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 4, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 5, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 6, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 7, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041012015979, 8, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 1, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 2, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 3, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 4, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 5, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 6, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 7, 45, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 8, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070915015980, 9, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 1, 159, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 2, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 3, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 4, 15, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 5, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 6, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 7, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 8, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 9, 5, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 10, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 11, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 12, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027015981, 13, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015982, 1, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015982, 2, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015982, 3, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015982, 4, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015982, 5, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027015983, 1, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027015983, 2, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027015983, 3, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 1, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 2, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 3, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 4, 153, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 5, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 6, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 7, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 8, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 9, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 10, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 11, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 12, 89, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 13, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 14, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 15, 23, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 16, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 17, 109, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131021015984, 18, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 1, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 2, 133, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 3, 52, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 4, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 5, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020524015985, 6, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 1, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 2, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 3, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 4, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 5, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 6, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 7, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 8, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 9, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 10, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 11, 168, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080915015986, 12, 36, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 1, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 2, 141, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 3, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 4, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 5, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 6, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 7, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 8, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 9, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 10, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 11, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 12, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 13, 59, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 14, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110308015987, 15, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 1, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 2, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 3, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 4, 129, 39, 7, 273);
commit;
prompt 154000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 5, 192, 25, 18, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 6, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 7, 125, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 8, 97, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 9, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 10, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070914015988, 11, 100, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 1, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 2, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 3, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 4, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 5, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 6, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 7, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050822015989, 8, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 1, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 2, 168, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 3, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 4, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 5, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 6, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 7, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 8, 103, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 9, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 10, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 11, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 12, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 13, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 14, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 15, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 16, 139, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140328015990, 17, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 1, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 2, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 3, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 4, 73, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 5, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 6, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 7, 166, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 8, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 9, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 10, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 11, 63, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 12, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 13, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090319015991, 14, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 1, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 2, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 3, 84, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 4, 173, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 5, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 6, 4, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 7, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 8, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 9, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 10, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 11, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 12, 100, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 13, 105, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 14, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131014015992, 15, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 1, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 2, 100, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 3, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 4, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 5, 140, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 6, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 7, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 8, 112, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 9, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 10, 128, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 11, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080821015993, 12, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625015994, 1, 125, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625015994, 2, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625015994, 3, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625015994, 4, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010625015994, 5, 127, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 1, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 2, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 3, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 4, 37, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 5, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 6, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 7, 78, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061215015995, 8, 6, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 1, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 2, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 3, 158, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 4, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 5, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 6, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040728015996, 7, 41, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 1, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 2, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 3, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 4, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 5, 52, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 6, 39, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 7, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 13, 44, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 14, 181, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 15, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 16, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 17, 87, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130111014854, 18, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 1, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 2, 62, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 3, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 4, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 5, 137, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 6, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 7, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 8, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 9, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081007014855, 10, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 1, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 2, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 3, 162, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 4, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 5, 148, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 6, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617014856, 7, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 1, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 2, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 3, 98, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 4, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 5, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 6, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 7, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 8, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 9, 152, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 10, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080116014857, 11, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 1, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 2, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 3, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 4, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 5, 117, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 6, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 7, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 8, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 9, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 10, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 11, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 12, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 13, 47, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 14, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130825014858, 15, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 1, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 2, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 3, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 4, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 5, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 6, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 7, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 8, 166, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302014859, 9, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 1, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 2, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 3, 28, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 4, 86, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 5, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 6, 71, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 7, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 8, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 9, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 10, 65, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 11, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 12, 21, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 13, 97, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 14, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 15, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130818014860, 16, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 1, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 2, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 3, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 4, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 5, 63, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 6, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 7, 16, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 8, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 9, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 10, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 11, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 12, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080106014861, 13, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 1, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 2, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 3, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 4, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 5, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421014862, 6, 143, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 1, 62, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 2, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 3, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 4, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 5, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 6, 118, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 7, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 8, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 9, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 10, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080502014863, 11, 139, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 1, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 2, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 3, 105, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 4, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 5, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 6, 80, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 7, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 8, 11, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 9, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 10, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 11, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 12, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702014864, 13, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 1, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 2, 22, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 3, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 4, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 5, 98, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 6, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 7, 146, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050903014865, 8, 26, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331014866, 1, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331014866, 2, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014867, 1, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014867, 2, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014867, 3, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014867, 4, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506014868, 1, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506014868, 2, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506014868, 3, 68, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506014868, 4, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 1, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 2, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 3, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 4, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 5, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 6, 6, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 7, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 8, 141, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 9, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 10, 71, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081130014869, 11, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 1, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 2, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 3, 190, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 4, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 5, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 6, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 7, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 8, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 9, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 10, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 11, 88, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 12, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 13, 92, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 14, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 15, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110530014870, 16, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820014871, 1, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820014871, 2, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820014871, 3, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820014871, 4, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020820014871, 5, 5, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 1, 69, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 2, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 3, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 4, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 5, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 6, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 7, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 8, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 9, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 10, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 11, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 12, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 13, 74, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 14, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221014872, 15, 192, 54, 18, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 1, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 2, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 3, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 4, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 5, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 6, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 7, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 8, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 9, 10, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 10, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 11, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607014873, 12, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 1, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 2, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 3, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 4, 58, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 5, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 6, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 7, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 8, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 9, 184, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 10, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106014874, 11, 185, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 1, 1, 65, 3, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 2, 140, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 3, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 4, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 5, 174, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 6, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 7, 8, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 8, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 9, 183, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 10, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116014875, 11, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 1, 151, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 2, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 3, 80, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 4, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 5, 101, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 6, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 7, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 8, 88, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 9, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324014876, 10, 18, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 1, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 2, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 3, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 4, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 5, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 6, 4, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 7, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 8, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 9, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 10, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 11, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 12, 14, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 13, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 12, 9, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101216015246, 13, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015247, 1, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015247, 2, 23, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001214015247, 3, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 1, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 2, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 3, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 4, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 5, 133, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040614015248, 6, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015249, 1, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015249, 2, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015249, 3, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015249, 4, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015249, 5, 169, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 1, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 2, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 3, 90, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 4, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 5, 145, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 6, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 7, 73, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 8, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 9, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 10, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 11, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127015250, 12, 94, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816015251, 1, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816015251, 2, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816015251, 3, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816015251, 4, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010816015251, 5, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 1, 177, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 2, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 3, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 4, 159, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 5, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 6, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 7, 178, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040526015252, 8, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 1, 190, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 2, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 3, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 4, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 5, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 6, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306015253, 7, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 1, 93, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 2, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 3, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 4, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 5, 127, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 6, 27, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 7, 40, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608015254, 8, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 1, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 2, 191, 98, 17, 1666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 3, 8, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 4, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 5, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 6, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020127015255, 7, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308015256, 1, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308015256, 2, 78, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308015256, 3, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308015256, 4, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 1, 176, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 2, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 3, 102, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 4, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 5, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 6, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 7, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 8, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 9, 186, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 10, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070222015257, 11, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 1, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 2, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 3, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 4, 46, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 5, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 6, 165, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 7, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040508015258, 8, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 1, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 2, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 3, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 4, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 5, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 6, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 7, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 8, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 9, 7, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 10, 40, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 11, 161, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 12, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110902015259, 13, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 1, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 2, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 3, 147, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 4, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 5, 5, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 6, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 7, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 8, 146, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050608015260, 9, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227015261, 1, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227015261, 2, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227015261, 3, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227015261, 4, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020227015261, 5, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 1, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 2, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 3, 175, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 4, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 5, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 6, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 7, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 8, 166, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 9, 181, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061230015262, 10, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 1, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 2, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 3, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 4, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 5, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 6, 12, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 7, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 8, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 9, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 10, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 11, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100907015263, 12, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 1, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 2, 51, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 3, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 4, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 5, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 6, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051008015264, 7, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619015265, 1, 30, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619015265, 2, 116, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619015265, 3, 101, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619015265, 4, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619015265, 5, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 1, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 2, 76, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 3, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 4, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 5, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 6, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 7, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 8, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 9, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 10, 137, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 11, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 12, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 13, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 14, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 15, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 16, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701015266, 17, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 1, 160, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 2, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 3, 75, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 4, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 5, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021120015267, 6, 192, 14, 18, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307015268, 1, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307015268, 2, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307015268, 3, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010307015268, 4, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 1, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 2, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 3, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 4, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 5, 36, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 6, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 7, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 8, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 9, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 10, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 11, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 12, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 13, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225015269, 14, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 1, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 2, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 3, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 4, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 5, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 6, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 7, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 8, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050301015270, 9, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 1, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 2, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 3, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 4, 52, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 5, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 6, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 7, 45, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 8, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101015271, 9, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 1, 21, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 2, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 3, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 4, 126, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 5, 5, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 6, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 7, 46, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 8, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 9, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 10, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 11, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 12, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 13, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090327015272, 14, 44, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 1, 75, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 2, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 3, 53, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 4, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 5, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 6, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 7, 23, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 8, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 9, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 10, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 11, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071224015273, 12, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 1, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 2, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 3, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 4, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 5, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 6, 51, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 7, 169, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 1, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 2, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 3, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 4, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 5, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 6, 8, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 7, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 8, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 9, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 10, 186, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 11, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 12, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 13, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090608015644, 14, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 1, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 2, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 3, 26, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 4, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 5, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 6, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 7, 26, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 8, 59, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 9, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 10, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070423015645, 11, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 1, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 2, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 3, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 4, 129, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 5, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 6, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 7, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 8, 41, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 9, 35, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 10, 31, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 11, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 12, 49, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015646, 13, 74, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 1, 76, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 2, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 3, 58, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 4, 119, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 5, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 6, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 7, 120, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 8, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 9, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 10, 79, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 11, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 12, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 13, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120504015647, 14, 108, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 1, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 2, 99, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 3, 24, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 4, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 5, 121, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 6, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015648, 7, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 1, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 2, 147, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 3, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 4, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 5, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 6, 178, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 7, 183, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 8, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 9, 77, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 10, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 11, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080304015649, 12, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423015650, 1, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423015650, 2, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423015650, 3, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423015650, 4, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423015650, 5, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103015651, 1, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000103015651, 2, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 1, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 2, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 3, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 4, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 5, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 6, 39, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 7, 104, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 8, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 9, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 10, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 11, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 12, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 13, 181, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 14, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 15, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130417015652, 16, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 1, 140, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 2, 147, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 3, 177, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 4, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 5, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 6, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 7, 175, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 8, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 9, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 10, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 11, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 12, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 13, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110417015653, 14, 188, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 1, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 2, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 3, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 4, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 5, 93, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 6, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 7, 71, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 8, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 9, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 10, 113, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 11, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029015654, 12, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117015655, 1, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117015655, 2, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117015655, 3, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117015655, 4, 148, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 1, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 2, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 3, 144, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 4, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 5, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 6, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 7, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 8, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 9, 22, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 10, 141, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 11, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 12, 103, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 13, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 14, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130108015656, 15, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 1, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 2, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 3, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 4, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 5, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 6, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 7, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 8, 105, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060722015657, 9, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 1, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 2, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 3, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 4, 3, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 5, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 6, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 7, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 8, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 9, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 10, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 11, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 12, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 13, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 14, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 15, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120716015658, 16, 169, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 1, 59, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 2, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 3, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 4, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 5, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 6, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 7, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 8, 5, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060502015659, 9, 185, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 1, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 2, 171, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 3, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 4, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 5, 106, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 6, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 7, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 8, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 9, 118, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 10, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 11, 56, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 12, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 13, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110106015660, 14, 125, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 1, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 2, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 3, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 4, 79, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 5, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 6, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 7, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 8, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 9, 68, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 10, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 11, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100430015661, 12, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 1, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 2, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 3, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 4, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 5, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 6, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 7, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 8, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 9, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071002015662, 10, 130, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 1, 21, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 2, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 3, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 4, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 5, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 6, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 7, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 8, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040810015663, 9, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 1, 112, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 2, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 3, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 4, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 5, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 6, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 7, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 8, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 9, 138, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 10, 180, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 11, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 12, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 13, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 14, 126, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 15, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 16, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140430015664, 17, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 1, 132, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 2, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 3, 31, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 4, 137, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 6, 97, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 7, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 8, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 9, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 10, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 11, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 12, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 13, 151, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 14, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 15, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 1, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 2, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 3, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 4, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 5, 45, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 6, 142, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 7, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 8, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050118016022, 9, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 1, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 2, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 3, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 4, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 5, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 6, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 7, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 8, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 9, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 10, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 11, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 12, 86, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 13, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 14, 180, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 15, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 16, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 17, 95, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130506016023, 18, 168, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016024, 1, 108, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016024, 2, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016024, 3, 52, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016024, 4, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016024, 5, 130, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 1, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 2, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 3, 92, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 4, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 5, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 6, 135, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 7, 56, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040708016025, 8, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 1, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 2, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 3, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 4, 136, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 5, 178, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 6, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 7, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 8, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040809016026, 9, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925016027, 1, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925016027, 2, 27, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925016027, 3, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925016027, 4, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030925016027, 5, 3, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 1, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 2, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 3, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 4, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 5, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 6, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016028, 7, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 1, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 2, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 3, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 4, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 5, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 6, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 7, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 8, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 9, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 10, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 11, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 12, 189, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 13, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 14, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 15, 166, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 16, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130525016029, 17, 15, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518016030, 1, 90, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518016030, 2, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518016030, 3, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000518016030, 4, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 1, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 2, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 3, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 4, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 5, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 6, 32, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 7, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040108016031, 8, 82, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 1, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 2, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 3, 23, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 4, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 5, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 6, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 7, 12, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 8, 6, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 9, 32, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 10, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 11, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 12, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090116016032, 13, 101, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 1, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 2, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 3, 112, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 4, 43, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 5, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 6, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 7, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 8, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 9, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 10, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 11, 167, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 12, 78, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 13, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 14, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 15, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 16, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121125016033, 17, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 1, 168, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 2, 12, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 3, 48, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 4, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 5, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 6, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 7, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 8, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 9, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 10, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081126016034, 11, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 1, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 2, 103, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 3, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 4, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 5, 180, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 6, 145, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 7, 190, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 8, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 9, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 10, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 11, 64, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 12, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 13, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 14, 150, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 15, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 16, 183, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130320016035, 17, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 1, 164, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 2, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 3, 131, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 4, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 5, 55, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 6, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 7, 93, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 8, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 9, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 10, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 11, 5, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 12, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 13, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 14, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 15, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140409016036, 16, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 1, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 2, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 3, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 4, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 5, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 6, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 7, 143, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 8, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 9, 115, 34, 10, 340);
commit;
prompt 155000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 10, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 11, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 12, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 13, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 14, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 15, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130213016037, 16, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 1, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 2, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 3, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 4, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 5, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020905016038, 6, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 1, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 2, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 3, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 4, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 5, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 6, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 7, 82, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 8, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520016039, 9, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016040, 1, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016040, 2, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016040, 3, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 1, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 2, 43, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 3, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 4, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 5, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 6, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 7, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 8, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 9, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 10, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080930016041, 11, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116016042, 1, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116016042, 2, 100, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116016042, 3, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116016042, 4, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011116016042, 5, 164, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 1, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 2, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 3, 46, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 4, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 5, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 6, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 7, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 8, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070318016043, 9, 13, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 1, 138, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 2, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 3, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 4, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 5, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402014877, 14, 4, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 1, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 2, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 3, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 4, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 5, 180, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 6, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 7, 165, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 8, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 9, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 10, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 11, 1, 23, 3, 69);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 12, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 13, 115, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 14, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 15, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 16, 39, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131015014878, 17, 147, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 1, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 2, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 3, 72, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 4, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 5, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 6, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 7, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 8, 2, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 9, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 10, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 11, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 12, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 13, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 14, 132, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719014879, 15, 73, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 1, 91, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 2, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 3, 57, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 4, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 5, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 6, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 7, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 8, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 9, 6, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 10, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070529014880, 11, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 1, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 2, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 3, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 4, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 5, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 6, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 7, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 8, 111, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 9, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 10, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 11, 137, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 12, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 13, 79, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 14, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121202014881, 15, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 1, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 2, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 3, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 4, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 5, 139, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 6, 17, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 7, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 8, 154, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 9, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916014882, 10, 170, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109014883, 1, 18, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109014883, 2, 136, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109014883, 3, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000109014883, 4, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 1, 36, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 2, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 3, 49, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 4, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 5, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 6, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 7, 13, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 8, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 9, 147, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 10, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 11, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 12, 186, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 13, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 14, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 15, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131117014884, 16, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 1, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 2, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 3, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 4, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 5, 31, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 6, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728014885, 7, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 1, 47, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 2, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 3, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 4, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 5, 174, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 6, 44, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 7, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 8, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 9, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 10, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 11, 90, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 12, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 13, 166, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 14, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 15, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 16, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140510014886, 17, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 1, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 2, 142, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 3, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 4, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 5, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 6, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 7, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 8, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 9, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 10, 42, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 11, 152, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071003014887, 12, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 1, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 2, 66, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 3, 96, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 4, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 5, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 6, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 7, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 8, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 9, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 10, 38, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 11, 121, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 12, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 13, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 14, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 15, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120705014888, 16, 15, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 1, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 2, 39, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 3, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 4, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 5, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 6, 133, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 7, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 8, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 9, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 10, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 11, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 12, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 13, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 14, 185, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 15, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 16, 55, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130602014889, 17, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 1, 38, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 2, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 3, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 4, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 5, 140, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 6, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030910014890, 7, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 1, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 2, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 3, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 4, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 5, 153, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 6, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 7, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 8, 24, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 9, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 10, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 11, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 12, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 13, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 14, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 15, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131123014891, 16, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 1, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 2, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 3, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 4, 4, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 5, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 6, 138, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 7, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050307014892, 8, 44, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210014893, 1, 43, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210014893, 2, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210014893, 3, 109, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210014893, 4, 31, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210014893, 5, 37, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 1, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 2, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 3, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 4, 173, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 5, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 6, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 7, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050123014894, 8, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 1, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 2, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 3, 88, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 4, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 5, 140, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 6, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 7, 59, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050105014895, 8, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 1, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 2, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 3, 35, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 4, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 5, 139, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 6, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 7, 103, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 8, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 9, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 10, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 11, 127, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 12, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 13, 144, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 14, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 15, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120707014896, 16, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 1, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 2, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 3, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 4, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 5, 54, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 6, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040109014897, 7, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 1, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 2, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 3, 116, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 4, 159, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 5, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 6, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 8, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 9, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 10, 98, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426015274, 11, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108015275, 1, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108015275, 2, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108015275, 3, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010108015275, 4, 63, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 1, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 2, 99, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 3, 47, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 4, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 5, 136, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 6, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 7, 74, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040120015276, 8, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004015277, 1, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004015277, 2, 126, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004015277, 3, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004015277, 4, 29, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 1, 5, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 2, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 3, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 4, 183, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 5, 23, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030628015278, 6, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 1, 188, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 2, 3, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 3, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 4, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 5, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 6, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030311015279, 7, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 1, 98, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 2, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 3, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 4, 184, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 5, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 6, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 7, 63, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 8, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 9, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 10, 99, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 11, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015280, 12, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 1, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 2, 52, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 3, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 4, 164, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 5, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 6, 155, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 7, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 8, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 9, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 10, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 11, 4, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 12, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 13, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 14, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910015281, 15, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 1, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 2, 174, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 3, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 4, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 5, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 6, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041130015282, 7, 157, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 1, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 2, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 3, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 4, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 5, 39, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030717015283, 6, 131, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226015284, 1, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226015284, 2, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011226015284, 3, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 1, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 2, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 3, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 4, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 5, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 6, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 7, 31, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 8, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051126015285, 9, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 1, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 2, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 3, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 4, 21, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 5, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 6, 17, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104015286, 7, 78, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 1, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 2, 37, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 3, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 4, 56, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 5, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 6, 148, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 7, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 8, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060108015287, 9, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 1, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 2, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 3, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 4, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 5, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 6, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 7, 31, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 8, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106015288, 9, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621015289, 1, 139, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621015289, 2, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621015289, 3, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621015289, 4, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010621015289, 5, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 1, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 2, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 3, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 4, 13, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 5, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 6, 15, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 7, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 8, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 9, 183, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 10, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 11, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 12, 23, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080614015290, 13, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 1, 56, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 2, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 3, 116, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 4, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 5, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 6, 170, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 7, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 8, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 9, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 10, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 11, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 12, 27, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403015291, 13, 169, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 1, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 2, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 3, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 4, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 5, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 6, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 7, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 8, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050125015292, 9, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 1, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 2, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 3, 14, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 4, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 5, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 6, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 7, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 8, 25, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 9, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 10, 70, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 11, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 12, 51, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 13, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121130015293, 14, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 1, 74, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 2, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 3, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 4, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 5, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 6, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 7, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 8, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 9, 160, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 10, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 11, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015294, 12, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 1, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 2, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 3, 73, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 4, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 5, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 6, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 7, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 8, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 9, 66, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 10, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 11, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 12, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 13, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 14, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 15, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015295, 16, 13, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 1, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 2, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 3, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 4, 29, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 5, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 6, 111, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 7, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 8, 135, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 9, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 10, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 11, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 12, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015296, 13, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 1, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 2, 4, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 3, 55, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 4, 173, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 5, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010506015297, 6, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903015298, 1, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903015298, 2, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903015298, 3, 166, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903015298, 4, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 1, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 2, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 3, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 4, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 5, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 6, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 7, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 8, 33, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 9, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 10, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 11, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080725015299, 12, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 1, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 2, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 3, 184, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 4, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 5, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 6, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 7, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526015300, 8, 78, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 1, 90, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 2, 183, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 3, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 4, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 5, 117, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 6, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 7, 189, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815015665, 8, 109, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 1, 129, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 2, 106, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 3, 171, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 4, 33, 67, 4, 268);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 5, 171, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 6, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 7, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 8, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 9, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 10, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 11, 116, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 12, 21, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080707015666, 13, 15, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 1, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 2, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 3, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 4, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 5, 152, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 6, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 7, 183, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 8, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714015667, 9, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 1, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 2, 164, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 3, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 4, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 5, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015668, 6, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 1, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 2, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 3, 96, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 4, 34, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 5, 178, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 6, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 7, 111, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 8, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 9, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 10, 98, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 11, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 12, 100, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 13, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 14, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 15, 12, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140426015669, 16, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 1, 88, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 2, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 3, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 4, 136, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 5, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010604015670, 6, 25, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 1, 65, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 2, 127, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 3, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 4, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 5, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 6, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 7, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040905015671, 8, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621015672, 1, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621015672, 2, 4, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621015672, 3, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621015672, 4, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000621015672, 5, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 1, 106, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 2, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 3, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 4, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 5, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 6, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 7, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 8, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 9, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 10, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 11, 141, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 12, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 13, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 14, 181, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 15, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126015673, 16, 51, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 1, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 2, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 3, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 4, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 5, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 6, 166, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 7, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 8, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041223015674, 9, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 1, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 2, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 3, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 4, 129, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 5, 17, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 6, 153, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 7, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 8, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 9, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061029015675, 10, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 1, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 2, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 3, 46, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 4, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 5, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031001015676, 6, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 1, 167, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 2, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 3, 30, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 4, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 5, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 6, 152, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 7, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 8, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 9, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 10, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 11, 11, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312015677, 12, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 1, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 2, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 3, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 4, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 5, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 6, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 7, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 8, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 9, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 10, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 11, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 12, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 13, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090514015678, 14, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 1, 45, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 2, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 3, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 4, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 5, 140, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 6, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 7, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 8, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 9, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015679, 10, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 1, 15, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 2, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 3, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 4, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 5, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 6, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 7, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 8, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 9, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 10, 42, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 11, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 12, 148, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 13, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 14, 179, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 15, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120531015680, 16, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 1, 45, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 2, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 3, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 4, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 5, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 6, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 7, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 8, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 9, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 10, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 11, 140, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 12, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 13, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 14, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 15, 33, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 16, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015681, 17, 6, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 1, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 2, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 3, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 4, 144, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 5, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 6, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 7, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 8, 25, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 9, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 10, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 11, 162, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 12, 181, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 13, 85, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223015682, 14, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015683, 1, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015683, 2, 49, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015683, 3, 174, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015683, 4, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 1, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 2, 29, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 3, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 4, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 5, 90, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 6, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 7, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 8, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 9, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 10, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909015684, 11, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 1, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 2, 172, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 3, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 4, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 5, 129, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 6, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 7, 30, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 8, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 9, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 10, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 11, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 12, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 13, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 14, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110613015685, 15, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 1, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 2, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 3, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 4, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 5, 113, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 6, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 7, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 8, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 9, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 10, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 11, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 12, 143, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 13, 158, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 14, 103, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130727015686, 15, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 1, 137, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 2, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 3, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 2, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 3, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 4, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 5, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 6, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 7, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 8, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 9, 49, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 10, 79, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 11, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 12, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 13, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 14, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110522016093, 15, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 1, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 2, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 3, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 4, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 5, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 6, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 7, 93, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 8, 69, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 9, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 10, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 11, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 12, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090214016094, 13, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 1, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 2, 165, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 3, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 4, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 5, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020916016095, 6, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 1, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 2, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 3, 190, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 4, 132, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 5, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 6, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 7, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 8, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 9, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 10, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315016096, 11, 115, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212016097, 1, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001212016097, 2, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 1, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 2, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 3, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 4, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 5, 48, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 6, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 7, 120, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 8, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071112016098, 9, 25, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112016099, 1, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112016099, 2, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112016099, 3, 188, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112016099, 4, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021112016099, 5, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 1, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 2, 128, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 3, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 4, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 5, 55, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 6, 155, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 7, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 8, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 9, 24, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 10, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 11, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 12, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 13, 10, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 14, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100421016100, 15, 172, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 1, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 2, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 3, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 4, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 5, 48, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 6, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 7, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 8, 96, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 9, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705016101, 10, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125016102, 1, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001125016102, 2, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 1, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 2, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 3, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 4, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 5, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 6, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 7, 133, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 8, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050328016103, 9, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 1, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 2, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 3, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 4, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 5, 63, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 6, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 7, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 8, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 9, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 10, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 11, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 12, 11, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 13, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 14, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 15, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110806016104, 16, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 1, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 2, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 3, 13, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 4, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 5, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 6, 90, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 7, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 8, 146, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 9, 156, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 10, 8, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 11, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 12, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016105, 13, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118016106, 1, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118016106, 2, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118016106, 3, 8, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725016107, 1, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000725016107, 2, 34, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 1, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 2, 156, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 3, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 4, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 5, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 6, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 7, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 8, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 9, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 10, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 11, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 12, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 13, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 14, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 15, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 16, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 17, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016108, 18, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 1, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 2, 151, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 3, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 4, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 5, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 6, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 7, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 8, 79, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 9, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 10, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 11, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 12, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 13, 174, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 14, 151, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016109, 15, 86, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 1, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 2, 44, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 3, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 4, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 5, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 6, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 7, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 8, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040201016110, 9, 63, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 1, 14, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 2, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 3, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 4, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 5, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 6, 39, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 7, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 8, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 9, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 10, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 11, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 12, 27, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 13, 140, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 14, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 15, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 16, 113, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130522016111, 17, 94, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421016112, 1, 150, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421016112, 2, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421016112, 3, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010421016112, 4, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 1, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 2, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 3, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 4, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 5, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 6, 176, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 7, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 8, 8, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 9, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 10, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016113, 11, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 1, 50, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 2, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 3, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 4, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 5, 179, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 6, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 7, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 8, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041227016114, 9, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 1, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 2, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 3, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 4, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 5, 11, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 6, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 7, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 8, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 9, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 10, 98, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070626016115, 11, 126, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 1, 125, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 2, 59, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 3, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 4, 33, 83, 4, 332);
commit;
prompt 156000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 5, 87, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 6, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 7, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 8, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071205016116, 9, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209016117, 1, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209016117, 2, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000209016117, 3, 168, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 1, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 2, 5, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 3, 188, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315014898, 7, 149, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014899, 1, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014899, 2, 175, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014899, 3, 172, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014899, 4, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011124014899, 5, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 1, 184, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 2, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 3, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 4, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 5, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 6, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 7, 130, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510014900, 8, 27, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 1, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 2, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 3, 37, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 4, 95, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 5, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 6, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 7, 12, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 8, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 9, 28, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 10, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 11, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090520014901, 12, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 1, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 2, 4, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 3, 104, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 4, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 5, 69, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 6, 73, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 7, 85, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 8, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520014902, 9, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 1, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 2, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 3, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 4, 43, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 5, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 6, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 7, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 8, 173, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 9, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 10, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 11, 180, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 12, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 13, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 14, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121112014903, 15, 114, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 1, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 2, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 3, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 4, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 5, 61, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 6, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 7, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 8, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 9, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050730014904, 10, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 1, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 2, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 3, 47, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 4, 35, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 5, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 6, 86, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 7, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051117014905, 8, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 1, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 2, 54, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 3, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 4, 41, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 5, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 6, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 7, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 8, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061021014906, 9, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 1, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 2, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 3, 7, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 4, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 5, 58, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 6, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 7, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 8, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070913014907, 9, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 1, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 2, 13, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 3, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 4, 22, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 5, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 6, 149, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 7, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 8, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 9, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070127014908, 10, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 1, 129, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 2, 4, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 3, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 4, 17, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 5, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 6, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 7, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 8, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 9, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 10, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 11, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 12, 117, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 13, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202014909, 14, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 1, 141, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 2, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 3, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 4, 95, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 5, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 6, 83, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 7, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 8, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 9, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 10, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 11, 29, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 12, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 13, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 14, 156, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 15, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302014910, 16, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731014911, 1, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731014911, 2, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731014911, 3, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010731014911, 4, 103, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 1, 104, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 2, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 3, 126, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 4, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 5, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 6, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 7, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 8, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303014912, 9, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 1, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 2, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 3, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 4, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 5, 152, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 6, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 7, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 8, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805014913, 9, 55, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 1, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 2, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 3, 45, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 4, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 5, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 6, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 7, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 8, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050627014914, 9, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 1, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 2, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 3, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 4, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 5, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 6, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040903014915, 7, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 1, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 2, 185, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 3, 168, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 4, 80, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 5, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 6, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 7, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 8, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 9, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070504014916, 10, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 1, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 2, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 3, 76, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 4, 47, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 5, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 6, 57, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 7, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 8, 80, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 9, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 10, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 11, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 12, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090129014917, 13, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 1, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 2, 81, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 3, 67, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 4, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 5, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020116014918, 6, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 1, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 2, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 3, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 4, 185, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 5, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 6, 90, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 7, 22, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 8, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 9, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 10, 39, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 11, 123, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 12, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 13, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 14, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 15, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 16, 98, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130107014919, 17, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 1, 192, 85, 18, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 2, 170, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 3, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 4, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 5, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 6, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041105014920, 7, 104, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 1, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 2, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 3, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 4, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 5, 129, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 6, 107, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 7, 52, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 8, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 9, 191, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 10, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 11, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 12, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 13, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100512014921, 14, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 1, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 2, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 3, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 4, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 5, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 6, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 7, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 8, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 5, 26, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 6, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 7, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 8, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 9, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 10, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 11, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 12, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 13, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 14, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423015301, 15, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 1, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 2, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 3, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 4, 112, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 5, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808015302, 6, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 1, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 2, 55, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 3, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 4, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 5, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 6, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 7, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041025015303, 8, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322015304, 1, 43, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322015304, 2, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322015304, 3, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322015304, 4, 19, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322015304, 5, 27, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 1, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 2, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 3, 99, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 4, 63, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 5, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 6, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 7, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 8, 41, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 9, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 10, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 11, 18, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 12, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100807015305, 13, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 1, 182, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 2, 90, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 3, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 4, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 5, 107, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020330015306, 6, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 1, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 2, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 3, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 4, 178, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 5, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 6, 19, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 7, 26, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 8, 53, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 9, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 10, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 11, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716015307, 12, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106015308, 1, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106015308, 2, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106015308, 3, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010106015308, 4, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015309, 1, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015309, 2, 153, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015309, 3, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015309, 4, 15, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 1, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 2, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 3, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 4, 75, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 5, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 6, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 7, 155, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 8, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015310, 9, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 1, 85, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 2, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 3, 134, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 4, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 5, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 6, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 7, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040929015311, 8, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 1, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 2, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 3, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 4, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 5, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040430015312, 6, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 1, 192, 47, 18, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 2, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 3, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 4, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 5, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 6, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 7, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 8, 107, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 9, 70, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 10, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 11, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 12, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226015313, 13, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 1, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 2, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 3, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 4, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 5, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010216015314, 6, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 1, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 2, 18, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 3, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 4, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 5, 98, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 6, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 7, 20, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 8, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 9, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 10, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 11, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015315, 12, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015316, 1, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015316, 2, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015316, 3, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015316, 4, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 1, 78, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 2, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 3, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 4, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 5, 123, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 6, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 7, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 8, 12, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 9, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015317, 10, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206015318, 1, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206015318, 2, 50, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206015318, 3, 72, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206015318, 4, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021206015318, 5, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831015319, 1, 78, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831015319, 2, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831015319, 3, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 1, 7, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 2, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 3, 138, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 4, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 5, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 6, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 7, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 8, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 9, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 10, 127, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 11, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090614015320, 12, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 1, 180, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 2, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 3, 178, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 4, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 5, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 6, 46, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 7, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 8, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 9, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 10, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 11, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080401015321, 12, 49, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 1, 104, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 2, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 3, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 4, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 5, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 6, 123, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 7, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 8, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 9, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 10, 168, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 11, 151, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 12, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 13, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 14, 136, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110112015322, 15, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122015323, 1, 35, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122015323, 2, 138, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122015323, 3, 99, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122015323, 4, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031122015323, 5, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 1, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 2, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 3, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 4, 8, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 5, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 6, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 7, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 8, 181, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 9, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 10, 186, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 11, 186, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 12, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 13, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100310015324, 14, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 1, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 2, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 3, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 4, 41, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 5, 28, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 6, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 7, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 8, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 9, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060621015325, 10, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 1, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 2, 115, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 3, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 4, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 5, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 6, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 7, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101015326, 8, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 1, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 2, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 3, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 4, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 5, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 6, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 7, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 8, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 9, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070519015327, 10, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 1, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 2, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 3, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 4, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 5, 170, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 6, 158, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041206015328, 7, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814015329, 1, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 4, 124, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 5, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 6, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 7, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 8, 153, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 9, 74, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 10, 172, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 11, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 12, 47, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 13, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090106015687, 14, 81, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 1, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 2, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 3, 52, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 4, 67, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 5, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 6, 107, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 7, 11, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 8, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 9, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071105015688, 10, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609015689, 1, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609015689, 2, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609015689, 3, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609015689, 4, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822015690, 1, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822015690, 2, 14, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822015690, 3, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010822015690, 4, 122, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 1, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 2, 109, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 3, 79, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 4, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 5, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 6, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 7, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116015691, 8, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 1, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 2, 185, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 3, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 4, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 5, 44, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 6, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 7, 9, 51, 4, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 8, 54, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 9, 186, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 10, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 11, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 12, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 13, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 14, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 15, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110512015692, 16, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 1, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 2, 62, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 3, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 4, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 5, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 6, 35, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 7, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 8, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 9, 96, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 10, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 11, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 12, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 13, 36, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 14, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 15, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131130015693, 16, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928015694, 1, 37, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928015694, 2, 54, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928015694, 3, 73, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000928015694, 4, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 1, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 2, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 3, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 4, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 5, 16, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 6, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 7, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 8, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 9, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 10, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 11, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 12, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 13, 157, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 14, 167, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 15, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 16, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 17, 81, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130501015695, 18, 46, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023015696, 1, 133, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023015696, 2, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023015696, 3, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023015696, 4, 59, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023015696, 5, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 1, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 2, 51, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 3, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 4, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 5, 96, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 6, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 7, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 8, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 9, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 10, 20, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 11, 168, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081214015697, 12, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 1, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 2, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 3, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 4, 128, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 5, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 6, 56, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 7, 107, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 8, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 9, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 10, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408015698, 11, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 1, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 2, 66, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 3, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 4, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 5, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 6, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 7, 39, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 8, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 9, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 10, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070301015699, 11, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000229015700, 1, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000229015700, 2, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 1, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 2, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 3, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 4, 144, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 5, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 6, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 7, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 8, 83, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 9, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 10, 74, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080111015701, 11, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 1, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 2, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 3, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 4, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 5, 169, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 6, 150, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 7, 36, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 8, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 9, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 10, 119, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 11, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 12, 175, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 13, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 14, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 15, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 16, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140101015702, 17, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 1, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 2, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 3, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 4, 121, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 5, 6, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 6, 100, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 7, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 8, 25, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 9, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 10, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 11, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 12, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 13, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 14, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110920015703, 15, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 1, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 2, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 3, 171, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 4, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 5, 105, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 6, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218015704, 7, 130, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 1, 108, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 2, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 3, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 4, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 5, 176, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 6, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 7, 119, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040507015705, 8, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419015706, 1, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419015706, 2, 190, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419015706, 3, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 1, 70, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 2, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 3, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 4, 91, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 5, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 6, 17, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 7, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 8, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 9, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 10, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 11, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 12, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725015707, 13, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127015708, 1, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127015708, 2, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127015708, 3, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127015708, 4, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 1, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 2, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 3, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 4, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 5, 169, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 6, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040106015709, 7, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 1, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 2, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 3, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 4, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 5, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 6, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 7, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 8, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 9, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 10, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 11, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081225015710, 12, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 1, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 2, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 3, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 4, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 5, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 6, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 7, 141, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 8, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 9, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 10, 174, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 8, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 9, 135, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 10, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 11, 41, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015997, 12, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 1, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 2, 98, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 3, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 4, 128, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 5, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 6, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 7, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040121015998, 8, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 1, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 2, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 3, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 4, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 5, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 6, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 7, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 8, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 9, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 10, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 11, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 12, 105, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 13, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 14, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 15, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 16, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120113015999, 17, 15, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 1, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 2, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 3, 13, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 4, 20, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 5, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 6, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 7, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 8, 139, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 9, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 10, 5, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 11, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 12, 12, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111121016000, 13, 12, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 1, 184, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 2, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 3, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 4, 180, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 5, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 6, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 7, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 8, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041203016001, 9, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425016002, 1, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425016002, 2, 106, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010425016002, 3, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 1, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 2, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 3, 162, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 4, 14, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 5, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 6, 143, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 7, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 8, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 9, 64, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 10, 79, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 11, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 12, 190, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 13, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 14, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 15, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 16, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111016003, 17, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 1, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 2, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 3, 4, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 4, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 5, 169, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 6, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 7, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 8, 136, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070130016004, 9, 163, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 1, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 2, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 3, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 4, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 5, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 6, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 7, 63, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 8, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 9, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 10, 40, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080523016005, 11, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 1, 1, 82, 3, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 2, 17, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 3, 142, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 4, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 5, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 6, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016006, 7, 128, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 1, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 2, 64, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 3, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 4, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 5, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 6, 37, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 7, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 8, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 9, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 10, 77, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 11, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100402016007, 12, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103016008, 1, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103016008, 2, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103016008, 3, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103016008, 4, 45, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020103016008, 5, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 1, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 2, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 3, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 4, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 5, 191, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 6, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 7, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 8, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 9, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 10, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016009, 11, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 1, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 2, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 3, 32, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 4, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 5, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020424016010, 6, 187, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 1, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 2, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 3, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 4, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 5, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 6, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 7, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 8, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 9, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016011, 10, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713016012, 1, 134, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713016012, 2, 61, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713016012, 3, 60, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713016012, 4, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 1, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 2, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 3, 38, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 4, 89, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 5, 70, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 6, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 7, 111, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031219016013, 8, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 1, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 2, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 3, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 4, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 5, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 6, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 7, 170, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 8, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040408016014, 9, 155, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 1, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 2, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 3, 63, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 4, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 5, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 6, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 7, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 8, 79, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 9, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 10, 99, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013016015, 11, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 1, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 2, 5, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 3, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 4, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 5, 1, 62, 3, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 6, 77, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 7, 5, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712016016, 8, 22, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 1, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 2, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 3, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 4, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 5, 50, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 6, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 7, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 8, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 9, 73, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 10, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 11, 55, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 12, 120, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 13, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 14, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100319016017, 15, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 1, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 2, 36, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 3, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 4, 68, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 5, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 6, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 7, 159, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 8, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 9, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 10, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 11, 77, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 12, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 13, 106, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090124016018, 14, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 1, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 2, 164, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 3, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 4, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 5, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104016019, 6, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 1, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 2, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 3, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 4, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 5, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 6, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 7, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 8, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 9, 125, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 10, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 11, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 12, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 13, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 14, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 15, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111011016020, 16, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 1, 39, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 2, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 3, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 4, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016021, 5, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 9, 141, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 10, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 11, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 12, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 13, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208014922, 14, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 1, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 2, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 3, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 4, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 5, 91, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 6, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020923014923, 7, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 1, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 2, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 3, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 4, 95, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 5, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 6, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 7, 145, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 8, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 9, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 10, 87, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080413014924, 11, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710014925, 1, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710014925, 2, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710014925, 3, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710014925, 4, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010710014925, 5, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 1, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 2, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 3, 4, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 4, 53, 54, 10, 540);
commit;
prompt 157000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 5, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 6, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 7, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 8, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 9, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 10, 165, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 11, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 12, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 13, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 14, 184, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 15, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 16, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 17, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414014926, 18, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 1, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 2, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 3, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 4, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 5, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030721014927, 6, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 1, 41, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 2, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 3, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 4, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 5, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 6, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 7, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 8, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 9, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 10, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 11, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 12, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 13, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 14, 41, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 15, 1, 98, 3, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 16, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 17, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630014928, 18, 89, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 1, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 2, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 3, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 4, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 5, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 6, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 7, 125, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 8, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 9, 120, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 10, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216014929, 11, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 1, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 2, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 3, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 4, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 5, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010101014930, 6, 159, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028014931, 1, 68, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028014931, 2, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028014931, 3, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028014931, 4, 146, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028014931, 5, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 1, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 2, 32, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 3, 183, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 4, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 5, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 6, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 7, 65, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 8, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 9, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301014932, 10, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 1, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 2, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 3, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 4, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 5, 190, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 6, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 7, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 8, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 9, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 10, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 11, 2, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 12, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 13, 131, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 14, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100913014933, 15, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014934, 1, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014934, 2, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014934, 3, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208014934, 4, 149, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 1, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 2, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 3, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 4, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 5, 137, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 6, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 7, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 8, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 9, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 10, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 11, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 12, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 13, 42, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 14, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 15, 77, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 16, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120216014935, 17, 117, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 1, 59, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 2, 150, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 3, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 4, 40, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 5, 13, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 6, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 7, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 8, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 9, 90, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 10, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 11, 164, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 12, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 13, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 14, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 15, 124, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802014936, 16, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 1, 168, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 2, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 3, 11, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 4, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 5, 149, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 6, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 7, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 8, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 9, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202014937, 10, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 1, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 2, 192, 100, 18, 1800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 3, 46, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 4, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 5, 43, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 6, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 7, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 8, 160, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 9, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 10, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 11, 101, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 12, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417014938, 13, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 1, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 2, 85, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 3, 11, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 4, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 5, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 6, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 7, 18, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207014939, 8, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609014940, 1, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609014940, 2, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609014940, 3, 53, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609014940, 4, 42, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 1, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 2, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 3, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 4, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 5, 113, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408014941, 6, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 1, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 2, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 3, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 4, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 5, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 6, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 7, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050415014942, 8, 90, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 1, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 2, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 3, 127, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 4, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 5, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 6, 27, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 7, 163, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 8, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 9, 47, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 10, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 11, 140, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 12, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 13, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 14, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 15, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130222014943, 16, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922014944, 1, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922014944, 2, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922014944, 3, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020922014944, 4, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 1, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 2, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 3, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 4, 92, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 5, 176, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 6, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 7, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 8, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 9, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 10, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070124014945, 11, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 1, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 2, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 3, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 4, 162, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000814015329, 2, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 1, 63, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 2, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 3, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 4, 147, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 5, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 6, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041006015330, 7, 155, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 1, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 2, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 3, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 4, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 5, 100, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 6, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 7, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 8, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 9, 113, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 10, 113, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 11, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 12, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 13, 178, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 14, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 15, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 16, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120112015331, 17, 171, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 1, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 2, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 3, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 4, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 5, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 6, 1, 45, 3, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213015332, 7, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 1, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 2, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 3, 65, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 4, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 5, 172, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 6, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 7, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 8, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 9, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 10, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 11, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 12, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 13, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 14, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 15, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 16, 119, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 17, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323015333, 18, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 1, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 2, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 3, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 4, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 5, 74, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 6, 103, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 7, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 8, 147, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 9, 23, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061227015334, 10, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015335, 1, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015335, 2, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015335, 3, 162, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015335, 4, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000501015335, 5, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016015336, 1, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016015336, 2, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016015336, 3, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016015336, 4, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031016015336, 5, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 1, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 2, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 3, 27, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 4, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 5, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 6, 28, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 7, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030308015337, 8, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223015338, 1, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223015338, 2, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000223015338, 3, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 1, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 2, 81, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 3, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 4, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 5, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 6, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 7, 189, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 8, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 9, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 10, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 11, 182, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 12, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 13, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 14, 132, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 15, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419015339, 16, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816015340, 1, 70, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816015340, 2, 57, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816015340, 3, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020816015340, 4, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 1, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 2, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 3, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 4, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 5, 21, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 6, 188, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 7, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 8, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 9, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 10, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 11, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080126015341, 12, 30, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 1, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 2, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 3, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 4, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 5, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 6, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 7, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 8, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 9, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 10, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 11, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 12, 179, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 13, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110120015342, 14, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 1, 108, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 2, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 3, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 4, 81, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 5, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030815015343, 6, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 1, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 2, 111, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 3, 96, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 4, 62, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 5, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 6, 168, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 7, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 8, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 9, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 10, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 11, 31, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 12, 153, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 13, 141, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 14, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321015344, 15, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015345, 1, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000702015345, 2, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 1, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 2, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 3, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 4, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 5, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 6, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 7, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 8, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 9, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070831015346, 10, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122015347, 1, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122015347, 2, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122015347, 3, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122015347, 4, 78, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 1, 60, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 2, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 3, 102, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 4, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 5, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 6, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 7, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 8, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 9, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 10, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070919015348, 11, 135, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 1, 134, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 2, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 3, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 4, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 5, 170, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 6, 95, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 7, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 8, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 9, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 10, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 11, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101010015349, 12, 168, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 1, 89, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 2, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 3, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 4, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 5, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 6, 183, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 7, 187, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 8, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 9, 66, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 10, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 11, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080513015350, 12, 183, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 1, 40, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 2, 174, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 3, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 4, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 5, 91, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 6, 104, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 7, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 8, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 9, 34, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 10, 77, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 11, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 12, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 13, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 14, 76, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 15, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 16, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514015351, 17, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 1, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 2, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 3, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 4, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 5, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 6, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040416015352, 7, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 1, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 2, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 3, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 4, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 5, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 6, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 7, 132, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 8, 167, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 9, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 10, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 11, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 12, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 13, 20, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 14, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100228015353, 15, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 1, 12, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 11, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 12, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 13, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 14, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 15, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121009015711, 16, 149, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907015712, 1, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907015712, 2, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907015712, 3, 63, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010907015712, 4, 155, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516015713, 1, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516015713, 2, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516015713, 3, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516015713, 4, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030516015713, 5, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 1, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 2, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 3, 126, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 4, 35, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 5, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 6, 164, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 7, 73, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 8, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629015714, 9, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 1, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 2, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 3, 1, 11, 3, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 4, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 5, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 6, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 7, 56, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 8, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 9, 173, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 10, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 11, 12, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015715, 12, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 1, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 2, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 3, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 4, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 5, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 6, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 7, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 8, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 9, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080224015716, 10, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714015717, 1, 25, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714015717, 2, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714015717, 3, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 1, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 2, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 3, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 4, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 5, 130, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 6, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 7, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 8, 37, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061013015718, 9, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 1, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 2, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 3, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 4, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 5, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 6, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 7, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 8, 101, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 9, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 10, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 11, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 12, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123015719, 13, 64, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 1, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 2, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 3, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 4, 67, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 5, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 6, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523015720, 7, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 1, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 2, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 3, 135, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 4, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 5, 124, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 6, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 7, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 8, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 9, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 10, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 11, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 12, 49, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 13, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 14, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 15, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130530015721, 16, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 1, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 2, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 3, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 4, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 5, 146, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 6, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 7, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 8, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 9, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 10, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 11, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 12, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 13, 182, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212015722, 14, 78, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 1, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 2, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 3, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 4, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 5, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015723, 6, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 1, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 2, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 3, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 4, 167, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 5, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 6, 11, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 7, 147, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 8, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 9, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 10, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 11, 63, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 12, 144, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 13, 36, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 14, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 15, 141, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120809015724, 16, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 1, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 2, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 3, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 4, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 5, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 6, 101, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 7, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061103015725, 8, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 1, 100, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 2, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 3, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 4, 186, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 5, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 6, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 7, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 8, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 9, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 10, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070522015726, 11, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 1, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 2, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 3, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 4, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 5, 149, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 6, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 7, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 8, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 9, 37, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 10, 55, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 11, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 12, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 13, 68, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 14, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823015727, 15, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 1, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 2, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 3, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 4, 107, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 5, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 6, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 7, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 8, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 9, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 10, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 11, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 12, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 13, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 14, 183, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317015728, 15, 66, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118015729, 1, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118015729, 2, 108, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118015729, 3, 134, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118015729, 4, 95, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 1, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 2, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 3, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 4, 148, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 5, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 6, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117015730, 7, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 1, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 2, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 3, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 4, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 5, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 6, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 7, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 8, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 9, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 10, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 11, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 12, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 13, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100108015731, 14, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 1, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 2, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 3, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 4, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 5, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 6, 91, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 7, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 8, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 9, 35, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704015732, 10, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801015733, 1, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801015733, 2, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010801015733, 3, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 1, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 2, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 3, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 4, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 5, 11, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 6, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 7, 128, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 8, 44, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 9, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 10, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 11, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 12, 35, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091017015734, 13, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 1, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 2, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 3, 93, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 4, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 5, 17, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 6, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 7, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 8, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 9, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 6, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 7, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 8, 93, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 9, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 10, 52, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 11, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 12, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 13, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 14, 154, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 15, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 16, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131022016044, 17, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 1, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 2, 160, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 3, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 4, 183, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 5, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020129016045, 6, 64, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 1, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 2, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 3, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 4, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 5, 186, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 6, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 7, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 8, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050517016046, 9, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 1, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 2, 39, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 3, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 4, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 5, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 6, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 7, 63, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 8, 143, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 9, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 10, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 11, 135, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 12, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 13, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 14, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016047, 15, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320016048, 1, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320016048, 2, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320016048, 3, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320016048, 4, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 1, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 2, 114, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 3, 144, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 4, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 5, 42, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 6, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 7, 96, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 8, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 9, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081028016049, 10, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 1, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 2, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 3, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 4, 47, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 5, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 6, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 7, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 8, 57, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 9, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 10, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070303016050, 11, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 1, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 2, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 3, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 4, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 5, 11, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 6, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 7, 66, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 8, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 9, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 10, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 11, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 12, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016051, 13, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 1, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 2, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 3, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 4, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 5, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 6, 26, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 7, 167, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 8, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 9, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 10, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 11, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 12, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110621016052, 13, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016053, 1, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016053, 2, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016053, 3, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016053, 4, 25, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 1, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 2, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 3, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 4, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 5, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 6, 13, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030811016054, 7, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727016055, 1, 19, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727016055, 2, 29, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727016055, 3, 135, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000320016056, 1, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000320016056, 2, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000320016056, 3, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622016057, 1, 49, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622016057, 2, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622016057, 3, 12, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000622016057, 4, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 1, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 2, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 3, 140, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 4, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 5, 88, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 6, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 7, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 8, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 9, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 10, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 11, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 12, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 13, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 14, 177, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 15, 192, 44, 18, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121230016058, 16, 157, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 1, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 2, 41, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 3, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 4, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 5, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 6, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 7, 64, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 8, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 9, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 10, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 11, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 12, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 13, 70, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110426016059, 14, 47, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311016060, 1, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311016060, 2, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010311016060, 3, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 1, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 2, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 3, 68, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 4, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 5, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 6, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 7, 181, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 8, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 9, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 10, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 11, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 12, 136, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 13, 17, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 14, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120524016061, 15, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308016062, 1, 44, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308016062, 2, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000308016062, 3, 137, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 1, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 2, 22, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 3, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 4, 107, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 5, 20, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 6, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 7, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 8, 61, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 9, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 10, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 11, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070803016063, 12, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 1, 169, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 2, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 3, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 4, 183, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 5, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521016064, 6, 83, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 1, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 2, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 3, 191, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 4, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 5, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 6, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 7, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 8, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 9, 47, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016065, 10, 13, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 1, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 2, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 3, 186, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 4, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 5, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 6, 145, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 7, 36, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 8, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050326016066, 9, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 1, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 2, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 3, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 4, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 5, 134, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 6, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 7, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 8, 114, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 9, 22, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 10, 159, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 11, 97, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016067, 12, 187, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 1, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 2, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 3, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 4, 78, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 5, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021004016068, 6, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 1, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 2, 2, 16, 4, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 3, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 4, 135, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 5, 141, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 6, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 7, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 8, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 9, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 10, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 11, 38, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 12, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 13, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 14, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016069, 15, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 1, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 2, 58, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 3, 168, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030714016070, 4, 20, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 5, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 6, 129, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 7, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 8, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 9, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 10, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 11, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 12, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 13, 92, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 14, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 15, 40, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 16, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906014946, 17, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 1, 68, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 2, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 3, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 4, 41, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 5, 14, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 6, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 7, 67, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 8, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 9, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 10, 181, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 11, 10, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 12, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 13, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 14, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 15, 161, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110525014947, 16, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 1, 105, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 2, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 3, 135, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 4, 136, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 5, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 6, 93, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 7, 83, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 8, 114, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 9, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 10, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 11, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524014948, 12, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 1, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 2, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 3, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 4, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 5, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021111014949, 6, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 1, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 2, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 3, 186, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 4, 103, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 5, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 6, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 7, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 8, 39, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 9, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071119014950, 10, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 1, 53, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 2, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 3, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 4, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 5, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 6, 50, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 7, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 8, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209014951, 9, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 1, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 2, 173, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 3, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 4, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 5, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 6, 1, 71, 3, 213);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 7, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 8, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041005014952, 9, 46, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401014953, 1, 140, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401014953, 2, 27, 69, 8, 552);
commit;
prompt 158000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401014953, 3, 155, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401014953, 4, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401014953, 5, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 1, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 2, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 3, 177, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 4, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 5, 138, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 6, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 7, 72, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 8, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 9, 32, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 10, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804014954, 11, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 1, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 2, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 3, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 4, 2, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 5, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 6, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 7, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 8, 106, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 9, 98, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 10, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 11, 129, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 12, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 13, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 14, 52, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627014955, 15, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014956, 1, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014956, 2, 175, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014956, 3, 172, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020123014956, 4, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 1, 75, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 2, 109, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 3, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 4, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 5, 101, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 6, 60, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 7, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 8, 29, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 9, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 10, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 11, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 12, 86, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 13, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110409014957, 14, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 1, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 2, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 3, 5, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 4, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 5, 61, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010627014958, 6, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111014959, 1, 47, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111014959, 2, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111014959, 3, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111014959, 4, 62, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020111014959, 5, 40, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 1, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 2, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 3, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 4, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 5, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 6, 163, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021118014960, 7, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 1, 154, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 2, 118, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 3, 30, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 4, 162, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 5, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 6, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 7, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 8, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 9, 112, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 10, 24, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 11, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 12, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 13, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 14, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 15, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 16, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 17, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140427014961, 18, 49, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 1, 168, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 2, 120, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 3, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 4, 65, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 5, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 6, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030104014962, 7, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 1, 118, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 2, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 3, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 4, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 5, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 6, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 7, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 8, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 9, 19, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 10, 188, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 11, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 12, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 13, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 14, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121218014963, 15, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 1, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 2, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 3, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 4, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 5, 178, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 6, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 7, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 8, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 9, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217014964, 10, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 1, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 2, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 3, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 4, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 5, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 6, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 7, 121, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030826014965, 8, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 1, 26, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 2, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 3, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 4, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 5, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 6, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 7, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226014966, 8, 32, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 1, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 2, 26, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 3, 134, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 4, 140, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 5, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 6, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 7, 10, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 8, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 9, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 10, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 11, 70, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090503014967, 12, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 1, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 2, 177, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 3, 4, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 4, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 5, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 6, 42, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 7, 134, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 8, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 9, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 10, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014968, 11, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 1, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 2, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 3, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 4, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 5, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 6, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 7, 102, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 2, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 3, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 4, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 5, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 6, 114, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 7, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040412015354, 8, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 1, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 2, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 3, 128, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 4, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 5, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 6, 108, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 7, 80, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211015355, 8, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 1, 19, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 2, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 3, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 4, 182, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 5, 88, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 6, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 7, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 8, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 9, 152, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 10, 124, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 11, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 12, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 13, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111109015356, 14, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 1, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 2, 3, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 3, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 4, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 5, 10, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 6, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 7, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 8, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 9, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 10, 60, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 11, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 12, 96, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 13, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 14, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816015357, 15, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 1, 18, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 2, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 3, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 4, 5, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 5, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 6, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 7, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 8, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 9, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 10, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 11, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 12, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 13, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120818015358, 14, 140, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 1, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 2, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 3, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 4, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 5, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 6, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 7, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 8, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 9, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015359, 10, 169, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324015360, 1, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324015360, 2, 187, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324015360, 3, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000324015360, 4, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 1, 129, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 2, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 3, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 4, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 5, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 6, 34, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 7, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 8, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 9, 44, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081113015361, 10, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 1, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 2, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 3, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 4, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 5, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 6, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 7, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 8, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050207015362, 9, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 1, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 2, 166, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 3, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 4, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 5, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 6, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 7, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 8, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 9, 11, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 10, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 11, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 12, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 13, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 14, 54, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101016015363, 15, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 1, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 2, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 3, 7, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 4, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 5, 182, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 6, 144, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 7, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 8, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 9, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 10, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 11, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 12, 28, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 13, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 14, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 15, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 16, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602015364, 17, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 1, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 2, 107, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 3, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 4, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 5, 41, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021127015365, 6, 170, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 1, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 2, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 3, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 4, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 5, 187, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 6, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 7, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 8, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 9, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 10, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026015366, 11, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 1, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 2, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 3, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 4, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 5, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 6, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221015367, 7, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 1, 65, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 2, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 3, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 4, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 5, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 6, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 7, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030426015368, 8, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 1, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 2, 186, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 3, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 4, 56, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 5, 58, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 6, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504015369, 7, 174, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 1, 84, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 2, 162, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 3, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 4, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 5, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 6, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 7, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 8, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 9, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 10, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 11, 107, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 12, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 13, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 14, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 15, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703015370, 16, 137, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 1, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 2, 171, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 3, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 4, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 5, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 6, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 7, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 8, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 9, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 10, 106, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129015371, 11, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 1, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 2, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 3, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 4, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 5, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010324015372, 6, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505015373, 1, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505015373, 2, 105, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505015373, 3, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000505015373, 4, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 1, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 2, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 3, 183, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 4, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 5, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 6, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 7, 178, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040116015374, 8, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 1, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 2, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 3, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 4, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 5, 159, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726015375, 6, 186, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024015376, 1, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024015376, 2, 84, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024015376, 3, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021024015376, 4, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015377, 1, 67, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015377, 2, 120, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015377, 3, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015377, 4, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 1, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 2, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 3, 107, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 4, 100, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 5, 50, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 6, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 7, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 8, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051216015378, 9, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 1, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 2, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 3, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 4, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 5, 40, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 6, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 7, 144, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 8, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 9, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 10, 93, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 11, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 12, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 13, 69, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 14, 29, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 15, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 16, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027015735, 17, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 1, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 2, 118, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 3, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 4, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 5, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 6, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 7, 13, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 8, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 9, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 10, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 11, 137, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 12, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 13, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100514015736, 14, 135, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 1, 103, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 2, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 3, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 4, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 5, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 6, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 7, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 8, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 9, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060316015737, 10, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 1, 44, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 2, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 3, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 4, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 5, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 6, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 7, 92, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721015738, 8, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 1, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 2, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 3, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 4, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 5, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 6, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 7, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003015739, 8, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 1, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 2, 24, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 3, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 4, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 5, 23, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 6, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 7, 188, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060504015740, 8, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 1, 76, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 2, 97, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 3, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 4, 69, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 5, 103, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 6, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 7, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 8, 97, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 9, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923015741, 10, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 1, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 2, 76, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 3, 115, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 4, 81, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 5, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 6, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 7, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 8, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 9, 95, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 10, 174, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 11, 47, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 12, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090910015742, 13, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 1, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 2, 178, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 3, 141, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 4, 54, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 5, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 6, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 7, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 8, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 9, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 10, 67, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206015743, 11, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729015744, 1, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729015744, 2, 111, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010729015744, 3, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 1, 148, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 2, 67, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 3, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 4, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 5, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 6, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 7, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 8, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 9, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 10, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 11, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 12, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 13, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 14, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 15, 162, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 16, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 17, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015745, 18, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 1, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 2, 34, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 3, 100, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 4, 149, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 5, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 6, 71, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021201015746, 7, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 1, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 2, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 3, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 4, 182, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 5, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 6, 26, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 7, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 8, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050521015747, 9, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 1, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 2, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 3, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 4, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 5, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 6, 149, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 7, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 8, 124, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 9, 148, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 10, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 11, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 12, 157, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 13, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 14, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311015748, 15, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 1, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 2, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 3, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 4, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 5, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 6, 97, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040304015749, 7, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 1, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 2, 109, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 3, 50, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 4, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 5, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020722015750, 6, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 1, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 2, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 3, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 4, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 5, 130, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 6, 152, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 7, 142, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 8, 103, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019015751, 9, 180, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 1, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 2, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 3, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 4, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 5, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 6, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 7, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 8, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070418015752, 9, 87, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 1, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 2, 168, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 3, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 4, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 5, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 6, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 7, 1, 86, 3, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 8, 165, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 9, 135, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209015753, 10, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 2, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 3, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 4, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 5, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 6, 22, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015754, 7, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 1, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 2, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 3, 131, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 4, 156, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 5, 53, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 6, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 7, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 8, 1, 61, 3, 183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 9, 18, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 10, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 11, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 12, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 13, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 14, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505015755, 15, 109, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 1, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 2, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 3, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 4, 117, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 5, 55, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 6, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 7, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 8, 119, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 9, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 10, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 11, 131, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 12, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090221015756, 13, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 1, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 2, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 3, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 4, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 5, 46, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 6, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 7, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060606015757, 8, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 1, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 2, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 3, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 4, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 5, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 6, 162, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 7, 84, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 8, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 9, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 10, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 11, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 12, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 13, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 1, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 2, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 3, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 4, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 5, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 6, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 7, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206014615, 8, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 1, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 2, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 3, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 4, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 5, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 6, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 7, 179, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 8, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 9, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209014616, 10, 130, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 1, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 2, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 3, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 4, 132, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 5, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 6, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 7, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 8, 67, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 9, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 10, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 11, 82, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 12, 28, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 13, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 14, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 15, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 16, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 17, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140321014617, 18, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 1, 73, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 2, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 3, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 4, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 5, 96, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 6, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 7, 170, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 8, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 9, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 10, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 11, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 12, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090526014618, 13, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 1, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 2, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 3, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 4, 1, 73, 3, 219);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 5, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040428014619, 6, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 1, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 2, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 3, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 4, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 5, 100, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 6, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 7, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 8, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 9, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 10, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 11, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 12, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111123014620, 13, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 1, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 2, 5, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 3, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 4, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 5, 129, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 6, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 7, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 8, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 9, 74, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 10, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 11, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080819014621, 12, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 1, 94, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 2, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 3, 10, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 4, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 5, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 6, 77, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 7, 175, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 8, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 9, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 10, 32, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060106014622, 11, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 1, 183, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 2, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 3, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 4, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 5, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 6, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 7, 102, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 8, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 9, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 10, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 11, 46, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 12, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080226014623, 13, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 1, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 2, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 3, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 4, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 5, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 6, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 7, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050516014624, 8, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 1, 160, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 2, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 3, 130, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 4, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 5, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031227014625, 6, 88, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 1, 111, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 2, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 3, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 4, 176, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 5, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 6, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 7, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 8, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 9, 114, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 10, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 11, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 12, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 13, 126, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 14, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111008014626, 15, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 1, 169, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 2, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 3, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 4, 128, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 5, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 6, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 7, 163, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 8, 116, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 9, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 10, 71, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 11, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080326014627, 12, 174, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831014628, 1, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831014628, 2, 90, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831014628, 3, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831014628, 4, 93, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000831014628, 5, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 1, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 2, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 3, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 4, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 5, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 6, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 7, 178, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 8, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 9, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 10, 131, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 11, 31, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014629, 12, 168, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325014630, 1, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325014630, 2, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325014630, 3, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325014630, 4, 93, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030325014630, 5, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226014631, 1, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226014631, 2, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226014631, 3, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226014631, 4, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226014631, 5, 93, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 1, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 2, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 3, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 4, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 5, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021022014632, 6, 75, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 1, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 2, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 3, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 4, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 5, 148, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 6, 152, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 7, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 8, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 9, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522014633, 10, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023014634, 1, 14, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023014634, 2, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023014634, 3, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011023014634, 4, 31, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411014635, 1, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411014635, 2, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010411014635, 3, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 1, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 2, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 3, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 4, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 5, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 6, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 7, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 8, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 9, 191, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 10, 188, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 11, 154, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 12, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091221014636, 13, 129, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 1, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 2, 6, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 3, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 4, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 5, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 6, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 7, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 8, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 9, 153, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 10, 94, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 11, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 12, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 13, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 14, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 15, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013014637, 16, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 1, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 2, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 3, 20, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 4, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 5, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 6, 132, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 7, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 8, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 9, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 10, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 11, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 12, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 13, 131, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 14, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 15, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040527014969, 8, 12, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129014970, 1, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129014970, 2, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129014970, 3, 135, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129014970, 4, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031129014970, 5, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 1, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 2, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 3, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 4, 36, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 5, 139, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 6, 123, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 7, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 8, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 9, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 10, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 11, 122, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 12, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 13, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 14, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 15, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709014971, 16, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 1, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 2, 76, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 3, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 4, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 5, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 6, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 7, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 8, 132, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 9, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 10, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 11, 39, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 12, 77, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 13, 125, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100524014972, 14, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 1, 60, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 2, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 3, 3, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 4, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 5, 80, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 6, 80, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 7, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 8, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921014973, 9, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 1, 113, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 2, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 3, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 4, 170, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 5, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 6, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 7, 181, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 8, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 9, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 10, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 11, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 12, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 13, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 14, 128, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014974, 15, 97, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 1, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 2, 172, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 3, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 4, 60, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 5, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 6, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 7, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 8, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 9, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 10, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071215014975, 11, 68, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 1, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 2, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 3, 137, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 4, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 5, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 6, 34, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231014976, 7, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607014977, 1, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607014977, 2, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607014977, 3, 48, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607014977, 4, 88, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607014977, 5, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 1, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 2, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 3, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 4, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 5, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 6, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 7, 11, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 8, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 9, 100, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 10, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 11, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 12, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 13, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 14, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 15, 105, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716014978, 16, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 1, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 2, 173, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 3, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 4, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 5, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 6, 37, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 7, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 8, 98, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 9, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 10, 81, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 11, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 12, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 13, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116014979, 14, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 1, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 2, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 3, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 4, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 5, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 6, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 7, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 8, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 9, 9, 41, 4, 164);
commit;
prompt 159000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 10, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 11, 153, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 12, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 13, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 14, 189, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 15, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130921014980, 16, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 1, 192, 43, 18, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 2, 108, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 3, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 4, 192, 76, 18, 1368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 5, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 6, 140, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 7, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 8, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 9, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 10, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126014981, 11, 103, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601014982, 1, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601014982, 2, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601014982, 3, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000601014982, 4, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 1, 111, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 2, 29, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 3, 92, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 4, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 5, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 6, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010014983, 7, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224014984, 1, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224014984, 2, 172, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224014984, 3, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224014984, 4, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 1, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 2, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 3, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 4, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 5, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 6, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 7, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 8, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 9, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 10, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 11, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 12, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 13, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 14, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130717014985, 15, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 1, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 2, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 3, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 4, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 5, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121014986, 6, 178, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 1, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 2, 103, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 3, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 4, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 5, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 6, 120, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 7, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 8, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 9, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 10, 171, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071011014987, 11, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 1, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 2, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 3, 186, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 4, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 5, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 6, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 7, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 8, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060408014988, 9, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 1, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 2, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 3, 77, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 4, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 5, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 6, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 7, 93, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050403014989, 8, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 1, 149, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 2, 57, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 3, 192, 100, 18, 1800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 4, 165, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 5, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 6, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 7, 60, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 8, 52, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 9, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 10, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 11, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 12, 16, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 13, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 14, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 15, 162, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140222014990, 16, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 1, 151, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 2, 77, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 3, 105, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 4, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 5, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 6, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050518014991, 7, 115, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 1, 89, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 2, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 3, 179, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 4, 15, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 5, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 6, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 7, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 8, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 9, 25, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 10, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 11, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 12, 162, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 10, 120, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 11, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 12, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 13, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 14, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 15, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130306015379, 16, 105, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 1, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 2, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 3, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 4, 46, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 5, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 6, 134, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 7, 173, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 8, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050513015380, 9, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 1, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 2, 62, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 3, 65, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 4, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 5, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 6, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 7, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 8, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 9, 118, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 10, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 11, 181, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 12, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 13, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 14, 83, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 15, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120129015381, 16, 106, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 1, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 2, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 3, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 4, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 5, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 6, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 7, 28, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 8, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060130015382, 9, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 1, 58, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 2, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 3, 174, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 4, 22, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 5, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 6, 62, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 7, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041126015383, 8, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529015384, 1, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529015384, 2, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529015384, 3, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529015384, 4, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010529015384, 5, 170, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 1, 104, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 2, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 3, 10, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 4, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 5, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 6, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 7, 2, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 8, 74, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402015385, 9, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 1, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 2, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 3, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 4, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 5, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 6, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 7, 29, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 8, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 9, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 10, 53, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 11, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 12, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 13, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 14, 164, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 15, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130712015386, 16, 165, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 1, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 2, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 3, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 4, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 5, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 6, 9, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 7, 87, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 8, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 9, 105, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 10, 16, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 11, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 12, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 13, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921015387, 14, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 1, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 2, 98, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 3, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 4, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 5, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 6, 94, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 7, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 8, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060710015388, 9, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 1, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 2, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 3, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 4, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 5, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 6, 106, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 7, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061019015389, 8, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 1, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 2, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 3, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 4, 183, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 5, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 6, 77, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 7, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040210015390, 8, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 1, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 2, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 3, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 4, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 5, 94, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 6, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 7, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 8, 69, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 9, 148, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 10, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 11, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 12, 155, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 13, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 14, 21, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120305015391, 15, 93, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 1, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 2, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 3, 89, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 4, 28, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 5, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 6, 101, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 7, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 8, 84, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060107015392, 9, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719015393, 1, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719015393, 2, 14, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719015393, 3, 10, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719015393, 4, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030719015393, 5, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801015394, 1, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801015394, 2, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801015394, 3, 127, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801015394, 4, 66, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020801015394, 5, 72, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 1, 44, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 2, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 3, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 4, 37, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 5, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 6, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040909015395, 7, 163, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 1, 148, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 2, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 3, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 4, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 5, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 6, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 7, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 8, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 9, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061201015396, 10, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 1, 149, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 2, 86, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 3, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 4, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 5, 169, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 6, 30, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 7, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 8, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 9, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 10, 154, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 11, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 12, 191, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 13, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 14, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 15, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130604015397, 16, 18, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 1, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 2, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 3, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 4, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 5, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 6, 115, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 7, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 8, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 9, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 10, 185, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 11, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 12, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090207015398, 13, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 1, 39, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 2, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 3, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 4, 137, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 5, 65, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 6, 168, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 7, 126, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 8, 51, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 9, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 10, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 11, 78, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070520015399, 12, 17, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210015400, 1, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210015400, 2, 181, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210015400, 3, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210015400, 4, 138, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210015400, 5, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 1, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 2, 60, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 3, 74, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 4, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 5, 27, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 6, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 7, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 8, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 9, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 10, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 11, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 12, 27, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930015401, 13, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 1, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 2, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 3, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 4, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 5, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 6, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 7, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 8, 184, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 9, 14, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 10, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 11, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 14, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 15, 96, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 16, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140319015758, 17, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 1, 115, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 2, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 3, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 4, 163, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 5, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 6, 84, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031102015759, 7, 72, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 1, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 2, 56, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 3, 67, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 4, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 5, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 6, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 7, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 8, 134, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007015760, 9, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 1, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 2, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 3, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 4, 42, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 5, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 6, 91, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 7, 54, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 8, 2, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 9, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 10, 130, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 11, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071217015761, 12, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 1, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 2, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 3, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 4, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 5, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 6, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 7, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 8, 121, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 9, 34, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 10, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 11, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 12, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131015762, 13, 9, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 1, 185, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 2, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 3, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 4, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 5, 109, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 6, 191, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 7, 43, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 8, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 9, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 10, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 11, 4, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081001015763, 12, 73, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 1, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 2, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 3, 139, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 4, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 5, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 6, 87, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 7, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 8, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 9, 113, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 10, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 11, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 12, 1, 79, 3, 237);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 13, 74, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100623015764, 14, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 1, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 2, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 3, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 4, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 5, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 6, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 7, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 8, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 9, 71, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 10, 18, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 11, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 12, 188, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 13, 10, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100806015765, 14, 162, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 1, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 2, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 3, 19, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 4, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 5, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 6, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 7, 112, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008015766, 8, 144, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 1, 139, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 2, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 3, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 4, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 5, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 6, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 7, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 8, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 9, 68, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 10, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 11, 48, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 12, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 13, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305015767, 14, 169, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 1, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 2, 120, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 3, 142, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 4, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 5, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010119015768, 6, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 1, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 2, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 3, 145, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 4, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 5, 155, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 6, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 7, 175, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 8, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 9, 163, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 10, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 11, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 12, 163, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080823015769, 13, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 1, 118, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 2, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 3, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 4, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 5, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 6, 40, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 7, 187, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 8, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 9, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 10, 156, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 11, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 12, 103, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 13, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 14, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226015770, 15, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 1, 138, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 2, 50, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 3, 5, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 4, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 5, 192, 45, 18, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041117015771, 6, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 1, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 2, 4, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 3, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 4, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 5, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 6, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040423015772, 7, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 1, 30, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 2, 169, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 3, 156, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 4, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 5, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 6, 169, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 7, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 8, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 9, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 10, 85, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 11, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 12, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 13, 29, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 14, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 15, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 16, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 17, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627015773, 18, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 1, 129, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 2, 123, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 3, 9, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 4, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 5, 122, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 6, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 7, 45, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 8, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070731015774, 9, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 1, 34, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 2, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 3, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 4, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 5, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 6, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205015775, 7, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 1, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 2, 81, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 3, 144, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 4, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 5, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 6, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 7, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 8, 35, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 9, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 10, 91, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 11, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 12, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 13, 94, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 14, 20, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015776, 15, 108, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520015777, 1, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520015777, 2, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520015777, 3, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520015777, 4, 100, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020520015777, 5, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 1, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 2, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 3, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 4, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 5, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 6, 7, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 7, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 8, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070623015778, 9, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 1, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 2, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 3, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 4, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 5, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 6, 56, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 7, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 8, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 9, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 10, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 11, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 12, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 13, 164, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328015779, 14, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 1, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 2, 133, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 3, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 4, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 5, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020521015780, 6, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219015781, 1, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219015781, 2, 49, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 16, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130129014638, 17, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 1, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 2, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 3, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 4, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 5, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 6, 138, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040426014639, 7, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 1, 36, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 2, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 3, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 4, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 5, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 6, 121, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 7, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060115014640, 8, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 1, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 2, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 3, 9, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 4, 123, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 5, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 6, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 7, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 8, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 9, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 10, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 11, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 12, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 13, 154, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 14, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110014641, 15, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 1, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 2, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 3, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 4, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 5, 163, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 6, 180, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 7, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 8, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 9, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 10, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 11, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819014642, 12, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 1, 57, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 2, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 3, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 4, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 5, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 6, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 7, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 8, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 9, 41, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 10, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 11, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 12, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 13, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713014643, 14, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 1, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 2, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 3, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 4, 81, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 5, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 6, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 7, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 8, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 9, 7, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 10, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 11, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 12, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615014644, 13, 7, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 1, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 2, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 3, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 4, 191, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 5, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 6, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 7, 39, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 8, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 9, 65, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 10, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 11, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 12, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 13, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 14, 104, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 15, 162, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 16, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121026014645, 17, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030014646, 1, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030014646, 2, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030014646, 3, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001030014646, 4, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 1, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 2, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 3, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 4, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 5, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 6, 120, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 7, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 8, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 9, 3, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 10, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 11, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 12, 59, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 13, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 14, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 15, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 16, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 17, 178, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130620014647, 18, 88, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 1, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 2, 175, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 3, 8, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 4, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 5, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 6, 30, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 7, 111, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 8, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 9, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 10, 38, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 11, 61, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 12, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 13, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 14, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121220014648, 15, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 1, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 2, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 3, 28, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 4, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 5, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 6, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 7, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 8, 138, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 9, 50, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 10, 152, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025014649, 11, 152, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 1, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 2, 78, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 3, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 4, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 5, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 6, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031216014650, 7, 11, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 1, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 2, 159, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 3, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 4, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 5, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 6, 117, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 7, 23, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 8, 57, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 9, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 10, 178, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081024014651, 11, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209014652, 1, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209014652, 2, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209014652, 3, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209014652, 4, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011209014652, 5, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 1, 35, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 2, 131, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 3, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 4, 190, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 5, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020604014653, 6, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 1, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 2, 59, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 3, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 4, 189, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 5, 161, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030227014654, 6, 127, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625014655, 1, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625014655, 2, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625014655, 3, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020625014655, 4, 133, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 1, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 2, 145, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 3, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 4, 20, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 5, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 6, 110, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 7, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 8, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 9, 187, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 10, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 11, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090303014656, 12, 32, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 1, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 2, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 3, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 4, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 5, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 6, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 7, 106, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 8, 58, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050116014657, 9, 183, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014658, 1, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014658, 2, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014658, 3, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526014658, 4, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 1, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 2, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 3, 156, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 4, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 5, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 6, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 7, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 8, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 9, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 10, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060925014659, 11, 122, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 1, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 2, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 3, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 4, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 5, 146, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 6, 141, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 7, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 8, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 9, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 10, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 11, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 12, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 13, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324014660, 14, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 1, 55, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 2, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 3, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 4, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 5, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 6, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 7, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 8, 105, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 9, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 10, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 11, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 12, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 13, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110910014661, 14, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 13, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 14, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 15, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 16, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110014992, 17, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901014993, 1, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901014993, 2, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901014993, 3, 92, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000901014993, 4, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 1, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 2, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 3, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 4, 20, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 5, 14, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 6, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 7, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 8, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 9, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 10, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 11, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 12, 103, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 13, 154, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 14, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 15, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 16, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 17, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140421014994, 18, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 1, 143, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 2, 120, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 3, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 4, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 5, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 6, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 7, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 8, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 9, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 10, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070202014995, 11, 95, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218014996, 1, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218014996, 2, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218014996, 3, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218014996, 4, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218014996, 5, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 1, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 2, 65, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 3, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 4, 4, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 5, 63, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 6, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030828014997, 7, 133, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 1, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 2, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 3, 94, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 4, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 5, 144, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010616014998, 6, 112, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620014999, 1, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620014999, 2, 116, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620014999, 3, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620014999, 4, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020620014999, 5, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 1, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 2, 83, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 3, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 4, 100, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 5, 153, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 6, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 7, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 8, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 9, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 10, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 11, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116015000, 12, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 1, 39, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 2, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 3, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 4, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 5, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 6, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 7, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 8, 34, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 9, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 10, 152, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 11, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090722015001, 12, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 1, 96, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 2, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 3, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 4, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 5, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 6, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 7, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 8, 65, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 9, 25, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 10, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071028015002, 11, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 1, 142, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 2, 119, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 3, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 4, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 5, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 6, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930015003, 7, 141, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 1, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 2, 20, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 3, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 4, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 5, 37, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 6, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 7, 27, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 8, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 9, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 10, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 11, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 12, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 13, 4, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 14, 2, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729015004, 15, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 1, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 2, 7, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 3, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 4, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 5, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 6, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 7, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 8, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 9, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 10, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 11, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 12, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 13, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 14, 23, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111022015005, 15, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 1, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 2, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 3, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 4, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 5, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 6, 160, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 7, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 8, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 9, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 10, 102, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 11, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 12, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 13, 96, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729015006, 14, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 1, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 2, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 3, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 4, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 5, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 6, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 7, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 8, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326015007, 9, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 1, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 2, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 3, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 4, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 5, 83, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 6, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 7, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 8, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 9, 192, 65, 18, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080519015008, 10, 83, 24, 9, 216);
commit;
prompt 160000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 1, 164, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 2, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 3, 59, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 4, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 5, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 6, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 7, 61, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 8, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 9, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 10, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 11, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 12, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 13, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090423015009, 14, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 1, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 2, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 3, 31, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 4, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 5, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010619015010, 6, 23, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015011, 1, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015011, 2, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015011, 3, 95, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015011, 4, 165, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124015011, 5, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 1, 57, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 2, 127, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 3, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 4, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 5, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 6, 85, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 7, 156, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051027015012, 8, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 1, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 2, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 3, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 4, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 5, 92, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 6, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 7, 61, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 8, 40, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 9, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 10, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081016015013, 11, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 1, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 2, 47, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 3, 82, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 4, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 5, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 6, 61, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 7, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 8, 130, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 9, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 10, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 11, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407015014, 12, 79, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205015015, 1, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205015015, 2, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205015015, 3, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000205015015, 4, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 1, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 2, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 3, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 4, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 5, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 6, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 7, 115, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040302015016, 8, 147, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 1, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 2, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 3, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 4, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 5, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 12, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 13, 96, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 14, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 15, 63, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 16, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 17, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905015402, 18, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 1, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 2, 104, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 3, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 5, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 6, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 7, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 8, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 9, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 10, 52, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 11, 73, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223015403, 12, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 1, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 2, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 3, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 4, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 5, 92, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 6, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 7, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129015404, 8, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 1, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 2, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 3, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 4, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 5, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 6, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 7, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 8, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 9, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 10, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 11, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 12, 90, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 13, 187, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 14, 121, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 15, 171, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109015405, 16, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 1, 74, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 2, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 3, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 4, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 5, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 6, 69, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 7, 173, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050609015406, 8, 42, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 1, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 2, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 3, 153, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 4, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 5, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 6, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 7, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 8, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 9, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 10, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 11, 148, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 12, 28, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 13, 96, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 14, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 15, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 16, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921015407, 17, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 1, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 2, 57, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 3, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 4, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 5, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 6, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 7, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 8, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 9, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 10, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 11, 189, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 12, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 13, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 14, 30, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 15, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 16, 45, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131212015408, 17, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 1, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 2, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 3, 93, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 4, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 5, 147, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 6, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 7, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 8, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 9, 142, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015409, 10, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 1, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 2, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 3, 75, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 4, 113, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 5, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 6, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040828015410, 7, 173, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 1, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 2, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 3, 112, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 4, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 5, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 6, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 7, 172, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 8, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 9, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 10, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 11, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015411, 12, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 1, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 2, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 3, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 4, 15, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 5, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 6, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 7, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 8, 93, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 9, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730015412, 10, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 1, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 2, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 3, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 4, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 5, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 6, 107, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 7, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 8, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 9, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 10, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 11, 105, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 12, 90, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101123015413, 13, 5, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 1, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 2, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 3, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 4, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 5, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 6, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 7, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 8, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015414, 9, 85, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 1, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 2, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 3, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 4, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 5, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 6, 153, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 7, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 8, 175, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 9, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 10, 84, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 11, 25, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 12, 117, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 13, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 14, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 15, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015415, 16, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924015416, 1, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924015416, 2, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010924015416, 3, 174, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 1, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 2, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 3, 170, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 4, 190, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 5, 129, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 6, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 7, 64, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 8, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 9, 64, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 10, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 11, 32, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 12, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 13, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 14, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 15, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 16, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015417, 17, 128, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 1, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 2, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 3, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 4, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 5, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 6, 25, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 7, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 8, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 9, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 10, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 11, 81, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 12, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 13, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 14, 37, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110422015418, 15, 17, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 1, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 2, 133, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 3, 129, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 4, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 5, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 6, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 7, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 8, 146, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 9, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015419, 10, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921015420, 1, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921015420, 2, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921015420, 3, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921015420, 4, 79, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921015420, 5, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 1, 85, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 2, 12, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 3, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 4, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 5, 169, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 6, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020301015421, 7, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 1, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 2, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 3, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 4, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 5, 113, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 6, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 7, 132, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 8, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 9, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 10, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 11, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 12, 152, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 13, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 14, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223015422, 15, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 1, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 2, 80, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 3, 19, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 4, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 5, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219015781, 3, 63, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219015781, 4, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021219015781, 5, 43, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 1, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 2, 119, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 3, 25, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 4, 52, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 5, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 6, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 7, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 8, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 9, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 10, 81, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 11, 25, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 12, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 13, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 14, 165, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 15, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526015782, 16, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 1, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 2, 57, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 3, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 4, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 5, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 6, 134, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 7, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 8, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 9, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 10, 176, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909015783, 11, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 1, 181, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 2, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 3, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 4, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 5, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 6, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 7, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 8, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 9, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 10, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 11, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 12, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 13, 1, 37, 3, 111);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 14, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120916015784, 15, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 1, 192, 42, 18, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 2, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 3, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 4, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 5, 85, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 6, 171, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 7, 78, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 8, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021015785, 9, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 1, 54, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 2, 26, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 3, 175, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 4, 151, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 5, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 6, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 7, 156, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818015786, 8, 169, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 1, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 2, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 3, 51, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 4, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 5, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 6, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 7, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 8, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 9, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 10, 21, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 11, 79, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 12, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 13, 81, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205015787, 14, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027015788, 1, 157, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027015788, 2, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027015788, 3, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027015788, 4, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011027015788, 5, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309015789, 1, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309015789, 2, 62, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309015789, 3, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010309015789, 4, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 1, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 2, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 3, 89, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 4, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 5, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 6, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 7, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 8, 108, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 9, 186, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 10, 122, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 11, 30, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 12, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 13, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 14, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 15, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131125015790, 16, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723015791, 1, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723015791, 2, 115, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723015791, 3, 122, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723015791, 4, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010723015791, 5, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 1, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 2, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 3, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 4, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 5, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 6, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 7, 163, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 8, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 9, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 10, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 11, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 12, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 13, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101201015792, 14, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 1, 11, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 2, 95, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 3, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 4, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 5, 127, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 6, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 7, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040908015793, 8, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 1, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 2, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 3, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 4, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 5, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 6, 161, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 7, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 8, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 9, 182, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 10, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 11, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 12, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 13, 117, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 14, 37, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 15, 150, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130626015794, 16, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 1, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 2, 27, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 3, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 4, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 5, 7, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030731015795, 6, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 1, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 2, 98, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 3, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 4, 147, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 5, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 6, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 7, 55, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 8, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 9, 75, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 10, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 11, 109, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090523015796, 12, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 1, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 2, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 3, 8, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 4, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 5, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 6, 21, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 7, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040817015797, 8, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 1, 154, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 2, 106, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 3, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 4, 100, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 5, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 6, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 7, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 8, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 9, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 10, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 11, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 12, 151, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 13, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 14, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 15, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 16, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015798, 17, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 1, 151, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 2, 36, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 3, 81, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 4, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 5, 49, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 6, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 7, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 8, 35, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 9, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 10, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 11, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 12, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 13, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 14, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 15, 51, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120718015799, 16, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 1, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 2, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 3, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 4, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 5, 67, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 6, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 7, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 8, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 9, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080505015800, 10, 78, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 1, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 2, 73, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 3, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 4, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 5, 67, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 6, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 7, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405015801, 8, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015802, 1, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015802, 2, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000319015802, 3, 121, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000225015803, 1, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000225015803, 2, 79, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 1, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 2, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 3, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 4, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 5, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 6, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 7, 139, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 8, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 9, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 10, 19, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 11, 52, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080313015804, 12, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620015805, 1, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 1, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 2, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 3, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 4, 2, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 5, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 6, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 7, 19, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 8, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 9, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 10, 100, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 11, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 12, 27, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809014662, 13, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 1, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 2, 29, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 3, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 4, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 5, 46, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 6, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 7, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 8, 118, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 9, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 10, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 11, 184, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081121014663, 12, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 1, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 2, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 3, 94, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 4, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 5, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 6, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 7, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 8, 63, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 9, 74, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 10, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014664, 11, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 1, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 2, 87, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 3, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 4, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 5, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 6, 11, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 7, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 8, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 9, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402014665, 10, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 1, 115, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 2, 35, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 3, 75, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 4, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 5, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 6, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 7, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 8, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 9, 20, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 10, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 11, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 12, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 13, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101029014666, 14, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 1, 32, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 2, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 3, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 4, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 5, 96, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 6, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 7, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 8, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 9, 173, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 10, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 11, 95, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 12, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 13, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 14, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 15, 68, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 16, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 17, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 18, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401014667, 19, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 1, 20, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 2, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 3, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 4, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 5, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 6, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 7, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 8, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060526014668, 9, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120014669, 1, 34, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120014669, 2, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120014669, 3, 22, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120014669, 4, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 1, 17, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 2, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 3, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 4, 126, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 5, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 6, 51, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 7, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 8, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 9, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070309014670, 10, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 1, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 2, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 3, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 4, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 5, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 6, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 7, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 8, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 9, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 10, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 11, 148, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 12, 178, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 13, 125, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 14, 82, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 15, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 16, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130929014671, 17, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 1, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 2, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 3, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 4, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 5, 178, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 6, 167, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 7, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 8, 125, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 9, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 10, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 11, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 12, 46, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 13, 15, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100620014672, 14, 13, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 1, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 2, 106, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 3, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 4, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 5, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 6, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 7, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 8, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819014673, 9, 61, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 1, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 2, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 3, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 4, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 5, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040822014674, 6, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 1, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 2, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 3, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 4, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 5, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 6, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 7, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 8, 30, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 9, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 10, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 11, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 12, 184, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 13, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 14, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 15, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130322014675, 16, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 1, 184, 80, 17, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 2, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 3, 188, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 4, 128, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 5, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 6, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 7, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 8, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 9, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 10, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 11, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070924014676, 12, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 1, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 2, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 3, 19, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 4, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 5, 89, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 6, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 7, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 8, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 9, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 10, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 11, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 12, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 13, 75, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813014677, 14, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 1, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 2, 84, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 3, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 4, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 5, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 6, 155, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 7, 177, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 8, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 9, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081021014678, 10, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 1, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 2, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 3, 145, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 4, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 5, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 6, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 7, 43, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 8, 32, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 9, 149, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 10, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 11, 112, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 12, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 13, 72, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 14, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 15, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120728014679, 16, 49, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 1, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 2, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 3, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 4, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 5, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 6, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 7, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 8, 71, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 9, 154, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051111014680, 10, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029014681, 1, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029014681, 2, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029014681, 3, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029014681, 4, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021029014681, 5, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 1, 95, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 2, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 3, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 4, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 5, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 6, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 7, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 8, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 6, 146, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 7, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 8, 50, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 9, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 10, 101, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 11, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015017, 12, 9, 80, 4, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 1, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 2, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 3, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 4, 47, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 5, 33, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 6, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 7, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 8, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 9, 26, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 10, 101, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 11, 56, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 12, 116, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 13, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 14, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 15, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120715015018, 16, 78, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 1, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 2, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 3, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 4, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 5, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 6, 129, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 7, 62, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 8, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 9, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 10, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 11, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 12, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 13, 124, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 14, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 15, 162, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 16, 176, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413015019, 17, 149, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 1, 100, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 2, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 3, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 4, 27, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 5, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 6, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 7, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041231015020, 8, 102, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 1, 119, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 2, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 3, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 4, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 5, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 6, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 7, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 8, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 9, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 10, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 11, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 12, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021015021, 13, 21, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 1, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 2, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 3, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 4, 43, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 5, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 6, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 7, 100, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 8, 65, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 9, 96, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 10, 52, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091108015022, 11, 40, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 1, 173, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 2, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 3, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 4, 183, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 5, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 6, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 7, 64, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 8, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 9, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061002015023, 10, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217015024, 1, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217015024, 2, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217015024, 3, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217015024, 4, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217015024, 5, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015025, 1, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015025, 2, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015025, 3, 5, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015025, 4, 155, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221015025, 5, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 1, 84, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 2, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 3, 188, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 4, 76, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 5, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 6, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 7, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 8, 24, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 9, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 10, 34, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 11, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 12, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091210015026, 13, 112, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 1, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 2, 77, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 3, 128, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 4, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 5, 109, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 6, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 7, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 8, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 9, 176, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060727015027, 10, 90, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 1, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 2, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 3, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 4, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 5, 134, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 6, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 7, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 8, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 9, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 10, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 11, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 12, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 13, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 14, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 15, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130806015028, 16, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 1, 83, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 2, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 3, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 4, 55, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 5, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 6, 170, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 7, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 8, 90, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 9, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 10, 101, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 11, 132, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 12, 147, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 13, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 14, 189, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 15, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008015029, 16, 10, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 1, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 2, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 3, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 4, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 5, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 6, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 7, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 8, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 9, 111, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911015030, 10, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618015031, 1, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618015031, 2, 46, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010618015031, 3, 81, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 1, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 2, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 3, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 4, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 5, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 6, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 7, 138, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 8, 44, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 9, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 10, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 11, 168, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 12, 58, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 13, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404015032, 14, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 1, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 2, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 3, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 4, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 5, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011028015033, 6, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 1, 113, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 2, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 3, 139, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 4, 11, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 5, 132, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 6, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 7, 82, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 8, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 9, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 10, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 11, 120, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 12, 95, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080114015034, 13, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 1, 168, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 2, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 3, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 4, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 5, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814015035, 6, 98, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 1, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 2, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 3, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 4, 19, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 5, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 6, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 7, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 8, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 9, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 10, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 11, 25, 46, 6, 276);
commit;
prompt 161000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604015036, 12, 53, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 1, 118, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 2, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 3, 25, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 4, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 5, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 6, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021011015037, 7, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004015038, 1, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004015038, 2, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004015038, 3, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004015038, 4, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011004015038, 5, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 1, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 2, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 3, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 4, 108, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 5, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 6, 143, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 7, 180, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 8, 191, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 9, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 10, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 11, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100315015039, 12, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 1, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 2, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 3, 37, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 4, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 6, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 7, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 8, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070210015423, 9, 71, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113015424, 1, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113015424, 2, 149, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113015424, 3, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113015424, 4, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021113015424, 5, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 1, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 2, 135, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 3, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 4, 138, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 5, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 6, 146, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 7, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 8, 121, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 9, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 10, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 11, 134, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 12, 113, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 13, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120215015425, 14, 31, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 1, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 2, 105, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 3, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 4, 149, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 5, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021104015426, 6, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 1, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 2, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 3, 91, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 4, 62, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 5, 164, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 6, 15, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 7, 88, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522015427, 8, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 1, 43, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 2, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 3, 71, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 4, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 5, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 6, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509015428, 7, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 1, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 2, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 3, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 4, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 5, 81, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 6, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 7, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 8, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 9, 173, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 10, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 11, 62, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820015429, 12, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 1, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 2, 142, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 3, 2, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 4, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 5, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 6, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 7, 49, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 8, 170, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050222015430, 9, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 1, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 2, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 3, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 4, 135, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 5, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 6, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040105015431, 7, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305015432, 1, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000305015432, 2, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 1, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 2, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 3, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 4, 16, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 5, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 6, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 7, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 8, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 9, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 10, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 11, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 12, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 13, 142, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 14, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 15, 127, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130804015433, 16, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 1, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 2, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 3, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 4, 20, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 5, 14, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 6, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 7, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 8, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 9, 143, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 10, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 11, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 12, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 13, 63, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 14, 90, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 15, 128, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120630015434, 16, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 1, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 2, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 3, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 4, 186, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 5, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 6, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 7, 90, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 8, 37, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 9, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 10, 107, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 11, 54, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 12, 101, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 13, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100731015435, 14, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 1, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 2, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 3, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 4, 15, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 5, 101, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 6, 51, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 7, 46, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 8, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 9, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 10, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060812015436, 11, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 1, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 2, 41, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 3, 104, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 4, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 5, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 6, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 7, 168, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 8, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 9, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 10, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 11, 57, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 12, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 13, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090718015437, 14, 148, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 1, 153, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 2, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 3, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 4, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 5, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 6, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 7, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040524015438, 8, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 1, 106, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 2, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 3, 89, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 4, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 5, 46, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 6, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 7, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 8, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 9, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 10, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 11, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 12, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 13, 55, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120904015439, 14, 192, 76, 18, 1368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 1, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 2, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 3, 135, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 4, 79, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 5, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 6, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122015440, 7, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 1, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 2, 52, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 3, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 4, 189, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 5, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 6, 164, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 7, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 8, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 9, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 10, 22, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 11, 65, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 12, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 13, 83, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 14, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 15, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 16, 172, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140209015441, 17, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 1, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 2, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 3, 180, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 4, 128, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 5, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 6, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 7, 62, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118015442, 8, 24, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 1, 28, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 2, 169, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 3, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 4, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 5, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 6, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 7, 154, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 8, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 9, 45, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070126015443, 10, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020015444, 1, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020015444, 2, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020015444, 3, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021020015444, 4, 190, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 1, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 2, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 3, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 4, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 5, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 6, 31, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 7, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 8, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 9, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 10, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 11, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070713015445, 12, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 1, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 2, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 3, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 4, 157, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 5, 33, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 6, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 7, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 8, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 9, 47, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 10, 12, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091129015446, 11, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 1, 166, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 2, 96, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 3, 110, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620015805, 2, 171, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620015805, 3, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620015805, 4, 22, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620015805, 5, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 1, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 2, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 3, 162, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 4, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 5, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 6, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 7, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 8, 11, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 9, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 10, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 11, 165, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 12, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 13, 154, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 14, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 15, 73, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 16, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 17, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130125015806, 18, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 1, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 2, 131, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 3, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 4, 163, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 5, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020921015807, 6, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707015808, 1, 84, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707015808, 2, 191, 96, 17, 1632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707015808, 3, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010707015808, 4, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610015809, 1, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610015809, 2, 35, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000610015809, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015810, 1, 72, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015810, 2, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015810, 3, 178, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214015810, 4, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 1, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 2, 48, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 3, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 4, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 5, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427015811, 6, 172, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 1, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 2, 155, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 3, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 4, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 5, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 6, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 7, 172, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 8, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 9, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 10, 98, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 11, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 12, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 13, 107, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 14, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120907015812, 15, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 1, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 2, 45, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 3, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 4, 39, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 5, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 6, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 7, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050203015813, 8, 187, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 1, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 2, 42, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 3, 3, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 4, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 5, 154, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 6, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606015814, 7, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 1, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 2, 124, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 3, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 4, 27, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 5, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 6, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 7, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 8, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 9, 68, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 10, 10, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 11, 184, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090522015815, 12, 171, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 1, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 2, 98, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 3, 178, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 4, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 5, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 6, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 7, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 8, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 9, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080518015816, 10, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 1, 66, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 2, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 3, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 4, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 5, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 6, 87, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 7, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 8, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 9, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 10, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 11, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 12, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 13, 92, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111122015817, 14, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 1, 190, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 2, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 3, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 4, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 5, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 6, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 7, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 8, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 9, 34, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528015818, 10, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 1, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 2, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 3, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 4, 74, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 5, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 6, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 7, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 8, 1, 78, 3, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050828015819, 9, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 1, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 2, 10, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 3, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 4, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 5, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 6, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 7, 125, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 8, 137, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 9, 58, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 10, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 11, 72, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 12, 174, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 13, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 14, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110705015820, 15, 190, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 1, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 2, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 3, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 4, 19, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 5, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 6, 12, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 7, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 8, 62, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 9, 181, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 10, 101, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 11, 65, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 12, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 13, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 14, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120626015821, 15, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 1, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 2, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 3, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 4, 171, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 5, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 6, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 7, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 8, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 9, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 10, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 11, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071231015822, 12, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 1, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 2, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 3, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 4, 17, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 5, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 6, 160, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 7, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 8, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 9, 175, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 10, 94, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 11, 29, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 12, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 13, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 14, 155, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213015823, 15, 75, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 1, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 2, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 3, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 4, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 5, 13, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 6, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 7, 151, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 8, 162, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 9, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 10, 83, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 11, 121, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 12, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 13, 60, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 14, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 15, 184, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329015824, 16, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926015825, 1, 168, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926015825, 2, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926015825, 3, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926015825, 4, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010926015825, 5, 173, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 1, 86, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 2, 66, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 3, 1, 47, 3, 141);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 4, 133, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 5, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 6, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 7, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 8, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 9, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 10, 146, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 11, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 12, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 13, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 14, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 15, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 16, 69, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130426015826, 17, 7, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 1, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 2, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 3, 136, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 4, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 5, 90, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 6, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015827, 7, 31, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 1, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 2, 83, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 3, 10, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 4, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 5, 96, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 6, 5, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 7, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 9, 153, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 10, 103, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 11, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091021014682, 12, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 1, 107, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 2, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 3, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 4, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 5, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 6, 7, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 7, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 8, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225014683, 9, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 1, 190, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 2, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 3, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 4, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 5, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 6, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 7, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040617014684, 8, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 1, 28, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 2, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 3, 71, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 4, 81, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 5, 112, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 6, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 7, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 8, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 9, 46, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 10, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 11, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 12, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 13, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 14, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 15, 140, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615014685, 16, 25, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 1, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 2, 78, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 3, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 4, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 5, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 6, 61, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 7, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 8, 150, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 9, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070321014686, 10, 128, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 1, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 2, 17, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 3, 159, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 4, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 5, 56, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 6, 140, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 7, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 8, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 9, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 10, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 11, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 12, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812014687, 13, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 1, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 2, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 3, 104, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 4, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 5, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 6, 153, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 7, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615014688, 8, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 1, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 2, 76, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 3, 122, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 4, 185, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 5, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010523014689, 6, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101014690, 1, 50, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101014690, 2, 111, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101014690, 3, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101014690, 4, 159, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021101014690, 5, 18, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 1, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 2, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 3, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 4, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 5, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 6, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 7, 19, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 8, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622014691, 9, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 1, 96, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 2, 42, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 3, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 4, 134, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 5, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 6, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 7, 53, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 8, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 9, 33, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 10, 89, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 11, 157, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 12, 7, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090831014692, 13, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 1, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 2, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 3, 51, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 4, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 5, 114, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 6, 39, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 7, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 8, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 9, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070305014693, 10, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007014694, 1, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007014694, 2, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007014694, 3, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007014694, 4, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011007014694, 5, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 1, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 2, 18, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 3, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 4, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 5, 138, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 6, 149, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 7, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 8, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 9, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 10, 134, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 11, 137, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 12, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 13, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120222014695, 14, 91, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 1, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 2, 35, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 3, 138, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 4, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 5, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 6, 42, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 7, 138, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 8, 26, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 9, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 10, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 11, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 12, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 13, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 14, 126, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 15, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 16, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140129014696, 17, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 1, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 2, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 3, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 4, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 5, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 6, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 7, 72, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 8, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 9, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 10, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090905014697, 11, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 1, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 2, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 3, 76, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 4, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 5, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 6, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 7, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031220014698, 8, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413014699, 1, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413014699, 2, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413014699, 3, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010413014699, 4, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 1, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 2, 32, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 3, 75, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 4, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 5, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 6, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 7, 175, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040815014700, 8, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 1, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 2, 84, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 3, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 4, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 5, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 6, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 7, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 8, 110, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 9, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 10, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 11, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 12, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 13, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 14, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111026014701, 15, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 1, 30, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 2, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 3, 81, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 4, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 5, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 6, 128, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 7, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 8, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 9, 168, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 10, 83, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 11, 78, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 12, 76, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 13, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 14, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 15, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 16, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120714014702, 17, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 1, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 2, 76, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 3, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 4, 132, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 5, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 6, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 7, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 8, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 9, 73, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 10, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 11, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 12, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 13, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 14, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131205014703, 15, 23, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 1, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 2, 18, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 3, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 4, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 5, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 6, 186, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 7, 179, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 8, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 9, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 10, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 11, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 12, 67, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 13, 1, 72, 3, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 14, 132, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 5, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 6, 88, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 7, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 8, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 9, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 10, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 11, 141, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 12, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 13, 78, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 14, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 15, 143, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 16, 159, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 17, 146, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911015040, 18, 22, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304015041, 1, 87, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304015041, 2, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010304015041, 3, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412015042, 1, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412015042, 2, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412015042, 3, 154, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412015042, 4, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 1, 109, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 2, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 3, 146, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 4, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 5, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 6, 99, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 7, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040904015043, 8, 14, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 1, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 2, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 3, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 4, 182, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 5, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 6, 4, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 7, 95, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 8, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 9, 113, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 10, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 11, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 12, 5, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 13, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809015044, 14, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 1, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 2, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 3, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 4, 69, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 5, 60, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 6, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 7, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 8, 45, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050625015045, 9, 98, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 1, 39, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 2, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 3, 115, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 4, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 5, 161, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020310015046, 6, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 1, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 2, 1, 59, 3, 177);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 3, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 4, 156, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 5, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 6, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 7, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 8, 183, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 9, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 10, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080430015047, 11, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 1, 46, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 2, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 3, 79, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 4, 70, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 5, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 6, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 7, 142, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 8, 114, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 9, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 10, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080220015048, 11, 144, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 1, 42, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 2, 130, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 3, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 4, 75, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 5, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 6, 27, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 7, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 8, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 9, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 10, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 11, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 12, 108, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110330015049, 13, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 1, 18, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 2, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 3, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 4, 147, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 5, 103, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324015050, 6, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 1, 190, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 2, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 3, 179, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 4, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 5, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 6, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 7, 123, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 8, 12, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 9, 151, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 10, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 11, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 12, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 13, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 14, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 15, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130329015051, 16, 179, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201015052, 1, 19, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201015052, 2, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201015052, 3, 60, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201015052, 4, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010201015052, 5, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 1, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 2, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 3, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 4, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 5, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040715015053, 6, 183, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 1, 134, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 2, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 3, 157, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 4, 81, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 5, 93, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 6, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 7, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 8, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 9, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 10, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080214015054, 11, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 1, 19, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 2, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 3, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 4, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 5, 135, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 6, 79, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 7, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 8, 150, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 9, 57, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 10, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 11, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 12, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 13, 15, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 14, 20, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 15, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 16, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130702015055, 17, 178, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 1, 190, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 2, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 3, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 4, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 5, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 6, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 7, 64, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 8, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 9, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 10, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 11, 61, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 12, 153, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 13, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 14, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 15, 16, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 16, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131026015056, 17, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 1, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 2, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 3, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 4, 27, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 5, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 6, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 7, 55, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 8, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 9, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 10, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 11, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 12, 133, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 13, 172, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 14, 160, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121114015057, 15, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 1, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 2, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 3, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 4, 43, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 5, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 6, 125, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 7, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 8, 151, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 9, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 10, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 11, 152, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 12, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090830015058, 13, 72, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 1, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 2, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 3, 172, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 4, 36, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 5, 136, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 6, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 7, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 8, 131, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 9, 68, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 10, 190, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 11, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 12, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 13, 156, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 14, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 15, 133, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 16, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 17, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131111015059, 18, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 1, 131, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 2, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 3, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 4, 45, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 5, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 6, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 7, 38, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 8, 158, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 9, 129, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 10, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 11, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 12, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 13, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 14, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 15, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203015060, 16, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 1, 10, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 2, 5, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 3, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 4, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 5, 84, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 6, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 4, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 5, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 6, 187, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015447, 7, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 1, 108, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 2, 89, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 3, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 4, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 5, 106, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 6, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 7, 121, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 8, 32, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 9, 171, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 10, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 11, 177, 56, 10, 560);
commit;
prompt 162000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 12, 7, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090708015448, 13, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 1, 172, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 2, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 3, 177, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 4, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 5, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 6, 27, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 7, 46, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 8, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 9, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 10, 51, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 11, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 12, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 13, 61, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 14, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121104015449, 15, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 1, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 2, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 3, 168, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 4, 185, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 5, 12, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 6, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425015450, 7, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212015451, 1, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212015451, 2, 2, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212015451, 3, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212015451, 4, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212015451, 5, 37, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 1, 83, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 2, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 3, 116, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 4, 38, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 5, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 6, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804015452, 7, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 1, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 2, 167, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 3, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 4, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 5, 121, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011203015453, 6, 62, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 1, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 2, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 3, 187, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 4, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 5, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 6, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 7, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 8, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040324015454, 9, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704015455, 1, 183, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704015455, 2, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704015455, 3, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704015455, 4, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010704015455, 5, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 1, 112, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 2, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 3, 50, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 4, 69, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 5, 107, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 6, 17, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 7, 118, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 8, 7, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 9, 134, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 10, 144, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510015456, 11, 136, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 1, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 2, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 3, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 4, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 5, 172, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 6, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 7, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 8, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 9, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 10, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 11, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814015457, 12, 125, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 1, 146, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 2, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 3, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 4, 38, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 5, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 6, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 7, 172, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040922015458, 8, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 1, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 2, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 3, 192, 74, 18, 1332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 4, 42, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 5, 96, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020326015459, 6, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021225015460, 1, 164, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021225015460, 2, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021225015460, 3, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021225015460, 4, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021225015460, 5, 102, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 1, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 2, 76, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 3, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 4, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 5, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 6, 88, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 7, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 8, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040111015461, 9, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 1, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 2, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 3, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 4, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 5, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 6, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 7, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 8, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 9, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 10, 79, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 11, 74, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 12, 180, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 13, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204015462, 14, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 1, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 2, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 3, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 4, 147, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 5, 165, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 6, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 7, 102, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 8, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061014015463, 9, 85, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 1, 192, 24, 18, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 2, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 3, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 4, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 5, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 6, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 7, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 8, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 9, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 10, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 11, 42, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 12, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101114015464, 13, 191, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 1, 86, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 2, 167, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 3, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 4, 186, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 5, 60, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 6, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 7, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 8, 178, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201015465, 9, 4, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 1, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 2, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 3, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 4, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 5, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 6, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 7, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 8, 88, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111015466, 9, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607015467, 1, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607015467, 2, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607015467, 3, 14, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010607015467, 4, 116, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 1, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 2, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 3, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 4, 174, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 5, 35, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 6, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 7, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 8, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 9, 68, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 10, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 11, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 12, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 13, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525015468, 14, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022015469, 1, 39, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022015469, 2, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011022015469, 3, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 1, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 2, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 3, 9, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 4, 135, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 5, 36, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 6, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 7, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 8, 183, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 9, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 10, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081218015470, 11, 129, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228015471, 1, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228015471, 2, 168, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011228015471, 3, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 1, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 2, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 3, 100, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 4, 110, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 5, 86, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 6, 105, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 7, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 8, 52, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 9, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 10, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 11, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 12, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100530015472, 13, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015473, 1, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015473, 2, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121015473, 3, 136, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 1, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 2, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 3, 82, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 4, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 5, 136, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 6, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 7, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 8, 143, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 9, 42, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120015474, 10, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008015475, 1, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 8, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 9, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 10, 63, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 11, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 12, 51, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 13, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 14, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130909015828, 15, 93, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 1, 57, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 2, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 3, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 4, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 5, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 6, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 7, 52, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 8, 142, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 9, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 10, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 11, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 12, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080918015829, 13, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 1, 147, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 2, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 3, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 4, 93, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 5, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 6, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 7, 124, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 8, 4, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 9, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 10, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 11, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705015830, 12, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 1, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 2, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 3, 176, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 4, 28, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 5, 144, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 6, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 7, 40, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 8, 11, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060323015831, 9, 143, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 1, 137, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 2, 43, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 3, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 4, 17, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 5, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 6, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 7, 121, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 8, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 9, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 10, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 11, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 12, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013015832, 13, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 1, 163, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 2, 77, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 3, 160, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 4, 175, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 5, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 6, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 7, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 8, 6, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 9, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 10, 184, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 11, 106, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 12, 148, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 13, 92, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 14, 170, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 15, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 16, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222015833, 17, 174, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 1, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 2, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 3, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 4, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 5, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 6, 43, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 7, 100, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 8, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 9, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 10, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060616015834, 11, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 1, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 2, 60, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 3, 141, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 4, 116, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 5, 135, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 6, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 7, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 8, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 9, 137, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 10, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 11, 52, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 12, 56, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 13, 111, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 14, 77, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120417015835, 15, 71, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 1, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 2, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 3, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 4, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 5, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 6, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 7, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 8, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 9, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 10, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 11, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 12, 179, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 13, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 14, 7, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 15, 40, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120103015836, 16, 50, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 1, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 2, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 3, 169, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 4, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 5, 7, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 6, 149, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 7, 38, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 8, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 9, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312015837, 10, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903015838, 1, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903015838, 2, 35, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903015838, 3, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903015838, 4, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020903015838, 5, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 1, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 2, 91, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 3, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 4, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 5, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 6, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 7, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 8, 162, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 9, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 10, 97, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 11, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 12, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 13, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 14, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217015839, 15, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 1, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 2, 78, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 3, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 4, 9, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 5, 142, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 6, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 7, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 8, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 9, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 10, 113, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 11, 141, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 12, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 13, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 14, 135, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120712015840, 15, 87, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 1, 38, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 2, 106, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 3, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 4, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 5, 38, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 6, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318015841, 7, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207015842, 1, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207015842, 2, 37, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207015842, 3, 145, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207015842, 4, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030015843, 1, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030015843, 2, 81, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030015843, 3, 21, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030015843, 4, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030015843, 5, 2, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 1, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 2, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 3, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 4, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 5, 32, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 6, 132, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 7, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 8, 151, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 9, 176, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 10, 39, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 11, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 12, 48, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090604015844, 13, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 1, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 2, 83, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 3, 187, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 4, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 5, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 6, 37, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 7, 165, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 8, 171, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060705015845, 9, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 1, 16, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 2, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 3, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 4, 187, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 5, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021212015846, 6, 122, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019015847, 1, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019015847, 2, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019015847, 3, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019015847, 4, 77, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021019015847, 5, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 1, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 2, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 3, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 4, 1, 15, 3, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 5, 4, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 6, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 7, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 8, 74, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 9, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 10, 190, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 11, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 12, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 13, 136, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 14, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110912015848, 15, 147, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 1, 163, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 2, 68, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 3, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 4, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 5, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 6, 187, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 7, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 8, 168, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015849, 9, 59, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015015850, 1, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015015850, 2, 4, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015015850, 3, 158, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015015850, 4, 141, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015015850, 5, 45, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 1, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 2, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 15, 16, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 16, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 17, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502014704, 18, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 1, 188, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 2, 16, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 3, 32, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 4, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 5, 119, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040415014705, 6, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 1, 149, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 2, 8, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 3, 67, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 4, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 5, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 6, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 7, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 8, 18, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 9, 135, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 10, 109, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 11, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 12, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 13, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100904014706, 14, 157, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 1, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 2, 84, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 3, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 4, 16, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 5, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 6, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 7, 161, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 8, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 9, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 10, 190, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711014707, 11, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 1, 153, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 2, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 3, 92, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 4, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 5, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 6, 18, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 7, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 8, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 9, 92, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 10, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 11, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 12, 145, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 13, 19, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 14, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 15, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 16, 42, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 17, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130303014708, 18, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 1, 152, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 2, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 3, 58, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 4, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 5, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 6, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 7, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 8, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216014709, 9, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 1, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 2, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 3, 64, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 4, 61, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 5, 52, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 6, 97, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 7, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 8, 110, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 9, 138, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 10, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 11, 188, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 12, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 13, 163, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 14, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217014710, 15, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 1, 71, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 2, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 3, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 4, 102, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 5, 25, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 6, 36, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030825014711, 7, 117, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 1, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 2, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 3, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 4, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 5, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 6, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 7, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 8, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 9, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 10, 191, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 11, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 12, 66, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 13, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 14, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 15, 88, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130330014712, 16, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 1, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 2, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 3, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 4, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 5, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 6, 88, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 7, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 8, 88, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040325014713, 9, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 1, 104, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 2, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 3, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 4, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 5, 131, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902014714, 6, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 1, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 2, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 3, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 4, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 5, 22, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 6, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 7, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 8, 3, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 9, 16, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 10, 78, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 11, 142, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 12, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619014715, 13, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 1, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 2, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 3, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 4, 102, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 5, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 6, 78, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 7, 162, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 8, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 9, 155, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070427014716, 10, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 1, 154, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 2, 52, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 3, 77, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 4, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 5, 127, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 6, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 7, 173, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 8, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 9, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 10, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 11, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 12, 30, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 13, 133, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716014717, 14, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 1, 165, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 2, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 3, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 4, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 5, 147, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 6, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 7, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 8, 11, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 9, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070805014718, 10, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 1, 131, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 2, 178, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 3, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 4, 100, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 5, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314014719, 6, 73, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102014720, 1, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102014720, 2, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102014720, 3, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 1, 118, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 2, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 3, 52, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 4, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 5, 82, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 6, 31, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 7, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 8, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 9, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 10, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 11, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224014721, 12, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 1, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 2, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 3, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 4, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 5, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 6, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 7, 42, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 8, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 9, 170, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 10, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 11, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 12, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 13, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 14, 103, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 15, 31, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 16, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 17, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014722, 18, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 1, 2, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 2, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 3, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 4, 104, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 5, 15, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 6, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 7, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 8, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060903014723, 9, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 1, 117, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 2, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 3, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 4, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 5, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 6, 97, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 7, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061111014724, 8, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 1, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 2, 58, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 3, 54, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 4, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 5, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 6, 172, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 7, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 8, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 9, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 10, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090916014725, 11, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 1, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 2, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 3, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 4, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 5, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 6, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 7, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030507014726, 8, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 1, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020112015061, 7, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516015062, 1, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516015062, 2, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516015062, 3, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000516015062, 4, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 1, 146, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 2, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 3, 98, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 4, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 5, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 6, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 7, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 8, 86, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 9, 35, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 10, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 11, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 12, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090513015063, 13, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 1, 112, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 2, 138, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 3, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 4, 149, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 5, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 6, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 7, 127, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 8, 67, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 9, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 10, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 11, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 12, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 13, 21, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330015064, 14, 91, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 1, 130, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 2, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 3, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 4, 114, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 5, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 6, 141, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 7, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030722015065, 8, 31, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 1, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 2, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 3, 37, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 4, 21, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 5, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 6, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 7, 190, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 8, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 9, 180, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 10, 147, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 11, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 12, 32, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110430015066, 13, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 1, 10, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 2, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 3, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 4, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 5, 128, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 6, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 7, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 8, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 9, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 10, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 11, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 12, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 13, 11, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 14, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 15, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102015067, 16, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 1, 143, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 2, 42, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 3, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 4, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 5, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 6, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 7, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 8, 100, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 9, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 10, 20, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080802015068, 11, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 1, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 2, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 3, 25, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 4, 19, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 5, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 6, 139, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 7, 50, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 8, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 9, 166, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 10, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 11, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 12, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 13, 115, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 14, 11, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 15, 58, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120525015069, 16, 92, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715015070, 1, 128, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000715015070, 2, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 1, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 2, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 3, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 4, 124, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 5, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 6, 167, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227015071, 7, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 1, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 2, 16, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 3, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 4, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 5, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 6, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 7, 151, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 8, 70, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 9, 157, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 10, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081017015072, 11, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 1, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 2, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 3, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 4, 109, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 5, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 6, 144, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 7, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 8, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 9, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 10, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 11, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 12, 70, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 13, 87, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 14, 85, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 15, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130102015073, 16, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 1, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 2, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 3, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 4, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 5, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 6, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 7, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 8, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 9, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 10, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 11, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080103015074, 12, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322015075, 1, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322015075, 2, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010322015075, 3, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 1, 142, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 2, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 3, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 4, 54, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 5, 160, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 6, 132, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 7, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030306015076, 8, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525015077, 1, 74, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525015077, 2, 122, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525015077, 3, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010525015077, 4, 8, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 1, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 2, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 3, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 4, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 5, 34, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 6, 81, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 7, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 8, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 9, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 10, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 11, 159, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 12, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 13, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 14, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 15, 188, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 16, 164, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120810015078, 17, 180, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 1, 14, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 2, 9, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 3, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 4, 39, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 5, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 6, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 7, 7, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030707015079, 8, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 1, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 2, 115, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 3, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 4, 127, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 5, 21, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 6, 26, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522015080, 7, 163, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 1, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 2, 152, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 3, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 4, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 5, 147, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 6, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 7, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 8, 84, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 9, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 10, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 11, 62, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 12, 55, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 13, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120415015081, 14, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 1, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 2, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 3, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 4, 175, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 5, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031101015082, 6, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 1, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 2, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 3, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 4, 35, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 5, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 6, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 7, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 8, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 9, 106, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 10, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 11, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 12, 113, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 13, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 14, 84, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 15, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121015083, 16, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 1, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 2, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 3, 133, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 4, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 5, 44, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010417015084, 6, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 1, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 2, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 3, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 4, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 5, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030330015085, 6, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008015475, 2, 177, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008015475, 3, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011008015475, 4, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018015476, 1, 55, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018015476, 2, 42, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018015476, 3, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018015476, 4, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018015476, 5, 83, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 1, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 2, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 3, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 4, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 5, 123, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 6, 115, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 7, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 8, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009015477, 9, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 1, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 2, 190, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 3, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 4, 133, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 5, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 6, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 7, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 8, 47, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 9, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322015478, 10, 84, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 1, 110, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 2, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 3, 59, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 4, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 5, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202015479, 6, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 1, 169, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 2, 152, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 3, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 4, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 5, 30, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 6, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 7, 62, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 8, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 9, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 10, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 11, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919015480, 12, 114, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 1, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 2, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 3, 191, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 4, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 5, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 6, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 7, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 8, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 9, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 10, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 11, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 12, 188, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 13, 93, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 14, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015481, 15, 39, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 1, 8, 35, 10, 350);
commit;
prompt 163000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 2, 9, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 3, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 4, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 5, 57, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 6, 183, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050808015482, 7, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003015483, 1, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003015483, 2, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003015483, 3, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011003015483, 4, 86, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 1, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 2, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 3, 73, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 4, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 5, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007015484, 6, 177, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 1, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 2, 103, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 3, 179, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 4, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 5, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020418015485, 6, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 1, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 2, 21, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 3, 167, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 4, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 5, 105, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 6, 53, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 7, 134, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 8, 14, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 9, 8, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 10, 167, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 11, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090322015486, 12, 177, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015487, 1, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015487, 2, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015487, 3, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015487, 4, 88, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010420015487, 5, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 1, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 2, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 3, 83, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 4, 61, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 5, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 6, 79, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 7, 41, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 8, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 9, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 10, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 11, 71, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 12, 26, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 13, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101022015488, 14, 78, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 1, 69, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 2, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 3, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 4, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 5, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 6, 73, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 7, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 8, 2, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 9, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 10, 15, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 11, 184, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 12, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090817015489, 13, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 1, 136, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 2, 18, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 3, 170, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 4, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 5, 22, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606015490, 6, 18, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 1, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 2, 66, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 3, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 4, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 5, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 6, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031226015491, 7, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 1, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 2, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 3, 42, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 4, 86, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 5, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 6, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 7, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 8, 85, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 9, 143, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 10, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 11, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 12, 78, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 13, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 14, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409015492, 15, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 1, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 2, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 3, 179, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 4, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 5, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 6, 12, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124015493, 7, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107015494, 1, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107015494, 2, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010107015494, 3, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 1, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 2, 24, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 3, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 4, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 5, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 6, 95, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 7, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 8, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 9, 159, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 10, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 11, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 12, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 13, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100403015495, 14, 26, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 1, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 2, 150, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 3, 35, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 4, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 5, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 6, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 7, 14, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 8, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 9, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 10, 138, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 11, 16, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 12, 191, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 13, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 14, 118, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 15, 190, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024015496, 16, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 1, 122, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 2, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 3, 19, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 4, 162, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 5, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 6, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 7, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 8, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 9, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 10, 52, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 11, 76, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 12, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 13, 192, 37, 18, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003015497, 14, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 1, 186, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 2, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 3, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 4, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 5, 18, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 6, 18, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 7, 139, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 8, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 9, 16, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 10, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 11, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 12, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 13, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 14, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 15, 145, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111202015498, 16, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 1, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 2, 120, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 3, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 4, 160, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 5, 181, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 6, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 7, 57, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203015499, 8, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 1, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 2, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 3, 191, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 4, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 5, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100722015500, 6, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 3, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 4, 49, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 5, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 6, 149, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 7, 192, 87, 18, 1566);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 8, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071220015851, 9, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 1, 66, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 2, 112, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 3, 84, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 4, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 5, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 6, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 7, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 8, 85, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 9, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 10, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 11, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 12, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 13, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 14, 112, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 15, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 16, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106015852, 17, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213015853, 1, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213015853, 2, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213015853, 3, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213015853, 4, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001213015853, 5, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 1, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 2, 124, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 3, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 4, 154, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 5, 189, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 6, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 7, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 8, 22, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061018015854, 9, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 1, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 2, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 3, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 4, 133, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 5, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 6, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 7, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 8, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 9, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 10, 117, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 11, 167, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 12, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100106015855, 13, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 1, 85, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 2, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 3, 14, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 4, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 5, 146, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 6, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030808015856, 7, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 1, 139, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 2, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 3, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 4, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 5, 174, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 6, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 7, 27, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 8, 138, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 9, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 10, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 11, 71, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 12, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 13, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 14, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 15, 98, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 16, 123, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919015857, 17, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 1, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 2, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 3, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 4, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 5, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 6, 63, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 7, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 8, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 9, 159, 94, 16, 1504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070601015858, 10, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 1, 78, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 2, 62, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 3, 108, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 4, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 5, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 6, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 7, 130, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 8, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 9, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 10, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 11, 49, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 12, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 13, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 14, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110814015859, 15, 189, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218015860, 1, 39, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218015860, 2, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218015860, 3, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218015860, 4, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010218015860, 5, 159, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331015861, 1, 16, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331015861, 2, 43, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331015861, 3, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010331015861, 4, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 1, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 2, 146, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 3, 21, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 4, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 5, 70, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 6, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 7, 84, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 8, 24, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 9, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 10, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 11, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 12, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100305015862, 13, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218015863, 1, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218015863, 2, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218015863, 3, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001218015863, 4, 71, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 1, 186, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 2, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 3, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 4, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 5, 111, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 6, 154, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 7, 66, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 8, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 9, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 10, 192, 78, 18, 1404);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 11, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 12, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 13, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 14, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 15, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 16, 74, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120108015864, 17, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 1, 95, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 2, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 3, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 4, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 5, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 6, 157, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 7, 118, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 8, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 9, 128, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 10, 93, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 11, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 12, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 13, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 14, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 15, 66, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218015865, 16, 103, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401015866, 1, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401015866, 2, 65, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401015866, 3, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401015866, 4, 85, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020401015866, 5, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 1, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 2, 91, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 3, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 4, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 5, 119, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 6, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 7, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 8, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 9, 180, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 10, 28, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 11, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 12, 3, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 13, 115, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110228015867, 14, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001231015868, 1, 45, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001231015868, 2, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 1, 84, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 2, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 3, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 4, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 5, 171, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 6, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 7, 51, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 8, 135, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 9, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 10, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 11, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 12, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 13, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 14, 157, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 15, 181, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120616015869, 16, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 1, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 2, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 3, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 4, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 5, 95, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 6, 50, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 7, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 8, 172, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 9, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 10, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 11, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 12, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090505015870, 13, 42, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 1, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 2, 88, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 3, 189, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 4, 3, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 5, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 6, 37, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 7, 120, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 8, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 9, 35, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 10, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071005015871, 11, 87, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107015872, 1, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107015872, 2, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107015872, 3, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001107015872, 4, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 1, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 2, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 3, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 4, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 5, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 6, 51, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041128015873, 7, 79, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430015874, 1, 128, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430015874, 2, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430015874, 3, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 1, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 2, 44, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 3, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 4, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070224015875, 5, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 2, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 3, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 4, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 5, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 6, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 7, 131, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 8, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 9, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 10, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 11, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 12, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 13, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 14, 140, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 15, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 16, 82, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 17, 19, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130430014727, 18, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 1, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 2, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 3, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 4, 36, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 5, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 6, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 7, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 8, 71, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 9, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530014728, 10, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 1, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 2, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 3, 165, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 4, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 5, 28, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 6, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 7, 142, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 8, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 9, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 10, 96, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 11, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 12, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 13, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 14, 60, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703014729, 15, 191, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 1, 114, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 2, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 3, 175, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 4, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 5, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 6, 94, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 7, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 8, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 9, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622014730, 10, 31, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 1, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 2, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 3, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 4, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 5, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 6, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 7, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 8, 82, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 9, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 10, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 11, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 12, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 13, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120104014731, 14, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 1, 87, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 2, 36, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 3, 77, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 4, 167, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 5, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 6, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 7, 68, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 8, 104, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 9, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 10, 41, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 11, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 12, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 13, 1, 13, 3, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 14, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922014732, 15, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 1, 34, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 2, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 3, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 4, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 5, 113, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 6, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 7, 162, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040407014733, 8, 21, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 1, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 2, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 3, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 4, 12, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 5, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 6, 130, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 7, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 8, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 9, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 10, 162, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 11, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 12, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 13, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 14, 77, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 15, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130915014734, 16, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 1, 92, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 2, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 3, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 4, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 5, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 6, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 7, 188, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 8, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 9, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 10, 94, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403014735, 11, 35, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 1, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 2, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 3, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 4, 72, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 5, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 6, 61, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 7, 79, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 8, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 9, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 10, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 11, 20, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 12, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 13, 140, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 14, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 15, 96, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140126014736, 16, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 1, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 2, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 3, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 4, 32, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 5, 27, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 6, 48, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 7, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 8, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051107014737, 9, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 1, 27, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 2, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 3, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 4, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 5, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 6, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 7, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 8, 119, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 9, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 10, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 11, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 12, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 13, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091215014738, 14, 118, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 1, 147, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 2, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 3, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 4, 19, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 5, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 6, 177, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 7, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 8, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 9, 78, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 10, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 11, 106, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080315014739, 12, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 1, 191, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 2, 77, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 3, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 4, 104, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 5, 167, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 6, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 7, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 8, 2, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 9, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 10, 161, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 11, 94, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 12, 108, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101014014740, 13, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 1, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 2, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 3, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 4, 89, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 5, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 6, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306014741, 7, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 1, 94, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 2, 46, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 3, 170, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 4, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 5, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 6, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 7, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 8, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 9, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 10, 112, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 11, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 12, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 13, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 14, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 15, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 16, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419014742, 17, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 1, 102, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 2, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 3, 121, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 4, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 5, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 6, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 7, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 8, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 9, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 10, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 11, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 12, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 13, 64, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120829014743, 14, 42, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 1, 140, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 2, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 3, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 4, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 5, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 6, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 7, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 8, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 9, 30, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 10, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080822014744, 11, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 1, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 2, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 3, 162, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 4, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 5, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 6, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 7, 18, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 8, 101, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 9, 128, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119014745, 10, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 1, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 2, 182, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 3, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 4, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 5, 79, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 6, 77, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 7, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 8, 88, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 9, 91, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 10, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060825015086, 11, 188, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 1, 108, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 2, 114, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 3, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 4, 33, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 5, 43, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 6, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 7, 19, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 8, 58, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628015087, 9, 1, 26, 3, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 1, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 2, 121, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 3, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 4, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 5, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 6, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 7, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 8, 111, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 9, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 10, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 11, 106, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022015088, 12, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 1, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 2, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 3, 166, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 4, 40, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 5, 38, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 6, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 7, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 8, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 9, 111, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 10, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 11, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 12, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 13, 110, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 14, 87, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 15, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120928015089, 16, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 1, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 2, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 3, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 4, 169, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 5, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030624015090, 6, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323015091, 1, 35, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323015091, 2, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323015091, 3, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323015091, 4, 122, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020323015091, 5, 191, 44, 17, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 1, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 2, 158, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 3, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 4, 69, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 5, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 6, 65, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 7, 179, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061121015092, 8, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 1, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 2, 18, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 3, 56, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 4, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 5, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 6, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 7, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060509015093, 8, 40, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 1, 186, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 2, 158, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 3, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 4, 175, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 5, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 6, 174, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 7, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 8, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015094, 9, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116015095, 1, 115, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116015095, 2, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116015095, 3, 188, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116015095, 4, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910015096, 1, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910015096, 2, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000910015096, 3, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 1, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 2, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 3, 191, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 4, 173, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 5, 82, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 6, 32, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 7, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 8, 156, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 9, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 10, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 11, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 12, 48, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 13, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623015097, 14, 26, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 1, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 2, 119, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 3, 32, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 4, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 5, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 6, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 7, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 8, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 9, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 10, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 11, 101, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 12, 178, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 13, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 14, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 15, 53, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 16, 58, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 17, 114, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 18, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112015098, 19, 156, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 1, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 2, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 3, 101, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 4, 59, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 5, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 6, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 7, 183, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 8, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 9, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 10, 16, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 11, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 12, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 13, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 14, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 15, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622015099, 16, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 1, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 2, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 3, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 4, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 5, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 6, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 7, 172, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 8, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 9, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 10, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 11, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 12, 19, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 13, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 14, 101, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100619015100, 15, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 1, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 2, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 3, 95, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 4, 5, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 5, 10, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021130015101, 6, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 1, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 2, 61, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 3, 22, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 4, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 5, 62, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 6, 183, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 7, 45, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 8, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 9, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 10, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 11, 54, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 12, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091203015102, 13, 93, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 1, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 2, 100, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 3, 161, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 4, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 5, 9, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 6, 123, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 7, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030101015103, 8, 115, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 1, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 2, 173, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 3, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 4, 69, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 5, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 6, 117, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 7, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 8, 173, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 9, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 10, 126, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 11, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 12, 70, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 13, 28, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111017015104, 14, 19, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 1, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 2, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 3, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 4, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 5, 48, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 6, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 7, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 8, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 9, 62, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060403015105, 10, 52, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 1, 69, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 2, 65, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 3, 25, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 4, 60, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 5, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 6, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 7, 120, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 8, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 9, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 10, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 11, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 12, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 13, 117, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 14, 149, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 15, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131109015106, 16, 145, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509015107, 1, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509015107, 2, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509015107, 3, 26, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509015107, 4, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020509015107, 5, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 1, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 2, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 3, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 4, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 5, 14, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028015108, 6, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 1, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 2, 156, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 3, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 4, 157, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 5, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 6, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131015109, 7, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 11, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 12, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 13, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928016626, 1, 50, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928016626, 2, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928016626, 3, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928016626, 4, 96, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928016626, 5, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 1, 36, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 2, 9, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 3, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 4, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 5, 173, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 6, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 7, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 8, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 9, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 10, 187, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070331016627, 11, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 1, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 2, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 3, 146, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 4, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 5, 114, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 6, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 7, 51, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 8, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 9, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 10, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 11, 38, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081215016628, 12, 174, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 1, 27, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 2, 133, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 3, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 4, 156, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 5, 113, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 6, 120, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 7, 172, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 8, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 9, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 10, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 11, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 12, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 13, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 14, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 15, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130827016629, 16, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 1, 95, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 2, 57, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 3, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 4, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 5, 67, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 6, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 7, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 8, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050820016630, 9, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 1, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 2, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 3, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 4, 52, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 5, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 6, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 7, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041027016631, 8, 28, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103016632, 1, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103016632, 2, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011103016632, 3, 83, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 1, 74, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 2, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 3, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 4, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 5, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 6, 127, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 7, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 8, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 9, 92, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 10, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 11, 151, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 12, 24, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 13, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110531016633, 14, 92, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 1, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 2, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 3, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 4, 132, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 5, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 6, 150, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 7, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 8, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060520016634, 9, 121, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 1, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 2, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 3, 177, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 4, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 5, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 6, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 7, 29, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016635, 8, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 1, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 2, 92, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 3, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 4, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 5, 168, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 6, 107, 35, 9, 315);
commit;
prompt 164000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 7, 80, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 8, 111, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 9, 119, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 10, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 11, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 12, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 13, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 14, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 15, 100, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130514016636, 16, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 1, 27, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 2, 50, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 3, 22, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 4, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 5, 167, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 6, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 7, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 8, 18, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 9, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 10, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071213016637, 11, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016638, 1, 36, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016638, 2, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016638, 3, 152, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016638, 4, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016638, 5, 67, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 1, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 2, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 3, 161, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 4, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 5, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 6, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 7, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 8, 140, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 9, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 10, 127, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 11, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 12, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 13, 86, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 14, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 15, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110421016639, 16, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 1, 145, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 2, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 3, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 4, 188, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 5, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 6, 165, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 7, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 8, 126, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 9, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 10, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 11, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 12, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 13, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 14, 162, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 15, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131214016640, 16, 77, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 1, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 2, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 3, 14, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 4, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 5, 50, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 6, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050411016641, 7, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 1, 179, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 2, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 3, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 4, 186, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 5, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 6, 45, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 7, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 8, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 9, 179, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 10, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 11, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 12, 58, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 13, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 14, 28, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120426016642, 15, 179, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 1, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 2, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 3, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 4, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 5, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040701016643, 6, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 1, 42, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 2, 45, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 3, 99, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 4, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 5, 8, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 6, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 7, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 8, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 9, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 10, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 11, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 12, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 13, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016644, 14, 35, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 1, 117, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 2, 9, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 3, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 4, 38, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 5, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 6, 61, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 7, 76, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 8, 22, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 9, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 10, 115, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 11, 106, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 12, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 13, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101205016645, 14, 159, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 1, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 2, 67, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 3, 164, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 4, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 5, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 6, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 7, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 8, 101, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 9, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 10, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 11, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 12, 91, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090302016646, 13, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 1, 136, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 2, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 3, 190, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 4, 86, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 5, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 6, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 7, 171, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 8, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 9, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 10, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 11, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331017013, 1, 55, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331017013, 2, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331017013, 3, 180, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331017013, 4, 102, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000331017013, 5, 192, 72, 18, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 1, 190, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 2, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 3, 131, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 4, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 5, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 6, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 7, 29, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 8, 14, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 9, 25, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080911017014, 10, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 1, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 2, 59, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 3, 4, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 4, 143, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 5, 102, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 6, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 7, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 8, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 9, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 10, 47, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 11, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017015, 12, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 1, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 2, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 3, 38, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 4, 123, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 5, 105, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 6, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 7, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 8, 114, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 9, 42, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 10, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 11, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 12, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 13, 33, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 14, 63, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111224017016, 15, 170, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 1, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 2, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 3, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 4, 189, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 5, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030210017017, 6, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 1, 174, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 2, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 3, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 4, 55, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 5, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 6, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 7, 83, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031015017018, 8, 33, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 1, 34, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 2, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 3, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 4, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 5, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 6, 152, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 7, 186, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 8, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 9, 136, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 10, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 11, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 12, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 13, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 14, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 15, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130308017019, 16, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 1, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 2, 23, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 3, 167, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 4, 159, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 5, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 6, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 7, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 8, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 9, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 10, 52, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070901017020, 11, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 1, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 2, 53, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 3, 122, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 4, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 5, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 6, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 7, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 8, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 9, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 10, 104, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 11, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 12, 67, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 13, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 14, 30, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 15, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120918017021, 16, 14, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 1, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 2, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 3, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 4, 82, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 5, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030211017022, 6, 133, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 1, 83, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 2, 149, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 3, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 4, 140, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 5, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 6, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 7, 10, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 8, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017023, 9, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 1, 148, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 2, 105, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 3, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 4, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 5, 96, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 6, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 7, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 8, 51, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 9, 73, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 10, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 11, 153, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100313017024, 12, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 1, 93, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 2, 135, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 3, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 4, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 5, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 6, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 7, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 8, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 9, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051202017025, 10, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 1, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 2, 36, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 3, 91, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 4, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 5, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 6, 19, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 7, 114, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 8, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 9, 92, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 10, 53, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 11, 166, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 12, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 13, 66, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 14, 41, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017026, 15, 145, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 1, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 2, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 3, 75, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 4, 3, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 5, 109, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 6, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 7, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 8, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 9, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 10, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 11, 171, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 12, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 13, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 14, 2, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106017027, 15, 15, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204017028, 1, 65, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204017028, 2, 72, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204017028, 3, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204017028, 4, 179, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 1, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 2, 2, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 3, 133, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 4, 39, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 5, 82, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 6, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 7, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051022017029, 8, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 1, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 2, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 3, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 4, 97, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 5, 2, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 6, 120, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 7, 118, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 8, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 9, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 10, 66, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 11, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 12, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108017030, 13, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 1, 141, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 2, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 3, 159, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 4, 98, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 5, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 6, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 7, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 8, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 9, 60, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 10, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 11, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090114017031, 12, 141, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 1, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 2, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 3, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 4, 73, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 5, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 6, 90, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 7, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930017032, 8, 35, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 1, 113, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 2, 133, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 3, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 4, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 5, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 6, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 7, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 8, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 9, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 10, 107, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 11, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070627017033, 12, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008017034, 1, 160, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008017034, 2, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008017034, 3, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008017034, 4, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031008017034, 5, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 1, 107, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 2, 19, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 3, 114, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 4, 99, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 5, 139, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 6, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021005017035, 7, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 4, 102, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 5, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 6, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 7, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 8, 1, 20, 3, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 9, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 10, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 11, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 12, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 13, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 14, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 15, 91, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 1, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 2, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 3, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 4, 107, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 5, 11, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 6, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040424017373, 7, 38, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 1, 151, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 2, 7, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 3, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 4, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 5, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 6, 37, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030120017374, 7, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 1, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 2, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 3, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 4, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 5, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 6, 38, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 7, 43, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 8, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 9, 148, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071211017375, 10, 5, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 1, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 2, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 3, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 4, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 5, 59, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 6, 169, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 7, 78, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 8, 6, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 9, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 10, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 11, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 12, 21, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 13, 112, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090818017376, 14, 48, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 1, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 2, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 3, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 4, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 5, 21, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 6, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 7, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 8, 133, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 9, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 10, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 11, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 12, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 13, 153, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 14, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 15, 68, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 16, 51, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 17, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140106017377, 18, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017378, 1, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017378, 2, 44, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017378, 3, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017378, 4, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017378, 5, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 1, 35, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 2, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 3, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 4, 83, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 5, 6, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 6, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 7, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 8, 2, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 9, 87, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 10, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 11, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 12, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 13, 56, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 14, 156, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110322017379, 15, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 1, 192, 39, 18, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 2, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 3, 27, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 4, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 5, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 6, 137, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813017380, 7, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 1, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 2, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 3, 2, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 4, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 5, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 6, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 7, 156, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 8, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 9, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017381, 10, 13, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 1, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 2, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 3, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 4, 159, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 5, 124, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 6, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 7, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 8, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 9, 161, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070720017382, 10, 70, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 1, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 2, 164, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 3, 96, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 4, 89, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 5, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 6, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 7, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 8, 1, 64, 3, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 9, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 10, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 11, 110, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 12, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 13, 13, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 14, 24, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120606017383, 15, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 1, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 2, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 3, 189, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 4, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 5, 112, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 6, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 7, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 8, 50, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 9, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061010017384, 10, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 1, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 2, 179, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 3, 2, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 4, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 5, 33, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011215017385, 6, 189, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 1, 49, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 2, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 3, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 4, 30, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 5, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 6, 152, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 7, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 8, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 9, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 10, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 11, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 12, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 13, 172, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100311017386, 14, 69, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 1, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 2, 184, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 3, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 4, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 5, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 6, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 7, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 8, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 9, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 10, 8, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 11, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 12, 15, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 13, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 14, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 15, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 16, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 17, 33, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 18, 169, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322017387, 19, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 1, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 2, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 3, 132, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 4, 76, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 5, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031223017388, 6, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 1, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 2, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 3, 70, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 4, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 5, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 6, 110, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 7, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 8, 45, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 9, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 10, 160, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 11, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 12, 89, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 13, 31, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 14, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130820017389, 15, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 1, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 2, 12, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 3, 170, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 4, 177, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 5, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 6, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 7, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 8, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 9, 99, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 10, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 11, 104, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 12, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 13, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100808017390, 14, 102, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 1, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 2, 146, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 3, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 4, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 5, 166, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017391, 6, 188, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 1, 97, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 2, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 3, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 4, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 5, 12, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 6, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 7, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 8, 171, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 9, 11, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081108017392, 10, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 1, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 2, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 3, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 4, 125, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 5, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 6, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 7, 139, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 8, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 9, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 8, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 9, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 10, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 11, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 12, 131, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 13, 21, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 14, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 15, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 16, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 17, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302016256, 1, 110, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000302016256, 2, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121016257, 1, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121016257, 2, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 1, 114, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 2, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 3, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 4, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 5, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913016258, 6, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 1, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 2, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 3, 80, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 4, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 5, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 6, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 7, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 8, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 9, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 10, 157, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091113016259, 11, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030404016260, 1, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030404016260, 2, 159, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030404016260, 3, 55, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030404016260, 4, 49, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030404016260, 5, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 1, 155, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 2, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 3, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 4, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 5, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 6, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 7, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 8, 32, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 9, 29, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 10, 47, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 11, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 12, 28, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 13, 179, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 14, 167, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016261, 15, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 1, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 2, 62, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 3, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 4, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 5, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 6, 67, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 7, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 8, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 9, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 10, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 11, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 12, 64, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 13, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110101016262, 14, 77, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308016263, 1, 115, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308016263, 2, 68, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010308016263, 3, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 1, 104, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 2, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 3, 135, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 4, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 5, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 6, 155, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 7, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 8, 77, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 9, 9, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 10, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 11, 62, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 12, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016264, 13, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 1, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 2, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 3, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 4, 11, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 5, 168, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 6, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 7, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 8, 70, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 9, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 10, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 11, 120, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 12, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 13, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 14, 99, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110729016265, 15, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529016266, 1, 80, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529016266, 2, 148, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529016266, 3, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529016266, 4, 42, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000529016266, 5, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 1, 28, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 2, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 3, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 4, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 5, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 6, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 7, 18, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 8, 174, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 9, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 10, 17, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 11, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 12, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813016267, 13, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524016268, 1, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524016268, 2, 115, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010524016268, 3, 143, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 1, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 2, 185, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 3, 105, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 4, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 5, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 6, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 7, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 8, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060911016269, 9, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 1, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 2, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 3, 58, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 4, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 5, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 6, 140, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 7, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 8, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 9, 184, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071225016270, 10, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 1, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 2, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 3, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 4, 102, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 5, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 6, 61, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 7, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 8, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 9, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 10, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 11, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100107016271, 12, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 1, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 2, 74, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 3, 72, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 4, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 5, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030916016272, 6, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 1, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 2, 70, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 3, 74, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 4, 118, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 5, 165, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 6, 113, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 7, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 8, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 9, 10, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 10, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 11, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 12, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 13, 59, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 14, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121204016273, 15, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016274, 1, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016274, 2, 59, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016274, 3, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016274, 4, 39, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016274, 5, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 1, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 2, 144, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 3, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 4, 45, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 5, 36, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 6, 66, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 7, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 8, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 9, 112, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060518016275, 10, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 1, 142, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 2, 44, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 3, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 4, 132, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 5, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 6, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 7, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 8, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061120016276, 9, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 1, 44, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 2, 91, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 3, 153, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 4, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 5, 2, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 6, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 7, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 8, 29, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 9, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 10, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 11, 168, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080708016277, 12, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 1, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 2, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 3, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 4, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 5, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 6, 87, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 7, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050617016278, 8, 106, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 1, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 2, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 3, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 4, 117, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 5, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 6, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 7, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 8, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 9, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 10, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 11, 115, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 12, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 13, 7, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 14, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 15, 29, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110813016279, 16, 71, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 1, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 2, 11, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 3, 74, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 4, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 5, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 6, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 7, 22, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 8, 22, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 9, 152, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 10, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 9, 36, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050310016647, 10, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 1, 114, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 2, 116, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 3, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 4, 2, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 5, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 6, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 7, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 8, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 9, 176, 37, 16, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 10, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 11, 11, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 12, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016648, 13, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 1, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 2, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 3, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 4, 50, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 5, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 6, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 7, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 8, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 9, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050119016649, 10, 185, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 1, 177, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 2, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 3, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 4, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 5, 156, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 6, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 7, 7, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 8, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 9, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071015016650, 10, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 1, 146, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 2, 38, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 3, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 4, 35, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 5, 191, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 6, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 7, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 8, 138, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 9, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327016651, 10, 21, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 1, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 2, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 3, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 4, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 5, 104, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 6, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 7, 173, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 8, 52, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 9, 172, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 10, 31, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 11, 103, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 12, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 13, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 14, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101213016652, 15, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 1, 105, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 2, 131, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 3, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 4, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 5, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 6, 19, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 7, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060923016653, 8, 51, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 1, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 2, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 3, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 4, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 5, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 6, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 7, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 8, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 9, 158, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 10, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 11, 161, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 12, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 13, 181, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 14, 68, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 15, 69, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 16, 103, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203016654, 17, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 1, 21, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 2, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 3, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 4, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 5, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 6, 76, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 7, 84, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 8, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 9, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 10, 106, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 11, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 12, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 13, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 14, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 15, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 16, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016655, 17, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 1, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 2, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 3, 97, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 4, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 5, 8, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 6, 18, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 7, 187, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 8, 66, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120016656, 9, 156, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 1, 143, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 2, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 3, 178, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 4, 156, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 5, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 6, 23, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 7, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 8, 7, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 9, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 10, 87, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 11, 20, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 12, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 13, 62, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 14, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 15, 52, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130409016657, 16, 116, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818016658, 1, 62, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818016658, 2, 148, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000818016658, 3, 97, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 1, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 2, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 3, 151, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 4, 13, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 5, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 6, 100, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 7, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 8, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 9, 75, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 10, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 11, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 12, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 13, 60, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 14, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 15, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 16, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130511016659, 17, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 1, 30, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 2, 109, 39, 11, 429);
commit;
prompt 165000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 3, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 4, 94, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 5, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 6, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 7, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050912016660, 8, 95, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 1, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 2, 34, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 3, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 4, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 5, 100, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 6, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 7, 128, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 8, 190, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 9, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 10, 184, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 11, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 12, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 13, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 14, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 15, 177, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016661, 16, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 1, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 2, 178, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 3, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 4, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 5, 51, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 6, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 7, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 8, 93, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 9, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 10, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 11, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090716016662, 12, 98, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 1, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 2, 84, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 3, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 4, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 5, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 6, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 7, 112, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 8, 157, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 9, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 10, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 11, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 12, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417016663, 13, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130016664, 1, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130016664, 2, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130016664, 3, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020130016664, 4, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 1, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 2, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 3, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 4, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 5, 144, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 6, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 7, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 8, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 9, 155, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 10, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 11, 98, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080402016665, 12, 130, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 1, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 2, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 3, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 4, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 5, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 6, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 7, 95, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 8, 102, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 9, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 10, 79, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516016666, 11, 67, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 1, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 2, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 3, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 4, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 5, 91, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 6, 178, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 7, 77, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 8, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 9, 131, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 10, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 11, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 12, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 13, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 14, 9, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 15, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 16, 139, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 1, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 2, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 3, 27, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 4, 34, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 5, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 6, 109, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040504017036, 7, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 1, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 2, 51, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 3, 191, 27, 17, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 4, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 5, 150, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 6, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 7, 17, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 8, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 9, 50, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 10, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 11, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025017037, 12, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 1, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 2, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 3, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 4, 1, 16, 3, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 5, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 6, 110, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 7, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 8, 45, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 9, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 10, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 11, 156, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 12, 125, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 13, 122, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125017038, 14, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 1, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 2, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 3, 35, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 4, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 5, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 6, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030523017039, 7, 90, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404017040, 1, 145, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404017040, 2, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404017040, 3, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010404017040, 4, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 1, 59, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 2, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 3, 89, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 4, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 5, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 6, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 7, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 8, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 9, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 10, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 11, 10, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 12, 147, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 13, 11, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 14, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017041, 15, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 1, 179, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 2, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 3, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 4, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 5, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 6, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 7, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017042, 8, 148, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 1, 69, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 2, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 3, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 4, 160, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 5, 150, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 6, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 7, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 8, 134, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 9, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 10, 192, 27, 18, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 11, 28, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100825017043, 12, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 1, 137, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 2, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 3, 90, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 4, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 5, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 6, 82, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 7, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219017044, 8, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 1, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 2, 5, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 3, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 4, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 5, 4, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 6, 131, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 7, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 8, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 9, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081008017045, 10, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 1, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 2, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 3, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 4, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 5, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 6, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040618017046, 7, 58, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 1, 31, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 2, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 3, 34, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 4, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 5, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 6, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 7, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 8, 130, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 9, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 10, 103, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 11, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 12, 11, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 13, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 14, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 15, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 16, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 17, 101, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130811017047, 18, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 1, 119, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 2, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 3, 122, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 4, 185, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 5, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 6, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 7, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 8, 38, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 9, 61, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 10, 37, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 11, 162, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 12, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 13, 102, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120706017048, 14, 68, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 1, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 2, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 3, 128, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 4, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 5, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 6, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 7, 45, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 8, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 9, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 10, 128, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 11, 13, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 12, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 13, 132, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091019017049, 14, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 1, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 2, 81, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 3, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 4, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 5, 148, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 6, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 7, 31, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 8, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 9, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 10, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 11, 74, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 12, 170, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 13, 69, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 14, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 15, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 16, 118, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808017050, 17, 84, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 1, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 2, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 3, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 4, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 5, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 6, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 7, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 8, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 9, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 10, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 11, 141, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 12, 51, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 13, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 14, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 15, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130630017051, 16, 89, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 1, 111, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 2, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 3, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 4, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 5, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021205017052, 6, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 1, 78, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 2, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 3, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 4, 156, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 5, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 6, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 7, 111, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 8, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 9, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 10, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 11, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 12, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 13, 186, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 14, 17, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 15, 131, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017053, 16, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 1, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 2, 148, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 3, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 4, 45, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 5, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 6, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 7, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 8, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 9, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 10, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 11, 146, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090301017054, 12, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 1, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 2, 184, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 3, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 4, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 5, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017055, 6, 176, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 1, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 2, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 3, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 4, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 5, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 6, 90, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 7, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 8, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 9, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 10, 185, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 11, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 12, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017056, 13, 69, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 1, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 3, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 10, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 11, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 12, 177, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 13, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 14, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017393, 15, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 1, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 2, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 3, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 4, 188, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 5, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 6, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 7, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 8, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 9, 24, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 10, 161, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 11, 75, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 12, 64, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 13, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017394, 14, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 1, 12, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 2, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 3, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 4, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 5, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 6, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 7, 139, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 8, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 9, 131, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050616017395, 10, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 1, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 2, 188, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 3, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 4, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 5, 63, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 6, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 7, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 8, 141, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 9, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 10, 43, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 11, 84, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 12, 25, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 13, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 14, 104, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110608017396, 15, 26, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 1, 5, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 2, 180, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 3, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 4, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 5, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 6, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 7, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 8, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 9, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 10, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 11, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404017397, 12, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 1, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 2, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 3, 114, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 4, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 5, 85, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 6, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 7, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 8, 182, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 9, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 10, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 11, 78, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 12, 142, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 13, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 14, 191, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110812017398, 15, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 1, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 2, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 3, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 4, 71, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 5, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 6, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 7, 138, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 8, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 9, 60, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 10, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 11, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 12, 115, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 13, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 14, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 15, 8, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 16, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 17, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017399, 18, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 1, 25, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 2, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 3, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 4, 60, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 5, 73, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 6, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 7, 85, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 8, 111, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 9, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 10, 110, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 11, 17, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 12, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 13, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 14, 116, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 15, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 16, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120906017400, 17, 65, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 1, 154, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 2, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 3, 139, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 4, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 5, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122017401, 6, 12, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 1, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 2, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 3, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 4, 73, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 5, 39, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 6, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 7, 71, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 8, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 9, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 10, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 11, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 12, 157, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 13, 163, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 14, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120618017402, 15, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 1, 53, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 2, 89, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 3, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 4, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 5, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 6, 121, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 7, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 8, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 9, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 10, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 11, 81, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100222017403, 12, 120, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031017404, 1, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001031017404, 2, 98, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 1, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 2, 84, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 3, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 4, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 5, 45, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010927017405, 6, 95, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 1, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 2, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 3, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 4, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 5, 90, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 6, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 7, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 8, 71, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 9, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 10, 90, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 11, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 12, 30, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 13, 111, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 14, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121017406, 15, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 1, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 2, 147, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 3, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 4, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 5, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 6, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 7, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 8, 122, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 9, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 10, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 11, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 12, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 13, 13, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 14, 50, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 15, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 16, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828017407, 17, 49, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 1, 170, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 2, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 3, 34, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 4, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 5, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 6, 55, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 7, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017408, 8, 40, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013017409, 1, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013017409, 2, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013017409, 3, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013017409, 4, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031013017409, 5, 83, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 1, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 2, 80, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 3, 116, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 4, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 5, 86, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 6, 98, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 7, 31, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 8, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 9, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 10, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 11, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 12, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 13, 55, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 14, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 15, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130723017410, 16, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 1, 32, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 2, 124, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 3, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 4, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 5, 106, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 6, 79, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 7, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 8, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 9, 97, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060209017411, 10, 80, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 1, 96, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 2, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 3, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 4, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 5, 65, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 6, 64, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 7, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 8, 163, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 9, 179, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 10, 115, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 11, 143, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 12, 12, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 13, 102, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 14, 35, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130830017412, 15, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 1, 60, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 2, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 3, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 4, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 5, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 11, 30, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 12, 187, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 13, 187, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 14, 136, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607016280, 15, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 1, 157, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 2, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 3, 61, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 4, 149, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 5, 97, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 6, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 7, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 8, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 9, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 10, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071006016281, 11, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 1, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 2, 180, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 3, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 4, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 5, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 6, 104, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 7, 76, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 8, 182, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 9, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 10, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 11, 101, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 12, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 13, 36, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 14, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101202016282, 15, 153, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 1, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 2, 89, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 3, 166, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 4, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 5, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 6, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202016283, 7, 143, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 1, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 2, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 3, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 4, 114, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 5, 123, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 6, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 7, 110, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 8, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 9, 192, 19, 18, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 10, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 11, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 12, 43, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 13, 39, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016284, 14, 4, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414016285, 1, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414016285, 2, 87, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414016285, 3, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010414016285, 4, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 1, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 2, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 3, 118, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 4, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 5, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016286, 6, 94, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 1, 53, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 2, 40, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 3, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 4, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 5, 45, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 6, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 7, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 8, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040405016287, 9, 112, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 1, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 2, 173, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 3, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 4, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 5, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 6, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 7, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 8, 164, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 9, 32, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 10, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 11, 27, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 12, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 13, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121016288, 14, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 1, 37, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 2, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 3, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 4, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 5, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 6, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 7, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 8, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 9, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 10, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 11, 48, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 12, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 13, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110831016289, 14, 30, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 1, 18, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 2, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 3, 40, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 4, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 5, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 6, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 7, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 8, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 9, 153, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 10, 36, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 11, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 12, 99, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 13, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100628016290, 14, 165, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 1, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 2, 163, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 3, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 4, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 5, 6, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 6, 11, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 7, 152, 1, 16, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 8, 177, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 9, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 10, 134, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 11, 44, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 12, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 13, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 14, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 15, 35, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120901016291, 16, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 1, 152, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 2, 150, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 3, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 4, 189, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 5, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 6, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 7, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 8, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 9, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 10, 108, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 11, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 12, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 13, 115, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 14, 168, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 15, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307016292, 16, 60, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 1, 181, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 2, 126, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 3, 107, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 4, 163, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 5, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 6, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 7, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040724016293, 8, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 1, 183, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 2, 32, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 3, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 4, 131, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 5, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 6, 151, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 7, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 8, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 9, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 10, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 11, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 12, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 13, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 14, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 15, 36, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 16, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016294, 17, 90, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 1, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 2, 53, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 3, 100, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 4, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 5, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030606016295, 6, 86, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 1, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 2, 97, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 3, 94, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 4, 5, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 5, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011208016296, 6, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 1, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 2, 128, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 3, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 4, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 5, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 6, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 7, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 8, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 9, 35, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 10, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 11, 166, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 12, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 13, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 14, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 15, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 16, 177, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016297, 17, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 1, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 2, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 3, 145, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 4, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 5, 53, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 6, 2, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 7, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 8, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 9, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 10, 11, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 11, 55, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016298, 12, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 1, 39, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 2, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 3, 30, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 4, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 5, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 6, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 7, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 8, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 9, 111, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 10, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 11, 110, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 12, 95, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 13, 31, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 14, 141, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 15, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120324016299, 16, 7, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 1, 23, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 2, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 3, 139, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 4, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 5, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 6, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 7, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 8, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060410016300, 9, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 1, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 2, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 3, 141, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 4, 149, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130621016667, 17, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103016668, 1, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103016668, 2, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103016668, 3, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103016668, 4, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021103016668, 5, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 1, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 2, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 3, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 4, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 5, 142, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 6, 86, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 7, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050325016669, 8, 146, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 1, 37, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 2, 144, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 3, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 4, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 5, 83, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 6, 104, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 7, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 8, 137, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 9, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 10, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 11, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 12, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 13, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091119016670, 14, 189, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 1, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 2, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 3, 109, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 4, 145, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 5, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020124016671, 6, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 1, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 2, 173, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 3, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 4, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 5, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 6, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 7, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060404016672, 8, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 1, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 2, 111, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 3, 177, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 4, 147, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 5, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 6, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 7, 170, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401016673, 8, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 1, 56, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 2, 149, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 3, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 4, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 5, 174, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 6, 134, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 7, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629016674, 8, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 1, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 2, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 3, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 4, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 5, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 6, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 7, 91, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 8, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051113016675, 9, 94, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 1, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 2, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 3, 57, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 4, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 5, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 6, 43, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 7, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 8, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 9, 151, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 10, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 11, 76, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 12, 1, 26, 3, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 13, 22, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111112016676, 14, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 1, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 2, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 3, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 4, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 5, 9, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 6, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 7, 162, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 8, 80, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118016677, 9, 156, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 1, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 2, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 3, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 4, 21, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 5, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030223016678, 6, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010016679, 1, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010016679, 2, 126, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010016679, 3, 168, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021010016679, 4, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 1, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 2, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 3, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 4, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 5, 18, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 6, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 7, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 8, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 9, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016680, 10, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 1, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 2, 114, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 3, 42, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 4, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 5, 85, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016681, 6, 50, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 1, 185, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 2, 14, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 3, 96, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 4, 32, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 5, 43, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016682, 6, 153, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 1, 73, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 2, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 3, 75, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 4, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 5, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 6, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 7, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 8, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 9, 56, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 10, 188, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 11, 67, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080209016683, 12, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 1, 91, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 2, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 3, 58, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 4, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 5, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 6, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020409016684, 7, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 1, 44, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 2, 51, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 3, 9, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 4, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 5, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 6, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 7, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030117016685, 8, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 1, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 2, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 3, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 4, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 5, 5, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 6, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213016686, 7, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825016687, 1, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825016687, 2, 44, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825016687, 3, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 1, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 2, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 3, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 4, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 5, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 6, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 7, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 8, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 9, 83, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 10, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 11, 144, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 12, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 13, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110726016688, 14, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 1, 161, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 2, 151, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 3, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 4, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 5, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 6, 17, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 7, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 8, 126, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 9, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 10, 107, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016689, 11, 78, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 1, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 2, 102, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 3, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 4, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 5, 38, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 6, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 7, 23, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 8, 69, 35, 9, 315);
commit;
prompt 166000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 9, 164, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 10, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 11, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 12, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 13, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 14, 64, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 15, 93, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 16, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 17, 126, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140119016690, 18, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 1, 177, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 2, 60, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 3, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 4, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 5, 166, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 6, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 7, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 8, 29, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 9, 165, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 10, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 11, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 12, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016691, 13, 179, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 1, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 2, 171, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 3, 153, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 4, 143, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 5, 36, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 6, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 7, 11, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 8, 113, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 9, 112, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 10, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 11, 13, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 12, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 13, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 14, 172, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 15, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316016692, 16, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208016693, 1, 109, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208016693, 2, 63, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208016693, 3, 172, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208016693, 4, 140, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010208016693, 5, 67, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 1, 188, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 2, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 3, 188, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 4, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 5, 55, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 6, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 7, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 8, 127, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 9, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 10, 169, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 11, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 12, 155, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 13, 16, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 14, 88, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110803017057, 15, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 1, 98, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 2, 109, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 3, 52, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 4, 144, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 5, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 6, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 7, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 8, 78, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 9, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060917017058, 10, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 1, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 2, 118, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 3, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 4, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 5, 164, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 6, 120, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 7, 168, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 8, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 9, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 10, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 11, 154, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 12, 123, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091117017059, 13, 18, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 1, 24, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 2, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 3, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 4, 189, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 5, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 6, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 7, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 8, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 9, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 10, 107, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 11, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 12, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090613017060, 13, 135, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 1, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 2, 161, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 3, 66, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 4, 20, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 5, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 6, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031124017061, 7, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021215017062, 1, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021215017062, 2, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021215017062, 3, 187, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021215017062, 4, 158, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 1, 61, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 2, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 3, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 4, 181, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 5, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 6, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 7, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 8, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 9, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628017063, 10, 141, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 1, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 2, 82, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 3, 31, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 4, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 5, 40, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 6, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 7, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061116017064, 8, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 1, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 2, 103, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 3, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 4, 95, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 5, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 6, 88, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 7, 161, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040509017065, 8, 116, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 1, 138, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 2, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 3, 92, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 4, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 5, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 6, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041201017066, 7, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 1, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 2, 69, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 3, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 4, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 5, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 6, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 7, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 8, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 9, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 10, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 11, 132, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 12, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 13, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 14, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 15, 111, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120803017067, 16, 134, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 1, 86, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 2, 185, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 3, 74, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 4, 12, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 5, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020312017068, 6, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 1, 101, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 2, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 3, 74, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 4, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 5, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 6, 143, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 7, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 8, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 9, 116, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 10, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 11, 36, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 12, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 13, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017069, 14, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 1, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 2, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 3, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 4, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 5, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030319017070, 6, 81, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 1, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 2, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 3, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 4, 61, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 5, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 6, 142, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 7, 73, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 8, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 9, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 10, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 11, 15, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010017071, 12, 97, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 1, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 2, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 3, 154, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 4, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 5, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 6, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050126017072, 7, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 1, 32, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 2, 62, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 3, 36, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 4, 155, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 5, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 6, 129, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050921017073, 7, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 1, 191, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 2, 49, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 3, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 4, 183, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 5, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 6, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 7, 99, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 8, 74, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 9, 115, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 10, 13, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 11, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 12, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101127017074, 13, 46, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826017075, 1, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000826017075, 2, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 1, 46, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 2, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 3, 16, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 4, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 5, 123, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 6, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 7, 188, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 8, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 9, 45, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 10, 58, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 11, 36, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 12, 57, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 13, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111005017076, 14, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 1, 120, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 2, 149, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 3, 60, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 4, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 5, 50, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 6, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 7, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 8, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 9, 108, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 10, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 11, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 12, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 13, 43, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 14, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 15, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120526017077, 16, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 1, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 2, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 3, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 4, 25, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 5, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030207017078, 6, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313017079, 1, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313017079, 2, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313017079, 3, 55, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313017079, 4, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 1, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 2, 7, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 3, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 4, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 5, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 6, 162, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 7, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 8, 176, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 9, 58, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 10, 8, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 11, 17, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 12, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 13, 95, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110918017080, 14, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 1, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 2, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 3, 98, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 4, 169, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 5, 73, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 6, 173, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 7, 8, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 8, 116, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 9, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 10, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 6, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 7, 85, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 8, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 9, 133, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070223017413, 10, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515017414, 1, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000515017414, 2, 180, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 1, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 2, 151, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 3, 40, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 4, 22, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 5, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 6, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 7, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 8, 140, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 9, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 10, 124, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 11, 59, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 12, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090227017415, 13, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 1, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 2, 166, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 3, 142, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 4, 47, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 5, 159, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 6, 92, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 7, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 8, 137, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 9, 37, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070114017416, 10, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021017417, 1, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021017417, 2, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021017417, 3, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021021017417, 4, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017418, 1, 49, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017418, 2, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017418, 3, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017418, 4, 26, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020522017418, 5, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 1, 64, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 2, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 3, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 4, 82, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 5, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 6, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 7, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 8, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050408017419, 9, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 1, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 2, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 3, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 4, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 5, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 6, 33, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 7, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 8, 165, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 9, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 10, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 11, 28, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100224017420, 12, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 1, 45, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 2, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 3, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 4, 83, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 5, 89, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 6, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 7, 2, 69, 4, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 8, 144, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 9, 5, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 10, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 11, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 12, 154, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 13, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 14, 129, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 15, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140128017421, 16, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 1, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 2, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 3, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 4, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 5, 183, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 6, 113, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 7, 25, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 8, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 9, 159, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 10, 166, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 11, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 12, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 13, 115, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 14, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 15, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 16, 167, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131129017422, 17, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 1, 125, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 2, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 3, 60, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 4, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 5, 110, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 6, 127, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 7, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 8, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 9, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 10, 168, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 11, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 12, 178, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 13, 8, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 14, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110306017423, 15, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 1, 34, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 2, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 3, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 4, 50, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 5, 37, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020902017424, 6, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707017425, 1, 75, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707017425, 2, 104, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000707017425, 3, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017426, 1, 128, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017426, 2, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017426, 3, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017426, 4, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 1, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 2, 42, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 3, 37, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 4, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 5, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 6, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 7, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 8, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 9, 69, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 10, 95, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 11, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 12, 169, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 13, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017427, 14, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 1, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 2, 24, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 3, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 4, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 5, 179, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 6, 137, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 7, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 8, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 9, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060515017428, 10, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 1, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 2, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 3, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 4, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 5, 82, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 6, 88, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 7, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 8, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 9, 40, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 10, 52, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 11, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 12, 126, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 13, 159, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 14, 63, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 15, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 16, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120905017429, 17, 10, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000523017430, 1, 120, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000523017430, 2, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010812017431, 1, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010812017431, 2, 10, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010812017431, 3, 84, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 1, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 2, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 3, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 4, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 5, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 6, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 7, 110, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 8, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 9, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 10, 113, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 11, 95, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 12, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 13, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120131017432, 14, 117, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 1, 99, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 2, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 3, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 4, 43, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 5, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030510017433, 6, 71, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 1, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 2, 64, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 3, 139, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 4, 20, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 5, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 6, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 7, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 8, 66, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 9, 81, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 10, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 11, 25, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 12, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017434, 13, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102017435, 1, 186, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102017435, 2, 188, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102017435, 3, 162, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001102017435, 4, 85, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 1, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 2, 76, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 3, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 4, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 5, 177, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 6, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 7, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 8, 75, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 9, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 10, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 11, 164, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 12, 86, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 13, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 14, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 15, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609017436, 16, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603017437, 1, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603017437, 2, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603017437, 3, 187, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603017437, 4, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020603017437, 5, 71, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223017438, 1, 37, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223017438, 2, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223017438, 3, 60, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223017438, 4, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021223017438, 5, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 1, 16, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 2, 104, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 3, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 4, 3, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 5, 165, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 6, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 7, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050312017439, 8, 116, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 1, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 5, 184, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 6, 88, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 7, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 8, 183, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050213016301, 9, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 1, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 2, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 3, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 4, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 5, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 6, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 7, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 8, 96, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 9, 64, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 10, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070525016302, 11, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 1, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 2, 119, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 3, 25, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 4, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 5, 167, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 6, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 7, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 8, 72, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 9, 167, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 10, 68, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070415016303, 11, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 1, 19, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 2, 165, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 3, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 4, 35, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 5, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 6, 114, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 7, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 8, 93, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 9, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 10, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 11, 188, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090418016304, 12, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 1, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 2, 137, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 3, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 4, 147, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 5, 10, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 6, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 7, 93, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318016305, 8, 171, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 1, 136, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 2, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 3, 54, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 4, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 5, 58, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 6, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 7, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 8, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050205016306, 9, 42, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 1, 25, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 2, 21, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 3, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 4, 3, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 5, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 6, 69, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 7, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 8, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 9, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 10, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 11, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 12, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 13, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 14, 180, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 15, 123, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110924016307, 16, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 1, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 2, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 3, 119, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 4, 120, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 5, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 6, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 7, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 8, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 9, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 10, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080623016308, 11, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 1, 28, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 2, 168, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 3, 122, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 4, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 5, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 6, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 7, 130, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 8, 153, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016309, 9, 68, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105016310, 1, 113, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105016310, 2, 148, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105016310, 3, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 1, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 2, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 3, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 4, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 5, 4, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 6, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 7, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016311, 8, 9, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 1, 78, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 2, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 3, 9, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 4, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 5, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 6, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 7, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 8, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 9, 104, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 10, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080913016312, 11, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016313, 1, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016313, 2, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016313, 3, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016313, 4, 149, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 1, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 2, 91, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 3, 117, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 4, 144, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 5, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 6, 44, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 7, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 8, 85, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 9, 154, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060810016314, 10, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 1, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 2, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 3, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 4, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 5, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 6, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 7, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 8, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 9, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 10, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 11, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 12, 124, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 13, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 14, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130518016315, 15, 7, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 1, 60, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 2, 75, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 3, 154, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 4, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 5, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 6, 128, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 7, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 8, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 9, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 10, 3, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 11, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 12, 188, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 13, 10, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111118016316, 14, 51, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 1, 85, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 2, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 3, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 4, 179, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 5, 130, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030218016317, 6, 166, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 1, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 2, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 3, 157, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 4, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 5, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 6, 5, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218016318, 7, 175, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 1, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 2, 52, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 3, 2, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 4, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 5, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030827016319, 6, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 1, 161, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 2, 62, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 3, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 4, 47, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 5, 126, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 6, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 7, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050707016320, 8, 162, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 1, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 2, 143, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 3, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 4, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 5, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 6, 129, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 7, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016321, 8, 94, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 1, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 2, 103, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 3, 151, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 4, 122, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 5, 79, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 6, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 7, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016322, 8, 102, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 1, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 2, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 3, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 4, 190, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 5, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 6, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 7, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 8, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 9, 72, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061114016323, 10, 169, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 1, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 2, 172, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 3, 54, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 4, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 5, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 6, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 7, 34, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 8, 189, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 9, 151, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 10, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 11, 73, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 12, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016324, 13, 119, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403016325, 1, 141, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403016325, 2, 136, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403016325, 3, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403016325, 4, 35, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010403016325, 5, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427016326, 1, 148, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427016326, 2, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427016326, 3, 94, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427016326, 4, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020427016326, 5, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 1, 96, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 2, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 3, 77, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 4, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 5, 37, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 4, 151, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 5, 17, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 6, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 7, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 8, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016694, 9, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 1, 189, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 2, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 3, 14, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 4, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 5, 41, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 6, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030802016695, 7, 46, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 1, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 2, 113, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 3, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 4, 88, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 5, 115, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 6, 27, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 7, 68, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 8, 153, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 9, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 10, 65, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 11, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070922016696, 12, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 1, 151, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 2, 34, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 3, 164, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 4, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 5, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 6, 121, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 7, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 8, 21, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 9, 44, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 10, 73, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080604016697, 11, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 1, 179, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 2, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 3, 89, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 4, 121, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 5, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 6, 175, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 7, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 8, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 9, 142, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 10, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 11, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091128016698, 12, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 1, 184, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 2, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 3, 192, 34, 18, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 4, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 5, 14, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030526016699, 6, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810016700, 1, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810016700, 2, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810016700, 3, 3, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010810016700, 4, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 1, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 2, 94, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 3, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 4, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 5, 160, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030823016701, 6, 33, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 1, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 2, 173, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 3, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 4, 146, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 5, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 6, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 7, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 8, 47, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 9, 96, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 10, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 11, 4, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 12, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 13, 189, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 14, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130214016702, 15, 116, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 1, 5, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 2, 56, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 3, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 4, 135, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 5, 12, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 6, 85, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 7, 64, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 8, 80, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 9, 178, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 10, 98, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081129016703, 11, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 1, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 2, 15, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 3, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 4, 87, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 5, 10, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 6, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 7, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 8, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 9, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 10, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 11, 38, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080813016704, 12, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 1, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 2, 112, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 3, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 4, 55, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 5, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 6, 107, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 7, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 8, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 9, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 10, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 11, 55, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 12, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 13, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 14, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120303016705, 15, 102, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231016706, 1, 88, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231016706, 2, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231016706, 3, 180, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021231016706, 4, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623016707, 1, 141, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623016707, 2, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623016707, 3, 83, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000623016707, 4, 137, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 1, 95, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 2, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 3, 114, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 4, 5, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 5, 51, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 6, 182, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 7, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 8, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040113016708, 9, 105, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 1, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 2, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 3, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 4, 1, 93, 3, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 5, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 6, 143, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 7, 2, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 8, 11, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 9, 150, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 10, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 11, 40, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 12, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 13, 125, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 14, 173, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 15, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805016709, 16, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 1, 43, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 2, 74, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 3, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 4, 152, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 5, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 6, 52, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 7, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051223016710, 8, 189, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 1, 89, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 2, 188, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 3, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 4, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 5, 153, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 6, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 7, 59, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 8, 68, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 9, 59, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 10, 74, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 11, 36, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 12, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016711, 13, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 1, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 2, 111, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 3, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 4, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 5, 142, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 6, 171, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 7, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 8, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 9, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615016712, 10, 137, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121016713, 1, 135, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121016713, 2, 171, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121016713, 3, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121016713, 4, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001121016713, 5, 36, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214016714, 1, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214016714, 2, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214016714, 3, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214016714, 4, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010214016714, 5, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 1, 34, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 2, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 3, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 4, 82, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 5, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 6, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 7, 123, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040410016715, 8, 104, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 1, 117, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 2, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 3, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 4, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 5, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 6, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 7, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 8, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901016716, 9, 35, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 1, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 2, 184, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 3, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 4, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 5, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 6, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 7, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 8, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 9, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060322016717, 10, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 1, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 2, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 3, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 4, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 5, 42, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 6, 15, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 7, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 8, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 9, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 10, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 11, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 12, 66, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 13, 66, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 14, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 15, 123, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 16, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121221016718, 17, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016719, 1, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016719, 2, 61, 53, 11, 583);
commit;
prompt 167000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016719, 3, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 1, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 11, 21, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 12, 139, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090424017081, 13, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 1, 140, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 2, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 3, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 4, 65, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 5, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 6, 1, 64, 3, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 7, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 8, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 9, 178, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 10, 98, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081029017082, 11, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314017083, 1, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314017083, 2, 5, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314017083, 3, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010314017083, 4, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 1, 99, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 2, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 3, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 4, 136, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 5, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 6, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 7, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 8, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 9, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 10, 119, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 11, 106, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100927017084, 12, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 1, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 2, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 3, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 4, 82, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 5, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 6, 7, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 7, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 8, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 9, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 10, 115, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 11, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 12, 22, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 13, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 14, 81, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121224017085, 15, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 1, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 2, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 3, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 4, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 5, 1, 97, 3, 291);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 6, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 7, 13, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 8, 15, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 9, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 10, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 11, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 12, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 13, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 14, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 15, 139, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 16, 184, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 17, 10, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 18, 121, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140214017086, 19, 153, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 1, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 2, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 3, 10, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 4, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 5, 147, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 6, 34, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 7, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 8, 2, 59, 4, 236);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 9, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060114017087, 10, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913017088, 1, 174, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913017088, 2, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913017088, 3, 148, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000913017088, 4, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 1, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 2, 33, 93, 4, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 3, 155, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 4, 143, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 5, 121, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 6, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 7, 130, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 8, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 9, 39, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 10, 8, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 11, 170, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 12, 73, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080718017089, 13, 113, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 1, 78, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 2, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 3, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 4, 66, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 5, 43, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 6, 111, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040216017090, 7, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 1, 34, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 2, 47, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 3, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 4, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 5, 140, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 6, 130, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 7, 191, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 8, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 9, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 10, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 11, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 12, 175, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 13, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 14, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 15, 144, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 16, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120913017091, 17, 54, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 1, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 2, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 3, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 4, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 5, 190, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010514017092, 6, 167, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118017093, 1, 77, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118017093, 2, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118017093, 3, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011118017093, 4, 123, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210017094, 1, 108, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210017094, 2, 55, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210017094, 3, 94, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000210017094, 4, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 1, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 2, 158, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 3, 122, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 4, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 5, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 6, 46, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 7, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 8, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 9, 8, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 10, 68, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 11, 48, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 12, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 13, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 14, 8, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 15, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 16, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121017095, 17, 79, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 1, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 2, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 3, 58, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 4, 172, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 5, 24, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 6, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 7, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 8, 70, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 9, 41, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 10, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017096, 11, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 1, 150, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 2, 172, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 3, 26, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 4, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 5, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 6, 82, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 7, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017097, 8, 93, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817017098, 1, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817017098, 2, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817017098, 3, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000817017098, 4, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 1, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 2, 5, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 3, 89, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 4, 38, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 5, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 6, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 7, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 8, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 9, 154, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 10, 131, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 11, 144, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 12, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 13, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 14, 148, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 15, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 16, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 17, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017099, 18, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 1, 92, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 2, 43, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 3, 121, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 4, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 5, 31, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 6, 130, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 7, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 8, 129, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060711017100, 9, 152, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 1, 47, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 2, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 3, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 4, 60, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 5, 113, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 6, 167, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 7, 42, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 8, 160, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 9, 135, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 10, 50, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 11, 177, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 12, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 13, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 14, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 15, 25, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 16, 1, 81, 3, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 17, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131217017101, 18, 71, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 1, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 2, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 3, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 4, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 5, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 6, 65, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 7, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 8, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 9, 65, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 10, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 11, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 12, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 13, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 14, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 15, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 16, 41, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130318017102, 17, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 1, 39, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 2, 39, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 3, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 4, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 5, 159, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 6, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050708017103, 7, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 1, 22, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 2, 68, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 3, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 4, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 5, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 6, 26, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 7, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 8, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 9, 164, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060513017440, 10, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 1, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 2, 182, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 3, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 4, 109, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 5, 181, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 6, 141, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 7, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 8, 37, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 9, 16, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 10, 132, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 11, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017441, 12, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 1, 46, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 2, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 3, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 4, 32, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 5, 157, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 6, 51, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 7, 42, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050815017442, 8, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 1, 91, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 2, 192, 16, 18, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 3, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 4, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 5, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 6, 187, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 7, 183, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 8, 148, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 9, 172, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 10, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081119017443, 11, 87, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 1, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 2, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 3, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 4, 77, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 5, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 6, 47, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 7, 47, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040313017444, 8, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017445, 1, 148, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017445, 2, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017445, 3, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 1, 90, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 2, 11, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 3, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 4, 166, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 5, 18, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 6, 67, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 7, 52, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060211017446, 8, 49, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 1, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 2, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 3, 64, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 4, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 5, 126, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 6, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 7, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 8, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060824017447, 9, 94, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 1, 98, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 2, 5, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 3, 96, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 4, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 5, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 6, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 7, 33, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 8, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 9, 48, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 10, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 11, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080908017448, 12, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 1, 124, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 2, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 3, 137, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 4, 90, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 5, 172, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 6, 20, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050924017449, 7, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 1, 66, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 2, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 3, 5, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 4, 110, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 5, 158, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 6, 143, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 7, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 8, 136, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 9, 45, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 10, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 11, 12, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 12, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 13, 34, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 14, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 15, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 16, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017450, 17, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 1, 118, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 2, 181, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 3, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 4, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 5, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 6, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 7, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 8, 15, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 9, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 10, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017451, 11, 113, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017452, 1, 189, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017452, 2, 36, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017452, 3, 70, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017452, 4, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 1, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 2, 32, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 3, 24, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 4, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 5, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 6, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 7, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 8, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 9, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 10, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206017453, 11, 140, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 1, 191, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 2, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 3, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 4, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 5, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 6, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 7, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 8, 103, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 9, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 10, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 11, 147, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 12, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 13, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 14, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 15, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727017454, 16, 138, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 1, 175, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 2, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 3, 163, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 4, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 5, 104, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 6, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 7, 78, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 8, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 9, 115, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 10, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090328017455, 11, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 1, 22, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 2, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 3, 188, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 4, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 5, 69, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 6, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 7, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 8, 118, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 9, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 10, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 11, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 12, 72, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 13, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 14, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 15, 58, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 16, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140219017456, 17, 78, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 1, 114, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 2, 144, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 3, 37, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 4, 99, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 5, 99, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 6, 115, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 7, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 8, 75, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 9, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 10, 65, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 11, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 12, 21, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 13, 146, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 14, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 15, 74, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130527017457, 16, 23, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 1, 25, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 2, 186, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 3, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 4, 17, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 5, 119, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 6, 97, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 7, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 8, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 9, 53, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 10, 68, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 11, 156, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 12, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 13, 121, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 14, 82, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 15, 159, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130216017458, 16, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 1, 131, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 2, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 3, 113, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 4, 128, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 5, 99, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 6, 2, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 7, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 8, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 9, 65, 56, 5, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 10, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017459, 11, 77, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 1, 150, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 2, 30, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 3, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 4, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 5, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 6, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 7, 44, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 8, 175, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 9, 77, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 10, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 11, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 12, 170, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 13, 14, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 14, 120, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017460, 15, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 1, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 2, 93, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 3, 168, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 4, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 5, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 6, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 7, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 6, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 7, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 8, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 9, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060319016327, 10, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 1, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 2, 153, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 3, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 4, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 5, 13, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 6, 55, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 7, 63, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 8, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 9, 96, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080407016328, 10, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 1, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 2, 107, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 3, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 4, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 5, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 6, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 7, 175, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 8, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 9, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 10, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 11, 95, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 12, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 13, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 14, 67, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110201016329, 15, 130, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 1, 23, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 2, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 3, 189, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 4, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 5, 28, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 6, 13, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 7, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 8, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041024016330, 9, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 1, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 2, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 3, 69, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 4, 139, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 5, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 6, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050428016331, 7, 82, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 1, 24, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 2, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 3, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 4, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 5, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 6, 146, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 7, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 8, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040719016332, 9, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 1, 105, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 2, 94, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 3, 3, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 4, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 5, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 6, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 7, 134, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 8, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 9, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 10, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 11, 159, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 12, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100308016333, 13, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 1, 40, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 2, 118, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 3, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 4, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 5, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 6, 72, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 7, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405016334, 8, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 1, 63, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 2, 103, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 3, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 4, 25, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 5, 135, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 6, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 7, 81, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 8, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 9, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 10, 96, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 11, 66, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 12, 189, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 13, 167, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 14, 89, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111116016335, 15, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 1, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 2, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 3, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 4, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 5, 113, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 6, 40, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 7, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016336, 8, 112, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 1, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 2, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 3, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 4, 45, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 5, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 6, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040115016337, 7, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 1, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 2, 83, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 3, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 4, 95, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 5, 37, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 6, 142, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 7, 97, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 8, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 9, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 10, 119, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 11, 2, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 12, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 13, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 14, 84, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 15, 128, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 16, 159, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 17, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 18, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016338, 19, 178, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 1, 39, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 2, 117, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 3, 128, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 4, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 5, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 6, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 7, 52, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 8, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 9, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 10, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 11, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 12, 34, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 13, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 14, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 15, 51, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110830016339, 16, 98, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 1, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 2, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 3, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 4, 18, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 5, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 6, 146, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 7, 177, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 8, 43, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 9, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 10, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 11, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 12, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090828016340, 13, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 1, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 2, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 3, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 4, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 5, 18, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 6, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030704016341, 7, 68, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 1, 37, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 2, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 3, 129, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 4, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 5, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 6, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 7, 108, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050610016342, 8, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430016343, 1, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430016343, 2, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430016343, 3, 30, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010430016343, 4, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 1, 95, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 2, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 3, 24, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 4, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 5, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 6, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 7, 143, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 8, 19, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 9, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 10, 67, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 11, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 12, 48, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 13, 27, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 14, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120211016344, 15, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502016345, 1, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502016345, 2, 95, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000502016345, 3, 48, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 1, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 2, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 3, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 4, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 5, 141, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 6, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 7, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 8, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 9, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 10, 109, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071206016346, 11, 6, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 1, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 2, 182, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 3, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 4, 58, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 5, 119, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531016347, 6, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 1, 80, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 2, 106, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 3, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 4, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 5, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020706016348, 6, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 1, 120, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 2, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 3, 145, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 4, 88, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 5, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 6, 167, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 7, 94, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016349, 8, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 1, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 2, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 3, 145, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 4, 63, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 5, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 6, 124, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 7, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 8, 71, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 9, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 10, 104, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 11, 102, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 12, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 13, 91, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111103016350, 14, 46, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 1, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 2, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 3, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 2, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 3, 59, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 4, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 5, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 6, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 7, 65, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 8, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 9, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 10, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 11, 150, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 12, 171, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 13, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 14, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101220016720, 15, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 1, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 2, 61, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 3, 127, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 4, 173, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 5, 1, 35, 3, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 6, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 7, 118, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 8, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 9, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 10, 73, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 11, 16, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 12, 34, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 13, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100105016721, 14, 83, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122016722, 1, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122016722, 2, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000122016722, 3, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 1, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 2, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 3, 120, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 4, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 5, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030113016723, 6, 189, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 1, 87, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 2, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 3, 192, 62, 18, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 4, 187, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 5, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 6, 7, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 7, 154, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 8, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 9, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 10, 184, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 11, 65, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 12, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 13, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 14, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110609016724, 15, 76, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 1, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 2, 140, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 3, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 4, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 5, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217016725, 6, 92, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 1, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 2, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 3, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 4, 146, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 5, 105, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 6, 135, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 7, 109, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 8, 144, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 9, 165, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704016726, 10, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 1, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 2, 155, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 3, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 4, 180, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 5, 45, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 6, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 7, 34, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 8, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 9, 188, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 10, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 11, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 12, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 13, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 14, 93, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 15, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120919016727, 16, 189, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 1, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 2, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 3, 66, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 4, 142, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 5, 49, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 6, 162, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 7, 82, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 8, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 9, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 10, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 11, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 12, 124, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 13, 176, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 14, 16, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 15, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120311016728, 16, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 1, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 2, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 3, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 4, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 5, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 6, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 7, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 8, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 9, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 10, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 11, 163, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080923016729, 12, 147, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127016730, 1, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127016730, 2, 146, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127016730, 3, 98, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127016730, 4, 76, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000127016730, 5, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 1, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 2, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 3, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 4, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 5, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 6, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 7, 105, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 8, 157, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 9, 97, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 10, 147, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 11, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 12, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 13, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111013016731, 14, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 1, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 2, 31, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 3, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 4, 110, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 5, 24, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016732, 6, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 1, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 2, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 3, 158, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 4, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 5, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 6, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 7, 58, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 8, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 9, 77, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 10, 151, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 11, 91, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 12, 159, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 13, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 14, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 15, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110119016733, 16, 92, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 1, 112, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 2, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 3, 4, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 4, 83, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 5, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 6, 76, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 7, 80, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 8, 148, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 9, 187, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 10, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 11, 156, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 12, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 13, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111208016734, 14, 178, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 1, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 2, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 3, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 4, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 5, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 6, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 7, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 8, 132, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 9, 31, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 10, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090711016735, 11, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 1, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 2, 107, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 3, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 4, 46, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 5, 116, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 6, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 7, 135, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 8, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 9, 133, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 10, 163, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 11, 86, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 12, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016736, 13, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 1, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 2, 178, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 3, 109, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 4, 76, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 5, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 6, 45, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 7, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 8, 135, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425016737, 9, 54, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 1, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 2, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 3, 159, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 4, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 5, 179, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 6, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 7, 163, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 8, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060312016738, 9, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000927016739, 1, 76, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000927016739, 2, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000927016739, 3, 102, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000927016739, 4, 115, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507016740, 1, 74, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507016740, 2, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507016740, 3, 79, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507016740, 4, 188, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 1, 180, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 2, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 3, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 4, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 5, 96, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020507016741, 6, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711016742, 1, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000711016742, 2, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 1, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 2, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 3, 130, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 4, 6, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 5, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 6, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 7, 115, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 8, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 9, 155, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050211016743, 10, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 1, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 2, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 3, 111, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 4, 175, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 2, 48, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 3, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 4, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 5, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 6, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 7, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 8, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 9, 180, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 10, 43, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 11, 129, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 12, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 13, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 14, 76, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 15, 115, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131124017104, 16, 64, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 1, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 2, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 3, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 4, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 5, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 6, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 7, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 8, 4, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 9, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 10, 143, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 11, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 12, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323017105, 13, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 1, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 2, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 3, 60, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 4, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 5, 38, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 6, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 7, 116, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031017106, 8, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 1, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 2, 103, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 3, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 4, 77, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 5, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 6, 94, 18, 13, 234);
commit;
prompt 168000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041002017107, 7, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 1, 114, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 2, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 3, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 4, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 5, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 6, 164, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 7, 96, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 8, 39, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 9, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 10, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 11, 63, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 12, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 13, 144, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 14, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120420017108, 15, 174, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 1, 160, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 2, 29, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 3, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 4, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 5, 112, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 6, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 7, 106, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 8, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 9, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 10, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 11, 172, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 12, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 13, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 14, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110208017109, 15, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 1, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 2, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 3, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 4, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 5, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 6, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 7, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 8, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 9, 128, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 10, 171, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 11, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 12, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 13, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121210017110, 14, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 1, 38, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 2, 156, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 3, 137, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 4, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 5, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 6, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 7, 73, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 8, 113, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 9, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 10, 37, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 11, 175, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081204017111, 12, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 1, 87, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 2, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 3, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 4, 153, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 5, 133, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 6, 8, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040829017112, 7, 127, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 1, 17, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 2, 101, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 3, 181, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 4, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 5, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 6, 65, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030509017113, 7, 73, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 1, 107, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 2, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 3, 102, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 4, 154, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 5, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 6, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 7, 152, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 8, 67, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 9, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 10, 160, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 11, 32, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 12, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 13, 122, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 14, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 15, 60, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 16, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 17, 124, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140211017114, 18, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 1, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 2, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 3, 102, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 4, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 5, 41, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 6, 28, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 7, 126, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 8, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426017115, 9, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 1, 41, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 2, 116, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 3, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 4, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 5, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 6, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 7, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 8, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 9, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 10, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 11, 42, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 12, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 13, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120122017116, 14, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 1, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 2, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 3, 171, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 4, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 5, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 6, 125, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 7, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 8, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 9, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 10, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 11, 54, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 12, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 13, 36, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 14, 35, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120922017117, 15, 14, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 1, 22, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 2, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 3, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 4, 31, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 5, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 6, 173, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 7, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 8, 81, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 9, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 10, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 11, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 12, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 13, 183, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 14, 135, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120729017118, 15, 147, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 1, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 2, 97, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 3, 144, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 4, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 5, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020102017119, 6, 111, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 1, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 2, 91, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 3, 121, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 4, 27, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 5, 173, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 6, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 7, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 8, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 9, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 10, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090524017120, 11, 156, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 1, 122, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 2, 55, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 3, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 4, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 5, 11, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 6, 28, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 7, 172, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 8, 154, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 9, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 10, 76, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 11, 144, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 12, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 13, 71, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 14, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 15, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 16, 70, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 17, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140506017121, 18, 76, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 1, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 2, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 3, 91, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 4, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 5, 99, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 6, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 7, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 8, 146, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 9, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 10, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 11, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 12, 137, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 13, 65, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 14, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 15, 21, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110929017122, 16, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 1, 148, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 2, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 3, 145, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 4, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 8, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 9, 90, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 10, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 11, 56, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 12, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 1, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 2, 165, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 3, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 4, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 5, 174, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 6, 1, 85, 3, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 7, 40, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 8, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 9, 91, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 10, 178, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 11, 176, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080722017556, 12, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 1, 192, 53, 18, 954);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 2, 114, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 3, 190, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 4, 13, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 5, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 6, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 7, 4, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 8, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 9, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 10, 65, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 11, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 12, 52, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017557, 13, 76, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 1, 187, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 2, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 3, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 4, 13, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 5, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 6, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 7, 94, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 8, 90, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 9, 48, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 10, 130, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 11, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 12, 41, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 13, 76, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 14, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120105017558, 15, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 1, 107, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 2, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 3, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 4, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 5, 10, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 6, 189, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 7, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 8, 25, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 9, 132, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 10, 175, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 11, 115, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 12, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 13, 150, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 14, 80, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 15, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 16, 21, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526017559, 17, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 1, 84, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 2, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 3, 58, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 4, 93, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 5, 8, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 6, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040203017560, 7, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 1, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 2, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 3, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 4, 150, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 5, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 6, 93, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 7, 108, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 8, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070628017561, 9, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202017562, 1, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202017562, 2, 101, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202017562, 3, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202017562, 4, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010202017562, 5, 111, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 1, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 2, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 3, 62, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 4, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 5, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 6, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 7, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 8, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 9, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 10, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 11, 192, 11, 18, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 12, 118, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110706017563, 13, 30, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 1, 159, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 2, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 3, 83, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 4, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 5, 90, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 6, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 7, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 8, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 9, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 10, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 11, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 12, 23, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080902017564, 13, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 1, 36, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 2, 34, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 3, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 4, 70, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 5, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 6, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 7, 158, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060131017565, 8, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 1, 155, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 2, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 4, 2, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 5, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 6, 58, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 7, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 8, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 9, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 10, 171, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 11, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 12, 188, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 13, 65, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 14, 80, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 15, 155, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 16, 112, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120822017566, 17, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 1, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 2, 102, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 3, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 4, 180, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 5, 15, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040805017567, 6, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 1, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 2, 84, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 3, 16, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 4, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 5, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 6, 119, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 7, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 8, 119, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 9, 70, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 10, 153, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212017568, 11, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 1, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 2, 33, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 3, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 4, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 5, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 6, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 7, 51, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 8, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 9, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 10, 106, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 11, 83, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 12, 110, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 13, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 14, 150, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 15, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 16, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 17, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324017569, 18, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 1, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 2, 14, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 3, 64, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 4, 25, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 5, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 6, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 7, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 8, 109, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 9, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 10, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 11, 167, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 12, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111016017570, 13, 93, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 1, 87, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 2, 83, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 3, 108, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 4, 119, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 5, 178, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 6, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 7, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 8, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 9, 160, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 10, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 11, 111, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 12, 157, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 13, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 14, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130304017571, 15, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 1, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 2, 110, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 3, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 4, 43, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 5, 13, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 6, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 7, 150, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 8, 144, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 9, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 10, 171, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 11, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 12, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 13, 113, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 14, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110423017572, 15, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 1, 148, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 2, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 3, 190, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 4, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 5, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017573, 6, 30, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 1, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 2, 172, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 3, 58, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 4, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 5, 46, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 6, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 7, 138, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 8, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061025017574, 9, 117, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 1, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 2, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 3, 16, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 4, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 5, 34, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030315017575, 6, 41, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828017576, 1, 38, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828017576, 2, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828017576, 3, 81, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828017576, 4, 110, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010828017576, 5, 103, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 1, 29, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 4, 126, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 5, 20, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 6, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 7, 46, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 8, 106, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 9, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 10, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 11, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 12, 175, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 13, 4, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 14, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 15, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 16, 104, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130315016351, 17, 40, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 1, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 2, 42, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 3, 25, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 4, 185, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 5, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 6, 11, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 7, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 8, 153, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 9, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 10, 11, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 11, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 12, 38, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 13, 59, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628016352, 14, 83, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 1, 132, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 2, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 3, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 4, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 5, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 6, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 7, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050304016353, 8, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 1, 29, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 2, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 3, 124, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 4, 94, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 5, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 6, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 7, 116, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 8, 118, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 9, 172, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 10, 73, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 11, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091219016354, 12, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016355, 1, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016355, 2, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016355, 3, 159, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000722016355, 4, 64, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 1, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 2, 21, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 3, 6, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 4, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 5, 185, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 6, 15, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 7, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 8, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 9, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 10, 157, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 11, 29, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 12, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 13, 139, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 14, 25, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 15, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110125016356, 16, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 1, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 2, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 3, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 4, 31, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 5, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 6, 175, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 7, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 8, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 9, 105, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 10, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 11, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 12, 164, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 13, 167, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120316016357, 14, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214016358, 1, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214016358, 2, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214016358, 3, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214016358, 4, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214016358, 5, 83, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 1, 100, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 2, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 3, 54, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 4, 134, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 5, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 6, 119, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 7, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040208016359, 8, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306016360, 1, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306016360, 2, 157, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306016360, 3, 32, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000306016360, 4, 93, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 1, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 2, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 3, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 4, 49, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 5, 152, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 6, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 7, 74, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 8, 49, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 9, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 10, 76, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 11, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 12, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 13, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 14, 112, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120124016361, 15, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 1, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 2, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 3, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 4, 188, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 5, 61, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 6, 21, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 7, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 8, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 9, 64, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 10, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 11, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 12, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101113016362, 13, 45, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 1, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 2, 106, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 3, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 4, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 5, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 6, 74, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 7, 125, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 8, 184, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 9, 41, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 10, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 11, 153, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016363, 12, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 1, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 2, 23, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 3, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 4, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 5, 40, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 6, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 7, 138, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 8, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 9, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080427016364, 10, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 1, 150, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 2, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 3, 100, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 4, 124, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 5, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 6, 110, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 7, 83, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 8, 140, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 9, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070227016365, 10, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 1, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 2, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 3, 189, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 4, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 5, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 6, 16, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 7, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 8, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 9, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061211016366, 10, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 1, 126, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 2, 30, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 3, 81, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 4, 102, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 5, 126, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 6, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 7, 142, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 8, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 9, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 10, 169, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 11, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 12, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 13, 92, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 14, 100, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100605016367, 15, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 1, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 2, 70, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 3, 25, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 4, 55, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 5, 99, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 6, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 7, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 8, 156, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 9, 106, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 10, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 11, 26, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 12, 129, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016368, 13, 160, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123016369, 1, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123016369, 2, 130, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123016369, 3, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123016369, 4, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021123016369, 5, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 1, 44, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 2, 149, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 3, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 4, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 5, 8, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016370, 6, 55, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 1, 44, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 2, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 3, 125, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 4, 79, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 5, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 6, 133, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 7, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 8, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 9, 62, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 10, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080206016371, 11, 188, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020202016372, 1, 173, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020202016372, 2, 144, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020202016372, 3, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020202016372, 4, 134, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020202016372, 5, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 1, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 2, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 3, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 4, 33, 15, 4, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 5, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010626016373, 6, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203016374, 1, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203016374, 2, 49, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203016374, 3, 2, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001203016374, 4, 140, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 1, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 2, 116, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 3, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 4, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 5, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 6, 31, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 7, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 8, 165, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 9, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 10, 135, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 11, 99, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070907016744, 12, 131, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 1, 71, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 2, 99, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 3, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 4, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 5, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 6, 147, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 7, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 8, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 9, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 10, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 11, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 12, 76, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 13, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 14, 178, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101031016745, 15, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904016746, 1, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904016746, 2, 75, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904016746, 3, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904016746, 4, 131, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010904016746, 5, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614016747, 1, 14, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614016747, 2, 61, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614016747, 3, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 1, 107, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 2, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 3, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 4, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 5, 56, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 6, 165, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 7, 123, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 8, 8, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227016748, 9, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 1, 81, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 2, 63, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 3, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 4, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 5, 159, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 6, 103, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 7, 70, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 8, 69, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 9, 37, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 10, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 11, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 12, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 13, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091015016749, 14, 61, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 1, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 2, 102, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 3, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 4, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 5, 158, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 6, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 7, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 8, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 9, 26, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 10, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 11, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 12, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090527016750, 13, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 1, 158, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 2, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 3, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 4, 65, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 5, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 6, 102, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 7, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 8, 93, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 9, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 10, 156, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 11, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 12, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081023016751, 13, 100, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 1, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 2, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 3, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 4, 83, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 5, 163, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 6, 182, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020126016752, 7, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 1, 115, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 2, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 3, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 4, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 5, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 6, 125, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 7, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 8, 53, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 9, 154, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060128016753, 10, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 1, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 2, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 3, 171, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 4, 142, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 5, 67, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 6, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030813016754, 7, 140, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 1, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 2, 109, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 3, 114, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 4, 39, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 5, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 6, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030205016755, 7, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016756, 1, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016756, 2, 177, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016756, 3, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011130016756, 4, 60, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003016757, 1, 80, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003016757, 2, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003016757, 3, 104, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003016757, 4, 36, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021003016757, 5, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 1, 54, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 2, 138, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 3, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 4, 149, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 5, 107, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 6, 77, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 7, 98, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 8, 8, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 9, 177, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 10, 95, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 11, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 12, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 13, 33, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100705016758, 14, 79, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 1, 6, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 2, 157, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 3, 19, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 4, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 5, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 6, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 7, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 8, 32, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 9, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 10, 4, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 11, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 12, 86, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 13, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 14, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121124016759, 15, 17, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 1, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 2, 98, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 3, 179, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 4, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 5, 95, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 6, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051018016760, 7, 191, 13, 17, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216016761, 1, 35, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216016761, 2, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216016761, 3, 109, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020216016761, 4, 136, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 1, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 2, 75, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 3, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 4, 40, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 5, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 6, 163, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301016762, 7, 49, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 1, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 2, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 3, 124, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 4, 91, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 5, 86, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 6, 22, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 7, 16, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 8, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060915016763, 9, 109, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 1, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 2, 77, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 3, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 4, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 5, 26, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 6, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040721016764, 7, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 1, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 2, 55, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 3, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 4, 80, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 5, 109, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 6, 182, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 7, 127, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 8, 18, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107016765, 9, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 1, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 2, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 3, 134, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 4, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 5, 131, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 6, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030804016766, 7, 27, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 1, 55, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 2, 27, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 3, 145, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 4, 63, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 5, 53, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 6, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 7, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 8, 103, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 9, 115, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 10, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 11, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 12, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 13, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 14, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 15, 84, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110714016767, 16, 99, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 1, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 2, 124, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 3, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 4, 71, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 5, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321016768, 6, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 1, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 2, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 3, 180, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 4, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 5, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 6, 166, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 7, 11, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 8, 109, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 9, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 10, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 11, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 12, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 13, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 14, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120513016769, 15, 27, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 1, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 2, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 3, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 5, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 6, 20, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 7, 154, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 8, 118, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 9, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 10, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 11, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 12, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100818017123, 13, 181, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 1, 186, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 2, 150, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 3, 168, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 4, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 5, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 6, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 7, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 8, 170, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 9, 153, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 10, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 11, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 12, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101121017124, 13, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605017125, 1, 66, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605017125, 2, 44, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010605017125, 3, 188, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 1, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 3, 183, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 4, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 5, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 6, 89, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 7, 116, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 8, 32, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 9, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 10, 17, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 11, 128, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 12, 179, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 13, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 14, 181, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110818017126, 15, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 1, 120, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 2, 40, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 3, 108, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 4, 114, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 5, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 6, 76, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 7, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040520017127, 8, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 1, 106, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 2, 176, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 3, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 4, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 5, 160, 4, 17, 68);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 6, 122, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 7, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017128, 8, 86, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 1, 134, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 2, 17, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 3, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 4, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 5, 60, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 6, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 7, 60, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 8, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 9, 177, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 10, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 11, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017129, 12, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 1, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 2, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 3, 33, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 4, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 5, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 6, 161, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 7, 186, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 8, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 9, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017130, 10, 170, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429017131, 1, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429017131, 2, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000429017131, 3, 69, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 1, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 2, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 3, 58, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 4, 181, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 5, 183, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 6, 86, 14, 12, 168);
commit;
prompt 169000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 7, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 8, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 9, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 10, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 11, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081106017132, 12, 175, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 1, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 2, 130, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 3, 127, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 4, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 5, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 6, 15, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 7, 145, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 8, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 9, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 10, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 11, 32, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 12, 16, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 13, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100525017133, 14, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511017134, 1, 136, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511017134, 2, 71, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010511017134, 3, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 1, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 2, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 3, 150, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 4, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 5, 165, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 6, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 7, 61, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 8, 39, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050618017135, 9, 90, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 1, 20, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 2, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 3, 49, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 4, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 5, 169, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 6, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 7, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 8, 174, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 9, 151, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 10, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 11, 64, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 12, 129, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 13, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 14, 169, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 15, 87, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120527017136, 16, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 1, 70, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 2, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 3, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 4, 83, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 5, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030316017137, 6, 189, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607017138, 1, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607017138, 2, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607017138, 3, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607017138, 4, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020607017138, 5, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 1, 165, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 2, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 3, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 4, 75, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 5, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 6, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 7, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 8, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 9, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 10, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 11, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 12, 86, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 13, 154, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 14, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101119017139, 15, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 1, 182, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 2, 42, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 3, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 4, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 5, 124, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 6, 73, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 7, 174, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 8, 91, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 9, 71, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 10, 53, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 11, 82, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 12, 64, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 13, 36, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 14, 143, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 15, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017140, 16, 124, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 1, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 2, 181, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 3, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 4, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 5, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 6, 181, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 7, 76, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 8, 59, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 9, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 10, 26, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 11, 184, 85, 17, 1445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080130017141, 12, 16, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 1, 129, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 2, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 3, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 4, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 5, 147, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 6, 179, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 7, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 8, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 9, 110, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 10, 96, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 11, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 12, 177, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100307017142, 13, 72, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 1, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 2, 30, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 3, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 4, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 5, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 6, 129, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 7, 170, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060425017143, 8, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 1, 137, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 2, 158, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 3, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 4, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 5, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 6, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 7, 18, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051227017144, 8, 108, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 1, 37, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 2, 43, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 3, 84, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 4, 125, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 5, 108, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 6, 165, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 7, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 8, 37, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 9, 19, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 10, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 11, 113, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 12, 65, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 13, 49, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 14, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 15, 125, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140204017145, 16, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 1, 133, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 2, 123, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 3, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 4, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 8, 180, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 9, 19, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 10, 62, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 11, 162, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 12, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 13, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321017461, 14, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 1, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 2, 40, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 3, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 4, 180, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 5, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 6, 40, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 7, 123, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 8, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 9, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 10, 160, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070316017462, 11, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 1, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 2, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 3, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 4, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 5, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 6, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 7, 56, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706017463, 8, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 1, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 2, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 3, 54, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 4, 74, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 5, 55, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 6, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 7, 149, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 8, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 9, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 10, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 11, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 12, 124, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 13, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 14, 145, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 15, 166, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 16, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 17, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130529017464, 18, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 1, 40, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 2, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 3, 34, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 4, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 5, 107, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010929017465, 6, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 1, 12, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 2, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 3, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 4, 37, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 5, 45, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 6, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 7, 139, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 8, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 9, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 10, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080524017466, 11, 5, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 1, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 2, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 3, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 4, 129, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 5, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710017467, 6, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629017468, 1, 40, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629017468, 2, 133, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629017468, 3, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010629017468, 4, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 1, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 2, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 3, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 4, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 5, 18, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 6, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 7, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 8, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 9, 11, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 10, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 11, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 12, 127, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 13, 79, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090904017469, 14, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 1, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 2, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 3, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 4, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 5, 157, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 6, 115, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 7, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 8, 90, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040522017470, 9, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 1, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 2, 192, 93, 18, 1674);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 3, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 4, 59, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 5, 163, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 6, 110, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041122017471, 7, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 1, 153, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 2, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 3, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 4, 117, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 5, 122, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 6, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 7, 139, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 8, 10, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 9, 103, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 10, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 11, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 12, 93, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 13, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100708017472, 14, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903017473, 1, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903017473, 2, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903017473, 3, 22, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010903017473, 4, 109, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 1, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 2, 94, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 3, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 4, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 5, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 6, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 7, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 8, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 9, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017474, 10, 139, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 1, 117, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 2, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 3, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 4, 161, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 5, 152, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 6, 139, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 7, 178, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 8, 15, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 9, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 10, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 11, 132, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 12, 25, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017475, 13, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 1, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 2, 30, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 3, 69, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 4, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 5, 105, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030112017476, 6, 152, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 1, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 2, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 3, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 4, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 5, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 6, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 7, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 8, 73, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 9, 9, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 10, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 11, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 12, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 13, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 14, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 15, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 16, 143, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130405017477, 17, 164, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 1, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 2, 86, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 3, 66, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 4, 1, 1, 3, 3);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 5, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020121017478, 6, 8, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 1, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 2, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 3, 15, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 4, 126, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 5, 169, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 6, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 7, 174, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 8, 42, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 9, 75, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 10, 81, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 11, 107, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 12, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 13, 2, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017479, 14, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203017480, 1, 8, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203017480, 2, 147, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203017480, 3, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203017480, 4, 132, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000203017480, 5, 161, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 1, 42, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 2, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 3, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 4, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 5, 41, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 6, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 7, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 8, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 9, 29, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 10, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 11, 23, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 12, 137, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101203017481, 13, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 1, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 2, 15, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 3, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 4, 168, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 5, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 6, 191, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 7, 163, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 8, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 9, 161, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060521017482, 10, 168, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 1, 172, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 2, 137, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 3, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 4, 119, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 5, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 6, 124, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 7, 88, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 8, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 9, 89, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 10, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 11, 98, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 12, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 13, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 14, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 15, 172, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 16, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120805017483, 17, 39, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 1, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 2, 65, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 3, 48, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 4, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 5, 155, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030712017484, 6, 147, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510017485, 1, 25, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510017485, 2, 188, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510017485, 3, 30, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 5, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 6, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 7, 70, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 8, 176, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 9, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 10, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 11, 137, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 12, 6, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 13, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 14, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 15, 172, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 16, 167, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 17, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131121016375, 18, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303016376, 1, 55, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303016376, 2, 93, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000303016376, 3, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 1, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 2, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 3, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 4, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 5, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 6, 79, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 7, 106, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 8, 162, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 9, 92, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 10, 189, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 11, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 12, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 13, 188, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 14, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 15, 108, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131011016377, 16, 149, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 1, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 2, 54, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 3, 27, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 4, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 5, 123, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 6, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 7, 54, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 8, 164, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 9, 5, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 10, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 11, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 12, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 13, 158, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 14, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 15, 124, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111128016378, 16, 157, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 1, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 2, 52, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 3, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 4, 62, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 5, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 6, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041213016379, 7, 96, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 1, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 2, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 3, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 4, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 5, 189, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 6, 6, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 7, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 8, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 9, 148, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 10, 73, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 11, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 12, 158, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 13, 62, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 14, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121217016380, 15, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 1, 76, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 2, 113, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 3, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 4, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 5, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 6, 157, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 7, 68, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 8, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 9, 108, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 10, 164, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 11, 123, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 12, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 13, 143, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 14, 9, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223016381, 15, 104, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 1, 88, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 2, 56, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 3, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 4, 126, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 5, 71, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 6, 52, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 7, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 8, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 9, 3, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080804016382, 10, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217016383, 1, 115, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217016383, 2, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217016383, 3, 152, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217016383, 4, 119, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011217016383, 5, 186, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001105016384, 1, 156, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001105016384, 2, 114, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 1, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 2, 9, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 3, 132, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 4, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 5, 12, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 6, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 7, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 8, 53, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 9, 65, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 10, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016385, 11, 32, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015016386, 1, 63, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015016386, 2, 185, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015016386, 3, 52, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001015016386, 4, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 1, 129, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 2, 179, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 3, 72, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 4, 71, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 5, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 6, 82, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 7, 153, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 8, 33, 40, 4, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 9, 136, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 10, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 11, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100325016387, 12, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 1, 32, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 2, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 3, 50, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 4, 103, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 5, 81, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 6, 13, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 7, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 8, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 9, 135, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 10, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 11, 29, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 12, 187, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 13, 83, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 14, 96, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111124016388, 15, 100, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 1, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 2, 76, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 3, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 4, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 5, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 6, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 7, 183, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 8, 40, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 9, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 10, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 11, 57, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 12, 165, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727016389, 13, 113, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 1, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 2, 64, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 3, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 4, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 5, 25, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 6, 80, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 7, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 8, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 9, 64, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 10, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 11, 78, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091003016390, 12, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 1, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 2, 170, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 3, 48, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 4, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 5, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 6, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 7, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030528016391, 8, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 1, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 2, 17, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 3, 23, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 4, 185, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 5, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 6, 143, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 7, 104, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 8, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 9, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 10, 188, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 11, 26, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 12, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 13, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 14, 5, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 15, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130422016392, 16, 95, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 1, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 2, 5, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 3, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 4, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 5, 46, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 6, 15, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020710016393, 7, 83, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 1, 130, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 2, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 3, 8, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 4, 6, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 5, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 6, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 7, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 8, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 9, 58, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 10, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 11, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 12, 41, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100326016394, 13, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 1, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 2, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 3, 187, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 4, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 5, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 6, 100, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023016395, 7, 145, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 1, 88, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 2, 99, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 3, 74, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 4, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 5, 160, 84, 17, 1428);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 6, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 7, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 8, 89, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 9, 108, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 10, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 11, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 12, 34, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 13, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016396, 14, 149, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 1, 159, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 2, 69, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 3, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 4, 181, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 4, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 5, 145, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 6, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031214016770, 7, 114, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 1, 160, 38, 17, 646);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 2, 110, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 3, 33, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 4, 139, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 5, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 6, 21, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 7, 10, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 8, 56, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 9, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007016771, 10, 176, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 1, 114, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 2, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 3, 116, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 4, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 5, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 6, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 7, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 8, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 9, 48, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 10, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 11, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 12, 88, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 13, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 14, 148, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 15, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111215016772, 16, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 1, 57, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 2, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 3, 73, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 4, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 5, 127, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 6, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 7, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 8, 105, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 9, 18, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070425016773, 10, 154, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 1, 177, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 2, 64, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 3, 19, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 4, 114, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 5, 51, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 6, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 7, 113, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 8, 168, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 9, 138, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 10, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 11, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 12, 13, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 13, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 14, 9, 89, 4, 356);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100324016774, 15, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 1, 107, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 2, 35, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 3, 141, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 4, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 5, 172, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 6, 183, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030625016775, 7, 146, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 1, 160, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 2, 89, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 3, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 4, 85, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 5, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 6, 150, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 7, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 8, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051106016776, 9, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 1, 17, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 2, 158, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 3, 159, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 4, 178, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 5, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 6, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 7, 94, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 8, 105, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 9, 53, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 10, 157, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 11, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 12, 105, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 13, 131, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 14, 165, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 15, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110713016777, 16, 131, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 1, 119, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 2, 174, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 3, 164, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 4, 91, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 5, 46, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 6, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 7, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 8, 7, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 9, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061020016778, 10, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 1, 116, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 2, 105, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 3, 122, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 4, 7, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 5, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 6, 44, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 7, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 8, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 9, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 10, 174, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 11, 39, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 12, 62, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091006016779, 13, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 1, 147, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 2, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 3, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 4, 112, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 5, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 6, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 7, 123, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 8, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 9, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 10, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 11, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 12, 24, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090125016780, 13, 86, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005016781, 1, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005016781, 2, 18, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005016781, 3, 71, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005016781, 4, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011005016781, 5, 99, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 1, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 2, 135, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 3, 48, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 4, 168, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 5, 164, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 6, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 7, 56, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051124016782, 8, 27, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 1, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 2, 181, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 3, 152, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 4, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 5, 41, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 6, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 7, 117, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050429016783, 8, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016784, 1, 16, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016784, 2, 191, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016784, 3, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 1, 122, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 2, 192, 41, 18, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 3, 118, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 4, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 5, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 6, 92, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 7, 58, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 8, 3, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 9, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 10, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 11, 60, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 12, 171, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 13, 34, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 14, 57, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016785, 15, 10, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 1, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 2, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 3, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 4, 43, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 5, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 6, 18, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 7, 130, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 8, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 9, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 10, 77, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 11, 156, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 12, 57, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 13, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 14, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121205016786, 15, 179, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 1, 5, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 2, 19, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 3, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 4, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 5, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 6, 20, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016787, 7, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 1, 171, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 2, 173, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 3, 44, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 4, 133, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 5, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 6, 158, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 7, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 8, 151, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 9, 160, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 10, 12, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 11, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 12, 91, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 13, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100110016788, 14, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 1, 59, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 2, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 3, 114, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 4, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 5, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 6, 35, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051015016789, 7, 125, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 1, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 2, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 3, 100, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 4, 65, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 5, 137, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 6, 135, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 7, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040819016790, 8, 113, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613016791, 1, 45, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613016791, 2, 20, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613016791, 3, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613016791, 4, 134, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020613016791, 5, 23, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 1, 135, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 2, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 3, 65, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 4, 57, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 5, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 6, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 7, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 8, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 9, 182, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 10, 76, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 11, 113, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 12, 89, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 13, 99, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 14, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120824016792, 15, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 1, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 2, 136, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 3, 181, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 4, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 5, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 6, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 5, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 6, 87, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 7, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 8, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 9, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060105017146, 10, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 1, 150, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 2, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 3, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 4, 13, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 5, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 6, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 7, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 8, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070410017147, 9, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 1, 9, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 2, 107, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 3, 48, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 4, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 5, 173, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 6, 44, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 7, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 8, 135, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 9, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 10, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 11, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 12, 140, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 13, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 14, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 15, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017148, 16, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 1, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 2, 41, 49, 5, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 3, 53, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 4, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 5, 178, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 6, 163, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 7, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 8, 88, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 9, 34, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 10, 79, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 11, 118, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 12, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 13, 167, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104017149, 14, 126, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 1, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 2, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 3, 156, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 4, 170, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 5, 48, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 6, 66, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 7, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 8, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 9, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 10, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 11, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 12, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 13, 168, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 14, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 15, 129, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 16, 53, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 17, 61, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140123017150, 18, 143, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 1, 143, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 2, 56, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 3, 155, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 4, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 5, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 6, 107, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 7, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 8, 25, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 9, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 10, 93, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 11, 31, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 12, 107, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 13, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017151, 14, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 1, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 2, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 3, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 4, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 5, 177, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 6, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 7, 190, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 8, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 9, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 10, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 11, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 12, 5, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091218017152, 13, 10, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 1, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 2, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 3, 89, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 4, 108, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 5, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 6, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 7, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 8, 102, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 9, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 10, 176, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 11, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 12, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 13, 174, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917017153, 14, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 1, 106, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 2, 190, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 3, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 4, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 5, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 6, 124, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 7, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 8, 131, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 9, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 10, 162, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 11, 44, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 12, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 13, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 14, 60, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 15, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 16, 167, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120328017154, 17, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 1, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 2, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 3, 117, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 4, 96, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 5, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 6, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 7, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 8, 45, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040429017155, 9, 45, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 1, 190, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 2, 76, 95, 9, 855);
commit;
prompt 170000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 3, 53, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 4, 7, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 5, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 6, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017156, 7, 77, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 1, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 2, 177, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 3, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 4, 26, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 5, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 6, 65, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 7, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 8, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 9, 29, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 10, 152, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 11, 3, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 12, 186, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 13, 8, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120628017157, 14, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 1, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 2, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 3, 116, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 4, 134, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 5, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 6, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 7, 16, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 8, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 9, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 10, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090826017158, 11, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 1, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 2, 48, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 3, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 4, 183, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 5, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 6, 75, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 7, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 8, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060331017159, 9, 18, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 1, 19, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 2, 36, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 3, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 4, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 5, 116, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 6, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 7, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 8, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 9, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 10, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 11, 85, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 12, 102, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 13, 7, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 14, 157, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120427017160, 15, 89, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 1, 152, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 2, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 3, 181, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 4, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 5, 48, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 6, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 7, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 8, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 9, 186, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 10, 84, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 11, 25, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 12, 192, 52, 18, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 13, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 14, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 15, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 16, 14, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121101017161, 17, 80, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 1, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 2, 181, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 3, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 4, 106, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 5, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 6, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 7, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 8, 127, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 9, 59, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 10, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090813017162, 11, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 1, 43, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 2, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 3, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 4, 176, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 5, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 6, 130, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 7, 55, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 8, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 9, 141, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 10, 43, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 11, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 12, 85, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 13, 14, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 14, 6, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 15, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 16, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017163, 17, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017164, 1, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017164, 2, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017164, 3, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017164, 4, 75, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017164, 5, 24, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 1, 142, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 2, 11, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 3, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 1, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 2, 48, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 3, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 4, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 5, 148, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105017510, 6, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 1, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 2, 161, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 3, 97, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 4, 92, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 5, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 6, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 7, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 8, 137, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 9, 30, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 10, 74, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 11, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 12, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 13, 4, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110802017511, 14, 178, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 1, 129, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 2, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 3, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 4, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 5, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 6, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 7, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 8, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 9, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 10, 21, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 11, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 12, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 13, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 14, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 15, 181, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130211017512, 16, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 1, 77, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 2, 126, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 3, 135, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 4, 165, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 5, 33, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 6, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 7, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 8, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 9, 81, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 10, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 11, 30, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 12, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100908017513, 13, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 1, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 2, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 3, 49, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 4, 103, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 5, 32, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 6, 115, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 7, 166, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 8, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 9, 188, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 10, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 11, 77, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 12, 31, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 13, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 14, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 15, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017514, 16, 146, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 1, 160, 52, 17, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 2, 67, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 3, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 4, 59, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 5, 69, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 6, 161, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 7, 148, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 8, 64, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 9, 116, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 10, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071209017515, 11, 108, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 1, 137, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 2, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 3, 158, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 4, 138, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 5, 145, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 6, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 7, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 8, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 9, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 10, 180, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080109017516, 11, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224017517, 1, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224017517, 2, 25, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224017517, 3, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224017517, 4, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011224017517, 5, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111017518, 1, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111017518, 2, 61, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111017518, 3, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111017518, 4, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111017518, 5, 121, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 1, 95, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 2, 154, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 3, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 4, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 5, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 6, 2, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 7, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 8, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 9, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 10, 145, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 11, 79, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 12, 3, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 13, 179, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101217017519, 14, 142, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 1, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 2, 149, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 3, 73, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 4, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 5, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 6, 70, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 7, 133, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 8, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 9, 144, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 10, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 11, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 12, 82, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101229017520, 13, 104, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 1, 58, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 2, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 3, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 4, 86, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 5, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 6, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 7, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060916017521, 8, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 1, 57, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 2, 107, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 3, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 4, 22, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 5, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 6, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 7, 115, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 8, 116, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 9, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 10, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730017522, 11, 20, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 1, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 2, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 3, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 4, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 5, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 6, 149, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 7, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 8, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 9, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 10, 146, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 11, 60, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 12, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 13, 114, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 14, 39, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 15, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 16, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 17, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130421017523, 18, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 1, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 2, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 3, 37, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 4, 108, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 5, 92, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 6, 41, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 7, 114, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050622017524, 8, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 1, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 2, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 3, 78, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 4, 122, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 5, 66, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 6, 151, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 7, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 8, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060901017525, 9, 129, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017526, 1, 152, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017526, 2, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017526, 3, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129017527, 1, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129017527, 2, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000129017527, 3, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 1, 99, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 2, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 3, 45, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 4, 133, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 5, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 6, 87, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 7, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 8, 59, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 9, 79, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 10, 171, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 11, 4, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 12, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 13, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 14, 1, 23, 3, 69);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 15, 130, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 16, 139, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017528, 17, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 1, 50, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 2, 19, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 3, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 4, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 5, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 6, 124, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 7, 184, 60, 17, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 8, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 9, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 10, 135, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090705017529, 11, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 1, 73, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 2, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 3, 80, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 4, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 5, 133, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 6, 12, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 7, 1, 56, 3, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130017530, 8, 154, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727017531, 1, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727017531, 2, 144, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727017531, 3, 113, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020727017531, 4, 191, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 1, 46, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 2, 132, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 3, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 4, 4, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 5, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 6, 8, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 7, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 8, 52, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 9, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 10, 109, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 11, 126, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 12, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090119017532, 13, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703017533, 1, 61, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703017533, 2, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 5, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 6, 151, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 7, 176, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051125016397, 8, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 1, 108, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 2, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 3, 36, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 4, 115, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 5, 85, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 6, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 7, 17, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 8, 4, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 9, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 10, 166, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 11, 116, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 12, 39, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110214016398, 13, 46, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 1, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 2, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 3, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 4, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 5, 46, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 6, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 7, 36, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040406016399, 8, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 1, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 2, 41, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 3, 153, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 4, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 5, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 6, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 7, 3, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 8, 75, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 9, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 10, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 11, 19, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 12, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 13, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 14, 110, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 15, 99, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 16, 8, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 17, 155, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130726016400, 18, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 1, 83, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 2, 48, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 3, 128, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 4, 153, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 5, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 6, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 7, 24, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 8, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050626016401, 9, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 1, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 2, 163, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 3, 76, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 4, 184, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 5, 43, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 6, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040613016402, 7, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314016403, 1, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314016403, 2, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314016403, 3, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314016403, 4, 149, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020314016403, 5, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 1, 136, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 2, 33, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 3, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 4, 52, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 5, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030411016404, 6, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 1, 150, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 2, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 3, 100, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 4, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 5, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030201016405, 6, 67, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 1, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 2, 126, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 3, 182, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 4, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 5, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 6, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 7, 180, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 8, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 9, 46, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 10, 185, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 11, 142, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 12, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 13, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 14, 174, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121010016406, 15, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 1, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 2, 7, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 3, 105, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 4, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 5, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 6, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 7, 110, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 8, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 9, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 10, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 11, 158, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 12, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 13, 185, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 14, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 15, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520016407, 16, 134, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 1, 15, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 2, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 3, 157, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 4, 2, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 5, 15, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 6, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 7, 144, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040217016408, 8, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 1, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 2, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 3, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 4, 144, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 5, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 6, 97, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 7, 96, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 8, 105, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 9, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 10, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 11, 165, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 12, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 13, 99, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 14, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 15, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019016409, 16, 131, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 1, 100, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 2, 124, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 3, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 4, 105, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 5, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 6, 32, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 7, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 8, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 9, 60, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 10, 181, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 11, 155, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 12, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 13, 87, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 14, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 15, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 16, 20, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 17, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140203016410, 18, 16, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 1, 188, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 2, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 3, 157, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 4, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 5, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 6, 151, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 7, 50, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 8, 187, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 9, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 10, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 11, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 12, 136, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 13, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 14, 26, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 15, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130109016411, 16, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 1, 113, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 2, 12, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 3, 123, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 4, 71, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 5, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 6, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 7, 186, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 8, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016412, 9, 107, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 1, 103, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 2, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 3, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 4, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 5, 94, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 6, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 7, 30, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030226016413, 8, 148, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 1, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 2, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 3, 186, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 4, 80, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 5, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 6, 114, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 7, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 8, 96, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 9, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 10, 94, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 11, 137, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 12, 143, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111204016414, 13, 16, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 1, 60, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 2, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 3, 14, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 4, 101, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 5, 89, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 6, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 7, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 8, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 9, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 10, 26, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 11, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 12, 111, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 13, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 14, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120602016415, 15, 60, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 1, 145, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 2, 133, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 3, 25, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 4, 114, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 5, 131, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 6, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 7, 27, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 8, 187, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 9, 10, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 10, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 11, 159, 93, 16, 1488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 12, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091227016416, 13, 72, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212016417, 1, 139, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212016417, 2, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212016417, 3, 171, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212016417, 4, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030212016417, 5, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121016418, 1, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000121016418, 2, 35, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 1, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 2, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 3, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 4, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 5, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 6, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 7, 99, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 8, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 9, 41, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 7, 51, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 8, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 9, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 10, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 11, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 12, 101, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 13, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 14, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 15, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130819016793, 16, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 1, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 2, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 3, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 4, 139, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 5, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 6, 37, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 7, 13, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 8, 108, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 9, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 10, 182, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 11, 129, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 12, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 13, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 14, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110808016794, 15, 100, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 1, 116, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 2, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 3, 108, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 4, 36, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 5, 109, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731016795, 6, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 1, 121, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 2, 31, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 3, 94, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 4, 56, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 5, 101, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 6, 85, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 7, 54, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 8, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 9, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 10, 185, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 11, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 12, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 13, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100111016796, 14, 180, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 1, 62, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 2, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 3, 187, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 4, 78, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 5, 7, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 6, 105, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002016797, 7, 43, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111016798, 1, 31, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111016798, 2, 77, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111016798, 3, 46, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010111016798, 4, 19, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 1, 162, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 2, 26, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 3, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 4, 150, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 5, 45, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 6, 97, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 7, 91, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 8, 125, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 9, 20, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 10, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 11, 165, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 12, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 13, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101012016799, 14, 38, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 1, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 2, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 3, 46, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 4, 89, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 5, 69, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 6, 121, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 7, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 8, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 9, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 10, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 11, 91, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 12, 157, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 13, 63, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 14, 48, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 15, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 16, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140502016800, 17, 30, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 1, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 2, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 3, 90, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 4, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 5, 154, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 6, 93, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 7, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 8, 120, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 9, 6, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 10, 116, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 11, 71, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 12, 185, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 13, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 14, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120711016801, 15, 46, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 1, 175, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 2, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 3, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 4, 88, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 5, 108, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020928016802, 6, 173, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106016803, 1, 3, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106016803, 2, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106016803, 3, 99, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000106016803, 4, 143, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118016804, 1, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118016804, 2, 115, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118016804, 3, 48, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020118016804, 4, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 1, 80, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 2, 54, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 3, 173, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 4, 48, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 5, 149, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 6, 44, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040320016805, 7, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 1, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 2, 31, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 3, 29, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 4, 180, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 5, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 6, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 7, 148, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040702016806, 8, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 1, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 2, 82, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 3, 186, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 4, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 5, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 6, 108, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 7, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 8, 167, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 9, 128, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 10, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 11, 30, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 12, 110, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 13, 130, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 14, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 15, 107, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 16, 126, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 17, 140, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130321016807, 18, 154, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204016808, 1, 80, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001204016808, 2, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 1, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 2, 152, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 3, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 4, 40, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 5, 53, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 6, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 7, 70, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 8, 26, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 9, 70, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 10, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 11, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 12, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080809016809, 13, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 1, 164, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 2, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 3, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 4, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 5, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020131016810, 6, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 1, 131, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 2, 187, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 3, 113, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 4, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 5, 83, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 6, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 7, 166, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 8, 40, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 9, 185, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 10, 180, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081109016811, 11, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 1, 100, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 2, 72, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 3, 167, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 4, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 5, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 6, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 7, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030909016812, 8, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 1, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 2, 80, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 3, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 4, 37, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 5, 110, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 6, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016813, 7, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 1, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 2, 97, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 3, 117, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 4, 162, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 5, 120, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040610016814, 6, 150, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 1, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 2, 83, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 3, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 4, 142, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 5, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 6, 34, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051121016815, 7, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 1, 119, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 2, 4, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 3, 177, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 4, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 5, 186, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020602016816, 6, 113, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412016817, 1, 142, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412016817, 2, 16, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412016817, 3, 145, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412016817, 4, 37, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412016817, 5, 118, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 1, 172, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 2, 102, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 3, 128, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 4, 22, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 5, 3, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117016818, 6, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 1, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 2, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 3, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 4, 140, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 5, 20, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 6, 151, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 7, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 8, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 9, 192, 12, 18, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 10, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 11, 170, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090607016819, 12, 28, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016820, 1, 86, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 4, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 5, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 6, 91, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 7, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 8, 58, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 9, 114, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 10, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 11, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100515017165, 12, 176, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 1, 126, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 2, 22, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 3, 180, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 4, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 5, 85, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 6, 77, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 7, 156, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 8, 73, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060318017166, 9, 10, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 1, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 2, 24, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 3, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 4, 100, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 5, 38, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 6, 88, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 7, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 8, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 9, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060922017167, 10, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 1, 34, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 2, 150, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 3, 60, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 4, 109, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 5, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017168, 6, 55, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 1, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 2, 97, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 3, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 4, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 5, 32, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 6, 14, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 7, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 8, 73, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 9, 39, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060814017169, 10, 24, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 1, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 2, 60, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 3, 188, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 4, 43, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 5, 84, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 6, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 7, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 8, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 9, 95, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 10, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 11, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 12, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 13, 15, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 14, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 15, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 16, 73, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130629017170, 17, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 1, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 2, 129, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 3, 19, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 4, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 5, 133, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 6, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 7, 115, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 8, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 9, 145, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060530017171, 10, 179, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 1, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 2, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 3, 36, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 4, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 5, 70, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 6, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 7, 88, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 8, 176, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 9, 173, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 10, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 11, 123, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 12, 186, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 13, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 14, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 15, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121102017172, 16, 92, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 1, 28, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 2, 122, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 3, 26, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 4, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 5, 125, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 6, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 7, 67, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 8, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 9, 132, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 10, 134, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 11, 186, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 12, 30, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 13, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 14, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100506017173, 15, 130, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 1, 6, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 2, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 3, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 4, 55, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 5, 17, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 6, 140, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 7, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 8, 34, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 9, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 10, 14, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 11, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 12, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 13, 155, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 14, 143, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 15, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130709017174, 16, 138, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217017175, 1, 83, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217017175, 2, 74, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217017175, 3, 32, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217017175, 4, 101, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031217017175, 5, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 1, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 2, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 3, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 4, 173, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 5, 25, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 6, 191, 39, 17, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 7, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 8, 168, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 9, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 10, 184, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 11, 77, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 12, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 13, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 14, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110118017176, 15, 19, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 1, 9, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 2, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 3, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 4, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 5, 34, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 6, 82, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 7, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 8, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 9, 179, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 10, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 11, 183, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 12, 18, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 13, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 14, 186, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 15, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130508017177, 16, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 1, 142, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 2, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 3, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 4, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 5, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 6, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 7, 30, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 8, 169, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 9, 72, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 10, 13, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070705017178, 11, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914017179, 1, 134, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914017179, 2, 4, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914017179, 3, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914017179, 4, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010914017179, 5, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 1, 19, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 2, 169, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 3, 69, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 4, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 5, 92, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 6, 113, 8, 8, 64);
commit;
prompt 171000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 7, 56, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 8, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 9, 19, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 10, 172, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 11, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 12, 79, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 13, 95, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 14, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 15, 104, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120424017180, 16, 2, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 1, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 2, 1, 57, 3, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 3, 55, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 4, 59, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 5, 90, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 6, 86, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 7, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 8, 21, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 9, 15, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 10, 113, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 11, 140, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 12, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 13, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 14, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 15, 141, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140125017181, 16, 134, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 1, 84, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 2, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 3, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 4, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 5, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 6, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 7, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 8, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 9, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 10, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 11, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 12, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091126017182, 13, 59, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 1, 81, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 2, 187, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 3, 28, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 4, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 5, 36, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030806017183, 6, 38, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 1, 136, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 2, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 3, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 4, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 5, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 6, 28, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 7, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 8, 191, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 9, 9, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 10, 85, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 11, 11, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 12, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 13, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 14, 86, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120719017184, 15, 81, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 1, 171, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 2, 181, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 3, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 2, 90, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 3, 16, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 4, 69, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 5, 30, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 6, 119, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 7, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 8, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 9, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 10, 100, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 11, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 12, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 13, 151, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110817017577, 14, 35, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 1, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 2, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 3, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 4, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 5, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 6, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 7, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 8, 86, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 9, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 10, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 11, 52, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090121017578, 12, 179, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 1, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 2, 23, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 3, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 4, 39, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 5, 158, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 6, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 7, 81, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 8, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 9, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 10, 14, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 11, 5, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 12, 140, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090320017579, 13, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 1, 155, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 2, 145, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 3, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 4, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 5, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 6, 77, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 7, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 8, 29, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040629017580, 9, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 1, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 2, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 3, 83, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 4, 174, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 5, 153, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020212017581, 6, 4, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 1, 129, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 2, 65, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 3, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 4, 50, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 5, 17, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 6, 32, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 7, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 8, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 9, 168, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 10, 36, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080919017582, 11, 184, 37, 17, 629);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 1, 26, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 2, 151, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 3, 96, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 4, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 5, 41, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 6, 16, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 7, 97, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 8, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 9, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 10, 161, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124017583, 11, 55, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 1, 22, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 2, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 3, 138, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 4, 76, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 5, 11, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 6, 64, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 7, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 8, 155, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 9, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 10, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070514017584, 11, 12, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 1, 104, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 2, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 3, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 4, 106, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 5, 87, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021121017585, 6, 141, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 1, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 2, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 3, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 4, 101, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 5, 32, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 6, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 7, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 8, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 9, 171, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 10, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071226017586, 11, 173, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 1, 75, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 2, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 3, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 4, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 5, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 6, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 7, 165, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041221017587, 8, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 1, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 2, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 3, 76, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 4, 77, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 5, 79, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 6, 140, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 7, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 8, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 9, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070909017588, 10, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 1, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 2, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 3, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 4, 42, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 5, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 6, 29, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 7, 47, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 8, 152, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 9, 33, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070501017589, 10, 1, 96, 3, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 1, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 2, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 3, 27, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 4, 182, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 5, 150, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041107017590, 6, 134, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 1, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 2, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 3, 94, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 4, 6, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 5, 172, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 6, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 7, 63, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 8, 89, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 9, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 10, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 11, 192, 40, 18, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081022017591, 12, 26, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 1, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 2, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 3, 157, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 4, 61, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 5, 103, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 6, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 7, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 8, 89, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 9, 79, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 10, 149, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 11, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070129017592, 12, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 1, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 2, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 3, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 4, 68, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 5, 29, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 6, 109, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 7, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 8, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 9, 156, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 10, 155, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 11, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 12, 22, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100104017593, 13, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 1, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 2, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 3, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 4, 192, 3, 18, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 5, 80, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 6, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 7, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 8, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 9, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 10, 66, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 11, 127, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 12, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 13, 59, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223017594, 14, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017595, 1, 66, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017595, 2, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017595, 3, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017595, 4, 81, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001225017595, 5, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 1, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 2, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 3, 152, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 4, 92, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 5, 115, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 6, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 7, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 8, 73, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 9, 156, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 10, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 11, 12, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 12, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 13, 121, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 14, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 15, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 16, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131028017596, 17, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 1, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 2, 89, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 3, 8, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 4, 41, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 5, 19, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 6, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 7, 77, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 8, 79, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051231017597, 9, 24, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322017598, 1, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322017598, 2, 53, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322017598, 3, 192, 32, 18, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322017598, 4, 39, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322017598, 5, 80, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 1, 189, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 2, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 3, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 4, 77, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 5, 126, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 6, 175, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 7, 88, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 8, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 9, 132, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 10, 143, 1, 14, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 11, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 12, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 13, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111223017599, 14, 178, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304017600, 1, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 10, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 11, 84, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 12, 134, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 13, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 14, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 15, 95, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603016419, 16, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027016420, 1, 20, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027016420, 2, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001027016420, 3, 84, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419016421, 1, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419016421, 2, 80, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419016421, 3, 80, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419016421, 4, 40, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010419016421, 5, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 1, 140, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 2, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 3, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 4, 118, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 5, 177, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 6, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 7, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 8, 32, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 9, 46, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 10, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 11, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 12, 125, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 13, 81, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 14, 180, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 15, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 16, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121105016422, 17, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 1, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 2, 187, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 3, 104, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 4, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 5, 85, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 6, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 7, 140, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 8, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050303016423, 9, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 1, 99, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 2, 40, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 3, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 4, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 5, 3, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 6, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 7, 135, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 8, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 9, 36, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 10, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080608016424, 11, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 1, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 2, 61, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 3, 129, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 4, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 5, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 6, 42, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 7, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 8, 72, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 9, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 10, 129, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 11, 168, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 12, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 13, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 14, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620016425, 15, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 1, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 2, 6, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 3, 142, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 4, 177, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 5, 161, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 6, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 7, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 8, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 9, 142, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 10, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 11, 38, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 12, 171, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 13, 59, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110917016426, 14, 159, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331016427, 1, 129, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331016427, 2, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331016427, 3, 128, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331016427, 4, 144, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020331016427, 5, 34, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504016428, 1, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504016428, 2, 183, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504016428, 3, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504016428, 4, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504016428, 5, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 1, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 2, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 3, 27, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 4, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 5, 105, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 6, 59, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 7, 94, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 8, 94, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 9, 151, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 10, 150, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080308016429, 11, 183, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016430, 1, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016430, 2, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010302016430, 3, 140, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 1, 85, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 2, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 3, 184, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 4, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 5, 74, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 6, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 7, 121, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 8, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 9, 38, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 10, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 11, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 12, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 13, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 14, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 15, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130627016431, 16, 34, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 1, 184, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 2, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 3, 44, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 4, 4, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 5, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 6, 33, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 7, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 8, 101, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 9, 153, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 10, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 11, 170, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 12, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 13, 123, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 14, 179, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120622016432, 15, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113016433, 1, 82, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113016433, 2, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113016433, 3, 126, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000113016433, 4, 92, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426016434, 1, 192, 4, 18, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426016434, 2, 47, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000426016434, 3, 192, 73, 18, 1314);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 1, 102, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 2, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 3, 138, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 4, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 5, 183, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 6, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 7, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 8, 1, 48, 3, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 9, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 10, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 11, 123, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070117016435, 12, 34, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 1, 187, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 2, 183, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 3, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 4, 71, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 5, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 6, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040425016436, 7, 52, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 1, 171, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 2, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 3, 47, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 4, 39, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 5, 159, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 6, 99, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 7, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 8, 92, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 9, 166, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080110016437, 10, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 1, 112, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 2, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 3, 145, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 4, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 5, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 6, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 7, 34, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 8, 150, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 9, 109, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 10, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071025016438, 11, 27, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 1, 135, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 2, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 3, 173, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 4, 109, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 5, 86, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 6, 33, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 7, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 8, 70, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 9, 185, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 10, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 11, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 12, 32, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 13, 158, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120121016439, 14, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 1, 12, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 2, 99, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 3, 59, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 4, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 5, 143, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 6, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 7, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 8, 8, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 9, 3, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 10, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 11, 48, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090618016440, 12, 100, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 1, 189, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 2, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 3, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 4, 120, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 5, 132, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 6, 45, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 7, 67, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 8, 45, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 9, 73, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060805016441, 10, 3, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 1, 169, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 2, 100, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 3, 14, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 4, 56, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 5, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 6, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040811016442, 7, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 1, 7, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 2, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 3, 71, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 4, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 5, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 6, 82, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 7, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 8, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 9, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 10, 163, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 11, 142, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 12, 127, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 13, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016820, 2, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016820, 3, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016820, 4, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016820, 5, 9, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 1, 62, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 2, 52, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 3, 75, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 4, 112, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 5, 9, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 6, 156, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 7, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 8, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 9, 65, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 10, 130, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 11, 101, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 12, 101, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 13, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 14, 165, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 15, 84, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 16, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140419016821, 17, 126, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 1, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 2, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 3, 78, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 4, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 5, 97, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 6, 124, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041014016822, 7, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104016823, 1, 160, 82, 17, 1394);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000104016823, 2, 37, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 1, 89, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 2, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 3, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 4, 166, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 5, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 6, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 7, 54, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 8, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 9, 28, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 10, 84, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 11, 8, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 12, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 13, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 14, 22, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016824, 15, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628016825, 1, 148, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628016825, 2, 98, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000628016825, 3, 100, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306016826, 1, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306016826, 2, 70, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306016826, 3, 20, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306016826, 4, 82, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020306016826, 5, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 1, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 2, 105, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 3, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 4, 118, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 5, 100, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 6, 1, 33, 3, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 7, 25, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 8, 131, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 9, 35, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 10, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080925016827, 11, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016828, 1, 175, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016828, 2, 164, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016828, 3, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016828, 4, 13, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016828, 5, 140, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805016829, 1, 131, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805016829, 2, 169, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805016829, 3, 70, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805016829, 4, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000805016829, 5, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 1, 101, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 2, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 3, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 4, 86, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 5, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 6, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 7, 18, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 8, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 9, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 10, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 11, 117, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 12, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 13, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016830, 14, 133, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 1, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 2, 100, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 3, 70, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 4, 50, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 5, 117, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 6, 97, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 7, 72, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041010016831, 8, 110, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 1, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 2, 18, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 3, 167, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 4, 111, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 5, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 6, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 7, 65, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 8, 42, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 9, 78, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 10, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 11, 59, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 12, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 13, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 14, 130, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 15, 24, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 16, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 17, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016832, 18, 58, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 1, 35, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 2, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 3, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 4, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 5, 176, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 6, 136, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040831016833, 7, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825016834, 1, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000825016834, 2, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 1, 161, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 2, 31, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 3, 58, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 4, 157, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 5, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 6, 98, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 7, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 8, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 9, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 10, 155, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 11, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 12, 14, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 13, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101104016835, 14, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 1, 168, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 2, 42, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 3, 102, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 4, 4, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 5, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 6, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 7, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 8, 192, 8, 18, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 9, 135, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061005016836, 10, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016837, 1, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016837, 2, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000220016837, 3, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 1, 175, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 2, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 3, 63, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 4, 49, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 5, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 6, 72, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 7, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030131016838, 8, 182, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 1, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 2, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 3, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 4, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 5, 148, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 6, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 7, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051214016839, 8, 76, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 1, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 2, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 3, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 4, 48, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 5, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 6, 127, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 7, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 8, 111, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 9, 158, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 10, 152, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071027016840, 11, 134, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 1, 137, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 2, 71, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 3, 25, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 4, 32, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 5, 94, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 6, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 7, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 8, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 9, 23, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 10, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 11, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 12, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 13, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 14, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100520016841, 15, 141, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 1, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 2, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 3, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 4, 103, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 5, 58, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 6, 85, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 7, 21, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 8, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 9, 122, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 10, 14, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 11, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 12, 180, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 13, 19, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 14, 115, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 15, 38, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 16, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 17, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131224016842, 18, 147, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 1, 88, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 2, 118, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 3, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 4, 60, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 5, 154, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 6, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 7, 169, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050101016843, 8, 91, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 1, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 2, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 3, 41, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 4, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 5, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 6, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 7, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 8, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 9, 29, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 10, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 11, 192, 63, 18, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 12, 84, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 13, 127, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 14, 88, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 15, 11, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 16, 156, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120110016844, 17, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 1, 28, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 2, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 3, 169, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 4, 157, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 4, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 5, 4, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 6, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 7, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 8, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 9, 178, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 10, 140, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 11, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 12, 154, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 13, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 14, 85, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100410017185, 15, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 1, 146, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 2, 149, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 3, 23, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 4, 5, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 5, 42, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 6, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 7, 89, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 8, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 9, 19, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 10, 90, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017186, 11, 183, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 1, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 2, 105, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 3, 70, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 4, 162, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 5, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 6, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 7, 89, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 8, 87, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050703017187, 9, 66, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 1, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 2, 169, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 3, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 4, 58, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 5, 81, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 6, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030913017188, 7, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 1, 169, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 2, 5, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 3, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 4, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 5, 150, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 6, 23, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 7, 67, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 8, 135, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 9, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 10, 191, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 11, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 12, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 13, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 14, 177, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 15, 127, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 16, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140325017189, 17, 158, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 1, 133, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 2, 99, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 3, 142, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 4, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 5, 124, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 6, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308017190, 7, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110017191, 1, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110017191, 2, 73, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010110017191, 3, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 1, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 2, 166, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 3, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 4, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 5, 132, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 6, 65, 29, 5, 145);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040326017192, 7, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030017193, 1, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030017193, 2, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030017193, 3, 189, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030017193, 4, 58, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011030017193, 5, 176, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 1, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 2, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 3, 21, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 4, 113, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 5, 16, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 6, 163, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 7, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 8, 126, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807017194, 9, 178, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608017195, 1, 13, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608017195, 2, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010608017195, 3, 29, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 1, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 2, 121, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 3, 111, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 4, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 5, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 6, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 7, 102, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 8, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 9, 140, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 10, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 11, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 12, 27, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 13, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 14, 126, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 15, 33, 27, 4, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121209017196, 16, 84, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 1, 125, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 2, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 3, 30, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 4, 187, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 5, 5, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 6, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 7, 63, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 8, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 9, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 10, 131, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 11, 55, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091103017197, 12, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 1, 110, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 2, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 3, 145, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 4, 19, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 5, 122, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 6, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020329017198, 7, 126, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 1, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 2, 118, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 3, 31, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 4, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 5, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 6, 80, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 7, 145, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 8, 83, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 9, 22, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 10, 18, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103017199, 11, 76, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 1, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 2, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 3, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 4, 97, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 5, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 6, 112, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 7, 67, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 8, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 9, 15, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 10, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 11, 138, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 12, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 13, 168, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 14, 80, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131005017200, 15, 121, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 1, 57, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 2, 59, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 3, 119, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 4, 65, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 5, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 6, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 7, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 8, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 9, 130, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 10, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 11, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 12, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 13, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 14, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 15, 105, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130118017201, 16, 94, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 1, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 2, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 3, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 4, 173, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 5, 187, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 6, 11, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 7, 127, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 8, 45, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 9, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 10, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 11, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 12, 33, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110128017202, 13, 158, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 1, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 2, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 3, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 4, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 5, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 6, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 7, 153, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 8, 23, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 9, 35, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 10, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 11, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071106017203, 12, 183, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224017204, 1, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224017204, 2, 28, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000224017204, 3, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 1, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 2, 109, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 3, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 4, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 5, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 6, 190, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 7, 2, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 8, 46, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 9, 46, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 10, 93, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 11, 137, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 12, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 13, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017205, 14, 65, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017206, 1, 64, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017206, 2, 139, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017206, 3, 177, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017206, 4, 30, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 1, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 2, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 3, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 4, 97, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 5, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 6, 54, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 7, 173, 82, 13, 1066);
commit;
prompt 172000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 8, 76, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 9, 184, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070820017207, 10, 32, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 1, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 2, 121, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 3, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 4, 86, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 5, 132, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 6, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 7, 133, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 8, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 9, 175, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 10, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 11, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 12, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 13, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 14, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100330017208, 15, 115, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 1, 166, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010510017485, 4, 51, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 1, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 2, 63, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 3, 13, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 4, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 5, 119, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 6, 79, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 7, 131, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 8, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 9, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 10, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060808017486, 11, 17, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 1, 35, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 2, 44, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 3, 169, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 4, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 5, 118, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 6, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 7, 137, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 8, 33, 49, 4, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 9, 183, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 10, 6, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 11, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 12, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100115017487, 13, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 1, 97, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 2, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 3, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 4, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 5, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021117017488, 6, 185, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000906017489, 1, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000906017489, 2, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 1, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 2, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 3, 132, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 4, 52, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 5, 184, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 6, 185, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 7, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 8, 98, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 9, 131, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 10, 87, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 11, 4, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 12, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 13, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 14, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 15, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206017490, 16, 73, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 1, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 2, 88, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 3, 181, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 4, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 5, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 6, 124, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 7, 31, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 8, 191, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 9, 69, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 10, 190, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 11, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 12, 81, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 13, 124, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100422017491, 14, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 1, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 2, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 3, 13, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 4, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 5, 58, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 6, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 7, 142, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 8, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 9, 175, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 10, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081019017492, 11, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017493, 1, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017493, 2, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017493, 3, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017493, 4, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 1, 161, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 2, 79, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 3, 9, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 4, 90, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 5, 26, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 6, 175, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 7, 13, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030301017494, 8, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630017495, 1, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630017495, 2, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630017495, 3, 155, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000630017495, 4, 42, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 1, 83, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 2, 114, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 3, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 4, 165, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 5, 29, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 6, 114, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 7, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 8, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 9, 192, 59, 18, 1062);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 10, 50, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 11, 161, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080615017496, 12, 106, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426017497, 1, 158, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426017497, 2, 66, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426017497, 3, 126, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010426017497, 4, 26, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 1, 179, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 2, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 3, 70, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 4, 154, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 5, 65, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 6, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 7, 31, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 8, 129, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 9, 106, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 10, 76, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 11, 97, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 12, 85, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 13, 133, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 14, 156, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 15, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121024017498, 16, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 1, 171, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 2, 108, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 3, 81, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 4, 67, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 5, 56, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 6, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 7, 31, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 8, 95, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 9, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 10, 120, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 11, 175, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 12, 109, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 13, 16, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 14, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 15, 12, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605017499, 16, 27, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 1, 75, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 2, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 3, 105, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 4, 115, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 5, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703017500, 6, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 1, 92, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 2, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 3, 133, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 4, 91, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 5, 93, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 6, 89, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 7, 112, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 8, 118, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 9, 165, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 10, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 11, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 12, 127, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 13, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 14, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 15, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110907017501, 16, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 1, 47, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 2, 167, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 3, 99, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 4, 24, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 5, 41, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 6, 77, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 7, 88, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 8, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 9, 98, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 10, 127, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 11, 157, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 12, 21, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 13, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 14, 85, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 15, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 16, 180, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131027017502, 17, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 1, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 2, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 3, 163, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 4, 92, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 5, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 6, 56, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 7, 40, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 8, 33, 100, 4, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 9, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 10, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070317017503, 11, 135, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017504, 1, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017504, 2, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001115017504, 3, 125, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 1, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 2, 93, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 3, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 4, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 5, 180, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606017505, 6, 152, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 1, 149, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 2, 89, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 3, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 4, 61, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 5, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 6, 43, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 7, 127, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 8, 9, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 9, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 10, 179, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 11, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 12, 191, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 13, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110824017506, 14, 136, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 1, 47, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 2, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 3, 10, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 4, 57, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 5, 33, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 6, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 7, 70, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 8, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 9, 85, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017507, 10, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526017508, 1, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526017508, 2, 71, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526017508, 3, 60, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526017508, 4, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000526017508, 5, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 1, 192, 1, 18, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 2, 155, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 3, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 4, 35, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 5, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 6, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 7, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 8, 173, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 9, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 10, 69, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 11, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 12, 28, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100304017509, 13, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 14, 9, 85, 4, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 15, 176, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 16, 154, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140404016443, 17, 165, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 1, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 2, 38, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 3, 138, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 4, 17, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 5, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 6, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 7, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051229016444, 8, 124, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 1, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 2, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 3, 62, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 4, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 5, 105, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 6, 186, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 7, 26, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 8, 50, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 9, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 10, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060811016445, 11, 50, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 1, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 2, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 3, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 4, 179, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 5, 83, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 6, 97, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 7, 7, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040606016446, 8, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 1, 102, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 2, 70, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 3, 138, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 4, 45, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 5, 21, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 6, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 7, 59, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 8, 139, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 9, 92, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 10, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 11, 122, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 12, 56, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 13, 148, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110506016447, 14, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 1, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 2, 102, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 3, 98, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 4, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 5, 179, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 6, 31, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 7, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 8, 142, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 9, 87, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 10, 185, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 11, 149, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 12, 58, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909016448, 13, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 1, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 2, 90, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 3, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 4, 58, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 5, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 6, 143, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 7, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 8, 190, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050807016449, 9, 46, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504016450, 1, 170, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000504016450, 2, 184, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 1, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 2, 78, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 3, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 4, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 5, 42, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 6, 150, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030118016451, 7, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 1, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 2, 192, 45, 18, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 3, 6, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 4, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 5, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 6, 144, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 7, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 8, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928016452, 9, 53, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 1, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 2, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 3, 104, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 4, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 5, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 6, 100, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040330016453, 7, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 1, 23, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 2, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 3, 184, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 4, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 5, 123, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 6, 144, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 7, 50, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030228016454, 8, 84, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 1, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 2, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 3, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 4, 1, 3, 3, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 5, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 6, 80, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 7, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 8, 146, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 9, 109, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 10, 178, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 11, 71, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 12, 55, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 13, 115, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 14, 170, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 15, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 16, 170, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 17, 136, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140311016455, 18, 41, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 1, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 2, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 3, 192, 26, 18, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 4, 22, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 5, 154, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 6, 122, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 7, 186, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 8, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 9, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 10, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 11, 86, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 12, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 13, 19, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090218016456, 14, 140, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 1, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 2, 71, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 3, 75, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 4, 77, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 5, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 6, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 7, 85, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 8, 131, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 9, 44, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070428016457, 10, 17, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 1, 136, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 2, 98, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 3, 93, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 4, 73, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 5, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 6, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 7, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 8, 190, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207016458, 9, 185, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 1, 162, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 2, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 3, 46, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 4, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 5, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 6, 168, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 7, 167, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 8, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 9, 31, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 10, 94, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 11, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 12, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101212016459, 13, 37, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 1, 129, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 2, 47, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 3, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 4, 101, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 5, 140, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 6, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 7, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 8, 80, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 9, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 10, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 11, 68, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 12, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 13, 8, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 14, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 15, 187, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120220016460, 16, 60, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 1, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 2, 165, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 3, 115, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 4, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 5, 151, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 6, 182, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 7, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 8, 158, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 9, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 10, 136, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 11, 14, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 12, 39, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 13, 159, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120611016461, 14, 114, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 1, 189, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 2, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 3, 95, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 4, 78, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 5, 87, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 6, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 7, 181, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040404016462, 8, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 1, 157, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 2, 77, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 3, 87, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 4, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 5, 10, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 6, 144, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 7, 46, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 8, 139, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 9, 161, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 10, 149, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 11, 46, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 12, 171, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 13, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 14, 84, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110321016463, 15, 125, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 1, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 2, 152, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 3, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 4, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 5, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 6, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 7, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 8, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 9, 67, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016464, 10, 117, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 1, 20, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 2, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 3, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 4, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 5, 7, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 6, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 7, 139, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 8, 41, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 9, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 10, 40, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070926016465, 11, 120, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 1, 104, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 5, 6, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 6, 19, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 7, 161, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 8, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 9, 167, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 10, 80, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 11, 50, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 12, 51, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 13, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 14, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111213016845, 15, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 1, 104, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 2, 86, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 3, 64, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 4, 44, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 5, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 6, 53, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 7, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 8, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060921016846, 9, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 1, 47, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 2, 184, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 3, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 4, 157, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 5, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 6, 68, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040906016847, 7, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 1, 162, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 2, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 3, 66, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 4, 37, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 5, 154, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 6, 111, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 7, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016848, 8, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722016849, 1, 7, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722016849, 2, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722016849, 3, 112, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722016849, 4, 177, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010722016849, 5, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 1, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 2, 19, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 3, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 4, 15, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 5, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020523016850, 6, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 1, 103, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 2, 100, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 3, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 4, 181, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 5, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 6, 10, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 7, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 8, 53, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 9, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 10, 183, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 11, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 12, 33, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 13, 76, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101129016851, 14, 85, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 1, 156, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 2, 143, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 3, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 4, 114, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 5, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 6, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030220016852, 7, 85, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 1, 107, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 2, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 3, 178, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 4, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 5, 189, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 6, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 7, 45, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 8, 151, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 9, 35, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051013016853, 10, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 1, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 2, 76, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 3, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 4, 156, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 5, 110, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 6, 115, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 7, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 8, 65, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 9, 104, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080609016854, 10, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 1, 167, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 2, 159, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 3, 64, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 4, 30, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 5, 86, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 6, 109, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 7, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 8, 71, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 9, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 10, 122, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 11, 7, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 12, 184, 87, 17, 1479);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 13, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 14, 164, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 15, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 16, 4, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130225016855, 17, 50, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 1, 106, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 2, 154, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 3, 70, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 4, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 5, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 6, 79, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 7, 39, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 8, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050723016856, 9, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 1, 33, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 2, 134, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 3, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 4, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 5, 175, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 6, 156, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 7, 191, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 8, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 9, 110, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 10, 82, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 11, 11, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 12, 169, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 13, 138, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 14, 18, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111220016857, 15, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 1, 31, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 2, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 3, 132, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 4, 160, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 5, 3, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 6, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 7, 75, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 8, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 9, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 10, 166, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 11, 170, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 12, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 13, 5, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 14, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101108016858, 15, 168, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 1, 111, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 2, 59, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 3, 173, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 4, 114, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 5, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 6, 61, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 7, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 8, 135, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 9, 157, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 10, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 11, 43, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 12, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 13, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 14, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130517016859, 15, 135, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 1, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 2, 155, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 3, 10, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 4, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 5, 69, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021102016860, 6, 120, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 1, 30, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 2, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 3, 124, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 4, 170, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 5, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 6, 151, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 7, 24, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 8, 121, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 9, 137, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 10, 144, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 11, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 12, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 13, 163, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110721016861, 14, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 1, 20, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 2, 36, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 3, 51, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 4, 155, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 5, 185, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 6, 94, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 7, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 8, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 9, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 10, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 11, 7, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070325016862, 12, 111, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 1, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 2, 78, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 3, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 4, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 5, 128, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040503016863, 6, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 1, 82, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 2, 116, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 3, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 4, 51, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 5, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 6, 176, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 7, 71, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 8, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 9, 81, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 10, 98, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 11, 16, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 12, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 13, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 14, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 15, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 16, 175, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130808016864, 17, 165, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 1, 96, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 2, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 3, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 4, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 5, 16, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 6, 28, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 7, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 8, 108, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040627016865, 9, 133, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 1, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 2, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 3, 16, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 4, 141, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 5, 98, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 6, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 7, 63, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 8, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 9, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 10, 185, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016866, 11, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 1, 8, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 2, 119, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 3, 129, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 4, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 5, 36, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 6, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 2, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 3, 73, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 4, 24, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 5, 99, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 6, 40, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 7, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060413017209, 8, 183, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 1, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 2, 164, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 3, 168, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 4, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 5, 160, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 6, 119, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 7, 111, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 8, 46, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 9, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 10, 191, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090311017210, 11, 30, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304017211, 1, 89, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304017211, 2, 172, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304017211, 3, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000304017211, 4, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 1, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 2, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 3, 17, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 4, 85, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 5, 54, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 6, 181, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 7, 152, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 8, 11, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 9, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 10, 65, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 11, 131, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 12, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 13, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 14, 36, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100730017212, 15, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407017213, 1, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407017213, 2, 179, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407017213, 3, 191, 72, 17, 1224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407017213, 4, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407017213, 5, 49, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 1, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 2, 51, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 3, 109, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 4, 14, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 5, 26, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 6, 109, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 7, 100, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 8, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 9, 88, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 10, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 11, 18, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 12, 108, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 13, 55, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 14, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 15, 26, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130831017214, 16, 55, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 1, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 2, 142, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 3, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 4, 51, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 5, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 6, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 7, 31, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 8, 190, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 9, 29, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 10, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 11, 67, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 12, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 13, 68, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 14, 15, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 15, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130703017215, 16, 111, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 1, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 2, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 3, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 4, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 5, 111, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031020017216, 6, 152, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 1, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 2, 62, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 3, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 4, 124, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 5, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 6, 10, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 7, 69, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 8, 156, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 9, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 10, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 11, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090725017217, 12, 157, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 1, 10, 57, 5, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 2, 102, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 3, 37, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 4, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 5, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 6, 173, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 7, 167, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 8, 5, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 9, 118, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 10, 141, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 11, 51, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 12, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100329017218, 13, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 1, 138, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 2, 34, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 3, 46, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 4, 27, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 5, 34, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 6, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 7, 77, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 8, 6, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060909017219, 9, 112, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 1, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 2, 103, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 3, 191, 25, 17, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 4, 129, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 5, 102, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 6, 168, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 7, 58, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 8, 16, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 9, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 10, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 11, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017220, 12, 20, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 1, 104, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 2, 122, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 3, 113, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 4, 12, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 5, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 6, 95, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 7, 87, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 8, 178, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 9, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 10, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 11, 133, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 12, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017221, 13, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412017222, 1, 103, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412017222, 2, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412017222, 3, 23, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010412017222, 4, 180, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 1, 170, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 2, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 3, 161, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 4, 128, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 5, 59, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 6, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 7, 141, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 8, 165, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 9, 20, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 10, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 11, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 12, 150, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 13, 189, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 14, 182, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 15, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 16, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130603017223, 17, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 1, 108, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 2, 122, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 3, 123, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 4, 12, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 5, 23, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 6, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 7, 107, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 8, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 9, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 10, 63, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 11, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080314017224, 12, 107, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813017225, 1, 48, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813017225, 2, 37, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000813017225, 3, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202017226, 1, 143, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202017226, 2, 186, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202017226, 3, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202017226, 4, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021202017226, 5, 99, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 1, 60, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 2, 117, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 3, 162, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 4, 170, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 5, 48, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 6, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 7, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301017227, 8, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 1, 143, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 2, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 3, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 4, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 5, 166, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 6, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 7, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 8, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 9, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 10, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 11, 23, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 12, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 13, 17, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100131017228, 14, 65, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 1, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 2, 173, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 3, 137, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 4, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 5, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 6, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 7, 75, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 8, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 9, 140, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 10, 2, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 11, 68, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 12, 25, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 13, 60, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100328017229, 14, 117, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 1, 119, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 2, 41, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 3, 61, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 4, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 5, 9, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 6, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 7, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 8, 155, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 9, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 10, 13, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 11, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 12, 146, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091012017230, 13, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 1, 42, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 2, 183, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 3, 152, 43, 16, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 4, 6, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 5, 113, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 6, 62, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050904017231, 7, 57, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 1, 81, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 2, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 3, 134, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000703017533, 3, 18, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 1, 154, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 2, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 3, 4, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 4, 56, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 5, 109, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 6, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 7, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 8, 122, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041226017534, 9, 139, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 1, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 2, 57, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 3, 73, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 4, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 5, 187, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 6, 99, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 7, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 8, 47, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 9, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 10, 147, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 11, 20, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 12, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 13, 112, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 14, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 15, 54, 56, 11, 616);
commit;
prompt 173000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 16, 28, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120703017535, 17, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 1, 69, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 2, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 3, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 4, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 5, 28, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 6, 136, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 7, 136, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 8, 57, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 9, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070819017536, 10, 49, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 1, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 2, 9, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 3, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 4, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 5, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 6, 40, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 7, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 8, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 9, 23, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 10, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 11, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090622017537, 12, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 1, 102, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 2, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 3, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 4, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 5, 10, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 6, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 7, 120, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030213017538, 8, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 1, 93, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 2, 185, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 3, 133, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 4, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 5, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 6, 174, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 7, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 8, 146, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 9, 130, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 10, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070728017539, 11, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 1, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 2, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 3, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 4, 44, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 5, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 6, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 7, 87, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 8, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 9, 100, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 10, 65, 15, 5, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 11, 10, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 12, 53, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 13, 123, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 14, 30, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100813017540, 15, 11, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 1, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 2, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 3, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 4, 14, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 5, 41, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 6, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 7, 11, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 8, 51, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060201017541, 9, 151, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902017542, 1, 97, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902017542, 2, 166, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902017542, 3, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010902017542, 4, 34, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 1, 94, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 2, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 3, 147, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 4, 31, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 5, 162, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 6, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 7, 127, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 8, 52, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 9, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 10, 30, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 11, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 12, 67, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 13, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 14, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120522017543, 15, 37, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 1, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 2, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 3, 60, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 4, 7, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 5, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 6, 176, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 7, 54, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 8, 75, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060218017544, 9, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 1, 93, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 2, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 3, 61, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 4, 66, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 5, 92, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 6, 137, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 7, 109, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 8, 160, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 9, 189, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060605017545, 10, 143, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 1, 75, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 2, 50, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 3, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 4, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 5, 96, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 6, 165, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 7, 100, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 8, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051024017546, 9, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 1, 187, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 2, 171, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 3, 66, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 4, 143, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 5, 127, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 6, 85, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 7, 131, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 8, 7, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 9, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 10, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 11, 161, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 12, 130, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 13, 94, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 14, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110822017547, 15, 1, 10, 3, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 1, 115, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 2, 175, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 3, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 4, 180, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 5, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 6, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 7, 118, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 8, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 9, 124, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 10, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 11, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 12, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 13, 66, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 14, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 15, 38, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 16, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130323017548, 17, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120017549, 1, 184, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000120017549, 2, 51, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 1, 39, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 2, 86, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 3, 24, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 4, 156, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 5, 179, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 6, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 7, 70, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 8, 176, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 9, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 10, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 11, 123, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 12, 12, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 13, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110520017550, 14, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 1, 116, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 2, 179, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 3, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 4, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 5, 187, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 6, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 7, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 8, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 9, 37, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 10, 22, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 11, 129, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 12, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 13, 114, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 14, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111217017551, 15, 113, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 1, 103, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 2, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 3, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 4, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 5, 121, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 6, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 7, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 8, 49, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 9, 128, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061015017552, 10, 175, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 1, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 2, 19, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 3, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 4, 28, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 5, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 6, 167, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021015017553, 7, 81, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 1, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 2, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 3, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 4, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 5, 24, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 6, 116, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 7, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 8, 115, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 9, 115, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 10, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 11, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 12, 47, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110607017554, 13, 105, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 1, 119, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 2, 182, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 3, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 4, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 5, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 6, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080901017555, 7, 41, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 2, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 3, 103, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 4, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 5, 115, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 6, 53, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 7, 137, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 8, 139, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 9, 97, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 10, 143, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 11, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 12, 130, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 13, 187, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110317016466, 14, 117, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 1, 129, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 2, 102, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 3, 66, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 4, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 5, 16, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 6, 165, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 7, 46, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 8, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050122016467, 9, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 1, 98, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 2, 8, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 3, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 4, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 5, 53, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 6, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 7, 11, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 8, 17, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 9, 112, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071227016468, 10, 117, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 1, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 2, 95, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 3, 33, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 4, 165, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 5, 179, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 6, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 7, 80, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050927016469, 8, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 1, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 2, 17, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 3, 36, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 4, 41, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 5, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 6, 22, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 7, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 8, 141, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 9, 56, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 10, 192, 19, 18, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 11, 81, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 12, 137, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 13, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 14, 175, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 15, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 16, 37, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140322016470, 17, 141, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 1, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 2, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 3, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 4, 38, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 5, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 6, 69, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 7, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 8, 54, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 9, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060116016471, 10, 75, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111016472, 1, 29, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111016472, 2, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111016472, 3, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000111016472, 4, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723016473, 1, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723016473, 2, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723016473, 3, 167, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723016473, 4, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723016473, 5, 28, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 1, 48, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 2, 19, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 3, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 4, 96, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 5, 186, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 6, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 7, 12, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 8, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 9, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 10, 148, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 11, 158, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 12, 81, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 13, 36, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 14, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817016474, 15, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 1, 136, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 2, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 3, 54, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 4, 85, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 5, 140, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 6, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 7, 116, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 8, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 9, 158, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 10, 103, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 11, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 12, 85, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 13, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 14, 87, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130910016475, 15, 7, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 1, 21, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 2, 21, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 3, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 4, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 5, 38, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 6, 79, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 7, 185, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 8, 97, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 9, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 10, 157, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 11, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 12, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 13, 60, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016476, 14, 52, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226016477, 1, 176, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001226016477, 2, 101, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 1, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 2, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 3, 75, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 4, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 5, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 6, 99, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 7, 96, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 8, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 9, 72, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 10, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 11, 124, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 12, 172, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 13, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 14, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 15, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130106016478, 16, 74, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 1, 51, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 2, 49, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 3, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 4, 112, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 5, 10, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 6, 138, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 7, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 8, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 9, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 10, 65, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 11, 78, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 12, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 13, 113, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 14, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 15, 14, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016479, 16, 15, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706016480, 1, 154, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706016480, 2, 133, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706016480, 3, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000706016480, 4, 69, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 1, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 2, 31, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 3, 124, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 4, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 5, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 6, 3, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 7, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030216016481, 8, 84, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 1, 191, 71, 17, 1207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 2, 102, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 3, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 4, 163, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 5, 163, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 6, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 7, 44, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 8, 138, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 9, 189, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 10, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 11, 39, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 12, 4, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 13, 43, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 14, 185, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110129016482, 15, 103, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 1, 149, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 2, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 3, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 4, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 5, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 6, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 7, 14, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030326016483, 8, 24, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 1, 121, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 2, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 3, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 4, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 5, 173, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 6, 152, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 7, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 8, 58, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 9, 172, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 10, 16, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 11, 158, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 12, 161, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100618016484, 13, 9, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 1, 116, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 2, 105, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 3, 30, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 4, 104, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 5, 98, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 6, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 7, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 8, 179, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 9, 67, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 10, 100, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081013016485, 11, 158, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 1, 90, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 2, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 3, 82, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 4, 22, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 5, 132, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 6, 173, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 7, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 8, 10, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 9, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 10, 112, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 11, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 12, 177, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 13, 69, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 14, 19, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 15, 52, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120409016486, 16, 126, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 1, 28, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 2, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 3, 162, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 4, 145, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 5, 131, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904016487, 6, 104, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 1, 156, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 2, 158, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 3, 78, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 4, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050107016867, 7, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016868, 1, 152, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016868, 2, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016868, 3, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016868, 4, 123, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020615016868, 5, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 1, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 2, 120, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 3, 15, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 4, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 5, 186, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 6, 28, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 7, 138, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 8, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 9, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809016869, 10, 143, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 1, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 2, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 3, 156, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 4, 13, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 5, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 6, 136, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 7, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 8, 156, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 9, 178, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 10, 130, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 11, 105, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 12, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100612016870, 13, 62, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 1, 191, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 2, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 3, 170, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 4, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 5, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 6, 163, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 7, 52, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 8, 124, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060913016871, 9, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 1, 163, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 2, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 3, 172, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 4, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 5, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 6, 152, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 7, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051224016872, 8, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 1, 30, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 2, 162, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 3, 188, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 4, 28, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 5, 125, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 6, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 7, 126, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 8, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 9, 20, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 10, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 11, 87, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 12, 87, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 13, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 14, 36, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 15, 181, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130112016873, 16, 131, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 1, 48, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 2, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 3, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 4, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 5, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 6, 91, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 7, 130, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 8, 9, 31, 4, 124);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 9, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 10, 48, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 11, 6, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 12, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111111016874, 13, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 1, 122, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 2, 155, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 3, 114, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 4, 86, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 5, 117, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 6, 142, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 7, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 8, 43, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 9, 48, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061101016875, 10, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 1, 14, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 2, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 3, 113, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 4, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 5, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 6, 13, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 7, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 8, 125, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 9, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 10, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090911016876, 11, 47, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617016877, 1, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617016877, 2, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617016877, 3, 131, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020617016877, 4, 92, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 1, 21, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 2, 130, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 3, 117, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 4, 19, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 5, 17, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 6, 80, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 7, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 8, 49, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 9, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 10, 81, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 11, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 12, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 13, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111127016878, 14, 142, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 1, 179, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 2, 145, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 3, 185, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 4, 118, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 5, 62, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 6, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 7, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 8, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 9, 6, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 10, 182, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 11, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824016879, 12, 85, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 1, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 2, 4, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 3, 33, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 4, 112, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 5, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 6, 72, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 7, 76, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 8, 26, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 9, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050430016880, 10, 167, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 1, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 2, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 3, 13, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 4, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 5, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 6, 141, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 7, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 8, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 9, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 10, 181, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 11, 15, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 12, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 13, 158, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091107016881, 14, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 1, 90, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 2, 1, 92, 3, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 3, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 4, 135, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 5, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 6, 191, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021028016882, 7, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 1, 172, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 2, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 3, 13, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 4, 39, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 5, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 6, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 7, 110, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 8, 105, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 9, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 10, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070101016883, 11, 137, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 1, 169, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 2, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 3, 192, 61, 18, 1098);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 4, 60, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 5, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706016884, 6, 143, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704016885, 1, 53, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704016885, 2, 75, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704016885, 3, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704016885, 4, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020704016885, 5, 39, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 1, 176, 21, 16, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 2, 171, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 3, 39, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 4, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 5, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 6, 61, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 7, 139, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 8, 30, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 9, 112, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 10, 177, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 11, 88, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 12, 119, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 13, 121, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 14, 157, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 15, 22, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130609016886, 16, 138, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 1, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 2, 1, 52, 3, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 3, 113, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 4, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 5, 153, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 6, 189, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 7, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 8, 75, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 9, 2, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 10, 105, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 11, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 12, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 13, 55, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090127016887, 14, 27, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 1, 41, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 2, 175, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 3, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 4, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 5, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 6, 16, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 7, 26, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 8, 2, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040218016888, 9, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 1, 76, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 2, 43, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 3, 139, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 4, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 5, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030604016889, 6, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 1, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 2, 47, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 3, 21, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 4, 187, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 5, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 6, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 7, 166, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 8, 20, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 9, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 10, 152, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 11, 88, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 12, 182, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 13, 148, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 14, 31, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 4, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 5, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 6, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 7, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 8, 133, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 9, 80, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 10, 142, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 11, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 12, 61, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 13, 6, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090228017232, 14, 21, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 1, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 2, 16, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 3, 67, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 4, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 5, 27, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 6, 9, 28, 4, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 7, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 8, 31, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 9, 105, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 10, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 11, 186, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 12, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 13, 61, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 14, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 15, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110727017233, 16, 81, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 1, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 2, 106, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 3, 151, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 4, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 5, 91, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 6, 110, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 7, 181, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 8, 149, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 9, 169, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060704017234, 10, 181, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 1, 187, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 2, 113, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 3, 130, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 4, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 5, 36, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 6, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031026017235, 7, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 1, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 2, 53, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 3, 37, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 4, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 5, 114, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 6, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 7, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 8, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017236, 9, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124017237, 1, 9, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124017237, 2, 48, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124017237, 3, 51, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124017237, 4, 41, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124017237, 5, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 1, 18, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 2, 113, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 3, 59, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 4, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 5, 16, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 6, 157, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 7, 155, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 8, 8, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 9, 12, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 10, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 11, 103, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 12, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080605017238, 13, 162, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 1, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 2, 90, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 3, 170, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 4, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 5, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020713017239, 6, 83, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 1, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 2, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 3, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 4, 126, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 5, 179, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 6, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 7, 184, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 8, 151, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 9, 105, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 10, 135, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 11, 110, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070612017240, 12, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 1, 24, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 2, 53, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 3, 182, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 4, 14, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 5, 50, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 6, 137, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 7, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 8, 44, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 9, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 10, 3, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061229017241, 11, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705017242, 1, 154, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705017242, 2, 122, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705017242, 3, 124, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705017242, 4, 166, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030705017242, 5, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 1, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 2, 34, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 3, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 4, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 5, 35, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 6, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 7, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 8, 25, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 9, 17, 9, 5, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 10, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 11, 91, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 12, 44, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090216017243, 13, 178, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 1, 30, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 2, 98, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 3, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 4, 167, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 5, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 6, 122, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 7, 119, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 8, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 9, 69, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 10, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 11, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 12, 186, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 13, 113, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 14, 171, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 15, 47, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 16, 45, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140225017244, 17, 63, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 1, 171, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 2, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 3, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 4, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 5, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 6, 43, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 7, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040901017245, 8, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 1, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 2, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 3, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 4, 158, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 5, 137, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 6, 128, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 7, 128, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 8, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 9, 42, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 10, 69, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 11, 100, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 12, 85, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100829017246, 13, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 1, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 2, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 3, 188, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 4, 130, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 5, 119, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 6, 83, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 7, 114, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 8, 155, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 9, 171, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080723017247, 10, 174, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 1, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 2, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 3, 8, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 4, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 5, 150, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 6, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 7, 66, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 8, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 9, 124, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 10, 182, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 11, 63, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081025017248, 12, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 1, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 2, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 3, 170, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 4, 122, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 5, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 6, 156, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 7, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017249, 8, 56, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 1, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 2, 156, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 3, 141, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 4, 11, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 5, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 6, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 7, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 8, 38, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 9, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 10, 134, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090425017250, 11, 88, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 1, 139, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 2, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 3, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 4, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 5, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 6, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 7, 191, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 8, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 9, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 10, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 11, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100801017251, 12, 48, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 1, 105, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 2, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 3, 124, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 4, 16, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 5, 24, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030901017252, 6, 108, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507017253, 1, 118, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507017253, 2, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507017253, 3, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010507017253, 4, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419017254, 1, 164, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419017254, 2, 155, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419017254, 3, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419017254, 4, 153, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000419017254, 5, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 1, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 2, 154, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 3, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 4, 145, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 5, 145, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 6, 79, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 7, 106, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 8, 31, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 9, 92, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 10, 181, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 11, 127, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 12, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 13, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 14, 43, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 4, 126, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 5, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 6, 54, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 7, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 8, 15, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050306016118, 9, 191, 50, 17, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 1, 117, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 2, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 3, 164, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 4, 172, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 5, 90, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 6, 73, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 7, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 8, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 9, 140, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080616016119, 10, 55, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 1, 183, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 2, 89, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 3, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 4, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 5, 159, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 6, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 7, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 8, 102, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 9, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 10, 164, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 11, 23, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 12, 85, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 13, 86, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 14, 66, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 15, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 16, 161, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 17, 63, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140320016120, 18, 104, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 1, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 2, 71, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 3, 182, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 4, 151, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 5, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020226016121, 6, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 1, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 2, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 3, 41, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 4, 69, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 5, 40, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030824016122, 6, 101, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 1, 34, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 2, 15, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 3, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 4, 43, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 5, 135, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 6, 77, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 7, 119, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 8, 68, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 9, 50, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 10, 141, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080128016123, 11, 131, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 1, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 2, 98, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 3, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 4, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 5, 152, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 6, 6, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 7, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 8, 32, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 9, 149, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 10, 76, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 11, 71, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 12, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 13, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100507016124, 14, 18, 96, 6, 576);
commit;
prompt 174000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 1, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 2, 26, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 3, 100, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 4, 143, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 5, 91, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 6, 188, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 7, 145, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 8, 43, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 9, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 10, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 11, 150, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 12, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101009016125, 13, 115, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510016126, 1, 122, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510016126, 2, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510016126, 3, 157, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000510016126, 4, 174, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 1, 131, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 2, 106, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 3, 151, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 4, 84, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 5, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 6, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 7, 177, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031116016127, 8, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 1, 157, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 2, 72, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 3, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 4, 145, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 5, 126, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 6, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 7, 84, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 8, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 9, 26, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 10, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 11, 49, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 12, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 13, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110926016128, 14, 178, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231016129, 1, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231016129, 2, 88, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231016129, 3, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231016129, 4, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 1, 95, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 2, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 3, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 4, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 5, 24, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 6, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 7, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 8, 181, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 9, 21, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 10, 119, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 11, 2, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080112016130, 12, 95, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 1, 189, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 2, 54, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 3, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 4, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 5, 139, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 6, 37, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 7, 1, 45, 3, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 8, 114, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 9, 83, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 10, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614016131, 11, 12, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 1, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 2, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 3, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 4, 57, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 5, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 6, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 7, 185, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 8, 15, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 9, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 10, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 11, 72, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 12, 94, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 13, 169, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 14, 86, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 15, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 16, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140423016132, 17, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 1, 72, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 2, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 3, 2, 66, 4, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 4, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 5, 93, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 6, 25, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 7, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 8, 160, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 9, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 10, 8, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 11, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 12, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 13, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 14, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 15, 133, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 16, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120329016133, 17, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 1, 186, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 2, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 3, 29, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 4, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 5, 19, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 6, 69, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 7, 47, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 8, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 9, 163, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 10, 64, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 11, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 12, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 13, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111106016134, 14, 182, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111016135, 1, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111016135, 2, 127, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111016135, 3, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 1, 100, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 2, 113, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 3, 181, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 4, 143, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 5, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 6, 175, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 7, 109, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 8, 92, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 9, 80, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 10, 191, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 11, 99, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 12, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 13, 116, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090919016136, 14, 137, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 1, 127, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 2, 130, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 3, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 4, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 5, 38, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 6, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 7, 15, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 8, 46, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 9, 170, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 10, 75, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080319016137, 11, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010016138, 1, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010016138, 2, 108, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010016138, 3, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011010016138, 4, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 1, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 2, 111, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 3, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 4, 168, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 5, 61, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 6, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 7, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 8, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 9, 149, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 10, 52, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 11, 158, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090409016139, 12, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 1, 9, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 2, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 3, 178, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 4, 165, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 5, 147, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 6, 58, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 7, 26, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 8, 101, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 9, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 10, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 5, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 6, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 7, 89, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050527016488, 8, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 1, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 2, 76, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 3, 175, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 4, 12, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 5, 175, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 6, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 7, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 8, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 9, 123, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 10, 61, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080119016489, 11, 96, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 1, 37, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 2, 107, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 3, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 4, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 5, 12, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010407016490, 6, 82, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 1, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 2, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 3, 124, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 4, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 5, 72, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 6, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 7, 52, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 8, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 9, 56, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 10, 9, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 11, 73, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 12, 165, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 13, 188, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 14, 102, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 15, 23, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 16, 159, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130704016491, 17, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 1, 104, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 2, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 3, 168, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 4, 176, 14, 16, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 5, 162, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 6, 171, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 7, 39, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 8, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 9, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 10, 112, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 11, 146, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 12, 107, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 13, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 14, 150, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 15, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 16, 188, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130420016492, 17, 23, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 1, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 2, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 3, 126, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 4, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 5, 63, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 6, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 7, 77, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 8, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 9, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 10, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 11, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 12, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 13, 184, 59, 17, 1003);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 14, 149, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 15, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120917016493, 16, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 1, 77, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 2, 76, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 3, 24, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 4, 55, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 5, 135, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 6, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 7, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 8, 59, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 9, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 10, 67, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 11, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 12, 123, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 13, 141, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 14, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 15, 54, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 16, 133, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130403016494, 17, 121, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221016495, 1, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221016495, 2, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221016495, 3, 63, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010221016495, 4, 28, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 1, 104, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 2, 30, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 3, 26, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 4, 122, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 5, 77, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 6, 187, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 7, 64, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 8, 91, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 9, 3, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 10, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 11, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 12, 125, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016496, 13, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 1, 53, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 2, 127, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 3, 108, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 4, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 5, 176, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 6, 28, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 7, 191, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 8, 85, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 9, 191, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 10, 192, 28, 18, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060910016497, 11, 83, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016498, 1, 119, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016498, 2, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000930016498, 3, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114016499, 1, 115, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114016499, 2, 85, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114016499, 3, 115, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001114016499, 4, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 1, 172, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 2, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 3, 142, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 4, 3, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 5, 110, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 6, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 7, 160, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 8, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 9, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 10, 9, 1, 4, 4);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070310016500, 11, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 1, 44, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 2, 83, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 3, 99, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 4, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 5, 124, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 6, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 7, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 8, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 9, 43, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080711016501, 10, 119, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 1, 50, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 2, 121, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 3, 15, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 4, 67, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 5, 94, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 6, 113, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 7, 76, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 8, 188, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 9, 169, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 10, 119, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 11, 180, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090903016502, 12, 43, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016503, 1, 11, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016503, 2, 95, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016503, 3, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 1, 129, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 2, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 3, 20, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 4, 6, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 5, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 6, 39, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 7, 47, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 8, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 9, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 10, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080507016504, 11, 107, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 1, 166, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 2, 114, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 3, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 4, 154, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 5, 8, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 6, 48, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 7, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 8, 51, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 9, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060801016505, 10, 13, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 1, 162, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 2, 81, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 3, 21, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 4, 45, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 5, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021119016506, 6, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 1, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 2, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 3, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 4, 4, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 5, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 6, 30, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 7, 136, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 8, 172, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 9, 128, 69, 16, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 10, 7, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 11, 124, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070804016507, 12, 141, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 1, 157, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 2, 145, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 3, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 4, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 5, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 6, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 7, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 8, 156, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 9, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 10, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 11, 138, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071021016508, 12, 34, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 1, 23, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 2, 154, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 3, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 4, 23, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 5, 111, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 6, 131, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 7, 1, 5, 3, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 8, 50, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 9, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 10, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 11, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 12, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090209016509, 13, 25, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 1, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 2, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 3, 88, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 4, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 5, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 6, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 7, 28, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 8, 47, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016510, 9, 13, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 1, 22, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 2, 165, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 3, 2, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 4, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 5, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 6, 126, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 7, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 15, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120114016890, 16, 184, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 1, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 2, 42, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 3, 13, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 4, 22, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 5, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 6, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 7, 76, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 8, 145, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 9, 82, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 10, 86, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 11, 182, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 12, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 13, 14, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 14, 140, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 15, 184, 7, 17, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308016891, 16, 55, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209016892, 1, 173, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001209016892, 2, 79, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122016893, 1, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122016893, 2, 50, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122016893, 3, 38, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020122016893, 4, 83, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 1, 5, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 2, 76, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 3, 4, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 4, 51, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 5, 168, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 6, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 7, 20, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 8, 157, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070426016894, 9, 81, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915016895, 1, 134, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915016895, 2, 13, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915016895, 3, 8, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915016895, 4, 50, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020915016895, 5, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 1, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 2, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 3, 192, 88, 18, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 4, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 5, 177, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 6, 141, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040308016896, 7, 143, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 1, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 2, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 3, 52, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 4, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 5, 54, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 6, 107, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 7, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 8, 109, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050216016897, 9, 37, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 1, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 2, 189, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 3, 23, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 4, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 5, 92, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 6, 102, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 7, 129, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 8, 118, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040214016898, 9, 39, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 1, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 2, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 3, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 4, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 5, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 6, 139, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 7, 105, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 8, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 9, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060313016899, 10, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009016900, 1, 83, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009016900, 2, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009016900, 3, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009016900, 4, 184, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 1, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 2, 102, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 3, 64, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 4, 125, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 5, 174, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 6, 108, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 7, 148, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 8, 165, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 9, 15, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 10, 75, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 11, 76, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090117016901, 12, 32, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 1, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 2, 41, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 3, 20, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 4, 174, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 5, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 6, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 7, 47, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 8, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 9, 44, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 10, 118, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 11, 90, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090225016902, 12, 150, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 1, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 2, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 3, 121, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 4, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 5, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 6, 94, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 7, 41, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 8, 123, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 9, 114, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 10, 81, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 11, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070604016903, 12, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 1, 31, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 2, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 3, 92, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 4, 65, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 5, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 6, 85, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 7, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061202016904, 8, 84, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728016905, 1, 122, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728016905, 2, 177, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728016905, 3, 10, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728016905, 4, 38, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030728016905, 5, 74, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 1, 34, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 2, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 3, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 4, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 5, 121, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 6, 184, 11, 17, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 7, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 8, 106, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 9, 132, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 10, 185, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 11, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 12, 27, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 13, 15, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 14, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130606016906, 15, 178, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106016907, 1, 141, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106016907, 2, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106016907, 3, 159, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001106016907, 4, 78, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 1, 60, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 2, 123, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 3, 119, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 4, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 5, 48, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 6, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 7, 79, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 8, 105, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 9, 72, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 10, 152, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 11, 51, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 12, 181, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 13, 110, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100703016908, 14, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724016909, 1, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724016909, 2, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724016909, 3, 166, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010724016909, 4, 188, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725016910, 1, 86, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725016910, 2, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725016910, 3, 165, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020725016910, 4, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 1, 140, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 2, 135, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 3, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 4, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 5, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020926016911, 6, 167, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 1, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 2, 75, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 3, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 4, 162, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 5, 185, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 6, 117, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 7, 159, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 8, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 9, 147, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 10, 1, 55, 3, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 11, 89, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 12, 149, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016912, 13, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 1, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 2, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 3, 69, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 4, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 5, 133, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 6, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 7, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061129016913, 8, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 1, 17, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 2, 99, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 3, 140, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 4, 182, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 5, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 6, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020428016914, 7, 86, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 1, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 2, 187, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 3, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 4, 50, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 5, 106, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 6, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 7, 38, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 8, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 9, 68, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 10, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 11, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 12, 18, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016915, 13, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 1, 147, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 2, 32, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 3, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 4, 42, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 5, 41, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 6, 108, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 7, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 8, 119, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 9, 125, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 10, 72, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081205016916, 11, 116, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 1, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 2, 29, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 3, 5, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 4, 138, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 5, 111, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 6, 80, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 7, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 8, 175, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 9, 28, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 10, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 11, 141, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 12, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 13, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 14, 24, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 15, 160, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 16, 93, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140227017255, 17, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 1, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 2, 115, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 3, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 4, 130, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 5, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 6, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 7, 29, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 8, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 9, 168, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 10, 12, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 11, 169, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 12, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 13, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100920017256, 14, 69, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011017257, 1, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011017257, 2, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011017257, 3, 65, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011011017257, 4, 29, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123017258, 1, 6, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123017258, 2, 124, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123017258, 3, 70, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011123017258, 4, 175, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 1, 80, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 2, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 3, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 4, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 5, 139, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 6, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 7, 61, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 8, 37, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 9, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 10, 24, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 11, 115, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 12, 131, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 13, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 14, 116, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 15, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131128017259, 16, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 1, 98, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 2, 67, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 3, 67, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 4, 65, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 5, 160, 19, 17, 323);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030727017260, 6, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704017261, 1, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704017261, 2, 49, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704017261, 3, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000704017261, 4, 152, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 1, 166, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 2, 68, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 3, 36, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 4, 98, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 5, 189, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 6, 166, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 7, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 8, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 9, 18, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 10, 134, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 11, 97, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090222017262, 12, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 1, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 2, 39, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 3, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 4, 180, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 5, 105, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 6, 105, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 7, 161, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041205017263, 8, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 1, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 2, 101, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 3, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 4, 82, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 5, 68, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 6, 32, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 7, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 8, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 9, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 10, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 11, 61, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 12, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 13, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 14, 178, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101116017264, 15, 152, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 1, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 2, 79, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 3, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 4, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 5, 112, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 6, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 7, 175, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 8, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 9, 23, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 10, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 11, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 12, 57, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 13, 166, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 14, 135, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 15, 73, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 16, 4, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130919017265, 17, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 1, 39, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 2, 150, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 3, 22, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 4, 109, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 5, 9, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 6, 150, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031218017266, 7, 164, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226017267, 1, 22, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226017267, 2, 136, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226017267, 3, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 1, 42, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 2, 28, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 3, 188, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 4, 88, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 5, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 6, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030513017268, 7, 126, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 1, 28, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 2, 4, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 3, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 4, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 5, 168, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030524017269, 6, 146, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 1, 85, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 2, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 3, 182, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 4, 120, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 5, 29, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 6, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 7, 175, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 8, 64, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 9, 36, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 10, 118, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 11, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 12, 110, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017270, 13, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 1, 147, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 2, 163, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 3, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 4, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 5, 56, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010720017271, 6, 190, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 1, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 2, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 3, 94, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 4, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 5, 3, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 6, 189, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 7, 21, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017272, 8, 25, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 1, 16, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 2, 95, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 3, 21, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 4, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 5, 73, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 6, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 7, 121, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 8, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070326017273, 9, 160, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 1, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 2, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 3, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 4, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 5, 112, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 6, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 7, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 8, 120, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 9, 145, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 10, 45, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 11, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091001017274, 12, 117, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 1, 131, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 2, 139, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 3, 182, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 4, 59, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 5, 119, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 6, 29, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 7, 163, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 8, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 9, 49, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 10, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071110017275, 11, 13, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009017276, 1, 159, 70, 16, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009017276, 2, 115, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009017276, 3, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009017276, 4, 44, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001009017276, 5, 3, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 1, 93, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 2, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 3, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 4, 56, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 5, 38, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 6, 99, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 7, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 8, 122, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 9, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 10, 124, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 11, 168, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 12, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 13, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120407017277, 14, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 1, 2, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 2, 170, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 3, 112, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 4, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 5, 66, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 6, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 7, 124, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 8, 183, 55, 16, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 9, 127, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 10, 140, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 11, 129, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 12, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 13, 152, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 14, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120620017278, 15, 148, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 1, 122, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 2, 137, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 3, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 4, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 5, 140, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 6, 150, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 7, 1, 68, 3, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 8, 101, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050402017279, 9, 117, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 1, 82, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 2, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 3, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 4, 8, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 5, 51, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 6, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017280, 7, 55, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 1, 118, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 2, 90, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 3, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 4, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070413016140, 11, 109, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 1, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 2, 56, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 3, 138, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 4, 162, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 5, 47, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 6, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 7, 106, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 8, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050925016141, 9, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 1, 58, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 2, 25, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 3, 69, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 4, 104, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 5, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 6, 49, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 7, 67, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 8, 162, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 9, 163, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 10, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 11, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 12, 163, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 13, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 14, 153, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110605016142, 15, 53, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825016143, 1, 37, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825016143, 2, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825016143, 3, 128, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825016143, 4, 63, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825016143, 5, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805016144, 1, 72, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805016144, 2, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805016144, 3, 62, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805016144, 4, 142, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020805016144, 5, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 1, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 2, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 3, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 4, 90, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 5, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 6, 117, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 7, 85, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 8, 86, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 9, 33, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 10, 43, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 11, 84, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 12, 86, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606016145, 13, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 1, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 2, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 3, 60, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 4, 111, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 5, 123, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 6, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030629016146, 7, 71, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 1, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 2, 127, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 3, 164, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 4, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 5, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 6, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 7, 191, 5, 17, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 8, 97, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 9, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 10, 154, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 11, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 12, 76, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 13, 115, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 14, 75, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 15, 109, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120827016147, 16, 112, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 1, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 2, 105, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 3, 97, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 4, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 5, 28, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 6, 111, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 7, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 8, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 9, 18, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 10, 134, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 11, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090808016148, 12, 81, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607016149, 1, 101, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607016149, 2, 12, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000607016149, 3, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 1, 44, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 2, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 3, 146, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 4, 121, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 5, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 6, 57, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 7, 183, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 8, 2, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 9, 11, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060110016150, 10, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 1, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 2, 181, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 3, 13, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 4, 76, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 5, 132, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 6, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 7, 8, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 8, 31, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 9, 10, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 10, 185, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 11, 102, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 12, 22, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 13, 86, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 14, 56, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120625016151, 15, 184, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 1, 176, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 2, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 3, 166, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 4, 60, 86, 10, 860);
commit;
prompt 175000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 5, 120, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 6, 169, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 7, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 8, 65, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 9, 74, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 10, 17, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 11, 75, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 12, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 13, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 14, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 15, 183, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 16, 51, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140413016152, 17, 63, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 1, 159, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 2, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 3, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 4, 160, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 5, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016153, 6, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 1, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 2, 51, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 3, 149, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 4, 187, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 5, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030830016154, 6, 84, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 1, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 2, 53, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 3, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 4, 87, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 5, 123, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 6, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040930016155, 7, 151, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 1, 13, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 2, 24, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 3, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 4, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 5, 135, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020222016156, 6, 3, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 1, 70, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 2, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 3, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 4, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 5, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 6, 32, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 7, 103, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 8, 44, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070416016157, 9, 37, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 1, 28, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 2, 177, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 3, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 4, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 5, 29, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 6, 148, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 7, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 8, 180, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 9, 13, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 10, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 11, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091010016158, 12, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 1, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 2, 13, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 3, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 4, 9, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 5, 164, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 6, 136, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 7, 171, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 8, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 9, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 10, 54, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090619016159, 11, 10, 65, 5, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 1, 150, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 2, 53, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 3, 175, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 4, 121, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 5, 190, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 6, 118, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 7, 15, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 8, 63, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 9, 26, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 10, 191, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 11, 95, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 12, 38, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 13, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 14, 78, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 15, 105, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 16, 166, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 17, 163, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140103016160, 18, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124016161, 1, 69, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124016161, 2, 159, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124016161, 3, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010124016161, 4, 108, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 1, 170, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 2, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 3, 152, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 4, 56, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 5, 22, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 6, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 7, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 8, 192, 77, 18, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 9, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 10, 118, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016162, 11, 123, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 1, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 2, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 3, 144, 74, 15, 1110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 4, 138, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 5, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 6, 70, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 7, 107, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 8, 18, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 9, 78, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 10, 156, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 11, 107, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 12, 176, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 13, 81, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 14, 8, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110701016163, 15, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 1, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 2, 106, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 3, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 4, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 5, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 6, 67, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060630016511, 8, 104, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 1, 153, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 2, 33, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 3, 183, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 4, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 5, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 6, 153, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 7, 5, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 8, 147, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 9, 4, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 10, 16, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 11, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 12, 21, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 13, 146, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 14, 182, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 15, 33, 9, 4, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 16, 101, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140515016512, 17, 155, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 1, 169, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 2, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 3, 137, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 4, 54, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 5, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 6, 162, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 8, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 9, 16, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051014016513, 10, 69, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127016514, 1, 150, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127016514, 2, 102, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127016514, 3, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127016514, 4, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127016514, 5, 92, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 1, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 2, 116, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 3, 87, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 4, 122, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 5, 116, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 6, 32, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 7, 119, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 8, 185, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 9, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 10, 131, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 11, 122, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 12, 24, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 13, 3, 11, 5, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 14, 144, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121226016515, 15, 149, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 1, 109, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 2, 145, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 3, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 4, 55, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 5, 157, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 6, 165, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 7, 60, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 8, 163, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 9, 83, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 10, 28, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 11, 124, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 12, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110716016516, 13, 44, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 1, 103, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 2, 67, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 3, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 4, 174, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 5, 155, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 6, 167, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 7, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 8, 53, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 9, 87, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060418016517, 10, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 1, 117, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 2, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 3, 24, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 4, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 5, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 6, 60, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 7, 63, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 8, 65, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 9, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 10, 83, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 11, 67, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 12, 8, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 13, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 14, 170, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 15, 43, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140315016518, 16, 24, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 1, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 2, 171, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 3, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 4, 49, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 5, 72, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 6, 116, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 7, 182, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 8, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 9, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 10, 60, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 11, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 12, 119, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 13, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 14, 185, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 15, 72, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130911016519, 16, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 1, 91, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 2, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 3, 101, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 4, 111, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 5, 8, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 6, 146, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 7, 8, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 8, 123, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 9, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 10, 68, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 11, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 12, 65, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 13, 145, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 14, 164, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 15, 159, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 16, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222016520, 17, 154, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001016521, 1, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001016521, 2, 73, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001016521, 3, 121, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001016521, 4, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001001016521, 5, 63, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606016522, 1, 17, 26, 5, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606016522, 2, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606016522, 3, 123, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606016522, 4, 68, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010606016522, 5, 88, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 1, 61, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 2, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 3, 52, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 4, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 5, 88, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 6, 92, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 7, 20, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 8, 11, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 9, 84, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 10, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 11, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 12, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 13, 66, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 14, 114, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 15, 37, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120208016523, 16, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 1, 149, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 2, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 3, 139, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 4, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 5, 23, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 6, 83, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 7, 172, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 8, 147, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 9, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 10, 125, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080320016524, 11, 192, 13, 18, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 1, 105, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 2, 182, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 3, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 4, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 5, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 6, 52, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 7, 45, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 8, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060725016525, 9, 92, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 1, 71, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 2, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 3, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 4, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 5, 107, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 6, 129, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 7, 160, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 8, 4, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 9, 36, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 10, 189, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 11, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 12, 92, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 13, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100727016526, 14, 176, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 1, 164, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 2, 26, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 3, 131, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 4, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 5, 101, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 6, 20, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 7, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 8, 85, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 9, 89, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 10, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080403016527, 11, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 1, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 2, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 3, 135, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 4, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 5, 155, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 6, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 7, 156, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 8, 89, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 9, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 10, 41, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 11, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 12, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 13, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 14, 121, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 15, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616016528, 16, 191, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 1, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 2, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 3, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 4, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 5, 59, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 6, 39, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 7, 132, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 8, 108, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051031016529, 9, 120, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 1, 190, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 2, 41, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 3, 41, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 4, 28, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 5, 33, 70, 4, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 6, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 7, 65, 28, 5, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 8, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040301016530, 9, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 1, 4, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 2, 139, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 3, 97, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 4, 63, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 5, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 6, 182, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 7, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 8, 3, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 9, 82, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 10, 72, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 11, 39, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123016531, 12, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010220016532, 1, 29, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 15, 62, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121223016917, 16, 49, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 1, 192, 33, 18, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 2, 47, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 3, 166, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 4, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 5, 19, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 6, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 7, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 8, 14, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 9, 147, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 10, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 11, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090415016918, 12, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 1, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 2, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 3, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 4, 2, 94, 4, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 5, 101, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 6, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051210016919, 7, 41, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 1, 29, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 2, 50, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 3, 85, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 4, 12, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 5, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 6, 139, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 7, 12, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 8, 23, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 9, 192, 58, 18, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 10, 57, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080210016920, 11, 103, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 1, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 2, 178, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 3, 108, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 4, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 5, 113, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 6, 147, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 7, 12, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 8, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 9, 192, 85, 18, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 10, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070111016921, 11, 12, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 1, 175, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 2, 154, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 3, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 4, 119, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 5, 186, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 6, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 7, 115, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 8, 18, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 9, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 10, 126, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 11, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 12, 125, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 13, 169, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 14, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 15, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 16, 19, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 17, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130823016922, 18, 3, 10, 5, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 1, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 2, 18, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 3, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 4, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 5, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 6, 50, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 7, 43, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 8, 67, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061206016923, 9, 75, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 1, 78, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 2, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 3, 16, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 4, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 5, 178, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 6, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 7, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 8, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 9, 87, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 10, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 11, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 12, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 13, 158, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 14, 167, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120520016924, 15, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016016925, 1, 133, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016016925, 2, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001016016925, 3, 102, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819016926, 1, 42, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819016926, 2, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819016926, 3, 33, 22, 4, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020819016926, 4, 33, 43, 4, 172);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322016927, 1, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322016927, 2, 125, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322016927, 3, 66, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322016927, 4, 144, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020322016927, 5, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 1, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 2, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 3, 110, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 4, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 5, 17, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 6, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 7, 189, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 8, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 9, 150, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 10, 6, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080412016928, 11, 53, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109016929, 1, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109016929, 2, 86, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109016929, 3, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109016929, 4, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010109016929, 5, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 1, 30, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 2, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 3, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 4, 139, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 5, 56, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 6, 149, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040229016930, 7, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 1, 71, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 2, 30, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 3, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 4, 146, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 5, 181, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 6, 58, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040306016931, 7, 144, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506016932, 1, 163, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506016932, 2, 107, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000506016932, 3, 95, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 1, 142, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 2, 127, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 3, 74, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 4, 65, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 5, 86, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 6, 160, 92, 17, 1564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 7, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 8, 184, 100, 17, 1700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 9, 49, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 10, 117, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 11, 22, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 12, 35, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 13, 98, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 14, 43, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 15, 20, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 16, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120408016933, 17, 97, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 1, 31, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 2, 1, 33, 3, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 3, 14, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 4, 186, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 5, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 6, 49, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 7, 163, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 8, 73, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 9, 47, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 10, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 11, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 12, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 13, 182, 58, 15, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 14, 153, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 15, 58, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 16, 161, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131031016934, 17, 177, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 1, 68, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 2, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 3, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 4, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 5, 183, 92, 16, 1472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 6, 156, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 7, 51, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 8, 135, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 9, 21, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 10, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 11, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 12, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 13, 98, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 14, 36, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 15, 100, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 16, 22, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130516016935, 17, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 1, 152, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 2, 76, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 3, 184, 15, 17, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 4, 142, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 5, 50, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 6, 142, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030222016936, 7, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016937, 1, 152, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016937, 2, 166, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016937, 3, 147, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016937, 4, 47, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016937, 5, 189, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 1, 183, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 2, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 3, 68, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 4, 131, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 5, 27, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 6, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031010016938, 7, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 1, 144, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 2, 178, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 3, 82, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 4, 11, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 5, 104, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 6, 44, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 7, 133, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 8, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070304016939, 9, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 1, 86, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 2, 127, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 3, 128, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 4, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 5, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 6, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 7, 14, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 8, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 9, 167, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071018016940, 10, 38, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 1, 1, 96, 3, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 2, 85, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 3, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 4, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 5, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 6, 108, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 7, 89, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 8, 161, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 9, 41, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 10, 58, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 11, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 12, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 13, 157, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110805016941, 14, 10, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 1, 20, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 2, 62, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 3, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 4, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 5, 189, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 6, 102, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 5, 186, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017281, 6, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 1, 158, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 2, 90, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 3, 101, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 4, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 5, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 6, 145, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030703017282, 7, 153, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 1, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 2, 125, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 3, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 4, 4, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 5, 40, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 6, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 7, 156, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 8, 159, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 9, 191, 43, 17, 731);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 10, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 11, 141, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 12, 48, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 13, 63, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111027017283, 14, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125017284, 1, 123, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125017284, 2, 167, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125017284, 3, 161, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000125017284, 4, 129, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 1, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 2, 69, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 3, 100, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 4, 134, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 5, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 6, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 7, 145, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 8, 46, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 9, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 10, 170, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 11, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 12, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 13, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 14, 79, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 15, 53, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140220017285, 16, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 1, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 2, 102, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 3, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 4, 28, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 5, 163, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 6, 68, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 7, 172, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 8, 180, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 9, 33, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 10, 112, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 11, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 12, 152, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 13, 80, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 14, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 15, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 16, 66, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 17, 123, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140327017286, 18, 56, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 1, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 2, 173, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 3, 173, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 4, 26, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 5, 34, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 6, 86, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 7, 189, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 8, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 9, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 10, 118, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 11, 93, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 12, 94, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 13, 123, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 14, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120218017287, 15, 39, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 1, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 2, 119, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 3, 190, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 4, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 5, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 6, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 7, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 8, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 9, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080327017288, 10, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417017289, 1, 20, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417017289, 2, 136, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417017289, 3, 58, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000417017289, 4, 86, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 1, 121, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 2, 186, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 3, 114, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 4, 40, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 5, 104, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 6, 54, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 7, 112, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 8, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 9, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080817017290, 10, 22, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 1, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 2, 41, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 3, 175, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 4, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 5, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 6, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 7, 44, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 8, 38, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050209017291, 9, 63, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 1, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 2, 166, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 3, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 4, 31, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 5, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017292, 6, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 1, 130, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 2, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 3, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 4, 2, 38, 4, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 5, 73, 50, 6, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 6, 126, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 7, 126, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 8, 2, 99, 4, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 9, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 10, 133, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 11, 161, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070923017293, 12, 41, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 1, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 2, 10, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 3, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 4, 23, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 5, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 6, 166, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 7, 70, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 8, 142, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 9, 179, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 10, 177, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 11, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070911017294, 12, 153, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 1, 167, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 2, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 3, 191, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 4, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 5, 132, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 6, 114, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 7, 95, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 8, 58, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 9, 18, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 10, 49, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 11, 150, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080607017295, 12, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 1, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 2, 166, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 3, 11, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 4, 12, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 5, 45, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 6, 10, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 7, 63, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 8, 82, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 9, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 10, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101017296, 11, 10, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 1, 56, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 2, 148, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 3, 10, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 4, 111, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 5, 147, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 6, 99, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409017297, 7, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 1, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 2, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 3, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 4, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 5, 40, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 6, 162, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 7, 29, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 8, 158, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 9, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 10, 156, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 11, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 12, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 13, 131, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 14, 38, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 15, 35, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 16, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 17, 33, 52, 4, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140115017298, 18, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 1, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 2, 74, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 3, 124, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 4, 169, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 5, 175, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 6, 35, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051102017299, 7, 115, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 1, 111, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 2, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 3, 140, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 4, 33, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 5, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 6, 104, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 7, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 8, 57, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 9, 191, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 10, 72, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 11, 7, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 12, 173, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 13, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 14, 109, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 15, 12, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120802017300, 16, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202017301, 1, 61, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202017301, 2, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202017301, 3, 110, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202017301, 4, 48, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011202017301, 5, 137, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 1, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 2, 71, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 3, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 4, 114, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 5, 150, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 6, 125, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 7, 33, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060303017302, 8, 62, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 1, 129, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 2, 100, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 3, 51, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 4, 28, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 5, 57, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 6, 12, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 7, 127, 38, 15, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 8, 118, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 9, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070605017303, 10, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 1, 115, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 2, 130, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 3, 29, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 4, 146, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 5, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 6, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 7, 148, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 8, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040806016164, 9, 92, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 1, 99, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 2, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 3, 51, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 4, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 5, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 6, 147, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 7, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 8, 94, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 9, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 10, 32, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 11, 151, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 12, 85, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 13, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 14, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111010016165, 15, 89, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905016166, 1, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905016166, 2, 50, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905016166, 3, 93, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000905016166, 4, 142, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 1, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 2, 120, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 3, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 4, 171, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 5, 35, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 6, 21, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 7, 139, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 8, 81, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 9, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 10, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 11, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 12, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 13, 3, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821016167, 14, 186, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121016168, 1, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121016168, 2, 24, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121016168, 3, 21, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011121016168, 4, 123, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 1, 186, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 2, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 3, 31, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 4, 106, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 5, 15, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 6, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 7, 114, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 8, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 9, 19, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 10, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 11, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 12, 159, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 13, 13, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110719016169, 14, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 1, 17, 4, 5, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 2, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 3, 107, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 4, 42, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 5, 159, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 6, 40, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 7, 79, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 8, 71, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 9, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 10, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 11, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 12, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 13, 179, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101218016170, 14, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 1, 7, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 2, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 3, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 4, 43, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 5, 20, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 6, 50, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 7, 87, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 8, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050519016171, 9, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 1, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 2, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 3, 31, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 4, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 5, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 6, 141, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 7, 170, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 8, 48, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 9, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 10, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090323016172, 11, 115, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 1, 2, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 2, 130, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 3, 84, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 4, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 5, 99, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 6, 161, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 7, 21, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 8, 149, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 9, 124, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 10, 86, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 11, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 12, 2, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090403016173, 13, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602016174, 1, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602016174, 2, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602016174, 3, 8, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602016174, 4, 45, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030602016174, 5, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 1, 110, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 2, 31, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 3, 10, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 4, 123, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 5, 136, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 6, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 7, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 8, 94, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 9, 180, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 10, 151, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070701016175, 11, 168, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 1, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 2, 4, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 3, 139, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 4, 129, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 5, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041008016176, 6, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 1, 144, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 2, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 3, 133, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 4, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 5, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 6, 131, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 7, 140, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 8, 62, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 9, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 10, 71, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 11, 73, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 12, 114, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 13, 117, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 14, 93, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 15, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 16, 185, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 17, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 18, 172, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140418016177, 19, 97, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 1, 39, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 2, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 3, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 4, 41, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 5, 16, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 6, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 7, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 8, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 9, 101, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 10, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 11, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 12, 111, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016178, 13, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 1, 117, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 2, 35, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 3, 38, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 4, 87, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 5, 22, 90, 10, 900);
commit;
prompt 176000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 6, 29, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 7, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 8, 33, 50, 4, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 9, 67, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 10, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 11, 158, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 12, 183, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 13, 84, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 14, 190, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 15, 53, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 16, 30, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 17, 28, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112016179, 18, 164, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 1, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 2, 127, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 3, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 4, 14, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 5, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 6, 161, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 7, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 8, 38, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 9, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 10, 16, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 11, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 12, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 13, 27, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110811016180, 14, 108, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401016181, 1, 7, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401016181, 2, 133, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401016181, 3, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010401016181, 4, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 1, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 2, 55, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 3, 179, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 4, 120, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 5, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 6, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 7, 42, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 8, 184, 91, 17, 1547);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 9, 52, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 10, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 11, 188, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 12, 165, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 13, 89, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 14, 190, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111114016182, 15, 52, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 1, 178, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 2, 97, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 3, 102, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 4, 63, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 5, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 6, 125, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 7, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 8, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 9, 155, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 10, 117, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 11, 156, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 12, 53, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 13, 40, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090408016183, 14, 52, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130016184, 1, 127, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001130016184, 2, 85, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703016185, 1, 30, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703016185, 2, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010703016185, 3, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 1, 155, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 2, 26, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 3, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 4, 114, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 5, 81, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 6, 74, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 7, 80, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 8, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 9, 141, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 10, 17, 37, 5, 185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 11, 147, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 12, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 13, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 14, 178, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010220016532, 2, 62, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010220016532, 3, 173, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010220016532, 4, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 1, 124, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 2, 136, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 3, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 4, 16, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 5, 149, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 6, 173, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 7, 112, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 8, 19, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 9, 189, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 10, 125, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 11, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080406016533, 12, 110, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 1, 141, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 2, 124, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 3, 96, 1, 15, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 4, 45, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 5, 56, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 6, 153, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 7, 171, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 8, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 9, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060415016534, 10, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 1, 192, 9, 18, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 2, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 3, 118, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 4, 13, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 5, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 6, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 7, 139, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 8, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 9, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 10, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 11, 71, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 12, 173, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080108016535, 13, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 1, 143, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 2, 80, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 3, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 4, 44, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 5, 34, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 6, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 7, 69, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 8, 77, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 9, 111, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 10, 179, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 11, 3, 35, 5, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 12, 71, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 13, 37, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 14, 11, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 15, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120727016536, 16, 73, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 1, 185, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 2, 110, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 3, 46, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 4, 123, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 5, 146, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 6, 189, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 7, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 8, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 9, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 10, 179, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 11, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080629016537, 12, 5, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 1, 61, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 2, 191, 20, 17, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 3, 31, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 4, 78, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 5, 92, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 6, 20, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 7, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 8, 80, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 9, 18, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 10, 167, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 11, 95, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080815016538, 12, 170, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 1, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 2, 54, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 3, 76, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 4, 125, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 5, 146, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 6, 37, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 7, 45, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 8, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 9, 80, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 10, 139, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070925016539, 11, 80, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423016540, 1, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423016540, 2, 125, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423016540, 3, 171, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020423016540, 4, 33, 47, 4, 188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 1, 58, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 2, 183, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 3, 147, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 4, 179, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 5, 3, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 6, 33, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 7, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 8, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 9, 169, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 10, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 11, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 12, 28, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 13, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 14, 125, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110622016541, 15, 55, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 1, 62, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 2, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 3, 71, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 4, 191, 94, 17, 1598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 5, 162, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 6, 53, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 7, 148, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 8, 57, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041028016542, 9, 144, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 1, 117, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 2, 11, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 3, 53, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 4, 165, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 5, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 6, 132, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 7, 143, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 8, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 9, 14, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 10, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501016543, 11, 63, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 1, 118, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 2, 165, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 3, 152, 97, 16, 1552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 4, 72, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 5, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 6, 44, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 7, 141, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004016544, 8, 102, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327016545, 1, 13, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327016545, 2, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327016545, 3, 158, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327016545, 4, 22, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000327016545, 5, 135, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 1, 136, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 2, 136, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 3, 118, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 4, 121, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 5, 82, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 6, 148, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 7, 108, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 8, 37, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 9, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 10, 90, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 11, 44, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 12, 113, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 13, 130, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 14, 176, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 15, 89, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121128016546, 16, 118, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 1, 98, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 2, 151, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 3, 165, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 4, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 5, 103, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011213016547, 6, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 1, 91, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 2, 28, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 3, 126, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 4, 163, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 5, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 6, 94, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 7, 99, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 8, 29, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 9, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 10, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060706016548, 11, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 1, 77, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 2, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 3, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 4, 54, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 5, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 6, 72, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 7, 142, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 8, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 9, 178, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 10, 117, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 11, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100720016549, 12, 67, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 1, 30, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 2, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 3, 64, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 4, 63, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 5, 161, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 6, 62, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 7, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 8, 8, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 9, 33, 83, 4, 332);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 10, 155, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 11, 57, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080730016550, 12, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 1, 152, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 2, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 3, 46, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 4, 57, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 5, 136, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010827016551, 6, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311016552, 1, 167, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311016552, 2, 36, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311016552, 3, 27, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020311016552, 4, 167, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 1, 59, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 2, 56, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 3, 82, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 4, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 5, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 6, 185, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 7, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 8, 139, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 9, 153, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 10, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080719016553, 11, 47, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 1, 30, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 2, 65, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 3, 116, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 4, 192, 98, 18, 1764);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 5, 118, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031230016554, 6, 75, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 1, 140, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 2, 172, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 3, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 4, 103, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 5, 154, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 6, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 7, 152, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050810016555, 8, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 1, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 2, 161, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 3, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 4, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 5, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 6, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 7, 168, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 8, 16, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040531016942, 9, 95, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 1, 157, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 2, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 3, 185, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 4, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 5, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 6, 24, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 7, 88, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 8, 148, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 9, 79, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 10, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080812016943, 11, 75, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 1, 160, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 2, 150, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 3, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 4, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 5, 55, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 6, 5, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 7, 24, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 8, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 9, 189, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060528016944, 10, 124, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 1, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 2, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 3, 125, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 4, 191, 32, 17, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 5, 8, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 6, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 7, 40, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 8, 72, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 9, 146, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061231016945, 10, 36, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 1, 95, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 2, 6, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 3, 141, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 4, 158, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 5, 136, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 6, 148, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 7, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 8, 115, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 9, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 10, 191, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080117016946, 11, 182, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 1, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 2, 138, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 3, 137, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 4, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 5, 101, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 6, 33, 82, 4, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 7, 109, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 8, 116, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 9, 177, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 10, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 11, 191, 29, 17, 493);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 12, 128, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 13, 49, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091211016947, 14, 74, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 1, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 2, 103, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 3, 90, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 4, 57, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 5, 129, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 6, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 7, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 8, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 9, 98, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 10, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 11, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 12, 185, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 13, 20, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110909016948, 14, 101, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016949, 1, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016949, 2, 38, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016949, 3, 19, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016949, 4, 68, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020609016949, 5, 20, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513016950, 1, 4, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513016950, 2, 150, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513016950, 3, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000513016950, 4, 136, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 1, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 2, 50, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 3, 170, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 4, 48, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 5, 177, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 6, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 7, 79, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 8, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071121016951, 9, 164, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 1, 65, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 2, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 3, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 4, 121, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 5, 141, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 6, 118, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051130016952, 7, 188, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 1, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 2, 95, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 3, 54, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 4, 125, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 5, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 6, 147, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031112016953, 7, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 1, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 2, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 3, 151, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 4, 173, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 5, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 6, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 7, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 8, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 9, 20, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060306016954, 10, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 1, 42, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 2, 48, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 3, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 4, 69, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 5, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 6, 167, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 7, 186, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 8, 72, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 9, 48, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 10, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 11, 91, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091114016955, 12, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 1, 168, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 2, 33, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 3, 25, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 4, 165, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 5, 65, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 6, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 7, 172, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 8, 153, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 9, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 10, 116, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 11, 32, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 12, 148, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 13, 48, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 14, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 15, 109, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 16, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140221016956, 17, 52, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 1, 155, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 2, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 3, 111, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 4, 180, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 5, 95, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 6, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 7, 3, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 8, 153, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 9, 24, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 10, 71, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 11, 133, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101120016957, 12, 112, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 1, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 2, 167, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 3, 64, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 4, 145, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 5, 147, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 6, 20, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 7, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 8, 178, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 9, 44, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 10, 91, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 11, 23, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826016958, 12, 14, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 1, 163, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 2, 101, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 3, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 4, 173, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 5, 49, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 6, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 7, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 8, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 9, 141, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 10, 78, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 11, 71, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090511016959, 12, 176, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611016960, 1, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611016960, 2, 35, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611016960, 3, 54, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000611016960, 4, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116016961, 1, 120, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116016961, 2, 183, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000116016961, 3, 84, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 1, 63, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 2, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 3, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 4, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 5, 78, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 6, 30, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 7, 123, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 8, 154, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 9, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 10, 3, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 11, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 12, 62, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 13, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100917016962, 14, 149, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203016963, 1, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203016963, 2, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203016963, 3, 26, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203016963, 4, 78, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203016963, 5, 92, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 1, 168, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 2, 57, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 3, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 4, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 5, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 6, 172, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 7, 54, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 8, 55, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 9, 30, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 10, 120, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 11, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100701016964, 12, 110, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 1, 85, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 2, 44, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 3, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 4, 160, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 5, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 6, 13, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 7, 57, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 8, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 9, 128, 25, 16, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 10, 186, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 11, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 12, 49, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 13, 133, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 14, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 15, 111, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130228016965, 16, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 1, 25, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 2, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 3, 173, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 4, 162, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 7, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 8, 104, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 9, 102, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 10, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 11, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 12, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 13, 24, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 14, 149, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110903017304, 15, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626017305, 1, 93, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626017305, 2, 173, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626017305, 3, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626017305, 4, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 1, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 2, 160, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 3, 36, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 4, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 5, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 6, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 7, 143, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 8, 126, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 9, 25, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050907017306, 10, 35, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 1, 190, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 2, 104, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 3, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 4, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 5, 117, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 6, 104, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 7, 47, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 8, 76, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 9, 152, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 10, 82, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 11, 75, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901017307, 12, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 1, 119, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 2, 54, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 3, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 4, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 5, 81, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 6, 10, 6, 5, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 7, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 8, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070903017308, 9, 111, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 1, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 2, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 3, 100, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 4, 116, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 5, 126, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 6, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 7, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 8, 35, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 9, 128, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 10, 86, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 11, 45, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 12, 148, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 13, 185, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 14, 169, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 15, 134, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317017309, 16, 108, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 1, 148, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 2, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 3, 162, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 4, 128, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 5, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 6, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 7, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 8, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 9, 38, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 10, 97, 63, 6, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 11, 56, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 12, 129, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 13, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110213017310, 14, 96, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 1, 52, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 2, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 3, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 4, 159, 18, 16, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 5, 49, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 6, 161, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 7, 178, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 8, 16, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 9, 30, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 10, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091020017311, 11, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 1, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 2, 134, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 3, 41, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 4, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 5, 51, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 6, 141, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 7, 87, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 8, 67, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 9, 42, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 10, 144, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 11, 176, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 12, 186, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 13, 192, 22, 18, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090310017312, 14, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 1, 154, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 2, 74, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 3, 134, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 4, 153, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 5, 99, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021115017313, 6, 66, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 1, 144, 46, 15, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 2, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 3, 3, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 4, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 5, 135, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 6, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 7, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051120017314, 8, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 1, 8, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 2, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 3, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 4, 115, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 5, 31, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020203017315, 6, 82, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 1, 34, 8, 5, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 2, 153, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 3, 172, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 4, 102, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 5, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 6, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 7, 180, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 8, 60, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050318017316, 9, 89, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 1, 14, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 2, 63, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 3, 180, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 4, 181, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 5, 168, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 6, 180, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 7, 129, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 8, 94, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 9, 186, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 10, 36, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080824017317, 11, 111, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227017318, 1, 32, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227017318, 2, 86, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227017318, 3, 101, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001227017318, 4, 76, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 1, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 2, 1, 67, 3, 201);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 3, 7, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 4, 167, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 5, 6, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 6, 143, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 7, 104, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 8, 71, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 9, 80, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 10, 180, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 11, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 12, 136, 84, 14, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 13, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 14, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110925017319, 15, 117, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 1, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 2, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 3, 109, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 4, 186, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 5, 170, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 6, 118, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 7, 73, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 8, 97, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 9, 19, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 10, 81, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 11, 64, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 12, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 13, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 14, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 15, 99, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131007017320, 16, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 1, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 2, 33, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 3, 154, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 4, 43, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 5, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 6, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 7, 118, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 8, 15, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 9, 53, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 10, 49, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 11, 146, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 12, 16, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 13, 100, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 14, 132, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110629017321, 15, 28, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 1, 97, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 2, 89, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 3, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 4, 124, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 5, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 6, 60, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 7, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 8, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 9, 103, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 10, 50, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 11, 8, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 12, 164, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 13, 181, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 14, 4, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 15, 190, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110602017322, 16, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 1, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 2, 80, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 3, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 4, 78, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 5, 150, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 6, 115, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 7, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 8, 95, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 9, 24, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 10, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 11, 91, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 12, 81, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 13, 168, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 14, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 15, 40, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 16, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120813017323, 17, 85, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 1, 153, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 2, 51, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 3, 140, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 4, 86, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 5, 111, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 6, 49, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 7, 25, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040714017324, 8, 147, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 1, 54, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 2, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 3, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 4, 138, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 5, 32, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 6, 153, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 7, 121, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 8, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017325, 9, 43, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100518016186, 15, 45, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 1, 83, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 2, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 3, 101, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 4, 83, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 5, 64, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 6, 93, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050212016187, 7, 2, 33, 4, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 1, 17, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 2, 136, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 3, 12, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 4, 192, 91, 18, 1638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 5, 182, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 6, 87, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 7, 4, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 8, 125, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 9, 146, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 10, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 11, 64, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 12, 125, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 13, 191, 63, 17, 1071);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 14, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 15, 4, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120828016188, 16, 58, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207016189, 1, 82, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207016189, 2, 189, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207016189, 3, 187, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207016189, 4, 86, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031207016189, 5, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 1, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 2, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 3, 105, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 4, 38, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 5, 171, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 6, 81, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030608016190, 7, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 1, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 2, 68, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 3, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 4, 60, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 5, 66, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 6, 128, 29, 16, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 7, 153, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 8, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 9, 157, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 10, 67, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 11, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 12, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 13, 174, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 14, 97, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 15, 87, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 16, 79, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130219016191, 17, 1, 13, 3, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 1, 89, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 2, 181, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 3, 91, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 4, 25, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 5, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 6, 165, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 7, 66, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 8, 104, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 9, 184, 65, 17, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 10, 47, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 11, 106, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 12, 86, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 13, 153, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 14, 99, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 15, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 16, 150, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140516016192, 17, 3, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 1, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 2, 146, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 3, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 4, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 5, 71, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 6, 47, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 7, 106, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 8, 173, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 9, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070821016193, 10, 88, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 1, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 2, 75, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 3, 122, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 4, 96, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 5, 40, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 6, 149, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 7, 99, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 8, 110, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 9, 80, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 10, 94, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 11, 7, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 12, 11, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 13, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 14, 153, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 15, 80, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 16, 116, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 17, 10, 16, 5, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130404016194, 18, 61, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 1, 4, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 2, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 3, 90, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 4, 130, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 5, 181, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 6, 183, 28, 16, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 7, 184, 31, 17, 527);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061218016195, 8, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817016196, 1, 104, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817016196, 2, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817016196, 3, 34, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020817016196, 4, 169, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 1, 3, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 2, 78, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 3, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 4, 54, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 5, 132, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 6, 174, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 7, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 8, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 9, 89, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 10, 115, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 11, 111, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 12, 161, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090601016197, 13, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208016198, 1, 146, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208016198, 2, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208016198, 3, 123, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208016198, 4, 33, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000208016198, 5, 42, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 1, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 2, 134, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 3, 88, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 4, 93, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 5, 136, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 6, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 7, 137, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 8, 87, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 9, 48, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050826016199, 10, 127, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 1, 10, 27, 5, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 2, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 3, 103, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 4, 89, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 5, 103, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 6, 61, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 7, 94, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 8, 124, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 9, 21, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 10, 117, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 11, 18, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 12, 80, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 13, 168, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110212016200, 14, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 1, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 2, 145, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 3, 92, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 4, 102, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 5, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 6, 172, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030720016201, 7, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105016202, 1, 50, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105016202, 2, 55, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105016202, 3, 111, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105016202, 4, 24, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020105016202, 5, 133, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 1, 22, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 2, 73, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 3, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 4, 123, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 5, 128, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 6, 143, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 7, 71, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 8, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 9, 97, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 10, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 11, 103, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 12, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 13, 61, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 14, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 15, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 16, 19, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 17, 36, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 18, 181, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140428016203, 19, 96, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 1, 56, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 2, 140, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 3, 55, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 4, 17, 89, 5, 445);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 5, 6, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 6, 97, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021210016204, 7, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712016205, 1, 128, 85, 16, 1360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712016205, 2, 134, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712016205, 3, 143, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712016205, 4, 66, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010712016205, 5, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 1, 87, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 2, 40, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 3, 118, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 4, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 5, 134, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 6, 76, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 7, 110, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 8, 7, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 9, 167, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 10, 114, 9, 9, 81);
commit;
prompt 177000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080710016206, 11, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 1, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 2, 126, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 3, 182, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 4, 121, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 5, 139, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 6, 108, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 7, 82, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 8, 47, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 9, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060219016207, 10, 172, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 1, 63, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 2, 137, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 3, 97, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 4, 124, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 5, 135, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 6, 187, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 7, 11, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 8, 171, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 9, 67, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 10, 189, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 11, 74, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 12, 65, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 13, 10, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 14, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 15, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110402016208, 16, 94, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 1, 105, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 2, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 3, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 4, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 5, 145, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 6, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 7, 170, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 7, 37, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 8, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 9, 82, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 10, 183, 80, 16, 1280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090801016556, 11, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 1, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 2, 103, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 3, 151, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 4, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 5, 28, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 6, 25, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 7, 29, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 8, 14, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050731016557, 9, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 1, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 2, 22, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 3, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 4, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 5, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 6, 48, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 7, 25, 42, 6, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 8, 127, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 9, 110, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 10, 61, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 11, 114, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 12, 95, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 13, 96, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 14, 86, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100811016558, 15, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 1, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 2, 66, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 3, 76, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 4, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 5, 15, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 6, 109, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 7, 104, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 8, 98, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 9, 101, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 10, 189, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070421016559, 11, 46, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 1, 97, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 2, 165, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 3, 35, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 4, 90, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 5, 11, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 6, 151, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 7, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 8, 30, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 9, 7, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 10, 2, 60, 4, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 11, 186, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 12, 59, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 13, 143, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 14, 143, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 15, 71, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 16, 92, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140517016560, 17, 85, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912016561, 1, 120, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912016561, 2, 16, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000912016561, 3, 86, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 1, 114, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 2, 163, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 3, 124, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 4, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 5, 32, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 6, 97, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 7, 132, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 8, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 9, 13, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 10, 67, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 11, 49, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070810016562, 12, 179, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721016563, 1, 161, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721016563, 2, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721016563, 3, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721016563, 4, 24, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000721016563, 5, 11, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 1, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 2, 95, 91, 14, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 3, 191, 18, 17, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 4, 39, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 5, 166, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 6, 6, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 7, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030124016564, 8, 152, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601016565, 1, 5, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601016565, 2, 185, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601016565, 3, 156, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601016565, 4, 182, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010601016565, 5, 47, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 1, 178, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 2, 5, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 3, 151, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 4, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 5, 186, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 6, 2, 61, 4, 244);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421016566, 7, 43, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 1, 4, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 2, 129, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 3, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 4, 145, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 5, 117, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 6, 119, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 7, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 8, 72, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 9, 178, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 10, 182, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 11, 174, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 12, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100921016567, 13, 55, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 1, 62, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 2, 9, 3, 4, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 3, 153, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 4, 186, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 5, 114, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 6, 22, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040331016568, 7, 173, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 1, 185, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 2, 90, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 3, 73, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 4, 171, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 5, 161, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 6, 78, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 7, 157, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 8, 53, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 9, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 10, 156, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 11, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080517016569, 12, 135, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905016570, 1, 19, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905016570, 2, 50, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905016570, 3, 143, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905016570, 4, 146, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010905016570, 5, 60, 1, 10, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 1, 65, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 2, 57, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 3, 76, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 4, 120, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 5, 29, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 6, 99, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 7, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 8, 54, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 9, 91, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 10, 17, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 11, 114, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 12, 52, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 13, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 14, 54, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 15, 132, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120403016571, 16, 176, 23, 16, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 1, 106, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 2, 56, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 3, 110, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 4, 9, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 5, 158, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 6, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 7, 3, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 8, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 9, 1, 83, 3, 249);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 10, 1, 77, 3, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 11, 184, 58, 17, 986);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 12, 44, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 13, 103, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 14, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 15, 136, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 16, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140317016572, 17, 80, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 1, 108, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 2, 1, 36, 3, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 3, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 4, 141, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 5, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 6, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 7, 190, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 8, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 9, 31, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 10, 170, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 11, 158, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 12, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 13, 186, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 14, 114, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 15, 54, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 16, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 17, 165, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130127016573, 18, 36, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230016574, 1, 91, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230016574, 2, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230016574, 3, 99, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021230016574, 4, 16, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 1, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 2, 125, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 3, 67, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 4, 87, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 5, 56, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 6, 133, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 7, 10, 20, 5, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040402016575, 8, 122, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 1, 174, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 2, 36, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 3, 132, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 4, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 5, 115, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 6, 117, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 7, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 8, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 9, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 10, 71, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 11, 89, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 12, 98, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 13, 138, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 14, 87, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111110016576, 15, 54, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324016577, 1, 42, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324016577, 2, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324016577, 3, 192, 2, 18, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324016577, 4, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030324016577, 5, 57, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 1, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 2, 28, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 3, 107, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 4, 37, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 5, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 6, 34, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 7, 71, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 8, 58, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 9, 101, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 10, 65, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 11, 103, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 12, 153, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 13, 45, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016578, 14, 45, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 1, 81, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 2, 150, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 3, 58, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 4, 33, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 5, 69, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 6, 84, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 7, 60, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 8, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 5, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 6, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 7, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 8, 111, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 9, 126, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 10, 26, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080525016966, 11, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 1, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 2, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 3, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 4, 11, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 5, 27, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 6, 167, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 7, 107, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 8, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 9, 6, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 10, 176, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 11, 108, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 12, 174, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090419016967, 13, 176, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 1, 142, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 2, 61, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 3, 39, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 4, 160, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 5, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 6, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 7, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 8, 147, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 9, 57, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050523016968, 10, 155, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 1, 59, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 2, 131, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 3, 68, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 4, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 5, 30, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 6, 123, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315016969, 7, 166, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 1, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 2, 104, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 3, 128, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 4, 1, 96, 3, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 5, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 6, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 7, 86, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 8, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 9, 82, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060628016970, 10, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 1, 1, 9, 3, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 2, 118, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 3, 142, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 4, 117, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 5, 107, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 6, 146, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 7, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 8, 22, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 9, 14, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060523016971, 10, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 1, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 2, 29, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 3, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 4, 68, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 5, 146, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 6, 118, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051003016972, 7, 109, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 1, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 2, 97, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 3, 160, 95, 17, 1615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 4, 141, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 5, 53, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 6, 78, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016973, 7, 147, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 1, 35, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 2, 137, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 3, 75, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 4, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 5, 180, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 6, 67, 26, 7, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 7, 123, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060325016974, 8, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016975, 1, 29, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016975, 2, 120, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016975, 3, 27, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010708016975, 4, 180, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 1, 60, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 2, 68, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 3, 53, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 4, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 5, 57, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 6, 124, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 7, 34, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 8, 73, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 9, 168, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 10, 37, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 11, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 12, 109, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 13, 20, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 14, 8, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 15, 64, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131126016976, 16, 101, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 1, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 2, 176, 49, 16, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 3, 153, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 4, 62, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 5, 2, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 6, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 7, 25, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 8, 110, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 9, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 10, 79, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 11, 75, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101115016977, 12, 116, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 1, 188, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 2, 42, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 3, 59, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 4, 73, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 5, 105, 12, 7, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 6, 137, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 7, 166, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 8, 165, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070618016978, 9, 142, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 1, 131, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 2, 12, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 3, 49, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 4, 15, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 5, 159, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 6, 139, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 7, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 8, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 9, 80, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 10, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 11, 59, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 12, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117016979, 13, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 1, 78, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 2, 122, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 3, 185, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 4, 83, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 5, 167, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 6, 161, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 7, 81, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061226016980, 8, 80, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 1, 111, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 2, 55, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 3, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 4, 174, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 5, 175, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 6, 176, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 7, 101, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040823016981, 8, 130, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 1, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 2, 150, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 3, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 4, 119, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 5, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 6, 144, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 7, 162, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 8, 81, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 9, 35, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 10, 48, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 11, 16, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 12, 51, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626016982, 13, 38, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 1, 34, 94, 5, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 2, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 3, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 4, 176, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 5, 149, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 6, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 7, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 8, 98, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 9, 66, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 10, 171, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 11, 102, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 12, 9, 30, 4, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 13, 156, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 14, 21, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110116016983, 15, 109, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226016984, 1, 106, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226016984, 2, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226016984, 3, 38, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226016984, 4, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010226016984, 5, 26, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 1, 17, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 2, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 3, 133, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 4, 190, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 5, 170, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 6, 71, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 7, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 8, 92, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 9, 164, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 10, 183, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 11, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080622016985, 12, 46, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224016986, 1, 36, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224016986, 2, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224016986, 3, 26, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010224016986, 4, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 1, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 2, 145, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 3, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 4, 49, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 5, 18, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 6, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 7, 161, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 8, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060328016987, 9, 146, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 1, 3, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 2, 162, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 3, 83, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 4, 159, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 5, 2, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 6, 4, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 7, 139, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 8, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 9, 91, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 10, 173, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 11, 164, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 12, 48, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 13, 40, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 14, 164, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120806016988, 15, 132, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 1, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 2, 177, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 3, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 4, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 5, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 6, 166, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 7, 24, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 8, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 9, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 10, 189, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 11, 80, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 12, 184, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 13, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 14, 138, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110725016989, 15, 143, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 1, 133, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 1, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 2, 128, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 3, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 4, 148, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 5, 9, 18, 4, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040615017326, 6, 9, 2, 4, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 1, 182, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 2, 151, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 3, 45, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 4, 87, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 5, 172, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 6, 113, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 7, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 8, 51, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 9, 157, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 10, 92, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 11, 131, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 12, 53, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090109017327, 13, 64, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 1, 41, 19, 5, 95);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 2, 38, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 3, 137, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 4, 98, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 5, 148, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 6, 49, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 7, 66, 16, 6, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 8, 7, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 9, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 10, 100, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 11, 59, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 12, 3, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 13, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 14, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110825017328, 15, 8, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 1, 120, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 2, 143, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 3, 108, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 4, 135, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 5, 182, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 6, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 7, 45, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 8, 16, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 9, 177, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 10, 41, 64, 5, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090615017329, 11, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 1, 33, 79, 4, 316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 2, 163, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 3, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 4, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 5, 93, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 6, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 7, 72, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 8, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 9, 121, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 10, 45, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 11, 6, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 12, 134, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 13, 57, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 14, 151, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110424017330, 15, 103, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 1, 81, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 2, 184, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 3, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 4, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 5, 87, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 6, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040421017331, 7, 161, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 1, 145, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 2, 168, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 3, 45, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 4, 71, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 5, 155, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 6, 61, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 7, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 8, 101, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 9, 147, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 10, 53, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 11, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 12, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 13, 185, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100508017332, 14, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 1, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 2, 162, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 3, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 4, 104, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 5, 161, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 6, 3, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 7, 101, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 8, 192, 99, 18, 1782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 9, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 10, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 11, 67, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 12, 138, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 13, 130, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 14, 39, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 15, 36, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 16, 36, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017333, 17, 68, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 1, 191, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 2, 99, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 3, 106, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 4, 179, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 5, 32, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 6, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 7, 11, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 8, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051201017334, 9, 151, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728017335, 1, 140, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728017335, 2, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000728017335, 3, 23, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 1, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 2, 86, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 3, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 4, 136, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 5, 1, 2, 3, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 6, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 7, 118, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 8, 22, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041007017336, 9, 9, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 1, 64, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 2, 161, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 3, 83, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 4, 182, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 5, 146, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 6, 37, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 7, 96, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051222017337, 8, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 1, 146, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 2, 64, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 3, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 4, 183, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 5, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 6, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 7, 129, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 8, 48, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 9, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 10, 159, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 11, 134, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 12, 98, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 13, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 14, 19, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 15, 176, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 16, 117, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130425017338, 17, 89, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 1, 171, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 2, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 3, 83, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 4, 83, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 5, 78, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 6, 91, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 7, 120, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 8, 29, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061118017339, 9, 67, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 1, 174, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 2, 155, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 3, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 4, 137, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 5, 147, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 6, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 7, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 8, 120, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060203017340, 9, 53, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 1, 159, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 2, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 3, 31, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 4, 170, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 5, 68, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 6, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 7, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 8, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 9, 51, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 10, 190, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 11, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 12, 148, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 13, 7, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100709017341, 14, 191, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 1, 82, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 2, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 3, 62, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 4, 13, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 5, 109, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 6, 96, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 7, 77, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 8, 170, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061007017342, 9, 51, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 1, 31, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 2, 72, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 3, 154, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 4, 97, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 5, 176, 77, 16, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 6, 87, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 7, 28, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 8, 43, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060224017343, 9, 137, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 1, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 2, 89, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 3, 72, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 4, 74, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 5, 186, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 6, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040518017344, 7, 51, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815017345, 1, 138, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815017345, 2, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815017345, 3, 91, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010815017345, 4, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 1, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 2, 187, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 3, 191, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 4, 125, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 5, 25, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020610017346, 6, 21, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 1, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 2, 5, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 3, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 4, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 5, 94, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 6, 177, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 7, 180, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 8, 143, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061127017347, 9, 176, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 1, 18, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 2, 108, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 3, 176, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 4, 186, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 5, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 6, 151, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 7, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 8, 179, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 9, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 10, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017348, 11, 32, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125017349, 1, 186, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125017349, 2, 127, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125017349, 3, 175, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125017349, 4, 26, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010125017349, 5, 162, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 1, 4, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 2, 12, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 3, 91, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 8, 191, 46, 17, 782);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 9, 3, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 10, 72, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 11, 27, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100206016209, 12, 34, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113016210, 1, 27, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113016210, 2, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113016210, 3, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011113016210, 4, 10, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 1, 163, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 2, 101, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 3, 33, 37, 4, 148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 4, 24, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 5, 41, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 6, 16, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 7, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 8, 33, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 9, 88, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 10, 153, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 11, 112, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070807016211, 12, 70, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 1, 174, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 2, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 3, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 4, 59, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 5, 58, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020204016212, 6, 66, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 1, 105, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 2, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 3, 161, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 4, 22, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 5, 54, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 6, 191, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 7, 23, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 8, 5, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 9, 151, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 10, 192, 66, 18, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061208016213, 11, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 1, 52, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 2, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 3, 14, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 4, 150, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 5, 147, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 6, 100, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 7, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 8, 164, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 9, 4, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 10, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 11, 17, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 12, 65, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100223016214, 13, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 1, 133, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 2, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 3, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 4, 8, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 5, 145, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 6, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 7, 88, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 8, 169, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 9, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 10, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 11, 92, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080706016215, 12, 67, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 1, 75, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 2, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 3, 134, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 4, 35, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 5, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 6, 104, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051220016216, 7, 69, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 1, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 2, 102, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 3, 184, 86, 17, 1462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 4, 148, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 5, 79, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 6, 12, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 7, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 8, 157, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 9, 35, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 10, 132, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 11, 128, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 12, 62, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 13, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091104016217, 14, 119, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 1, 129, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 2, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 3, 110, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 4, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 5, 77, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 6, 165, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020210016218, 7, 44, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 1, 41, 44, 5, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 2, 60, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 3, 172, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 4, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 5, 64, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 6, 104, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 7, 28, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 8, 48, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 9, 78, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 10, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 11, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 12, 123, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016219, 13, 100, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 1, 140, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 2, 174, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 3, 132, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 4, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 5, 165, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 6, 46, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 7, 62, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 8, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 9, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 10, 78, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 11, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 12, 170, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 13, 177, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120201016220, 14, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 1, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 2, 45, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 3, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 4, 21, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 5, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 6, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040813016221, 7, 112, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 1, 153, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 2, 38, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 3, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 4, 70, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 5, 152, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 6, 99, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 7, 155, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031221016222, 8, 25, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016223, 1, 92, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016223, 2, 127, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016223, 3, 32, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016223, 4, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030927016223, 5, 18, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826016224, 1, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826016224, 2, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826016224, 3, 3, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010826016224, 4, 81, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 1, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 2, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 3, 77, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 4, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 5, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 6, 45, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 7, 123, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 8, 24, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 9, 93, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 10, 166, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 11, 66, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101002016225, 12, 68, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 1, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 2, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 3, 125, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 4, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 5, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 6, 21, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 7, 169, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 8, 81, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 9, 70, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 10, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 11, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 12, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 13, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120116016226, 14, 178, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 1, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 2, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 3, 61, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 4, 15, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 5, 65, 86, 5, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 6, 95, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205016227, 7, 28, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 1, 139, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 2, 130, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 3, 93, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 4, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 5, 13, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 6, 23, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 7, 118, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 8, 135, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 9, 37, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 10, 95, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 11, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 12, 189, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 13, 83, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 14, 6, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130708016228, 15, 93, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 1, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 2, 156, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 3, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 4, 171, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 5, 98, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030908016229, 6, 107, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 1, 81, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 2, 144, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 3, 30, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 4, 136, 53, 14, 742);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 5, 185, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030425016230, 6, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 1, 100, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 2, 101, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 3, 182, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 4, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 5, 15, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 6, 146, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 7, 48, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050409016231, 8, 135, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 1, 91, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 2, 156, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 3, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 4, 126, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 5, 62, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 6, 182, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 7, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 8, 175, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 9, 165, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 10, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 11, 89, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 12, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091030016232, 13, 33, 24, 4, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 1, 80, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 2, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 3, 174, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 4, 35, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 5, 52, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 6, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 7, 27, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 8, 129, 78, 7, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 9, 21, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 10, 164, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 11, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 12, 76, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 13, 124, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 14, 150, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 15, 17, 75, 5, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 16, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 9, 121, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 10, 24, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 11, 71, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 12, 191, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 13, 72, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100817016579, 14, 57, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 1, 29, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 2, 1, 66, 3, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 3, 173, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 4, 9, 45, 4, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 5, 8, 25, 10, 250);
commit;
prompt 178000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 6, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 7, 18, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 8, 72, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 9, 42, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 10, 126, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 11, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 12, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 13, 15, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111129016580, 14, 25, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 1, 136, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 2, 95, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 3, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 4, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 5, 98, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 6, 59, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 7, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 8, 31, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 9, 109, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080617016581, 10, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703016582, 1, 26, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703016582, 2, 95, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703016582, 3, 13, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703016582, 4, 20, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020703016582, 5, 183, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 1, 110, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 2, 79, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 3, 80, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 4, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 5, 122, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 6, 155, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 7, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 8, 24, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 9, 163, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 10, 161, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 11, 19, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 12, 149, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 13, 59, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 14, 122, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 15, 84, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130324016583, 16, 116, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 1, 155, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 2, 164, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 3, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 4, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 5, 36, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 6, 181, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 7, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 8, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041026016584, 9, 43, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 1, 163, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 2, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 3, 186, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 4, 124, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 5, 90, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 6, 158, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 7, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 8, 185, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 9, 19, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 10, 184, 33, 17, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 11, 18, 26, 6, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 12, 96, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 13, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120808016585, 14, 142, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 1, 175, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 2, 7, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 3, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 4, 162, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 5, 105, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 6, 99, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 7, 107, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 8, 164, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 9, 112, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 10, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080310016586, 11, 94, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 1, 104, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 2, 165, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 3, 73, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 4, 164, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 5, 113, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 6, 154, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 7, 123, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 8, 91, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 9, 123, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081103016587, 10, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 1, 107, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 2, 174, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 3, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 4, 70, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 5, 85, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 6, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041016016588, 7, 165, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 1, 164, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 2, 19, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 3, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 4, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 5, 93, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 6, 98, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 7, 53, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 8, 179, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 9, 117, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 10, 99, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 11, 152, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 12, 64, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 13, 26, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 14, 102, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 15, 108, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121113016589, 16, 19, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 1, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 2, 162, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 3, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 4, 183, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 5, 26, 80, 7, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 6, 55, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 7, 131, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 8, 81, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 9, 44, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 10, 102, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 11, 152, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 12, 29, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 13, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 14, 23, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 15, 91, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 16, 26, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140501016590, 17, 93, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 1, 177, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 2, 117, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 3, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 4, 182, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 5, 150, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 6, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 7, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 8, 63, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 9, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 10, 184, 2, 17, 34);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 11, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 12, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 13, 118, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 14, 45, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 15, 188, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130908016591, 16, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 1, 23, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 2, 76, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 3, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 4, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 5, 77, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 6, 139, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 7, 64, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 8, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 9, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 10, 127, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091124016592, 11, 8, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016593, 1, 91, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016593, 2, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016593, 3, 173, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016593, 4, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001224016593, 5, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619016594, 1, 127, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619016594, 2, 59, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619016594, 3, 5, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619016594, 4, 40, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030619016594, 5, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702016595, 1, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702016595, 2, 58, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702016595, 3, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702016595, 4, 33, 90, 4, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010702016595, 5, 139, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 1, 119, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 2, 62, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 3, 66, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 4, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 5, 36, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 6, 5, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 7, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 8, 103, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 9, 35, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 10, 136, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 11, 169, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 12, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 13, 170, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090426016596, 14, 60, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 1, 27, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 2, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 3, 40, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 4, 53, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 5, 53, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 6, 40, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031222016597, 7, 148, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 1, 87, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 2, 97, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 3, 58, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 4, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 5, 89, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123016598, 6, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016599, 1, 64, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016599, 2, 148, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000926016599, 3, 39, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313016600, 1, 150, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313016600, 2, 105, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313016600, 3, 20, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000313016600, 4, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 1, 15, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 2, 124, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 3, 145, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 4, 24, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 5, 83, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 6, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 7, 132, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 8, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 9, 104, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 10, 16, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 11, 160, 35, 17, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 12, 108, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 13, 159, 61, 16, 976);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101211016601, 14, 156, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 1, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 2, 183, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 3, 27, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 4, 7, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 5, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 6, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 7, 82, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 8, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 9, 181, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 10, 144, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 11, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 12, 173, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 13, 88, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 14, 133, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 2, 117, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 3, 48, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 4, 176, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 5, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 6, 114, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 7, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 8, 160, 67, 17, 1139);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 9, 184, 22, 17, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 10, 87, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 11, 89, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 12, 59, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 13, 26, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 14, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120911016990, 15, 77, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 1, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 2, 119, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 3, 185, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 4, 2, 64, 4, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 5, 44, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508016991, 6, 29, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 1, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 2, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 3, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 4, 72, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 5, 148, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 6, 54, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 7, 19, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 8, 169, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 9, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 10, 121, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 11, 43, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090913016992, 12, 133, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 1, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 2, 142, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 3, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 4, 74, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 5, 21, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 6, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 7, 147, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 8, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 9, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 10, 146, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 11, 82, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 12, 138, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100824016993, 13, 55, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207016994, 1, 26, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207016994, 2, 23, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207016994, 3, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207016994, 4, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001207016994, 5, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 1, 42, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 2, 117, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 3, 31, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 4, 98, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 5, 10, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 6, 82, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 7, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 8, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 9, 189, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 10, 20, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 11, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 12, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 13, 72, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 14, 96, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 15, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 16, 62, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 17, 97, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 18, 25, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140127016995, 19, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 1, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 2, 151, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 3, 29, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 4, 58, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 5, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 6, 76, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 7, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 8, 21, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 9, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 10, 159, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090112016996, 11, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 1, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 2, 4, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 3, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 4, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 5, 44, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 6, 154, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 7, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 8, 147, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 9, 129, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 10, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071218016997, 11, 177, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 1, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 2, 181, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 3, 110, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 4, 166, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 5, 41, 32, 5, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 6, 167, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 7, 114, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 8, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050918016998, 9, 105, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 1, 171, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 2, 92, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 3, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 4, 65, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 5, 161, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 6, 184, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 7, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 8, 19, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060602016999, 9, 3, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 1, 116, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 2, 170, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 3, 71, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 4, 159, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 5, 15, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 6, 116, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 7, 142, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050426017000, 8, 166, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 1, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 2, 65, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 3, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 4, 108, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 5, 116, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040223017001, 6, 169, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 1, 180, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 2, 80, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 3, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 4, 134, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 5, 120, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 6, 74, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 7, 21, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050901017002, 8, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 1, 87, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 2, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 3, 136, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 4, 91, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 5, 188, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 6, 117, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 7, 160, 28, 17, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 8, 191, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 9, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 10, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 11, 182, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091222017003, 12, 86, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 1, 75, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 2, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 3, 156, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 4, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 5, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 6, 82, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 7, 59, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 8, 88, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 9, 73, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 10, 130, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 11, 1, 30, 3, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 12, 123, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 13, 141, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120322017004, 14, 58, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 1, 33, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 2, 178, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 3, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 4, 110, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 5, 147, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 6, 89, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 7, 2, 34, 4, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 8, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 9, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 10, 21, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 11, 61, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 12, 57, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 13, 98, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 14, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 15, 136, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 16, 172, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 17, 12, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140224017005, 18, 26, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 1, 13, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 2, 102, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 3, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 4, 138, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 5, 189, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 6, 157, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 7, 20, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 8, 54, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 9, 156, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 10, 7, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 11, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 12, 41, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 13, 41, 60, 5, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121008017006, 14, 153, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 1, 123, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 2, 182, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 3, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 4, 95, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 5, 183, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 6, 155, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 7, 34, 73, 5, 365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 8, 167, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050401017007, 9, 32, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 1, 141, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 2, 173, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 3, 69, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 4, 17, 30, 5, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 5, 9, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 6, 48, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 7, 11, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 8, 33, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 9, 3, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070513017008, 10, 141, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 1, 47, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 2, 165, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 3, 108, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 4, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 5, 103, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 6, 159, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 7, 112, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 8, 187, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 9, 65, 38, 5, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 10, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 11, 172, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 12, 81, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017009, 13, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017010, 1, 94, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017010, 2, 60, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017010, 3, 94, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017010, 4, 13, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011221017010, 5, 2, 98, 4, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001017011, 1, 138, 42, 9, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001017011, 2, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001017011, 3, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001017011, 4, 159, 30, 16, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021001017011, 5, 7, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 1, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 2, 102, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 3, 155, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 4, 43, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 5, 25, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 6, 75, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 7, 149, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060127017012, 8, 59, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 4, 23, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 5, 21, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 6, 1, 52, 3, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 7, 147, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 8, 2, 20, 4, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 9, 33, 88, 4, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 10, 75, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 11, 39, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080514017350, 12, 4, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 1, 36, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 2, 13, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 3, 43, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 4, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 5, 170, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 6, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 7, 186, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 8, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 9, 94, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 10, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 11, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 12, 133, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 13, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 14, 184, 81, 17, 1377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 15, 147, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 16, 149, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130701017351, 17, 63, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017352, 1, 143, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017352, 2, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017352, 3, 163, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017352, 4, 60, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 1, 9, 13, 4, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 2, 31, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 3, 43, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 4, 144, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 5, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 6, 158, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 7, 125, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 8, 95, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 9, 46, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 10, 99, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 11, 49, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 12, 110, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101021017353, 13, 124, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 1, 155, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 2, 179, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 3, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 4, 153, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 5, 17, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 6, 24, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 7, 141, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 8, 55, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 9, 154, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 10, 93, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080811017354, 11, 113, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 1, 55, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 2, 123, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 3, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 4, 49, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 5, 145, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 6, 111, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030508017355, 7, 165, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 1, 38, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 2, 153, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 3, 177, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 4, 182, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 5, 149, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 6, 70, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 7, 28, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 8, 46, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 9, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 10, 122, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 11, 136, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 12, 56, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 13, 93, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 14, 25, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 15, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131207017356, 16, 1, 43, 3, 129);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 1, 109, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 2, 116, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 3, 44, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 4, 158, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 5, 92, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 6, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 7, 49, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 8, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 9, 49, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 10, 131, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 11, 177, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 12, 106, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 13, 182, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 14, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 15, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 16, 140, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 17, 139, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017357, 18, 180, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 1, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 2, 128, 90, 16, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 3, 26, 91, 7, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 4, 154, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 5, 21, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 6, 79, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 7, 44, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 8, 99, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 9, 62, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 10, 98, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 11, 106, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080329017358, 12, 40, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 1, 142, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 2, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 3, 63, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 4, 44, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 5, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 6, 75, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 7, 75, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 8, 113, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 9, 48, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 10, 104, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 11, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 12, 35, 29, 6, 174);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 13, 127, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 14, 112, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 15, 95, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 16, 180, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130719017359, 17, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105017360, 1, 17, 55, 5, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105017360, 2, 31, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105017360, 3, 125, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010105017360, 4, 171, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 1, 134, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 2, 17, 40, 5, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 3, 122, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 4, 43, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 5, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 6, 23, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 7, 161, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 8, 49, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 9, 105, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 10, 48, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 11, 126, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 12, 164, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 13, 147, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 14, 35, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 15, 164, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 16, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121116017361, 17, 169, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914017362, 1, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000914017362, 2, 78, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 1, 69, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 2, 184, 69, 17, 1173);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 3, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 4, 192, 15, 18, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 5, 89, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 6, 51, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031117017363, 7, 94, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 1, 32, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 2, 182, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 3, 192, 95, 18, 1710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 4, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 5, 100, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011122017364, 6, 52, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 1, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 2, 140, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 3, 125, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 4, 55, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 5, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010825017365, 6, 82, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 1, 70, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 2, 42, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 3, 49, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 4, 166, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 5, 41, 12, 5, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 6, 190, 40, 16, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 7, 62, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 8, 90, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041108017366, 9, 145, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 1, 17, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 2, 144, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 3, 102, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 4, 28, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 5, 121, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 6, 64, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 7, 36, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 8, 140, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 9, 38, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 10, 9, 6, 4, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 11, 128, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090531017367, 12, 53, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 1, 179, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 2, 80, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 3, 124, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 4, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 5, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 6, 48, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 7, 85, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 8, 111, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 9, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 10, 129, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 11, 44, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 12, 2, 87, 4, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 13, 46, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 14, 188, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20121106017368, 15, 31, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 1, 118, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 2, 189, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 3, 180, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 4, 111, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 5, 54, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 6, 120, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 7, 51, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 8, 154, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 9, 160, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 10, 132, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 11, 33, 78, 4, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080411017369, 12, 76, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 1, 57, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 2, 151, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 3, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 4, 112, 95, 14, 1330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 5, 72, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 6, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 7, 63, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 8, 27, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 9, 182, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 10, 118, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 11, 127, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 12, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 13, 61, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110626017370, 14, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 1, 32, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 2, 62, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 3, 170, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 4, 85, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 5, 70, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 6, 83, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 7, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050908017371, 8, 140, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 1, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 2, 116, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130507017372, 3, 38, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131220016233, 17, 113, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 1, 81, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 2, 75, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 3, 142, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 4, 56, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 5, 191, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 6, 17, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 7, 98, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 8, 130, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 9, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 10, 46, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 11, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 12, 30, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 13, 164, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120921016234, 14, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 1, 56, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 2, 68, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 3, 6, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 4, 161, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 5, 29, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020626016235, 6, 71, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 1, 42, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 2, 88, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 3, 112, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 4, 53, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 5, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 6, 175, 83, 15, 1245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 7, 187, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 8, 162, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 9, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 10, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060212016236, 11, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 1, 29, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 2, 165, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 3, 16, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 4, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 5, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 6, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 7, 98, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 8, 51, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 9, 1, 70, 3, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 10, 131, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 11, 101, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 12, 87, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 13, 10, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 14, 130, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110203016237, 15, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 1, 132, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 2, 77, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 3, 157, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 4, 41, 31, 5, 155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 5, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 6, 39, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 7, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 8, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 9, 2, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 10, 120, 47, 15, 705);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 11, 39, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 12, 103, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 13, 173, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 14, 33, 84, 4, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 15, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 16, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 17, 49, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131023016238, 18, 21, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 1, 96, 95, 15, 1425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 2, 81, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 3, 152, 53, 16, 848);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 4, 78, 73, 11, 803);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 5, 93, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 6, 21, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 7, 70, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 8, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 9, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 10, 128, 13, 16, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 11, 137, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 12, 24, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 13, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090213016239, 14, 18, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 1, 170, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 2, 38, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 3, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 4, 165, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 5, 182, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 6, 163, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 7, 141, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 8, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 9, 172, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 10, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 11, 13, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517016240, 12, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 1, 26, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 2, 62, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 3, 87, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 4, 150, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 5, 188, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 6, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 7, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 8, 36, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 9, 36, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402016241, 10, 118, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 1, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 2, 76, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 3, 122, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 4, 67, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 5, 175, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 6, 119, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 7, 51, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 8, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 9, 118, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 10, 129, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 11, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 12, 106, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 13, 173, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 14, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 15, 101, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111218016242, 16, 52, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 1, 25, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 2, 171, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 3, 49, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 4, 45, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 5, 26, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 6, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 7, 55, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040215016243, 8, 167, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 1, 109, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 2, 103, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 3, 20, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 4, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 5, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 6, 119, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051110016244, 7, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 1, 143, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 2, 17, 42, 5, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 3, 109, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 4, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 5, 111, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 6, 87, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 7, 86, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 8, 48, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 9, 142, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 10, 18, 71, 6, 426);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 11, 131, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 12, 54, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 13, 11, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090901016245, 14, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 1, 166, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 2, 17, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 3, 163, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 4, 22, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 5, 106, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 6, 15, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 7, 172, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040209016246, 8, 69, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 1, 93, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 2, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 3, 117, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 4, 86, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 5, 125, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 6, 174, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040914016247, 7, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 1, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 2, 96, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 3, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 4, 10, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 5, 173, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427016248, 6, 53, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 1, 179, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 2, 184, 3, 17, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 3, 93, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 4, 101, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 5, 34, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 6, 100, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040517016249, 7, 145, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 1, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 2, 162, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 3, 92, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 4, 24, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 5, 80, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 6, 122, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 7, 22, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 8, 39, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 9, 124, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 10, 185, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060101016250, 11, 188, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 1, 158, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 2, 77, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 3, 122, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 4, 15, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 5, 177, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 6, 12, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 7, 72, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 8, 23, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 9, 122, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071017016251, 10, 72, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 1, 28, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 2, 52, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 3, 1, 51, 3, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 4, 133, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 5, 106, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020515016252, 6, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 1, 97, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 2, 106, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 3, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 4, 132, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 5, 149, 57, 13, 741);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 6, 23, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 7, 79, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 8, 45, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 9, 79, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 10, 129, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 11, 158, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 12, 161, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 13, 29, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 14, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 15, 36, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130905016253, 16, 112, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 1, 17, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 2, 34, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 3, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 4, 175, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 5, 153, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 6, 129, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 7, 145, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 8, 113, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 9, 46, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 10, 125, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 11, 77, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 12, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 13, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 14, 111, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110623016254, 15, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 1, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 2, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 3, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 4, 36, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 5, 176, 22, 16, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 6, 74, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130526016255, 7, 181, 27, 14, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 15, 184, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 16, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 17, 21, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130713016602, 18, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903016603, 1, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903016603, 2, 148, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000903016603, 3, 61, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 1, 79, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 2, 176, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 3, 129, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 4, 27, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 5, 164, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 6, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 7, 158, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 8, 38, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 9, 133, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071115016604, 10, 43, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 1, 71, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 2, 7, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 3, 127, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 4, 71, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 5, 122, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 6, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 7, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 8, 173, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 9, 108, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 10, 139, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 11, 63, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 12, 122, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 13, 131, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 14, 75, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110919016605, 15, 146, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 1, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 2, 89, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 3, 74, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 4, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 5, 169, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040219016606, 6, 72, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 1, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 2, 43, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 3, 109, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 4, 2, 42, 4, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 5, 148, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 6, 94, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 7, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 8, 182, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 9, 85, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 10, 86, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 11, 115, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080602016607, 12, 65, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 1, 127, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 2, 152, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 3, 98, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 4, 126, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 5, 94, 72, 13, 936);
commit;
prompt 179000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 6, 188, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 7, 30, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 8, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 9, 79, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 10, 119, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 11, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 12, 4, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081020016608, 13, 117, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 1, 102, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 2, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 3, 39, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 4, 40, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 5, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 6, 128, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 7, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 8, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 9, 47, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 10, 174, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090406016609, 11, 107, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 1, 20, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 2, 107, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 3, 166, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 4, 76, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 5, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 6, 54, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 7, 94, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041214016610, 8, 75, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 1, 108, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 2, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 3, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 4, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 5, 51, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 6, 66, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030607016611, 7, 123, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 1, 122, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 2, 163, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 3, 15, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 4, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 5, 128, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 6, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 7, 66, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 8, 73, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 9, 150, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 10, 122, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 11, 29, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 12, 83, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 13, 77, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 14, 180, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111003016612, 15, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 1, 2, 74, 4, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 2, 153, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 3, 171, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 4, 127, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 5, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 6, 76, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 7, 61, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 8, 82, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019016613, 9, 5, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018016614, 1, 151, 92, 15, 1380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018016614, 2, 95, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018016614, 3, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018016614, 4, 64, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021018016614, 5, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201016615, 1, 6, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201016615, 2, 61, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201016615, 3, 148, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011201016615, 4, 164, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 1, 170, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 2, 158, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 3, 178, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 4, 171, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 5, 105, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 6, 171, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 7, 69, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 8, 125, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 9, 77, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 10, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 11, 64, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 12, 185, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 13, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120115016616, 14, 191, 74, 17, 1258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 1, 136, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 2, 21, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 3, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 4, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 5, 84, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 6, 82, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 7, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 8, 129, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 9, 79, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 10, 30, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 11, 108, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 12, 153, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 13, 174, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 14, 117, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 15, 64, 4, 14, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140206016617, 16, 122, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 1, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 2, 160, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 3, 169, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 4, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 5, 122, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 6, 142, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 7, 29, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 8, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 9, 180, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 10, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070330016618, 11, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 1, 180, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 2, 9, 92, 4, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 3, 134, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 4, 73, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 5, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 6, 165, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 7, 50, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 8, 131, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 9, 8, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070313016619, 10, 122, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228016620, 1, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228016620, 2, 6, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228016620, 3, 174, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228016620, 4, 148, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000228016620, 5, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 1, 55, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 2, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 3, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 4, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 5, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 6, 111, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 7, 5, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 8, 177, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070621016621, 9, 6, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 1, 97, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 2, 94, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 3, 117, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 4, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 5, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 6, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 7, 173, 59, 13, 767);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 8, 35, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 9, 81, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 10, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 11, 54, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 12, 132, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 13, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 14, 111, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 15, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 16, 118, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130816016622, 17, 70, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 1, 185, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 2, 23, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 3, 79, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 4, 107, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 5, 160, 9, 17, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 6, 21, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 7, 45, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 8, 160, 93, 17, 1581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 9, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 10, 13, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 11, 99, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223016623, 12, 32, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 1, 145, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 2, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 3, 32, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 4, 182, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 5, 161, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 6, 5, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 7, 157, 7, 14, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 8, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 9, 189, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 10, 54, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 11, 107, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 12, 176, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091002016624, 13, 64, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 1, 71, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 2, 175, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 3, 47, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 4, 84, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 5, 132, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 6, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 7, 117, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 8, 154, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 9, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090404016625, 10, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 13, 136, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 14, 173, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 15, 45, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 16, 5, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 1, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 2, 107, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 3, 59, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 4, 180, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 5, 79, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030421017746, 6, 66, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 1, 149, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 2, 129, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 3, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 4, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 5, 122, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 6, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 7, 70, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 8, 177, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 9, 173, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 10, 131, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 11, 146, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101204017747, 12, 116, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 1, 179, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 2, 158, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 3, 21, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 4, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 5, 153, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 6, 26, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 7, 31, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 8, 155, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040825017748, 9, 128, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 1, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 2, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 3, 19, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 4, 125, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 5, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 6, 12, 94, 7, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 7, 142, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040409017749, 8, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017750, 1, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017750, 2, 94, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017750, 3, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017750, 4, 173, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726017751, 1, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726017751, 2, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726017751, 3, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000726017751, 4, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 1, 146, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 2, 158, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 3, 176, 67, 16, 1072);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 4, 72, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 5, 97, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 6, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 7, 128, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 8, 27, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 9, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 10, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091115017752, 11, 57, 28, 7, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 1, 162, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 2, 26, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 3, 109, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 4, 181, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 5, 24, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 6, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 7, 18, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 8, 29, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 9, 106, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 10, 152, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 11, 86, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 12, 113, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 13, 134, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 14, 68, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 15, 142, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 16, 12, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 17, 59, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 18, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140112017753, 19, 28, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 1, 12, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 2, 148, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 3, 40, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 4, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 5, 143, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 6, 65, 45, 5, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 7, 91, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050706017754, 8, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 1, 82, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 2, 154, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 3, 44, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 4, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 5, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 6, 163, 69, 10, 690);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 7, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 8, 152, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 9, 94, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 10, 18, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 11, 15, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 12, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 13, 149, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100706017755, 14, 185, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 1, 7, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 2, 87, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 3, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 4, 74, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 5, 179, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 6, 122, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 7, 46, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 8, 6, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 9, 110, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 10, 72, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 11, 103, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 12, 39, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 13, 146, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 14, 15, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 15, 75, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 16, 1, 6, 3, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120302017756, 17, 67, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105017757, 1, 170, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000105017757, 2, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 1, 55, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 2, 118, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 3, 105, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 4, 64, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 5, 33, 53, 4, 212);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 6, 49, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040318017758, 7, 3, 39, 5, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 1, 28, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 2, 103, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 3, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 4, 104, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 5, 12, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 6, 177, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 7, 66, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 8, 54, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 9, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 10, 65, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 11, 162, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 12, 128, 26, 16, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 13, 120, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 14, 22, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 15, 32, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017759, 16, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 1, 158, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 2, 129, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 3, 90, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 4, 129, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 5, 86, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 6, 135, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 7, 67, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 8, 135, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 9, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 10, 147, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 11, 123, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 12, 90, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091009017760, 13, 76, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 1, 166, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 2, 69, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 3, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 4, 2, 68, 4, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 5, 184, 88, 17, 1496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 6, 183, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 7, 98, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 8, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 9, 67, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 10, 149, 24, 13, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 11, 99, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 12, 186, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100812017761, 13, 42, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 1, 134, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 2, 109, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 3, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 4, 139, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 5, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 6, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 7, 12, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 8, 63, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 9, 105, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017762, 10, 5, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 1, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 2, 173, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 3, 79, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 4, 73, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 5, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 6, 83, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 7, 106, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030818017763, 8, 136, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 1, 75, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 2, 68, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 3, 73, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 4, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 5, 23, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 6, 151, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 7, 174, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 8, 34, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 9, 145, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 10, 108, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080428017764, 11, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403017765, 1, 75, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000403017765, 2, 45, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 1, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 2, 52, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 3, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 4, 148, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 5, 71, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031002017766, 6, 93, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 1, 118, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 2, 175, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 3, 180, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 4, 98, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 5, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 6, 24, 96, 12, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 7, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 8, 91, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 9, 142, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 10, 49, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 11, 114, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 12, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 13, 148, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 14, 103, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 15, 7, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 16, 149, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140218017767, 17, 44, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 1, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 2, 75, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 3, 69, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 4, 47, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 5, 21, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 6, 140, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 7, 111, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 8, 6, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 9, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 10, 86, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 11, 186, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 12, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 13, 59, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017768, 14, 172, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 1, 160, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 2, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 3, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 4, 95, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 5, 44, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 6, 132, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 7, 23, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 8, 47, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 9, 44, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 10, 144, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 11, 24, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 12, 27, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100109017769, 13, 56, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006017770, 1, 139, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006017770, 2, 30, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001006017770, 3, 180, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 1, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 2, 52, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 3, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 4, 66, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 5, 93, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 6, 17, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031107017771, 7, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912017772, 1, 34, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912017772, 2, 73, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912017772, 3, 112, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010912017772, 4, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 1, 136, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 2, 176, 95, 16, 1520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 3, 189, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 4, 112, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 5, 96, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 6, 94, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 7, 120, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 8, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 9, 91, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 10, 190, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 11, 142, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 12, 40, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 13, 116, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110921017773, 14, 112, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000229017774, 1, 51, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000229017774, 2, 92, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000229017774, 3, 134, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830017775, 1, 108, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830017775, 2, 57, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830017775, 3, 66, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830017775, 4, 131, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000830017775, 5, 134, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 1, 192, 62, 18, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 2, 5, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 3, 19, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 4, 101, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 5, 79, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 6, 104, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 7, 36, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 8, 3, 18, 5, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 9, 58, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 10, 96, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071129017776, 11, 181, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 1, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 2, 77, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 3, 121, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 4, 78, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 5, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 6, 72, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031004017777, 7, 91, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 1, 64, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 2, 164, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 3, 27, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 4, 50, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 5, 145, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041225017778, 6, 136, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218017779, 1, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218017779, 2, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000218017779, 3, 190, 56, 16, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 1, 123, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 2, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 3, 23, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 4, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 5, 9, 58, 4, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 6, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 7, 81, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051115017780, 8, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 1, 4, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 2, 110, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 3, 152, 72, 16, 1152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 4, 155, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 5, 97, 72, 6, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020813017781, 6, 149, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 1, 143, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 2, 11, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 3, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 4, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 5, 180, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 6, 1, 63, 3, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 7, 65, 100, 5, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 8, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 9, 96, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 10, 148, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 11, 184, 16, 17, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070327017782, 12, 66, 56, 6, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 1, 71, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 2, 51, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 3, 18, 78, 6, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 4, 126, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 5, 134, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 6, 97, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 7, 15, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 8, 146, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 9, 137, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 10, 119, 100, 14, 1400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 11, 131, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 12, 62, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 13, 58, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101118017783, 14, 77, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 1, 159, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 2, 6, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 3, 126, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 4, 7, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 5, 74, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 6, 110, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 7, 102, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 8, 130, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 9, 184, 56, 17, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 10, 84, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 11, 30, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 12, 128, 59, 16, 944);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 13, 127, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 14, 12, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 15, 39, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 16, 190, 98, 16, 1568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131215017784, 17, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130017785, 1, 14, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130017785, 2, 109, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130017785, 3, 15, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130017785, 4, 27, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010130017785, 5, 33, 95, 4, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 1, 169, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 2, 89, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 3, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 4, 76, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 5, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 6, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 7, 147, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 8, 157, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 9, 172, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 10, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 11, 121, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 12, 130, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 13, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 14, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130619017786, 15, 134, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508017787, 1, 141, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508017787, 2, 24, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508017787, 3, 3, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508017787, 4, 56, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020508017787, 5, 187, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 1, 113, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 2, 33, 76, 4, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 3, 105, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 4, 20, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 5, 128, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 6, 26, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 7, 171, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 8, 176, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 9, 73, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 10, 74, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 11, 107, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 12, 42, 34, 6, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110524017788, 13, 120, 96, 15, 1440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 1, 183, 74, 16, 1184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 2, 165, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 3, 136, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 4, 110, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 5, 139, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 6, 41, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 7, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 8, 173, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 9, 113, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 10, 139, 80, 10, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 11, 46, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 12, 60, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 13, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 14, 18, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 15, 72, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 16, 151, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130331017789, 17, 77, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020611017790, 1, 22, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020611017790, 2, 11, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020611017790, 3, 16, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020611017790, 4, 151, 89, 15, 1335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020611017790, 5, 176, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 1, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 2, 163, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 3, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 4, 188, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 5, 116, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 6, 59, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 7, 180, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 8, 156, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 9, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 10, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 11, 168, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 12, 134, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091105017791, 13, 62, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 1, 168, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 2, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 3, 63, 34, 13, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 4, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 5, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 6, 148, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 7, 191, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 8, 190, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 9, 130, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 10, 60, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 11, 113, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 12, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 13, 79, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 14, 125, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110708017792, 15, 165, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 1, 89, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 2, 53, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 3, 69, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 4, 4, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 5, 58, 78, 8, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 6, 81, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 7, 25, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 8, 57, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 9, 52, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 10, 138, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 11, 2, 29, 4, 116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081213017793, 12, 144, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 1, 150, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 2, 116, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 3, 26, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 4, 76, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 5, 82, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 6, 154, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 7, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 8, 80, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 9, 46, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 10, 149, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 11, 27, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 12, 141, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 13, 100, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 14, 52, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 15, 171, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 16, 161, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130115017794, 17, 170, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021017795, 1, 106, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001021017795, 2, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 1, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 2, 157, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 3, 146, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 4, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 5, 36, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 6, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 7, 13, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 8, 94, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070324017796, 9, 58, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727017797, 1, 154, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727017797, 2, 67, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727017797, 3, 104, 71, 13, 923);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000727017797, 4, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 1, 11, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 2, 84, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 3, 93, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 4, 87, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 5, 9, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 6, 166, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 7, 182, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 8, 150, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070315017798, 9, 59, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809017799, 1, 91, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809017799, 2, 95, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809017799, 3, 1, 95, 3, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809017799, 4, 3, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000809017799, 5, 23, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 1, 72, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 2, 80, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 3, 128, 75, 16, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 4, 183, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 5, 146, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 6, 11, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 7, 55, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 8, 62, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 9, 24, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 10, 183, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 11, 15, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 12, 129, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 13, 42, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 14, 33, 26, 4, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 15, 124, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 16, 20, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130402017800, 17, 17, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 1, 66, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 2, 29, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 3, 16, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 4, 53, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 5, 152, 27, 16, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020917017801, 6, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 1, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 2, 112, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 3, 60, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 4, 11, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 5, 162, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 6, 47, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 7, 155, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 8, 144, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060721017802, 9, 115, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 1, 175, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 2, 73, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 3, 135, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 5, 142, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 6, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 7, 4, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 8, 168, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050218017803, 9, 36, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 1, 5, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 2, 75, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 3, 1, 47, 3, 141);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 4, 41, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 5, 164, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 6, 13, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 7, 173, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 8, 34, 84, 5, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 9, 148, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050729017804, 10, 101, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 1, 100, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 2, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 3, 38, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 4, 140, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 5, 58, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 6, 73, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 7, 176, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 8, 95, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 9, 154, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 10, 38, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 11, 37, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 12, 124, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090510017805, 13, 136, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017806, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017806, 2, 47, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017806, 3, 127, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 1, 131, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 2, 186, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 3, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 4, 34, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 5, 190, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 6, 18, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 7, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 8, 7, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 9, 6, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 10, 99, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 11, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 12, 53, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090517017807, 13, 86, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 1, 169, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 2, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 3, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 4, 169, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 5, 6, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 6, 97, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 7, 181, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060519017808, 8, 42, 96, 6, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 1, 60, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 2, 19, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 3, 176, 42, 16, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 4, 134, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 5, 150, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 6, 19, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 7, 187, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 8, 131, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051017017809, 9, 22, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 1, 189, 70, 15, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 2, 46, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 3, 136, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 4, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 5, 73, 27, 6, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 6, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 7, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 8, 113, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 9, 102, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 10, 104, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 11, 85, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100930017810, 12, 53, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 1, 150, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 2, 144, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 3, 117, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 4, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 5, 150, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017811, 6, 89, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 1, 109, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 2, 129, 17, 7, 119);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 3, 4, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 4, 179, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 5, 74, 31, 7, 217);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030919017812, 6, 36, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 1, 99, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 2, 75, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 3, 66, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 4, 145, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 5, 80, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 6, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 7, 123, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 8, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 9, 134, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 10, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 11, 125, 83, 13, 1079);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 12, 183, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 13, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 14, 78, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130817017813, 15, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 1, 116, 94, 11, 1034);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 2, 3, 88, 5, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 3, 188, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 4, 47, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 5, 126, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020827017814, 6, 174, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010205017815, 1, 115, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010205017815, 2, 5, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010205017815, 3, 185, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010205017815, 4, 151, 42, 15, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010205017815, 5, 124, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 1, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 2, 89, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 3, 6, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 4, 192, 82, 18, 1476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 5, 70, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 6, 141, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 7, 46, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 8, 92, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 9, 30, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 10, 178, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 11, 51, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 12, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 13, 47, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 14, 182, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130625017816, 15, 22, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 1, 126, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 2, 13, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 3, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 4, 117, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 5, 176, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 6, 56, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 7, 109, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 8, 128, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 9, 173, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 10, 130, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 11, 29, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 12, 79, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017817, 13, 27, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 1, 95, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 2, 121, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 3, 162, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 4, 150, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 5, 102, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 6, 141, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 7, 176, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 8, 12, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 9, 145, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 10, 147, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 11, 96, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 12, 92, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 13, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100226017818, 14, 73, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 1, 160, 55, 17, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 2, 10, 14, 5, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 3, 47, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 4, 116, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 5, 113, 64, 8, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 6, 91, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 7, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 8, 112, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 9, 154, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 10, 62, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 11, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080120017819, 12, 26, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412017820, 1, 192, 30, 18, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412017820, 2, 170, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000412017820, 3, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 1, 102, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 2, 12, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 3, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 4, 140, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 5, 79, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 6, 132, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 7, 187, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 8, 22, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 9, 141, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 10, 105, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 11, 103, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 12, 123, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 13, 106, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 14, 80, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 15, 143, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130802017821, 16, 167, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 1, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 2, 104, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 3, 135, 70, 13, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 4, 61, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 5, 21, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 6, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 7, 167, 17, 14, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 8, 92, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070221017822, 9, 168, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212017823, 1, 19, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212017823, 2, 33, 91, 4, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212017823, 3, 154, 82, 11, 902);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010212017823, 4, 180, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 1, 107, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 2, 134, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 3, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 4, 20, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 5, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 6, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 7, 151, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 8, 37, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 9, 65, 78, 5, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 10, 176, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 11, 7, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 12, 86, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100312017824, 13, 100, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 1, 148, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 2, 166, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 3, 141, 44, 12, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 4, 48, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 5, 6, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 6, 104, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 7, 169, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 8, 69, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 9, 28, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 10, 164, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 11, 142, 53, 13, 689);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090814017825, 12, 119, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123017826, 1, 128, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123017826, 2, 103, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123017826, 3, 86, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010123017826, 4, 167, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 1, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 2, 70, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 3, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 4, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 5, 95, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 6, 24, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030906017827, 7, 139, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 1, 20, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 2, 73, 92, 6, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 3, 97, 12, 6, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 4, 130, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 5, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 6, 81, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 7, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 8, 38, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 9, 34, 72, 5, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 10, 40, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 11, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 12, 137, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 13, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 14, 73, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120217017828, 15, 129, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 1, 172, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 2, 76, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 3, 96, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 4, 100, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 5, 2, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 6, 135, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 7, 8, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040220017829, 8, 156, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 1, 93, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 2, 145, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 3, 34, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 4, 185, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 5, 74, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 6, 23, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 7, 63, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 8, 126, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 9, 41, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050405017830, 10, 49, 19, 6, 114);
commit;
prompt 180000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 1, 85, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 2, 50, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 3, 160, 26, 17, 442);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 4, 154, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 5, 32, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 6, 13, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 7, 68, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 8, 169, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060402017831, 9, 122, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 1, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 2, 13, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 3, 154, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 4, 38, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 5, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 6, 31, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040928017832, 7, 181, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 1, 95, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 2, 62, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 3, 144, 5, 15, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 4, 166, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 5, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 6, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030130017833, 7, 161, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 1, 155, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 2, 143, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 3, 110, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 4, 35, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 5, 21, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 6, 151, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 7, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 8, 67, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070319017834, 9, 24, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 1, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 2, 152, 83, 16, 1328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 3, 147, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 4, 74, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 5, 5, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 6, 103, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 7, 38, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 8, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 9, 123, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 10, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070809017835, 11, 134, 56, 12, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 1, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 2, 62, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 3, 153, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 4, 173, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 5, 17, 70, 5, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 6, 75, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 7, 113, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 8, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 9, 86, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 10, 179, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 11, 102, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 12, 23, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 13, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 14, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110823017836, 15, 90, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 1, 80, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 2, 41, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 3, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 4, 171, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 5, 171, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 6, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 7, 169, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 8, 32, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 9, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 10, 46, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 11, 127, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 12, 116, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110820017837, 13, 85, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 1, 154, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 2, 153, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 3, 62, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 4, 65, 36, 5, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 5, 158, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 6, 115, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 7, 191, 21, 17, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 8, 125, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 9, 23, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 10, 135, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 11, 91, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 12, 134, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 13, 164, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017838, 14, 177, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 1, 52, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 2, 182, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 3, 172, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 4, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 5, 180, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 6, 46, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 7, 84, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 8, 98, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 9, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 10, 35, 62, 6, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 11, 167, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 12, 126, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110829017839, 13, 138, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111017840, 1, 187, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111017840, 2, 23, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111017840, 3, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011111017840, 4, 13, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 1, 67, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 2, 67, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 3, 161, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 4, 22, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 5, 78, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 6, 66, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 7, 189, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 8, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 9, 51, 56, 8, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 10, 121, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 11, 50, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 12, 101, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 13, 116, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091026017841, 14, 72, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208017842, 1, 62, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208017842, 2, 64, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208017842, 3, 135, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001208017842, 4, 66, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 1, 100, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 2, 138, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 3, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 4, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 5, 57, 95, 7, 665);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 6, 92, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 7, 174, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 8, 163, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 9, 74, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050705017843, 10, 63, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 1, 111, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 2, 180, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 3, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 4, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 5, 62, 33, 12, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040911017844, 6, 23, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 1, 78, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 2, 114, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 3, 183, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 4, 179, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 5, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 6, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 7, 125, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 8, 19, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 9, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 10, 48, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 11, 66, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 12, 118, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 13, 114, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 14, 137, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 15, 160, 42, 17, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110809017845, 16, 56, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 1, 109, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 2, 63, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 3, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 4, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 5, 27, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 6, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 7, 38, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 8, 6, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050313017846, 9, 80, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 1, 142, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 2, 77, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 3, 8, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 4, 18, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 5, 75, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 6, 61, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 7, 48, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 8, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 9, 134, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 10, 48, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 11, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 12, 119, 38, 14, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 13, 160, 47, 17, 799);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 14, 139, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 15, 178, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 16, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017847, 17, 151, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 1, 177, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 2, 120, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 3, 1, 17, 3, 51);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 4, 3, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 5, 47, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 6, 81, 35, 7, 245);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 7, 106, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 8, 86, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050629017848, 9, 110, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 1, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 2, 34, 98, 5, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 3, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 4, 11, 77, 6, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 5, 173, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011013017849, 6, 33, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519017850, 1, 119, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519017850, 2, 170, 7, 10, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519017850, 3, 117, 58, 12, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519017850, 4, 159, 99, 16, 1584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030519017850, 5, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 1, 113, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 2, 87, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 3, 75, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 4, 179, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 5, 135, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 6, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 7, 132, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 8, 4, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 9, 150, 74, 14, 1036);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 10, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 11, 139, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 12, 80, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 13, 135, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110111017851, 14, 144, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 1, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 2, 120, 41, 15, 615);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 3, 181, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 4, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 5, 11, 54, 6, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 6, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 7, 114, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 8, 148, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 9, 9, 96, 4, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 10, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 11, 156, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 12, 56, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101020017852, 13, 39, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231017853, 1, 7, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231017853, 2, 54, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231017853, 3, 98, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011231017853, 4, 38, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 1, 27, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 2, 131, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 3, 133, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 4, 79, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 5, 52, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 6, 149, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 7, 158, 39, 15, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 8, 146, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 9, 72, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 10, 159, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 11, 155, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 12, 160, 68, 17, 1156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 13, 169, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 14, 112, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 15, 30, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110529017854, 16, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421017855, 1, 177, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421017855, 2, 149, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000421017855, 3, 35, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 1, 169, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 2, 4, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 3, 116, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 4, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 5, 4, 20, 6, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 6, 51, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 7, 162, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 8, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 9, 56, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 10, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 11, 139, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 12, 105, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 13, 177, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120414017856, 14, 13, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 1, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 2, 149, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 3, 127, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 4, 10, 22, 5, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 5, 110, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 6, 54, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 7, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 8, 12, 99, 7, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 9, 64, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 10, 112, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 11, 113, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 12, 154, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 13, 17, 79, 5, 395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 14, 105, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 15, 114, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 16, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130731017857, 17, 137, 5, 8, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 1, 97, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 2, 150, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 3, 43, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 4, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 5, 175, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 6, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 7, 75, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 8, 95, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 9, 130, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 10, 47, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 11, 166, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 12, 151, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 13, 79, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 14, 129, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 15, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130325017858, 16, 36, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 1, 36, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 2, 78, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 3, 3, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 4, 55, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 5, 44, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 6, 91, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 7, 55, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 8, 70, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 9, 98, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 10, 122, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 11, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 12, 105, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 13, 69, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 14, 58, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 15, 57, 5, 7, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 16, 57, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 17, 8, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140401017859, 18, 13, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 1, 49, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 2, 132, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 3, 6, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 4, 50, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 5, 157, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 6, 54, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 7, 41, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 8, 104, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 9, 135, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071123017860, 10, 60, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 1, 43, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 2, 91, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 3, 167, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 4, 42, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 5, 115, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 6, 92, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 7, 44, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 8, 3, 77, 5, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 9, 35, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 10, 49, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080405017861, 11, 22, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 1, 147, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 2, 62, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 3, 128, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 4, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 5, 163, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 6, 153, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 7, 13, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 8, 7, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 9, 190, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 10, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 11, 152, 16, 16, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 12, 146, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080818017862, 13, 119, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 1, 109, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 2, 43, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 3, 2, 75, 4, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 4, 23, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 5, 24, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 6, 63, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 7, 174, 83, 14, 1162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 8, 188, 88, 14, 1232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 9, 189, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 10, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080516017863, 11, 14, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 1, 174, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 2, 169, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 3, 53, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 4, 14, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 5, 153, 64, 10, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020217017864, 6, 35, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218017865, 1, 135, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218017865, 2, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218017865, 3, 143, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218017865, 4, 40, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020218017865, 5, 125, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 1, 15, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 2, 120, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 3, 97, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 4, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 5, 101, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 6, 3, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 7, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050315017866, 8, 70, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 1, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 2, 29, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 3, 126, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 4, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 5, 151, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 6, 66, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040907017867, 7, 51, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 1, 48, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 2, 149, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 3, 159, 5, 16, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 4, 190, 4, 16, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 5, 4, 89, 6, 534);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 6, 105, 27, 7, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 7, 136, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 8, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 9, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 10, 120, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070818017868, 11, 178, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 1, 104, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 2, 120, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 3, 98, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 4, 130, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 5, 47, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 6, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 7, 35, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 8, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 9, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 10, 27, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 11, 185, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 12, 25, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 13, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 14, 134, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 15, 8, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 16, 4, 32, 6, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130616017869, 17, 73, 45, 6, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 1, 151, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 2, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 3, 188, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 4, 39, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 5, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 6, 13, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 7, 173, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040725017870, 8, 178, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113017871, 1, 118, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113017871, 2, 61, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113017871, 3, 160, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113017871, 4, 15, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020113017871, 5, 52, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 1, 96, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 2, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 3, 60, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 4, 56, 38, 13, 494);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 5, 144, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 6, 187, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 7, 87, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 8, 147, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 9, 10, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 10, 74, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080325017872, 11, 79, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 1, 123, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 2, 191, 78, 17, 1326);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 3, 25, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 4, 13, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 5, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 6, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 7, 132, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 8, 66, 59, 6, 354);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 9, 141, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 10, 103, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 11, 41, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 12, 2, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 13, 125, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 14, 94, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 15, 13, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 16, 121, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130419017873, 17, 1, 31, 3, 93);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 1, 131, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 2, 105, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 3, 87, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 4, 75, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 5, 23, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 6, 181, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 7, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 8, 147, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 9, 56, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 10, 93, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 11, 38, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 12, 133, 67, 11, 737);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 13, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100711017874, 14, 159, 24, 16, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 1, 61, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 2, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 3, 98, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 4, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 5, 177, 56, 10, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 6, 95, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030327017875, 7, 5, 74, 7, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 1, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 2, 98, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 3, 75, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 4, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 5, 130, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 6, 176, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 7, 45, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 8, 43, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 9, 126, 64, 14, 896);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 10, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 11, 174, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080201017876, 12, 9, 63, 4, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 1, 84, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 2, 162, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 3, 38, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 4, 126, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 5, 131, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 6, 139, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 7, 82, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050623017877, 8, 191, 90, 17, 1530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017878, 1, 117, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017878, 2, 65, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017878, 3, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017878, 4, 80, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408017879, 1, 166, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408017879, 2, 58, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408017879, 3, 72, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010408017879, 4, 90, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525017880, 1, 155, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525017880, 2, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525017880, 3, 39, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525017880, 4, 8, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020525017880, 5, 48, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 1, 184, 61, 17, 1037);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 2, 144, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 3, 113, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 4, 139, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 5, 71, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020924017881, 6, 117, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 1, 116, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 2, 52, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 3, 89, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 4, 151, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 5, 139, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040609017882, 6, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 1, 103, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 2, 167, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 3, 17, 24, 5, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 4, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 5, 48, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 6, 16, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 7, 99, 97, 8, 776);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040727017883, 8, 163, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 1, 50, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 2, 63, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 3, 137, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 4, 5, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 5, 59, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 6, 112, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 7, 182, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060713017884, 8, 125, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 1, 52, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 2, 94, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 3, 77, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 4, 137, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 5, 104, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 6, 6, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 7, 59, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 8, 47, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 9, 171, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 10, 75, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 11, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 12, 38, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100309017885, 13, 140, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 1, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 2, 114, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 3, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 4, 137, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 5, 115, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030318017886, 6, 99, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 1, 176, 54, 16, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 2, 56, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 3, 96, 99, 15, 1485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 4, 115, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 5, 157, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 6, 128, 73, 16, 1168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 7, 29, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 8, 181, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 9, 4, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 10, 19, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 11, 84, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090501017887, 12, 16, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 1, 121, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 2, 124, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 3, 98, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 4, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 5, 76, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 6, 87, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 7, 130, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 8, 3, 23, 5, 115);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 9, 61, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 10, 88, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 11, 115, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 12, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 13, 99, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110315017888, 14, 134, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 1, 123, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 2, 43, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 3, 107, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 4, 173, 23, 13, 299);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 5, 119, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 6, 138, 73, 9, 657);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 7, 35, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 8, 178, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 9, 152, 34, 16, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 10, 93, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 11, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070515017889, 12, 29, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 1, 140, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 2, 62, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 3, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 4, 86, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 5, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041114017890, 6, 103, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 1, 75, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 2, 70, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 3, 6, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 4, 107, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 5, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 6, 126, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 7, 153, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 8, 119, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 9, 184, 23, 17, 391);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 10, 27, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 11, 163, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 12, 175, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 13, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110305017891, 14, 45, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 1, 98, 93, 7, 651);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 2, 71, 11, 11, 121);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 3, 111, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 4, 5, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 5, 187, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 6, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 7, 13, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 8, 136, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 9, 128, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017892, 10, 120, 44, 15, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017893, 1, 147, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017893, 2, 136, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017893, 3, 137, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017893, 4, 52, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030522017893, 5, 67, 90, 7, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 1, 6, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 2, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 3, 73, 64, 6, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 4, 23, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 5, 55, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 6, 7, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 7, 183, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 8, 135, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 9, 133, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 10, 156, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 11, 116, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 12, 47, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 13, 46, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111019017894, 14, 114, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 1, 47, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 2, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 3, 54, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 4, 169, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 5, 127, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 6, 105, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 7, 61, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 8, 54, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 9, 137, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 10, 22, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 11, 34, 76, 5, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 12, 51, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 13, 41, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 14, 28, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110104017895, 15, 124, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 1, 23, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 2, 189, 66, 15, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 3, 126, 57, 14, 798);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 4, 137, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 5, 183, 62, 16, 992);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 6, 161, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 7, 88, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 8, 131, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 9, 156, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 10, 183, 82, 16, 1312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 11, 88, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 12, 146, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 13, 177, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 14, 140, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 15, 68, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120307017896, 16, 10, 68, 5, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 1, 135, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 2, 170, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 3, 114, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 4, 136, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 5, 92, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 6, 17, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 7, 148, 67, 12, 804);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 8, 171, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 9, 80, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 10, 9, 55, 4, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 11, 136, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070806017897, 12, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 1, 110, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 2, 55, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 3, 113, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 4, 169, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 5, 100, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 6, 178, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 7, 173, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 8, 21, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 9, 56, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 10, 157, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 11, 137, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 12, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101125017898, 13, 1, 25, 3, 75);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 1, 70, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 2, 83, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 3, 81, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 4, 131, 81, 9, 729);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 5, 108, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 6, 27, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 7, 4, 23, 6, 138);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 8, 172, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060806017899, 9, 20, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 1, 6, 75, 8, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 2, 110, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 3, 142, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 4, 183, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 5, 47, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 6, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 7, 67, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 8, 112, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070207017900, 9, 127, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 1, 138, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 2, 61, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 3, 6, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 4, 122, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 5, 149, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 6, 187, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 7, 156, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 8, 74, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 9, 11, 75, 6, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060120017901, 10, 26, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 1, 59, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 2, 146, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 3, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 4, 30, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 5, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 6, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 7, 63, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 8, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051219017902, 9, 68, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 1, 119, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 2, 79, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 3, 167, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 4, 169, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 5, 34, 3, 5, 15);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 6, 159, 8, 16, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 7, 105, 65, 7, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041222017903, 8, 58, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804017904, 1, 26, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804017904, 2, 48, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804017904, 3, 78, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804017904, 4, 92, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020804017904, 5, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 1, 5, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 2, 21, 33, 9, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 3, 56, 2, 13, 26);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 4, 28, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 5, 123, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 6, 88, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 7, 18, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 8, 40, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 9, 50, 92, 7, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060102017905, 10, 127, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921017906, 1, 66, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921017906, 2, 87, 74, 13, 962);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921017906, 3, 39, 70, 10, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010921017906, 4, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 1, 61, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 2, 6, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 3, 111, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 4, 49, 93, 6, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 5, 22, 22, 10, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 6, 160, 14, 17, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 7, 24, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050928017907, 8, 77, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 1, 175, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 2, 6, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 3, 161, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 4, 150, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 5, 108, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 6, 13, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 7, 164, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 8, 3, 50, 5, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 9, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071130017908, 10, 10, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 1, 164, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 2, 144, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 3, 149, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 4, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 5, 96, 19, 15, 285);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 6, 31, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 7, 154, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050813017909, 8, 27, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 1, 122, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 2, 44, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 3, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 4, 67, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 5, 58, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 6, 120, 79, 15, 1185);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 7, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 8, 184, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040710017910, 9, 64, 44, 14, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216017911, 1, 151, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216017911, 2, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216017911, 3, 158, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216017911, 4, 70, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000216017911, 5, 184, 53, 17, 901);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 1, 60, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 2, 43, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 3, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 4, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 5, 108, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030419017912, 6, 110, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 1, 51, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 2, 110, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 3, 162, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 4, 89, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 5, 159, 15, 16, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 6, 177, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 7, 126, 73, 14, 1022);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 8, 52, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 9, 106, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 10, 57, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 11, 147, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080131017913, 12, 24, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 1, 171, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 3, 154, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 4, 13, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 5, 111, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 6, 21, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017914, 7, 82, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 1, 99, 11, 8, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 2, 184, 54, 17, 918);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 3, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 4, 99, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 5, 74, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 6, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 7, 37, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 8, 136, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 9, 181, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 10, 15, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 11, 58, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 12, 29, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110703017915, 13, 71, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 1, 137, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 2, 166, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 3, 31, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 4, 50, 69, 7, 483);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 5, 141, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021023017916, 6, 83, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 1, 176, 38, 16, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 2, 86, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 3, 22, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 4, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 5, 134, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020731017917, 6, 152, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 1, 66, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 2, 9, 73, 4, 292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 3, 89, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 4, 174, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 5, 176, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 6, 158, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 7, 108, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050515017918, 8, 44, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 1, 21, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 2, 71, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 3, 176, 81, 16, 1296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 4, 175, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 5, 166, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 6, 119, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 7, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 8, 48, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 9, 38, 53, 9, 477);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 10, 161, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 11, 52, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 12, 129, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 13, 152, 17, 16, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 14, 128, 79, 16, 1264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131119017919, 15, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 1, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 2, 162, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 3, 148, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 4, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 5, 64, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 6, 140, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 7, 87, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 8, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 9, 70, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 10, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 11, 123, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 12, 144, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 13, 155, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 14, 18, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 15, 90, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120126017920, 16, 38, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 1, 169, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 2, 33, 41, 4, 164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 3, 192, 20, 18, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 4, 24, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 5, 104, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 6, 6, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 7, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040726017921, 8, 92, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 1, 76, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 2, 172, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 3, 157, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 4, 161, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 5, 66, 60, 6, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 6, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 7, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 8, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 9, 83, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070614017922, 10, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025017923, 1, 100, 16, 9, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025017923, 2, 124, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025017923, 3, 188, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001025017923, 4, 181, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017924, 1, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017924, 2, 139, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000811017924, 3, 127, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 1, 95, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 2, 97, 68, 6, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 3, 34, 61, 5, 305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 4, 120, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 5, 10, 53, 5, 265);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 6, 185, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 7, 115, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 8, 113, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 9, 51, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 10, 20, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 11, 35, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 12, 29, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 13, 19, 59, 7, 413);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 14, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 15, 74, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110509017925, 16, 27, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 1, 71, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 2, 192, 10, 18, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 3, 56, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 4, 86, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 5, 96, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 6, 70, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 7, 184, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 8, 152, 78, 16, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 9, 99, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 10, 120, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 11, 25, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 12, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 13, 58, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100103017926, 14, 146, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 1, 113, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 2, 106, 45, 8, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 3, 105, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 4, 130, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 5, 99, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 6, 11, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 7, 123, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 8, 172, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 9, 146, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 10, 158, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 11, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 12, 128, 33, 16, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090909017927, 13, 146, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 1, 136, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 2, 20, 41, 8, 328);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 3, 40, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 4, 88, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 5, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 6, 123, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 7, 190, 68, 16, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 8, 87, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 9, 100, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 10, 109, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 11, 74, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 12, 120, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 13, 67, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 14, 100, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 15, 148, 63, 12, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131112017928, 16, 184, 48, 17, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 1, 67, 18, 7, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 2, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 3, 45, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 4, 93, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 5, 32, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 6, 163, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 7, 77, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 8, 61, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 9, 80, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 10, 10, 66, 5, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080912017929, 11, 119, 78, 14, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 1, 55, 27, 12, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 2, 19, 82, 7, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 3, 49, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 4, 121, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 5, 34, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 6, 146, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 7, 127, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 8, 85, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 9, 88, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 10, 125, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 11, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 12, 68, 52, 8, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 13, 51, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 14, 46, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 15, 100, 76, 9, 684);
commit;
prompt 181000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131222017930, 16, 178, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 1, 151, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 2, 4, 70, 6, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 3, 31, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 4, 186, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 5, 164, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 6, 98, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 7, 52, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 8, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 9, 147, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 10, 105, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 11, 65, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 12, 149, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 13, 107, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 14, 17, 91, 5, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130203017931, 15, 148, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 1, 23, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 2, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 3, 171, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 4, 6, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 5, 50, 71, 7, 497);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 6, 168, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 7, 101, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 8, 69, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 9, 127, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 10, 98, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 11, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 12, 20, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 13, 178, 19, 11, 209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 14, 177, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 15, 154, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 16, 127, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 17, 136, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130901017932, 18, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 1, 23, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 2, 59, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 3, 165, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 4, 110, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 5, 173, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 6, 150, 96, 14, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 7, 15, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 8, 9, 62, 4, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060826017933, 9, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 1, 185, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 2, 36, 100, 7, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 3, 189, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 4, 149, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 5, 135, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 6, 19, 39, 7, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 7, 18, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 8, 66, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 9, 182, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 10, 182, 59, 15, 885);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 11, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 12, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091213017934, 13, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 1, 90, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 2, 58, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 3, 57, 25, 7, 175);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 4, 122, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 5, 53, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 6, 191, 41, 17, 697);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 7, 167, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 8, 80, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 9, 190, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 10, 101, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 11, 86, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 12, 23, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 13, 57, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 14, 29, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 15, 91, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017935, 16, 155, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 1, 96, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 2, 88, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 3, 16, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 4, 87, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 5, 156, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 6, 147, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 7, 45, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 8, 63, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 9, 20, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 10, 146, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 11, 87, 46, 13, 598);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080410017936, 12, 147, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 1, 130, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 2, 39, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 3, 126, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 4, 62, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 5, 168, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 6, 5, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 7, 96, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 8, 63, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 9, 68, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 10, 74, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060417017937, 11, 43, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 1, 10, 93, 5, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 2, 52, 31, 9, 279);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 3, 74, 75, 7, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 4, 83, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 5, 171, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 6, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 7, 156, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 8, 171, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 9, 29, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 10, 108, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 11, 38, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 12, 127, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 13, 56, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 14, 176, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 15, 32, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140414017938, 16, 99, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 1, 59, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 2, 174, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 3, 57, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 4, 27, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 5, 47, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 6, 102, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030724017939, 7, 149, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 1, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 2, 29, 54, 10, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 3, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 4, 171, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 5, 74, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020904017940, 6, 151, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 1, 171, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 2, 44, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 3, 9, 21, 4, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 4, 130, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 5, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 6, 6, 8, 8, 64);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 7, 117, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051208017941, 8, 111, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620017942, 1, 45, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620017942, 2, 17, 80, 5, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620017942, 3, 4, 48, 6, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010620017942, 4, 57, 47, 7, 329);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 1, 51, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 2, 192, 27, 18, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 3, 153, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 4, 15, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 5, 118, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 6, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 7, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 8, 73, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 9, 84, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 10, 88, 30, 14, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 11, 178, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 12, 154, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110617017943, 13, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107017944, 1, 18, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107017944, 2, 5, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107017944, 3, 70, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000107017944, 4, 165, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017945, 1, 4, 57, 6, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017945, 2, 35, 5, 6, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000820017945, 3, 176, 96, 16, 1536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 1, 71, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 2, 121, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 3, 1, 32, 3, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 4, 62, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 5, 32, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 6, 122, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 7, 79, 85, 12, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 8, 160, 66, 17, 1122);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 9, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 10, 134, 95, 12, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 11, 31, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 12, 96, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 13, 162, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 14, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 15, 19, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017946, 16, 54, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 1, 133, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 2, 65, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 3, 94, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 4, 134, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 5, 163, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 6, 116, 92, 11, 1012);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 7, 118, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 8, 16, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 9, 154, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 10, 41, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 11, 183, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 12, 19, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 13, 115, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 14, 29, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 15, 22, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 16, 17, 54, 5, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140308017947, 17, 138, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 1, 31, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 2, 91, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 3, 45, 24, 9, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 4, 98, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 5, 30, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 6, 111, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 7, 168, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 8, 135, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 9, 56, 28, 13, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 10, 94, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 11, 115, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 12, 150, 9, 14, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 13, 108, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 14, 102, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 15, 67, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 16, 150, 56, 14, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130521017948, 17, 102, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 1, 157, 50, 14, 700);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 2, 185, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 3, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 4, 16, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 5, 158, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 6, 93, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 7, 185, 16, 11, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 8, 83, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 9, 139, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 10, 1, 6, 3, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 11, 111, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 12, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 13, 131, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 14, 106, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 15, 13, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 16, 56, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140102017949, 17, 150, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207017950, 1, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207017950, 2, 106, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011207017950, 3, 69, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 1, 19, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 2, 62, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 3, 132, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 4, 96, 49, 15, 735);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 5, 99, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 6, 62, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 7, 71, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 8, 116, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 9, 119, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 10, 8, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070212017951, 11, 122, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 1, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 2, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 3, 18, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 4, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 5, 87, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031109017952, 6, 126, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 1, 166, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 2, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 3, 64, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 4, 55, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 5, 118, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 6, 106, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 7, 88, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 8, 75, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 9, 103, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 10, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 11, 18, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 12, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100923017953, 13, 58, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 1, 98, 44, 7, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 2, 37, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 3, 191, 70, 17, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 4, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 5, 73, 9, 6, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 6, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 7, 104, 89, 13, 1157);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 8, 182, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 9, 189, 91, 15, 1365);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 10, 61, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 11, 160, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 12, 159, 2, 16, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 13, 33, 5, 4, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 14, 73, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 15, 187, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120724017954, 16, 123, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822017955, 1, 173, 60, 13, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822017955, 2, 22, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822017955, 3, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000822017955, 4, 24, 98, 12, 1176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 1, 107, 72, 9, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 2, 153, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 3, 56, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 4, 130, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 5, 109, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 6, 187, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 7, 42, 86, 6, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 8, 81, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051109017956, 9, 90, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 1, 148, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 2, 185, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 3, 172, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 4, 132, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 5, 115, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 6, 101, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 7, 18, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 8, 63, 52, 13, 676);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 9, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 10, 24, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 11, 23, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 12, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091226017957, 13, 63, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 1, 189, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 2, 132, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 3, 6, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 4, 11, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 5, 14, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 6, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 7, 114, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 8, 37, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 9, 96, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 10, 112, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 11, 174, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 12, 77, 73, 10, 730);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 13, 20, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 14, 150, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 15, 163, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110906017958, 16, 184, 36, 17, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 1, 11, 38, 6, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 2, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 3, 121, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 4, 48, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 5, 124, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 6, 120, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 7, 4, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060407017959, 8, 130, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 1, 90, 20, 9, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 2, 168, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 3, 3, 41, 5, 205);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 4, 97, 46, 6, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 5, 82, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 6, 175, 28, 15, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050712017960, 7, 109, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 1, 125, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 2, 68, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 3, 141, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 4, 50, 81, 7, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 5, 60, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020324017961, 6, 85, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017962, 1, 151, 9, 15, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017962, 2, 21, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017962, 3, 79, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017962, 4, 117, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030805017962, 5, 189, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 1, 49, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 2, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 3, 78, 45, 11, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 4, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 5, 187, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 6, 95, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 7, 144, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 8, 75, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 9, 68, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 10, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 11, 38, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080330017963, 12, 163, 86, 10, 860);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 1, 135, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 2, 81, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 3, 61, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 4, 54, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 5, 149, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 6, 181, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 7, 122, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 8, 155, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 9, 121, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 10, 182, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 11, 112, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 12, 13, 100, 8, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 13, 100, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 14, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 15, 93, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120312017964, 16, 158, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 1, 116, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 2, 69, 52, 9, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 3, 173, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 4, 73, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 5, 35, 8, 6, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 6, 56, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 7, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 8, 82, 44, 8, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 9, 34, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081123017965, 10, 102, 22, 11, 242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 1, 20, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 2, 76, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 3, 185, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 4, 46, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 5, 32, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 6, 101, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 7, 63, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 8, 146, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 9, 69, 82, 9, 738);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 10, 158, 57, 15, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 11, 172, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 12, 126, 99, 14, 1386);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 13, 68, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 14, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 15, 132, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 16, 92, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130613017966, 17, 22, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 1, 45, 61, 9, 549);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 2, 67, 19, 7, 133);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 3, 24, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 4, 38, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 5, 44, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 6, 8, 50, 10, 500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 7, 151, 20, 15, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 8, 87, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 9, 86, 9, 12, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 10, 182, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 11, 125, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 12, 136, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091101017967, 13, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017968, 1, 55, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017968, 2, 185, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017968, 3, 1, 69, 3, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017968, 4, 166, 72, 13, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030108017968, 5, 181, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 1, 102, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 2, 62, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 3, 165, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 4, 181, 11, 14, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 5, 178, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 6, 98, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 7, 107, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 8, 29, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 9, 92, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 10, 37, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20091217017969, 11, 9, 19, 4, 76);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 1, 84, 100, 10, 1000);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 2, 106, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 3, 178, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 4, 103, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 5, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 6, 22, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 7, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 8, 164, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 9, 138, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 10, 159, 60, 16, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 11, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090429017970, 12, 78, 21, 11, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 1, 177, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 2, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 3, 164, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 4, 89, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 5, 188, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 6, 186, 92, 12, 1104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 7, 44, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050916017971, 8, 52, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 1, 3, 25, 5, 125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 2, 21, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 3, 95, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 4, 160, 24, 17, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 5, 188, 31, 14, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 6, 163, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 7, 190, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 8, 180, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 9, 110, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 10, 130, 31, 8, 248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 11, 158, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070402017972, 12, 182, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017973, 1, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017973, 2, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017973, 3, 129, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017973, 4, 170, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017973, 5, 153, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017974, 1, 52, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017974, 2, 166, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017974, 3, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017974, 4, 20, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010301017974, 5, 59, 71, 9, 639);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621017975, 1, 155, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621017975, 2, 169, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621017975, 3, 119, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020621017975, 4, 125, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 1, 129, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 2, 4, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 3, 111, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 4, 112, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 5, 161, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 6, 25, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 7, 69, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 8, 115, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 9, 66, 94, 6, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 10, 134, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 11, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 12, 14, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 13, 122, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100717017976, 14, 117, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028017977, 1, 82, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028017977, 2, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028017977, 3, 57, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028017977, 4, 8, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001028017977, 5, 77, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 1, 114, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 2, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 3, 68, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 4, 109, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 5, 57, 63, 7, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 6, 191, 64, 17, 1088);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 7, 88, 47, 14, 658);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050520017978, 8, 82, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 1, 120, 3, 15, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 2, 181, 35, 14, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 3, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 4, 149, 93, 13, 1209);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 5, 129, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 6, 44, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 7, 47, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 8, 79, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 9, 87, 88, 13, 1144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 10, 127, 6, 15, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 11, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 12, 121, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 13, 87, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 14, 102, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 15, 42, 90, 6, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 16, 70, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 17, 119, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130424017979, 18, 179, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 1, 102, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 2, 166, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 3, 9, 65, 4, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 4, 176, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 5, 166, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 6, 114, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 7, 31, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 8, 14, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 9, 91, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 10, 45, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 11, 27, 92, 8, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 12, 56, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 13, 31, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 14, 31, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 15, 133, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130220017980, 16, 72, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 1, 129, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 2, 22, 51, 10, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 3, 68, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 4, 13, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 5, 12, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 6, 44, 4, 8, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 7, 26, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 8, 22, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 9, 108, 4, 10, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 10, 133, 87, 11, 957);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 11, 5, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 12, 140, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 13, 55, 72, 12, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110516017981, 14, 127, 88, 15, 1320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 1, 71, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 2, 87, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 3, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 4, 187, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 5, 64, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 6, 168, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 7, 26, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 8, 5, 41, 7, 287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 9, 20, 67, 8, 536);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 10, 179, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 11, 152, 39, 16, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 12, 183, 47, 16, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 13, 147, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 14, 42, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120607017982, 15, 95, 33, 14, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 1, 95, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 2, 145, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 3, 139, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 4, 169, 75, 9, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 5, 53, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 6, 119, 14, 14, 196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 7, 132, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 8, 62, 82, 12, 984);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 9, 42, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 10, 156, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 11, 56, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 12, 69, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 13, 90, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 14, 185, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304017600, 2, 162, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304017600, 3, 106, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020304017600, 4, 21, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 1, 33, 14, 4, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 2, 176, 51, 16, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 3, 161, 20, 8, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 4, 25, 6, 6, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 5, 145, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 6, 7, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 7, 58, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050614017601, 8, 95, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017602, 1, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017602, 2, 72, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017602, 3, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017602, 4, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609017603, 1, 186, 76, 12, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609017603, 2, 75, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000609017603, 3, 116, 83, 11, 913);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 1, 172, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 2, 6, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 3, 141, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 4, 98, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 5, 189, 69, 15, 1035);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 6, 167, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 7, 163, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 8, 27, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 9, 44, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 10, 89, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 11, 31, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 12, 181, 69, 14, 966);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 13, 64, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 14, 60, 12, 10, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 15, 124, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130503017604, 16, 123, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214017605, 1, 166, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214017605, 2, 189, 43, 15, 645);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214017605, 3, 138, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214017605, 4, 125, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011214017605, 5, 67, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701017606, 1, 17, 2, 5, 10);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701017606, 2, 83, 21, 9, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701017606, 3, 44, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000701017606, 4, 65, 48, 5, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 1, 160, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 2, 9, 71, 4, 284);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 3, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 4, 134, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 5, 89, 12, 8, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 6, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050522017607, 7, 21, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 1, 126, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 2, 161, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 3, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 4, 44, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 5, 120, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040420017608, 6, 133, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 1, 44, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 2, 106, 10, 8, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 3, 33, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 4, 113, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 5, 79, 50, 12, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 6, 36, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 7, 84, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 8, 6, 80, 8, 640);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 9, 189, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 10, 179, 32, 12, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071116017609, 11, 161, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 1, 35, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 2, 150, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 3, 64, 71, 14, 994);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 4, 163, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 5, 63, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 6, 149, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 7, 87, 35, 13, 455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041009017610, 8, 147, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 1, 188, 48, 14, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 2, 166, 56, 13, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 3, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 4, 53, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 5, 186, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 6, 53, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 7, 113, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 8, 87, 12, 13, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 9, 68, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 10, 30, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 11, 86, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 12, 49, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 13, 11, 58, 6, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 14, 46, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 15, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130316017611, 16, 49, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 1, 62, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 2, 130, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 3, 63, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 4, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 5, 43, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 6, 132, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 7, 153, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 8, 66, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 9, 130, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 10, 7, 7, 9, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 11, 20, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 12, 67, 85, 7, 595);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 13, 101, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100417017612, 14, 132, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204017613, 1, 151, 24, 15, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204017613, 2, 108, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000204017613, 3, 158, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408017614, 1, 94, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000408017614, 2, 84, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017615, 1, 12, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017615, 2, 161, 21, 8, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017615, 3, 69, 28, 9, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017615, 4, 64, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010504017615, 5, 182, 36, 15, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017616, 1, 15, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017616, 2, 6, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017616, 3, 164, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017616, 4, 84, 59, 10, 590);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000723017616, 5, 71, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 1, 7, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 2, 38, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 3, 6, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 4, 98, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 5, 81, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 6, 41, 7, 5, 35);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 7, 31, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040110017617, 8, 121, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 1, 177, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 2, 8, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 3, 161, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 4, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 5, 157, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 6, 70, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 7, 29, 15, 10, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 8, 13, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 9, 84, 47, 10, 470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 10, 127, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080213017618, 11, 78, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 1, 123, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 2, 38, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 3, 112, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 4, 167, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 5, 112, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 6, 47, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 7, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 8, 50, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 9, 176, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 10, 24, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 11, 71, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 12, 54, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090326017619, 13, 130, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 1, 6, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 2, 40, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 3, 86, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 4, 188, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 5, 57, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 6, 73, 95, 6, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 7, 86, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 8, 138, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 9, 147, 75, 11, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 10, 40, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071221017620, 11, 30, 81, 11, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 1, 57, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 2, 176, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 3, 87, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 4, 79, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 5, 66, 44, 6, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 6, 115, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040915017621, 7, 82, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 1, 155, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 2, 34, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 3, 144, 84, 15, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 4, 170, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 5, 112, 75, 14, 1050);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 6, 66, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 7, 182, 32, 15, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 8, 129, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 9, 8, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 10, 184, 77, 17, 1309);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 11, 122, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100529017622, 12, 169, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 1, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 2, 110, 62, 12, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 3, 76, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 4, 141, 54, 12, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 5, 114, 19, 9, 171);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 6, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 7, 156, 79, 13, 1027);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 8, 103, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 9, 109, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 10, 159, 64, 16, 1024);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 11, 54, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101111017623, 12, 7, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 1, 40, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 2, 6, 23, 8, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 3, 88, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 4, 187, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 5, 15, 41, 10, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 6, 104, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050418017624, 7, 68, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 1, 39, 31, 10, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 2, 136, 29, 14, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 3, 7, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 4, 12, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 5, 125, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 6, 122, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 7, 130, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 8, 121, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 9, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 10, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 11, 58, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 12, 181, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 13, 11, 37, 6, 222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 14, 138, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120229017625, 15, 60, 88, 10, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 1, 114, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 2, 51, 73, 8, 584);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 3, 130, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 4, 18, 25, 6, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 5, 125, 43, 13, 559);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020320017626, 6, 135, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 1, 28, 90, 9, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 2, 85, 3, 11, 33);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 3, 49, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 4, 82, 76, 8, 608);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 5, 66, 49, 6, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 6, 42, 39, 6, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050130017627, 7, 62, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 1, 46, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 2, 140, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 3, 25, 73, 6, 438);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 4, 110, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 5, 49, 19, 6, 114);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 6, 90, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 7, 120, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 8, 62, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 9, 155, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 10, 22, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120823017983, 15, 79, 53, 12, 636);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 1, 143, 76, 14, 1064);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 2, 188, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 3, 40, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 4, 78, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 5, 123, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 6, 18, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 7, 83, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 8, 59, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 9, 33, 39, 4, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 10, 107, 15, 9, 135);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 11, 184, 8, 17, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 12, 138, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090820017984, 13, 26, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 1, 129, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 2, 85, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 3, 141, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 4, 147, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 5, 62, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 6, 110, 23, 12, 276);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 7, 107, 10, 9, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 8, 64, 5, 14, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 9, 11, 3, 6, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 10, 152, 9, 16, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 11, 156, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071127017985, 12, 127, 61, 15, 915);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222017986, 1, 13, 65, 8, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222017986, 2, 16, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222017986, 3, 16, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222017986, 4, 157, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010222017986, 5, 38, 4, 9, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 1, 46, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 2, 22, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 3, 10, 92, 5, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 4, 185, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 5, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 6, 134, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 7, 142, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 8, 63, 26, 13, 338);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 9, 16, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 10, 47, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 11, 93, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 12, 9, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090102017987, 13, 55, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 1, 10, 62, 5, 310);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 2, 148, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 3, 25, 80, 6, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 4, 116, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 5, 185, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 6, 66, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 7, 23, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 8, 77, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 9, 56, 61, 13, 793);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 10, 53, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 11, 188, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 12, 124, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090727017988, 13, 100, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 1, 79, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 2, 56, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 3, 168, 54, 15, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 4, 131, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 5, 42, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 6, 144, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 7, 156, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 8, 9, 12, 4, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 9, 12, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 10, 122, 99, 10, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 11, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 12, 9, 8, 4, 32);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 13, 109, 27, 11, 297);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 14, 105, 70, 7, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110225017989, 15, 179, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 1, 136, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 2, 161, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 3, 56, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 4, 68, 35, 8, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 5, 27, 62, 8, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 6, 83, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 7, 181, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 8, 55, 77, 12, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 9, 162, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 10, 69, 23, 9, 207);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 11, 187, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101030017990, 12, 160, 76, 17, 1292);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 1, 101, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 2, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 3, 92, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 4, 78, 2, 11, 22);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 5, 47, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 6, 25, 15, 6, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 7, 112, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 8, 3, 97, 5, 485);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 9, 105, 32, 7, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 10, 103, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 11, 90, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 12, 54, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 13, 134, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110821017991, 14, 99, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 1, 98, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 2, 116, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 3, 18, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 4, 182, 65, 15, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 5, 51, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 6, 188, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017992, 7, 31, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 1, 22, 42, 10, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 2, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 3, 43, 33, 7, 231);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 4, 57, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 5, 143, 79, 14, 1106);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 6, 178, 48, 11, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 7, 144, 11, 15, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 8, 140, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 9, 129, 96, 7, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 10, 184, 62, 17, 1054);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 11, 156, 21, 13, 273);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 12, 99, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 13, 120, 22, 15, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 14, 43, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130724017993, 15, 161, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 1, 132, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 2, 80, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 3, 161, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 4, 17, 43, 5, 215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 5, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 6, 119, 22, 14, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030127017994, 7, 40, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 1, 25, 74, 6, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 2, 120, 2, 15, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 3, 147, 7, 11, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 4, 150, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 5, 31, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021027017995, 6, 138, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 1, 106, 6, 8, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 2, 74, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 3, 34, 82, 5, 410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 4, 140, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 5, 143, 42, 14, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020430017996, 6, 150, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810017997, 1, 181, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810017997, 2, 143, 61, 14, 854);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810017997, 3, 176, 52, 16, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810017997, 4, 50, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020810017997, 5, 20, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 1, 32, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 2, 111, 85, 13, 1105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 3, 33, 54, 4, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 4, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 5, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 6, 122, 25, 10, 250);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 7, 11, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 8, 57, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 9, 127, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 10, 174, 20, 14, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 11, 84, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 12, 63, 15, 13, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 13, 28, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 14, 190, 6, 16, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 15, 101, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 16, 73, 91, 6, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 17, 190, 36, 16, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140111017998, 18, 138, 35, 9, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 1, 142, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 2, 189, 67, 15, 1005);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 3, 146, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 4, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 5, 184, 49, 17, 833);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 6, 33, 32, 4, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 7, 57, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 8, 172, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 9, 105, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 10, 173, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 11, 107, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 12, 74, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 13, 30, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 14, 113, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110816017999, 15, 179, 91, 12, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011018000, 1, 38, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011018000, 2, 59, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001011018000, 3, 20, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 1, 42, 53, 6, 318);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 2, 177, 62, 10, 620);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 3, 7, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 4, 42, 99, 6, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 5, 69, 89, 9, 801);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020402018001, 6, 160, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 1, 58, 38, 8, 304);
commit;
prompt 182000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 2, 4, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 3, 132, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 4, 58, 42, 8, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 5, 191, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 6, 52, 51, 9, 459);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 7, 35, 41, 6, 246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 8, 114, 55, 9, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 9, 15, 97, 10, 970);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 10, 119, 23, 14, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070707018002, 11, 29, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 11, 180, 37, 13, 481);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 12, 92, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 13, 190, 63, 16, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 14, 14, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 15, 40, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 16, 12, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 17, 144, 85, 15, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140124017628, 18, 19, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 1, 26, 51, 7, 357);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 2, 74, 55, 7, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 3, 154, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 4, 38, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 5, 30, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 6, 136, 92, 14, 1288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 7, 131, 47, 9, 423);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 8, 44, 3, 8, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 9, 153, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 10, 64, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 11, 121, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 12, 2, 4, 4, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 13, 108, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 14, 95, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120627017629, 15, 129, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 1, 32, 87, 13, 1131);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 2, 59, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 3, 149, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 4, 138, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 5, 61, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 6, 83, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030521017630, 7, 124, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 1, 55, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 2, 133, 9, 11, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 3, 168, 23, 15, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 4, 91, 85, 10, 850);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 5, 83, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 6, 148, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 7, 37, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 8, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 9, 168, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 10, 182, 73, 15, 1095);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 11, 88, 67, 14, 938);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 12, 30, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111012017631, 13, 149, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 1, 142, 69, 13, 897);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 2, 31, 70, 12, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 3, 70, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 4, 122, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 5, 141, 78, 12, 936);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 6, 105, 72, 7, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 7, 174, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 8, 166, 30, 13, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 9, 59, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 10, 114, 83, 9, 747);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 11, 53, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 12, 49, 2, 6, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090630017632, 13, 12, 14, 7, 98);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 1, 112, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 2, 56, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 3, 178, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 4, 138, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 5, 97, 66, 6, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 6, 66, 67, 6, 402);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 7, 121, 67, 9, 603);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 8, 103, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050111017633, 9, 163, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 1, 28, 79, 9, 711);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 2, 158, 51, 15, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 3, 32, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 4, 133, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 5, 58, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 6, 13, 2, 8, 16);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031006017634, 7, 125, 80, 13, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 1, 175, 26, 15, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 2, 88, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 3, 82, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 4, 164, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 5, 75, 84, 8, 672);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 6, 26, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 7, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 8, 72, 94, 12, 1128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 9, 153, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 10, 169, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 11, 183, 57, 16, 912);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 12, 68, 72, 8, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 13, 68, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 14, 82, 59, 8, 472);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 15, 127, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 16, 154, 26, 11, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130406017635, 17, 100, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 1, 37, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 2, 67, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 3, 30, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 4, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 5, 152, 86, 16, 1376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 6, 123, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 7, 73, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 8, 134, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 9, 130, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 10, 110, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 11, 101, 10, 10, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080826017636, 12, 180, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 1, 140, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 2, 108, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 3, 28, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 4, 7, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 5, 179, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 6, 28, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 7, 190, 84, 16, 1344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 8, 154, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 9, 69, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 10, 92, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 11, 17, 83, 5, 415);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 12, 25, 13, 6, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090428017637, 13, 126, 65, 14, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 1, 76, 43, 9, 387);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 2, 137, 24, 8, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 3, 180, 100, 13, 1300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 4, 109, 56, 11, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 5, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 6, 179, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 7, 48, 26, 12, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 8, 79, 69, 12, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 9, 188, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 10, 63, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 11, 32, 99, 13, 1287);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 12, 118, 86, 13, 1118);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 13, 71, 39, 11, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120109017638, 14, 74, 40, 7, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 1, 124, 48, 12, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 2, 16, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 3, 107, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 4, 89, 27, 8, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 5, 56, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 6, 139, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 7, 95, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031011017639, 8, 21, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 1, 171, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 2, 155, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 3, 122, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 4, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 5, 189, 37, 15, 555);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 6, 87, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 7, 70, 82, 10, 820);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 8, 156, 81, 13, 1053);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 9, 28, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 10, 141, 100, 12, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 11, 165, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 12, 94, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 13, 185, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 14, 70, 17, 10, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 15, 77, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 16, 3, 85, 5, 425);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 17, 36, 52, 7, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 18, 142, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140201017640, 19, 54, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227017641, 1, 8, 55, 10, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227017641, 2, 111, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227017641, 3, 126, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227017641, 4, 58, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010227017641, 5, 122, 93, 10, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 1, 49, 4, 6, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 2, 110, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 3, 72, 17, 12, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 4, 170, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 5, 98, 64, 7, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 6, 128, 89, 16, 1424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 7, 38, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 8, 186, 43, 12, 516);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 9, 7, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 10, 97, 79, 6, 474);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 11, 149, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 12, 46, 34, 10, 340);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080702017642, 13, 153, 33, 10, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 1, 189, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 2, 163, 14, 10, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 3, 88, 55, 14, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 4, 137, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 5, 39, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 6, 42, 47, 6, 282);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 7, 96, 63, 15, 945);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 8, 62, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 9, 3, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 10, 83, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 11, 123, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 12, 178, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 13, 9, 35, 4, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 14, 102, 17, 11, 187);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 15, 16, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 16, 111, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131019017643, 17, 122, 49, 10, 490);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 1, 120, 71, 15, 1065);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 2, 119, 97, 14, 1358);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 3, 56, 40, 13, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 4, 122, 96, 10, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 5, 67, 83, 7, 581);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 6, 144, 35, 15, 525);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 7, 99, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 8, 154, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 9, 7, 48, 9, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 10, 72, 29, 12, 348);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 11, 102, 59, 11, 649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 12, 56, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 13, 160, 17, 17, 289);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 14, 2, 81, 4, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20110603017644, 15, 47, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 1, 129, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 2, 155, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 3, 165, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 4, 19, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 5, 130, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020930017645, 6, 162, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 1, 168, 34, 15, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 2, 187, 95, 13, 1235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 3, 88, 87, 14, 1218);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 4, 120, 78, 15, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 5, 102, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 6, 159, 31, 16, 496);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20021129017646, 7, 14, 49, 9, 441);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 1, 132, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 2, 174, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 3, 47, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 4, 92, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 5, 13, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020114017647, 6, 181, 3, 14, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410017648, 1, 153, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410017648, 2, 54, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410017648, 3, 38, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410017648, 4, 122, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010410017648, 5, 177, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 1, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 2, 131, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 3, 9, 36, 4, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 4, 147, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 5, 44, 40, 8, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030531017649, 6, 172, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 1, 20, 66, 8, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 2, 146, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 3, 40, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 4, 60, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 5, 187, 27, 13, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 6, 156, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 7, 36, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 8, 184, 89, 17, 1513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 9, 75, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 10, 25, 14, 6, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060714017650, 11, 7, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 1, 120, 30, 15, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 2, 138, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 3, 55, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 4, 24, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 5, 17, 51, 5, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 6, 179, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040707017651, 7, 154, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 1, 138, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 2, 118, 3, 13, 39);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 3, 5, 84, 7, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 4, 94, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 5, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 6, 57, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 7, 144, 93, 15, 1395);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 8, 97, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 9, 174, 16, 14, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070125017652, 10, 108, 39, 10, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 1, 68, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 2, 146, 13, 10, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 3, 68, 36, 8, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 4, 94, 7, 13, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 5, 46, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 6, 42, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 7, 159, 12, 16, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 8, 141, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050206017653, 9, 178, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 1, 161, 55, 8, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 2, 70, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 3, 163, 43, 10, 430);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 4, 175, 50, 15, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 5, 14, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 6, 72, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 7, 72, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 8, 187, 50, 13, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 9, 102, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 10, 98, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 11, 110, 5, 12, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 12, 46, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100702017654, 13, 160, 73, 17, 1241);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 1, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 2, 10, 52, 5, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 3, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 4, 52, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 5, 25, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 6, 69, 36, 9, 324);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 7, 170, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040227017655, 8, 16, 24, 11, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 1, 85, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 2, 157, 52, 14, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 3, 130, 28, 8, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 4, 125, 1, 13, 13);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 5, 130, 22, 8, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 6, 22, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 7, 185, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 8, 170, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070927017656, 9, 30, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 1, 105, 60, 7, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 2, 24, 47, 12, 564);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 3, 105, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 4, 156, 68, 13, 884);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 5, 132, 35, 10, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 6, 116, 71, 11, 781);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 7, 106, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 8, 134, 52, 12, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 9, 123, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 10, 73, 35, 6, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 11, 18, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 12, 47, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 13, 8, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 14, 7, 85, 9, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 15, 176, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130904017657, 16, 181, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614017658, 1, 17, 33, 5, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614017658, 2, 132, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000614017658, 3, 157, 82, 14, 1148);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 1, 143, 15, 14, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 2, 160, 30, 17, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 3, 137, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 4, 174, 32, 14, 448);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 5, 112, 8, 14, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 6, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 7, 89, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 8, 144, 62, 15, 930);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 9, 138, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 10, 170, 77, 10, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 11, 58, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 12, 5, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 13, 127, 81, 15, 1215);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 14, 38, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 15, 44, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130302017659, 16, 123, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017660, 1, 157, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017660, 2, 100, 11, 9, 99);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017660, 3, 151, 60, 15, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017660, 4, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020808017660, 5, 161, 94, 8, 752);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 1, 76, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 2, 116, 41, 11, 451);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 3, 182, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 4, 107, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 5, 144, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 6, 98, 77, 7, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 7, 75, 49, 8, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 8, 168, 27, 15, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051025017661, 9, 155, 1, 12, 12);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125017662, 1, 9, 10, 4, 40);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125017662, 2, 185, 61, 11, 671);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125017662, 3, 126, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125017662, 4, 149, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011125017662, 5, 119, 25, 14, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017663, 1, 96, 56, 15, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017663, 2, 71, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017663, 3, 55, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017663, 4, 51, 48, 8, 384);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030623017663, 5, 151, 55, 15, 825);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 1, 35, 88, 6, 528);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 2, 50, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 3, 67, 22, 7, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 4, 12, 46, 7, 322);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 5, 154, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 6, 107, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 7, 152, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 8, 172, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 9, 71, 38, 11, 418);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 10, 157, 18, 14, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 11, 147, 42, 11, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 12, 60, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 13, 182, 8, 15, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 14, 113, 93, 8, 744);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120123017664, 15, 8, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 1, 113, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 2, 126, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 3, 28, 92, 9, 828);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 4, 11, 55, 6, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 5, 30, 86, 11, 946);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 6, 35, 22, 6, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 7, 121, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 8, 116, 72, 11, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051205017665, 9, 116, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 1, 80, 39, 13, 507);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 2, 9, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 3, 28, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 4, 147, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 5, 111, 25, 13, 325);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 6, 146, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 7, 166, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 8, 82, 37, 8, 296);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070904017666, 9, 63, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 1, 58, 54, 8, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 2, 101, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 3, 37, 82, 8, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 4, 116, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 5, 100, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 6, 95, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 7, 139, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 8, 132, 71, 10, 710);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 9, 23, 40, 11, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 10, 119, 66, 14, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 11, 15, 92, 10, 920);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080626017667, 12, 52, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714017668, 1, 177, 63, 10, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000714017668, 2, 28, 95, 9, 855);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 1, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 2, 104, 73, 13, 949);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 3, 170, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 4, 88, 98, 14, 1372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 5, 26, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 6, 137, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 7, 48, 60, 12, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 8, 110, 7, 12, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 9, 124, 34, 12, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 10, 146, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 11, 81, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 12, 141, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 13, 137, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 14, 168, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 15, 151, 68, 15, 1020);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 16, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130110017669, 17, 170, 66, 10, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 1, 77, 45, 10, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 2, 144, 48, 15, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 3, 63, 65, 13, 845);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 4, 1, 98, 3, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 5, 53, 48, 10, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010928017670, 6, 136, 51, 14, 714);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 1, 11, 65, 6, 390);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 2, 80, 63, 13, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 3, 129, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 4, 21, 1, 9, 9);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 5, 5, 15, 7, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 6, 160, 75, 17, 1275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 7, 21, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 8, 89, 46, 8, 368);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 9, 18, 10, 6, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 10, 45, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 11, 14, 63, 9, 567);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 12, 137, 51, 8, 408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 13, 37, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 14, 74, 73, 7, 511);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111117017671, 15, 14, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 1, 144, 18, 15, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 2, 142, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 3, 172, 42, 12, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 4, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 5, 43, 43, 7, 301);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 6, 149, 47, 13, 611);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 7, 83, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 8, 108, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 9, 84, 90, 10, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 10, 174, 40, 14, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 11, 151, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 12, 158, 80, 15, 1200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 13, 68, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 14, 47, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 15, 16, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 16, 41, 59, 5, 295);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130519017672, 17, 177, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 1, 88, 36, 14, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 2, 162, 9, 9, 81);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 3, 28, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 4, 144, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 5, 157, 62, 14, 868);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 6, 187, 76, 13, 988);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 7, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 8, 68, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 9, 20, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 10, 188, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 11, 187, 97, 13, 1261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 12, 151, 17, 15, 255);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 13, 28, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 14, 104, 82, 13, 1066);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20101223017673, 15, 59, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 1, 103, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 2, 189, 94, 15, 1410);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 3, 117, 97, 12, 1164);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 4, 137, 1, 8, 8);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 5, 144, 40, 15, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 6, 173, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030427017674, 7, 132, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 1, 161, 60, 8, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 2, 119, 39, 14, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 3, 175, 45, 15, 675);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 4, 170, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 5, 99, 61, 8, 488);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 6, 69, 96, 9, 864);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 7, 57, 37, 7, 259);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 8, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 9, 92, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 10, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 11, 82, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 12, 167, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 13, 163, 98, 10, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20111025017675, 14, 18, 98, 6, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017676, 1, 190, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017676, 2, 24, 90, 12, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017676, 3, 189, 53, 15, 795);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017676, 4, 185, 46, 11, 506);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020408017676, 5, 41, 34, 5, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 1, 105, 76, 7, 532);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 2, 88, 81, 14, 1134);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 3, 165, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 4, 137, 32, 8, 256);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 5, 132, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 6, 136, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 7, 14, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 8, 71, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 9, 97, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 10, 93, 86, 12, 1032);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090827017677, 11, 54, 89, 11, 979);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 1, 54, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 2, 14, 8, 9, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 3, 79, 61, 12, 732);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 4, 84, 89, 10, 890);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 5, 161, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 6, 165, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031106017678, 7, 145, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 1, 3, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 2, 42, 81, 6, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 3, 102, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 4, 192, 97, 18, 1746);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 5, 181, 24, 14, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010727017679, 6, 32, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313017680, 1, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313017680, 2, 115, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313017680, 3, 179, 45, 12, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313017680, 4, 31, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010313017680, 5, 14, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 1, 135, 90, 13, 1170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 2, 42, 83, 6, 498);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 3, 164, 54, 11, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 4, 8, 2, 10, 20);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 5, 123, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 6, 37, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 7, 45, 64, 9, 576);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 8, 123, 52, 11, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 9, 10, 58, 5, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 10, 136, 68, 14, 952);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 11, 172, 3, 12, 36);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 12, 10, 81, 5, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 13, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 14, 149, 36, 13, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 15, 82, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 16, 48, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 17, 26, 38, 7, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131106017681, 18, 111, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 1, 39, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 2, 82, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 3, 17, 67, 5, 335);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 4, 162, 65, 9, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 5, 158, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 6, 138, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 7, 160, 10, 17, 170);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 8, 140, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 9, 190, 19, 16, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 10, 53, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 11, 55, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 12, 147, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 13, 147, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 14, 31, 46, 12, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 15, 82, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 16, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130428017682, 17, 55, 11, 12, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 1, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 2, 80, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 3, 57, 62, 7, 434);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 4, 64, 37, 14, 518);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 5, 69, 37, 9, 333);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 6, 145, 22, 9, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 7, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 8, 85, 13, 11, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 9, 40, 96, 11, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060912017683, 10, 94, 58, 13, 754);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519017684, 1, 21, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519017684, 2, 36, 98, 7, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519017684, 3, 106, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000519017684, 4, 77, 38, 10, 380);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 1, 5, 13, 7, 91);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 2, 97, 52, 6, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 3, 24, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 4, 106, 86, 8, 688);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 5, 190, 32, 16, 512);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 6, 142, 77, 13, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 7, 131, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 8, 119, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051019017685, 9, 117, 10, 12, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 1, 32, 8, 13, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 2, 147, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 3, 147, 1, 11, 11);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 4, 149, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 5, 136, 46, 14, 644);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030814017686, 6, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 1, 101, 27, 10, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 2, 31, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 3, 81, 68, 7, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 4, 114, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 5, 67, 49, 7, 343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 6, 121, 56, 9, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 7, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 8, 20, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 9, 151, 86, 15, 1290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 10, 53, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20061124017687, 11, 171, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 1, 72, 66, 12, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 2, 14, 99, 9, 891);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 3, 148, 87, 12, 1044);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 4, 48, 13, 12, 156);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 5, 110, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030821017688, 6, 166, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 1, 117, 28, 12, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 2, 75, 25, 8, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 3, 21, 98, 9, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 4, 1, 50, 3, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 5, 106, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 6, 133, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 7, 55, 38, 12, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051213017689, 8, 47, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 1, 144, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 2, 83, 70, 9, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 3, 12, 10, 7, 70);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 4, 8, 23, 10, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 5, 115, 3, 10, 30);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 6, 97, 85, 6, 510);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 7, 123, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 8, 66, 100, 6, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 9, 42, 87, 6, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 10, 41, 90, 5, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 11, 131, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 12, 30, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 13, 70, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100831017690, 14, 129, 45, 7, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 1, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 2, 64, 49, 14, 686);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 3, 54, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 4, 110, 4, 12, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 5, 191, 40, 17, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 6, 90, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 7, 20, 29, 8, 232);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 8, 114, 12, 9, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 9, 55, 64, 12, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 10, 50, 11, 7, 77);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 11, 71, 36, 11, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070827017691, 12, 22, 78, 10, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017692, 1, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017692, 2, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017692, 3, 155, 19, 12, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017692, 4, 24, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010609017692, 5, 128, 58, 16, 928);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 1, 122, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 2, 41, 47, 5, 235);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 3, 179, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 4, 135, 64, 13, 832);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 5, 190, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 6, 43, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030627017693, 7, 7, 45, 9, 405);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 1, 120, 98, 15, 1470);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 2, 154, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 3, 112, 10, 14, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 4, 147, 85, 11, 935);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 5, 160, 97, 17, 1649);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 6, 171, 100, 11, 1100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 7, 37, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 8, 153, 57, 10, 570);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 9, 112, 72, 14, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 10, 79, 84, 12, 1008);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 11, 44, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 12, 72, 55, 12, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 13, 55, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 14, 49, 11, 6, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 15, 62, 15, 12, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130410017694, 16, 61, 20, 11, 220);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 1, 77, 29, 10, 290);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 2, 9, 44, 4, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 3, 158, 31, 15, 465);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 4, 171, 37, 11, 407);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 5, 152, 91, 16, 1456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030406017695, 6, 154, 95, 11, 1045);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 1, 39, 91, 10, 910);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 2, 188, 6, 14, 84);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 3, 130, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 4, 46, 9, 10, 90);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 5, 9, 7, 4, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 6, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 7, 180, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060429017696, 8, 26, 9, 7, 63);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 1, 140, 60, 11, 660);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 2, 96, 29, 15, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 3, 67, 24, 7, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 4, 84, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 5, 49, 24, 6, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 6, 158, 52, 15, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 7, 19, 21, 7, 147);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 8, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 9, 162, 27, 9, 243);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 10, 92, 34, 11, 374);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 11, 20, 9, 8, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20081005017697, 12, 172, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 1, 93, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 2, 3, 74, 5, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 3, 80, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 4, 106, 14, 8, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 5, 79, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010610017698, 6, 178, 14, 11, 154);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111017699, 1, 179, 79, 12, 948);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20001111017699, 2, 91, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 1, 159, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 2, 72, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 3, 33, 72, 4, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 4, 112, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 5, 190, 65, 16, 1040);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 6, 151, 7, 15, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051128017700, 7, 45, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 1, 91, 37, 10, 370);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 2, 84, 83, 10, 830);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 3, 6, 57, 8, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 4, 21, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 5, 45, 91, 9, 819);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 6, 176, 11, 16, 176);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 7, 160, 83, 17, 1411);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 8, 151, 77, 15, 1155);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040505017701, 9, 137, 85, 8, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 1, 162, 66, 9, 594);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 2, 72, 88, 12, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 3, 127, 72, 15, 1080);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 4, 147, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 5, 130, 88, 8, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 6, 15, 53, 10, 530);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 7, 52, 97, 9, 873);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 8, 77, 20, 10, 200);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 9, 125, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 10, 16, 63, 11, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 11, 131, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 12, 157, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 13, 107, 78, 9, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 14, 15, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 15, 82, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 16, 145, 17, 9, 153);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 17, 140, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 18, 47, 10, 11, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140326017702, 19, 106, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 1, 36, 8, 7, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 2, 45, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 3, 84, 81, 10, 810);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 4, 152, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 5, 129, 50, 7, 350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 6, 141, 21, 12, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050221017703, 7, 77, 44, 10, 440);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 1, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 2, 138, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 3, 120, 82, 15, 1230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 4, 146, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 5, 186, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 6, 67, 53, 7, 371);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 7, 156, 75, 13, 975);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060527017704, 8, 116, 84, 11, 924);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 1, 176, 44, 16, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 2, 184, 57, 17, 969);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 3, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 4, 138, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 5, 187, 31, 13, 403);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 6, 60, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 7, 169, 62, 9, 558);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 8, 14, 100, 9, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 9, 160, 99, 17, 1683);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 10, 189, 25, 15, 375);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 11, 30, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 12, 56, 42, 13, 546);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 13, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 14, 14, 76, 9, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 15, 1, 100, 3, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120518017705, 16, 144, 100, 15, 1500);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 1, 7, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 2, 152, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 3, 13, 16, 8, 128);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 4, 133, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 5, 113, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 6, 112, 59, 14, 826);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 7, 158, 12, 15, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 8, 100, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 9, 161, 69, 8, 552);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 10, 3, 1, 5, 5);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 11, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 12, 32, 29, 13, 377);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 13, 90, 18, 9, 162);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 14, 160, 79, 17, 1343);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 15, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120502017706, 16, 170, 65, 10, 650);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 1, 180, 13, 13, 169);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 2, 173, 11, 13, 143);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 3, 192, 69, 18, 1242);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 4, 75, 18, 8, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 5, 54, 88, 11, 968);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 6, 160, 45, 17, 765);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 7, 2, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 8, 97, 84, 6, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 9, 140, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 10, 96, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 11, 119, 85, 14, 1190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 12, 171, 90, 11, 990);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 13, 111, 62, 13, 806);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 14, 88, 60, 14, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 15, 92, 64, 11, 704);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 16, 184, 6, 17, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120615017707, 17, 123, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 1, 116, 5, 11, 55);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 2, 23, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 3, 35, 69, 6, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 4, 56, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 5, 92, 18, 11, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 6, 29, 84, 10, 840);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 7, 79, 75, 12, 900);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 8, 180, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 9, 100, 74, 9, 666);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 10, 68, 70, 8, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 11, 92, 33, 11, 363);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 12, 67, 23, 7, 161);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 13, 176, 66, 16, 1056);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 14, 149, 14, 13, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 15, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 16, 136, 45, 14, 630);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130624017708, 17, 148, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 1, 107, 39, 9, 351);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 2, 144, 76, 15, 1140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 3, 57, 2, 7, 14);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 4, 43, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 5, 2, 57, 4, 228);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 6, 72, 14, 12, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 7, 122, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051023017709, 8, 6, 74, 8, 592);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 1, 169, 94, 9, 846);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 2, 191, 12, 17, 204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 3, 48, 57, 12, 684);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 4, 106, 99, 8, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 5, 138, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 6, 95, 43, 14, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 7, 51, 50, 8, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 8, 124, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 9, 135, 91, 13, 1183);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20060117017710, 10, 68, 79, 8, 632);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 1, 189, 13, 15, 195);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 2, 185, 47, 11, 517);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 3, 56, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 4, 7, 26, 9, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 5, 26, 67, 7, 469);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 6, 121, 32, 9, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040224017711, 7, 61, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 1, 159, 87, 16, 1392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 2, 148, 35, 12, 420);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 3, 167, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 4, 17, 21, 5, 105);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 5, 156, 49, 13, 637);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 6, 57, 34, 7, 238);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 7, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 8, 24, 8, 12, 96);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 9, 138, 86, 9, 774);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 10, 190, 3, 16, 48);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 11, 186, 2, 12, 24);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100606017712, 12, 30, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 1, 187, 78, 13, 1014);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 2, 118, 17, 13, 221);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 3, 108, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 4, 32, 66, 13, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 5, 14, 34, 9, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 6, 149, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 7, 112, 77, 14, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 8, 124, 18, 12, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 9, 48, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 10, 66, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 11, 59, 30, 9, 270);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 12, 134, 12, 12, 144);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080423017713, 13, 43, 48, 7, 336);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 1, 174, 86, 14, 1204);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 2, 158, 97, 15, 1455);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 3, 10, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 4, 95, 28, 14, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 5, 190, 45, 16, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 6, 163, 67, 10, 670);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 7, 84, 76, 10, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 8, 127, 15, 15, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051104017714, 9, 50, 89, 7, 623);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 1, 176, 20, 16, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 2, 50, 3, 7, 21);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 3, 161, 26, 8, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 4, 99, 83, 8, 664);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 5, 109, 93, 11, 1023);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 6, 30, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050831017715, 7, 1, 63, 3, 189);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027017716, 1, 4, 61, 6, 366);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027017716, 2, 13, 96, 8, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027017716, 3, 161, 38, 8, 304);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027017716, 4, 22, 87, 10, 870);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20031027017716, 5, 30, 79, 11, 869);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 1, 161, 81, 8, 648);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 2, 57, 56, 7, 392);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 3, 63, 84, 13, 1092);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 4, 177, 60, 10, 600);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 5, 114, 68, 9, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 6, 12, 4, 7, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 7, 111, 32, 13, 416);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 8, 183, 48, 16, 768);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 9, 79, 36, 12, 432);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 10, 35, 18, 6, 108);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 11, 185, 29, 11, 319);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 12, 59, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 13, 34, 63, 5, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 14, 31, 41, 12, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 15, 80, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 16, 10, 99, 5, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130124017717, 17, 105, 30, 7, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 1, 34, 69, 5, 345);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 2, 128, 10, 16, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 3, 103, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 4, 62, 59, 12, 708);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 5, 55, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020806017718, 6, 187, 9, 13, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 1, 84, 46, 10, 460);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 2, 185, 74, 11, 814);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 3, 97, 97, 6, 582);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 4, 114, 14, 9, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 5, 186, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 6, 119, 34, 14, 476);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 7, 77, 26, 10, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 8, 125, 10, 13, 130);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 9, 4, 28, 6, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 10, 137, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 11, 117, 89, 12, 1068);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 12, 79, 68, 12, 816);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 13, 116, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 14, 52, 29, 9, 261);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120505017719, 15, 15, 30, 10, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118017720, 1, 50, 7, 7, 49);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118017720, 2, 170, 32, 10, 320);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118017720, 3, 126, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20000118017720, 4, 137, 87, 8, 696);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 1, 47, 80, 11, 880);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 2, 187, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 3, 57, 66, 7, 462);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 4, 133, 4, 11, 44);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 5, 134, 24, 12, 288);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 6, 6, 58, 8, 464);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 7, 52, 60, 9, 540);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 8, 22, 72, 10, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 9, 75, 95, 8, 760);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20071202017721, 10, 113, 47, 8, 376);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128017722, 1, 111, 67, 13, 871);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128017722, 2, 34, 13, 5, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128017722, 3, 151, 21, 15, 315);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128017722, 4, 162, 5, 9, 45);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20011128017722, 5, 47, 76, 11, 836);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 1, 73, 36, 6, 216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 2, 160, 34, 17, 578);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 3, 92, 43, 11, 473);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 4, 72, 30, 12, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 5, 128, 46, 16, 736);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 6, 3, 71, 5, 355);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 7, 38, 13, 9, 117);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 8, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050410017723, 9, 72, 65, 12, 780);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 1, 142, 48, 13, 624);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 2, 150, 94, 14, 1316);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 3, 43, 29, 7, 203);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 4, 25, 17, 6, 102);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 5, 147, 32, 11, 352);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 6, 81, 79, 7, 553);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 7, 117, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 8, 24, 22, 12, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 9, 125, 4, 13, 52);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 10, 131, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 11, 61, 91, 11, 1001);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20090421017724, 12, 123, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 1, 113, 89, 8, 712);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 2, 36, 86, 7, 602);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 3, 28, 77, 9, 693);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 4, 106, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 5, 105, 54, 7, 378);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 6, 12, 97, 7, 679);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 7, 167, 80, 14, 1120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20051211017725, 8, 61, 58, 11, 638);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 1, 101, 74, 10, 740);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 2, 68, 53, 8, 424);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 3, 182, 16, 15, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 4, 70, 19, 10, 190);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 5, 140, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 6, 167, 2, 14, 28);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 7, 67, 62, 7, 434);
commit;
prompt 183000 records committed...
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030706017726, 8, 87, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 1, 120, 90, 15, 1350);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 2, 93, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 3, 170, 16, 10, 160);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 4, 56, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 5, 157, 21, 14, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 6, 178, 53, 11, 583);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 7, 143, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 8, 161, 34, 8, 272);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041202017727, 9, 42, 33, 6, 198);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 1, 170, 68, 10, 680);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 2, 82, 7, 8, 56);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 3, 28, 69, 9, 621);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 4, 95, 90, 14, 1260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 5, 176, 50, 16, 800);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 6, 59, 80, 9, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 7, 137, 63, 8, 504);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 8, 97, 82, 6, 492);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 9, 171, 97, 11, 1067);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 10, 109, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20070302017728, 11, 48, 37, 12, 444);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 1, 132, 52, 10, 520);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 2, 2, 48, 4, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 3, 104, 94, 13, 1222);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 4, 10, 96, 5, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 5, 120, 87, 15, 1305);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 6, 74, 6, 7, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 7, 40, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 8, 25, 1, 6, 6);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 9, 123, 15, 11, 165);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 10, 48, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 11, 140, 31, 11, 341);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 12, 149, 44, 13, 572);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 13, 143, 54, 14, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 14, 119, 41, 14, 574);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 15, 109, 51, 11, 561);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 16, 39, 75, 10, 750);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 17, 126, 70, 14, 980);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140301017729, 18, 187, 45, 13, 585);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 1, 2, 56, 4, 224);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 2, 6, 33, 8, 264);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 3, 19, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 4, 145, 40, 9, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 5, 118, 92, 13, 1196);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 6, 111, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 7, 118, 22, 13, 286);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 8, 84, 5, 10, 50);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 9, 121, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 10, 21, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 11, 48, 71, 12, 852);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 12, 54, 57, 11, 627);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 13, 69, 50, 9, 450);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 14, 13, 98, 8, 784);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120422017730, 15, 75, 43, 8, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 1, 11, 40, 6, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 2, 67, 20, 7, 140);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 3, 27, 15, 8, 120);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 4, 104, 98, 13, 1274);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 5, 106, 13, 8, 104);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 6, 80, 19, 13, 247);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030321017731, 7, 135, 33, 13, 429);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 1, 135, 16, 13, 208);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 2, 69, 6, 9, 54);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 3, 18, 31, 6, 186);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 4, 93, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 5, 187, 54, 13, 702);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 6, 81, 88, 7, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 7, 121, 38, 9, 342);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 8, 183, 41, 16, 656);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 9, 110, 20, 12, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 10, 33, 86, 4, 344);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 11, 126, 58, 14, 812);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 12, 128, 88, 16, 1408);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 13, 188, 89, 14, 1246);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 14, 41, 5, 5, 25);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20120425017732, 15, 71, 77, 11, 847);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 1, 164, 6, 11, 66);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 2, 69, 88, 9, 792);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 3, 65, 17, 5, 85);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 4, 129, 57, 7, 399);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 5, 81, 61, 7, 427);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 6, 178, 8, 11, 88);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 7, 158, 75, 15, 1125);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20050223017733, 8, 171, 49, 11, 539);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 1, 164, 68, 11, 748);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 2, 7, 57, 9, 513);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 3, 17, 46, 5, 230);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 4, 14, 84, 9, 756);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 5, 23, 35, 11, 385);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 6, 8, 28, 10, 280);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 7, 178, 98, 11, 1078);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 8, 49, 30, 6, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 9, 110, 25, 12, 300);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 10, 145, 59, 9, 531);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 11, 90, 58, 9, 522);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 12, 124, 49, 12, 588);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 13, 121, 87, 9, 783);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 14, 72, 93, 12, 1116);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20100423017734, 15, 45, 25, 9, 225);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 1, 15, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 2, 97, 43, 6, 258);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 3, 138, 46, 9, 414);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 4, 99, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 5, 159, 35, 16, 560);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 6, 113, 19, 8, 152);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20030217017735, 7, 70, 40, 10, 400);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 1, 101, 94, 10, 940);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 2, 92, 55, 11, 605);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 3, 78, 50, 11, 550);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 4, 61, 70, 11, 770);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 5, 56, 6, 13, 78);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 6, 176, 76, 16, 1216);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 7, 22, 21, 10, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 8, 83, 41, 9, 369);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 9, 186, 74, 12, 888);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 10, 17, 95, 5, 475);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 11, 112, 93, 14, 1302);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 12, 11, 76, 6, 456);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 13, 3, 87, 5, 435);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 14, 118, 51, 13, 663);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 15, 85, 12, 11, 132);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20140226017736, 16, 2, 77, 4, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316017737, 1, 49, 21, 6, 126);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316017737, 2, 137, 77, 8, 616);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316017737, 3, 71, 28, 11, 308);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316017737, 4, 158, 4, 15, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020316017737, 5, 148, 99, 12, 1188);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214017738, 1, 43, 1, 7, 7);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214017738, 2, 45, 54, 9, 486);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214017738, 3, 103, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214017738, 4, 18, 7, 6, 42);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20020214017738, 5, 163, 61, 10, 610);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 1, 109, 69, 11, 759);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 2, 88, 63, 14, 882);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 3, 24, 73, 12, 876);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 4, 22, 36, 10, 360);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 5, 147, 62, 11, 682);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 6, 135, 5, 13, 65);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040812017739, 7, 174, 12, 14, 168);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 1, 103, 31, 12, 372);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 2, 185, 78, 11, 858);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 3, 78, 66, 11, 726);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 4, 36, 58, 7, 406);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 5, 129, 16, 7, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 6, 96, 64, 15, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 7, 160, 51, 17, 867);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20041219017740, 8, 94, 41, 13, 533);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901017741, 1, 161, 71, 8, 568);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901017741, 2, 54, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901017741, 3, 124, 16, 12, 192);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20010901017741, 4, 122, 79, 10, 790);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 1, 99, 68, 8, 544);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 2, 43, 87, 7, 609);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 3, 6, 30, 8, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 4, 53, 24, 10, 240);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 5, 143, 19, 14, 266);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 6, 53, 11, 10, 110);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 7, 20, 17, 8, 136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 8, 151, 33, 15, 495);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20040303017742, 9, 33, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 1, 181, 13, 14, 182);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 2, 80, 20, 13, 260);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 3, 182, 14, 15, 210);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 4, 83, 44, 9, 396);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 5, 107, 2, 9, 18);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 6, 60, 6, 10, 60);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 7, 72, 51, 12, 612);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 8, 134, 40, 12, 480);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 9, 22, 95, 10, 950);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 10, 2, 97, 4, 388);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 11, 179, 81, 12, 972);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20080301017743, 12, 85, 23, 11, 253);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 1, 84, 58, 10, 580);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 2, 159, 71, 16, 1136);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 3, 100, 93, 9, 837);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 4, 166, 18, 13, 234);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 5, 2, 46, 4, 184);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 6, 141, 83, 12, 996);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 7, 48, 6, 12, 72);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 8, 47, 65, 11, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 9, 117, 80, 12, 960);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 10, 106, 90, 8, 720);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 11, 53, 18, 10, 180);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 12, 42, 51, 6, 306);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 13, 183, 7, 16, 112);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 14, 37, 91, 8, 728);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 15, 85, 30, 11, 330);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 16, 106, 39, 8, 312);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 17, 136, 26, 14, 364);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20131108017744, 18, 29, 8, 10, 80);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 1, 185, 44, 11, 484);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 2, 43, 36, 7, 252);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 3, 2, 25, 4, 100);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 4, 118, 55, 13, 715);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 5, 116, 99, 11, 1089);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 6, 23, 25, 11, 275);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 7, 96, 10, 15, 150);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 8, 165, 39, 12, 468);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 9, 121, 3, 9, 27);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 10, 118, 96, 13, 1248);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 11, 43, 42, 7, 294);
insert into INVLINES (invno, invlineno, productid, quantity, price, invlineamount)
values (20130718017745, 12, 106, 71, 8, 568);
commit;
prompt 183202 records loaded
prompt Loading LAUNDERING_ACCOUNT...
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (1, to_date('01-01-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (2, to_date('02-01-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (3, to_date('05-01-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (4, to_date('06-01-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (5, to_date('08-01-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (6, to_date('12-01-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (7, to_date('15-01-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (8, to_date('16-01-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (9, to_date('20-01-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (10, to_date('21-01-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (11, to_date('28-01-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (12, to_date('01-02-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (13, to_date('02-02-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (14, to_date('05-02-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (15, to_date('06-02-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (16, to_date('08-02-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (17, to_date('12-02-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (18, to_date('15-02-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (19, to_date('16-02-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (20, to_date('20-02-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (21, to_date('21-02-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (22, to_date('28-02-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (23, to_date('01-03-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (24, to_date('02-03-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (25, to_date('05-03-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (26, to_date('06-03-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (27, to_date('08-03-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (28, to_date('12-03-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (29, to_date('15-03-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (30, to_date('16-03-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (31, to_date('20-03-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (32, to_date('21-03-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (33, to_date('28-03-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (34, to_date('01-04-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (35, to_date('02-04-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (36, to_date('05-04-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (37, to_date('06-04-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (38, to_date('08-04-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (39, to_date('12-04-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (40, to_date('15-04-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (41, to_date('16-04-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (42, to_date('20-04-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (43, to_date('21-04-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (44, to_date('28-04-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (45, to_date('01-05-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (46, to_date('02-05-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (47, to_date('05-05-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (48, to_date('06-05-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (49, to_date('08-05-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (50, to_date('12-05-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (51, to_date('15-05-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (52, to_date('16-05-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (53, to_date('20-05-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (54, to_date('21-05-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (55, to_date('28-05-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (56, to_date('01-06-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (57, to_date('02-06-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (58, to_date('05-06-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (59, to_date('06-06-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (60, to_date('08-06-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (61, to_date('12-06-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (62, to_date('15-06-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (63, to_date('16-06-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (64, to_date('20-06-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (65, to_date('21-06-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (66, to_date('28-06-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (67, to_date('01-07-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (68, to_date('02-07-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (69, to_date('05-07-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (70, to_date('06-07-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (71, to_date('08-07-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (72, to_date('12-07-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (73, to_date('15-07-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (74, to_date('16-07-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (75, to_date('20-07-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (76, to_date('21-07-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (77, to_date('28-07-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (78, to_date('01-08-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (79, to_date('02-08-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (80, to_date('05-08-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (81, to_date('06-08-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (82, to_date('08-08-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (83, to_date('12-08-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (84, to_date('15-08-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (85, to_date('16-08-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (86, to_date('20-08-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (87, to_date('21-08-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (88, to_date('28-08-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (89, to_date('01-09-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (90, to_date('02-09-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (91, to_date('05-09-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (92, to_date('06-09-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (93, to_date('08-09-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (94, to_date('12-09-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (95, to_date('15-09-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (96, to_date('16-09-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (97, to_date('20-09-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (98, to_date('21-09-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (99, to_date('28-09-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (100, to_date('01-10-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (101, to_date('02-10-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (102, to_date('05-10-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (103, to_date('06-10-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (104, to_date('08-10-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (105, to_date('12-10-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (106, to_date('15-10-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (107, to_date('16-10-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (108, to_date('20-10-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (109, to_date('21-10-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (110, to_date('28-10-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (111, to_date('01-11-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (112, to_date('02-11-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (113, to_date('05-11-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (114, to_date('06-11-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (115, to_date('08-11-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (116, to_date('12-11-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (117, to_date('15-11-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (118, to_date('16-11-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (119, to_date('20-11-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (120, to_date('21-11-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (121, to_date('28-11-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (122, to_date('01-12-2013', 'dd-mm-yyyy'), 510, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (123, to_date('01-12-2013', 'dd-mm-yyyy'), 950, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (124, to_date('01-12-2013', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (125, to_date('02-12-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (126, to_date('05-12-2013', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (127, to_date('06-12-2013', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (128, to_date('06-12-2013', 'dd-mm-yyyy'), 890, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (129, to_date('08-12-2013', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (130, to_date('10-12-2013', 'dd-mm-yyyy'), 750, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (131, to_date('12-12-2013', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (132, to_date('12-12-2013', 'dd-mm-yyyy'), 800, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (133, to_date('15-12-2013', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (134, to_date('15-12-2013', 'dd-mm-yyyy'), 770, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (135, to_date('16-12-2013', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (136, to_date('20-12-2013', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (137, to_date('21-12-2013', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (138, to_date('24-12-2013', 'dd-mm-yyyy'), 880, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (139, to_date('27-12-2013', 'dd-mm-yyyy'), 900, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (140, to_date('28-12-2013', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (141, to_date('01-01-2014', 'dd-mm-yyyy'), 950, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (142, to_date('01-01-2014', 'dd-mm-yyyy'), 990, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (143, to_date('01-01-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (144, to_date('02-01-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (145, to_date('05-01-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (146, to_date('06-01-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (147, to_date('08-01-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (148, to_date('08-01-2014', 'dd-mm-yyyy'), 800, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (149, to_date('08-01-2014', 'dd-mm-yyyy'), 970, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (150, to_date('10-01-2014', 'dd-mm-yyyy'), 980, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (151, to_date('12-01-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (152, to_date('12-01-2014', 'dd-mm-yyyy'), 720, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (153, to_date('12-01-2014', 'dd-mm-yyyy'), 900, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (154, to_date('14-01-2014', 'dd-mm-yyyy'), 880, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (155, to_date('15-01-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (156, to_date('15-01-2014', 'dd-mm-yyyy'), 500, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (157, to_date('15-01-2014', 'dd-mm-yyyy'), 990, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (158, to_date('16-01-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (159, to_date('18-01-2014', 'dd-mm-yyyy'), 940, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (160, to_date('20-01-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (161, to_date('20-01-2014', 'dd-mm-yyyy'), 820, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (162, to_date('21-01-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (163, to_date('25-01-2014', 'dd-mm-yyyy'), 850, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (164, to_date('28-01-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (165, to_date('01-02-2014', 'dd-mm-yyyy'), 790, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (166, to_date('01-02-2014', 'dd-mm-yyyy'), 860, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (167, to_date('01-02-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (168, to_date('02-02-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (169, to_date('05-02-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (170, to_date('06-02-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (171, to_date('08-02-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (172, to_date('12-02-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (173, to_date('15-02-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (174, to_date('16-02-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (175, to_date('20-02-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (176, to_date('21-02-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (177, to_date('28-02-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (178, to_date('01-03-2014', 'dd-mm-yyyy'), 750, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (179, to_date('01-03-2014', 'dd-mm-yyyy'), 940, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (180, to_date('01-03-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (181, to_date('02-03-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (182, to_date('05-03-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (183, to_date('06-03-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (184, to_date('08-03-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (185, to_date('11-03-2014', 'dd-mm-yyyy'), -20000, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (186, to_date('12-03-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (187, to_date('15-03-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (188, to_date('16-03-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (189, to_date('20-03-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (190, to_date('21-03-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (191, to_date('28-03-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (192, to_date('01-04-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (193, to_date('02-04-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (194, to_date('05-04-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (195, to_date('06-04-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (196, to_date('08-04-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (197, to_date('12-04-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (198, to_date('15-04-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (199, to_date('16-04-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (200, to_date('20-04-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (201, to_date('21-04-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (202, to_date('28-04-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (203, to_date('01-05-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (204, to_date('02-05-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (205, to_date('05-05-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (206, to_date('06-05-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (207, to_date('08-05-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (208, to_date('12-05-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (209, to_date('15-05-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (210, to_date('16-05-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (211, to_date('20-05-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (212, to_date('21-05-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (213, to_date('28-05-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (214, to_date('01-06-2014', 'dd-mm-yyyy'), 3000, 'Gehalt');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (215, to_date('02-06-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (216, to_date('05-06-2014', 'dd-mm-yyyy'), -100, 'Internet+Telefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (217, to_date('06-06-2014', 'dd-mm-yyyy'), -50, 'Mobiltelefon');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (218, to_date('08-06-2014', 'dd-mm-yyyy'), -456, 'Versicherungen');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (219, to_date('12-06-2014', 'dd-mm-yyyy'), -222, 'Amex');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (220, to_date('15-06-2014', 'dd-mm-yyyy'), -300, 'Stadtwerke');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (221, to_date('16-06-2014', 'dd-mm-yyyy'), -400, 'Barabhebung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (222, to_date('20-06-2014', 'dd-mm-yyyy'), -123, 'berweisung');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (223, to_date('21-06-2014', 'dd-mm-yyyy'), -444, 'Visa');
insert into LAUNDERING_ACCOUNT (transaction_nr, booking_date, amount, text)
values (224, to_date('28-06-2014', 'dd-mm-yyyy'), -420, 'Dauerauftrag');
commit;
prompt 224 records loaded
prompt Loading MEIERS...
insert into MEIERS (name)
values ('Dimpflhuber');
insert into MEIERS (name)
values ('Dimpflmayr');
insert into MEIERS (name)
values ('Donnermaier');
insert into MEIERS (name)
values ('Vordermayer');
insert into MEIERS (name)
values ('Mittermeier');
insert into MEIERS (name)
values ('Hintermaier');
insert into MEIERS (name)
values ('Magyar');
insert into MEIERS (name)
values ('Maier');
insert into MEIERS (name)
values ('Mayer');
insert into MEIERS (name)
values ('Mayr');
insert into MEIERS (name)
values ('Mayrhuber');
insert into MEIERS (name)
values ('Meier');
insert into MEIERS (name)
values ('Meierhans');
insert into MEIERS (name)
values ('Mejer');
insert into MEIERS (name)
values ('Meyer');
insert into MEIERS (name)
values ('Moier');
insert into MEIERS (name)
values ('Mller');
insert into MEIERS (name)
values ('Muyer');
insert into MEIERS (name)
values ('Schmitz');
insert into MEIERS (name)
values ('Schulze');
insert into MEIERS (name)
values ('Myr');
commit;
prompt 21 records loaded
prompt Loading REALCHARTS...
prompt Table is empty
prompt Loading RESULTS...
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1990', 'dd-mm-yyyy'), 'CORP1', 100000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1991', 'dd-mm-yyyy'), 'CORP1', 150000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1992', 'dd-mm-yyyy'), 'CORP1', 160000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1993', 'dd-mm-yyyy'), 'CORP1', 200000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1994', 'dd-mm-yyyy'), 'CORP1', 170000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1995', 'dd-mm-yyyy'), 'CORP1', 130000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1996', 'dd-mm-yyyy'), 'CORP1', 190000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1997', 'dd-mm-yyyy'), 'CORP1', 160000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1998', 'dd-mm-yyyy'), 'CORP1', 200000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1999', 'dd-mm-yyyy'), 'CORP1', 140000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2000', 'dd-mm-yyyy'), 'CORP1', 120000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2001', 'dd-mm-yyyy'), 'CORP1', 90000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2002', 'dd-mm-yyyy'), 'CORP1', 100000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2003', 'dd-mm-yyyy'), 'CORP1', 110000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2004', 'dd-mm-yyyy'), 'CORP1', 150000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2005', 'dd-mm-yyyy'), 'CORP1', 140000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2006', 'dd-mm-yyyy'), 'CORP1', 160000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2007', 'dd-mm-yyyy'), 'CORP1', 180000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2008', 'dd-mm-yyyy'), 'CORP1', 200000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2009', 'dd-mm-yyyy'), 'CORP1', 210000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1990', 'dd-mm-yyyy'), 'CORP2', 127000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1991', 'dd-mm-yyyy'), 'CORP2', 151000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1992', 'dd-mm-yyyy'), 'CORP2', 126000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1993', 'dd-mm-yyyy'), 'CORP2', 224000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1994', 'dd-mm-yyyy'), 'CORP2', 208000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1995', 'dd-mm-yyyy'), 'CORP2', 169000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1996', 'dd-mm-yyyy'), 'CORP2', 214000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1997', 'dd-mm-yyyy'), 'CORP2', 144000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1998', 'dd-mm-yyyy'), 'CORP2', 167000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1999', 'dd-mm-yyyy'), 'CORP2', 153000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2000', 'dd-mm-yyyy'), 'CORP2', 92000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2001', 'dd-mm-yyyy'), 'CORP2', 75000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2002', 'dd-mm-yyyy'), 'CORP2', 119000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2003', 'dd-mm-yyyy'), 'CORP2', 135000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2004', 'dd-mm-yyyy'), 'CORP2', 134000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2005', 'dd-mm-yyyy'), 'CORP2', 122000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2006', 'dd-mm-yyyy'), 'CORP2', 152000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2007', 'dd-mm-yyyy'), 'CORP2', 198000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2008', 'dd-mm-yyyy'), 'CORP2', 164000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2009', 'dd-mm-yyyy'), 'CORP2', 241000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1990', 'dd-mm-yyyy'), 'CORP3', 123000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1991', 'dd-mm-yyyy'), 'CORP3', 173000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1992', 'dd-mm-yyyy'), 'CORP3', 209000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1993', 'dd-mm-yyyy'), 'CORP3', 222000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1994', 'dd-mm-yyyy'), 'CORP3', 213000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1995', 'dd-mm-yyyy'), 'CORP3', 166000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1996', 'dd-mm-yyyy'), 'CORP3', 144000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1997', 'dd-mm-yyyy'), 'CORP3', 159000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1998', 'dd-mm-yyyy'), 'CORP3', 227000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-1999', 'dd-mm-yyyy'), 'CORP3', 129000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2000', 'dd-mm-yyyy'), 'CORP3', 74000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2001', 'dd-mm-yyyy'), 'CORP3', 124000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2002', 'dd-mm-yyyy'), 'CORP3', 103000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2003', 'dd-mm-yyyy'), 'CORP3', 129000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2004', 'dd-mm-yyyy'), 'CORP3', 167000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2005', 'dd-mm-yyyy'), 'CORP3', 117000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2006', 'dd-mm-yyyy'), 'CORP3', 129000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2007', 'dd-mm-yyyy'), 'CORP3', 151000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2008', 'dd-mm-yyyy'), 'CORP3', 193000);
insert into RESULTS (year, corp, revenue)
values (to_date('01-07-2009', 'dd-mm-yyyy'), 'CORP3', 252000);
commit;
prompt 60 records loaded
prompt Loading REVENUE...
insert into REVENUE (revenue)
values (2272710);
insert into REVENUE (revenue)
values (3575821);
insert into REVENUE (revenue)
values (3072669);
insert into REVENUE (revenue)
values (5034199);
insert into REVENUE (revenue)
values (5637042);
insert into REVENUE (revenue)
values (8668806);
insert into REVENUE (revenue)
values (10025079);
insert into REVENUE (revenue)
values (8309954);
insert into REVENUE (revenue)
values (4115310);
insert into REVENUE (revenue)
values (4477235);
insert into REVENUE (revenue)
values (6305605);
insert into REVENUE (revenue)
values (9741897);
insert into REVENUE (revenue)
values (6848440);
insert into REVENUE (revenue)
values (7736724);
insert into REVENUE (revenue)
values (11188108);
commit;
prompt 15 records loaded
prompt Loading REVYEAR...
insert into REVYEAR (calyear, revenue)
values (1999, 2272710);
insert into REVYEAR (calyear, revenue)
values (2000, 3575821);
insert into REVYEAR (calyear, revenue)
values (2001, 3072669);
insert into REVYEAR (calyear, revenue)
values (2002, 5034199);
insert into REVYEAR (calyear, revenue)
values (2003, 5637042);
insert into REVYEAR (calyear, revenue)
values (2004, 8668806);
insert into REVYEAR (calyear, revenue)
values (2005, 10025079);
insert into REVYEAR (calyear, revenue)
values (2006, 8309954);
insert into REVYEAR (calyear, revenue)
values (2007, 4115310);
insert into REVYEAR (calyear, revenue)
values (2008, 4477235);
insert into REVYEAR (calyear, revenue)
values (2009, 6305605);
insert into REVYEAR (calyear, revenue)
values (2010, 9741897);
insert into REVYEAR (calyear, revenue)
values (2011, 6848440);
insert into REVYEAR (calyear, revenue)
values (2012, 7736724);
insert into REVYEAR (calyear, revenue)
values (2013, 11188108);
commit;
prompt 15 records loaded
prompt Loading RUSSIAN_BUSINESS...
insert into RUSSIAN_BUSINESS (name)
values ('Cornel');
insert into RUSSIAN_BUSINESS (name)
values ('Emil');
insert into RUSSIAN_BUSINESS (name)
values ('Maksim');
insert into RUSSIAN_BUSINESS (name)
values ('Dimitri');
insert into RUSSIAN_BUSINESS (name)
values ('Wladimir');
commit;
prompt 5 records loaded
prompt Enabling foreign key constraints for FKT_SALES...
alter table FKT_SALES enable constraint FK_COLOUR;
alter table FKT_SALES enable constraint FK_DATE;
alter table FKT_SALES enable constraint FK_MATERIAL;
alter table FKT_SALES enable constraint FK_SHAPE;
prompt Enabling foreign key constraints for INVOICES...
alter table INVOICES enable constraint CUSTOMERS_INVOICES;
prompt Enabling foreign key constraints for PRODUCTS...
alter table PRODUCTS enable constraint PRODCOLOURSPRODUCTS;
alter table PRODUCTS enable constraint PRODFORMSPRODUCTS;
alter table PRODUCTS enable constraint PRODMATERIALPRODUCTS;
prompt Enabling foreign key constraints for INVLINES...
alter table INVLINES enable constraint INVOICESINVDETAILS;
alter table INVLINES enable constraint PRODUCTSINVDETAILS;
prompt Enabling triggers for CHARTS...
alter table CHARTS enable all triggers;
prompt Enabling triggers for CUSTOMERS...
alter table CUSTOMERS enable all triggers;
prompt Enabling triggers for DIM_COLOUR...
alter table DIM_COLOUR enable all triggers;
prompt Enabling triggers for DIM_DATE...
alter table DIM_DATE enable all triggers;
prompt Enabling triggers for DIM_MATERIAL...
alter table DIM_MATERIAL enable all triggers;
prompt Enabling triggers for DIM_SHAPE...
alter table DIM_SHAPE enable all triggers;
prompt Enabling triggers for FINRESULTS...
alter table FINRESULTS enable all triggers;
prompt Enabling triggers for FKT_SALES...
alter table FKT_SALES enable all triggers;
prompt Enabling triggers for INVOICES...
alter table INVOICES enable all triggers;
prompt Enabling triggers for PRODCOLOURS...
alter table PRODCOLOURS enable all triggers;
prompt Enabling triggers for PRODFORMS...
alter table PRODFORMS enable all triggers;
prompt Enabling triggers for PRODMATERIAL...
alter table PRODMATERIAL enable all triggers;
prompt Enabling triggers for PRODUCTS...
alter table PRODUCTS enable all triggers;
prompt Enabling triggers for INVLINES...
alter table INVLINES enable all triggers;
prompt Enabling triggers for LAUNDERING_ACCOUNT...
alter table LAUNDERING_ACCOUNT enable all triggers;
prompt Enabling triggers for MEIERS...
alter table MEIERS enable all triggers;
prompt Enabling triggers for REALCHARTS...
alter table REALCHARTS enable all triggers;
prompt Enabling triggers for RESULTS...
alter table RESULTS enable all triggers;
prompt Enabling triggers for REVENUE...
alter table REVENUE enable all triggers;
prompt Enabling triggers for REVYEAR...
alter table REVYEAR enable all triggers;
prompt Enabling triggers for RUSSIAN_BUSINESS...
alter table RUSSIAN_BUSINESS enable all triggers;
set feedback on
set define on
prompt Done.
